(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1254775,      26372]
NotebookOptionsPosition[   1234300,      25795]
NotebookOutlinePosition[   1235433,      25832]
CellTagsIndexPosition[   1235164,      25823]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Examples", "Section",
 CellChangeTimes->{{3.505367011632235*^9, 3.5053670125982447`*^9}}],

Cell[CellGroupData[{

Cell["Tests", "Subsection",
 CellChangeTimes->{{3.50557494488837*^9, 3.505574945299773*^9}}],

Cell[CellGroupData[{

Cell["?Permutations", "Input",
 CellChangeTimes->{{3.505570594841681*^9, 3.50557060231329*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Permutations\\\", \\\"[\\\", \
StyleBox[\\\"list\\\", \\\"TI\\\"], \\\"]\\\"}]\) generates a list of all \
possible permutations of the elements in \!\(\*StyleBox[\\\"list\\\", \
\\\"TI\\\"]\). \\n\!\(\*RowBox[{\\\"Permutations\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\) gives all permutations containing at most \
\!\(\*StyleBox[\\\"n\\\", \\\"TI\\\"]\) \
elements.\\n\!\(\*RowBox[{\\\"Permutations\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
StyleBox[\\\"n\\\", \\\"TI\\\"], \\\"}\\\"}]}], \\\"]\\\"}]\) gives all \
permutations containing exactly \!\(\*StyleBox[\\\"n\\\", \\\"TI\\\"]\) \
elements.\"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Permutations"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.505574927948792*^9},
 CellTags->"Info3505553327-7028263"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ReadSurfaces[{SphericalMirror[100,{50,50},OffAxis->{15,0}],Move[\
SphericalMirror[100,50],50]},{SurfaceFunction,SurfaceBoundary,OffAxis}]\
\>", "Input",
 CellChangeTimes->{{3.5055737030325537`*^9, 3.5055737275978737`*^9}, {
  3.505573784556095*^9, 3.505573784638736*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SqrtBox[
             RowBox[{"10000", "-", 
              SuperscriptBox["#1", "2"], "-", 
              SuperscriptBox["#2", "2"]}]]}], "+", "100"}], ",", "#1", ",", 
          "#2"}], "}"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"50.`", ",", "50.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "0"}], "}"}]}], "}"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SqrtBox[
             RowBox[{"10000", "-", 
              SuperscriptBox["#1", "2"], "-", 
              SuperscriptBox["#2", "2"]}]]}], "+", "100"}], ",", "#1", ",", 
          "#2"}], "}"}], "&"}], ",", "50.`", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5055737285695047`*^9, 3.50557378602652*^9, 
  3.505574928319886*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{SphericalMirror[100,{50,50},OffAxis->{15,0}],Move[SphericalMirror[\
100,{50,50}],50]},PlotType->TopView,Frame->True]\
\>", "Input",
 CellChangeTimes->{{3.50557355662646*^9, 3.505573621190858*^9}, {
  3.505573660249529*^9, 3.5055736690869904`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.5012562893380021, -10.}, {0.5012562893380021, -10.}, {
      0.0138898535290366, -1.6666666666666714`}, {
      0.0138898535290366, -1.6666666666666679`}, {0.5012562893380021, -10.}}],
      PolygonBox[{{0.0138898535290366, -1.6666666666666679`}, {
      0.0138898535290366, -1.6666666666666714`}, {0.22246968602823358`, 
      6.666666666666664}, {0.22246968602823358`, 6.666666666666664}, {
      0.0138898535290366, -1.6666666666666679`}}], 
     PolygonBox[{{0.22246968602823358`, 6.666666666666664}, {
      0.22246968602823358`, 6.666666666666664}, {1.1314003335740637`, 
      14.999999999999993`}, {1.1314003335740637`, 15.}, {0.22246968602823358`,
       6.666666666666664}}], 
     PolygonBox[{{1.1314003335740637`, 15.}, {1.1314003335740637`, 15.}, {
      2.7603190279011898`, 23.333333333333332`}, {2.7603190279011898`, 
      23.33333333333333}, {1.1314003335740637`, 15.}}], 
     PolygonBox[{{2.7603190279011898`, 23.33333333333333}, {
      2.7603190279011898`, 23.333333333333332`}, {5.146311499118696, 
      31.666666666666664`}, {5.146311499118696, 31.666666666666664`}, {
      2.7603190279011898`, 23.33333333333333}}], 
     PolygonBox[{{5.146311499118696, 31.666666666666664`}, {5.146311499118696,
       31.666666666666664`}, {8.348486100883207, 40.}, {8.348486100883207, 
      39.99999999999999}, {5.146311499118696, 31.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5012562893380021, -10.}, {
       0.0138898535290366, -1.6666666666666679`}, {0.22246968602823358`, 
       6.666666666666664}, {1.1314003335740637`, 14.999999999999996`}, {
       2.7603190279011898`, 23.33333333333333}, {5.146311499118696, 
       31.666666666666657`}, {8.348486100883207, 39.99999999999999}, {
       8.348486100883207, 40.}, {5.146311499118696, 31.666666666666668`}, {
       2.7603190279011898`, 23.333333333333336`}, {1.1314003335740637`, 
       15.000000000000004`}, {0.22246968602823358`, 6.666666666666671}, {
       0.0138898535290366, -1.6666666666666572`}, {
       0.5012562893380021, -9.999999999999993}, {
       0.5012562893380021, -10.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.344367651455045, 15.}, {4.344367651455045, 
        15.000000000000004`}, {2.5463072930418775`, 15.000000000000002`}, {
        2.5463072930418775`, 15.}, {4.344367651455045, 15.}}], 
       PolygonBox[{{2.5463072930418775`, 15.}, {2.5463072930418775`, 
        15.000000000000002`}, {1.4832219591223463`, 15.000000000000002`}, {
        1.4832219591223463`, 15.000000000000002`}, {2.5463072930418775`, 
        15.}}], PolygonBox[{{1.4832219591223463`, 15.000000000000002`}, {
        1.4832219591223463`, 15.000000000000002`}, {1.1314003335740637`, 
        15.000000000000002`}, {1.1314003335740637`, 15.000000000000002`}, {
        1.4832219591223463`, 15.000000000000002`}}], 
       PolygonBox[{{1.1314003335740637`, 15.000000000000002`}, {
        1.1314003335740637`, 15.000000000000002`}, {1.4832219591223463`, 
        15.000000000000002`}, {1.4832219591223463`, 15.000000000000002`}, {
        1.1314003335740637`, 15.000000000000002`}}], 
       PolygonBox[{{1.4832219591223463`, 15.000000000000002`}, {
        1.4832219591223463`, 15.000000000000002`}, {2.5463072930418775`, 
        15.}, {2.5463072930418775`, 15.000000000000002`}, {
        1.4832219591223463`, 15.000000000000002`}}], 
       PolygonBox[{{2.5463072930418775`, 15.000000000000002`}, {
        2.5463072930418775`, 15.}, {4.344367651455045, 15.}, {
        4.344367651455045, 15.000000000000004`}, {2.5463072930418775`, 
        15.000000000000002`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.344367651455045, 15.}, {2.5463072930418775`, 15.}, {
         1.4832219591223463`, 15.}, {1.1314003335740637`, 15.}, {
         1.4832219591223463`, 15.}, {2.5463072930418775`, 15.}, {
         4.344367651455045, 15.}, {4.344367651455045, 15.}, {
         2.5463072930418775`, 15.}, {1.4832219591223463`, 15.}, {
         1.1314003335740637`, 15.}, {1.4832219591223463`, 15.}, {
         2.5463072930418775`, 15.}, {4.344367651455045, 15.}, {
         4.344367651455045, 15.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.6931985787088877`, -10.}, {
      3.189761790282617, -1.6666666666666643`}, {
      1.4127571921983133`, -1.6666666666666643`}, {
      1.9070735362522555`, -10.}, {3.6931985787088877`, -10.}}], 
     PolygonBox[{{1.9070735362522555`, -10.}, {
      1.4127571921983133`, -1.6666666666666643`}, {
      0.36176548243251716`, -1.6666666666666643`}, {
      0.8508418817610135, -10.}, {1.9070735362522555`, -10.}}], 
     PolygonBox[{{0.8508418817610135, -10.}, {
      0.36176548243251716`, -1.6666666666666643`}, {
      0.0138898535290366, -1.6666666666666643`}, {0.5012562893380021, -10.}, {
      0.8508418817610135, -10.}}], 
     PolygonBox[{{0.5012562893380021, -10.}, {
      0.0138898535290366, -1.6666666666666643`}, {
      0.36176548243251716`, -1.6666666666666643`}, {
      0.8508418817610135, -10.}, {0.5012562893380021, -10.}}], 
     PolygonBox[{{0.8508418817610135, -10.}, {
      0.36176548243251716`, -1.6666666666666643`}, {
      1.4127571921983133`, -1.6666666666666643`}, {
      1.9070735362522555`, -10.}, {0.8508418817610135, -10.}}], 
     PolygonBox[{{1.9070735362522555`, -10.}, {
      1.4127571921983133`, -1.6666666666666643`}, {
      3.189761790282617, -1.6666666666666643`}, {3.6931985787088877`, -10.}, {
      1.9070735362522555`, -10.}}], 
     PolygonBox[{{3.189761790282617, -1.6666666666666643`}, {
      3.405199127719328, 6.66666666666667}, {1.624302910841962, 
      6.66666666666667}, {1.4127571921983133`, -1.6666666666666643`}, {
      3.189761790282617, -1.6666666666666643`}}], 
     PolygonBox[{{1.4127571921983133`, -1.6666666666666643`}, {
      1.624302910841962, 6.66666666666667}, {0.5710750781689882, 
      6.66666666666667}, {0.36176548243251716`, -1.6666666666666643`}, {
      1.4127571921983133`, -1.6666666666666643`}}], 
     PolygonBox[{{0.36176548243251716`, -1.6666666666666643`}, {
      0.5710750781689882, 6.66666666666667}, {0.22246968602823358`, 
      6.66666666666667}, {0.0138898535290366, -1.6666666666666643`}, {
      0.36176548243251716`, -1.6666666666666643`}}], 
     PolygonBox[{{0.0138898535290366, -1.6666666666666643`}, {
      0.22246968602823358`, 6.66666666666667}, {0.5710750781689882, 
      6.66666666666667}, {0.36176548243251716`, -1.6666666666666643`}, {
      0.0138898535290366, -1.6666666666666643`}}], 
     PolygonBox[{{0.36176548243251716`, -1.6666666666666643`}, {
      0.5710750781689882, 6.66666666666667}, {1.624302910841962, 
      6.66666666666667}, {1.4127571921983133`, -1.6666666666666643`}, {
      0.36176548243251716`, -1.6666666666666643`}}], 
     PolygonBox[{{1.4127571921983133`, -1.6666666666666643`}, {
      1.624302910841962, 6.66666666666667}, {3.405199127719328, 
      6.66666666666667}, {3.189761790282617, -1.6666666666666643`}, {
      1.4127571921983133`, -1.6666666666666643`}}], 
     PolygonBox[{{3.405199127719328, 6.666666666666668}, {4.344367651455045, 
      15.000000000000002`}, {2.5463072930418775`, 15.000000000000002`}, {
      1.624302910841962, 6.666666666666668}, {3.405199127719328, 
      6.666666666666668}}], 
     PolygonBox[{{1.624302910841962, 6.666666666666668}, {2.5463072930418775`,
       15.000000000000002`}, {1.4832219591223463`, 15.000000000000002`}, {
      0.5710750781689882, 6.666666666666668}, {1.624302910841962, 
      6.666666666666668}}], 
     PolygonBox[{{0.5710750781689882, 6.666666666666668}, {
      1.4832219591223463`, 15.000000000000002`}, {1.1314003335740637`, 
      15.000000000000002`}, {0.22246968602823358`, 6.666666666666668}, {
      0.5710750781689882, 6.666666666666668}}], 
     PolygonBox[{{0.22246968602823358`, 6.666666666666668}, {
      1.1314003335740637`, 15.000000000000002`}, {1.4832219591223463`, 
      15.000000000000002`}, {0.5710750781689882, 6.666666666666668}, {
      0.22246968602823358`, 6.666666666666668}}], 
     PolygonBox[{{0.5710750781689882, 6.666666666666668}, {
      1.4832219591223463`, 15.000000000000002`}, {2.5463072930418775`, 
      15.000000000000002`}, {1.624302910841962, 6.666666666666668}, {
      0.5710750781689882, 6.666666666666668}}], 
     PolygonBox[{{1.624302910841962, 6.666666666666668}, {2.5463072930418775`,
       15.000000000000002`}, {4.344367651455045, 15.000000000000002`}, {
      3.405199127719328, 6.666666666666668}, {1.624302910841962, 
      6.666666666666668}}], 
     PolygonBox[{{4.344367651455045, 15.}, {6.028964273263682, 
      23.333333333333336`}, {4.1992809120005745`, 23.333333333333336`}, {
      2.5463072930418775`, 15.}, {4.344367651455045, 15.}}], 
     PolygonBox[{{2.5463072930418775`, 15.}, {4.1992809120005745`, 
      23.333333333333336`}, {3.118055804442548, 23.333333333333336`}, {
      1.4832219591223463`, 15.}, {2.5463072930418775`, 15.}}], 
     PolygonBox[{{1.4832219591223463`, 15.}, {3.118055804442548, 
      23.333333333333336`}, {2.7603190279011898`, 23.333333333333336`}, {
      1.1314003335740637`, 15.}, {1.4832219591223463`, 15.}}], 
     PolygonBox[{{1.1314003335740637`, 15.}, {2.7603190279011898`, 
      23.333333333333336`}, {3.118055804442548, 23.333333333333336`}, {
      1.4832219591223463`, 15.}, {1.1314003335740637`, 15.}}], 
     PolygonBox[{{1.4832219591223463`, 15.}, {3.118055804442548, 
      23.333333333333336`}, {4.1992809120005745`, 23.333333333333336`}, {
      2.5463072930418775`, 15.}, {1.4832219591223463`, 15.}}], 
     PolygonBox[{{2.5463072930418775`, 15.}, {4.1992809120005745`, 
      23.333333333333336`}, {6.028964273263682, 23.333333333333336`}, {
      4.344367651455045, 15.}, {2.5463072930418775`, 15.}}], 
     PolygonBox[{{6.028964273263682, 23.333333333333336`}, {8.500151791261302,
       31.66666666666667}, {6.622034481123734, 31.66666666666667}, {
      4.1992809120005745`, 23.333333333333336`}, {6.028964273263682, 
      23.333333333333336`}}], 
     PolygonBox[{{4.1992809120005745`, 23.333333333333336`}, {
      6.622034481123734, 31.66666666666667}, {5.5130814462775675`, 
      31.66666666666667}, {3.118055804442548, 23.333333333333336`}, {
      4.1992809120005745`, 23.333333333333336`}}], 
     PolygonBox[{{3.118055804442548, 23.333333333333336`}, {
      5.5130814462775675`, 31.66666666666667}, {5.146311499118696, 
      31.66666666666667}, {2.7603190279011898`, 23.333333333333336`}, {
      3.118055804442548, 23.333333333333336`}}], 
     PolygonBox[{{2.7603190279011898`, 23.333333333333336`}, {
      5.146311499118696, 31.66666666666667}, {5.5130814462775675`, 
      31.66666666666667}, {3.118055804442548, 23.333333333333336`}, {
      2.7603190279011898`, 23.333333333333336`}}], 
     PolygonBox[{{3.118055804442548, 23.333333333333336`}, {
      5.5130814462775675`, 31.66666666666667}, {6.622034481123734, 
      31.66666666666667}, {4.1992809120005745`, 23.333333333333336`}, {
      3.118055804442548, 23.333333333333336`}}], 
     PolygonBox[{{4.1992809120005745`, 23.333333333333336`}, {
      6.622034481123734, 31.66666666666667}, {8.500151791261302, 
      31.66666666666667}, {6.028964273263682, 23.333333333333336`}, {
      4.1992809120005745`, 23.333333333333336`}}], 
     PolygonBox[{{8.500151791261302, 31.66666666666667}, {11.824039557258004`,
       40.00000000000001}, {9.876627769361505, 40.00000000000001}, {
      6.622034481123734, 31.66666666666667}, {8.500151791261302, 
      31.66666666666667}}], 
     PolygonBox[{{6.622034481123734, 31.66666666666667}, {9.876627769361505, 
      40.00000000000001}, {8.72812286604622, 40.00000000000001}, {
      5.5130814462775675`, 31.66666666666667}, {6.622034481123734, 
      31.66666666666667}}], 
     PolygonBox[{{5.5130814462775675`, 31.66666666666667}, {8.72812286604622, 
      40.00000000000001}, {8.348486100883207, 40.00000000000001}, {
      5.146311499118696, 31.66666666666667}, {5.5130814462775675`, 
      31.66666666666667}}], 
     PolygonBox[{{5.146311499118696, 31.66666666666667}, {8.348486100883207, 
      40.00000000000001}, {8.72812286604622, 40.00000000000001}, {
      5.5130814462775675`, 31.66666666666667}, {5.146311499118696, 
      31.66666666666667}}], 
     PolygonBox[{{5.5130814462775675`, 31.66666666666667}, {8.72812286604622, 
      40.00000000000001}, {9.876627769361505, 40.00000000000001}, {
      6.622034481123734, 31.66666666666667}, {5.5130814462775675`, 
      31.66666666666667}}], 
     PolygonBox[{{6.622034481123734, 31.66666666666667}, {9.876627769361505, 
      40.00000000000001}, {11.824039557258004`, 40.00000000000001}, {
      8.500151791261302, 31.66666666666667}, {6.622034481123734, 
      31.66666666666667}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQfaDRc9Pqbl4HBjBQObAgKurKwhZOhwWrQODX/gMJ
/lw3bbkd1oD5Ug4fjB6/XJggCFWv58CwrvL8ClkJh7BQEDB3mMHo+lSYQRGq
3t5BQdCr+cVSdah6Fwz+gogHUVcPKMP5F9yMWs+UKCL453SO5mxSwCmPrp+Q
fTD3rYK6D+b+UKj70f0H8/8KqP9h4XMAFj5o4YfOZwgJ6Ypv/mcP4zcksh+U
sHqN4N83XujF9QCnPLp+dPMBE72P2g==
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{53.17541634481458, -25.}, {53.17541634481458, -25.}, {
      51.39867028167306, -16.66666666666667}, {
      51.39867028167306, -16.666666666666668`}, {53.17541634481458, -25.}}], 
     PolygonBox[{{51.39867028167306, -16.666666666666668`}, {
      51.39867028167306, -16.66666666666667}, {
      50.34782714082169, -8.333333333333336}, {
      50.34782714082169, -8.333333333333336}, {
      51.39867028167306, -16.666666666666668`}}], 
     PolygonBox[{{50.34782714082169, -8.333333333333336}, {
      50.34782714082169, -8.333333333333336}, {
      50., -7.105427357601002*^-15}, {50., 0.}, {
      50.34782714082169, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {50., 0.}, {50.34782714082169, 
      8.333333333333332}, {50.34782714082169, 8.333333333333329}, {50., 0.}}],
      PolygonBox[{{50.34782714082169, 8.333333333333329}, {50.34782714082169, 
      8.333333333333332}, {51.39867028167306, 16.666666666666664`}, {
      51.39867028167306, 16.666666666666664`}, {50.34782714082169, 
      8.333333333333329}}], 
     PolygonBox[{{51.39867028167306, 16.666666666666664`}, {51.39867028167306,
       16.666666666666664`}, {53.17541634481458, 24.999999999999996`}, {
      53.17541634481458, 24.999999999999993`}, {51.39867028167306, 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{53.17541634481458, -25.}, {
       51.39867028167306, -16.666666666666668`}, {
       50.34782714082169, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.34782714082169, 
       8.333333333333329}, {51.39867028167306, 16.666666666666657`}, {
       53.17541634481458, 24.999999999999993`}, {53.17541634481458, 25.}, {
       51.39867028167306, 16.666666666666668`}, {50.34782714082169, 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50.34782714082169, -8.333333333333329}, {
       51.39867028167306, -16.666666666666657`}, {
       53.17541634481458, -24.999999999999993`}, {
       53.17541634481458, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{53.17541634481458, 0.}, {53.17541634481458, 
        3.061616997868383*^-15}, {51.39867028167306, 
        2.551347498223653*^-15}, {51.39867028167306, 
        5.102694996447305*^-16}, {53.17541634481458, 0.}}], 
       PolygonBox[{{51.39867028167306, 5.102694996447305*^-16}, {
        51.39867028167306, 2.551347498223653*^-15}, {50.34782714082169, 
        2.0410779985789223`*^-15}, {50.34782714082169, 
        1.020538999289461*^-15}, {51.39867028167306, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.34782714082169, 1.020538999289461*^-15}, {
        50.34782714082169, 2.0410779985789223`*^-15}, {50., 
        1.530808498934192*^-15}, {50., 1.5308084989341915`*^-15}, {
        50.34782714082169, 1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.34782714082169, 
        1.0205389992894611`*^-15}, {50.34782714082169, 
        2.041077998578922*^-15}, {50., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.34782714082169, 2.041077998578922*^-15}, {
        50.34782714082169, 1.0205389992894611`*^-15}, {51.39867028167306, 
        5.102694996447307*^-16}, {51.39867028167306, 
        2.5513474982236525`*^-15}, {50.34782714082169, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{51.39867028167306, 2.5513474982236525`*^-15}, {
        51.39867028167306, 5.102694996447308*^-16}, {53.17541634481458, 
        2.5493082627129206`*^-31}, {53.17541634481458, 
        3.0616169978683826`*^-15}, {51.39867028167306, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{53.17541634481458, 0.}, {51.39867028167306, 0.}, {
         50.34782714082169, 0.}, {50., 0.}, {50.34782714082169, 0.}, {
         51.39867028167306, 0.}, {53.17541634481458, 0.}, {53.17541634481458, 
         0.}, {51.39867028167306, 0.}, {50.34782714082169, 0.}, {50., 0.}, {
         50.34782714082169, 0.}, {51.39867028167306, 0.}, {53.17541634481458, 
         0.}, {53.17541634481458, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.45856533065147, -25.}, {
      54.62064048117003, -16.666666666666664`}, {
      52.81746841924499, -16.666666666666664`}, {54.62064048117003, -25.}, {
      56.45856533065147, -25.}}], 
     PolygonBox[{{54.62064048117003, -25.}, {
      52.81746841924499, -16.666666666666664`}, {
      51.751448978736704`, -16.666666666666664`}, {53.53469247674812, -25.}, {
      54.62064048117003, -25.}}], 
     PolygonBox[{{53.53469247674812, -25.}, {
      51.751448978736704`, -16.666666666666664`}, {
      51.39867028167306, -16.666666666666664`}, {53.17541634481458, -25.}, {
      53.53469247674812, -25.}}], 
     PolygonBox[{{53.17541634481458, -25.}, {
      51.39867028167306, -16.666666666666664`}, {
      51.751448978736704`, -16.666666666666664`}, {53.53469247674812, -25.}, {
      53.17541634481458, -25.}}], 
     PolygonBox[{{53.53469247674812, -25.}, {
      51.751448978736704`, -16.666666666666664`}, {
      52.81746841924499, -16.666666666666664`}, {54.62064048117003, -25.}, {
      53.53469247674812, -25.}}], 
     PolygonBox[{{54.62064048117003, -25.}, {
      52.81746841924499, -16.666666666666664`}, {
      54.62064048117003, -16.666666666666664`}, {56.45856533065147, -25.}, {
      54.62064048117003, -25.}}], 
     PolygonBox[{{54.62064048117003, -16.666666666666664`}, {
      53.53469247674812, -8.33333333333333}, {
      51.751448978736704`, -8.33333333333333}, {
      52.81746841924499, -16.666666666666664`}, {
      54.62064048117003, -16.666666666666664`}}], 
     PolygonBox[{{52.81746841924499, -16.666666666666664`}, {
      51.751448978736704`, -8.33333333333333}, {
      50.69687260155847, -8.33333333333333}, {
      51.751448978736704`, -16.666666666666664`}, {
      52.81746841924499, -16.666666666666664`}}], 
     PolygonBox[{{51.751448978736704`, -16.666666666666664`}, {
      50.69687260155847, -8.33333333333333}, {
      50.34782714082169, -8.33333333333333}, {
      51.39867028167306, -16.666666666666664`}, {
      51.751448978736704`, -16.666666666666664`}}], 
     PolygonBox[{{51.39867028167306, -16.666666666666664`}, {
      50.34782714082169, -8.33333333333333}, {
      50.69687260155847, -8.33333333333333}, {
      51.751448978736704`, -16.666666666666664`}, {
      51.39867028167306, -16.666666666666664`}}], 
     PolygonBox[{{51.751448978736704`, -16.666666666666664`}, {
      50.69687260155847, -8.33333333333333}, {
      51.751448978736704`, -8.33333333333333}, {
      52.81746841924499, -16.666666666666664`}, {
      51.751448978736704`, -16.666666666666664`}}], 
     PolygonBox[{{52.81746841924499, -16.666666666666664`}, {
      51.751448978736704`, -8.33333333333333}, {
      53.53469247674812, -8.33333333333333}, {
      54.62064048117003, -16.666666666666664`}, {
      52.81746841924499, -16.666666666666664`}}], 
     PolygonBox[{{53.53469247674812, -8.333333333333332}, {53.17541634481458, 
      1.7763568394002505`*^-15}, {51.39867028167306, 
      1.7763568394002505`*^-15}, {51.751448978736704`, -8.333333333333332}, {
      53.53469247674812, -8.333333333333332}}], 
     PolygonBox[{{51.751448978736704`, -8.333333333333332}, {
      51.39867028167306, 1.7763568394002505`*^-15}, {50.34782714082169, 
      1.7763568394002505`*^-15}, {50.69687260155847, -8.333333333333332}, {
      51.751448978736704`, -8.333333333333332}}], 
     PolygonBox[{{50.69687260155847, -8.333333333333332}, {50.34782714082169, 
      1.7763568394002505`*^-15}, {50., 1.7763568394002505`*^-15}, {
      50.34782714082169, -8.333333333333332}, {
      50.69687260155847, -8.333333333333332}}], 
     PolygonBox[{{50.34782714082169, -8.333333333333332}, {50., 
      1.7763568394002505`*^-15}, {50.34782714082169, 
      1.7763568394002505`*^-15}, {50.69687260155847, -8.333333333333332}, {
      50.34782714082169, -8.333333333333332}}], 
     PolygonBox[{{50.69687260155847, -8.333333333333332}, {50.34782714082169, 
      1.7763568394002505`*^-15}, {51.39867028167306, 
      1.7763568394002505`*^-15}, {51.751448978736704`, -8.333333333333332}, {
      50.69687260155847, -8.333333333333332}}], 
     PolygonBox[{{51.751448978736704`, -8.333333333333332}, {
      51.39867028167306, 1.7763568394002505`*^-15}, {53.17541634481458, 
      1.7763568394002505`*^-15}, {53.53469247674812, -8.333333333333332}, {
      51.751448978736704`, -8.333333333333332}}], 
     PolygonBox[{{53.17541634481458, 0.}, {53.53469247674812, 
      8.333333333333334}, {51.751448978736704`, 8.333333333333334}, {
      51.39867028167306, 0.}, {53.17541634481458, 0.}}], 
     PolygonBox[{{51.39867028167306, 0.}, {51.751448978736704`, 
      8.333333333333334}, {50.69687260155847, 8.333333333333334}, {
      50.34782714082169, 0.}, {51.39867028167306, 0.}}], 
     PolygonBox[{{50.34782714082169, 0.}, {50.69687260155847, 
      8.333333333333334}, {50.34782714082169, 8.333333333333334}, {50., 0.}, {
      50.34782714082169, 0.}}], 
     PolygonBox[{{50., 0.}, {50.34782714082169, 8.333333333333334}, {
      50.69687260155847, 8.333333333333334}, {50.34782714082169, 0.}, {50., 
      0.}}], PolygonBox[{{50.34782714082169, 0.}, {50.69687260155847, 
      8.333333333333334}, {51.751448978736704`, 8.333333333333334}, {
      51.39867028167306, 0.}, {50.34782714082169, 0.}}], 
     PolygonBox[{{51.39867028167306, 0.}, {51.751448978736704`, 
      8.333333333333334}, {53.53469247674812, 8.333333333333334}, {
      53.17541634481458, 0.}, {51.39867028167306, 0.}}], 
     PolygonBox[{{53.53469247674812, 8.333333333333336}, {54.62064048117003, 
      16.66666666666667}, {52.81746841924499, 16.66666666666667}, {
      51.751448978736704`, 8.333333333333336}, {53.53469247674812, 
      8.333333333333336}}], 
     PolygonBox[{{51.751448978736704`, 8.333333333333336}, {52.81746841924499,
       16.66666666666667}, {51.751448978736704`, 16.66666666666667}, {
      50.69687260155847, 8.333333333333336}, {51.751448978736704`, 
      8.333333333333336}}], 
     PolygonBox[{{50.69687260155847, 8.333333333333336}, {51.751448978736704`,
       16.66666666666667}, {51.39867028167306, 16.66666666666667}, {
      50.34782714082169, 8.333333333333336}, {50.69687260155847, 
      8.333333333333336}}], 
     PolygonBox[{{50.34782714082169, 8.333333333333336}, {51.39867028167306, 
      16.66666666666667}, {51.751448978736704`, 16.66666666666667}, {
      50.69687260155847, 8.333333333333336}, {50.34782714082169, 
      8.333333333333336}}], 
     PolygonBox[{{50.69687260155847, 8.333333333333336}, {51.751448978736704`,
       16.66666666666667}, {52.81746841924499, 16.66666666666667}, {
      51.751448978736704`, 8.333333333333336}, {50.69687260155847, 
      8.333333333333336}}], 
     PolygonBox[{{51.751448978736704`, 8.333333333333336}, {52.81746841924499,
       16.66666666666667}, {54.62064048117003, 16.66666666666667}, {
      53.53469247674812, 8.333333333333336}, {51.751448978736704`, 
      8.333333333333336}}], 
     PolygonBox[{{54.62064048117003, 16.66666666666667}, {56.45856533065147, 
      25.000000000000007`}, {54.62064048117003, 25.000000000000007`}, {
      52.81746841924499, 16.66666666666667}, {54.62064048117003, 
      16.66666666666667}}], 
     PolygonBox[{{52.81746841924499, 16.66666666666667}, {54.62064048117003, 
      25.000000000000007`}, {53.53469247674812, 25.000000000000007`}, {
      51.751448978736704`, 16.66666666666667}, {52.81746841924499, 
      16.66666666666667}}], 
     PolygonBox[{{51.751448978736704`, 16.66666666666667}, {53.53469247674812,
       25.000000000000007`}, {53.17541634481458, 25.000000000000007`}, {
      51.39867028167306, 16.66666666666667}, {51.751448978736704`, 
      16.66666666666667}}], 
     PolygonBox[{{51.39867028167306, 16.66666666666667}, {53.17541634481458, 
      25.000000000000007`}, {53.53469247674812, 25.000000000000007`}, {
      51.751448978736704`, 16.66666666666667}, {51.39867028167306, 
      16.66666666666667}}], 
     PolygonBox[{{51.751448978736704`, 16.66666666666667}, {53.53469247674812,
       25.000000000000007`}, {54.62064048117003, 25.000000000000007`}, {
      52.81746841924499, 16.66666666666667}, {51.751448978736704`, 
      16.66666666666667}}], 
     PolygonBox[{{52.81746841924499, 16.66666666666667}, {54.62064048117003, 
      25.000000000000007`}, {56.45856533065147, 25.000000000000007`}, {
      54.62064048117003, 16.66666666666667}, {52.81746841924499, 
      16.66666666666667}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQLSd71mWTlY8DAxhYHqiYuUW10N/bYRUYGBwoaZt2
tuCIF5SvcOCMyBeukmleUPUMDDD5NRB5B5h+CN/AAc18DD5MPYwPMw/GR7UP
Ux5dP7H2Qf3ngOY/BwL+O4DmvwPo4YcrPGF8NPejhSemPLp+dPMBwrWSXA==

       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"M1\"\>", {0., -26.}, {0., 0.}], 
    InsetBox["\<\"M2\"\>", {50., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5055735862128077`*^9, 3.505573622073042*^9, 
  3.505573670446782*^9, 3.505574928640436*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"ShowSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SphericalMirror", "[", 
         RowBox[{"100", ",", 
          RowBox[{"{", 
           RowBox[{"50", ",", "50"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"OffAxis", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"15", ",", "0"}], "}"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"SphericalMirror", "[", 
           RowBox[{"100", ",", 
            RowBox[{"{", 
             RowBox[{"50", ",", "50"}], "}"}]}], "]"}], ",", "50.`"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.5055735862128077`*^9, 3.505573622073042*^9, 
  3.505573670446782*^9, 3.505574928711944*^9}]
}, Open  ]],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.505573586423758*^9, 3.505573622334688*^9, 
  3.505573670460227*^9, 3.505574928766068*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["1", "Subsection",
 CellChangeTimes->{3.505372334202929*^9}],

Cell[CellGroupData[{

Cell["Surfaces/.Window[{100,100},5]", "Input",
 CellChangeTimes->{{3.505563914667433*^9, 3.5055639175866747`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentID", "\[Rule]", "4133"}], ",", 
     RowBox[{"SurfaceID", "\[Rule]", "4116"}], ",", 
     RowBox[{"SurfaceContinuation", "\[Rule]", "False"}], ",", 
     RowBox[{"SurfaceFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
     RowBox[{"ActiveComponent", "\[Rule]", "True"}], ",", 
     RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}], ",", 
     RowBox[{"SurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
     RowBox[{"SurfaceNormalFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
     ",", 
     RowBox[{"ActiveRegion", "\[Rule]", "1.`"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
     RowBox[{"JacobianMatrix", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "RayL", ",", "SCx", ",", "SCy", ",", "RTx", ",", "RTy", ",", "RTz"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"RTx", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTy", ",", 
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTz", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"SymbolicJacobianMatrix", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "RayL", ",", "SCx", ",", "SCy", ",", "RTx", ",", "RTy", ",", "RTz"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"RTx", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTy", ",", 
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTz", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"SurfaceRayIntersections", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"RotationMatrix", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"TranslationVector", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
     RowBox[{"ComponentTransformation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}],
      ",", 
     RowBox[{"SymbolicValues", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"SymbolicTranslationVector", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SymbolicRotationMatrix", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"SymbolicComponentTransformation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], ",", 
     
     RowBox[{"SurfaceCenter", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100.`", ",", "100.`"}], "}"}]}], ",", 
     RowBox[{
     "InsideSurfaceBoundaryQ", "\[Rule]", "\<\"-boundary check-\"\>"}], ",", 
     RowBox[{"OffAxis", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"CheckLimits", "\[Rule]", "False"}], ",", 
     RowBox[{"SymbolicSurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
     RowBox[{"SymbolicSurfaceFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
     RowBox[{"SymbolicSurfaceNormalFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
     ",", 
     RowBox[{"SymbolicSurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", "100"}], "}"}]}], ",", 
     RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
     RowBox[{"SymbolicOffAxis", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{
     "SurfaceIntersectionFunction", 
      "\[Rule]", "\<\"-compiled surface intersection code-\"\>"}], ",", 
     RowBox[{"BoundaryChecked", "\[Rule]", "True"}], ",", 
     RowBox[{"SurfaceStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FillStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"LineStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}]}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentID", "\[Rule]", "4133"}], ",", 
     RowBox[{"SurfaceID", "\[Rule]", "4117"}], ",", 
     RowBox[{"SurfaceContinuation", "\[Rule]", "False"}], ",", 
     RowBox[{"SurfaceFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
     RowBox[{"ActiveComponent", "\[Rule]", "True"}], ",", 
     RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}], ",", 
     RowBox[{"SurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
     RowBox[{"SurfaceNormalFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
     ",", 
     RowBox[{"ActiveRegion", "\[Rule]", 
      RowBox[{"-", "1.`"}]}], ",", 
     RowBox[{"JacobianMatrix", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "RayL", ",", "SCx", ",", "SCy", ",", "RTx", ",", "RTy", ",", "RTz"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"RTx", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTy", ",", 
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTz", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"SymbolicJacobianMatrix", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "RayL", ",", "SCx", ",", "SCy", ",", "RTx", ",", "RTy", ",", "RTz"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"RTx", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTy", ",", 
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"RTz", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"SurfaceRayIntersections", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"RotationMatrix", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"TranslationVector", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"5.`", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ComponentTransformation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], ",", 
     
     RowBox[{"SymbolicValues", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"SymbolicTranslationVector", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"5", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SymbolicRotationMatrix", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"SymbolicComponentTransformation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], ",", 
     
     RowBox[{"SurfaceCenter", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"5.`", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100.`", ",", "100.`"}], "}"}]}], ",", 
     RowBox[{
     "InsideSurfaceBoundaryQ", "\[Rule]", "\<\"-boundary check-\"\>"}], ",", 
     RowBox[{"OffAxis", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`"}], "}"}]}], ",", 
     RowBox[{"CheckLimits", "\[Rule]", "False"}], ",", 
     RowBox[{"SymbolicSurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
     RowBox[{"SymbolicSurfaceFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
     RowBox[{"SymbolicSurfaceNormalFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
     ",", 
     RowBox[{"SymbolicSurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", "100"}], "}"}]}], ",", 
     RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
     RowBox[{"SymbolicOffAxis", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{
     "SurfaceIntersectionFunction", 
      "\[Rule]", "\<\"-compiled surface intersection code-\"\>"}], ",", 
     RowBox[{"BoundaryChecked", "\[Rule]", "True"}], ",", 
     RowBox[{"SurfaceStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FillStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"LineStyle", "\[Rule]", 
         RowBox[{"{", "}"}]}]}], "}"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.505563918458847*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
clist1  = {Screen[{100,100}],
Move[Screen[{100,100}],{30,30},90],
Move[Screen[{100,100}],{30,-30},90],
Move[Screen[{100,100}],50],
Move[Move[Screen[{100,100}],{30,-30},90],0,0,90],
Move[Move[Screen[{100,100}],{30,-30},90],0,0,-90]}\
\>", "Input",
 CellChangeTimes->{{3.505367019143448*^9, 3.505367138444253*^9}, {
   3.5053671807046537`*^9, 3.505367182188649*^9}, {3.5053672846161823`*^9, 
   3.5053672910041323`*^9}, {3.5053694986436234`*^9, 
   3.5053695332722607`*^9}, {3.505369565125681*^9, 3.505369582393523*^9}, 
   3.5053696841970243`*^9, {3.5053699935893097`*^9, 3.505370014809224*^9}, 
   3.505562613740995*^9, {3.5057349779524717`*^9, 3.5057350524037857`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"100", ",", "100"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "30.`"}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", "50.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", "30.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505369583256447*^9, 3.505369685048155*^9, 3.505370015404882*^9, 
   3.505547884448133*^9, 3.505548886305489*^9, 3.505562664330472*^9, {
   3.505735033292397*^9, 3.5057350534684763`*^9}, 3.506915122144432*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist1,LabelSurfaces->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.505562626525798*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDDBEN+Aw5wVOOz9BzbfFkM8BIe/VuAIB7Ax
/4MxxKGmYYgDAPzZQAA=
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4YIhD3YkhvhqHOWtw2At1py0Od2L4awWOcIC6E0c4eB4A
AJNCRzc=
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {80., 
      30., 50.}, {80., 30., -50.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdgdgIqtXgYA/hnhYKAi4Y4gzQfgY4hvA
5mhhiDeAxbkOoIv/+Q8CxhjiEGCCIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENNwxAHACyzR4A=
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DSByC05wF08dWrQMABQ3wNWNwAQxxq8F50
8RUQ9Q7YxR0wxP/9BwEPDHGoOzHEV+MwZw0Oe6HutMXhTgx/rcARDlB34ggH
zwMAww1Otw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{80., -30., -50.}, {-20., -30., -50.}, {-20., -30., 50.}, {
       80., -30., 50.}, {80., -30., -50.}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDSBxhQgKfD6lUg4IAhvgYsboAhDmXsRRdf
AVHvgF3cAUP8338Q8MAQR7MH3Z0Y4mtw2Atl2OJw5wEc7sQQh7oTQxxKw8UB
ojtAeg==
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAZ4H0MVXrwIBBwzxNWBxAwxxKNiLLr4C
ot4Bu7gDhvi//yDggSGOysdwJ4b4Ghz2QoEtDndi+GsFjnCAuhNDHMo/AADs
dUB6
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{50., -50., -50.}, {50., 50., -50.}, {50., 50., 50.}, {
        50., -50., 50.}, {50., -50., -50.}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCU3YHVq0DAH0M8LBQE3DHEmSA0hvgG
sDlaGOINYHGuA+jif/6DgDGGOIQ2wRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcQhNGZ4AgDlX08A
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa7gBMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBqTRONw==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., 50., -30.}, {-20., 50., -30.}, {-20., -50., -30.}, {
         80., -50., -30.}, {80., 50., -30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAXYOq1eBgD+GeFgoCLhjiDNBaXTxDWBz
tDDEG8DiXAfQxf/8BwFjDHEIbYIhvgGHOStw2PsPbL4thngIDn+twBEOYGP+
B2OIQ2jM8AQAwclAAA==
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngdQ+XYOq1eBgAOG+BqwuAGGONTAveji
KyDqHbCLO2CI//sPAh4Y4lB3YoivxmHOGhz2Qt1pi8OdGP5agSMcoO7EEQ6I
8AQADfhHNw==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., -50., 30.}, {-20., -50., 30.}, {-20., 50., 30.}, {
          80., 50., 30.}, {80., -50., 30.}}], 
         {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
          Text3DBox[
           FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
           FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
          Text3DBox[
           FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
          Text3DBox[
           FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], Text3DBox[
           FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, -30.}], 
          Text3DBox[
           FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., 0, 30.}]}}}}}}}},
  
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{356.5911446922533, 355.57947477416155`},
  PlotRange:>All,
  ViewPoint->{-0.009036939553580155, 0.1505723570138074, 3.380421023929831},
  ViewVertical->{0.0035259276811582725`, 0.8321182164787521, 
   0.5545870911211405}]], "Print",
 CellChangeTimes->{{3.505367172878573*^9, 3.505367185549945*^9}, 
   3.505367294486753*^9, {3.50536952664528*^9, 3.50536953651007*^9}, {
   3.505369585285687*^9, 3.505369606882863*^9}, 3.505369686820415*^9, 
   3.5053700228981543`*^9, 3.50537248631435*^9, 3.5055626645964003`*^9, {
   3.505735034892008*^9, 3.50573505529384*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["results1 = MeldSurfaces[clist1]", "Input",
 CellChangeTimes->{
  3.505370279332316*^9, 3.5055749051897783`*^9, 3.505735074981992*^9, {
   3.505735141975456*^9, 3.505735144341832*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDDBEN+Aw5wVOOz9BzbfFkM8BIe/VuAIB7Ax
/4MxxKGmYYgDAPzZQAA=
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4YIhD3YkhvhqHOWtw2At1py0Od2L4awWOcIC6E0c4eB4A
AJNCRzc=
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {80., 
      30., 50.}, {80., 30., -50.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdgdgIqtXgYA/hnhYKAi4Y4gzQfgY4hvA
5mhhiDeAxbkOoIv/+Q8CxhjiEGCCIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENNwxAHACyzR4A=
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DSByC05wF08dWrQMABQ3wNWNwAQxxq8F50
8RUQ9Q7YxR0wxP/9BwEPDHGoOzHEV+MwZw0Oe6HutMXhTgx/rcARDlB34ggH
zwMAww1Otw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{80., -30., -50.}, {-20., -30., -50.}, {-20., -30., 50.}, {
       80., -30., 50.}, {80., -30., -50.}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDSBxhQgKfD6lUg4IAhvgYsboAhDmXsRRdf
AVHvgF3cAUP8338Q8MAQR7MH3Z0Y4mtw2Atl2OJw5wEc7sQQh7oTQxxKw8UB
ojtAeg==
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAZ4H0MVXrwIBBwzxNWBxAwxxKNiLLr4C
ot4Bu7gDhvi//yDggSGOysdwJ4b4Ghz2QoEtDndi+GsFjnCAuhNDHMo/AADs
dUB6
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{50., -50., -50.}, {50., 50., -50.}, {50., 50., 50.}, {
        50., -50., 50.}, {50., -50., -50.}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCU3YHVq0DAH0M8LBQE3DHEmSA0hvgG
sDlaGOINYHGuA+jif/6DgDGGOIQ2wRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcQhNGZ4AgDlX08A
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa7gBMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBqTRONw==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., 50., -30.}, {-20., 50., -30.}, {-20., -50., -30.}, {
         80., -50., -30.}, {80., 50., -30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAXYOq1eBgD+GeFgoCLhjiDNBaXTxDWBz
tDDEG8DiXAfQxf/8BwFjDHEIbYIhvgGHOStw2PsPbL4thngIDn+twBEOYGP+
B2OIQ2jM8AQAwclAAA==
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngdQ+XYOq1eBgAOG+BqwuAGGONTAveji
KyDqHbCLO2CI//sPAh4Y4lB3YoivxmHOGhz2Qt1pi8OdGP5agSMcoO7EEQ6I
8AQADfhHNw==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., -50., 30.}, {-20., -50., 30.}, {-20., 50., 30.}, {
          80., 50., 30.}, {80., -50., 30.}}], 
         {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
          Text3DBox[
           FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
           FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
          Text3DBox[
           FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
          Text3DBox[
           FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], Text3DBox[
           FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, -30.}], 
          Text3DBox[
           FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., 0, 30.}]}}}}}}}},
  
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129048387*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129565023*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129568152*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-30., 30.}}], 
    ArrowBox[{{-30., 30.}, {-30., -30.}}], 
    ArrowBox[{{-30., -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129628202*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129656393*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129708613*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129752953*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.50691512978922*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129826871*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-20., 30.}}], 
    ArrowBox[{{-20., 30.}, {-20., -30.}}], 
    ArrowBox[{{-20., -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129884776*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129931666*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915129993601*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151300422792`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151300784597`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151301129627`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-20., 30.}}], 
    ArrowBox[{{-20., 30.}, {-20., -30.}}], 
    ArrowBox[{{-20., -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.50691513015259*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130199048*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151302469893`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.50691513028288*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130327196*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130364191*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-30., 30.}}], 
    ArrowBox[{{-30., 30.}, {-30., -30.}}], 
    ArrowBox[{{-30., -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130448249*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151305053368`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130597233*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-30., 30.}, {-30., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130627281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130665983*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151306975613`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-20., 30.}}], 
    ArrowBox[{{-20., 30.}, {-20., -30.}}], 
    ArrowBox[{{-20., -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130735911*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130782371*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130825635*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20., 30.}, {-20., -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130865902*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {6, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.50691513090022*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915130932242*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., 30.}, {30., -30.}}], 
    ArrowBox[{{30., -30.}, {-20., -30.}}], 
    ArrowBox[{{-20., -30.}, {-20., 30.}}], 
    ArrowBox[{{-20., 30.}, {30., 30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.50691513099618*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151310372667`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151311282263`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20."}], ",", " ", "30."}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., 30.}, {30., -30.}, {-20., -30.}, {-20., 30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.506915131160976*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBnRgdwBDCAxMcIir4BDHBVQccJiPQ9yORHFc5uCy
FxfA5S9c4YAr3BDiAMFACxQ=
    "]], 
   {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBlzA7gB2cRMc4io4xHEBFQcc5uMQtyNRHJc5uOzF
BXD5C1c44Ao3uwMAdpALFA==
     "]]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -30., -30.}, {0., 30., -30.}, {0., 30., 30.}, {0., -30., 
     30.}, {0., -30., -30.}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdg4wkbBQILjqgiG+ehUIOGCIM4JJSwzx
NWD1BhjiG8DiChjiUGCLQ5wBXXwVDnNW4bD3PxhY4FCP6a8QHOEAMccDh/sx
wxMA27k4cg==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdjD6AHZxExziKjjEcZmv4oDDfBzidiSK
4zIHl7043XkAh/k4xHGFm90BALiAGY0=
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{50., 30., -30.}, {0., 30., -30.}, {0., 30., 30.}, {50., 30., 
      30.}, {50., 30., -30.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdgdgImGhQHDVBUN89SoQcMAQZwSTlhji
a8DqDTDEN4DFFTDEocAWhzgDuvgqHOaswmHvfzCwwKEe018hOMIBYo4HDvdj
hicAC5M/8g==
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdgdQaXRxExziKjjEcZmv4oDDfBzidiSK
4zIHl7043XkAh/k4xHGFm90BAOhLIQ0=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., -30., -30.}, {0., -30., -30.}, {0., -30., 30.}, {
       50., -30., 30.}, {50., -30., -30.}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdgcYUABM3ASHuAoOcXQAV++AXdwEh7gd
ieK4zMFlLzog5C9c4YAr3BDiAJLwExs=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAXYHsIub4BBXwSGOy3wVBxzm4xC3I1Ec
lzm47IUBYv2FKxxwhZvdAQBIQBMb
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{50., -30., -30.}, {50., 30., -30.}, {50., 30., 30.}, {
        50., -30., 30.}, {50., -30., -30.}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIAyGiCU3YGwUCC46oIhvnoVCDhgiDOCaUsM
8TVg9QYY4hvA4goY4lC+LQ5xBnTxVTjMWYXD3v9gYIFDPaa/QnCEA8QcDxzu
xwxPAMQ/R3I=
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdjD6AKq4CQ5xFRziDA041B/AYT4OcTsS
xXGZg8tenO50wC6OKxxwhRtCHAB0eiGN
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{50., 30., -30.}, {0., 30., -30.}, {0., -30., -30.}, {
         50., -30., -30.}, {50., 30., -30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAXYOYaFAcNUFQ3z1KhBwwBBnBNOWGOJr
wOoNMMQ3gMUVMMShDFsc4gzo4qtwmLMKh73/wcACh3pMf4XgCAeIOR443I8Z
ngCgqThy
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdgegtAOquAkOcRUc4jCAod4Bu7gJDnE7
EsVxmYPLXpzuPIDDfBziuMINIQ4AyCAZjQ==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{50., -30., 30.}, {0., -30., 30.}, {0., 30., 30.}, {50., 
          30., 30.}, {50., -30., 30.}}], 
         {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
          Text3DBox[
           FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
           FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., 30., 0}], 
          Text3DBox[
           FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., -30., 0}], 
          Text3DBox[
           FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], Text3DBox[
           FormBox["\<\"{5, 1}\"\>", TraditionalForm], {25., 0, -30.}], 
          Text3DBox[
           FormBox["\<\"{6, 1}\"\>", TraditionalForm], {25., 0, 30.}]}}}}}}}},
  
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{296.16391325520163`, 342.37700302301266`},
  PlotRange:>All,
  ViewPoint->{0.1503047532748963, -3.3666004789683646`, 0.3056299987778606},
  ViewVertical->{-0.08508296704770033, -0.5199581237720093, 
   0.8512440243028093}]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.50556266469298*^9, 3.5055637885731373`*^9, 
   3.50573507593605*^9, 3.505735144953643*^9, 3.5069151312955027`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"30.`", ",", 
           RowBox[{"-", "30.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "30.`"}], ",", "30.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "30.`"}], ",", 
           RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "30.`"}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", "50.`"}], 
       "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", "30.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505549033731407*^9, 3.505549106433662*^9, 3.505549165132571*^9, 
   3.505549212580736*^9, 3.505549366477466*^9, {3.505549422681087*^9, 
   3.505549445201804*^9}, 3.5055626647300053`*^9, 3.505563790076817*^9, 
   3.5057350775136147`*^9, 3.505735146197198*^9, 3.506915131382585*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[results1,LabelSurfaces->True,Axes->True];\
\>", "Input",
 CellChangeTimes->{{3.505735124766494*^9, 3.50573514962177*^9}}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBnRgdwBDCAxMcIir4BDHBVQccJiPQ9yORHFc5uCy
FxfA5S9c4YAr3BDiAMFACxQ=
    "]], 
   {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBlzA7gB2cRMc4io4xHEBFQcc5uMQtyNRHJc5uOzF
BXD5C1c44Ao3uwMAdpALFA==
     "]]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -30., -30.}, {0., 30., -30.}, {0., 30., 30.}, {0., -30., 
     30.}, {0., -30., -30.}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdg4wkbBQILjqgiG+ehUIOGCIM4JJSwzx
NWD1BhjiG8DiChjiUGCLQ5wBXXwVDnNW4bD3PxhY4FCP6a8QHOEAMccDh/sx
wxMA27k4cg==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdjD6AHZxExziKjjEcZmv4oDDfBzidiSK
4zIHl7043XkAh/k4xHGFm90BALiAGY0=
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{50., 30., -30.}, {0., 30., -30.}, {0., 30., 30.}, {50., 30., 
      30.}, {50., 30., -30.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdgdgImGhQHDVBUN89SoQcMAQZwSTlhji
a8DqDTDEN4DFFTDEocAWhzgDuvgqHOaswmHvfzCwwKEe018hOMIBYo4HDvdj
hicAC5M/8g==
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdgdQaXRxExziKjjEcZmv4oDDfBzidiSK
4zIHl7043XkAh/k4xHGFm90BAOhLIQ0=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., -30., -30.}, {0., -30., -30.}, {0., -30., 30.}, {
       50., -30., 30.}, {50., -30., -30.}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDQdgcYUABM3ASHuAoOcXQAV++AXdwEh7gd
ieK4zMFlLzog5C9c4YAr3BDiAJLwExs=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAXYHsIub4BBXwSGOy3wVBxzm4xC3I1Ec
lzm47IUBYv2FKxxwhZvdAQBIQBMb
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{50., -30., -30.}, {50., 30., -30.}, {50., 30., 30.}, {
        50., -30., 30.}, {50., -30., -30.}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIAyGiCU3YGwUCC46oIhvnoVCDhgiDOCaUsM
8TVg9QYY4hvA4goY4lC+LQ5xBnTxVTjMWYXD3v9gYIFDPaa/QnCEA8QcDxzu
xwxPAMQ/R3I=
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDQdjD6AKq4CQ5xFRziDA041B/AYT4OcTsS
xXGZg8tenO50wC6OKxxwhRtCHAB0eiGN
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{50., 30., -30.}, {0., 30., -30.}, {0., -30., -30.}, {
         50., -30., -30.}, {50., 30., -30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQJg6ofDuHsFAQUMcQ37AKBLgwxP/8BwHh
A+jiK8DqtXCIm2KI/wObY4shDqUxxFfjMGcNDntZwLQIhvgCHP4KwBEOEHca
Y4hDaER4AgAvXEhn
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQIgcgtB2U74lD3AWHuB0OcRMc4io4xGGA
WHFc5uCyF5c7cfkLVzjgCjdMcQCcLBv8
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{60., 20., 30.}, {60., -30., 30.}, {0., -30., 30.}, {0., 
          20., 30.}, {60., 20., 30.}}], 
         {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
          Text3DBox[
           FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
           FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., 30., 0}], 
          Text3DBox[
           FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., -30., 0}], 
          Text3DBox[
           FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], Text3DBox[
           FormBox["\<\"{5, 1}\"\>", TraditionalForm], {25., 0, -30.}], 
          Text3DBox[
           FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., -5., 
           30.}]}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{363.4317095395812, 362.7748686846654},
  PlotRange:>All,
  ViewPoint->{0.2542501597774318, -0.2517351705665912, 3.3648159325812994`},
  ViewVertical->{0.09514837145924365, 0.7590960284402684, 
   0.6439875829663684}]], "Print",
 CellChangeTimes->{{3.5057351298800592`*^9, 3.505735150266775*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2", "Subsection",
 CellChangeTimes->{{3.5053723383943872`*^9, 3.505372339660027*^9}}],

Cell[CellGroupData[{

Cell["\<\
clist2  = {Screen[{100,100}],
Move[Mirror[{100,100}],{30,30},90],
Move[SphericalScreen[100,{100,100}],{30,-30},90],
Move[SphericalScreen[-100,{100,100}],50],
Move[Move[Screen[{100,100}],{30,-30},90],0,0,90],
Move[Move[Screen[{100,100}],{30,-30},90],0,0,-90]
}\
\>", "Input",
 CellChangeTimes->{{3.505367019143448*^9, 3.505367138444253*^9}, {
   3.5053671807046537`*^9, 3.505367182188649*^9}, {3.5053672846161823`*^9, 
   3.5053672910041323`*^9}, {3.5053694986436234`*^9, 
   3.5053695332722607`*^9}, {3.505369565125681*^9, 3.505369582393523*^9}, 
   3.5053696841970243`*^9, {3.5053699935893097`*^9, 3.505369995153349*^9}, 
   3.505562633638173*^9, {3.5056919342581377`*^9, 3.505691967001515*^9}, {
   3.5056921284108667`*^9, 3.505692133863933*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"100", ",", "100"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Mirror", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "30.`"}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalScreen", "[", 
         RowBox[{"100", ",", 
          RowBox[{"{", 
           RowBox[{"100", ",", "100"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalScreen", "[", 
         RowBox[{
          RowBox[{"-", "100"}], ",", 
          RowBox[{"{", 
           RowBox[{"100", ",", "100"}], "}"}]}], "]"}], ",", "50.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", "30.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505369583256447*^9, 3.505369685048155*^9, 3.505549484014566*^9, 
   3.505562669715719*^9, 3.505691968328711*^9, {3.505692137047153*^9, 
   3.505692137531275*^9}, 3.50573552915482*^9, 3.50691517988769*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?StringReplace", "Input",
 CellChangeTimes->{{3.505692621057919*^9, 3.505692624477099*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"StringReplace\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"\\\\\\\"\\\\!\\\\(\\\\*StyleBox[\\\\\\\"string\\\\\\\",\\\
\\\\\"TI\\\\\\\"]\\\\)\\\\\\\"\\\", ShowStringCharacters->True], \\\",\\\", \
RowBox[{StyleBox[\\\"s\\\", \\\"TI\\\"], \\\"->\\\", StyleBox[\\\"sp\\\", \
\\\"TI\\\"]}]}], \\\"]\\\"}]\\) or \\!\\(\\*RowBox[{\\\"StringReplace\\\", \\\
\"[\\\", RowBox[{StyleBox[\\\"\\\\\\\"\\\\!\\\\(\\\\*StyleBox[\\\\\\\"string\\\
\\\\\",\\\\\\\"TI\\\\\\\"]\\\\)\\\\\\\"\\\", ShowStringCharacters->True], \
\\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\"->\\\", \
SubscriptBox[StyleBox[\\\"sp\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]}], \\\",\\\", RowBox[{SubscriptBox[StyleBox[\\\"s\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\"->\\\", \
SubscriptBox[StyleBox[\\\"sp\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\
\\\"}]}], \\\"]\\\"}]\\) replaces the string expressions \
\\!\\(\\*SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \\\
\"TI\\\"]]\\) by \\!\\(\\*SubscriptBox[StyleBox[\\\"sp\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]]\\) whenever they appear as substrings of \
\\\"\\!\\(\\*\\nStyleBox[\\\"string\\\", \\\"TI\\\"]\\)\\\". \
\\n\\!\\(\\*RowBox[{\\\"StringReplace\\\", \\\"[\\\", RowBox[{StyleBox[\\\"\\\
\\\\\"\\\\!\\\\(\\\\*StyleBox[\\\\\\\"string\\\\\\\",\\\\\\\"TI\\\\\\\"]\\\\)\
\\\\\\\"\\\", ShowStringCharacters->True], \\\",\\\", \
StyleBox[\\\"srules\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\
\"]}], \\\"]\\\"}]\\) does only the first \\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\
\\\"]\\) replacements. \\n\\!\\(\\*RowBox[{\\\"StringReplace\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"s\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\
\"}], \\\",\\\", StyleBox[\\\"srules\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives \
the list of results for each of the \\!\\(\\*SubscriptBox[StyleBox[\\\"s\\\", \
\\\"TI\\\"], StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/StringReplace"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.505692625958672*^9},
 CellTags->"Info3505671025-6384412"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalScreen[100,100]//InputForm", "Input",
 CellChangeTimes->{{3.5056925509365053`*^9, 3.505692556485734*^9}, {
  3.5056926741046743`*^9, 3.505692674461896*^9}}],

Cell["\<\
Component[ComponentID -> 8509, ComponentDescription -> \
ComponentDescription[SphericalScreen[100, 100, ComponentLabel -> \"\", \
SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, 
    ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, \
{0., 0., 1.}}}]], TranslationVector -> {0., 0., 0.}, RotationMatrix -> {{1., \
0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, Labels -> {\"S\"}, 
 LabelPositions -> {{0., -50. - 1.*Offy, -50. - 1.*Offz}}, EdgeStyle -> \
{FillStyle -> {}, LineStyle -> {}}, CrossStyle -> {FillStyle -> {}, LineStyle \
-> {}}, CatalogInformation -> {{}}, 
 Surfaces -> {{ComponentID -> 8509, SurfaceID -> 8511, SurfaceContinuation -> \
False, ActiveComponent -> True, SurfaceFunction -> ({-Sqrt[10000 - #1^2 - \
#2^2] + 100, #1, #2} & ), SurfaceLabel -> SphericalShape, SurfaceValue -> 100, 
    SurfaceNormalFunction -> ({{1, -((1*#1)/(10000 - #1^2 - #2^2)^(1/2)), \
-((1*#2)/(10000 - #1^2 - #2^2)^(1/2))}, {(1*#1)/(10000 - #1^2 - #2^2)^(1/2), \
1, 0}, {(1*#2)/(10000 - #1^2 - #2^2)^(1/2), 0, 1}} & ), ActiveRegion -> 0., 
    ComponentMedium -> Automatic, JacobianMatrix -> Function[{RayL, SCx, SCy, \
RTx, RTy, RTz}, {{RTx, -(SCx/Sqrt[10000 - SCx^2 - SCy^2]), -(SCy/Sqrt[10000 - \
SCx^2 - SCy^2])}, {RTy, -1, 0}, {RTz, 0, -1}}], SurfaceRayIntersections -> \
Automatic, 
    RotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, TranslationVector -> \
{0, 0, 0}, ComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, \
0, 1}}}, SurfaceCenter -> {0, 0, 0}, SurfaceBoundary -> 100., 
    InsideSurfaceBoundaryQ -> InsideSurfaceBoundaryQ[{_Real, _Real}, {{3, 0, \
0}, {3, 0, 1}, {1, 0, 0}}, {1, 1, 4, 0, 0}, {{1, 7}, {7, 2, 0}, {94, 264, 3, \
0, 0, 2, 0, 0, 3, 0, 2}, {7, 2, 0}, {94, 264, 3, 0, 1, 2, 0, 0, 3, 0, 3}, \
{18, 2, 3, 2}, 
       {8, 2500., 3}, {39, 2, 3, 0}, {2}}, Function[{SCx, SCy}, SCx^2 + SCy^2 \
<= 2500.], Evaluate], OffAxis -> {0, 0}, CheckLimits -> False, SymbolicValues \
-> {}, SymbolicRanges -> {}, SymbolicTranslationVector -> {0, 0, 0}, 
    SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, \
SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SymbolicSurfaceApproximation -> Automatic, SymbolicSurfaceValue -> 100, \

    SymbolicSurfaceFunction -> ({-Sqrt[10000 - #1^2 - #2^2] + 100, #1, #2} & \
), SymbolicSurfaceNormalFunction -> ({{1, -((1*#1)/(10000 - #1^2 - \
#2^2)^(1/2)), -((1*#2)/(10000 - #1^2 - #2^2)^(1/2))}, {(1*#1)/(10000 - #1^2 - \
#2^2)^(1/2), 1, 0}, 
       {(1*#2)/(10000 - #1^2 - #2^2)^(1/2), 0, 1}} & ), \
SymbolicSurfaceBoundary -> 100, SurpressMissedRays -> False, SymbolicOffAxis \
-> {0, 0}, SymbolicRefractiveModels -> {}, 
    SurfaceIntersectionFunction -> \
CompiledSurfaceIntersectionFunction[{_Real, _Real, _Real, _Real, _Real, \
_Real}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, \
{3, 2, 5}}, {6, 3, 19, 4, 6}, 
      {{1, 7}, {8, 1., 6}, {8, 1., 7}, {8, 1., 8}, {45, {{-1., 0., 0.}}, 3, \
1, 3, 0}, {8, 1., 9}, {8, 1., 10}, {8, 1., 11}, {7, 2, 0}, {94, 264, 3, 0, 0, \
2, 0, 0, 3, 0, 12}, {7, 2, 0}, {94, 264, 3, 0, 1, 2, 0, 0, 3, 0, 13}, {7, 2, \
0}, 
       {94, 264, 3, 0, 2, 2, 0, 0, 3, 0, 14}, {18, 12, 13, 14, 12}, {12, 12, \
6}, {21, 0, 3, 12}, {21, 1, 4, 13}, {21, 2, 5, 14}, {7, 100, 0}, {15, 1, 0, \
15}, {21, 15, 3, 15}, {24, 15, 16}, {18, 12, 13, 14, 16, 12}, {12, 12, 7}, \
{24, 6, 12}, 
       {7, 2, 0}, {94, 264, 3, 0, 7, 2, 0, 0, 3, 0, 13}, {7, 2, 0}, {7, 100, \
1}, {15, 1, 0, 14}, {15, 1, 1, 16}, {21, 14, 0, 16, 14}, {18, 12, 13, 14, \
12}, {12, 12, 8}, {8, 1.*^-10, 12}, {94, 270, 3, 0, 8, 3, 0, 12, 3, 0, 13}, \
{8, 0., 12}, 
       {39, 12, 13, 0}, {3, 0, 180}, {93, 57, 3, 0, 8, 3, 0, 13}, {12, 13, \
8}, {24, 7, 13}, {24, 8, 12}, {18, 13, 12, 13}, {18, 7, 8, 12}, {21, 12, 4, \
12}, {24, 12, 14}, {18, 1, 14, 12}, {18, 7, 8, 14}, {21, 14, 5, 14}, {24, 14, \
16}, 
       {18, 2, 16, 14}, {67, 13, 12, 14, 3, 1}, {7, 1, 0}, {70, 1, 0, 0, 0, \
13}, {12, 13, 9}, {7, 2, 0}, {70, 1, 0, 0, 0, 13}, {12, 13, 10}, {7, 3, 0}, \
{70, 1, 0, 0, 0, 13}, {12, 13, 11}, {67, 9, 10, 11, 3, 2}, {8, 1.*^-10, 13}, 
       {94, 270, 3, 0, 9, 3, 0, 13, 3, 0, 12}, {8, 0., 13}, {39, 13, 12, 1}, \
{3, 1, 47}, {7, 2, 0}, {94, 264, 3, 0, 10, 2, 0, 0, 3, 0, 12}, {7, 2, 0}, \
{94, 264, 3, 0, 11, 2, 0, 0, 3, 0, 13}, {18, 12, 13, 12}, {8, 2500., 13}, \
{39, 12, 13, 2}, 
       {3, 2, 35}, {21, 9, 4, 12}, {24, 10, 13}, {18, 1, 12, 13, 14}, {93, \
38, 3, 0, 14, 3, 0, 12}, {21, 9, 5, 14}, {24, 11, 13}, {18, 2, 14, 13, 16}, \
{93, 38, 3, 0, 16, 3, 0, 14}, {7, -100, 0}, {21, 9, 3, 16}, {7, 10000, 1}, \
{7, 2, 2}, 
       {94, 264, 3, 0, 10, 2, 0, 2, 3, 0, 13}, {24, 13, 15}, {7, 2, 2}, {94, \
264, 3, 0, 11, 2, 0, 2, 3, 0, 13}, {24, 13, 17}, {15, 0, 1, 13}, {18, 13, 15, \
17, 13}, {93, 57, 3, 0, 13, 4, 0, 0}, {15, 0, 0, 13}, {8, 0., 15}, {16, 13, \
15, 1}, 
       {8, 0., 17}, {16, 0, 17, 2}, {8, 0., 18}, {16, 16, 18, 3}, {19, 1, 2, \
3, 0, 1}, {93, 38, 4, 0, 1, 3, 0, 16}, {18, 12, 14, 16, 12}, {8, 1.*^-7, 14}, \
{37, 12, 14, 3}, {10, 3, 5}, {4, 3}, {6, False, 4}, {10, 4, 5}, {10, 5, 3}, \
{4, 3}, 
       {6, False, 2}, {10, 2, 3}, {3, 3, 4}, {67, 9, 10, 11, 3, 1}, {46, 1, \
4}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 3}, {46, 3, 4}, {24, 7, 12}, {18, 12, \
8, 12}, {24, 7, 14}, {18, 14, 8, 14}, {21, 14, 4, 14}, {18, 1, 14, 16}, {24, \
7, 14}, 
       {18, 14, 8, 14}, {21, 14, 5, 14}, {18, 2, 14, 13}, {67, 12, 16, 13, 3, \
2}, {7, 1, 0}, {70, 2, 0, 0, 0, 12}, {12, 12, 9}, {7, 2, 0}, {70, 2, 0, 0, 0, \
12}, {12, 12, 10}, {7, 3, 0}, {70, 2, 0, 0, 0, 12}, {12, 12, 11}, 
       {67, 9, 10, 11, 3, 1}, {8, 1.*^-10, 12}, {94, 270, 3, 0, 9, 3, 0, 12, \
3, 0, 16}, {8, 0., 12}, {39, 12, 16, 3}, {3, 3, 47}, {7, 2, 0}, {94, 264, 3, \
0, 10, 2, 0, 0, 3, 0, 16}, {7, 2, 0}, {94, 264, 3, 0, 11, 2, 0, 0, 3, 0, 12}, \

       {18, 16, 12, 16}, {8, 2500., 12}, {39, 16, 12, 1}, {3, 1, 35}, {21, 9, \
4, 16}, {24, 10, 12}, {18, 1, 16, 12, 13}, {93, 38, 3, 0, 13, 3, 0, 16}, {21, \
9, 5, 13}, {24, 11, 12}, {18, 2, 13, 12, 14}, {93, 38, 3, 0, 14, 3, 0, 13}, 
       {7, -100, 0}, {21, 9, 3, 14}, {7, 10000, 1}, {7, 2, 2}, {94, 264, 3, \
0, 10, 2, 0, 2, 3, 0, 12}, {24, 12, 15}, {7, 2, 2}, {94, 264, 3, 0, 11, 2, 0, \
2, 3, 0, 12}, {24, 12, 17}, {15, 0, 1, 12}, {18, 12, 15, 17, 12}, 
       {93, 57, 3, 0, 12, 4, 0, 1}, {15, 0, 0, 12}, {8, 0., 15}, {16, 12, 15, \
0}, {8, 0., 17}, {16, 0, 17, 2}, {8, 0., 18}, {16, 14, 18, 3}, {19, 0, 2, 3, \
1, 0}, {93, 38, 4, 0, 0, 3, 0, 14}, {18, 16, 13, 14, 16}, {8, 1.*^-7, 13}, 
       {37, 16, 13, 5}, {10, 5, 4}, {4, 3}, {6, False, 2}, {10, 2, 4}, {10, \
4, 5}, {4, 3}, {6, False, 1}, {10, 1, 5}, {3, 5, 4}, {67, 9, 10, 11, 3, 2}, \
{46, 2, 5}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 3}, {46, 3, 5}, {68, 4, 5, 1}, \
{46, 1, 0}, 
       {7, 1, 0}, {70, 0, 0, 0, 1, 1}, {7, 2, 0}, {70, 0, 0, 0, 1, 4}, {53, \
1, 4, 0, 5}, {3, 5, 6}, {7, 1, 0}, {70, 0, 0, 0, 1, 1}, {68, 1, 4}, {46, 4, \
1}, {4, 2}, {46, 0, 1}, {46, 1, 5}, {4, 3}, {45, {{-1., 0., 0.}}, 3, 1, 3, \
4}, {46, 4, 5}, 
       {2}}, Function[{RSx, RSy, RSz, RTx, RTy, RTz}, Block[{TempVar, \
TempVar1, TempVar2, TempVar3, RayL, SCx, SCy}, TempVar1 = 1.; TempVar2 = 1.; \
TempVar3 = 1.; TempVar = {{-1., 0., 0.}}; RayL = 1.; SCx = 1.; SCy = 1.; 
         TempVar1 = RSx^2 + RSy^2 + RSz^2; TempVar2 = RSx*RTx + RSy*RTy + \
RSz*RTz - 100*RTx; TempVar3 = -TempVar1 + TempVar2^2 + 2*RSx*100; TempVar3 = \
Re[TempVar3]; 
         If[N[Chop[TempVar3]] >= 0., TempVar3 = Sqrt[TempVar3]; TempVar = \
{{RayL, SCx, SCy} = {-TempVar2 - TempVar3, RSy - (TempVar2 + TempVar3)*RTy, \
RSz - (TempVar2 + TempVar3)*RTz}; If[N[Chop[RayL]] >= 0. && SCx^2 + SCy^2 <= \
2500. && 
                Abs[RSy + RayL*RTy - SCx] + Abs[RSz + RayL*RTz - SCy] + \
Abs[-100 + RSx + RayL*RTx + Sqrt[10000 - SCx^2 - SCy^2]] < 1.*^-7, {RayL, \
SCx, SCy}, {-1., 0., 0.}], 
             {RayL, SCx, SCy} = {-TempVar2 + TempVar3, RSy + (-TempVar2 + \
TempVar3)*RTy, RSz + (-TempVar2 + TempVar3)*RTz}; If[N[Chop[RayL]] >= 0. && \
SCx^2 + SCy^2 <= 2500. && Abs[RSy + RayL*RTy - SCx] + Abs[RSz + RayL*RTz - \
SCy] + 
                  Abs[-100 + RSx + RayL*RTx + Sqrt[10000 - SCx^2 - SCy^2]] < \
1.*^-7, {RayL, SCx, SCy}, {-1., 0., 0.}]}; If[TempVar[[1]] == TempVar[[2]], \
{TempVar[[1]]}, TempVar], {{-1., 0., 0.}}]]], Evaluate], BoundaryChecked -> \
True, 
    SurfaceStyle -> {FillStyle -> {}, LineStyle -> {}}}}, Deflections -> \
{{{DeflectionID -> 8508, DeflectionLabel -> Transmission, ComponentLabel -> \
SphericalScreen, Options -> {}, AddTo -> {NewRay}, ReplaceFor -> {ReplaceFor}, 
     TakeFrom -> {OriginalRay}, DeflectionFunction -> {Transmission, 100, \
{AddTo, 100, False, 8508, False, OriginalRay}}}}}, EntranceCoordinates -> \
{{0., 0., 0.}}, ConfinedPaths -> {{{SurfaceNumber -> 1, DeflectionNumber -> \
{1}}}}, 
 RenderedSurfaces -> {{SurfaceNumber -> 1, PlotFactor -> {1., 1.}, FillOffset \
-> {0., 0.}, RenderType -> Trace}}, 
 RenderedPolygons -> {{{{SurfaceNumber -> 1, StartPoint -> {-50., 0.}, \
FinishPoint -> {50., 0.}}, {SurfaceNumber -> 1, StartPoint -> {50., 0.}, \
FinishPoint -> {-50., 0.}}}, {PlotFactor -> 1., RenderType -> Trace}}, 
   {{{SurfaceNumber -> 1, StartPoint -> {0., -50.}, FinishPoint -> {0., \
50.}}, {SurfaceNumber -> 1, StartPoint -> {0., 50.}, FinishPoint -> {0., \
-50.}}}, {PlotFactor -> 1., RenderType -> Trace}}}, 
 Options -> {ComponentLabel -> SphericalScreen, GraphicDesign -> Automatic, \
WaveFrontID -> False}]\
\>", "Output",
 CellChangeTimes->{3.5056925636422462`*^9, 3.505692677158873*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RecoverInput[Flatten[{clist2}],Print\[Rule]All(*,DeleteRecoveredOptions->\
False*)][[1,1]]\
\>", "Input",
 CellChangeTimes->{{3.505692397495481*^9, 3.505692412812252*^9}, {
  3.5056925236695642`*^9, 3.505692530692293*^9}}],

Cell[BoxData["\<\"{Screen[{100, 100}], Move[Mirror[{100, 100}], {30., 30.}, \
90.], Move[SphericalScreen[100, {100, 100}], {30., -30.}, 90.], \
Move[SphericalScreen[-100, {100, 100}], 50.], Move[Screen[{100, 100}], {30., \
0, -30.}, {{0, 0, 1.}, {-1., 0, 0}, {0, -1., 0}}], Move[Screen[{100, 100}], \
{30., 0, 30.}, {0, 0, -1.}]}\"\>"], "Output",
 CellChangeTimes->{{3.505692399730637*^9, 3.5056924131754913`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist2,LabelSurfaces->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, {3.505372444384778*^9, 3.50537245377987*^9}, 
   3.505562635468861*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[
    None], Polygon3DBox[{{80., 30., 0.}, {80., 30., 
     1.2246467991473532`*^-14}, {63.33333333333334, 30., 
     1.0205389992894611`*^-14}, {63.333333333333336`, 30., 0.}, {80., 30., 
     0.}}], Polygon3DBox[{{63.333333333333336`, 30., 0.}, {63.33333333333334, 
     30., 1.0205389992894611`*^-14}, {46.66666666666667, 30., 
     8.164311994315689*^-15}, {46.66666666666667, 30., 0.}, {
     63.333333333333336`, 30., 0.}}], 
    Polygon3DBox[{{46.66666666666667, 30., 0.}, {46.66666666666667, 30., 
     8.164311994315689*^-15}, {30.000000000000014`, 30., 
     6.123233995736768*^-15}, {30., 30., 0.}, {46.66666666666667, 30., 0.}}], 
    Polygon3DBox[{{30., 30., 0.}, {30., 30., 6.123233995736766*^-15}, {
     13.333333333333336`, 30., 4.0821559971578446`*^-15}, {
     13.333333333333343`, 30., 0.}, {30., 30., 0.}}], 
    Polygon3DBox[{{13.333333333333343`, 30., 0.}, {13.333333333333336`, 30., 
     4.0821559971578446`*^-15}, {-3.3333333333333286`, 30., 
     2.0410779985789227`*^-15}, {-3.3333333333333286`, 30., 0.}, {
     13.333333333333343`, 30., 0.}}], 
    Polygon3DBox[{{-3.3333333333333286`, 30., 0.}, {-3.3333333333333286`, 30.,
      2.041077998578923*^-15}, {-19.999999999999993`, 30., 
     1.0197233050851683`*^-30}, {-19.999999999999986`, 30., 
     0.}, {-3.3333333333333286`, 30., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDDBEN+Aw5wVOOz9BzbfFkM8BIe/VuAIB7Ax
/4MxxKGmYYgDAPzZQAA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      Polygon3DBox[{{30., 30., -50.}, {29.999999999999993`, 30., -50.}, {
       29.999999999999996`, 30., -33.33333333333334}, {30., 
       30., -33.333333333333336`}, {30., 30., -50.}}], 
      Polygon3DBox[{{30., 30., -33.333333333333336`}, {29.999999999999996`, 
       30., -33.33333333333334}, {29.999999999999996`, 
       30., -16.66666666666667}, {29.999999999999996`, 
       30., -16.66666666666667}, {30., 30., -33.333333333333336`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., -16.66666666666667}, {
       29.999999999999996`, 30., -16.66666666666667}, {29.999999999999996`, 
       30., -1.4210854715202004`*^-14}, {29.999999999999996`, 30., 0.}, {
       29.999999999999996`, 30., -16.66666666666667}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 0.}, {29.999999999999996`, 30.,
        0.}, {29.999999999999996`, 30., 16.666666666666664`}, {
       29.999999999999996`, 30., 16.666666666666657`}, {29.999999999999996`, 
       30., 0.}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 16.666666666666657`}, {
       29.999999999999996`, 30., 16.666666666666664`}, {30., 30., 
       33.33333333333333}, {29.999999999999996`, 30., 33.33333333333333}, {
       29.999999999999996`, 30., 16.666666666666657`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 33.33333333333333}, {30., 30., 
       33.33333333333333}, {30., 30., 49.99999999999999}, {
       29.999999999999993`, 30., 49.999999999999986`}, {29.999999999999996`, 
       30., 33.33333333333333}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4YIhD3YkhvhqHOWtw2At1py0Od2L4awWOcIC6E0c4eB4A
AJNCRzc=
        "]], 
       {GrayLevel[0.5], EdgeForm[None], 
        Polygon3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {
         80., 30., 50.}, {80., 30., -50.}}], 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {
          80., 30., 50.}, {80., 30., -50.}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcZjyXljMYZbBAZjI6lUg4O/QcG5P6Et3C7h4
WCgIuDvsCZ6078NMG7g4E5i0c4Dw7ODiG8DmaGGobwCLcx1AN//PfxAwPjAD
zT0QYHIA3Z0bcJizAoe9/8Dm22K4MwSHv1bgCAewMf+DHbC7EzM8AUoEcZw=

          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc5jyXljMYZbBAQjf8wBMvOHcntCX7hYHVq8C
AQe4+J7gSfs+zLQ5sAYsbgAXh9JQPsNedPUrIOod0M2HiDvAxWdA3fPvPwh4
wMXR3Ilhzmo0c9DcCRdHc6ctDndihMMKtHBAcydcHD08AeBeeNM=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmBhgIcWCI2cz5YO+z/RC+p8MqMPB32HHm/qXcO8oH
YOKhYODuEGHlJLHouy5cHELbOUx5LyzmMMsALr4CbI4WhvoDYHGuA+jmQ2iT
A+juISQOMwfibge4OMxeiLgBXBzVnTCAUL8Gov4AuvkQcQe4OJp7cIovwO5f
qHkY4XMAR3geCMMe/lBzMOILSmPEL0FxtPCEi6OFJ1wce3gi1K9BCX+E+WtQ
4gszHQIAeincIA==
           "]]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID71nZNbwdfJgQEMPA8wQIFD+r1VX5TdHFavAgEH
uPg9Tc/4Hz4eDmvA4gZwcah+qDkMe9HVr4Coh8nDzYeIO8DFz0Dd8+8/CHjA
xdHciWHOajRz0NwJF0fTb4vDnRjhsAItHNDcCRfHFZ4AcnNkeQ==
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID71nZNbwdfJgQEFeB5wSL+36ouyG1x89SoQcDhw
T9Mz/oePB1x8DVjc4ABUH5o5DHvR1a+AqHdANx8i7uBwBs09//6DgIcDDndi
mAN1pwMOdzrgcKctDndihAPUnQdwuPMArvAEALytZHk=
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4wy5fh/VYTBwYw8DwApR1inuW/NHtn67AKDBzg
4tP6BNpe1DpCxQ3g4qe+c3Ir+DpBzYEBhPo1EPUO6OZDxB3g4mjuISgOMwfG
h7oXbi+quAGaO2HmMDCgq4e69wC6+VD3HsDhHpziaOEJF0cLT7g4jvA8gBae
B9DNh7kPh3sIiqP59wAs/tHC5wAs/tHC8wCO8DwAi39082HxjysdAgDjldI/

            "]]}, 
          {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
           EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCU3YHVq0DAH0M8LBQE3DHEmSA0hvgG
sDlaGOINYHGuA+jif/6DgDGGOIQ2wRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcQhNGZ4AgDlX08A
            "]], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa7gBMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBqTRONw==
             "]]}, 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{80., 50., -30.}, {-20., 
             50., -30.}, {-20., -50., -30.}, {80., -50., -30.}, {80., 
             50., -30.}}]}, 
           {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
            EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAXYOq1eBgD+GeFgoCLhjiDNBaXTxDWBz
tDDEG8DiXAfQxf/8BwFjDHEIbYIhvgGHOStw2PsPbL4thngIDn+twBEOYGP+
B2OIQ2jM8AQAwclAAA==
             "]], 
            {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngdQ+XYOq1eBgAOG+BqwuAGGONTAveji
KyDqHbCLO2CI//sPAh4Y4lB3YoivxmHOGhz2Qt1pi8OdGP5agSMcoO7EEQ6I
8AQADfhHNw==
              "]]}, 
            {GrayLevel[0], AbsoluteThickness[0.5], 
             Line3DBox[{{80., -50., 30.}, {-20., -50., 30.}, {-20., 50., 
              30.}, {80., 50., 30.}, {80., -50., 30.}}], 
             {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
              Text3DBox[
               FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], 
              Text3DBox[
               FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
              Text3DBox[
               FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
              Text3DBox[
               FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], 
              Text3DBox[
               FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, -30.}], 
              Text3DBox[
               FormBox["\<\"{6, 1}\"\>", TraditionalForm], {
               30., 0, 30.}]}}}}}}}}}}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{971.2133899630269, 1002.},
  PlotRange:>All,
  ViewPoint->{2.6937998157383873`, 0.12184069716844852`, -2.044161783529218},
  ViewVertical->{-0.01706666819666195, 
   0.09786227443594687, -0.9950536186954392}]], "Print",
 CellChangeTimes->{3.505694020239843*^9}]
}, Open  ]],

Cell["\<\
crossingpoints = {{{{1, 1}, {2, 1}}, {30., -30.}}, {{{1, 1}, {3, 1}}, {30., \
-160.554}, {30., 20.5539}}, {{{1, 1}, {4, 1}}, {30., -81.2404}, {30., \
81.2404}}, {{{1, 1}, {2, 1}}, {30., -30.}}, {{{2, 1}, {3, 1}}, {-86.6025, \
-30.}, {86.6025, -30.}}, {{{2, 1}, {4, 1}}, {-10.5539, -30.}, {170.554, \
-30.}}, {{{1, 1}, {3, 1}}, {30., -160.554}, {30., 20.5539}}, {{{2, 1}, {3, \
1}}, {-86.6025, -30.}, {86.6025, -30.}}, {{{3, 1}, {4, 1}}, {-12.1634, \
24.6153}, {92.1634, -94.6153}}, {{{1, 1}, {4, 1}}, {30., -81.2404}, {30., \
81.2404}}, {{{2, 1}, {4, 1}}, {-10.5539, -30.}, {170.554, -30.}}, {{{3, 1}, \
{4, 1}}, {-12.1634, 24.6153}, {92.1634, -94.6153}}};\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.5057080459311123`*^9, 3.50570805833584*^9}}],

Cell[CellGroupData[{

Cell["\<\
Union[Map[#[[2]]&,Select[crossingpoints,MemberQ[#[[1]],{1,1}]&]]]\
\>", "Input",
 CellChangeTimes->{{3.505708063271571*^9, 3.5057080678864183`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "160.554`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "81.2404`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.505708070508683*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Apply[Join,Map[Rest,Union[Select[crossingpoints,MemberQ[#[[1]],{1,1}]&]]]]\
\>", "Input",
 CellChangeTimes->{{3.505708063271571*^9, 3.5057080678864183`*^9}, {
  3.505708126976459*^9, 3.50570821076717*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "30.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "160.554`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", "20.5539`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", 
     RowBox[{"-", "81.2404`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", "81.2404`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5057081355804863`*^9, 3.505708211100589*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeldSurfaces[clist2]", "Input",
 CellChangeTimes->{
  3.505370279332316*^9, {3.505370341324349*^9, 3.505370343531807*^9}, 
   3.5055626415332336`*^9, 3.505574906132802*^9, {3.5057100091215754`*^9, 
   3.505710020917562*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[
    None], Polygon3DBox[{{80., 30., 0.}, {80., 30., 
     1.2246467991473532`*^-14}, {63.33333333333334, 30., 
     1.0205389992894611`*^-14}, {63.333333333333336`, 30., 0.}, {80., 30., 
     0.}}], Polygon3DBox[{{63.333333333333336`, 30., 0.}, {63.33333333333334, 
     30., 1.0205389992894611`*^-14}, {46.66666666666667, 30., 
     8.164311994315689*^-15}, {46.66666666666667, 30., 0.}, {
     63.333333333333336`, 30., 0.}}], 
    Polygon3DBox[{{46.66666666666667, 30., 0.}, {46.66666666666667, 30., 
     8.164311994315689*^-15}, {30.000000000000014`, 30., 
     6.123233995736768*^-15}, {30., 30., 0.}, {46.66666666666667, 30., 0.}}], 
    Polygon3DBox[{{30., 30., 0.}, {30., 30., 6.123233995736766*^-15}, {
     13.333333333333336`, 30., 4.0821559971578446`*^-15}, {
     13.333333333333343`, 30., 0.}, {30., 30., 0.}}], 
    Polygon3DBox[{{13.333333333333343`, 30., 0.}, {13.333333333333336`, 30., 
     4.0821559971578446`*^-15}, {-3.3333333333333286`, 30., 
     2.0410779985789227`*^-15}, {-3.3333333333333286`, 30., 0.}, {
     13.333333333333343`, 30., 0.}}], 
    Polygon3DBox[{{-3.3333333333333286`, 30., 0.}, {-3.3333333333333286`, 30.,
      2.041077998578923*^-15}, {-19.999999999999993`, 30., 
     1.0197233050851683`*^-30}, {-19.999999999999986`, 30., 
     0.}, {-3.3333333333333286`, 30., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDDBEN+Aw5wVOOz9BzbfFkM8BIe/VuAIB7Ax
/4MxxKGmYYgDAPzZQAA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      Polygon3DBox[{{30., 30., -50.}, {29.999999999999993`, 30., -50.}, {
       29.999999999999996`, 30., -33.33333333333334}, {30., 
       30., -33.333333333333336`}, {30., 30., -50.}}], 
      Polygon3DBox[{{30., 30., -33.333333333333336`}, {29.999999999999996`, 
       30., -33.33333333333334}, {29.999999999999996`, 
       30., -16.66666666666667}, {29.999999999999996`, 
       30., -16.66666666666667}, {30., 30., -33.333333333333336`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., -16.66666666666667}, {
       29.999999999999996`, 30., -16.66666666666667}, {29.999999999999996`, 
       30., -1.4210854715202004`*^-14}, {29.999999999999996`, 30., 0.}, {
       29.999999999999996`, 30., -16.66666666666667}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 0.}, {29.999999999999996`, 30.,
        0.}, {29.999999999999996`, 30., 16.666666666666664`}, {
       29.999999999999996`, 30., 16.666666666666657`}, {29.999999999999996`, 
       30., 0.}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 16.666666666666657`}, {
       29.999999999999996`, 30., 16.666666666666664`}, {30., 30., 
       33.33333333333333}, {29.999999999999996`, 30., 33.33333333333333}, {
       29.999999999999996`, 30., 16.666666666666657`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 33.33333333333333}, {30., 30., 
       33.33333333333333}, {30., 30., 49.99999999999999}, {
       29.999999999999993`, 30., 49.999999999999986`}, {29.999999999999996`, 
       30., 33.33333333333333}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4YIhD3YkhvhqHOWtw2At1py0Od2L4awWOcIC6E0c4eB4A
AJNCRzc=
        "]], 
       {GrayLevel[0.5], EdgeForm[None], 
        Polygon3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {
         80., 30., 50.}, {80., 30., -50.}}], 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., 30., -50.}, {-20., 30., -50.}, {-20., 30., 50.}, {
          80., 30., 50.}, {80., 30., -50.}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcZjyXljMYZbBAZjI6lUg4O/QcG5P6Et3C7h4
WCgIuDvsCZ6078NMG7g4E5i0c4Dw7ODiG8DmaGGobwCLcx1AN//PfxAwPjAD
zT0QYHIA3Z0bcJizAoe9/8Dm22K4MwSHv1bgCAewMf+DHbC7EzM8AUoEcZw=

          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc5jyXljMYZbBAQjf8wBMvOHcntCX7hYHVq8C
AQe4+J7gSfs+zLQ5sAYsbgAXh9JQPsNedPUrIOod0M2HiDvAxWdA3fPvPwh4
wMXR3Ilhzmo0c9DcCRdHc6ctDndihMMKtHBAcydcHD08AeBeeNM=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmBhgIcWCI2cz5YO+z/RC+p8MqMPB32HHm/qXcO8oH
YOKhYODuEGHlJLHouy5cHELbOUx5LyzmMMsALr4CbI4WhvoDYHGuA+jmQ2iT
A+juISQOMwfibge4OMxeiLgBXBzVnTCAUL8Gov4AuvkQcQe4OJp7cIovwO5f
qHkY4XMAR3geCMMe/lBzMOILSmPEL0FxtPCEi6OFJ1wce3gi1K9BCX+E+WtQ
4gszHQIAeincIA==
           "]]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID71nZNbwdfJgQEMPA8wQIFD+r1VX5TdHFavAgEH
uPg9Tc/4Hz4eDmvA4gZwcah+qDkMe9HVr4Coh8nDzYeIO8DFz0Dd8+8/CHjA
xdHciWHOajRz0NwJF0fTb4vDnRjhsAItHNDcCRfHFZ4AcnNkeQ==
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID71nZNbwdfJgQEFeB5wSL+36ouyG1x89SoQcDhw
T9Mz/oePB1x8DVjc4ABUH5o5DHvR1a+AqHdANx8i7uBwBs09//6DgIcDDndi
mAN1pwMOdzrgcKctDndihAPUnQdwuPMArvAEALytZHk=
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4wy5fh/VYTBwYw8DwApR1inuW/NHtn67AKDBzg
4tP6BNpe1DpCxQ3g4qe+c3Ir+DpBzYEBhPo1EPUO6OZDxB3g4mjuISgOMwfG
h7oXbi+quAGaO2HmMDCgq4e69wC6+VD3HsDhHpziaOEJF0cLT7g4jvA8gBae
B9DNh7kPh3sIiqP59wAs/tHC5wAs/tHC8wCO8DwAi39082HxjysdAgDjldI/

            "]]}, 
          {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
           EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCU3YHVq0DAH0M8LBQE3DHEmSA0hvgG
sDlaGOINYHGuA+jif/6DgDGGOIQ2wRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcQhNGZ4AgDlX08A
            "]], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa7gBMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBqTRONw==
             "]]}, 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{80., 50., -30.}, {-20., 
             50., -30.}, {-20., -50., -30.}, {80., -50., -30.}, {80., 
             50., -30.}}]}, 
           {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
            EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAXYOq1eBgD+GeFgoCLhjiDNBaXTxDWBz
tDDEG8DiXAfQxf/8BwFjDHEIbYIhvgGHOStw2PsPbL4thngIDn+twBEOYGP+
B2OIQ2jM8AQAwclAAA==
             "]], 
            {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngdQ+XYOq1eBgAOG+BqwuAGGONTAveji
KyDqHbCLO2CI//sPAh4Y4lB3YoivxmHOGhz2Qt1pi8OdGP5agSMcoO7EEQ6I
8AQADfhHNw==
              "]]}, 
            {GrayLevel[0], AbsoluteThickness[0.5], 
             Line3DBox[{{80., -50., 30.}, {-20., -50., 30.}, {-20., 50., 
              30.}, {80., 50., 30.}, {80., -50., 30.}}], 
             {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
              Text3DBox[
               FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], 
              Text3DBox[
               FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
              Text3DBox[
               FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
              Text3DBox[
               FormBox["\<\"{4, 1}\"\>", TraditionalForm], {50., 0, 0}], 
              Text3DBox[
               FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, -30.}], 
              Text3DBox[
               FormBox["\<\"{6, 1}\"\>", TraditionalForm], {
               30., 0, 30.}]}}}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{379.4573085079842, 372.33235628953423`},
  PlotRange:>All,
  ViewPoint->{-0.154820938955792, -0.41485444631962787`, 3.354687208254994},
  ViewVertical->{-0.40668924031293124`, 0.6357840177116572, 
   0.6560354751353877}]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxU1IGgAYBmCHlnUZNtaIKGuyHyzBMqKWtmEUFsHYpLVoJRV0iayQooEo
iG2tgU5KnJWlroQttpmuiMEoK6xTUFYQ0gihrXDFtsBcJtH37vDw3GzplLde
YTAYUmLdi9tOM8PSxZIpL+bd8vn+r7y+gQeXhb4orf3rTvhHt7MltThjXdSI
c3Sh1IfcsNRS5n9RQ/PmlqaG6KVQtQ9/UrRpzLRuWjWJPY/H/NiYOrGJr7Ea
7Bb626OwBz+vaZrHkoGTbRxTR/fxuzMm+y0t2ORz8PdXpXz8eTbQZaVXXscM
+H6hcQ3zONYQNh0kKkfojH5/N0682j2Mi3MWDnBQqD7Ht/PuCkbpk4mZfHwj
ECvFHS5XFbbFj2vxUV1QgUW5DhVetZ+OYKFS5MamkqKveNfMYdrocbeuF3c4
7Gps0LQM4I/3NL/xpErLHKNZelYSzqo3ZGHn0woxNgd3ZPg8MvcEF5Q79fjB
xcvj9/Qd8c/kD7S3J6XZQ89Utqswt7+yD8ffpDnwyqgs4KXlkfQf+NmvCOcL
nSnZ+nOYHZZeAu8AAfw=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwd0E9I0wEchvHJ5maXmKERYtOGJdPBchLVnMbC2CKIGsvESnTgJZzFD0Nh
bDD8twVbo8aa22wzFXRUa1MZQtRSNk+CTgIZSQwqYybVYLPmiL5vh4fP/Tmh
vafuKWKxWArK9angzR1PK97LAmEorIlG/6sr24CPVyTRfdL4K1j8m+zlydtg
5br0DqwzpcqvCtIK58XYiIYURpYDT8jl1JUofNl51+AgTa+ZaRi6PhGDtvKp
TXiEc9vnJN9cS4fgoKbrLZRbMh9gXr//GT7/w+Y9JcWbIj7cNjeL4KvFxH0X
GX+Yt8KWM7Y1KOS7UtC+w9W5ycqxWD/kHu4fh+fq3u3ApER/AE+erhV7yMzU
QgM8msg3w76ZmcvQW9hrg9/bk51QWu9n4Kov54YSnTQI7bKzS/Cjg8/2ks+C
pgHY5/fpodWgtcAX5w0/4DRjZE+QnCFOCazqsFbByZuXmqAjuaWEB9nIDdjY
OjkEL/wd3ZslTzV9PTRHhh+UdofIBVUvAwVjqmFYeHTMD+MeZSJMqrMVX+Ct
3Sx/Hr/MuZ/fqtOKf/LoAos=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.553851381374166`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20.553851381374166`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-20.553851381374166`, 
   30.}, {-20.553851381374166`, -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxV1IkwEYBtDJptaNTNGIWNNGJjNhtgjNTWVhOBGkxrLIEht0E85iTArG
BsPfBVujhq053UwHNaq5tRAh6svYugpqI4hRxKBcfCrZYJvOIb6PF4dzTHNb
dbOIw+EoiPNXwZ09yio+tPhDWHScYfbXVn7FDz9KmBxt+h8o3qIHS+W9WPBF
eh3Xm5NVPUJWMXUuMqamRUsr/kf0SrKbwS/7bxkdtHlRt4CDF2ci2FY1H8cV
vGueKfrtBTaI76kH3mG5Jf0N5w253/jpNrf0Md0QF/Pxz8lWMX71JnbHSUfv
56247YztMxbxnUlsT5VoXbRgIqLHJWX6J7i5/n0KJySGHVzbWNcwTafnw6fw
oVi+FQ/5fF3YXdjoxetXEv1YetKrw588WReWaKUBbG9pWsY/HHyum54NmO/i
Ia/HgK1GjQW/OGv8hxd0Ju4MzRvhHcDVV63VeO7yeRl2JL534p3M0iV8umNu
BLfvjm88o0/IVg8+p0PD5TeCdFg5qMPCCeUoLjw47MXR6c5YiFZljvzBfWsZ
/mtaY89t/q1hFXv0RgK4
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-20.553851381374166`, 30.}}], 
    ArrowBox[{{-20.553851381374166`, 30.}, {-20.553851381374166`, -30.}}], 
    ArrowBox[{{-20.553851381374166`, -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIEwAYBtDF1lYvMUUlwmaNTLaE1ULSqcVC2SQIlaXijRR8CTdjKAlj
wrAyhZnomGsXt7UJNaq5aYgQORdbT0JNAhlJDLTFSixhm25D/L8eDudi70Bz
3wkGgyElph85a+p8Qrom8fgx/1Ig8H9lwVc8/UkUSNMj/7wnD+h+Tk0LLv4i
7sJCXazwLi8hNd4OPVHQ/OWgZ4YOxu4E8NvuB1oDrVtQu7GvyRbCk4WuDZzP
6rQb6Q+NCR8eVtz/iGvG97/hjCa9jV8eMjmzdPmGgIu3ntUK8Lv3kYcmOjyR
0eObFZPrmM81xfBUnK0008VjoUHMPjP4AlcKV+M4KtJkcenVsnILve9auoaL
IplarJqfb8DW3G4L/tMW7cbiKw41/mxPmbFIKfbiKcmNFfzdwGVa6Tmv7hFW
OewarNf2juM3Vdo97FaPMG00a5R1Cpe060uws7W+GhuimzKcTS7fw9frnKP4
1tHT3Vf05eqfp1/T/qG8Hh+9JO9XY96Y/DHOPT/rwGGLLOKnm5PndnDH7yR3
ke7TZv7+upCQHgPz6wKr
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.553851381374166"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.55385138137416"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.942619271714406"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.31396388285856"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.668096958538413"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.005217243371575"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.32551110067031"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.629153078283068"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.91630642680542"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.187123574021754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.441746559019336"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.680307429042955"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.902928601827966"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.109723195852624"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.300795330686356"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.476240399372358"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.636145314567827"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.780588729971512"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.909641238390535"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.02336554763781"}], ",", " ", "8.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.12181663530191"}], ",", " ", "7.199999999999999"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.205041883295237"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.273081192958173"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.32596708137821"}], ",", " ", "3.6000000000000014"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.363724759470244"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.38637219225815"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.393920141694565"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.38637219225815"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.363724759470244"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.32596708137821"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.273081192958173"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.205041883295237"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.12181663530191"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.02336554763781"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.909641238390535"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.780588729971512"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.636145314567827"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.476240399372386"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.300795330686356"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.109723195852624"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.902928601827966"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.680307429042955"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.44174655901932"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.187123574021754"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.91630642680542"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.629153078283068"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.32551110067031"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.005217243371575"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.668096958538413"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.31396388285856"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.942619271714406"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.55385138137416"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20.553851381374166`, 
      30.}, {-20.55385138137416, 30.}, {-20.942619271714406`, 
      28.8}, {-21.31396388285856, 27.6}, {-21.668096958538413`, 
      26.4}, {-22.005217243371575`, 25.2}, {-22.32551110067031, 
      24.}, {-22.629153078283068`, 22.8}, {-22.91630642680542, 
      21.6}, {-23.187123574021754`, 20.4}, {-23.441746559019336`, 
      19.200000000000003`}, {-23.680307429042955`, 
      18.}, {-23.902928601827966`, 16.8}, {-24.109723195852624`, 
      15.600000000000001`}, {-24.300795330686356`, 
      14.4}, {-24.476240399372358`, 13.2}, {-24.636145314567827`, 
      12.}, {-24.780588729971512`, 10.8}, {-24.909641238390535`, 
      9.600000000000001}, {-25.02336554763781, 
      8.400000000000002}, {-25.12181663530191, 
      7.199999999999999}, {-25.205041883295237`, 6.}, {-25.273081192958173`, 
      4.800000000000001}, {-25.32596708137821, 
      3.6000000000000014`}, {-25.363724759470244`, 
      2.400000000000002}, {-25.38637219225815, 
      1.2000000000000028`}, {-25.393920141694565`, 
       0}, {-25.38637219225815, -1.1999999999999993`}, {-25.363724759470244`, \
-2.3999999999999986`}, {-25.32596708137821, -3.6000000000000014`}, \
{-25.273081192958173`, -4.799999999999997}, {-25.205041883295237`, -6.}, \
{-25.12181663530191, -7.199999999999996}, {-25.02336554763781, \
-8.399999999999999}, {-24.909641238390535`, -9.600000000000001}, \
{-24.780588729971512`, -10.799999999999997`}, {-24.636145314567827`, -12.}, \
{-24.476240399372386`, -13.199999999999996`}, {-24.300795330686356`, \
-14.399999999999999`}, {-24.109723195852624`, -15.600000000000001`}, \
{-23.902928601827966`, -16.799999999999997`}, {-23.680307429042955`, -18.}, \
{-23.44174655901932, -19.199999999999996`}, {-23.187123574021754`, -20.4}, \
{-22.91630642680542, -21.6}, {-22.629153078283068`, -22.799999999999997`}, \
{-22.32551110067031, -24.}, {-22.005217243371575`, -25.199999999999996`}, \
{-21.668096958538413`, -26.4}, {-21.31396388285856, -27.599999999999994`}, \
{-20.942619271714406`, -28.799999999999997`}, {-20.55385138137416, -30.}, \
{-20.553851381374166`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20.553851381374166`, 
     30.}, {-20.55385138137416, 30.}, {-20.942619271714406`, 
     28.8}, {-21.31396388285856, 27.6}, {-21.668096958538413`, 
     26.4}, {-22.005217243371575`, 25.2}, {-22.32551110067031, 
     24.}, {-22.629153078283068`, 22.8}, {-22.91630642680542, 
     21.6}, {-23.187123574021754`, 20.4}, {-23.441746559019336`, 
     19.200000000000003`}, {-23.680307429042955`, 18.}, {-23.902928601827966`,
      16.8}, {-24.109723195852624`, 
     15.600000000000001`}, {-24.300795330686356`, 
     14.4}, {-24.476240399372358`, 13.2}, {-24.636145314567827`, 
     12.}, {-24.780588729971512`, 10.8}, {-24.909641238390535`, 
     9.600000000000001}, {-25.02336554763781, 
     8.400000000000002}, {-25.12181663530191, 
     7.199999999999999}, {-25.205041883295237`, 6.}, {-25.273081192958173`, 
     4.800000000000001}, {-25.32596708137821, 
     3.6000000000000014`}, {-25.363724759470244`, 
     2.400000000000002}, {-25.38637219225815, 
     1.2000000000000028`}, {-25.393920141694565`, 
      0}, {-25.38637219225815, -1.1999999999999993`}, {-25.363724759470244`, \
-2.3999999999999986`}, {-25.32596708137821, -3.6000000000000014`}, \
{-25.273081192958173`, -4.799999999999997}, {-25.205041883295237`, -6.}, \
{-25.12181663530191, -7.199999999999996}, {-25.02336554763781, \
-8.399999999999999}, {-24.909641238390535`, -9.600000000000001}, \
{-24.780588729971512`, -10.799999999999997`}, {-24.636145314567827`, -12.}, \
{-24.476240399372386`, -13.199999999999996`}, {-24.300795330686356`, \
-14.399999999999999`}, {-24.109723195852624`, -15.600000000000001`}, \
{-23.902928601827966`, -16.799999999999997`}, {-23.680307429042955`, -18.}, \
{-23.44174655901932, -19.199999999999996`}, {-23.187123574021754`, -20.4}, \
{-22.91630642680542, -21.6}, {-22.629153078283068`, -22.799999999999997`}, \
{-22.32551110067031, -24.}, {-22.005217243371575`, -25.199999999999996`}, \
{-21.668096958538413`, -26.4}, {-21.31396388285856, -27.599999999999994`}, \
{-20.942619271714406`, -28.799999999999997`}, {-20.55385138137416, -30.}, \
{-20.553851381374166`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxV1IUwEYBuDFltpNnERFxGaOLPyB2SSs/RQLw0UQNdQkS0zoRtyKg1Iw
Jgy1ZTCTHLbmbLNtoKLOLUMEqZMx80aoSRBDkYG5cUwyYTO3EX2vFw9PcetD
7YMjAoFATWwbaUfiJK/+JJ8IYMlpjjtcl/MNv/ws5fbprj++o3/p9kxlAy78
KruHy0yR3BtiXj10JdhbR0vmFicG6cXIdQ5PNbcZrbRphvVg/62RIO7Pda/i
bNFd5xC9cJP34yd1LR+wsm/vO04a9jfx2wNh5iu6YrWUwevPVKV4+n3okY1e
ep604Evn+1ewhLFF8EA0Q2enC83BDpxxvOM1vlD2MYrDUkMKl1SerRim99yz
53BeKKnCeq/3Gnakdxrwr8ZwM5aVu1j8xZmwY6lO5sMD8up5vGZlhA76jc/0
GOtdTgO2GFv78ORF42/sYbuEI7SoW5SFi+5YivDo7asKbA3/qMWp+Fw9rqoZ
7caX/z3dGaPPKLaOjdOBzhP3/fSspp3FYrOmB6df5Lvw0nBtKEBr4wU/cdN2
nHlHL8dSu7FTvPo/+fYDeg==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-20.553851381374166`, 
     30.}, {-20.55385138137416, 30.}, {-20.942619271714406`, 
     28.8}, {-21.31396388285856, 27.6}, {-21.668096958538413`, 
     26.4}, {-22.005217243371575`, 25.2}, {-22.32551110067031, 
     24.}, {-22.629153078283068`, 22.8}, {-22.91630642680542, 
     21.6}, {-23.187123574021754`, 20.4}, {-23.441746559019336`, 
     19.200000000000003`}, {-23.680307429042955`, 18.}, {-23.902928601827966`,
      16.8}, {-24.109723195852624`, 
     15.600000000000001`}, {-24.300795330686356`, 
     14.4}, {-24.476240399372358`, 13.2}, {-24.636145314567827`, 
     12.}, {-24.780588729971512`, 10.8}, {-24.909641238390535`, 
     9.600000000000001}, {-25.02336554763781, 
     8.400000000000002}, {-25.12181663530191, 
     7.199999999999999}, {-25.205041883295237`, 6.}, {-25.273081192958173`, 
     4.800000000000001}, {-25.32596708137821, 
     3.6000000000000014`}, {-25.363724759470244`, 
     2.400000000000002}, {-25.38637219225815, 
     1.2000000000000028`}, {-25.393920141694565`, 
      0}, {-25.38637219225815, -1.1999999999999993`}, {-25.363724759470244`, \
-2.3999999999999986`}, {-25.32596708137821, -3.6000000000000014`}, \
{-25.273081192958173`, -4.799999999999997}, {-25.205041883295237`, -6.}, \
{-25.12181663530191, -7.199999999999996}, {-25.02336554763781, \
-8.399999999999999}, {-24.909641238390535`, -9.600000000000001}, \
{-24.780588729971512`, -10.799999999999997`}, {-24.636145314567827`, -12.}, \
{-24.476240399372386`, -13.199999999999996`}, {-24.300795330686356`, \
-14.399999999999999`}, {-24.109723195852624`, -15.600000000000001`}, \
{-23.902928601827966`, -16.799999999999997`}, {-23.680307429042955`, -18.}, \
{-23.44174655901932, -19.199999999999996`}, {-23.187123574021754`, -20.4}, \
{-22.91630642680542, -21.6}, {-22.629153078283068`, -22.799999999999997`}, \
{-22.32551110067031, -24.}, {-22.005217243371575`, -25.199999999999996`}, \
{-21.668096958538413`, -26.4}, {-21.31396388285856, -27.599999999999994`}, \
{-20.942619271714406`, -28.799999999999997`}, {-20.55385138137416, -30.}, \
{-20.553851381374166`, -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxV1IkwEYBtDFltZNrFCR0FmjjOlgNols02RRbBFIiVr4M1TwRjaLj4XC
2GCsWgtmUmOtOdtsCjrUtaUMIXJOZldCbggxEhlYxmqUg82aK3ofLw7ndO/d
5r5DLBZLRuxbeWe2PClblngDmH8mFDpYXbSOn62IQnu0ftd3+DetKqxvw2Uf
xV24ypAobuIlZbYrkYctND8Y9j6nw4kbITyr7NdZacMbZgL7b41F8HCxJ4ZP
cDpdNvrdzaQfD7V0v8f15vQGzmn3tvHrP+zCF7QwJuDizccNAjy3EL1np1ef
5Cz48oXhNczn2hN4ZKdA7aDLTBENLjimeYnrqpZ2cFyk3cdna84JR+m0Z/48
LonmGvDA5OR17Myn2vCPO3ElFle7GfzBlXVgkVrswyOSi4v4s5XLdtKvfIZB
POB2abFF12vGM5d0P/EEo2eP0Rwj5wiuaLdU4PHb16TYGv8kx/uZYCuuvTpu
xI3/HqWm6Erp16PTdOD+8R4/Pa9QMZhnUjzA+aelbrw6Ko8G6ObMyS+443uG
+5bOmv7++nYqKfsP+MsDSQ==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.553851381374166"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.55385138137416"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.942619271714406"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.31396388285856"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.668096958538413"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.005217243371575"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.32551110067031"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.629153078283068"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.91630642680542"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.187123574021754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.441746559019336"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.680307429042955"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.902928601827966"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.109723195852624"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.300795330686356"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.476240399372358"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.636145314567827"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.780588729971512"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.909641238390535"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.02336554763781"}], ",", " ", "8.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.12181663530191"}], ",", " ", "7.199999999999999"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.205041883295237"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.273081192958173"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.32596708137821"}], ",", " ", "3.6000000000000014"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.363724759470244"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.38637219225815"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.393920141694565"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.38637219225815"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.363724759470244"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.32596708137821"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.273081192958173"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.205041883295237"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.12181663530191"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.02336554763781"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.909641238390535"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.780588729971512"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.636145314567827"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.476240399372386"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.300795330686356"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.109723195852624"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.902928601827966"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.680307429042955"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.44174655901932"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "23.187123574021754"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.91630642680542"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.629153078283068"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.32551110067031"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22.005217243371575"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.668096958538413"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21.31396388285856"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.942619271714406"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.55385138137416"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-20.553851381374166`, 
      30.}, {-20.55385138137416, 30.}, {-20.942619271714406`, 
      28.8}, {-21.31396388285856, 27.6}, {-21.668096958538413`, 
      26.4}, {-22.005217243371575`, 25.2}, {-22.32551110067031, 
      24.}, {-22.629153078283068`, 22.8}, {-22.91630642680542, 
      21.6}, {-23.187123574021754`, 20.4}, {-23.441746559019336`, 
      19.200000000000003`}, {-23.680307429042955`, 
      18.}, {-23.902928601827966`, 16.8}, {-24.109723195852624`, 
      15.600000000000001`}, {-24.300795330686356`, 
      14.4}, {-24.476240399372358`, 13.2}, {-24.636145314567827`, 
      12.}, {-24.780588729971512`, 10.8}, {-24.909641238390535`, 
      9.600000000000001}, {-25.02336554763781, 
      8.400000000000002}, {-25.12181663530191, 
      7.199999999999999}, {-25.205041883295237`, 6.}, {-25.273081192958173`, 
      4.800000000000001}, {-25.32596708137821, 
      3.6000000000000014`}, {-25.363724759470244`, 
      2.400000000000002}, {-25.38637219225815, 
      1.2000000000000028`}, {-25.393920141694565`, 
       0}, {-25.38637219225815, -1.1999999999999993`}, {-25.363724759470244`, \
-2.3999999999999986`}, {-25.32596708137821, -3.6000000000000014`}, \
{-25.273081192958173`, -4.799999999999997}, {-25.205041883295237`, -6.}, \
{-25.12181663530191, -7.199999999999996}, {-25.02336554763781, \
-8.399999999999999}, {-24.909641238390535`, -9.600000000000001}, \
{-24.780588729971512`, -10.799999999999997`}, {-24.636145314567827`, -12.}, \
{-24.476240399372386`, -13.199999999999996`}, {-24.300795330686356`, \
-14.399999999999999`}, {-24.109723195852624`, -15.600000000000001`}, \
{-23.902928601827966`, -16.799999999999997`}, {-23.680307429042955`, -18.}, \
{-23.44174655901932, -19.199999999999996`}, {-23.187123574021754`, -20.4}, \
{-22.91630642680542, -21.6}, {-22.629153078283068`, -22.799999999999997`}, \
{-22.32551110067031, -24.}, {-22.005217243371575`, -25.199999999999996`}, \
{-21.668096958538413`, -26.4}, {-21.31396388285856, -27.599999999999994`}, \
{-20.942619271714406`, -28.799999999999997`}, {-20.55385138137416, -30.}, \
{-20.553851381374166`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-20.553851381374166`, 
     30.}, {-20.55385138137416, 30.}, {-20.942619271714406`, 
     28.8}, {-21.31396388285856, 27.6}, {-21.668096958538413`, 
     26.4}, {-22.005217243371575`, 25.2}, {-22.32551110067031, 
     24.}, {-22.629153078283068`, 22.8}, {-22.91630642680542, 
     21.6}, {-23.187123574021754`, 20.4}, {-23.441746559019336`, 
     19.200000000000003`}, {-23.680307429042955`, 18.}, {-23.902928601827966`,
      16.8}, {-24.109723195852624`, 
     15.600000000000001`}, {-24.300795330686356`, 
     14.4}, {-24.476240399372358`, 13.2}, {-24.636145314567827`, 
     12.}, {-24.780588729971512`, 10.8}, {-24.909641238390535`, 
     9.600000000000001}, {-25.02336554763781, 
     8.400000000000002}, {-25.12181663530191, 
     7.199999999999999}, {-25.205041883295237`, 6.}, {-25.273081192958173`, 
     4.800000000000001}, {-25.32596708137821, 
     3.6000000000000014`}, {-25.363724759470244`, 
     2.400000000000002}, {-25.38637219225815, 
     1.2000000000000028`}, {-25.393920141694565`, 
      0}, {-25.38637219225815, -1.1999999999999993`}, {-25.363724759470244`, \
-2.3999999999999986`}, {-25.32596708137821, -3.6000000000000014`}, \
{-25.273081192958173`, -4.799999999999997}, {-25.205041883295237`, -6.}, \
{-25.12181663530191, -7.199999999999996}, {-25.02336554763781, \
-8.399999999999999}, {-24.909641238390535`, -9.600000000000001}, \
{-24.780588729971512`, -10.799999999999997`}, {-24.636145314567827`, -12.}, \
{-24.476240399372386`, -13.199999999999996`}, {-24.300795330686356`, \
-14.399999999999999`}, {-24.109723195852624`, -15.600000000000001`}, \
{-23.902928601827966`, -16.799999999999997`}, {-23.680307429042955`, -18.}, \
{-23.44174655901932, -19.199999999999996`}, {-23.187123574021754`, -20.4}, \
{-22.91630642680542, -21.6}, {-22.629153078283068`, -22.799999999999997`}, \
{-22.32551110067031, -24.}, {-22.005217243371575`, -25.199999999999996`}, \
{-21.668096958538413`, -26.4}, {-21.31396388285856, -27.599999999999994`}, \
{-20.942619271714406`, -28.799999999999997`}, {-20.55385138137416, -30.}, \
{-20.553851381374166`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwd0E9I0wEchvHJltYlVqRITFejDE2YLiLdnLIoNAKxsUzUpAZeZLP4oSiM
DcbKuWBr1LDlZtucQkm5NhdDEF3G7BTohhCjiEFpTIcpzD/bqL6vh4fP/Tmr
fCDvzmOxWDLK/iPn3C1Jyj6KpwJQcC4cPlR9agU++yQM75G6bd+RfVJVUNcK
ecuiu7BCnyhsLk3KRq5GHitIQWhx6jm5mLgZhu+6erQ2Uv+emYD+W2MRaCn0
xuBJTqdrhJxrSfrhoOLePKwz7azCjGbvJxw/YBe8ICtj5Vz4fVhaDqc/RB/a
yaUnGTOsv2z5AgVcewJa1/PVoyTPGOmD+cf7XsKaioV1GBdqsvB81YVKB7nj
DVbDomhGCnsnJ29AZy7VCjfb4l1QdNHNwM+u3VEoVIt80Cq+Mgu/2bhsJ/nK
px+AvW6XBpq1ShN8W6vdghOMjj1Gcgyco5DfbuZDz53rEmiLf22E2XToNrx0
zWOADX+HUq/JMsnasTdkoP/EfT8ZbFIxsNTY9Ajmnha74ZKjMRog5enTv2DH
Rpo7g3/Sf39+n0nK/gP0kQK5
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwd0VFLkwEYhuHFlssT+RQXIWurUclsMFtENbfiC0UjCB1Lo3Ko0Im4JcMo
GBuMVTZhS3To0ulmOqhRzU1Dgsi12DwKaiOIYcRAnayGKExrDvF9Ori5fsB9
vOue5u4BDofDUu5fRc/20Sz7SRkIQ8mJSOS/+spvcOizPLJDWjaDB/+SPXxV
KxR+VbTDGmtacF2UZUeuxB5rSclCNDBMRtPXIvCNrtvsIq2zxhkYapmIQadg
OgkreHe8I+SH5mwIPtR2fIQq+9Z3WDDtrMAX/7j8UVKWlDLw51O1FL59l+h1
k/GBggNeOuf8AiWMOw0HMyX6MVLYH+uDJWV9z+GFmsUMTMlNu/BkbbVsnNya
nj8DDycKamjw+69CTzHXCv/cTOmg4rTPCJe822NQrlcE4aDy/Hu47GK4HnIy
aH0ADT6vCTrMXXb4+qJ5A84YLdwJkmfjHYLiWw4xnGprqIOu1I9GuJtfuAHP
1k/Z4OW9J7mX5Km6tdJXZPh+eWeInG/qMUJRf9MjWHx2xAfj442JMKnJV63C
27/zzBw+JTmb68ey7D7zVgJl
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.553851381374166`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.553851381374166`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-10.553851381374166`, 
   30.}, {-10.553851381374166`, -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIEwAYBtDZ5qWXmNFEwtSGFc7BbCGVOmWSbCFEiS3RHCr0Em7GMArG
hGE2FbaGG3Nu022pUFLt0mQIYlPZfBJqI5BRyMBSViMcTGuO6P96OJzz/YPt
D/IYDIaYWHdyjsNzSfFa/aIfc6tCof8rznzCkxuC0BE9fODJ/00PFDbKcNlH
YQ/maROcW+VJsaUlPNpBc4PriyZ6PdEWwm/lDzVmWutVzWPfnZkwNnDmYvg0
677TQq/cTvrw047eVdw4nv6Ms+qjXfzyD7NwiubHqtn465ioGr9bij6y0pGJ
rB431Rm2MJdtTWDjXoHCRpfpwkO44NTQNL7G+7CH4wL1Mb5Qe4lvp9Nzgcu4
JJoVYeXCwk3syKVk+GdnXI6FNS4V3nQe2rBAIfRgY/3VZfzFzGY66FmP9glW
upxqrNf0j+M31zW/8LxqmDlDs0ZYRbiiS1+B3fdaG7A5vi3Bx5ngXXzlhnsE
N/99nnpFX2z4fvI17X9c3OejA9IBFS7XSZ/h3ItSF47YJVE/3Z45+w13/8iw
39Ne04mD/cqk+B/xEgIV
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-10.553851381374166`, 30.}}], 
    ArrowBox[{{-10.553851381374166`, 30.}, {-10.553851381374166`, -30.}}], 
    ArrowBox[{{-10.553851381374166`, -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdzk1IEwAchvHF5lYXmaESMV0NS2aD1SLya8bC0AhCxUy0RgleZNMYE4Ux
YVh+wWzUWHObbeYGKtXaXAwhai22TkFOhBhFDFJjOmSDbTqH+H89PPyuz/me
gbbeEwwGQ0aZ/+ZtmbK47GvtkhcKKgKBY5XFq/DFN3EgS44k3QV7pIJT3wF5
PyUPYZUuVnK3PC4z3Qw9aycF/uDSSzIYuxOA7+R9WiOp+6ByQk/rbAhOl8yv
wdOsB3YT+akl7oHD7Y8+w/rJ1DrMabL/4Jt9JucVKVoTcuGfCakQvv8YeWIm
w1M5PWy4Nv0DCrjmGDRssZUWkjceUkN2oXoGVld92YJRseYAXrhcKbKSqXnf
FVgayUlhv8t1G9ryiQ640xmVQ8klhwp+t2csUKyUuKGh9voK/G3kMm3ka7du
CPY77Bqo1/ZMwrc12l3oVI0wZ0nWKOsk5Hfp+XDu/q06aIz+aoIHaf89eLVx
bhTeOBxLLJAX6zZPLZLewaLHHtLXrFDB8vHmpzD//IwDhq1NES/Zlj67Abu3
09xl/KcKkv/PxWVH9HUCjg==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.942619271714406"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.313963882858559"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.668096958538413"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.005217243371575"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.325511100670312"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.629153078283068"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.91630642680542"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.187123574021754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.441746559019336"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.680307429042955"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.902928601827966"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.109723195852624"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.300795330686356"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.476240399372358"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.636145314567827"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.780588729971512"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.909641238390535"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.023365547637809"}], ",", " ", "8.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.121816635301911"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.205041883295237"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.273081192958173"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32596708137821"}], ",", " ", "3.6000000000000014"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.363724759470244"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.38637219225815"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.393920141694565"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.38637219225815"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.363724759470244"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32596708137821"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.273081192958173"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.205041883295237"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.121816635301911"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.023365547637809"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.909641238390535"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.780588729971512"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.636145314567827"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.476240399372386"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.300795330686356"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.109723195852624"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.902928601827966"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.680307429042955"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.441746559019322"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.187123574021754"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.91630642680542"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.629153078283068"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.325511100670312"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.005217243371575"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.668096958538413"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.313963882858559"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.942619271714406"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-10.553851381374166`, 
      30.}, {-10.553851381374159`, 30.}, {-10.942619271714406`, 
      28.8}, {-11.313963882858559`, 27.6}, {-11.668096958538413`, 
      26.4}, {-12.005217243371575`, 25.2}, {-12.325511100670312`, 
      24.}, {-12.629153078283068`, 22.8}, {-12.91630642680542, 
      21.6}, {-13.187123574021754`, 20.4}, {-13.441746559019336`, 
      19.200000000000003`}, {-13.680307429042955`, 
      18.}, {-13.902928601827966`, 16.8}, {-14.109723195852624`, 
      15.600000000000001`}, {-14.300795330686356`, 
      14.4}, {-14.476240399372358`, 13.2}, {-14.636145314567827`, 
      12.}, {-14.780588729971512`, 10.8}, {-14.909641238390535`, 
      9.600000000000001}, {-15.023365547637809`, 
      8.400000000000002}, {-15.121816635301911`, 
      7.199999999999999}, {-15.205041883295237`, 6.}, {-15.273081192958173`, 
      4.800000000000001}, {-15.32596708137821, 
      3.6000000000000014`}, {-15.363724759470244`, 
      2.400000000000002}, {-15.38637219225815, 
      1.2000000000000028`}, {-15.393920141694565`, 
       0}, {-15.38637219225815, -1.1999999999999993`}, {-15.363724759470244`, \
-2.3999999999999986`}, {-15.32596708137821, -3.6000000000000014`}, \
{-15.273081192958173`, -4.799999999999997}, {-15.205041883295237`, -6.}, \
{-15.121816635301911`, -7.199999999999996}, {-15.023365547637809`, \
-8.399999999999999}, {-14.909641238390535`, -9.600000000000001}, \
{-14.780588729971512`, -10.799999999999997`}, {-14.636145314567827`, -12.}, \
{-14.476240399372386`, -13.199999999999996`}, {-14.300795330686356`, \
-14.399999999999999`}, {-14.109723195852624`, -15.600000000000001`}, \
{-13.902928601827966`, -16.799999999999997`}, {-13.680307429042955`, -18.}, \
{-13.441746559019322`, -19.199999999999996`}, {-13.187123574021754`, -20.4}, \
{-12.91630642680542, -21.6}, {-12.629153078283068`, -22.799999999999997`}, \
{-12.325511100670312`, -24.}, {-12.005217243371575`, -25.199999999999996`}, \
{-11.668096958538413`, -26.4}, {-11.313963882858559`, -27.599999999999994`}, \
{-10.942619271714406`, -28.799999999999997`}, {-10.553851381374159`, -30.}, \
{-10.553851381374166`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-10.553851381374166`, 
     30.}, {-10.553851381374159`, 30.}, {-10.942619271714406`, 
     28.8}, {-11.313963882858559`, 27.6}, {-11.668096958538413`, 
     26.4}, {-12.005217243371575`, 25.2}, {-12.325511100670312`, 
     24.}, {-12.629153078283068`, 22.8}, {-12.91630642680542, 
     21.6}, {-13.187123574021754`, 20.4}, {-13.441746559019336`, 
     19.200000000000003`}, {-13.680307429042955`, 18.}, {-13.902928601827966`,
      16.8}, {-14.109723195852624`, 
     15.600000000000001`}, {-14.300795330686356`, 
     14.4}, {-14.476240399372358`, 13.2}, {-14.636145314567827`, 
     12.}, {-14.780588729971512`, 10.8}, {-14.909641238390535`, 
     9.600000000000001}, {-15.023365547637809`, 
     8.400000000000002}, {-15.121816635301911`, 
     7.199999999999999}, {-15.205041883295237`, 6.}, {-15.273081192958173`, 
     4.800000000000001}, {-15.32596708137821, 
     3.6000000000000014`}, {-15.363724759470244`, 
     2.400000000000002}, {-15.38637219225815, 
     1.2000000000000028`}, {-15.393920141694565`, 
      0}, {-15.38637219225815, -1.1999999999999993`}, {-15.363724759470244`, \
-2.3999999999999986`}, {-15.32596708137821, -3.6000000000000014`}, \
{-15.273081192958173`, -4.799999999999997}, {-15.205041883295237`, -6.}, \
{-15.121816635301911`, -7.199999999999996}, {-15.023365547637809`, \
-8.399999999999999}, {-14.909641238390535`, -9.600000000000001}, \
{-14.780588729971512`, -10.799999999999997`}, {-14.636145314567827`, -12.}, \
{-14.476240399372386`, -13.199999999999996`}, {-14.300795330686356`, \
-14.399999999999999`}, {-14.109723195852624`, -15.600000000000001`}, \
{-13.902928601827966`, -16.799999999999997`}, {-13.680307429042955`, -18.}, \
{-13.441746559019322`, -19.199999999999996`}, {-13.187123574021754`, -20.4}, \
{-12.91630642680542, -21.6}, {-12.629153078283068`, -22.799999999999997`}, \
{-12.325511100670312`, -24.}, {-12.005217243371575`, -25.199999999999996`}, \
{-11.668096958538413`, -26.4}, {-11.313963882858559`, -27.599999999999994`}, \
{-10.942619271714406`, -28.799999999999997`}, {-10.553851381374159`, -30.}, \
{-10.553851381374166`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdzU1IEwAchvHFlluXWKESMTcbpkyF1SI0N41JoRGEjmWiJSp0CWcxFIOx
wVhlCzZHDZv7aJtT0KGtzckQotZkehJsEsQwYqApSwkH82OO6P92ePgdnwu9
jxUPTzAYDDll+5l37pek5V/q/CEoLItG/6sq/ApfL4qjB6RuL3DykOxjy9og
b1XyAFbqU0V3+Gn5aGP8uZIURmL+N2QsdTsKZ7seaa2k/oN6AgZbXXFoLvKt
wbOs++5R8mNLOgifKrs/QZkx8w3mNAcbcPyIyX5LVq+JuPDHy3oRfD+feGIj
l17lTLDhqnkFCrm2FLRsFajsJG84PgALTg+MwdrKz1swKdYcw4uXKqodZMYX
vgyLE7l62D85eQs687ttcKc92QUlVR41XHbv26FYJQlAS13NAly3cplO8l1A
PwT7PW4NNGl7jXDmmvYPnFDrmC6SZWBxoKDDJIDeezel0Jr83gSPs5G78MoN
rwFe//tid4osl/46NU2GBs/0BMlwc58a8oebn8H8yDkPXHI0JUKkInt+E3b+
znLn8ONz9rZL0/J/6XsBFQ==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-10.553851381374166`, 
     30.}, {-10.553851381374159`, 30.}, {-10.942619271714406`, 
     28.8}, {-11.313963882858559`, 27.6}, {-11.668096958538413`, 
     26.4}, {-12.005217243371575`, 25.2}, {-12.325511100670312`, 
     24.}, {-12.629153078283068`, 22.8}, {-12.91630642680542, 
     21.6}, {-13.187123574021754`, 20.4}, {-13.441746559019336`, 
     19.200000000000003`}, {-13.680307429042955`, 18.}, {-13.902928601827966`,
      16.8}, {-14.109723195852624`, 
     15.600000000000001`}, {-14.300795330686356`, 
     14.4}, {-14.476240399372358`, 13.2}, {-14.636145314567827`, 
     12.}, {-14.780588729971512`, 10.8}, {-14.909641238390535`, 
     9.600000000000001}, {-15.023365547637809`, 
     8.400000000000002}, {-15.121816635301911`, 
     7.199999999999999}, {-15.205041883295237`, 6.}, {-15.273081192958173`, 
     4.800000000000001}, {-15.32596708137821, 
     3.6000000000000014`}, {-15.363724759470244`, 
     2.400000000000002}, {-15.38637219225815, 
     1.2000000000000028`}, {-15.393920141694565`, 
      0}, {-15.38637219225815, -1.1999999999999993`}, {-15.363724759470244`, \
-2.3999999999999986`}, {-15.32596708137821, -3.6000000000000014`}, \
{-15.273081192958173`, -4.799999999999997}, {-15.205041883295237`, -6.}, \
{-15.121816635301911`, -7.199999999999996}, {-15.023365547637809`, \
-8.399999999999999}, {-14.909641238390535`, -9.600000000000001}, \
{-14.780588729971512`, -10.799999999999997`}, {-14.636145314567827`, -12.}, \
{-14.476240399372386`, -13.199999999999996`}, {-14.300795330686356`, \
-14.399999999999999`}, {-14.109723195852624`, -15.600000000000001`}, \
{-13.902928601827966`, -16.799999999999997`}, {-13.680307429042955`, -18.}, \
{-13.441746559019322`, -19.199999999999996`}, {-13.187123574021754`, -20.4}, \
{-12.91630642680542, -21.6}, {-12.629153078283068`, -22.799999999999997`}, \
{-12.325511100670312`, -24.}, {-12.005217243371575`, -25.199999999999996`}, \
{-11.668096958538413`, -26.4}, {-11.313963882858559`, -27.599999999999994`}, \
{-10.942619271714406`, -28.799999999999997`}, {-10.553851381374159`, -30.}, \
{-10.553851381374166`, -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxXkoKwAcB/Bpc/2jEZJcbz3kqDHJ7bUXISXkyhXKPzK0iFpTy63micUe
Y3MVwmxISgyNvxST0iKtXA2JmmOW/L7++PT5VVWfW23HYDD4RH5pU7z6mvk7
8fNazPmt0/0scD/GA3tc3Rvd+qy2f6drHRMLsM8RrwyHSkweWX5m/tBffUce
zVnfnR+kd02ZOrxYXiOW0ZJl4TTW5IzpcZ/H1Al2Y5Uqh+jNbLMGt+RVbOHE
npdTbBW9XeHJD6bjMB1+EsLGF91JIXhpzdAgp/d7rVKcHN13iDlsuQn33zoI
RmifLn0jdnBp/I9jQ7dvsZEr+sSBEcHho/TL1Gok9jRYk3DdzEwGVtgeC/BD
kbEc88JUQnygfB3BXAFPjfvjYzbwuYzNVNDjakkzrlMpRVgqrurBC3HiJzwt
bGWO0aw2lhP2L5b644nC1AQsM56l4U/Lej6OSplow3++Oh9n6aCEG+c5Wtvk
WqmhV9NrhdivK70d2/55qfD+aJpBS+davK9xyb2FvULfKJ2f7wLM/G/zQAJe

  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.942619271714406"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.313963882858559"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.668096958538413"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.005217243371575"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.325511100670312"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.629153078283068"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.91630642680542"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.187123574021754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.441746559019336"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.680307429042955"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.902928601827966"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.109723195852624"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.300795330686356"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.476240399372358"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.636145314567827"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.780588729971512"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.909641238390535"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.023365547637809"}], ",", " ", "8.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.121816635301911"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.205041883295237"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.273081192958173"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32596708137821"}], ",", " ", "3.6000000000000014"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.363724759470244"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.38637219225815"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.393920141694565"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.38637219225815"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.363724759470244"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32596708137821"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.273081192958173"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.205041883295237"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.121816635301911"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.023365547637809"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.909641238390535"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.780588729971512"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.636145314567827"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.476240399372386"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.300795330686356"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.109723195852624"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.902928601827966"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.680307429042955"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.441746559019322"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.187123574021754"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.91630642680542"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.629153078283068"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.325511100670312"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.005217243371575"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.668096958538413"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.313963882858559"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.942619271714406"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-10.553851381374166`, 
      30.}, {-10.553851381374159`, 30.}, {-10.942619271714406`, 
      28.8}, {-11.313963882858559`, 27.6}, {-11.668096958538413`, 
      26.4}, {-12.005217243371575`, 25.2}, {-12.325511100670312`, 
      24.}, {-12.629153078283068`, 22.8}, {-12.91630642680542, 
      21.6}, {-13.187123574021754`, 20.4}, {-13.441746559019336`, 
      19.200000000000003`}, {-13.680307429042955`, 
      18.}, {-13.902928601827966`, 16.8}, {-14.109723195852624`, 
      15.600000000000001`}, {-14.300795330686356`, 
      14.4}, {-14.476240399372358`, 13.2}, {-14.636145314567827`, 
      12.}, {-14.780588729971512`, 10.8}, {-14.909641238390535`, 
      9.600000000000001}, {-15.023365547637809`, 
      8.400000000000002}, {-15.121816635301911`, 
      7.199999999999999}, {-15.205041883295237`, 6.}, {-15.273081192958173`, 
      4.800000000000001}, {-15.32596708137821, 
      3.6000000000000014`}, {-15.363724759470244`, 
      2.400000000000002}, {-15.38637219225815, 
      1.2000000000000028`}, {-15.393920141694565`, 
       0}, {-15.38637219225815, -1.1999999999999993`}, {-15.363724759470244`, \
-2.3999999999999986`}, {-15.32596708137821, -3.6000000000000014`}, \
{-15.273081192958173`, -4.799999999999997}, {-15.205041883295237`, -6.}, \
{-15.121816635301911`, -7.199999999999996}, {-15.023365547637809`, \
-8.399999999999999}, {-14.909641238390535`, -9.600000000000001}, \
{-14.780588729971512`, -10.799999999999997`}, {-14.636145314567827`, -12.}, \
{-14.476240399372386`, -13.199999999999996`}, {-14.300795330686356`, \
-14.399999999999999`}, {-14.109723195852624`, -15.600000000000001`}, \
{-13.902928601827966`, -16.799999999999997`}, {-13.680307429042955`, -18.}, \
{-13.441746559019322`, -19.199999999999996`}, {-13.187123574021754`, -20.4}, \
{-12.91630642680542, -21.6}, {-12.629153078283068`, -22.799999999999997`}, \
{-12.325511100670312`, -24.}, {-12.005217243371575`, -25.199999999999996`}, \
{-11.668096958538413`, -26.4}, {-11.313963882858559`, -27.599999999999994`}, \
{-10.942619271714406`, -28.799999999999997`}, {-10.553851381374159`, -30.}, \
{-10.553851381374166`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-10.553851381374166`, 
     30.}, {-10.553851381374159`, 30.}, {-10.942619271714406`, 
     28.8}, {-11.313963882858559`, 27.6}, {-11.668096958538413`, 
     26.4}, {-12.005217243371575`, 25.2}, {-12.325511100670312`, 
     24.}, {-12.629153078283068`, 22.8}, {-12.91630642680542, 
     21.6}, {-13.187123574021754`, 20.4}, {-13.441746559019336`, 
     19.200000000000003`}, {-13.680307429042955`, 18.}, {-13.902928601827966`,
      16.8}, {-14.109723195852624`, 
     15.600000000000001`}, {-14.300795330686356`, 
     14.4}, {-14.476240399372358`, 13.2}, {-14.636145314567827`, 
     12.}, {-14.780588729971512`, 10.8}, {-14.909641238390535`, 
     9.600000000000001}, {-15.023365547637809`, 
     8.400000000000002}, {-15.121816635301911`, 
     7.199999999999999}, {-15.205041883295237`, 6.}, {-15.273081192958173`, 
     4.800000000000001}, {-15.32596708137821, 
     3.6000000000000014`}, {-15.363724759470244`, 
     2.400000000000002}, {-15.38637219225815, 
     1.2000000000000028`}, {-15.393920141694565`, 
      0}, {-15.38637219225815, -1.1999999999999993`}, {-15.363724759470244`, \
-2.3999999999999986`}, {-15.32596708137821, -3.6000000000000014`}, \
{-15.273081192958173`, -4.799999999999997}, {-15.205041883295237`, -6.}, \
{-15.121816635301911`, -7.199999999999996}, {-15.023365547637809`, \
-8.399999999999999}, {-14.909641238390535`, -9.600000000000001}, \
{-14.780588729971512`, -10.799999999999997`}, {-14.636145314567827`, -12.}, \
{-14.476240399372386`, -13.199999999999996`}, {-14.300795330686356`, \
-14.399999999999999`}, {-14.109723195852624`, -15.600000000000001`}, \
{-13.902928601827966`, -16.799999999999997`}, {-13.680307429042955`, -18.}, \
{-13.441746559019322`, -19.199999999999996`}, {-13.187123574021754`, -20.4}, \
{-12.91630642680542, -21.6}, {-12.629153078283068`, -22.799999999999997`}, \
{-12.325511100670312`, -24.}, {-12.005217243371575`, -25.199999999999996`}, \
{-11.668096958538413`, -26.4}, {-11.313963882858559`, -27.599999999999994`}, \
{-10.942619271714406`, -28.799999999999997`}, {-10.553851381374159`, -30.}, \
{-10.553851381374166`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdy1tIEwAYhuHJ5qYIMUMlYm41OrA1mC3E2maxMGYEUTJNTEWFbsJpjInB
2GDMMoPZyGFrh7Y1hZJqbU4kiJqT6VVQk0BGEoN0sRqhMLVtiP/nxctz9R7v
G2y5U8JgMFSU42fRvV2bUS3IZ8JQeCIaPVBb9Q0+XZRGd0jTZrB0l+znKNsg
76usC4rNqerr/Ixq8nL8gYYUzsdmJshY6loUvu2+a7ST5ve6KRi66YnD8erA
CjzM6vROkh9vZELwvqbnE1SObX2HecPOL/jyP5PzjJSsiLhw7VGjCL6bS9xz
kEuP81Z4sX78CxRyHSloS7O1TpI3GtdD9iH9c3he/DkNk1JDAZ6sOy1xkVuB
yFlYk8g3woHp6avQXcy2wb/tyW4oO+PTwWXvthNKtbIgtMkbPsAfdi7TTb4I
mofhgM9rgFZj3xh8c8H4D07pTEwPybKwyqCgwyqA/ltXFNCeXFXDQm6+FZ5r
8lvgpb2H2VfkKcVG+WsyPFTZGyIjzf06yB9tHoHFJ0d8cMmlToTJltzRdXj7
T447i09Usfn7WEa1D+5yAbY=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdyl9IUwEYh+HFliaInKKFhM4a/cEprBahTi1OKC6CqGEmalKDbmRTGYrC
2GBYmsFMcujS2bbmoESbW5NRiJ2M2ZVgEyGGEQN1cVRCYVPnEL9fFy/PzXte
06J+ekwgELCU7U/Knsjl2W/KcT+UXuC4/+pO/4Svv8u5XdK07T2+R2rTy2pg
zqLiEZSZo+K7Ep4dvBV6Xk1Kg3PjA+Rc9A4HJxubjFbSPKUfg777oyHYJ3Yv
wVOiBscgOXOP98HO6sezsKx3ZxkmDbur8N2+MH2ILFzKZ+DvF+X58ON0uNVG
zr9MWuCN630LUMrYorA/lqYbJnN6Qm0wLavtDSyWfY3BiNxwAC9euVw4Qu64
A1fhmXCyHDZ7PLehPbVVAzdrI41QUeDUwx+OxDCU6xRe2K8s+gxXrIzQTr71
mjtgs9NhgBajphdOlBj/wTG9SThKirpEJ2BenSUPuh5WlkJr5FcVPIgHH8Br
Fa4uePOwe+s9eal0PeMD6W8/+cRHBlRaPZT0qJ7B1KtsJ5wfqQr7SXX87Bqs
34gzn/B/ydz+e45njwDyfwJK
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12.163375074040639`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12.163375074040639`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-12.163375074040639`, 
   30.}, {-12.163375074040639`, -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxW0o4wEcB/Bd2w1vNEKSh7M85KHmduk87bTLhZTQOOGWU/dGhhZRa2px
N9ScWG4Ym6dCmO1ISm6m8erqblJaLq08XH+kqXmYJb+vF58+sXVNZV9esFgs
MdEd+fQ3UYx4K2vegvlxVuvzspC/eGBbYL2lO9yml3d0g19OBY78I/yEk1Wu
0OJoRjz03v5VQvPXbPODtM1VZMWL0nqlllYty6exuXTMjvtCp/ZwMKfGMERv
lDBm3C6p3cQ5Pdf72Ku4PcaT92y/H3TqXhIP/+sWJeGlVUezjt7p9Wrwu/S+
35jP07lw/xlXNkJHqu0tmBvYMowzkn+dYadA8YDj0xJTR+nrqZXXOMzhFeHG
mZlCrPddVuCLSqcUC1OMcrxruBnBApnQhPuz3q7jQy2PrafHTao23Gg0KLBG
WdeDFzKVV3ha3sEeozmdHH8cU6WJwRMfP2RjrfMgHz941srxm7yJTpz7+O1y
lk7IPg2Yoy2tQZ/N9EpBgxxHqwu6sO97uBHvjOY7LHSZJ+IEV597eD/pLUmg
+/8rRvwE8CkB8w==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-12.163375074040639`, 30.}}], 
    ArrowBox[{{-12.163375074040639`, 30.}, {-12.163375074040639`, -30.}}], 
    ArrowBox[{{-12.163375074040639`, -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxV1ImgEYBlBDs3UTX2ONGGVN2kYmWI5Rs2wYRY3B2KLaaCVN2M3QFlI0
EAOprRVYUlKWNm0VbLHldIYEUWborgamDIY0hrBVuCQS7Mdk7H26OJyriheN
z9JYLJaMmH6lLEf5UdmGZNGJ+UUez/mqS1t4bFPkOab7Du3pJ7Qyo6oF5wXE
7Vigi+Tc50VlEzW+V0003+1dHKe9kXse/En+XGukdZ/V89jxcMaHR3LmQvgi
p806Qa8+iDrwy6aONVw1FP+Ok5rj3/jdKTtjkhaGihn88420GC8tB7tMtH84
qcfVt0a+YT5jimDDLlc1TecN+roxN6t7ClcI1ndxWKQ5w9dKbwjNdHzOVYYv
B5NS3LmwcBdbUrEWvP84LMfiEpsaf7UeTWORSmzHBkn5Ct42MmwL/dau68Wd
NqsG67WKIfzxtvYAz6v72DM0p59zARe06gvw7KO6SmwM/6jHZwl3M75ZO9uP
7/x7HXtPX6/cyfxAO3uynzpoV4NSjXmDDQM4NZprw35zfdBJNyau/MFP/iaY
L3RAwBzuFUZl/wHvhwHa
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040639"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.455833929834128"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.73483173269927"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.00058106210114"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.253280259596025"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.49311427030851"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.720255404344137"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.934864026176271"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.137089179034746"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.327069150450917"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.504931984357796"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.6707959444852"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.824769933216217"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.966953869567071"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.09743902951044"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.216308351469877"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.323636709466797"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.419491156090565"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.503931137185361"}], ",", " ", "8.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.577008679896672"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.638768555492675"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.689248418168937"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.728478920852112"}], ",", " ", 
         "3.6000000000000014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.756483808842034"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.773279991963413"}], ",", " ", 
         "1.2000000000000028"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.778877595741463"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.77327999196342"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.756483808842027"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.728478920852112"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.689248418168944"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.638768555492682"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.577008679896664"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.503931137185361"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.419491156090572"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32363670946679"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.216308351469877"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.097439029510426"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.966953869567071"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.824769933216217"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.6707959444852"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.504931984357789"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.327069150450917"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.137089179034746"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.934864026176271"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.720255404344137"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.493114270308503"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.253280259596025"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.00058106210114"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.734831732699277"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.455833929834121"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040639"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-12.163375074040639`, 
      30.}, {-12.163375074040644`, 30.}, {-12.455833929834128`, 
      28.8}, {-12.73483173269927, 27.6}, {-13.00058106210114, 
      26.4}, {-13.253280259596025`, 25.2}, {-13.49311427030851, 
      24.}, {-13.720255404344137`, 22.8}, {-13.934864026176271`, 
      21.6}, {-14.137089179034746`, 20.4}, {-14.327069150450917`, 
      19.200000000000003`}, {-14.504931984357796`, 18.}, {-14.6707959444852, 
      16.8}, {-14.824769933216217`, 
      15.600000000000001`}, {-14.966953869567071`, 14.4}, {-15.09743902951044,
       13.2}, {-15.216308351469877`, 12.}, {-15.323636709466797`, 
      10.8}, {-15.419491156090565`, 9.600000000000001}, {-15.503931137185361`,
       8.400000000000002}, {-15.577008679896672`, 
      7.199999999999999}, {-15.638768555492675`, 6.}, {-15.689248418168937`, 
      4.800000000000001}, {-15.728478920852112`, 
      3.6000000000000014`}, {-15.756483808842034`, 
      2.400000000000002}, {-15.773279991963413`, 
      1.2000000000000028`}, {-15.778877595741463`, 
       0}, {-15.77327999196342, -1.1999999999999993`}, {-15.756483808842027`, \
-2.3999999999999986`}, {-15.728478920852112`, -3.6000000000000014`}, \
{-15.689248418168944`, -4.799999999999997}, {-15.638768555492682`, -6.}, \
{-15.577008679896664`, -7.199999999999996}, {-15.503931137185361`, \
-8.399999999999999}, {-15.419491156090572`, -9.600000000000001}, \
{-15.32363670946679, -10.799999999999997`}, {-15.216308351469877`, -12.}, \
{-15.097439029510426`, -13.199999999999996`}, {-14.966953869567071`, \
-14.399999999999999`}, {-14.824769933216217`, -15.600000000000001`}, \
{-14.6707959444852, -16.799999999999997`}, {-14.504931984357789`, -18.}, \
{-14.327069150450917`, -19.199999999999996`}, {-14.137089179034746`, -20.4}, \
{-13.934864026176271`, -21.6}, {-13.720255404344137`, -22.799999999999997`}, \
{-13.493114270308503`, -24.}, {-13.253280259596025`, -25.199999999999996`}, \
{-13.00058106210114, -26.4}, {-12.734831732699277`, -27.599999999999994`}, \
{-12.455833929834121`, -28.799999999999997`}, {-12.163375074040637`, -30.}, \
{-12.163375074040639`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-12.163375074040639`, 
     30.}, {-12.163375074040644`, 30.}, {-12.455833929834128`, 
     28.8}, {-12.73483173269927, 27.6}, {-13.00058106210114, 
     26.4}, {-13.253280259596025`, 25.2}, {-13.49311427030851, 
     24.}, {-13.720255404344137`, 22.8}, {-13.934864026176271`, 
     21.6}, {-14.137089179034746`, 20.4}, {-14.327069150450917`, 
     19.200000000000003`}, {-14.504931984357796`, 18.}, {-14.6707959444852, 
     16.8}, {-14.824769933216217`, 
     15.600000000000001`}, {-14.966953869567071`, 14.4}, {-15.09743902951044, 
     13.2}, {-15.216308351469877`, 12.}, {-15.323636709466797`, 
     10.8}, {-15.419491156090565`, 9.600000000000001}, {-15.503931137185361`, 
     8.400000000000002}, {-15.577008679896672`, 
     7.199999999999999}, {-15.638768555492675`, 6.}, {-15.689248418168937`, 
     4.800000000000001}, {-15.728478920852112`, 
     3.6000000000000014`}, {-15.756483808842034`, 
     2.400000000000002}, {-15.773279991963413`, 
     1.2000000000000028`}, {-15.778877595741463`, 
      0}, {-15.77327999196342, -1.1999999999999993`}, {-15.756483808842027`, \
-2.3999999999999986`}, {-15.728478920852112`, -3.6000000000000014`}, \
{-15.689248418168944`, -4.799999999999997}, {-15.638768555492682`, -6.}, \
{-15.577008679896664`, -7.199999999999996}, {-15.503931137185361`, \
-8.399999999999999}, {-15.419491156090572`, -9.600000000000001}, \
{-15.32363670946679, -10.799999999999997`}, {-15.216308351469877`, -12.}, \
{-15.097439029510426`, -13.199999999999996`}, {-14.966953869567071`, \
-14.399999999999999`}, {-14.824769933216217`, -15.600000000000001`}, \
{-14.6707959444852, -16.799999999999997`}, {-14.504931984357789`, -18.}, \
{-14.327069150450917`, -19.199999999999996`}, {-14.137089179034746`, -20.4}, \
{-13.934864026176271`, -21.6}, {-13.720255404344137`, -22.799999999999997`}, \
{-13.493114270308503`, -24.}, {-13.253280259596025`, -25.199999999999996`}, \
{-13.00058106210114, -26.4}, {-12.734831732699277`, -27.599999999999994`}, \
{-12.455833929834121`, -28.799999999999997`}, {-12.163375074040637`, -30.}, \
{-12.163375074040639`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIUwEcB+Dp1swXWaIRMWeOTGbCahHmLsqRwoUQObxhJSX0EtuSw6Jg
TBirvMBMaqzlppvpQKWcm4oEUSdj9hTUJJBRxCBbnJRQmKtthP+fDx9fRc9t
w808gUDAEM/3nG+3jGfeqWcjWH6c4/Y3lXzGj98ruTTdtx068Jc2FmjbsfST
6hqutidKL8l4xt0YfdBKy5dXZp/QK4lmDr/svmVz0fZ5dgqHW8aieLh0cg0X
i6763fTry3wY32u9/gZrB3e+4Iw1/QM//ycseErXrCkk+NuAToHnlmK9Hnp1
KOPE9WeHP2K5xJPAI0mxaZSW9kctWFxkeYbPVb9N4rjSmsWVp6pqvPTO5OJp
fDiW0WFzMHgR+3Jb7XizM96NVScDLP7g3x3FSpMqhEfUta/wV5dE6KPHQ/a7
2BzwW7HT1jOIX9TZ/uAptk84RoscooO4vMtZjic6LmiwK77ehLOp5TZ85vyE
Azf8f7g1TZ/Q/CycoSN3Dt0I04t6I4tl/fr7OPfoSACveptiEdqQOrqBr/xO
SRbo5vzi7V/HeGYP6lMBLw==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-12.163375074040639`, 
     30.}, {-12.163375074040644`, 30.}, {-12.455833929834128`, 
     28.8}, {-12.73483173269927, 27.6}, {-13.00058106210114, 
     26.4}, {-13.253280259596025`, 25.2}, {-13.49311427030851, 
     24.}, {-13.720255404344137`, 22.8}, {-13.934864026176271`, 
     21.6}, {-14.137089179034746`, 20.4}, {-14.327069150450917`, 
     19.200000000000003`}, {-14.504931984357796`, 18.}, {-14.6707959444852, 
     16.8}, {-14.824769933216217`, 
     15.600000000000001`}, {-14.966953869567071`, 14.4}, {-15.09743902951044, 
     13.2}, {-15.216308351469877`, 12.}, {-15.323636709466797`, 
     10.8}, {-15.419491156090565`, 9.600000000000001}, {-15.503931137185361`, 
     8.400000000000002}, {-15.577008679896672`, 
     7.199999999999999}, {-15.638768555492675`, 6.}, {-15.689248418168937`, 
     4.800000000000001}, {-15.728478920852112`, 
     3.6000000000000014`}, {-15.756483808842034`, 
     2.400000000000002}, {-15.773279991963413`, 
     1.2000000000000028`}, {-15.778877595741463`, 
      0}, {-15.77327999196342, -1.1999999999999993`}, {-15.756483808842027`, \
-2.3999999999999986`}, {-15.728478920852112`, -3.6000000000000014`}, \
{-15.689248418168944`, -4.799999999999997}, {-15.638768555492682`, -6.}, \
{-15.577008679896664`, -7.199999999999996}, {-15.503931137185361`, \
-8.399999999999999}, {-15.419491156090572`, -9.600000000000001}, \
{-15.32363670946679, -10.799999999999997`}, {-15.216308351469877`, -12.}, \
{-15.097439029510426`, -13.199999999999996`}, {-14.966953869567071`, \
-14.399999999999999`}, {-14.824769933216217`, -15.600000000000001`}, \
{-14.6707959444852, -16.799999999999997`}, {-14.504931984357789`, -18.}, \
{-14.327069150450917`, -19.199999999999996`}, {-14.137089179034746`, -20.4}, \
{-13.934864026176271`, -21.6}, {-13.720255404344137`, -22.799999999999997`}, \
{-13.493114270308503`, -24.}, {-13.253280259596025`, -25.199999999999996`}, \
{-13.00058106210114, -26.4}, {-12.734831732699277`, -27.599999999999994`}, \
{-12.455833929834121`, -28.799999999999997`}, {-12.163375074040637`, -30.}, \
{-12.163375074040639`, -30.}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdyk1IGgAchnGH9rHLcFtGhNNN2kZNcBljK6thLCoGsUm10Za0oEuoG9Jo
IAbShzOwoklZWVopbLJyOkMGo5xhnYJNGQwpQqgMt4gCa5lE/7fDw+/y3Gh5
LWu9wGAwpJR5I2U5vBaX/ihxeqAgz+8/V5n1Cw4tifxHZOe+K+0/qcgobYDc
n+ImWKCLcmp5celwRbCnjhT4As4PZCD62A9n5W1aE6n7orZD99OJIOznzITh
FdZL6zD5/UncDd/VNS/AUsPBb5jUHG3C6WNmxggpDOez4fr7snw4Nx96YyaX
+5JGWH6vfxUK2OYoHIylK8dIrj7YDtMvtY/CBwWLMRgRaU7gzbu3hePkwYy3
EGaHkmVQ5XDUQEtqtwH+ex6RQ/EdmxquWA/HoEgpdsHBkvvf4JqJzbSQky5d
B1TZrBpo1LYY4Odi7R60qzuZEySri5UJ+Y1GPpx6VimBpsifKniS8NXDokdT
XfDhae/uR/KWZPviJ9Lz9vIrN+mtVqghT1/dDVMDOTa4PF4V8pCyRO4WfPE3
wf6Kz3N1f+d6XHoG7cEBsw==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040639"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.455833929834128"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.73483173269927"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.00058106210114"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.253280259596025"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.49311427030851"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.720255404344137"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.934864026176271"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.137089179034746"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.327069150450917"}], ",", " ", 
         "19.200000000000003"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.504931984357796"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.6707959444852"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.824769933216217"}], ",", " ", 
         "15.600000000000001"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.966953869567071"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.09743902951044"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.216308351469877"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.323636709466797"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.419491156090565"}], ",", " ", "9.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.503931137185361"}], ",", " ", "8.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.577008679896672"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.638768555492675"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.689248418168937"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.728478920852112"}], ",", " ", 
         "3.6000000000000014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.756483808842034"}], ",", " ", "2.400000000000002"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.773279991963413"}], ",", " ", 
         "1.2000000000000028"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.778877595741463"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.77327999196342"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.756483808842027"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.728478920852112"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.689248418168944"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.638768555492682"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.577008679896664"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.503931137185361"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.419491156090572"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.32363670946679"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.216308351469877"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.097439029510426"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.966953869567071"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.824769933216217"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.6707959444852"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.504931984357789"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.327069150450917"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.137089179034746"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.934864026176271"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.720255404344137"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.493114270308503"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.253280259596025"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.00058106210114"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.734831732699277"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.455833929834121"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040639"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-12.163375074040639`, 
      30.}, {-12.163375074040644`, 30.}, {-12.455833929834128`, 
      28.8}, {-12.73483173269927, 27.6}, {-13.00058106210114, 
      26.4}, {-13.253280259596025`, 25.2}, {-13.49311427030851, 
      24.}, {-13.720255404344137`, 22.8}, {-13.934864026176271`, 
      21.6}, {-14.137089179034746`, 20.4}, {-14.327069150450917`, 
      19.200000000000003`}, {-14.504931984357796`, 18.}, {-14.6707959444852, 
      16.8}, {-14.824769933216217`, 
      15.600000000000001`}, {-14.966953869567071`, 14.4}, {-15.09743902951044,
       13.2}, {-15.216308351469877`, 12.}, {-15.323636709466797`, 
      10.8}, {-15.419491156090565`, 9.600000000000001}, {-15.503931137185361`,
       8.400000000000002}, {-15.577008679896672`, 
      7.199999999999999}, {-15.638768555492675`, 6.}, {-15.689248418168937`, 
      4.800000000000001}, {-15.728478920852112`, 
      3.6000000000000014`}, {-15.756483808842034`, 
      2.400000000000002}, {-15.773279991963413`, 
      1.2000000000000028`}, {-15.778877595741463`, 
       0}, {-15.77327999196342, -1.1999999999999993`}, {-15.756483808842027`, \
-2.3999999999999986`}, {-15.728478920852112`, -3.6000000000000014`}, \
{-15.689248418168944`, -4.799999999999997}, {-15.638768555492682`, -6.}, \
{-15.577008679896664`, -7.199999999999996}, {-15.503931137185361`, \
-8.399999999999999}, {-15.419491156090572`, -9.600000000000001}, \
{-15.32363670946679, -10.799999999999997`}, {-15.216308351469877`, -12.}, \
{-15.097439029510426`, -13.199999999999996`}, {-14.966953869567071`, \
-14.399999999999999`}, {-14.824769933216217`, -15.600000000000001`}, \
{-14.6707959444852, -16.799999999999997`}, {-14.504931984357789`, -18.}, \
{-14.327069150450917`, -19.199999999999996`}, {-14.137089179034746`, -20.4}, \
{-13.934864026176271`, -21.6}, {-13.720255404344137`, -22.799999999999997`}, \
{-13.493114270308503`, -24.}, {-13.253280259596025`, -25.199999999999996`}, \
{-13.00058106210114, -26.4}, {-12.734831732699277`, -27.599999999999994`}, \
{-12.455833929834121`, -28.799999999999997`}, {-12.163375074040637`, -30.}, \
{-12.163375074040639`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-12.163375074040639`, 
     30.}, {-12.163375074040644`, 30.}, {-12.455833929834128`, 
     28.8}, {-12.73483173269927, 27.6}, {-13.00058106210114, 
     26.4}, {-13.253280259596025`, 25.2}, {-13.49311427030851, 
     24.}, {-13.720255404344137`, 22.8}, {-13.934864026176271`, 
     21.6}, {-14.137089179034746`, 20.4}, {-14.327069150450917`, 
     19.200000000000003`}, {-14.504931984357796`, 18.}, {-14.6707959444852, 
     16.8}, {-14.824769933216217`, 
     15.600000000000001`}, {-14.966953869567071`, 14.4}, {-15.09743902951044, 
     13.2}, {-15.216308351469877`, 12.}, {-15.323636709466797`, 
     10.8}, {-15.419491156090565`, 9.600000000000001}, {-15.503931137185361`, 
     8.400000000000002}, {-15.577008679896672`, 
     7.199999999999999}, {-15.638768555492675`, 6.}, {-15.689248418168937`, 
     4.800000000000001}, {-15.728478920852112`, 
     3.6000000000000014`}, {-15.756483808842034`, 
     2.400000000000002}, {-15.773279991963413`, 
     1.2000000000000028`}, {-15.778877595741463`, 
      0}, {-15.77327999196342, -1.1999999999999993`}, {-15.756483808842027`, \
-2.3999999999999986`}, {-15.728478920852112`, -3.6000000000000014`}, \
{-15.689248418168944`, -4.799999999999997}, {-15.638768555492682`, -6.}, \
{-15.577008679896664`, -7.199999999999996}, {-15.503931137185361`, \
-8.399999999999999}, {-15.419491156090572`, -9.600000000000001}, \
{-15.32363670946679, -10.799999999999997`}, {-15.216308351469877`, -12.}, \
{-15.097439029510426`, -13.199999999999996`}, {-14.966953869567071`, \
-14.399999999999999`}, {-14.824769933216217`, -15.600000000000001`}, \
{-14.6707959444852, -16.799999999999997`}, {-14.504931984357789`, -18.}, \
{-14.327069150450917`, -19.199999999999996`}, {-14.137089179034746`, -20.4}, \
{-13.934864026176271`, -21.6}, {-13.720255404344137`, -22.799999999999997`}, \
{-13.493114270308503`, -24.}, {-13.253280259596025`, -25.199999999999996`}, \
{-13.00058106210114, -26.4}, {-12.734831732699277`, -27.599999999999994`}, \
{-12.455833929834121`, -28.799999999999997`}, {-12.163375074040637`, -30.}, \
{-12.163375074040639`, -30.}}]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwd0EFIkwEch+HJ5paXWNEkZGkNK5zCdCKWzmSSaARRtkzMpAQvsk0ZE4Mx
YVipwWzo0LXNtrUNSqq1qQxB8msyOwU6EWQoMrAWqxEK22qO6P/r8PLc33M9
/W29eSwWS05Z9nL29JmE/FPdXACKShnmv6pTG3ByVcJkyOEDX/5vUsmTtUPh
uvQ+FBtighvFCfl0U/iJghQFQ3NTZCh2nYHvuvv0ZtLwQeOB/luzYTghcG/C
k5wuxzS5fDPhh48UDz5C2fjhFszqMvvw1R82b4as2Czjw92xhjL4fjEyYCHX
nmWN8ErNxBco4lti0BTnqqykcDSshdzj2hfwknglDqMS3RE8X3mxwkYeuheq
YGEk2wDVXu81aM8l2+HPjmg3lJY7NfCzI22FEpXUB011tUtwx8xn28mXPsMQ
VDsdOmjU94zDt5f1v6BHM8yeJTkjnGOwpNNYAl13m+uhObrdAo9SwTuw+qpr
BDb+fZp8TV6o/1bwhgwMnnjoJxdalRpYPNr6GOaen3bCNVtLJEC2pYq+wns/
Uvx5/LgtOPh+NiH/B+p0AT4=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIEwAYBtDFlpeXWNFEYt6GFS5hNYl0TmVSzAiixlphKSX0EpvJUBTG
hLF0TtiUGmvqbDMd1KjWliFC5FRmT0FtBDIUGaibS5EN5mwb4v/1cDgVHc9l
T08wGAwJsW3k7AclccmiyO3DvEq///+qs7/xy2WBP033JzwnD2llvliBub+E
bZivi3Bul8Yl1ubAgJzmzS25X9FLkVt+/LH9mdZC6z6rZ7D37mQAmznTIXyG
9chhpb/diXtxn/zxdyw2Jv/gjCa9id/+Y+a/pqtDVWy8PtRQhT99DXbZ6JXh
jAk3XjX/xDy2LYJHo3mqcZprCHTjvFPdY7iWvxDFYYEmi89fvlg9QSenZ6/g
omCmAXe6XDexPbenwLsPwu1YeMmpxj8cB+NYoBJ68Kjo2jxes7CZdvqNR9eL
O50ODTZpO4z4Q512H8+o+5mTNEvPKsBlraYyPHX/Rj22hFelOJuau4drrk/p
cdPR4N47+kL9duF72tdz+omXnm1RqnGpoeUFzo0UO/HKhDToo2Wpc1v44d8U
+wsd2ylKxMrjkmP1pAK3
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "24.61528579890359`"}], ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "24.61528579890359`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 30.}, {-24.61528579890359, 
   30.}, {-24.61528579890359, -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxU1IEwAYBuDJ1qxLrGhSMTVHKVNhNgltm8lEUQnChpn0IyZ0CacxJkZj
wrCaBlsjx5xzc7NtYKNcm4sRiC1ldhJ0IsQoZJAtViIOttkc0fd2eHjK+gbl
9wsYDIaMWLbztkxxUvZJ7A1g/vlw+P+KUxv45YownKVH9n1HDuj+QmkX5q2L
7uJKbZx7rSQpMzdFnnbS/NCyd4Jejl8N47c9DzQmWvtO6cb+6/YINnBdm/gk
647DTC92JP34UWfvEpaOp7ZwTp39jl/9YRZO0tWbAg7+NtYgwPPvow8t9Orz
nB5fuWRYw3yOJY6NCbbCSvN0ERVmH1dN4frKjwkcE6oP8YWaiuppOuUKXsRF
0VwDHvB42rEtv9uFf3fHerCoyqnEnx0ZKxYqRD5sFNd9wF9NHKaNnvFph/GA
06HGek3fOH5zWbOH3coRpp1mjbKO4tJb+lI8e7NFgk2xL634MB26gWubZ0dx
499nu3N0ueTHsdd0YOjEPT8dbOtX4hJd2xOcf3HaiVenW6MBWp4+u4Nv/0pz
FujHgjP7P88lZf8A7QYBjA==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {ArrowBox[{{30., -30.}, {30., 30.}}], 
    ArrowBox[{{30., 30.}, {-24.61528579890359, 30.}}], 
    ArrowBox[{{-24.61528579890359, 30.}, {-24.61528579890359, -30.}}], 
    ArrowBox[{{-24.61528579890359, -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxU1oEgAYBmCHTrdLWGSMsbmSftAEN8doc3NhFBpBlCw32pI16DLmClkU
iIJYuQWuUWK2uXRNoaRyOkUGsczQToPNNRiyGEK1sEZsoFsqY9/b4eE51ndb
fauMwWAoiHO95MrXZhWfZP4QFhyPxf6vO7yEn36WxHZo01agfJce4LRpcM2i
9AYWmTO8y/yswnEu8bCDFkTj/md0PHMpht9p+4122jyj9+Lg1ckEHuVNL+ND
rB63g/5wJRvE9zt653HbyPYKLhh2vuNX/5ic57R4WcjF34blQvw+krrjpJOP
Czbc3jS6gAVcZwaPbbB143SNNTGE2QeGXuBm0ccNnJYYivhE/SnxBL09HW7A
R1IFOR70+S5iV2lTg/90pbVYetqjx1/c+XEs0UkDeEx2Zg6v2blMF/0yYL6H
Bz1uA7YZ+0bw2xbjX+zVm5iTNMvCqsB11211eKrzQiu2p1eVuJiLXsON56cs
+Ozeo83X9MnWn5Vv6NDdgzeDdFg1oMd8q+oBLj2p8uDkhDIVotW56h+4+3eO
O0t/jVRv/TqaVewD87ACcw==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.61528579890359"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.6152857989036"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.949524491239004"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.26837912308489"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.57209264240131"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.860891725252607"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.134987737495443"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.39457760496473"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.639844601344315"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.870959061754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.08807902908677"}], ",", " ", "19.200000000000003"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.29135083926605"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.480909650840232"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.65687992367568"}], ",", " ", "15.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.819375850933795"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.96850174801193"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.10435240167986"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.22701338224777"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.33656132124637"}], ",", " ", "9.600000000000001"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.43306415678328"}], ",", " ", "8.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.516581348453336"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.58716406342021"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.644855335050217"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.689690195259566"}], ",", " ", 
         "3.6000000000000014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.72169578153376"}], ",", " ", "2.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.74089141938677"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.747288680847383"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.740891419386763"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.72169578153376"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.68969019525956"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.644855335050224"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.58716406342021"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.516581348453336"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.433064156783274"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.336561321246364"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.22701338224777"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.10435240167986"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.968501748011924"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.819375850933795"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.65687992367568"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.480909650840232"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.29135083926605"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.08807902908677"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.870959061753993"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.639844601344322"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.394577604964724"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.134987737495436"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.8608917252526"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.57209264240131"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.26837912308489"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.949524491238996"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.615285798903592"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-24.61528579890359, 
      30.}, {-24.6152857989036, 30.}, {-24.949524491239004`, 
      28.8}, {-25.26837912308489, 27.6}, {-25.57209264240131, 
      26.4}, {-25.860891725252607`, 25.2}, {-26.134987737495443`, 
      24.}, {-26.39457760496473, 22.8}, {-26.639844601344315`, 
      21.6}, {-26.870959061754, 20.4}, {-27.08807902908677, 
      19.200000000000003`}, {-27.29135083926605, 18.}, {-27.480909650840232`, 
      16.8}, {-27.65687992367568, 15.600000000000001`}, {-27.819375850933795`,
       14.4}, {-27.96850174801193, 13.2}, {-28.10435240167986, 
      12.}, {-28.22701338224777, 10.8}, {-28.33656132124637, 
      9.600000000000001}, {-28.43306415678328, 
      8.400000000000002}, {-28.516581348453336`, 
      7.199999999999999}, {-28.58716406342021, 6.}, {-28.644855335050217`, 
      4.800000000000001}, {-28.689690195259566`, 
      3.6000000000000014`}, {-28.72169578153376, 
      2.400000000000002}, {-28.74089141938677, 
      1.2000000000000028`}, {-28.747288680847383`, 
       0}, {-28.740891419386763`, -1.1999999999999993`}, {-28.72169578153376, \
-2.3999999999999986`}, {-28.68969019525956, -3.6000000000000014`}, \
{-28.644855335050224`, -4.799999999999997}, {-28.58716406342021, -6.}, \
{-28.516581348453336`, -7.199999999999996}, {-28.433064156783274`, \
-8.399999999999999}, {-28.336561321246364`, -9.600000000000001}, \
{-28.22701338224777, -10.799999999999997`}, {-28.10435240167986, -12.}, \
{-27.968501748011924`, -13.199999999999996`}, {-27.819375850933795`, \
-14.399999999999999`}, {-27.65687992367568, -15.600000000000001`}, \
{-27.480909650840232`, -16.799999999999997`}, {-27.29135083926605, -18.}, \
{-27.08807902908677, -19.199999999999996`}, {-26.870959061753993`, -20.4}, \
{-26.639844601344322`, -21.6}, {-26.394577604964724`, -22.799999999999997`}, \
{-26.134987737495436`, -24.}, {-25.8608917252526, -25.199999999999996`}, \
{-25.57209264240131, -26.4}, {-25.26837912308489, -27.599999999999994`}, \
{-24.949524491238996`, -28.799999999999997`}, {-24.615285798903592`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -30.}, {30., 30.}, {-24.61528579890359, 
     30.}, {-24.6152857989036, 30.}, {-24.949524491239004`, 
     28.8}, {-25.26837912308489, 27.6}, {-25.57209264240131, 
     26.4}, {-25.860891725252607`, 25.2}, {-26.134987737495443`, 
     24.}, {-26.39457760496473, 22.8}, {-26.639844601344315`, 
     21.6}, {-26.870959061754, 20.4}, {-27.08807902908677, 
     19.200000000000003`}, {-27.29135083926605, 18.}, {-27.480909650840232`, 
     16.8}, {-27.65687992367568, 15.600000000000001`}, {-27.819375850933795`, 
     14.4}, {-27.96850174801193, 13.2}, {-28.10435240167986, 
     12.}, {-28.22701338224777, 10.8}, {-28.33656132124637, 
     9.600000000000001}, {-28.43306415678328, 
     8.400000000000002}, {-28.516581348453336`, 
     7.199999999999999}, {-28.58716406342021, 6.}, {-28.644855335050217`, 
     4.800000000000001}, {-28.689690195259566`, 
     3.6000000000000014`}, {-28.72169578153376, 
     2.400000000000002}, {-28.74089141938677, 
     1.2000000000000028`}, {-28.747288680847383`, 
      0}, {-28.740891419386763`, -1.1999999999999993`}, {-28.72169578153376, \
-2.3999999999999986`}, {-28.68969019525956, -3.6000000000000014`}, \
{-28.644855335050224`, -4.799999999999997}, {-28.58716406342021, -6.}, \
{-28.516581348453336`, -7.199999999999996}, {-28.433064156783274`, \
-8.399999999999999}, {-28.336561321246364`, -9.600000000000001}, \
{-28.22701338224777, -10.799999999999997`}, {-28.10435240167986, -12.}, \
{-27.968501748011924`, -13.199999999999996`}, {-27.819375850933795`, \
-14.399999999999999`}, {-27.65687992367568, -15.600000000000001`}, \
{-27.480909650840232`, -16.799999999999997`}, {-27.29135083926605, -18.}, \
{-27.08807902908677, -19.199999999999996`}, {-26.870959061753993`, -20.4}, \
{-26.639844601344322`, -21.6}, {-26.394577604964724`, -22.799999999999997`}, \
{-26.134987737495436`, -24.}, {-25.8608917252526, -25.199999999999996`}, \
{-25.57209264240131, -26.4}, {-25.26837912308489, -27.599999999999994`}, \
{-24.949524491238996`, -28.799999999999997`}, {-24.615285798903592`, -30.}}]],
  
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVFIEwEcB+DFluZLnOEiYs4aljgHq4VUTpOLZIsgVGyK5Sihl9hUDqVg
TBhWS2E2aszpZpupUFLNTUWCyMuYPQk2CWIYMVAnV0MU5mwb0f/Xw8d3sr2z
8e4BkUjEEs/PnG+vWGA/VU2FsaKU5/9vLvqKn31W82m6dyd4cJ825VcbsGxF
04aVtrj0ulxg3Zcjj5poxfzi1HN6MX6Nx2+N96wu2jbNTeBQw2gED0rHV/ER
yS2/m/5QL4Twg6bbH3F1/+43nLGk1/HLP+L8IVq1Ws7gH09qyvG7uWiXh14a
yDjwpcrBZaxgPHHsTOSZR2iZPdKN8w53D+MLyoUEjqktWXzqTJnKS++Oz57F
R6OZGtwxOXkV+3JJA/7dEjNiTUWAw1/8eyNYbdYEsbPq/Hu85mLEPvpF0HYf
dwT8FuywtvfjNxet23iC6xWP0pI+ySFc0uoowWPNdVrsin3X4Wxq/gY+d2Ws
D9f+fZx8RZ/Wbha8psM9hXdC9KzexGG5Xf8Q554eC+Alry4aphtTxzfwzV8p
ZobWDhfvbJ0Q2H/uNgHB
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], 
   LineBox[{{30., -30.}, {30., 30.}, {-24.61528579890359, 
     30.}, {-24.6152857989036, 30.}, {-24.949524491239004`, 
     28.8}, {-25.26837912308489, 27.6}, {-25.57209264240131, 
     26.4}, {-25.860891725252607`, 25.2}, {-26.134987737495443`, 
     24.}, {-26.39457760496473, 22.8}, {-26.639844601344315`, 
     21.6}, {-26.870959061754, 20.4}, {-27.08807902908677, 
     19.200000000000003`}, {-27.29135083926605, 18.}, {-27.480909650840232`, 
     16.8}, {-27.65687992367568, 15.600000000000001`}, {-27.819375850933795`, 
     14.4}, {-27.96850174801193, 13.2}, {-28.10435240167986, 
     12.}, {-28.22701338224777, 10.8}, {-28.33656132124637, 
     9.600000000000001}, {-28.43306415678328, 
     8.400000000000002}, {-28.516581348453336`, 
     7.199999999999999}, {-28.58716406342021, 6.}, {-28.644855335050217`, 
     4.800000000000001}, {-28.689690195259566`, 
     3.6000000000000014`}, {-28.72169578153376, 
     2.400000000000002}, {-28.74089141938677, 
     1.2000000000000028`}, {-28.747288680847383`, 
      0}, {-28.740891419386763`, -1.1999999999999993`}, {-28.72169578153376, \
-2.3999999999999986`}, {-28.68969019525956, -3.6000000000000014`}, \
{-28.644855335050224`, -4.799999999999997}, {-28.58716406342021, -6.}, \
{-28.516581348453336`, -7.199999999999996}, {-28.433064156783274`, \
-8.399999999999999}, {-28.336561321246364`, -9.600000000000001}, \
{-28.22701338224777, -10.799999999999997`}, {-28.10435240167986, -12.}, \
{-27.968501748011924`, -13.199999999999996`}, {-27.819375850933795`, \
-14.399999999999999`}, {-27.65687992367568, -15.600000000000001`}, \
{-27.480909650840232`, -16.799999999999997`}, {-27.29135083926605, -18.}, \
{-27.08807902908677, -19.199999999999996`}, {-26.870959061753993`, -20.4}, \
{-26.639844601344322`, -21.6}, {-26.394577604964724`, -22.799999999999997`}, \
{-26.134987737495436`, -24.}, {-25.8608917252526, -25.199999999999996`}, \
{-25.57209264240131, -26.4}, {-25.26837912308489, -27.599999999999994`}, \
{-24.949524491238996`, -28.799999999999997`}, {-24.615285798903592`, -30.}}]},
  
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdzF9IUwEYh+HFltqNHEVFQp2NUjRhNolMnXFC0QiiRE0yxQRvYltxUAzG
hGG6DGaiY65tus0plJRrUxFB8jjZuhJsIsQwZOA/VhIKczWH+P26eHnu3ivt
L+o6LggEApYybcetJ9lhdqVs2gMlV3n+v8q073B4VcpHyZ4j18W/pCKxohFm
rctaYKE2lP4gJ8wa7/r66knJgnd6hPSG7vPwc+tzjYHUfuEmofvRmA8Opjs3
YKroqc1ILj0Mu+Gr+ravsGLgeBPG1NEdOPFPmDhKFm0UMPDnG3kBnJkPvDSR
/rcxPay8ObgGJYwpBIf2E5RmMkvn64QJyZ3vYWnh8j4MStWn8FpxfpGFPHbO
3YAZgZgcqqam7kFr/LAR/m4KtkLZdTsHv9lOzFCqlLngUNmtRbhlYIRWctyl
7YYqu00N9Zr2AfjptuYPnOR6hGOkqFeUBMVP9GLoeFxdDg3BHzXwNLLQAEuq
HL3wzln/4Qcyr3zv0kfS05XyzE3O1So4mKOrfQ3j7zLt0G+pCXjIusjlXdj8
K8LM4jcvPjrIDbPn7sYB1w==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.61528579890359"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.6152857989036"}], ",", " ", "30."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.949524491239004"}], ",", " ", "28.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.26837912308489"}], ",", " ", "27.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.57209264240131"}], ",", " ", "26.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.860891725252607"}], ",", " ", "25.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.134987737495443"}], ",", " ", "24."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.39457760496473"}], ",", " ", "22.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.639844601344315"}], ",", " ", "21.6"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.870959061754"}], ",", " ", "20.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.08807902908677"}], ",", " ", "19.200000000000003"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.29135083926605"}], ",", " ", "18."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.480909650840232"}], ",", " ", "16.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.65687992367568"}], ",", " ", "15.600000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.819375850933795"}], ",", " ", "14.4"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.96850174801193"}], ",", " ", "13.2"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.10435240167986"}], ",", " ", "12."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.22701338224777"}], ",", " ", "10.8"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.33656132124637"}], ",", " ", "9.600000000000001"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.43306415678328"}], ",", " ", "8.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.516581348453336"}], ",", " ", "7.199999999999999"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.58716406342021"}], ",", " ", "6."}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.644855335050217"}], ",", " ", "4.800000000000001"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.689690195259566"}], ",", " ", 
         "3.6000000000000014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.72169578153376"}], ",", " ", "2.400000000000002"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.74089141938677"}], ",", " ", "1.2000000000000028"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.747288680847383"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.740891419386763"}], ",", " ", 
         RowBox[{"-", "1.1999999999999993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.72169578153376"}], ",", " ", 
         RowBox[{"-", "2.3999999999999986"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.68969019525956"}], ",", " ", 
         RowBox[{"-", "3.6000000000000014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.644855335050224"}], ",", " ", 
         RowBox[{"-", "4.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.58716406342021"}], ",", " ", 
         RowBox[{"-", "6."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.516581348453336"}], ",", " ", 
         RowBox[{"-", "7.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.433064156783274"}], ",", " ", 
         RowBox[{"-", "8.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.336561321246364"}], ",", " ", 
         RowBox[{"-", "9.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.22701338224777"}], ",", " ", 
         RowBox[{"-", "10.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "28.10435240167986"}], ",", " ", 
         RowBox[{"-", "12."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.968501748011924"}], ",", " ", 
         RowBox[{"-", "13.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.819375850933795"}], ",", " ", 
         RowBox[{"-", "14.399999999999999"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.65687992367568"}], ",", " ", 
         RowBox[{"-", "15.600000000000001"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.480909650840232"}], ",", " ", 
         RowBox[{"-", "16.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.29135083926605"}], ",", " ", 
         RowBox[{"-", "18."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "27.08807902908677"}], ",", " ", 
         RowBox[{"-", "19.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.870959061753993"}], ",", " ", 
         RowBox[{"-", "20.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.639844601344322"}], ",", " ", 
         RowBox[{"-", "21.6"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.394577604964724"}], ",", " ", 
         RowBox[{"-", "22.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "26.134987737495436"}], ",", " ", 
         RowBox[{"-", "24."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.8608917252526"}], ",", " ", 
         RowBox[{"-", "25.199999999999996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.57209264240131"}], ",", " ", 
         RowBox[{"-", "26.4"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.26837912308489"}], ",", " ", 
         RowBox[{"-", "27.599999999999994"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.949524491238996"}], ",", " ", 
         RowBox[{"-", "28.799999999999997"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "24.615285798903592"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -30.}, {30., 30.}, {-24.61528579890359, 
      30.}, {-24.6152857989036, 30.}, {-24.949524491239004`, 
      28.8}, {-25.26837912308489, 27.6}, {-25.57209264240131, 
      26.4}, {-25.860891725252607`, 25.2}, {-26.134987737495443`, 
      24.}, {-26.39457760496473, 22.8}, {-26.639844601344315`, 
      21.6}, {-26.870959061754, 20.4}, {-27.08807902908677, 
      19.200000000000003`}, {-27.29135083926605, 18.}, {-27.480909650840232`, 
      16.8}, {-27.65687992367568, 15.600000000000001`}, {-27.819375850933795`,
       14.4}, {-27.96850174801193, 13.2}, {-28.10435240167986, 
      12.}, {-28.22701338224777, 10.8}, {-28.33656132124637, 
      9.600000000000001}, {-28.43306415678328, 
      8.400000000000002}, {-28.516581348453336`, 
      7.199999999999999}, {-28.58716406342021, 6.}, {-28.644855335050217`, 
      4.800000000000001}, {-28.689690195259566`, 
      3.6000000000000014`}, {-28.72169578153376, 
      2.400000000000002}, {-28.74089141938677, 
      1.2000000000000028`}, {-28.747288680847383`, 
       0}, {-28.740891419386763`, -1.1999999999999993`}, {-28.72169578153376, \
-2.3999999999999986`}, {-28.68969019525956, -3.6000000000000014`}, \
{-28.644855335050224`, -4.799999999999997}, {-28.58716406342021, -6.}, \
{-28.516581348453336`, -7.199999999999996}, {-28.433064156783274`, \
-8.399999999999999}, {-28.336561321246364`, -9.600000000000001}, \
{-28.22701338224777, -10.799999999999997`}, {-28.10435240167986, -12.}, \
{-27.968501748011924`, -13.199999999999996`}, {-27.819375850933795`, \
-14.399999999999999`}, {-27.65687992367568, -15.600000000000001`}, \
{-27.480909650840232`, -16.799999999999997`}, {-27.29135083926605, -18.}, \
{-27.08807902908677, -19.199999999999996`}, {-26.870959061753993`, -20.4}, \
{-26.639844601344322`, -21.6}, {-26.394577604964724`, -22.799999999999997`}, \
{-26.134987737495436`, -24.}, {-25.8608917252526, -25.199999999999996`}, \
{-25.57209264240131, -26.4}, {-25.26837912308489, -27.599999999999994`}, \
{-24.949524491238996`, -28.799999999999997`}, {-24.615285798903592`, -30.}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -30.}, {30., 30.}, {-24.61528579890359, 
     30.}, {-24.6152857989036, 30.}, {-24.949524491239004`, 
     28.8}, {-25.26837912308489, 27.6}, {-25.57209264240131, 
     26.4}, {-25.860891725252607`, 25.2}, {-26.134987737495443`, 
     24.}, {-26.39457760496473, 22.8}, {-26.639844601344315`, 
     21.6}, {-26.870959061754, 20.4}, {-27.08807902908677, 
     19.200000000000003`}, {-27.29135083926605, 18.}, {-27.480909650840232`, 
     16.8}, {-27.65687992367568, 15.600000000000001`}, {-27.819375850933795`, 
     14.4}, {-27.96850174801193, 13.2}, {-28.10435240167986, 
     12.}, {-28.22701338224777, 10.8}, {-28.33656132124637, 
     9.600000000000001}, {-28.43306415678328, 
     8.400000000000002}, {-28.516581348453336`, 
     7.199999999999999}, {-28.58716406342021, 6.}, {-28.644855335050217`, 
     4.800000000000001}, {-28.689690195259566`, 
     3.6000000000000014`}, {-28.72169578153376, 
     2.400000000000002}, {-28.74089141938677, 
     1.2000000000000028`}, {-28.747288680847383`, 
      0}, {-28.740891419386763`, -1.1999999999999993`}, {-28.72169578153376, \
-2.3999999999999986`}, {-28.68969019525956, -3.6000000000000014`}, \
{-28.644855335050224`, -4.799999999999997}, {-28.58716406342021, -6.}, \
{-28.516581348453336`, -7.199999999999996}, {-28.433064156783274`, \
-8.399999999999999}, {-28.336561321246364`, -9.600000000000001}, \
{-28.22701338224777, -10.799999999999997`}, {-28.10435240167986, -12.}, \
{-27.968501748011924`, -13.199999999999996`}, {-27.819375850933795`, \
-14.399999999999999`}, {-27.65687992367568, -15.600000000000001`}, \
{-27.480909650840232`, -16.799999999999997`}, {-27.29135083926605, -18.}, \
{-27.08807902908677, -19.199999999999996`}, {-26.870959061753993`, -20.4}, \
{-26.639844601344322`, -21.6}, {-26.394577604964724`, -22.799999999999997`}, \
{-26.134987737495436`, -24.}, {-25.8608917252526, -25.199999999999996`}, \
{-25.57209264240131, -26.4}, {-25.26837912308489, -27.599999999999994`}, \
{-24.949524491238996`, -28.799999999999997`}, {-24.615285798903592`, -30.}}]],
  
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdyl1IUwEchvHFluZNHMVFiHNtlKIOlgtJ3SxOGDOCqGFLsiSFbsRpDEVh
TBjmV7A1aqylm5tfoKLNLWMIUSdjeiXoJIhhxKA0jokobNoc4v/t4uF388ga
W3VPTwkEApZy/Uy5ExKe/VIxHYTyixz3X0P2Gnz1VckdkF17/tOHZHO6Rg9z
V1WPYZElJr6Tx7POG+GeGlIeWpx+TS7GbnNwtr7J7CAtc8ZxGLjnCUObeGwd
ZokeeZ3kx7t8AHbWPPkENQP732DSdPALjv4Tpr8hFeuFDPzRX1kI332IPHOR
Sy+SVnit1LYC5YwrBu1baYZBMrcv3AbTzra9hWVFn7dgVGk6gpcuFyiGyP2x
+RJ4LpKshC0TE7egO7Wjh39ro/VQVewzwmVvYhAqDSo/tFdcXYAbDkboJof9
lg7Y4vOaoNXcOABnys27cNzYJfSQom7RGSh9aJXCkQc31dAR/a6FR/HQfXil
aqQbXj/u3Zkk89WbGVNksD2zIUDOVzcbYV5f9XOYenneB5eGtJEgqYvn/IZ1
23HmPX6JbO/PBZ49Ae6yAcI=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIGgAYBlCHTreXcKPGGJabrIVOcDlGN91wLCyCqHA1WpNN2MvQFmIU
iIG0rQvYpMRc2rRVsMk20zUiiHIO3dOgKYMhjSFsFS6JBLuoRP/Xw+Fc0jxt
eXyCwWAoiONP3rVbnFR8qfYGsOByMHi8rvAHHv0qCe7RfTu+k/u0liNrxbxV
6QMsMieKGkuSCvvt8HMVLVgIecfoUKIhiD+on5hstHlOP4P9zZNhPFI0HcNn
WR1uO73UlPTjXtXDZSwbSv/EWePeX/zmgMkZp8UxIRf/HpQL8cfP0S4HHRnO
WvDNGyPfsYDrSGDrBls3QfMGwgbMLjC8wpWilQ0clxhzuPRamdhJp6fny/G5
aFaOO2dn67Ern2rFW/fiaiy96tHjb+7dCSzRSX3YWl2xiNdsXKaLfu0z9+BO
j9uILSbNEH5fZdrGM/o+5iTN6medwvx2Cx9PtdXWYFv8lxLnMgt38fU7U/34
1uGL1Fv6Ss366Xd0oPvMIz89X6fV45KBumc4//K8B0ecymiAbslc+Ifv/89w
P9GDXsHO5sWk4gjxMwIk
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "30.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "20.553851381374166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12.163375074040639`"}], ",", "24.61528579890359`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.553851381374166`"}], ",", 
       RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -30.}, {30., 
   20.553851381374166`}, {-12.163375074040639`, 
   24.61528579890359}, {-10.553851381374166`, -30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxV1IUwEYBuDJptZNnCIjxLSGGv7AdBGVbsqJYkogNszCdNjAG9ksDkbB
mLBWLoWZ1LClm9uagxrp3JyIIDonW1dCbQgxihhUxqkRE6Y1R/S9XTw8p9S3
lX15AoGAJdbPOdvuCZ5db/AGsLg8FPq/9uh7/HRDEtqjh9K+/N+0plDWiUve
SXtwtSFZ1FbKsxMXI486aPFS2PuMDievhPCsql9voQ3z3Az2X7VH8FiRO46P
iLodE/RKO+/H9zt6V7FsZGcLZ3V7X/DLP8LC53RtvIrBnx7Lq/DcYuyOlY6O
Zs246ezYJhYz1iQe3y7QTtIlpsggLjg0+AKfr17bxgmJbh9X1J2unaJ33MF6
fCyWleMBj6cV23KpTvzzRkKFpTVODr917E5iiVbqw+MN55bxRwsjtNHTPsM9
POB06LBZrx7Bby7of+EZbkhop0VG0QFc1mUuw67rlxuxJfFBgfczS9fwmUsu
I27+O5x6RVc2fjv4mg7cPXzLTwdbNBwuNbU8xLknx504OqWIBWhlpvgrvvkj
wyzQDxTl6e8nefYf7loBvQ==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {
    ArrowBox[{{30., -30.}, {30., 20.553851381374166`}}], 
    ArrowBox[{{30., 20.553851381374166`}, {-12.163375074040639`, 
     24.61528579890359}}], 
    ArrowBox[{{-12.163375074040639`, 
     24.61528579890359}, {-10.553851381374166`, -30.}}], 
    ArrowBox[{{-10.553851381374166`, -30.}, {30., -30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIGgAYBlBD0/Yy3LoQo9WSVliBmzG2pRXGwkYwKrrRlrRgL6EVUmwg
BtK6giZNnKml3aCiMq2IIDYzrKdgU4KQxRBaDbcYBWYzif3fHg4ns6W9+k0c
g8GQENP3mPXibkiyVTjvwrwst/v/iqSveGRb4I7Q3WeO+EtazhHX4bQvwiac
qwkmv0gPSYyl3t4amrfumf9Ae4IVbrwoa1UbaM2ycho7q8a8WJc85ce3Wa9s
RnqzMuTE72qaP2Hx4Pk+jqoiR3jyL5Pzkc7387n4cKCIj5fWfB0memcoqsXF
j3R7mMc1BbH+hK0w02n93k7Mvtk5ip/kfj7BAYHqCt9/kJNvoc+nVh/iFF+0
CLfNzDzH1thpHf7dEJBhYZ5diXdtF2YsUAgdWF/4eAN/M3CZVnrcoXmL2+w2
FdaqWwbxwlP1Hzyt7GaO0aweVgLOaNRm4In6MhE2BA6k+Cq8XosLnk304JLr
vtNZOlt0fGOOdnXdeu2kV8vlSpzeX/4ex4ZT7XjHIvW56OrwnR/45a8wd4Vu
SMw++3kvJPkH66oBYQ==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "20.553851381374166"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "20.55385138137416"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"29.156732498519187", ",", " ", "20.828877291364762"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"28.313464997038373", ",", " ", "21.095267164993174"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"27.470197495557564", ",", " ", "21.353096551540403"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"26.62692999407675", ",", " ", "21.602437735523907"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.783662492595937", ",", " ", "21.84335984962604"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.940394991115124", ",", " ", "22.075928980853405"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.09712748963431", ",", " ", "22.300208270340917"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"23.253859988153497", ",", " ", "22.516258007181378"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"22.410592486672684", ",", " ", "22.72413571663145"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"21.567324985191874", ",", " ", "22.92389624301771"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"20.724057483711057", ",", " ", "23.11559182764097"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.880789982230247", ",", " ", "23.299272181954635"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.037522480749434", ",", " ", "23.474984556270243"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"18.19425497926862", ",", " ", "23.642773804225598"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"17.35098747778781", ",", " ", "23.802682443231078"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"16.507719976306994", ",", " ", "23.954750711094093"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"15.664452474826183", ",", " ", "24.099016619005695"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"14.821184973345371", ",", " ", "24.23551600105918"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.977917471864558", ",", " ", "24.36428256045687"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.134649970383744", ",", " ", "24.485347912549372"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"12.291382468902931", ",", " ", "24.598741624839533"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"11.448114967422118", ",", " ", "24.704491254072465"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"10.604847465941308", ",", " ", "24.802622380523417"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"9.761579964460495", ",", " ", "24.893158639584996"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.918312462979681", ",", " ", "24.976121750746714"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.075044961498868", ",", " ", "25.051531544051258"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"7.231777460018055", ",", " ", "25.119405984103864"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"6.388509958537242", ",", " ", "25.179761191703307"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"5.545242457056432", ",", " ", "25.232611463156147"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"4.7019749555756185", ",", " ", "25.277969287328645"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.858707454094805", ",", " ", "25.315845360484076"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.015439952613992", ",", " ", "25.34624859894687"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"2.1721724511331786", ",", " ", "25.369186149628746"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"1.3289049496523653", ",", " ", "25.384663398445724"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.48563744817155197", ",", " ", "25.39268397664955"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3576300533092578"}], ",", " ", "25.39324976509066"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.200897554790071"}], ",", " ", "25.38636089642428"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0441650562708844"}], ",", " ", 
         "25.372015755266077"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.887432557751694"}], ",", " ", "25.350210976297447"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.730700059232511"}], ",", " ", "25.320941440315437"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4.573967560713321"}], ",", " ", "25.28420026821624"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5.417235062194138"}], ",", " ", "25.239978812896283"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.260502563674947"}], ",", " ", "25.188266649047776"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.103770065155764"}], ",", " ", "25.129051560821296"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.947037566636574"}], ",", " ", "25.062319527320966"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8.790305068117384"}], ",", " ", "24.988054705891457"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9.6335725695982"}], ",", " ", "24.90623941315073"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.47684007107901"}], ",", " ", "24.816854103714235"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.320107572559827"}], ",", " ", 
         "24.719877346551044"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         "24.615285798903585"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", "24.61528579890359"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.448198511481507"}], ",", " ", 
         "23.522980082925518"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.719279804385721"}], ",", " ", 
         "22.430674366947446"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.976739151872422"}], ",", " ", "21.33836865096937"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.220689418349451"}], ",", " ", "20.2460629349913"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.451236398429188"}], ",", " ", "19.15375721901323"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.668479061013414"}], ",", " ", "18.06145150303516"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.87250977393542"}], ",", " ", "16.969145787057087"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.063414510410908"}], ",", " ", 
         "15.876840071079014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.241273038424296"}], ",", " ", 
         "14.784534355100943"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.406159094065373"}], ",", " ", "13.69222863912287"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.558140539727248"}], ",", " ", "12.5999229231448"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.69727950798439"}], ",", " ", "11.507617207166728"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.823632531882652"}], ",", " ", 
         "10.415311491188655"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.937250662294787"}], ",", " ", "9.323005775210584"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.038179572921905"}], ",", " ", "8.230700059232511"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.126459653453892"}], ",", " ", "7.13839434325444"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.202126091338542"}], ",", " ", "6.046088627276369"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.265208942550117"}], ",", " ", "4.953782911298298"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.315733191693084"}], ",", " ", "3.861477195320223"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.353718801722664"}], ",", " ", "2.769171479342152"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.379180753514845"}], ",", " ", 
         "1.6768657633640807"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392129075469327"}], ",", " ", 
         "0.5845600473860095"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392568863282136"}], ",", " ", 
         RowBox[{"-", "0.5077456685920616"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.380500289979267"}], ",", " ", 
         RowBox[{"-", "1.6000513845701327"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.355918606257092"}], ",", " ", 
         RowBox[{"-", "2.6923571005482074"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.318814131131532"}], ",", " ", 
         RowBox[{"-", "3.7846628165262786"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.269172232852767"}], ",", " ", 
         RowBox[{"-", "4.87696853250435"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.20697329999733"}], ",", " ", 
         RowBox[{"-", "5.969274248482421"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.132192702604783"}], ",", " ", 
         RowBox[{"-", "7.061579964460492"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.044800743177618"}], ",", " ", 
         RowBox[{"-", "8.153885680438567"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.944762597316725"}], ",", " ", 
         RowBox[{"-", "9.246191396416638"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.832038243712802"}], ",", " ", 
         RowBox[{"-", "10.338497112394709"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.70658238316311"}], ",", " ", 
         RowBox[{"-", "11.43080282837278"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.56834434622617"}], ",", " ", 
         RowBox[{"-", "12.523108544350851"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.417267989068776"}], ",", " ", 
         RowBox[{"-", "13.615414260328922"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.253291576997668"}], ",", " ", 
         RowBox[{"-", "14.707719976306993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.076347655099426"}], ",", " ", 
         RowBox[{"-", "15.800025692285065"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.886362905341088"}], ",", " ", 
         RowBox[{"-", "16.892331408263143"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.683257989404723"}], ",", " ", 
         RowBox[{"-", "17.984637124241214"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.466947376444296"}], ",", " ", 
         RowBox[{"-", "19.076942840219285"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.237339154859683"}], ",", " ", 
         RowBox[{"-", "20.169248556197356"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.994334827081488"}], ",", " ", 
         RowBox[{"-", "21.261554272175427"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.737829086247373"}], ",", " ", 
         RowBox[{"-", "22.3538599881535"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.467709573528452"}], ",", " ", 
         RowBox[{"-", "23.44616570413157"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.183856614726537"}], ",", " ", 
         RowBox[{"-", "24.53847142010964"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.886142934613403"}], ",", " ", 
         RowBox[{"-", "25.630777136087712"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.574433347313843"}], ",", " ", 
         RowBox[{"-", "26.723082852065783"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.248584420848601"}], ",", " ", 
         RowBox[{"-", "27.815388568043854"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.90844411374296"}], ",", " ", 
         RowBox[{"-", "28.907694284021932"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         RowBox[{"-", "30.000000000000004"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[CompressedData["
1:eJw1lQ801IkWx6fo5U/hoQyRv81fM2aMmfmNGeZuomyeFe2GhNCiEpvJ32rV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     "]],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[CompressedData["
1:eJw1lQ801IkWx6fo5U/hoQyRv81fM2aMmfmNGeZuomyeFe2GhNCiEpvJ32rV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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxUFIEwAYBtDFltNLrMiIWJuNargGy0lkcysWxowgTNQiU1LoEtuSMSkY
GwwtU5iNHLZ0a9NtkaKuLWUEodOYnQLbEGQoMcgW0xkK22yO8P88PN6Z9if1
jw4xGAwlsf8sOLKnU8p52XgQC86Gwwdrjv/Ar79KwjnatO0/vEur2fImzF2S
tmCROVF6m5dSDl6PPG+gBaGF8QF6IXErjCdbHxtttPmjzosDd5wR3F/qieFj
rAeuQfpLXSqAnzU8nMXy3p1lnDfkfuHRf0z2G1ocK+fgtZeKcjw1E+2w04t9
eQu+eqn/OxZw7AlsTRZphmhuT0SPi47o3+Iq0VwSxyWGPXzuolA8TO94pivw
iWhegbU+303sKKSb8Oa9eCuWXnDr8DdXdghLNFI/tsouf8arNg7TQb/zm59i
rdtlwBZjey+euGL8i706E9NJs7pYxZh/38LHI3dvVGNbfEWF9zKhRlxZM9KF
r/1/kf5An6/+XTJGBzuPtgXo6Vq1DvN6artx4dVJN14cVkWDdH3m1Dpu3shw
PtFb74Xbf8pSyn30ZQKL
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], LineBox[CompressedData["
1:eJw1lQ801IkWx6fo5U/hoQyRv81fM2aMmfmNGeZuomyeFe2GhNCiEpvJ32rV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    "]]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxU1IGgAYBmBDs3YZNmqM4cpJW5SByzG2mTaMQsdgbOJqVItN2CXSDTEK
REH6daDFJmZl01ZByTbTGRKMcg3tNGhGMGRjCFsNK4aCuUzGvneHh+e8+ony
cQGDwZAR5/e86/BcUvZB7A1gfmU4/H9N6Wf8/KMwnKVNKV/hH7q7SNKCuZui
B7jGnCi7XZ6UORojgyqaH1r3vqDXE7fC+E1nl9FOm5d0c9h/dzqCbWWzW/gU
q8PtoN/fSfpxn+rhKpZY0ts4Z8j+wK+OmEXjdO1WNQd/G5FW47fLsadOOvos
Z8UNV2yfMJ/jTOCxXbZmkuYOR/SYfVI/ga/VrO3iuNBwjC9cqqqdotOzwTp8
OpaTYu38/E3syh+04P378U4sEnh0eMN9OImFGpEPj4mvruCvdg7TRb/0mXux
1uM2YKtRbcGvrxt/4zmdiTlNs/pZxbiizVqBZ1qb67E9/kWOjzOhe/hy00w/
vvF36GCBvli/c2KRDvSUPPLTQUW3DpcPKwZwfvSMB0en5LEArcyc/Ynb9zKc
dzSvQ5D6xUvK/gHsBwF3
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "30."}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "20.553851381374166"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "20.55385138137416"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"29.156732498519187", ",", " ", "20.828877291364762"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"28.313464997038373", ",", " ", "21.095267164993174"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"27.470197495557564", ",", " ", "21.353096551540403"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"26.62692999407675", ",", " ", "21.602437735523907"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.783662492595937", ",", " ", "21.84335984962604"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.940394991115124", ",", " ", "22.075928980853405"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.09712748963431", ",", " ", "22.300208270340917"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"23.253859988153497", ",", " ", "22.516258007181378"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"22.410592486672684", ",", " ", "22.72413571663145"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"21.567324985191874", ",", " ", "22.92389624301771"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"20.724057483711057", ",", " ", "23.11559182764097"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.880789982230247", ",", " ", "23.299272181954635"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.037522480749434", ",", " ", "23.474984556270243"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"18.19425497926862", ",", " ", "23.642773804225598"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"17.35098747778781", ",", " ", "23.802682443231078"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"16.507719976306994", ",", " ", "23.954750711094093"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"15.664452474826183", ",", " ", "24.099016619005695"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"14.821184973345371", ",", " ", "24.23551600105918"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.977917471864558", ",", " ", "24.36428256045687"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.134649970383744", ",", " ", "24.485347912549372"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"12.291382468902931", ",", " ", "24.598741624839533"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"11.448114967422118", ",", " ", "24.704491254072465"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"10.604847465941308", ",", " ", "24.802622380523417"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"9.761579964460495", ",", " ", "24.893158639584996"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.918312462979681", ",", " ", "24.976121750746714"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.075044961498868", ",", " ", "25.051531544051258"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"7.231777460018055", ",", " ", "25.119405984103864"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"6.388509958537242", ",", " ", "25.179761191703307"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"5.545242457056432", ",", " ", "25.232611463156147"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"4.7019749555756185", ",", " ", "25.277969287328645"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.858707454094805", ",", " ", "25.315845360484076"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.015439952613992", ",", " ", "25.34624859894687"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"2.1721724511331786", ",", " ", "25.369186149628746"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"1.3289049496523653", ",", " ", "25.384663398445724"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.48563744817155197", ",", " ", "25.39268397664955"}], "}"}],
        ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3576300533092578"}], ",", " ", "25.39324976509066"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.200897554790071"}], ",", " ", "25.38636089642428"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0441650562708844"}], ",", " ", 
         "25.372015755266077"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.887432557751694"}], ",", " ", "25.350210976297447"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.730700059232511"}], ",", " ", "25.320941440315437"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4.573967560713321"}], ",", " ", "25.28420026821624"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5.417235062194138"}], ",", " ", "25.239978812896283"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.260502563674947"}], ",", " ", "25.188266649047776"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.103770065155764"}], ",", " ", "25.129051560821296"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.947037566636574"}], ",", " ", "25.062319527320966"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8.790305068117384"}], ",", " ", "24.988054705891457"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9.6335725695982"}], ",", " ", "24.90623941315073"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.47684007107901"}], ",", " ", "24.816854103714235"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.320107572559827"}], ",", " ", 
         "24.719877346551044"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         "24.615285798903585"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", "24.61528579890359"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.448198511481507"}], ",", " ", 
         "23.522980082925518"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.719279804385721"}], ",", " ", 
         "22.430674366947446"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.976739151872422"}], ",", " ", "21.33836865096937"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.220689418349451"}], ",", " ", "20.2460629349913"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.451236398429188"}], ",", " ", "19.15375721901323"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.668479061013414"}], ",", " ", "18.06145150303516"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.87250977393542"}], ",", " ", "16.969145787057087"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.063414510410908"}], ",", " ", 
         "15.876840071079014"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.241273038424296"}], ",", " ", 
         "14.784534355100943"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.406159094065373"}], ",", " ", "13.69222863912287"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.558140539727248"}], ",", " ", "12.5999229231448"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.69727950798439"}], ",", " ", "11.507617207166728"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.823632531882652"}], ",", " ", 
         "10.415311491188655"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.937250662294787"}], ",", " ", "9.323005775210584"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.038179572921905"}], ",", " ", "8.230700059232511"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.126459653453892"}], ",", " ", "7.13839434325444"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.202126091338542"}], ",", " ", "6.046088627276369"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.265208942550117"}], ",", " ", "4.953782911298298"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.315733191693084"}], ",", " ", "3.861477195320223"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.353718801722664"}], ",", " ", "2.769171479342152"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.379180753514845"}], ",", " ", 
         "1.6768657633640807"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392129075469327"}], ",", " ", 
         "0.5845600473860095"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392568863282136"}], ",", " ", 
         RowBox[{"-", "0.5077456685920616"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.380500289979267"}], ",", " ", 
         RowBox[{"-", "1.6000513845701327"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.355918606257092"}], ",", " ", 
         RowBox[{"-", "2.6923571005482074"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.318814131131532"}], ",", " ", 
         RowBox[{"-", "3.7846628165262786"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.269172232852767"}], ",", " ", 
         RowBox[{"-", "4.87696853250435"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.20697329999733"}], ",", " ", 
         RowBox[{"-", "5.969274248482421"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.132192702604783"}], ",", " ", 
         RowBox[{"-", "7.061579964460492"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.044800743177618"}], ",", " ", 
         RowBox[{"-", "8.153885680438567"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.944762597316725"}], ",", " ", 
         RowBox[{"-", "9.246191396416638"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.832038243712802"}], ",", " ", 
         RowBox[{"-", "10.338497112394709"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.70658238316311"}], ",", " ", 
         RowBox[{"-", "11.43080282837278"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.56834434622617"}], ",", " ", 
         RowBox[{"-", "12.523108544350851"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.417267989068776"}], ",", " ", 
         RowBox[{"-", "13.615414260328922"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.253291576997668"}], ",", " ", 
         RowBox[{"-", "14.707719976306993"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.076347655099426"}], ",", " ", 
         RowBox[{"-", "15.800025692285065"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.886362905341088"}], ",", " ", 
         RowBox[{"-", "16.892331408263143"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.683257989404723"}], ",", " ", 
         RowBox[{"-", "17.984637124241214"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.466947376444296"}], ",", " ", 
         RowBox[{"-", "19.076942840219285"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.237339154859683"}], ",", " ", 
         RowBox[{"-", "20.169248556197356"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.994334827081488"}], ",", " ", 
         RowBox[{"-", "21.261554272175427"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.737829086247373"}], ",", " ", 
         RowBox[{"-", "22.3538599881535"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.467709573528452"}], ",", " ", 
         RowBox[{"-", "23.44616570413157"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.183856614726537"}], ",", " ", 
         RowBox[{"-", "24.53847142010964"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.886142934613403"}], ",", " ", 
         RowBox[{"-", "25.630777136087712"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.574433347313843"}], ",", " ", 
         RowBox[{"-", "26.723082852065783"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.248584420848601"}], ",", " ", 
         RowBox[{"-", "27.815388568043854"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.90844411374296"}], ",", " ", 
         RowBox[{"-", "28.907694284021932"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         RowBox[{"-", "30.000000000000004"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", 
         RowBox[{"-", "30."}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[CompressedData["
1:eJw1lQ801IkWx6fo5U/hoQyRv81fM2aMmfmNGeZuomyeFe2GhNCiEpvJ32rV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     "]],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[CompressedData["
1:eJw1lQ801IkWx6fo5U/hoQyRv81fM2aMmfmNGeZuomyeFe2GhNCiEpvJ32rV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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxUFIEwAYBtDFprNLzMiQWJrDitlgORHNuWShaARRMjWsRg28xKYxlIKx
wbBaE2ZDh85ttpkKNdS5qYwgak62TkFuCDISGVSL5TCFbTWH+H8dHq9C0dfe
c4zBYEiJdTvvyJxNSlcb3D7MqwwE/q86tY5H1oSBLK3b8xT8pZXsxk7M/Sq6
j6v08ZKbZUnp2LXQcxnN8wfdo3QwfiOA5+WPtBZav6iewd7bkyE8XDIdxSdZ
95xj9IdbSS9+KnvwETca9zdwTpP9jt/8Y7LHaUGUz8FbLyV8vLASeWylw0M5
E75aO/wF8zjWODYnClU2mmsI9ePCE/0TuL7qUwLHhJoDfP7yRYGd3p9ersan
IzkJ7p2dvY4d+VQn3rkTk2PRJZcaf3ZmbFioEnmwuaHuPf5m4TAd9GuP/gnu
dTk12KRVGPHcFe0unlHrmJM0a5BVhMu7TeV4qqtFjC2xzVZ8kPZ34JrmqUHc
dPgi9Za+IP55/B3tGyh+6KWX25RqXGZoe4bzr0pdOGxvjfjo9vSZH/ju7zRn
iR76I9j7dS4pPQLzaQJ2
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {6, 1}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIGgAYBlBD0/YyXFTEKG2yNjLJcow1qw1HUTEYK7rRmpTQy1A3pCgQ
A+m2BpqUlDNLmwUVW6YZEYzNFdpTUMZgyMYQtgq3GAVaUxn7vx4O55rieX1n
CoPBkBHL96QtlhuRfZIuebDgus93sSpjD49tiX1ndN+JK/WcVnLKm3DOruQp
FurDmY94EdnEA/9gAy1Y31wapzfDD334nfyZzkzrVzRz2F037cfGTOc+Tme1
2Sfo948jbtzb0P4Bl4+cfsZx7dkP/OYvkzNJi/YLuPjby4oCvLwWfGGhA6/i
BnzvtnEHC7iWMDYdslVWOmfY34XZl7te41Lhx0McEmsTOL/4pmiKPnV6S3BW
MF6B1fPztdiWPG7Cv1tCciwpdGjwtj1mxWKVxIVN0jsb+KuZy7TRMy59D1Y7
7Fps0ClG8Nu7uj94TtPHnKZZ/aw0zG818PFsc1UZNoe+VONEdL0R36qc7cf3
/w0dL9A3yg4uLdKe7isdbtpbo9Rg3nDNAE6OZjtwYKo66KHro1d/4ie/otxV
+sBZdHKUF5H9B/Q6Aoc=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "20.553851381374166`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12.163375074040639`"}], ",", 
       RowBox[{"-", "24.61528579890359`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.553851381374166`"}], ",", "30.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 30.}, {
   30., -20.553851381374166`}, {-12.163375074040639`, -24.61528579890359}, \
{-10.553851381374166`, 30.}}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtIGgAYBlBDq+0lLNYYo6vURk6wOUb3xCgygtHELNoWS9jLyDakKBAD
aa0ZaFJSZpaaClusTGtIMDbXsJ4GmzIYsjGErYYVUaCWSfR/ezicYvkzyZM0
BoMhIqbfKUs8Pyr6VL3kxZwSv///iivf8ORnvj9BDx+500/o3sxaGc77KniE
uZpI7r2CqGi6ITAqpTm+zaUpejPS6sfL3U/VRlqzqnRiz/35ANbnOkI4h/XQ
Ok2/b4t68JD08Qdcqz3+jpOqxB+8eMrMnKF5oTI2/vWqrgyvvAs+N9Fb40kd
rr+r/4I5bFMEG3YzFGY6byzQjzOy+mdxJffjLg7zVWe4tPwmb44+dqzfxleD
yTrc53K1YEvqQIb3O8PdWHDLpsTb1rgZ8xUCNzZUV2zgn0Y200IvuDWDuM9m
VWGdWq7Fb6vUh9ipHGbO06wR1iVc2KUrxPaOphpsDP9oxmcxXzu+02gfwcLz
lwev6Rs1O5ff0N6B7B4PvS7uVeKCMfELnJq4ZsNbc81BLy2JXf+LH+zF2Gt0
u7D86F9RVHQB7QIBlA==
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], {
    ArrowBox[{{30., 30.}, {30., -20.553851381374166`}}], 
    ArrowBox[{{
     30., -20.553851381374166`}, {-12.163375074040639`, -24.61528579890359}}],
     ArrowBox[{{-12.163375074040639`, -24.61528579890359}, \
{-10.553851381374166`, 30.}}], 
    ArrowBox[{{-10.553851381374166`, 30.}, {30., 30.}}]}},
  Frame->True]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdzk9IEwAYh+HFlqtLzHAhsbSGJdPB3EIy/xQTRUMQlTXDbNTAS2wzhlIw
NhhWpjAdOnRus21NQUc1txQRItdi6xTUhiAjiYG2WIk4mNM5ou/X4eW5vpeU
/V19JxgMhpSy/sg7Di6kpB9rvQHILwsG/6su+gYnPomCWdKw7zt5SKrY9XLI
+yq5ByuMCW57SUo61Rh+JiP5qyHvJBlKtAXhG8VDvYU0LmnnoL9zNgzHuJ4Y
PMvqdU6R7ztSfvhEdv8DrB9Jb8CcLrsNXx0x2dOkMCbgwK0XDQL4diX6yEpG
RnMmeKN67Avkc6wJaE4WqG0kbzg8AAvODMzAmor1JIyLdMfwclW50E6mPcti
eC6aa4Ca+flb0JHflcM/d+IKKKl0aeFn54ENitQSHzTXXluD3y0cpoN86TM+
hhqXUwdNeuUIfH1dvwfntAbmLMkaYp2CpT2mUujubq6DlvhmCzzOrN6GV5vc
Q/Dm3+e7C+SVup+nF8nAYOEDP7ncqtLCkuHWpzA/XuyCEXtLNEB2Zc7vwLu/
M5x3+MuK939dTEn/AfRYApY=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "20.553851381374166"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "20.55385138137416"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"29.156732498519187", ",", " ", 
         RowBox[{"-", "20.828877291364762"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"28.313464997038373", ",", " ", 
         RowBox[{"-", "21.095267164993174"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"27.470197495557564", ",", " ", 
         RowBox[{"-", "21.353096551540403"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"26.62692999407675", ",", " ", 
         RowBox[{"-", "21.602437735523907"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.783662492595937", ",", " ", 
         RowBox[{"-", "21.84335984962604"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.940394991115124", ",", " ", 
         RowBox[{"-", "22.075928980853405"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.09712748963431", ",", " ", 
         RowBox[{"-", "22.300208270340917"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"23.253859988153497", ",", " ", 
         RowBox[{"-", "22.516258007181378"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"22.410592486672684", ",", " ", 
         RowBox[{"-", "22.72413571663145"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"21.567324985191874", ",", " ", 
         RowBox[{"-", "22.92389624301771"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"20.724057483711057", ",", " ", 
         RowBox[{"-", "23.11559182764097"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.880789982230247", ",", " ", 
         RowBox[{"-", "23.299272181954635"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.037522480749434", ",", " ", 
         RowBox[{"-", "23.474984556270243"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"18.19425497926862", ",", " ", 
         RowBox[{"-", "23.642773804225598"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"17.35098747778781", ",", " ", 
         RowBox[{"-", "23.802682443231078"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"16.507719976306994", ",", " ", 
         RowBox[{"-", "23.954750711094093"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"15.664452474826183", ",", " ", 
         RowBox[{"-", "24.099016619005695"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"14.821184973345371", ",", " ", 
         RowBox[{"-", "24.23551600105918"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.977917471864558", ",", " ", 
         RowBox[{"-", "24.36428256045687"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.134649970383744", ",", " ", 
         RowBox[{"-", "24.485347912549372"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"12.291382468902931", ",", " ", 
         RowBox[{"-", "24.598741624839533"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"11.448114967422118", ",", " ", 
         RowBox[{"-", "24.704491254072465"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"10.604847465941308", ",", " ", 
         RowBox[{"-", "24.802622380523417"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"9.761579964460495", ",", " ", 
         RowBox[{"-", "24.893158639584996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.918312462979681", ",", " ", 
         RowBox[{"-", "24.976121750746714"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.075044961498868", ",", " ", 
         RowBox[{"-", "25.051531544051258"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"7.231777460018055", ",", " ", 
         RowBox[{"-", "25.119405984103864"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"6.388509958537242", ",", " ", 
         RowBox[{"-", "25.179761191703307"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"5.545242457056432", ",", " ", 
         RowBox[{"-", "25.232611463156147"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"4.7019749555756185", ",", " ", 
         RowBox[{"-", "25.277969287328645"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.858707454094805", ",", " ", 
         RowBox[{"-", "25.315845360484076"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.015439952613992", ",", " ", 
         RowBox[{"-", "25.34624859894687"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"2.1721724511331786", ",", " ", 
         RowBox[{"-", "25.369186149628746"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1.3289049496523653", ",", " ", 
         RowBox[{"-", "25.384663398445724"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.48563744817155197", ",", " ", 
         RowBox[{"-", "25.39268397664955"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3576300533092578"}], ",", " ", 
         RowBox[{"-", "25.39324976509066"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.200897554790071"}], ",", " ", 
         RowBox[{"-", "25.38636089642428"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0441650562708844"}], ",", " ", 
         RowBox[{"-", "25.372015755266077"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.887432557751694"}], ",", " ", 
         RowBox[{"-", "25.350210976297447"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.730700059232511"}], ",", " ", 
         RowBox[{"-", "25.320941440315437"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4.573967560713321"}], ",", " ", 
         RowBox[{"-", "25.28420026821624"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5.417235062194138"}], ",", " ", 
         RowBox[{"-", "25.239978812896283"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.260502563674947"}], ",", " ", 
         RowBox[{"-", "25.188266649047776"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.103770065155764"}], ",", " ", 
         RowBox[{"-", "25.129051560821296"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.947037566636574"}], ",", " ", 
         RowBox[{"-", "25.062319527320966"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8.790305068117384"}], ",", " ", 
         RowBox[{"-", "24.988054705891457"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9.6335725695982"}], ",", " ", 
         RowBox[{"-", "24.90623941315073"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.47684007107901"}], ",", " ", 
         RowBox[{"-", "24.816854103714235"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.320107572559827"}], ",", " ", 
         RowBox[{"-", "24.719877346551044"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         RowBox[{"-", "24.615285798903585"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", 
         RowBox[{"-", "24.61528579890359"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.448198511481507"}], ",", " ", 
         RowBox[{"-", "23.522980082925518"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.719279804385721"}], ",", " ", 
         RowBox[{"-", "22.430674366947446"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.976739151872422"}], ",", " ", 
         RowBox[{"-", "21.33836865096937"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.220689418349451"}], ",", " ", 
         RowBox[{"-", "20.2460629349913"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.451236398429188"}], ",", " ", 
         RowBox[{"-", "19.15375721901323"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.668479061013414"}], ",", " ", 
         RowBox[{"-", "18.06145150303516"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.87250977393542"}], ",", " ", 
         RowBox[{"-", "16.969145787057087"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.063414510410908"}], ",", " ", 
         RowBox[{"-", "15.876840071079014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.241273038424296"}], ",", " ", 
         RowBox[{"-", "14.784534355100943"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.406159094065373"}], ",", " ", 
         RowBox[{"-", "13.69222863912287"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.558140539727248"}], ",", " ", 
         RowBox[{"-", "12.5999229231448"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.69727950798439"}], ",", " ", 
         RowBox[{"-", "11.507617207166728"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.823632531882652"}], ",", " ", 
         RowBox[{"-", "10.415311491188655"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.937250662294787"}], ",", " ", 
         RowBox[{"-", "9.323005775210584"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.038179572921905"}], ",", " ", 
         RowBox[{"-", "8.230700059232511"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.126459653453892"}], ",", " ", 
         RowBox[{"-", "7.13839434325444"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.202126091338542"}], ",", " ", 
         RowBox[{"-", "6.046088627276369"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.265208942550117"}], ",", " ", 
         RowBox[{"-", "4.953782911298298"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.315733191693084"}], ",", " ", 
         RowBox[{"-", "3.861477195320223"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.353718801722664"}], ",", " ", 
         RowBox[{"-", "2.769171479342152"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.379180753514845"}], ",", " ", 
         RowBox[{"-", "1.6768657633640807"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392129075469327"}], ",", " ", 
         RowBox[{"-", "0.5845600473860095"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392568863282136"}], ",", " ", 
         "0.5077456685920616"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.380500289979267"}], ",", " ", 
         "1.6000513845701327"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.355918606257092"}], ",", " ", 
         "2.6923571005482074"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.318814131131532"}], ",", " ", 
         "3.7846628165262786"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.269172232852767"}], ",", " ", "4.87696853250435"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.20697329999733"}], ",", " ", "5.969274248482421"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.132192702604783"}], ",", " ", "7.061579964460492"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.044800743177618"}], ",", " ", "8.153885680438567"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.944762597316725"}], ",", " ", "9.246191396416638"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.832038243712802"}], ",", " ", 
         "10.338497112394709"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.70658238316311"}], ",", " ", "11.43080282837278"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.56834434622617"}], ",", " ", "12.523108544350851"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.417267989068776"}], ",", " ", 
         "13.615414260328922"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.253291576997668"}], ",", " ", 
         "14.707719976306993"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.076347655099426"}], ",", " ", 
         "15.800025692285065"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.886362905341088"}], ",", " ", 
         "16.892331408263143"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.683257989404723"}], ",", " ", 
         "17.984637124241214"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.466947376444296"}], ",", " ", 
         "19.076942840219285"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.237339154859683"}], ",", " ", 
         "20.169248556197356"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.994334827081488"}], ",", " ", 
         "21.261554272175427"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.737829086247373"}], ",", " ", "22.3538599881535"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.467709573528452"}], ",", " ", "23.44616570413157"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.183856614726537"}], ",", " ", "24.53847142010964"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.886142934613403"}], ",", " ", 
         "25.630777136087712"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.574433347313843"}], ",", " ", 
         "26.723082852065783"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.248584420848601"}], ",", " ", 
         "27.815388568043854"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.90844411374296"}], ",", " ", "28.907694284021932"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         "30.000000000000004"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", "30."}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[CompressedData["
1:eJxdlX801Pkax6fo5kdhUYbI+NH8njFjfn2/ZpjPJsrmWtFuRkJoUYnN5Ge1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     "]],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[CompressedData["
1:eJxdlX801Pkax6fo5kdhUYbI+NH8njFjfn2/ZpjPJsrmWtFuRkJoUYnN5Ge1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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxXsoIwAcB/Bd2xn/aCck7eys4zJqDB3m0S7iUjryyiuUf7Sh5Tq1ptbu
DldzOosdc5tXsTAbkhJD4y/FpLRIK6+GLmrczZLf1x+fPpH1zUUNLxgMhoTo
jn36u9duyVqayYr5b22252XBu/jXhtB2T7ffmF/+o6Xs9FLM3RFVY4HKFVIQ
4Zb0fbB/K6b5i+umXnrdlW/D0zWNSi2tmpWPYUvhkB13h4zu4SBWlaGPXv7k
tuC24toVnN51u4+9ivsTPPKfye6n4/ZiOPioMyMGzyw4WnT05g+vBmcmd29j
Pkfnwj3nfrIBmtthb8V+ga2/cYpg9Rw7hYoHHBX/Lm6Qvh2dT8ChDm8Gbhof
/4j1vutSfFXurMGiWKMcbxnuBrBQJjLjnrT3S/hQy2Hq6T9m1RfcZDQosEZZ
34WnUpV/8Zi8nTlEs9Qsf8yr0PDwcFmOGGudB7n4wbNYghOzh9U46/H79QQd
LT4LmKStn1/VWej5PKkcR3TkfcW+n2FGvDmY67DSRZ7wU1x56eHM0buspJuL
N27JE+9dAdk=
  "]],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -50.}, {-50., 50.}, {50., 50.}, {
    50., -50.}, {-50., -50.}}], LineBox[CompressedData["
1:eJxdlX801Pkax6fo5kdhUYbI+NH8njFjfn2/ZpjPJsrmWtFuRkJoUYnN5Ge1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    "]]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->CompressedData["
1:eJwd0EFIkwEch+HFlstLrHARYq5GJS5hOZHKzWKSzAiiZK3IGjnoIk5lLArG
hLF0TtgUHXPp1rY2oaSaW4YIsb6M2UmwDUGGIgNNmYlM2FZzRP9fh5fn/p7R
dLc+OcRiseSUa73ozp1Ky782TEWg8CzD/Fdb9gOOfBMzebI3Ezr8m+zkylSw
YknyCIpMKf6tyrTc2RTrU5LC2fmpUXI+dZOB79UdRgdpmtYFYfiOJwbt/EAC
Huc89DrJz7fTYfhc+TgKZdb9ZVgw5Dfg6z9s7hhZk6jmwbWBxmr44VO8x0Uu
DBZs8Gq9fREKea4UHN4q0Y6TFZaYHpYc1b+El0VftmBSbDiA5y5W1UyQ+4GZ
WngiXmiEXZOTN6C7uKuCv+4n1VBywaeD3725cSjWSkJwuOHSHFx18Nhu8lXI
9Ax2+bwGaDNqrPDdFeMeDOp62R6SY+YcgYIHNgH032uWQkdyRQEPsrN3Yd11
vxle+9u/+4Y8L/1Z+paMPD3WHiZnWjp1sNLS8gIWh0764MKEIh4hW7Plm7Bt
J8v7iO/R+sz26bT8H/PRAn8=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "30."}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "20.553851381374166"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "20.55385138137416"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"29.156732498519187", ",", " ", 
         RowBox[{"-", "20.828877291364762"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"28.313464997038373", ",", " ", 
         RowBox[{"-", "21.095267164993174"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"27.470197495557564", ",", " ", 
         RowBox[{"-", "21.353096551540403"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"26.62692999407675", ",", " ", 
         RowBox[{"-", "21.602437735523907"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.783662492595937", ",", " ", 
         RowBox[{"-", "21.84335984962604"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.940394991115124", ",", " ", 
         RowBox[{"-", "22.075928980853405"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"24.09712748963431", ",", " ", 
         RowBox[{"-", "22.300208270340917"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"23.253859988153497", ",", " ", 
         RowBox[{"-", "22.516258007181378"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"22.410592486672684", ",", " ", 
         RowBox[{"-", "22.72413571663145"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"21.567324985191874", ",", " ", 
         RowBox[{"-", "22.92389624301771"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"20.724057483711057", ",", " ", 
         RowBox[{"-", "23.11559182764097"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.880789982230247", ",", " ", 
         RowBox[{"-", "23.299272181954635"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"19.037522480749434", ",", " ", 
         RowBox[{"-", "23.474984556270243"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"18.19425497926862", ",", " ", 
         RowBox[{"-", "23.642773804225598"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"17.35098747778781", ",", " ", 
         RowBox[{"-", "23.802682443231078"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"16.507719976306994", ",", " ", 
         RowBox[{"-", "23.954750711094093"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"15.664452474826183", ",", " ", 
         RowBox[{"-", "24.099016619005695"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"14.821184973345371", ",", " ", 
         RowBox[{"-", "24.23551600105918"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.977917471864558", ",", " ", 
         RowBox[{"-", "24.36428256045687"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"13.134649970383744", ",", " ", 
         RowBox[{"-", "24.485347912549372"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"12.291382468902931", ",", " ", 
         RowBox[{"-", "24.598741624839533"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"11.448114967422118", ",", " ", 
         RowBox[{"-", "24.704491254072465"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"10.604847465941308", ",", " ", 
         RowBox[{"-", "24.802622380523417"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"9.761579964460495", ",", " ", 
         RowBox[{"-", "24.893158639584996"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.918312462979681", ",", " ", 
         RowBox[{"-", "24.976121750746714"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"8.075044961498868", ",", " ", 
         RowBox[{"-", "25.051531544051258"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"7.231777460018055", ",", " ", 
         RowBox[{"-", "25.119405984103864"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"6.388509958537242", ",", " ", 
         RowBox[{"-", "25.179761191703307"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"5.545242457056432", ",", " ", 
         RowBox[{"-", "25.232611463156147"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"4.7019749555756185", ",", " ", 
         RowBox[{"-", "25.277969287328645"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.858707454094805", ",", " ", 
         RowBox[{"-", "25.315845360484076"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3.015439952613992", ",", " ", 
         RowBox[{"-", "25.34624859894687"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"2.1721724511331786", ",", " ", 
         RowBox[{"-", "25.369186149628746"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1.3289049496523653", ",", " ", 
         RowBox[{"-", "25.384663398445724"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.48563744817155197", ",", " ", 
         RowBox[{"-", "25.39268397664955"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3576300533092578"}], ",", " ", 
         RowBox[{"-", "25.39324976509066"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.200897554790071"}], ",", " ", 
         RowBox[{"-", "25.38636089642428"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0441650562708844"}], ",", " ", 
         RowBox[{"-", "25.372015755266077"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.887432557751694"}], ",", " ", 
         RowBox[{"-", "25.350210976297447"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.730700059232511"}], ",", " ", 
         RowBox[{"-", "25.320941440315437"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4.573967560713321"}], ",", " ", 
         RowBox[{"-", "25.28420026821624"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5.417235062194138"}], ",", " ", 
         RowBox[{"-", "25.239978812896283"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.260502563674947"}], ",", " ", 
         RowBox[{"-", "25.188266649047776"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.103770065155764"}], ",", " ", 
         RowBox[{"-", "25.129051560821296"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.947037566636574"}], ",", " ", 
         RowBox[{"-", "25.062319527320966"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8.790305068117384"}], ",", " ", 
         RowBox[{"-", "24.988054705891457"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9.6335725695982"}], ",", " ", 
         RowBox[{"-", "24.90623941315073"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.47684007107901"}], ",", " ", 
         RowBox[{"-", "24.816854103714235"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.320107572559827"}], ",", " ", 
         RowBox[{"-", "24.719877346551044"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040637"}], ",", " ", 
         RowBox[{"-", "24.615285798903585"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.163375074040644"}], ",", " ", 
         RowBox[{"-", "24.61528579890359"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.448198511481507"}], ",", " ", 
         RowBox[{"-", "23.522980082925518"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.719279804385721"}], ",", " ", 
         RowBox[{"-", "22.430674366947446"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.976739151872422"}], ",", " ", 
         RowBox[{"-", "21.33836865096937"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.220689418349451"}], ",", " ", 
         RowBox[{"-", "20.2460629349913"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.451236398429188"}], ",", " ", 
         RowBox[{"-", "19.15375721901323"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.668479061013414"}], ",", " ", 
         RowBox[{"-", "18.06145150303516"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.87250977393542"}], ",", " ", 
         RowBox[{"-", "16.969145787057087"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.063414510410908"}], ",", " ", 
         RowBox[{"-", "15.876840071079014"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.241273038424296"}], ",", " ", 
         RowBox[{"-", "14.784534355100943"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.406159094065373"}], ",", " ", 
         RowBox[{"-", "13.69222863912287"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.558140539727248"}], ",", " ", 
         RowBox[{"-", "12.5999229231448"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.69727950798439"}], ",", " ", 
         RowBox[{"-", "11.507617207166728"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.823632531882652"}], ",", " ", 
         RowBox[{"-", "10.415311491188655"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.937250662294787"}], ",", " ", 
         RowBox[{"-", "9.323005775210584"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.038179572921905"}], ",", " ", 
         RowBox[{"-", "8.230700059232511"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.126459653453892"}], ",", " ", 
         RowBox[{"-", "7.13839434325444"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.202126091338542"}], ",", " ", 
         RowBox[{"-", "6.046088627276369"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.265208942550117"}], ",", " ", 
         RowBox[{"-", "4.953782911298298"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.315733191693084"}], ",", " ", 
         RowBox[{"-", "3.861477195320223"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.353718801722664"}], ",", " ", 
         RowBox[{"-", "2.769171479342152"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.379180753514845"}], ",", " ", 
         RowBox[{"-", "1.6768657633640807"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392129075469327"}], ",", " ", 
         RowBox[{"-", "0.5845600473860095"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.392568863282136"}], ",", " ", 
         "0.5077456685920616"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.380500289979267"}], ",", " ", 
         "1.6000513845701327"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.355918606257092"}], ",", " ", 
         "2.6923571005482074"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.318814131131532"}], ",", " ", 
         "3.7846628165262786"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.269172232852767"}], ",", " ", "4.87696853250435"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.20697329999733"}], ",", " ", "5.969274248482421"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.132192702604783"}], ",", " ", "7.061579964460492"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15.044800743177618"}], ",", " ", "8.153885680438567"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.944762597316725"}], ",", " ", "9.246191396416638"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.832038243712802"}], ",", " ", 
         "10.338497112394709"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.70658238316311"}], ",", " ", "11.43080282837278"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.56834434622617"}], ",", " ", "12.523108544350851"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.417267989068776"}], ",", " ", 
         "13.615414260328922"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.253291576997668"}], ",", " ", 
         "14.707719976306993"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "14.076347655099426"}], ",", " ", 
         "15.800025692285065"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.886362905341088"}], ",", " ", 
         "16.892331408263143"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.683257989404723"}], ",", " ", 
         "17.984637124241214"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.466947376444296"}], ",", " ", 
         "19.076942840219285"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "13.237339154859683"}], ",", " ", 
         "20.169248556197356"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.994334827081488"}], ",", " ", 
         "21.261554272175427"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.737829086247373"}], ",", " ", "22.3538599881535"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.467709573528452"}], ",", " ", "23.44616570413157"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12.183856614726537"}], ",", " ", "24.53847142010964"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.886142934613403"}], ",", " ", 
         "25.630777136087712"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.574433347313843"}], ",", " ", 
         "26.723082852065783"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11.248584420848601"}], ",", " ", 
         "27.815388568043854"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.90844411374296"}], ",", " ", "28.907694284021932"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374159"}], ",", " ", 
         "30.000000000000004"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10.553851381374166"}], ",", " ", "30."}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[CompressedData["
1:eJxdlX801Pkax6fo5kdhUYbI+NH8njFjfn2/ZpjPJsrmWtFuRkJoUYnN5Ge1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     "]],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[CompressedData["
1:eJxdlX801Pkax6fo5kdhUYbI+NH8njFjfn2/ZpjPJsrmWtFuRkJoUYnN5Ge1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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxUFIEwAYBtDF1rRLLGkRos6GFU5hNQnNqbEoXARRMldYigpexK0YE4Wx
wZg6F8xGDZvbdDMd1FDX1mQGkVOZnoScCDKUGFSLpYTCZm0j+j8Pj3eh82lT
1wkGgyEhtq85Z7o4KVmq9QYwvywcPl5xdgO/XBGGj2jdge/kH7onr06Oi76I
WrFAH+feK0lKRm9GBmU0P7TsfUUvx++G8Wxbt9ZK69+rprH/wXgEj3CnNnEB
64lrlP50P+nH/bL2z7jOdLiFM5qjb/jNX2bea7pys5yDd4fry/HcfPSZjV59
njHjhmsj65jPscWxJcFW2OkiY0SN2afVY7hGsJjAMaEmiy9euVzpoA+nglfx
uWimHis9njvYmduX471HsTYsqnCr8JorbcdChciHLbXVH/GOlcN00hM+fR9W
ul0abNZ2mvDMde1vPK3SMcdploGVj3ktZh6efHhbjK2x7UacTYWacdWtSQO+
8W9o/y19Sfzj1Ds60Humw08HpT0qXGKUDuDci/NuvOpojAboplThd/z4V4rz
gV5aqD74WZqU/Afz2wKA
  "]],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
     0, -13.052428498814855`, -5.}, {0, -4.441942799051883, -10.}, {
     0, 4.168542900711088, -15.}, {0, 12.77902860047406, -20.}, {
     0, 21.38951430023703, -25.}, {0, 30.000000000000004`, -30.}, {
     0, -21.662914198577827`, 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -13.052428498814855`, 5.}, {
      0, -4.441942799051883, 10.}, {0, 4.168542900711088, 15.}, {
      0, 12.77902860047406, 20.}, {0, 21.38951430023703, 25.}, {
      0, 30.000000000000004`, 30.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -21.47807039571055, 5.}, {
      0, -21.293226592843272`, 10.}, {0, -21.108382789975998`, 15.}, {
      0, -20.92353898710872, 20.}, {
      0, -20.738695184241443`, 24.999999999999996`}, {
      0, -20.553851381374166`, 30.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -21.47807039571055, 5.}, {
      0, -21.293226592843272`, 10.}, {0, -21.108382789975995`, 15.}, {
      0, -20.923538987108717`, 20.}, {
      0, -20.738695184241436`, 24.999999999999996`}, {
      0, -20.55385138137416, 30.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.54286504410059, 4.800000000000001}, {
      0, -21.422815889623354`, 9.600000000000001}, {
      0, -21.30276673514612, 14.400000000000002`}, {
      0, -21.182717580668882`, 19.200000000000003`}, {
      0, -21.062668426191646`, 24.000000000000004`}, {
      0, -20.942619271714406`, 28.800000000000004`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.604755812624617`, 4.6}, {0, -21.546597426671404`, 9.2}, {
      0, -21.48843904071819, 13.799999999999999`}, {
      0, -21.43028065476498, 18.4}, {0, -21.372122268811772`, 23.}, {
      0, -21.31396388285856, 27.599999999999998`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.663777991904592`, 4.399999999999999}, {
      0, -21.664641785231357`, 8.799999999999997}, {
      0, -21.66550557855812, 13.199999999999998`}, {
      0, -21.666369371884883`, 17.599999999999994`}, {
      0, -21.66723316521165, 21.999999999999993`}, {
      0, -21.668096958538413`, 26.399999999999995`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.719964706043452`, 4.2}, {0, -21.777015213509074`, 8.4}, {
      0, -21.8340657209747, 12.6}, {0, -21.891116228440325`, 16.8}, {
      0, -21.94816673590595, 21.}, {0, -22.005217243371572`, 25.2}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.77334701559324, 3.999999999999999}, {
      0, -21.883779832608656`, 7.999999999999998}, {
      0, -21.99421264962407, 11.999999999999998`}, {
      0, -22.104645466639486`, 15.999999999999996`}, {
      0, -22.2150782836549, 19.999999999999996`}, {
      0, -22.325511100670315`, 23.999999999999996`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.823954011862035`, 3.8000000000000003`}, {
      0, -21.98499382514624, 7.6000000000000005`}, {
      0, -22.14603363843045, 11.399999999999999`}, {
      0, -22.307073451714658`, 15.200000000000001`}, {
      0, -22.468113264998866`, 19.}, {
      0, -22.62915307828307, 22.799999999999997`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.871812903282425`, 3.6}, {0, -22.080711607987027`, 7.2}, {
      0, -22.289610312691625`, 10.799999999999999`}, {
      0, -22.498509017396227`, 14.4}, {0, -22.707407722100825`, 18.}, {
      0, -22.916306426805424`, 21.599999999999998`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.916949094485147`, 3.3999999999999995`}, {
      0, -22.170983990392468`, 6.799999999999999}, {
      0, -22.42501888629979, 10.199999999999998`}, {
      0, -22.67905378220711, 13.599999999999998`}, {
      0, -22.93308867811443, 16.999999999999996`}, {
      0, -23.18712357402175, 20.399999999999995`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.959386258651413`, 3.2}, {0, -22.255858318724997`, 6.4}, {
      0, -22.552330378798583`, 9.600000000000001}, {
      0, -22.848802438872166`, 12.8}, {0, -23.145274498945753`, 16.}, {
      0, -23.441746559019336`, 19.200000000000003`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.99914640365535, 3.0000000000000004`}, {
      0, -22.33537860873287, 6.000000000000001}, {
      0, -22.671610813810393`, 9.000000000000002}, {
      0, -23.007843018887915`, 12.000000000000002`}, {
      0, -23.344075223965433`, 15.000000000000002`}, {
      0, -23.680307429042955`, 18.000000000000004`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -22.03624993245285, 2.8}, {
      0, -22.409585666327875`, 5.6}, {0, -22.7829214002029, 8.4}, {
      0, -23.156257134077922`, 11.2}, {
      0, -23.529592867952942`, 13.999999999999998`}, {
      0, -23.902928601827966`, 16.8}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.070715698123628`, 2.6}, {0, -22.478517197669426`, 5.2}, {
      0, -22.886318697215227`, 7.8}, {0, -23.29412019676103, 10.4}, {
      0, -23.701921696306826`, 13.}, {0, -24.109723195852627`, 15.6}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.102561053929247`, 2.4000000000000004`}, {
      0, -22.54220790928067, 4.800000000000001}, {
      0, -22.98185476463209, 7.2}, {
      0, -23.421501619983513`, 9.600000000000001}, {
      0, -23.861148475334932`, 12.}, {0, -24.300795330686356`, 14.4}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.13180189871025, 2.1999999999999997`}, {
      0, -22.60068959884267, 4.3999999999999995`}, {
      0, -23.069577298975094`, 6.6}, {
      0, -23.538464999107514`, 8.799999999999999}, {
      0, -24.007352699239938`, 10.999999999999998`}, {
      0, -24.476240399372358`, 13.2}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.158452717909494`, 1.9999999999999998`}, {
      0, -22.65399123724116, 3.9999999999999996`}, {
      0, -23.14952975657283, 5.999999999999999}, {
      0, -23.645068275904492`, 7.999999999999999}, {
      0, -24.14060679523616, 9.999999999999998}, {
      0, -24.636145314567827`, 11.999999999999998`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.182526620476775`, 1.8}, {0, -22.702139042375723`, 3.6}, {
      0, -23.221751464274668`, 5.4}, {0, -23.741363886173616`, 7.2}, {
      0, -24.260976308072564`, 9.}, {0, -24.780588729971512`, 10.8}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.204035371879947`, 1.6}, {0, -22.745156545182063`, 3.2}, {
      0, -23.28627771848418, 4.8}, {0, -23.8273988917863, 6.4}, {
      0, -24.36852006508842, 8.000000000000002}, {
      0, -24.909641238390535`, 9.6}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.222989423421158`, 1.4000000000000004`}, {
      0, -22.78306464826449, 2.8000000000000007`}, {
      0, -23.343139873107816`, 4.200000000000001}, {
      0, -23.903215097951147`, 5.600000000000001}, {
      0, -24.463290322794478`, 7.000000000000001}, {
      0, -25.02336554763781, 8.400000000000002}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.239397938031843`, 1.2}, {0, -22.815881677485855`, 2.4}, {
      0, -23.39236541693987, 3.599999999999999}, {
      0, -23.968849156393883`, 4.8}, {
      0, -24.5453328958479, 5.999999999999999}, {
      0, -25.12181663530191, 7.199999999999998}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -22.253268812697396`, 1.}, {
      0, -22.843623426816965`, 2.}, {0, -23.43397804093653, 3.}, {
      0, -24.0243326550561, 4.}, {0, -24.61468726917567, 5.}, {
      0, -25.205041883295237`, 6.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.26460869764122, 0.7999999999999999}, {
      0, -22.86630319670461, 1.5999999999999999`}, {
      0, -23.467997695768002`, 2.4}, {
      0, -24.06969219483139, 3.1999999999999997`}, {
      0, -24.67138669389478, 3.9999999999999996`}, {
      0, -25.273081192958173`, 4.8}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.27342301237789, 0.6000000000000002}, {
      0, -22.883931826177953`, 1.2000000000000004`}, {
      0, -23.49444063997802, 1.8000000000000007`}, {
      0, -24.104949453778083`, 2.400000000000001}, {
      0, -24.715458267578146`, 3.0000000000000004`}, {
      0, -25.32596708137821, 3.6000000000000014`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.279715958726563`, 0.4000000000000004}, {
      0, -22.896517718875298`, 0.8000000000000008}, {
      0, -23.513319479024034`, 1.200000000000001}, {
      0, -24.130121239172773`, 1.6000000000000016`}, {
      0, -24.74692299932151, 2.000000000000002}, {
      0, -25.363724759470244`, 2.400000000000002}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.283490530857883`, 0.2000000000000002}, {
      0, -22.904066863137935`, 0.4000000000000004}, {
      0, -23.524643195417987`, 0.6000000000000006}, {
      0, -24.145219527698043`, 0.8000000000000008}, {
      0, -24.7657958599781, 1.000000000000001}, {
      0, -25.38637219225815, 1.2000000000000013`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -22.28474852243062, 0.}, {
      0, -22.906582846283406`, 0.}, {0, -23.528417170136194`, 0.}, {
      0, -24.150251493988986`, 0.}, {0, -24.772085817841777`, 0.}, {
      0, -25.393920141694565`, 0.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.283490530857883`, -0.19999999999999993`}, {
      0, -22.904066863137935`, -0.39999999999999986`}, {
      0, -23.524643195417987`, -0.5999999999999998}, {
      0, -24.145219527698043`, -0.7999999999999997}, {
      0, -24.7657958599781, -0.9999999999999997}, {
      0, -25.38637219225815, -1.1999999999999995`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.279715958726563`, -0.39999999999999974`}, {
      0, -22.896517718875298`, -0.7999999999999995}, {
      0, -23.513319479024034`, -1.199999999999999}, {
      0, -24.130121239172773`, -1.599999999999999}, {
      0, -24.74692299932151, -1.9999999999999987`}, {
      0, -25.363724759470244`, -2.399999999999998}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.27342301237789, -0.6000000000000002}, {
      0, -22.883931826177953`, -1.2000000000000004`}, {
      0, -23.49444063997802, -1.8000000000000007`}, {
      0, -24.104949453778083`, -2.400000000000001}, {
      0, -24.715458267578146`, -3.0000000000000004`}, {
      0, -25.32596708137821, -3.6000000000000014`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.26460869764122, -0.7999999999999994}, {
      0, -22.86630319670461, -1.5999999999999988`}, {
      0, -23.467997695768, -2.3999999999999977`}, {
      0, -24.06969219483139, -3.1999999999999975`}, {
      0, -24.67138669389478, -3.999999999999997}, {
      0, -25.273081192958173`, -4.799999999999995}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.253268812697396`, -1.}, {0, -22.843623426816965`, -2.}, {
      0, -23.43397804093653, -3.}, {0, -24.0243326550561, -4.}, {
      0, -24.61468726917567, -5.}, {0, -25.205041883295237`, -6.}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.23939793803184, -1.1999999999999993`}, {
      0, -22.815881677485855`, -2.3999999999999986`}, {
      0, -23.392365416939867`, -3.599999999999998}, {
      0, -23.968849156393883`, -4.799999999999997}, {
      0, -24.545332895847896`, -5.9999999999999964`}, {
      0, -25.12181663530191, -7.199999999999996}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.222989423421158`, -1.3999999999999997`}, {
      0, -22.78306464826449, -2.7999999999999994`}, {
      0, -23.343139873107816`, -4.199999999999999}, {
      0, -23.903215097951147`, -5.599999999999999}, {
      0, -24.463290322794478`, -6.999999999999997}, {
      0, -25.02336554763781, -8.399999999999999}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.204035371879947`, -1.6}, {0, -22.745156545182063`, -3.2}, {
      0, -23.28627771848418, -4.8}, {0, -23.8273988917863, -6.4}, {
      0, -24.36852006508842, -8.000000000000002}, {
      0, -24.909641238390535`, -9.6}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.182526620476775`, -1.7999999999999998`}, {
      0, -22.702139042375723`, -3.5999999999999996`}, {
      0, -23.221751464274668`, -5.3999999999999995`}, {
      0, -23.741363886173616`, -7.199999999999999}, {
      0, -24.260976308072564`, -9.}, {
      0, -24.780588729971512`, -10.799999999999999`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.158452717909494`, -1.9999999999999998`}, {
      0, -22.65399123724116, -3.9999999999999996`}, {
      0, -23.14952975657283, -5.999999999999999}, {
      0, -23.645068275904492`, -7.999999999999999}, {
      0, -24.14060679523616, -9.999999999999998}, {
      0, -24.636145314567827`, -11.999999999999998`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.131801898710254`, -2.1999999999999993`}, {
      0, -22.60068959884268, -4.399999999999999}, {
      0, -23.069577298975105`, -6.599999999999998}, {
      0, -23.538464999107532`, -8.799999999999997}, {
      0, -24.00735269923996, -10.999999999999996`}, {
      0, -24.476240399372386`, -13.199999999999996`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.102561053929247`, -2.4}, {0, -22.54220790928067, -4.8}, {
      0, -22.98185476463209, -7.2}, {0, -23.421501619983513`, -9.6}, {
      0, -23.861148475334932`, -11.999999999999998`}, {
      0, -24.300795330686356`, -14.4}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.070715698123628`, -2.6}, {0, -22.478517197669426`, -5.2}, {
      0, -22.886318697215227`, -7.8}, {0, -23.29412019676103, -10.4}, {
      0, -23.701921696306826`, -13.}, {0, -24.109723195852627`, -15.6}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -22.03624993245285, -2.7999999999999994`}, {
      0, -22.409585666327875`, -5.599999999999999}, {
      0, -22.7829214002029, -8.399999999999999}, {
      0, -23.15625713407792, -11.199999999999998`}, {
      0, -23.529592867952942`, -13.999999999999996`}, {
      0, -23.902928601827966`, -16.799999999999997`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.99914640365535, -3.0000000000000004`}, {
      0, -22.33537860873287, -6.000000000000001}, {
      0, -22.671610813810393`, -9.000000000000002}, {
      0, -23.007843018887915`, -12.000000000000002`}, {
      0, -23.344075223965433`, -15.000000000000002`}, {
      0, -23.680307429042955`, -18.000000000000004`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.95938625865141, -3.1999999999999997`}, {
      0, -22.255858318724993`, -6.3999999999999995`}, {
      0, -22.552330378798576`, -9.599999999999998}, {
      0, -22.84880243887216, -12.799999999999999`}, {
      0, -23.14527449894574, -15.999999999999998`}, {
      0, -23.44174655901932, -19.199999999999996`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.916949094485147`, -3.3999999999999995`}, {
      0, -22.170983990392468`, -6.799999999999999}, {
      0, -22.42501888629979, -10.199999999999998`}, {
      0, -22.67905378220711, -13.599999999999998`}, {
      0, -22.93308867811443, -16.999999999999996`}, {
      0, -23.18712357402175, -20.399999999999995`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.871812903282425`, -3.6}, {0, -22.080711607987027`, -7.2}, {
      0, -22.289610312691625`, -10.799999999999999`}, {
      0, -22.498509017396227`, -14.4}, {0, -22.707407722100825`, -18.}, {
      0, -22.916306426805424`, -21.599999999999998`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.823954011862035`, -3.8}, {0, -21.98499382514624, -7.6}, {
      0, -22.14603363843045, -11.399999999999999`}, {
      0, -22.307073451714658`, -15.2}, {
      0, -22.468113264998866`, -18.999999999999996`}, {
      0, -22.62915307828307, -22.799999999999997`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.77334701559324, -3.999999999999999}, {
      0, -21.883779832608656`, -7.999999999999998}, {
      0, -21.99421264962407, -11.999999999999998`}, {
      0, -22.104645466639486`, -15.999999999999996`}, {
      0, -22.2150782836549, -19.999999999999996`}, {
      0, -22.325511100670315`, -23.999999999999996`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.719964706043452`, -4.199999999999999}, {
      0, -21.777015213509074`, -8.399999999999999}, {
      0, -21.8340657209747, -12.599999999999996`}, {
      0, -21.891116228440325`, -16.799999999999997`}, {
      0, -21.94816673590595, -20.999999999999996`}, {
      0, -22.005217243371572`, -25.199999999999992`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.663777991904592`, -4.399999999999999}, {
      0, -21.664641785231357`, -8.799999999999997}, {
      0, -21.66550557855812, -13.199999999999998`}, {
      0, -21.666369371884883`, -17.599999999999994`}, {
      0, -21.66723316521165, -21.999999999999993`}, {
      0, -21.668096958538413`, -26.399999999999995`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.604755812624617`, -4.599999999999999}, {
      0, -21.546597426671404`, -9.199999999999998}, {
      0, -21.488439040718195`, -13.799999999999995`}, {
      0, -21.43028065476498, -18.399999999999995`}, {
      0, -21.372122268811772`, -22.999999999999996`}, {
      0, -21.31396388285856, -27.59999999999999}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {
      0, -21.54286504410059, -4.799999999999999}, {
      0, -21.422815889623354`, -9.599999999999998}, {
      0, -21.30276673514612, -14.399999999999997`}, {
      0, -21.182717580668882`, -19.199999999999996`}, {
      0, -21.062668426191646`, -23.999999999999993`}, {
      0, -20.94261927171441, -28.799999999999994`}, {
      0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -21.47807039571055, -5.}, {
      0, -21.293226592843272`, -10.}, {0, -21.108382789975995`, -15.}, {
      0, -20.923538987108717`, -20.}, {
      0, -20.738695184241436`, -24.999999999999996`}, {
      0, -20.55385138137416, -30.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -21.662914198577827`, 0.}, {0, -21.47807039571055, -5.}, {
      0, -21.293226592843272`, -10.}, {0, -21.108382789975998`, -15.}, {
      0, -20.92353898710872, -20.}, {
      0, -20.738695184241443`, -24.999999999999996`}, {
      0, -20.553851381374166`, -30.}, {0, -21.662914198577827`, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 30., -30.}, {0, 30., 30.}, {
      0, -20.553851381374166`, 30.}, {0, -20.55385138137416, 30.}, {
      0, -20.942619271714406`, 28.8}, {0, -21.31396388285856, 27.6}, {
      0, -21.668096958538413`, 26.4}, {0, -22.005217243371575`, 25.2}, {
      0, -22.32551110067031, 24.}, {0, -22.629153078283068`, 22.8}, {
      0, -22.91630642680542, 21.6}, {0, -23.187123574021754`, 20.4}, {
      0, -23.441746559019336`, 19.200000000000003`}, {
      0, -23.680307429042955`, 18.}, {0, -23.902928601827966`, 16.8}, {
      0, -24.109723195852624`, 15.600000000000001`}, {
      0, -24.300795330686356`, 14.4}, {0, -24.476240399372358`, 13.2}, {
      0, -24.636145314567827`, 12.}, {0, -24.780588729971512`, 10.8}, {
      0, -24.909641238390535`, 9.600000000000001}, {
      0, -25.02336554763781, 8.400000000000002}, {
      0, -25.12181663530191, 7.199999999999999}, {
      0, -25.205041883295237`, 6.}, {
      0, -25.273081192958173`, 4.800000000000001}, {
      0, -25.32596708137821, 3.6000000000000014`}, {
      0, -25.363724759470244`, 2.400000000000002}, {
      0, -25.38637219225815, 1.2000000000000028`}, {
      0, -25.393920141694565`, 0.}, {
      0, -25.38637219225815, -1.1999999999999993`}, {
      0, -25.363724759470244`, -2.3999999999999986`}, {
      0, -25.32596708137821, -3.6000000000000014`}, {
      0, -25.273081192958173`, -4.799999999999997}, {
      0, -25.205041883295237`, -6.}, {
      0, -25.12181663530191, -7.199999999999996}, {
      0, -25.02336554763781, -8.399999999999999}, {
      0, -24.909641238390535`, -9.600000000000001}, {
      0, -24.780588729971512`, -10.799999999999997`}, {
      0, -24.636145314567827`, -12.}, {
      0, -24.476240399372386`, -13.199999999999996`}, {
      0, -24.300795330686356`, -14.399999999999999`}, {
      0, -24.109723195852624`, -15.600000000000001`}, {
      0, -23.902928601827966`, -16.799999999999997`}, {
      0, -23.680307429042955`, -18.}, {
      0, -23.44174655901932, -19.199999999999996`}, {
      0, -23.187123574021754`, -20.4}, {0, -22.91630642680542, -21.6}, {
      0, -22.629153078283068`, -22.799999999999997`}, {
      0, -22.32551110067031, -24.}, {
      0, -22.005217243371575`, -25.199999999999996`}, {
      0, -21.668096958538413`, -26.4}, {
      0, -21.31396388285856, -27.599999999999994`}, {
      0, -20.942619271714406`, -28.799999999999997`}, {
      0, -20.55385138137416, -30.}, {0, -20.553851381374166`, -30.}, {
      0, 30., -30.}}]}, 
   {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[
    None], Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.553851381374166`, 
     30., -30.}, {0., 30., -30.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {0., 30., -30.}, {0., 30., 
     30.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {0., 30., 30.}, {
     40.553851381374166`, 30., 30.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.553851381374166`, 30., 
     30.}, {40.55385138137416, 30., 30.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.55385138137416, 30., 
     30.}, {40.942619271714406`, 30., 28.8}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.942619271714406`, 30., 
     28.8}, {41.31396388285856, 30., 27.6}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {41.31396388285856, 30., 
     27.6}, {41.66809695853841, 30., 26.4}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {41.66809695853841, 30., 
     26.4}, {42.005217243371575`, 30., 25.2}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.005217243371575`, 30., 
     25.2}, {42.32551110067031, 30., 24.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.32551110067031, 30., 
     24.}, {42.62915307828307, 30., 22.8}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.62915307828307, 30., 
     22.8}, {42.91630642680542, 30., 21.6}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.91630642680542, 30., 
     21.6}, {43.187123574021754`, 30., 20.4}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.187123574021754`, 30., 
     20.4}, {43.441746559019336`, 30., 19.200000000000003`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.441746559019336`, 30., 
     19.200000000000003`}, {43.680307429042955`, 30., 18.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.680307429042955`, 30., 
     18.}, {43.902928601827966`, 30., 16.8}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.902928601827966`, 30., 
     16.8}, {44.109723195852624`, 30., 15.600000000000001`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.109723195852624`, 30., 
     15.600000000000001`}, {44.300795330686356`, 30., 14.4}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.300795330686356`, 30., 
     14.4}, {44.47624039937236, 30., 13.2}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.47624039937236, 30., 
     13.2}, {44.63614531456783, 30., 12.}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.63614531456783, 30., 
     12.}, {44.78058872997151, 30., 10.8}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.78058872997151, 30., 
     10.8}, {44.909641238390535`, 30., 9.600000000000001}, {29.65847509531303,
      30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.909641238390535`, 30., 
     9.600000000000001}, {45.02336554763781, 30., 8.400000000000002}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.02336554763781, 30., 
     8.400000000000002}, {45.12181663530191, 30., 7.199999999999999}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.12181663530191, 30., 
     7.199999999999999}, {45.20504188329524, 30., 6.}, {29.65847509531303, 
     30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.20504188329524, 30., 
     6.}, {45.27308119295817, 30., 4.800000000000001}, {29.65847509531303, 
     30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.27308119295817, 30., 
     4.800000000000001}, {45.32596708137821, 30., 3.6000000000000014`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.32596708137821, 30., 
     3.6000000000000014`}, {45.363724759470244`, 30., 2.400000000000002}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.363724759470244`, 30., 
     2.400000000000002}, {45.38637219225815, 30., 1.2000000000000028`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.38637219225815, 30., 
     1.2000000000000028`}, {45.393920141694565`, 30., 0.}, {29.65847509531303,
      30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.393920141694565`, 30., 
     0.}, {45.38637219225815, 30., -1.1999999999999993`}, {29.65847509531303, 
     30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.38637219225815, 
     30., -1.1999999999999993`}, {45.363724759470244`, 
     30., -2.3999999999999986`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.363724759470244`, 
     30., -2.3999999999999986`}, {45.32596708137821, 
     30., -3.6000000000000014`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.32596708137821, 
     30., -3.6000000000000014`}, {45.27308119295817, 
     30., -4.799999999999997}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.27308119295817, 
     30., -4.799999999999997}, {45.20504188329524, 30., -6.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.20504188329524, 
     30., -6.}, {45.12181663530191, 30., -7.199999999999996}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.12181663530191, 
     30., -7.199999999999996}, {45.02336554763781, 30., -8.399999999999999}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {45.02336554763781, 
     30., -8.399999999999999}, {44.909641238390535`, 
     30., -9.600000000000001}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.909641238390535`, 
     30., -9.600000000000001}, {44.78058872997151, 
     30., -10.799999999999997`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.78058872997151, 
     30., -10.799999999999997`}, {44.63614531456783, 30., -12.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.63614531456783, 
     30., -12.}, {44.47624039937239, 30., -13.199999999999996`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.47624039937239, 
     30., -13.199999999999996`}, {44.300795330686356`, 
     30., -14.399999999999999`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.300795330686356`, 
     30., -14.399999999999999`}, {44.109723195852624`, 
     30., -15.600000000000001`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {44.109723195852624`, 
     30., -15.600000000000001`}, {43.902928601827966`, 
     30., -16.799999999999997`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.902928601827966`, 
     30., -16.799999999999997`}, {43.680307429042955`, 30., -18.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.680307429042955`, 
     30., -18.}, {43.44174655901932, 30., -19.199999999999996`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.44174655901932, 
     30., -19.199999999999996`}, {43.187123574021754`, 30., -20.4}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {43.187123574021754`, 
     30., -20.4}, {42.91630642680542, 30., -21.6}, {29.65847509531303, 30., 
     0.}}], Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.91630642680542, 
     30., -21.6}, {42.62915307828307, 30., -22.799999999999997`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.62915307828307, 
     30., -22.799999999999997`}, {42.32551110067031, 30., -24.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.32551110067031, 
     30., -24.}, {42.005217243371575`, 30., -25.199999999999996`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {42.005217243371575`, 
     30., -25.199999999999996`}, {41.66809695853841, 30., -26.4}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {41.66809695853841, 
     30., -26.4}, {41.31396388285856, 30., -27.599999999999994`}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {41.31396388285856, 
     30., -27.599999999999994`}, {40.942619271714406`, 
     30., -28.799999999999997`}, {29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.942619271714406`, 
     30., -28.799999999999997`}, {40.55385138137416, 30., -30.}, {
     29.65847509531303, 30., 0.}}], 
    Polygon3DBox[{{29.65847509531303, 30., 0.}, {40.55385138137416, 
     30., -30.}, {40.553851381374166`, 30., -30.}, {29.65847509531303, 30., 
     0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCwAGJmBnRg5wClD+AQd4h8ozDriZuLA7p4BA7xe94T9i+v
QIifPQMCNg4RDR++669AiM+aCQLWDkl7a41briLE08DAyuHf5Yyvqxhc4eLG
YGDpMO0da+QqTVc0ey0clm3uFusIcEWz18zBQj6n3bPUFc1eU4dvsf6rPk93
RbPXxOEZ7w617h0IcROIxQ4TqsMDRK6j22vksGGPuNbkz+j2GjhEPXuQwc3n
hmaOvoMBt1xZg5obmnodBx9ttqKvNghxiHu0HNxOrjHNDXRDs1fDwSv3bsir
ZIQ4xF+qDlV/j8jnl6Dbq+wwoSp7yd8mhPg5sL0KDg2xDBum9yPEwcJnZByk
On6ft5uFbq+Eg1WJSPCXRejmCzsc4xb02rkSIX4BbA6Pw4nQ3I6+dQhxC7B6
ZodJr+4sKdmIEIdE8Gd7nRfLfmZvQreXgQFdvQFE/X508yHizAdwuOcAuvsh
6oUP4PDvAfTwOQEJnwPo4QkJN4UDOML/AHp8zYDE1wEc8XsgAC09pEDSwwH0
9AOxV+cAjvR2AD19QtQbHMCRng88QUv/RpD0fwBHfjmAI38dQM+PEHvNDuDI
vwfQ8zvEXssDOMqHA+jlCSQ8rQ+glz8Qe20O4CivDuAo3w4woACEOACx5XgR

      "]]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], 
     Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
      35.695898013668554`, -29.712370074218413`, -5.}, {
      28.556718410934845`, -29.488275380844073`, -10.}, {
      21.417538808201133`, -28.495387505665803`, -15.}, {
      14.278359205467424`, -26.71003055902571, -20.}, {
      7.139179602733712, -24.08710268025014, -25.}, {
      0., -20.553851381374173`, -30.}, {
      42.835077616402266`, -29.172883302750307`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       35.695898013668554`, -29.712370074218413`, 5.}, {
       28.556718410934845`, -29.488275380844073`, 10.}, {
       21.417538808201133`, -28.495387505665803`, 15.}, {
       14.278359205467424`, -26.71003055902571, 20.}, {
       7.139179602733712, -24.08710268025014, 25.}, {0., -20.553851381374173`,
        30.}, {42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.72312719267533, -29.061203477643076`, 4.999999999999999}, {
       42.61117676894839, -28.696292840725974`, 9.999999999999998}, {
       42.49922634522146, -28.075324831330136`, 14.999999999999998`}, {
       42.38727592149452, -27.193391726211317`, 19.999999999999996`}, {
       42.27532549776758, -26.0433047324167, 24.999999999999996`}, {
       42.163375074040644`, -24.615285798903585`, 29.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.72312719267533, -29.061203477643076`, 4.999999999999999}, {
       42.61117676894839, -28.696292840725974`, 9.999999999999998}, {
       42.49922634522146, -28.075324831330136`, 14.999999999999998`}, {
       42.38727592149452, -27.193391726211317`, 19.999999999999996`}, {
       42.27532549776758, -26.0433047324167, 24.999999999999996`}, {
       42.163375074040644`, -24.615285798903585`, 29.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.771870335307575`, -29.064823868707748`, 4.800000000000001}, {
       42.70866305421289, -28.723502183494716`, 9.600000000000001}, {
       42.6454557731182, -28.146484645605682`, 14.4}, {
       42.58224849202351, -27.329579383068193`, 19.200000000000003`}, {
       42.51904121092882, -26.26667963090378, 24.000000000000004`}, {
       42.45583392983413, -24.94952449123899, 28.8}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.818369969118436`, -29.068306694597354`, 4.6000000000000005`}, {
       42.8016623218346, -28.749569324618932`, 9.200000000000001}, {
       42.78495467455077, -28.214586156892608`, 13.800000000000002`}, {
       42.76824702726694, -27.459796161549036`, 18.400000000000002`}, {
       42.7515393799831, -26.48004064800523, 23.000000000000004`}, {
       42.73483173269926, -25.268379123084884`, 27.600000000000005`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.86266152401875, -29.07165052889009, 4.3999999999999995`}, {
       42.89024543163522, -28.774498595093903`, 8.799999999999999}, {
       42.9178293392517, -28.27965041229018, 13.199999999999998`}, {
       42.945413246868185`, -27.584098478531885`, 17.599999999999998`}, {
       42.97299715448466, -26.683511235524193`, 21.999999999999996`}, {
       43.00058106210114, -25.572092642401316`, 26.399999999999995`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.90477805693456, -29.07485404128164, 4.199999999999999}, {
       42.97447849746685, -28.798294052674663`, 8.399999999999999}, {
       43.04417893799914, -28.341697137244182`, 12.599999999999998`}, {
       43.113879378531436`, -27.702539207767416`, 16.799999999999997`}, {
       43.18357981906373, -26.877206933077787`, 20.999999999999996`}, {
       43.253280259596025`, -25.8608917252526, 25.199999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.94475039205331, -29.077915991846723`, 3.9999999999999996`}, {
       43.05442316770435, -28.820959496245038`, 7.999999999999999}, {
       43.16409594335539, -28.400744804062, 11.999999999999998`}, {
       43.273768719006426`, -27.815167862629195`, 15.999999999999998`}, {
       43.38344149465747, -27.061235793488024`, 19.999999999999996`}, {
       43.49311427030851, -26.134987737495436`, 23.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.98260724772591, -29.080835225846243`, 3.8}, {
       43.13013687904956, -28.842498478829555`, 7.6}, {
       43.2776665103732, -28.456810694026217`, 11.399999999999999`}, {
       43.425196141696844`, -27.92203076201477, 15.2}, {
       43.572725773020494`, -27.235698768972625`, 19.}, {
       43.72025540434414, -26.39457760496471, 22.799999999999997`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.018375351364604`, -29.08361066902529, 3.6000000000000005`}, {
       43.201673086326934`, -28.862914319383435`, 7.200000000000001}, {
       43.38497082128927, -28.50991095373722, 10.8}, {
       43.56826855625161, -28.02317118102961, 14.400000000000002`}, {
       43.75156629121394, -27.400690061920756`, 18.000000000000004`}, {
       43.93486402617628, -26.639844601344322`, 21.6}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.05207954350768, -29.086241323354017`, 3.4000000000000004`}, {
       43.269081470613095`, -28.88221011347912, 6.800000000000001}, {
       43.4860833977185, -28.560060646236323`, 10.200000000000001`}, {
       43.70308532482392, -28.11862948788368, 13.600000000000001`}, {
       43.92008725192933, -27.556297443571907`, 17.}, {
       44.137089179034746`, -26.870959061754007`, 20.400000000000002`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.08374287207704, -29.088726263169676`, 3.2}, {
       43.33240812775182, -28.900388742992604`, 6.4}, {
       43.5810733834266, -28.607273797392764`, 9.600000000000001}, {
       43.82973863910137, -28.208443268255436`, 12.8}, {
       44.078403894776145`, -27.702602543512384`, 16.}, {
       44.327069150450924`, -27.08807902908677, 19.200000000000003`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.11338667772819, -29.09106463168301, 2.9999999999999996`}, {
       43.39169573905411, -28.91745288488073, 5.999999999999999}, {
       43.67000480038003, -28.651563437978965`, 9.}, {
       43.948313861705955`, -28.292647438225714`, 11.999999999999998`}, {
       44.226622923031876`, -27.839681112552, 14.999999999999998`}, {
       44.504931984357796`, -27.291350839266045`, 18.}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.14103067108275, -29.093255637816554`, 2.7999999999999994`}, {
       43.446983725763246`, -28.933405019129196`, 5.599999999999999}, {
       43.75293678044373, -28.692941641806982`, 8.399999999999999}, {
       44.05888983512422, -28.371274346751463`, 11.199999999999998`}, {
       44.364842889804706`, -27.96760326123747, 13.999999999999998`}, {
       44.6707959444852, -27.480909650840232`, 16.799999999999997`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.166693002537926`, -29.09529855334671, 2.6}, {
       43.49830838867358, -28.948247435941298`, 5.2}, {
       43.829923774809245`, -28.73141956025431, 7.8}, {
       44.1615391609449, -28.444353868533383`, 10.4}, {
       44.49315454708056, -28.086433675990264`, 13.}, {
       44.82476993321622, -27.656879923675675`, 15.6}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.19039032526307, -29.097192710324578`, 2.4}, {
       43.54570303412387, -28.961982242229396`, 4.8}, {
       43.90101574298467, -28.76700745346743, 7.2}, {
       44.25632845184547, -28.511913488029975`, 9.6}, {
       44.61164116070627, -28.196231814620845`, 12.}, {
       44.96695386956707, -27.81937585093381, 14.4}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.212137851920296`, -29.098937498753514`, 2.1999999999999997`}, {
       43.58919808743832, -28.97461136746314, 4.3999999999999995`}, {
       43.96625832295635, -28.7997147184973, 6.6}, {
       44.34331855847438, -28.57397837527978, 8.799999999999999}, {
       44.72037879399241, -28.29705208276279, 10.999999999999998`}, {
       45.09743902951044, -27.968501748011917`, 13.2}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.2319494055802, -29.100532364504303`, 1.9999999999999996`}, {
       43.62882119475814, -28.986136568922177`, 3.999999999999999}, {
       44.02569298393607, -28.82954991458965, 5.999999999999999}, {
       44.422564773114004`, -28.63057145411524, 7.999999999999998}, {
       44.81943656229194, -28.388943992585908`, 9.999999999999998}, {
       45.21630835146988, -28.10435240167986, 11.999999999999998`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.24983746524636, -29.101976807450995`, 1.8}, {
       43.66459731409044, -28.99655943639533, 3.6}, {
       44.07935716293453, -28.85652078582639, 5.4}, {
       44.49411701177862, -28.681713463279863`, 7.2}, {
       44.90887686062271, -28.471952304982707`, 9.}, {
       45.3236367094668, -28.227013382247776`, 10.8}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.265813206350316`, -29.1032703798125, 1.6}, {
       43.696548796298366`, -29.005881396362597`, 3.2}, {
       44.127284386246416`, -28.88063428128946, 4.800000000000001}, {
       44.558019976194466`, -28.727423010897652`, 6.4}, {
       44.988755566142515`, -28.546117156275784`, 8.000000000000002}, {
       45.419491156090565`, -28.336561321246364`, 9.600000000000001}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.279886536532786`, -29.104412684687333`, 1.4000000000000001`}, {
       43.7246954566633, -29.014103715692173`, 2.8000000000000003`}, {
       44.16950437679382, -28.90189657289703, 4.2}, {
       44.61431329692433, -28.76771662268669, 5.6000000000000005`}, {
       45.05912221705485, -28.61147417036115, 7.}, {
       45.50393113718536, -28.43306415678329, 8.4}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.292066126984665`, -29.105403374769963`, 1.1999999999999997`}, {
       43.74905463756707, -29.02122750487996, 2.3999999999999995`}, {
       44.20604314814947, -28.92031307104176, 3.599999999999999}, {
       44.66303165873187, -28.802608784257444`, 4.799999999999999}, {
       45.12002016931427, -28.66805455708311, 5.999999999999998}, {
       45.57700867989667, -28.51658134845333, 7.199999999999998}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.302359439584, -29.106242151239442`, 1.}, {
       43.76964126276574, -29.027253720855754`, 2.}, {
       44.23692308594747, -28.935888438143692`, 2.9999999999999996`}, {
       44.7042049091292, -28.832111977789594`, 4.}, {
       45.17148673231094, -28.715885197526916`, 5.}, {
       45.638768555492675`, -28.587164063420204`, 5.999999999999999}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.31077275003005, -29.106928762811833`, 0.8000000000000003}, {
       43.78646788365782, -29.032183169376168`, 1.6000000000000005`}, {
       44.2621630172856, -28.94862660021296, 2.400000000000001}, {
       44.73785815091338, -28.856236713338205`, 3.200000000000001}, {
       45.213553284541156`, -28.754988716815845`, 4.000000000000001}, {
       45.68924841816894, -28.644855335050195`, 4.800000000000002}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.317311167143906`, -29.10746300494965, 0.6000000000000001}, {
       43.799544717885546`, -29.036016507021714`, 1.2000000000000002`}, {
       44.28177826862719, -28.958530756503094`, 1.8000000000000005`}, {
       44.76401181936883, -28.874991554980866`, 2.4000000000000004`}, {
       45.24624537011047, -28.78538354490702, 3.0000000000000004`}, {
       45.72847892085211, -28.68969019525956, 3.600000000000001}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.321978648475564`, -29.10784471922271, 0.4}, {
       43.808879680548856`, -29.038754242812075`, 0.8}, {
       44.29578071262215, -28.965603387321494`, 1.2000000000000002`}, {
       44.782681744695445`, -28.88838314198007, 1.6}, {
       45.26958277676874, -28.80708396579371, 2.0000000000000004`}, {
       45.756483808842034`, -28.721695781533754`, 2.4000000000000004`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.324778012329126`, -29.108073792815432`, 0.2000000000000005}, {
       43.81447840825598, -29.040396739450856`, 0.400000000000001}, {
       44.30417880418284, -28.969846260050176`, 0.6000000000000015}, {
       44.7938792001097, -28.89641620510099, 0.800000000000002}, {
       45.28357959603655, -28.820100155442134`, 1.0000000000000024`}, {
       45.77327999196341, -28.740891419386756`, 1.200000000000003}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.32571094629213, -29.10815015817755, 0.}, {
       43.816344276182, -29.040944214208764`, 0.}, {
       44.30697760607187, -28.971260433417527`, 0.}, {
       44.79761093596173, -28.89909357819164, 0.}, {
       45.288244265851596`, -28.824438208712607`, 0.}, {
       45.77887759574146, -28.747288680847376`, 0.}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.324778012329126`, -29.108073792815432`, -0.1999999999999997}, {
       43.81447840825599, -29.040396739450856`, -0.3999999999999994}, {
       44.30417880418284, -28.96984626005016, -0.5999999999999992}, {
       44.7938792001097, -28.89641620510099, -0.7999999999999988}, {
       45.28357959603656, -28.820100155442134`, -0.9999999999999986}, {
       45.77327999196342, -28.740891419386756`, -1.1999999999999984`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.32197864847556, -29.10784471922271, -0.39999999999999974`}, {
       43.808879680548856`, -29.038754242812075`, -0.7999999999999995}, {
       44.29578071262215, -28.965603387321494`, -1.199999999999999}, {
       44.78268174469544, -28.88838314198007, -1.599999999999999}, {
       45.269582776768736`, -28.80708396579371, -1.999999999999999}, {
       45.75648380884203, -28.721695781533754`, -2.399999999999998}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.317311167143906`, -29.10746300494965, -0.6000000000000001}, {
       43.799544717885546`, -29.036016507021714`, -1.2000000000000002`}, {
       44.28177826862719, -28.958530756503094`, -1.8000000000000005`}, {
       44.76401181936883, -28.874991554980866`, -2.4000000000000004`}, {
       45.24624537011047, -28.78538354490702, -3.0000000000000004`}, {
       45.72847892085211, -28.68969019525956, -3.600000000000001}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.31077275003005, -29.106928762811833`, -0.7999999999999996}, {
       43.78646788365783, -29.032183169376168`, -1.5999999999999992`}, {
       44.2621630172856, -28.94862660021296, -2.399999999999999}, {
       44.73785815091338, -28.856236713338205`, -3.1999999999999984`}, {
       45.21355328454116, -28.754988716815845`, -3.999999999999998}, {
       45.689248418168944`, -28.644855335050195`, -4.799999999999998}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.302359439584, -29.106242151239442`, -1.}, {
       43.76964126276574, -29.027253720855754`, -2.}, {
       44.236923085947474`, -28.935888438143692`, -3.}, {
       44.70420490912921, -28.832111977789594`, -4.}, {
       45.171486732310946`, -28.715885197526916`, -5.}, {
       45.63876855549268, -28.587164063420204`, -6.}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.292066126984665`, -29.105403374769963`, -1.1999999999999993`}, {
       43.74905463756706, -29.02122750487996, -2.3999999999999986`}, {
       44.20604314814946, -28.92031307104176, -3.599999999999998}, {
       44.66303165873187, -28.802608784257444`, -4.799999999999997}, {
       45.120020169314266`, -28.66805455708311, -5.999999999999997}, {
       45.577008679896664`, -28.51658134845333, -7.199999999999996}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.279886536532786`, -29.104412684687333`, -1.4}, {
       43.7246954566633, -29.014103715692173`, -2.8}, {
       44.16950437679382, -28.90189657289703, -4.199999999999999}, {
       44.61431329692433, -28.76771662268669, -5.6}, {
       45.05912221705485, -28.61147417036115, -6.999999999999999}, {
       45.50393113718536, -28.43306415678329, -8.399999999999999}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.265813206350316`, -29.1032703798125, -1.6000000000000003`}, {
       43.696548796298366`, -29.005881396362597`, -3.2000000000000006`}, {
       44.127284386246416`, -28.88063428128946, -4.8}, {
       44.55801997619447, -28.727423010897652`, -6.400000000000001}, {
       44.98875556614252, -28.546117156275784`, -8.000000000000002}, {
       45.41949115609057, -28.33656132124635, -9.6}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.24983746524635, -29.101976807450995`, -1.7999999999999996`}, {
       43.66459731409044, -28.99655943639533, -3.599999999999999}, {
       44.07935716293453, -28.85652078582639, -5.3999999999999995`}, {
       44.49411701177861, -28.681713463279863`, -7.199999999999998}, {
       44.9088768606227, -28.471952304982707`, -8.999999999999996}, {
       45.32363670946679, -28.227013382247776`, -10.799999999999999`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.2319494055802, -29.100532364504303`, -1.9999999999999996`}, {
       43.62882119475814, -28.986136568922177`, -3.999999999999999}, {
       44.02569298393607, -28.82954991458965, -5.999999999999999}, {
       44.422564773114004`, -28.63057145411524, -7.999999999999998}, {
       44.81943656229194, -28.388943992585908`, -9.999999999999998}, {
       45.21630835146988, -28.10435240167986, -11.999999999999998`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.21213785192029, -29.098937498753514`, -2.1999999999999993`}, {
       43.58919808743832, -28.97461136746314, -4.399999999999999}, {
       43.96625832295635, -28.7997147184973, -6.599999999999998}, {
       44.34331855847437, -28.57397837527978, -8.799999999999997}, {
       44.720378793992396`, -28.29705208276279, -10.999999999999998`}, {
       45.097439029510426`, -27.96850174801193, -13.199999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.19039032526307, -29.097192710324578`, -2.3999999999999995`}, {
       43.54570303412387, -28.961982242229396`, -4.799999999999999}, {
       43.90101574298467, -28.76700745346743, -7.199999999999998}, {
       44.25632845184547, -28.511913488029975`, -9.599999999999998}, {
       44.61164116070627, -28.196231814620845`, -11.999999999999998`}, {
       44.96695386956707, -27.81937585093381, -14.399999999999997`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.166693002537926`, -29.09529855334671, -2.6}, {
       43.49830838867358, -28.948247435941298`, -5.2}, {
       43.829923774809245`, -28.73141956025431, -7.8}, {
       44.1615391609449, -28.444353868533383`, -10.4}, {
       44.49315454708056, -28.086433675990264`, -13.}, {
       44.82476993321622, -27.656879923675675`, -15.6}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.14103067108275, -29.093255637816554`, -2.799999999999999}, {
       43.446983725763246`, -28.933405019129196`, -5.599999999999998}, {
       43.75293678044373, -28.692941641806982`, -8.399999999999997}, {
       44.05888983512422, -28.371274346751463`, -11.199999999999996`}, {
       44.364842889804706`, -27.96760326123747, -13.999999999999996`}, {
       44.6707959444852, -27.480909650840232`, -16.799999999999994`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.11338667772819, -29.09106463168301, -3.}, {
       43.39169573905411, -28.91745288488073, -6.}, {
       43.67000480038003, -28.651563437978965`, -9.000000000000002}, {
       43.94831386170595, -28.292647438225714`, -12.}, {
       44.22662292303187, -27.839681112552, -15.}, {
       44.50493198435779, -27.291350839266045`, -18.000000000000004`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.08374287207704, -29.088726263169676`, -3.1999999999999993`}, {
       43.33240812775182, -28.900388742992604`, -6.399999999999999}, {
       43.58107338342659, -28.607273797392764`, -9.599999999999998}, {
       43.82973863910137, -28.208443268255436`, -12.799999999999997`}, {
       44.078403894776145`, -27.702602543512384`, -15.999999999999996`}, {
       44.327069150450924`, -27.08807902908677, -19.199999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.05207954350768, -29.086241323354017`, -3.4000000000000004`}, {
       43.269081470613095`, -28.88221011347912, -6.800000000000001}, {
       43.4860833977185, -28.560060646236323`, -10.200000000000001`}, {
       43.70308532482392, -28.11862948788368, -13.600000000000001`}, {
       43.92008725192933, -27.556297443571907`, -17.}, {
       44.137089179034746`, -26.870959061754007`, -20.400000000000002`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       43.018375351364604`, -29.08361066902529, -3.6000000000000005`}, {
       43.201673086326934`, -28.862914319383435`, -7.200000000000001}, {
       43.38497082128927, -28.50991095373722, -10.8}, {
       43.56826855625161, -28.02317118102961, -14.400000000000002`}, {
       43.75156629121394, -27.400690061920756`, -18.000000000000004`}, {
       43.93486402617628, -26.639844601344322`, -21.6}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.98260724772591, -29.080835225846243`, -3.7999999999999994`}, {
       43.13013687904956, -28.842498478829555`, -7.599999999999999}, {
       43.2776665103732, -28.456810694026217`, -11.399999999999999`}, {
       43.425196141696844`, -27.922030762014785`, -15.199999999999998`}, {
       43.572725773020494`, -27.235698768972625`, -18.999999999999996`}, {
       43.72025540434414, -26.39457760496471, -22.799999999999997`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.94475039205331, -29.077915991846723`, -3.9999999999999996`}, {
       43.05442316770434, -28.820959496245038`, -7.999999999999999}, {
       43.164095943355385`, -28.400744804062, -11.999999999999998`}, {
       43.273768719006426`, -27.815167862629195`, -15.999999999999998`}, {
       43.38344149465746, -27.061235793488024`, -19.999999999999996`}, {
       43.4931142703085, -26.134987737495436`, -23.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.90477805693456, -29.07485404128164, -4.199999999999998}, {
       42.97447849746685, -28.798294052674663`, -8.399999999999997}, {
       43.04417893799914, -28.341697137244182`, -12.599999999999996`}, {
       43.113879378531436`, -27.702539207767416`, -16.799999999999994`}, {
       43.18357981906373, -26.877206933077787`, -20.999999999999993`}, {
       43.253280259596025`, -25.8608917252526, -25.199999999999992`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.86266152401875, -29.07165052889009, -4.3999999999999995`}, {
       42.89024543163522, -28.774498595093903`, -8.799999999999999}, {
       42.9178293392517, -28.27965041229018, -13.199999999999998`}, {
       42.945413246868185`, -27.584098478531885`, -17.599999999999998`}, {
       42.97299715448466, -26.683511235524193`, -21.999999999999996`}, {
       43.00058106210114, -25.572092642401316`, -26.399999999999995`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.818369969118436`, -29.068306694597354`, -4.599999999999999}, {
       42.801662321834606`, -28.749569324618932`, -9.199999999999998}, {
       42.784954674550775`, -28.214586156892608`, -13.799999999999997`}, {
       42.76824702726694, -27.459796161549036`, -18.399999999999995`}, {
       42.751539379983114`, -26.48004064800523, -22.999999999999996`}, {
       42.73483173269928, -25.268379123084884`, -27.599999999999994`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.771870335307575`, -29.064823868707748`, -4.799999999999999}, {
       42.708663054212884`, -28.723502183494716`, -9.599999999999998}, {
       42.645455773118194`, -28.146484645605682`, -14.399999999999995`}, {
       42.5822484920235, -27.329579383068193`, -19.199999999999996`}, {
       42.51904121092881, -26.26667963090378, -23.999999999999996`}, {
       42.455833929834114`, -24.949524491239004`, -28.79999999999999}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.72312719267533, -29.061203477643076`, -4.999999999999999}, {
       42.61117676894839, -28.696292840725974`, -9.999999999999998}, {
       42.49922634522146, -28.075324831330136`, -14.999999999999998`}, {
       42.38727592149452, -27.193391726211317`, -19.999999999999996`}, {
       42.27532549776758, -26.0433047324167, -24.999999999999996`}, {
       42.163375074040644`, -24.615285798903585`, -29.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.835077616402266`, -29.172883302750307`, 0.}, {
       42.72312719267533, -29.061203477643076`, -4.999999999999999}, {
       42.61117676894839, -28.696292840725974`, -9.999999999999998}, {
       42.49922634522146, -28.075324831330136`, -14.999999999999998`}, {
       42.38727592149452, -27.193391726211317`, -19.999999999999996`}, {
       42.27532549776758, -26.0433047324167, -24.999999999999996`}, {
       42.163375074040644`, -24.615285798903585`, -29.999999999999996`}, {
       42.835077616402266`, -29.172883302750307`, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{42.16337507404064, -24.615285798903585`, -30.}, {
       35.13614589503386, -25.255551047405774`, -30.}, {
       28.108916716027096`, -25.375173939621618`, -30.}, {
       21.081687537020322`, -24.976121750746714`, -30.}, {
       14.05445835801355, -24.05179265566221, -30.}, {
       7.027229179006774, -22.586455817285298`, -30.}, {
       7.105427357601002*^-15, -20.553851381374173`, -30.}}], 
      Line3DBox[{{0., -20.553851381374173`, -30.}, {
       0., -23.27379053088815, -20.}, {
       0., -24.868329805051374`, -10.}, {-3.552713678800501*^-15, \
-25.393920141694565`, 0.}, {-3.552713678800501*^-15, -24.868329805051374`, 
       10.}, {-3.552713678800501*^-15, -23.27379053088815, 
       20.}, {-3.552713678800501*^-15, -20.553851381374173`, 30.}}], 
      Line3DBox[{{0., -20.553851381374173`, 30.}, {
       7.027229179006774, -22.586455817285298`, 30.}, {
       14.054458358013544`, -24.05179265566221, 30.}, {
       21.081687537020315`, -24.976121750746714`, 30.000000000000004`}, {
       28.10891671602709, -25.375173939621618`, 30.000000000000004`}, {
       35.13614589503386, -25.255551047405774`, 30.000000000000004`}, {
       42.16337507404063, -24.615285798903585`, 30.000000000000004`}}], 
      Line3DBox[{}], 
      Line3DBox[{{42.163375074040644`, -24.615285798903585`, 30.}, {
       42.21211821667289, -24.672193217765937`, 29.8}, {
       42.26086135930514, -24.728619111269097`, 29.6}, {
       42.309604501937386`, -24.78456433937903, 29.4}, {
       42.35834764456963, -24.840029752715495`, 29.2}, {
       42.40709078720188, -24.895016192622734`, 29.}, {
       42.45583392983413, -24.94952449123899, 28.8}}], 
      Line3DBox[{{42.45583392983413, -24.94952449123899, 28.8}, {
       42.50233356364498, -25.00385074018503, 28.6}, {
       42.54883319745584, -25.057702399029353`, 28.400000000000002`}, {
       42.5953328312667, -25.111080273907177`, 28.200000000000003`}, {
       42.641832465077556`, -25.163985162060712`, 28.}, {
       42.68833209888841, -25.216417851903657`, 27.8}, {
       42.73483173269927, -25.268379123084884`, 27.6}}], 
      Line3DBox[{{42.73483173269927, -25.268379123084884`, 27.6}, {
       42.77912328759958, -25.320165799270043`, 27.400000000000002`}, {
       42.82341484249989, -25.37148437440382, 27.2}, {
       42.867706397400205`, -25.422335603727007`, 27.}, {
       42.91199795230052, -25.472720234000803`, 26.8}, {
       42.95628950720083, -25.522639003566056`, 26.599999999999998`}, {
       43.00058106210114, -25.572092642401316`, 26.4}}], 
      Line3DBox[{{43.00058106210114, -25.572092642401316`, 26.4}, {
       43.04269759501695, -25.62137856904667, 26.2}, {
       43.084814127932766`, -25.67020246261346, 26.}, {
       43.126930660848586`, -25.718565030119805`, 25.799999999999997`}, {
       43.1690471937644, -25.76646697048193, 25.599999999999998`}, {
       43.21116372668021, -25.81390897456825, 25.4}, {
       43.253280259596025`, -25.8608917252526, 25.2}}], 
      Line3DBox[{{43.253280259596025`, -25.8608917252526, 25.2}, {
       43.29325259471477, -25.907713117627353`, 25.}, {
       43.33322492983352, -25.95407814663463, 24.8}, {
       43.37319726495227, -25.999987473502685`, 24.6}, {
       43.413169600071015`, -26.045441751702768`, 24.4}, {
       43.45314193518976, -26.090441626998683`, 24.2}, {
       43.49311427030851, -26.134987737495436`, 24.}}], 
      Line3DBox[{{43.49311427030851, -26.134987737495436`, 24.}, {
       43.53097112598111, -26.17937835309533, 23.8}, {
       43.56882798165372, -26.223317897504927`, 23.6}, {
       43.60668483732633, -26.266806988378264`, 23.4}, {
       43.64454169299893, -26.30984623592758, 23.2}, {
       43.68239854867153, -26.35243624296851, 23.}, {
       43.72025540434414, -26.39457760496471, 22.8}}], 
      Line3DBox[{{43.72025540434414, -26.39457760496471, 22.8}, {
       43.756023507982825`, -26.436568879485876`, 22.6}, {
       43.79179161162151, -26.478114016297013`, 22.400000000000002`}, {
       43.82755971526021, -26.519213591496452`, 22.200000000000003`}, {
       43.863327818898895`, -26.55986817402841, 22.}, {
       43.89909592253758, -26.600078325724454`, 21.8}, {
       43.93486402617627, -26.639844601344322`, 21.6}}], 
      Line3DBox[{{43.93486402617627, -26.639844601344322`, 21.6}, {
       43.96856821831935, -26.67946577184918, 21.400000000000002`}, {
       44.00227241046243, -26.71864539654804, 21.2}, {
       44.03597660260551, -26.7573840118216, 21.}, {
       44.069680794748585`, -26.795682147159255`, 20.8}, {
       44.10338498689167, -26.833540325196807`, 20.599999999999998`}, {
       44.137089179034746`, -26.870959061754007`, 20.4}}], 
      Line3DBox[{{44.137089179034746`, -26.870959061754007`, 20.4}, {
       44.16875250760411, -26.908237278253395`, 20.2}, {
       44.20041583617347, -26.945078214831284`, 20.}, {
       44.23207916474283, -26.98148236982405, 19.8}, {
       44.26374249331219, -27.017450234916396`, 19.6}, {
       44.29540582188156, -27.052982295175838`, 19.400000000000002`}, {
       44.32706915045092, -27.08807902908677, 19.200000000000003`}}], 
      Line3DBox[{{44.32706915045092, -27.08807902908677, 
       19.200000000000003`}, {44.356712956102065`, -27.123039455610595`, 
       19.000000000000004`}, {44.38635676175321, -27.15756655620578, 18.8}, {
       44.41600056740435, -27.19166079268632, 18.6}, {
       44.4456443730555, -27.225322620432635`, 18.400000000000002`}, {
       44.47528817870665, -27.25855248842332, 18.2}, {
       44.504931984357796`, -27.291350839266045`, 18.}}], 
      Line3DBox[{{44.504931984357796`, -27.291350839266045`, 18.}, {
       44.53257597771236, -27.324016745364645`, 17.8}, {
       44.56021997106693, -27.35625298045393, 17.6}, {
       44.5878639644215, -27.388059971207625`, 17.4}, {
       44.61550795777607, -27.419438138064535`, 17.2}, {
       44.64315195113063, -27.45038789525725, 17.}, {
       44.6707959444852, -27.480909650840232`, 16.8}}], 
      Line3DBox[{{44.6707959444852, -27.480909650840232`, 16.8}, {
       44.69645827594037, -27.511302494344434`, 16.6}, {
       44.72212060739554, -27.541269034297983`, 16.400000000000002`}, {
       44.747782938850705`, -27.570809663487694`, 16.200000000000003`}, {
       44.77344527030588, -27.59992476864558, 16.}, {
       44.79910760176105, -27.628614730474894`, 15.8}, {
       44.82476993321622, -27.656879923675675`, 15.600000000000001`}}], 
      Line3DBox[{{44.82476993321622, -27.656879923675675`, 
       15.600000000000001`}, {44.84846725594136, -27.685019425443315`, 
       15.400000000000002`}, {44.8721645786665, -27.712735714158867`, 
       15.200000000000001`}, {44.89586190139164, -27.74002914985583, 15.}, {
       44.91955922411679, -27.766900086675918`, 14.8}, {
       44.94325654684193, -27.79334887289251, 14.6}, {
       44.96695386956707, -27.81937585093381, 14.4}}], 
      Line3DBox[{{44.96695386956707, -27.81937585093381, 14.4}, {
       44.9887013962243, -27.845280062222855`, 14.2}, {
       45.01044892288153, -27.8707638834681, 14.}, {
       45.03219644953876, -27.895827642971966`, 13.8}, {
       45.05394397619598, -27.920471663291906`, 13.6}, {
       45.07569150285321, -27.94469626126164, 13.399999999999999`}, {
       45.09743902951044, -27.968501748011917`, 13.2}}], 
      Line3DBox[{{45.09743902951044, -27.968501748011917`, 13.2}, {
       45.117250583170346`, -27.992187111042867`, 13.}, {
       45.13706213683025, -28.015454648059148`, 12.799999999999999`}, {
       45.15687369049016, -28.038304656550068`, 12.6}, {
       45.176685244150065`, -28.06073742839179, 12.4}, {
       45.19649679780997, -28.082753249866258`, 12.2}, {
       45.21630835146988, -28.10435240167986, 12.}}], 
      Line3DBox[{{45.21630835146988, -28.10435240167986, 12.}, {
       45.23419641113603, -28.125833803881278`, 11.8}, {
       45.25208447080218, -28.146899692733626`, 11.6}, {
       45.26997253046834, -28.167550335733367`, 11.4}, {
       45.28786059013449, -28.187785994881324`, 11.200000000000001`}, {
       45.30574864980064, -28.207606926699555`, 11.}, {
       45.3236367094668, -28.227013382247776`, 10.8}}], 
      Line3DBox[{{45.3236367094668, -28.227013382247776`, 10.8}, {
       45.339612450570755`, -28.246304204617772`, 10.600000000000001`}, {
       45.35558819167472, -28.26518158171642, 10.4}, {
       45.371563932778685`, -28.283645751775495`, 10.200000000000001`}, {
       45.38753967388264, -28.30169694763508, 10.000000000000002`}, {
       45.4035154149866, -28.319335396758404`, 9.8}, {
       45.419491156090565`, -28.336561321246364`, 9.600000000000001}}], 
      Line3DBox[{{45.419491156090565`, -28.336561321246364`, 
       9.600000000000001}, {45.43356448627303, -28.353673481207863`, 
       9.400000000000002}, {45.4476378164555, -28.370374025372158`, 
       9.200000000000001}, {45.46171114663797, -28.38666316334715, 
       9.000000000000002}, {45.47578447682043, -28.40254109944013, 
       8.800000000000002}, {45.48985780700289, -28.418008032670684`, 
       8.600000000000001}, {45.50393113718536, -28.43306415678329, 
       8.400000000000002}}], 
      Line3DBox[{{45.50393113718536, -28.43306415678329, 8.400000000000002}, {
       45.51611072763725, -28.448008145861948`, 8.200000000000001}, {
       45.528290318089134`, -28.46254211524878, 8.000000000000002}, {
       45.54046990854101, -28.476666246485678`, 7.800000000000001}, {
       45.5526494989929, -28.490380715892627`, 7.6000000000000005`}, {
       45.564829089444785`, -28.503685694578834`, 7.3999999999999995`}, {
       45.57700867989667, -28.51658134845333, 7.199999999999999}}], 
      Line3DBox[{{45.57700867989667, -28.51658134845333, 7.199999999999999}, {
       45.58730199249601, -28.529366265061952`, 6.999999999999999}, {
       45.59759530509534, -28.54174252923717, 6.8}, {
       45.60788861769467, -28.553710294933282`, 6.6}, {
       45.61818193029401, -28.565269710949607`, 6.4}, {
       45.628475242893344`, -28.576420920939654`, 6.2}, {
       45.638768555492675`, -28.587164063420204`, 6.}}], 
      Line3DBox[{{45.638768555492675`, -28.587164063420204`, 6.}, {
       45.64718186593872, -28.59779764099318, 5.8}, {
       45.655595176384764`, -28.60802370838367, 5.6000000000000005`}, {
       45.66400848683081, -28.617842392360686`, 5.4}, {
       45.67242179727685, -28.627253814593473`, 5.2}, {
       45.68083510772289, -28.6362580916592, 5.000000000000001}, {
       45.68924841816894, -28.644855335050195`, 4.800000000000001}}], 
      Line3DBox[{{45.68924841816894, -28.644855335050195`, 
       4.800000000000001}, {45.6957868352828, -28.653343965733683`, 
       4.6000000000000005`}, {45.70232525239666, -28.661426006661515`, 
       4.400000000000001}, {45.70886366951052, -28.66910155774569, 
       4.200000000000001}, {45.71540208662439, -28.676370713842743`, 
       4.000000000000001}, {45.72194050373825, -28.683233564759703`, 
       3.800000000000001}, {45.72847892085211, -28.68969019525956, 
       3.6000000000000014`}}], 
      Line3DBox[{{45.72847892085211, -28.68969019525956, 
       3.6000000000000014`}, {45.73314640218376, -28.696038949328937`, 
       3.4000000000000017`}, {45.73781388351542, -28.701981814793513`, 
       3.2000000000000015`}, {45.74248136484707, -28.70751886496511, 
       3.0000000000000018`}, {45.747148846178725`, -28.712650168133422`, 
       2.8000000000000016`}, {45.75181632751038, -28.717375787570333`, 
       2.600000000000002}, {45.756483808842034`, -28.721695781533754`, 
       2.400000000000002}}], 
      Line3DBox[{{45.756483808842034`, -28.721695781533754`, 
       2.400000000000002}, {45.759283172695596`, -28.725908422676937`, 
       2.2000000000000024`}, {45.76208253654916, -28.72971565902037, 
       2.000000000000002}, {45.76488190040273, -28.73311753746235, 
       1.8000000000000025`}, {45.76768126425629, -28.73611409990177, 
       1.6000000000000028`}, {45.77048062810985, -28.73870538324074, 
       1.4000000000000026`}, {45.77327999196341, -28.740891419386756`, 
       1.2000000000000028`}}], 
      Line3DBox[{{45.77327999196341, -28.740891419386756`, 
       1.2000000000000028`}, {45.77421292592642, -28.74297041596195, 
       1.0000000000000024`}, {45.77514585988943, -28.744644275521154`, 
       0.8000000000000019}, {45.776078793852435`, -28.745913018667054`, 
       0.6000000000000014}, {45.77701172781545, -28.74677666101499, 
       0.400000000000001}, {45.777944661778456`, -28.747235213193974`, 
       0.20000000000000062`}, {45.77887759574146, -28.747288680847376`, 0.}}],
       Line3DBox[{{45.77887759574146, -28.747288680847376`, 0.}, {
       45.777944661778456`, -28.747235213193974`, -0.19999999999999987`}, {
       45.77701172781545, -28.74677666101499, -0.39999999999999974`}, {
       45.77607879385244, -28.745913018667054`, -0.5999999999999996}, {
       45.775145859889435`, -28.744644275521154`, -0.7999999999999995}, {
       45.77421292592643, -28.74297041596195, -0.9999999999999993}, {
       45.77327999196342, -28.740891419386756`, -1.1999999999999993`}}], 
      Line3DBox[{{
       45.77327999196342, -28.740891419386756`, -1.1999999999999993`}, {
       45.77048062810985, -28.73870538324074, -1.3999999999999992`}, {
       45.76768126425629, -28.73611409990177, -1.599999999999999}, {
       45.76488190040273, -28.73311753746235, -1.799999999999999}, {
       45.76208253654916, -28.72971565902037, -1.9999999999999987`}, {
       45.75928317269559, -28.725908422676937`, -2.199999999999999}, {
       45.75648380884203, -28.721695781533754`, -2.3999999999999986`}}], 
      Line3DBox[{{
       45.75648380884203, -28.721695781533754`, -2.3999999999999986`}, {
       45.751816327510376`, -28.717375787570333`, -2.599999999999999}, {
       45.747148846178725`, -28.712650168133422`, -2.7999999999999994`}, {
       45.742481364847066`, -28.70751886496511, -3.}, {
       45.737813883515415`, -28.701981814793513`, -3.2000000000000006`}, {
       45.73314640218376, -28.696038949328937`, -3.4000000000000012`}, {
       45.72847892085211, -28.68969019525956, -3.6000000000000014`}}], 
      Line3DBox[{{
       45.72847892085211, -28.68969019525956, -3.6000000000000014`}, {
       45.72194050373825, -28.683233564759703`, -3.8000000000000007`}, {
       45.71540208662439, -28.676370713842743`, -4.}, {
       45.70886366951053, -28.66910155774569, -4.199999999999999}, {
       45.70232525239667, -28.661426006661515`, -4.399999999999999}, {
       45.6957868352828, -28.653343965733683`, -4.599999999999998}, {
       45.689248418168944`, -28.644855335050195`, -4.799999999999997}}], 
      Line3DBox[{{
       45.689248418168944`, -28.644855335050195`, -4.799999999999997}, {
       45.6808351077229, -28.6362580916592, -4.999999999999997}, {
       45.672421797276854`, -28.62725381459346, -5.199999999999998}, {
       45.66400848683081, -28.617842392360686`, -5.399999999999999}, {
       45.65559517638477, -28.60802370838367, -5.599999999999999}, {
       45.64718186593873, -28.59779764099318, -5.8}, {
       45.63876855549268, -28.587164063420204`, -6.}}], 
      Line3DBox[{{45.63876855549268, -28.587164063420204`, -6.}, {
       45.628475242893344`, -28.576420920939654`, -6.199999999999999}, {
       45.61818193029401, -28.565269710949607`, -6.399999999999999}, {
       45.60788861769467, -28.553710294933282`, -6.599999999999998}, {
       45.59759530509534, -28.54174252923717, -6.799999999999997}, {
       45.587301992496, -28.529366265061952`, -6.9999999999999964`}, {
       45.577008679896664`, -28.51658134845333, -7.199999999999996}}], 
      Line3DBox[{{
       45.577008679896664`, -28.51658134845333, -7.199999999999996}, {
       45.56482908944478, -28.503685694578834`, -7.399999999999996}, {
       45.5526494989929, -28.490380715892627`, -7.599999999999997}, {
       45.54046990854101, -28.476666246485678`, -7.799999999999997}, {
       45.52829031808913, -28.46254211524878, -7.999999999999997}, {
       45.51611072763725, -28.448008145861948`, -8.199999999999998}, {
       45.50393113718536, -28.43306415678329, -8.399999999999999}}], 
      Line3DBox[{{
       45.50393113718536, -28.43306415678329, -8.399999999999999}, {
       45.4898578070029, -28.418008032670684`, -8.6}, {
       45.47578447682043, -28.40254109944013, -8.799999999999999}, {
       45.46171114663797, -28.38666316334715, -9.}, {
       45.447637816455504`, -28.370374025372158`, -9.200000000000001}, {
       45.433564486273035`, -28.353673481207863`, -9.4}, {
       45.41949115609057, -28.33656132124635, -9.600000000000001}}], 
      Line3DBox[{{
       45.41949115609057, -28.33656132124635, -9.600000000000001}, {
       45.40351541498661, -28.319335396758404`, -9.8}, {
       45.38753967388264, -28.30169694763508, -10.}, {
       45.371563932778685`, -28.283645751775495`, -10.2}, {
       45.35558819167472, -28.26518158171642, -10.399999999999999`}, {
       45.339612450570755`, -28.246304204617772`, -10.599999999999998`}, {
       45.32363670946679, -28.227013382247776`, -10.799999999999997`}}], 
      Line3DBox[{{
       45.32363670946679, -28.227013382247776`, -10.799999999999997`}, {
       45.305748649800634`, -28.207606926699555`, -10.999999999999998`}, {
       45.287860590134486`, -28.187785994881324`, -11.199999999999998`}, {
       45.26997253046834, -28.167550335733367`, -11.399999999999999`}, {
       45.25208447080218, -28.146899692733626`, -11.6}, {
       45.234196411136026`, -28.125833803881278`, -11.799999999999999`}, {
       45.21630835146988, -28.10435240167986, -12.}}], 
      Line3DBox[{{45.21630835146988, -28.10435240167986, -12.}, {
       45.19649679780997, -28.082753249866258`, -12.2}, {
       45.17668524415006, -28.06073742839179, -12.399999999999999`}, {
       45.15687369049015, -28.038304656550068`, -12.599999999999998`}, {
       45.137062136830245`, -28.015454648059148`, -12.799999999999997`}, {
       45.11725058317033, -27.992187111042867`, -12.999999999999996`}, {
       45.097439029510426`, -27.96850174801193, -13.199999999999996`}}], 
      Line3DBox[{{
       45.097439029510426`, -27.96850174801193, -13.199999999999996`}, {
       45.0756915028532, -27.94469626126164, -13.399999999999997`}, {
       45.053943976195974`, -27.92047166329192, -13.599999999999996`}, {
       45.032196449538745`, -27.895827642971966`, -13.799999999999997`}, {
       45.01044892288152, -27.870763883468115`, -13.999999999999998`}, {
       44.9887013962243, -27.845280062222855`, -14.199999999999998`}, {
       44.96695386956707, -27.81937585093381, -14.399999999999999`}}], 
      Line3DBox[{{
       44.96695386956707, -27.81937585093381, -14.399999999999999`}, {
       44.94325654684193, -27.79334887289251, -14.6}, {
       44.91955922411679, -27.766900086675918`, -14.799999999999999`}, {
       44.89586190139164, -27.74002914985583, -15.}, {
       44.8721645786665, -27.712735714158867`, -15.200000000000001`}, {
       44.84846725594136, -27.685019425443315`, -15.4}, {
       44.82476993321622, -27.656879923675675`, -15.600000000000001`}}], 
      Line3DBox[{{
       44.82476993321622, -27.656879923675675`, -15.600000000000001`}, {
       44.79910760176105, -27.628614730474894`, -15.8}, {
       44.77344527030588, -27.59992476864558, -16.}, {
       44.747782938850705`, -27.570809663487694`, -16.2}, {
       44.72212060739554, -27.541269034297997`, -16.4}, {
       44.69645827594037, -27.511302494344434`, -16.599999999999998`}, {
       44.6707959444852, -27.480909650840232`, -16.799999999999997`}}], 
      Line3DBox[{{
       44.6707959444852, -27.480909650840232`, -16.799999999999997`}, {
       44.64315195113063, -27.45038789525725, -16.999999999999996`}, {
       44.61550795777606, -27.41943813806455, -17.2}, {
       44.587863964421494`, -27.388059971207625`, -17.4}, {
       44.56021997106693, -27.35625298045393, -17.599999999999998`}, {
       44.532575977712355`, -27.324016745364645`, -17.8}, {
       44.50493198435779, -27.291350839266045`, -18.}}], 
      Line3DBox[{{44.50493198435779, -27.291350839266045`, -18.}, {
       44.47528817870664, -27.25855248842332, -18.2}, {
       44.4456443730555, -27.225322620432635`, -18.4}, {
       44.41600056740435, -27.19166079268632, -18.599999999999998`}, {
       44.386356761753206`, -27.15756655620578, -18.799999999999997`}, {
       44.356712956102065`, -27.123039455610595`, -18.999999999999996`}, {
       44.32706915045092, -27.08807902908677, -19.199999999999996`}}], 
      Line3DBox[{{
       44.32706915045092, -27.08807902908677, -19.199999999999996`}, {
       44.29540582188156, -27.052982295175838`, -19.399999999999995`}, {
       44.26374249331219, -27.017450234916396`, -19.599999999999998`}, {
       44.23207916474283, -26.98148236982405, -19.799999999999997`}, {
       44.20041583617347, -26.945078214831284`, -19.999999999999996`}, {
       44.16875250760411, -26.908237278253395`, -20.2}, {
       44.137089179034746`, -26.870959061754007`, -20.4}}], 
      Line3DBox[{{44.137089179034746`, -26.870959061754007`, -20.4}, {
       44.10338498689167, -26.833540325196807`, -20.599999999999998`}, {
       44.069680794748585`, -26.795682147159255`, -20.8}, {
       44.03597660260551, -26.7573840118216, -21.}, {
       44.00227241046243, -26.71864539654804, -21.2}, {
       43.96856821831935, -26.67946577184918, -21.400000000000002`}, {
       43.93486402617627, -26.639844601344322`, -21.6}}], 
      Line3DBox[{{43.93486402617627, -26.639844601344322`, -21.6}, {
       43.89909592253758, -26.600078325724454`, -21.8}, {
       43.863327818898895`, -26.55986817402841, -22.}, {
       43.82755971526021, -26.519213591496452`, -22.2}, {
       43.79179161162151, -26.478114016297013`, -22.4}, {
       43.756023507982825`, -26.436568879485876`, -22.599999999999998`}, {
       43.72025540434414, -26.39457760496471, -22.799999999999997`}}], 
      Line3DBox[{{
       43.72025540434414, -26.39457760496471, -22.799999999999997`}, {
       43.68239854867153, -26.35243624296851, -22.999999999999996`}, {
       43.64454169299893, -26.30984623592758, -23.2}, {
       43.60668483732632, -26.266806988378264`, -23.4}, {
       43.56882798165371, -26.223317897504927`, -23.599999999999998`}, {
       43.53097112598111, -26.179378353095345`, -23.8}, {
       43.4931142703085, -26.134987737495436`, -24.}}], 
      Line3DBox[{{43.4931142703085, -26.134987737495436`, -24.}, {
       43.453141935189755`, -26.090441626998683`, -24.2}, {
       43.41316960007101, -26.045441751702768`, -24.4}, {
       43.37319726495227, -25.999987473502685`, -24.599999999999998`}, {
       43.33322492983352, -25.95407814663463, -24.799999999999997`}, {
       43.29325259471477, -25.907713117627353`, -24.999999999999996`}, {
       43.253280259596025`, -25.8608917252526, -25.199999999999996`}}], 
      Line3DBox[{{
       43.253280259596025`, -25.8608917252526, -25.199999999999996`}, {
       43.21116372668021, -25.81390897456825, -25.399999999999995`}, {
       43.1690471937644, -25.76646697048193, -25.599999999999998`}, {
       43.126930660848586`, -25.718565030119805`, -25.799999999999997`}, {
       43.084814127932766`, -25.67020246261346, -25.999999999999996`}, {
       43.04269759501695, -25.62137856904667, -26.2}, {
       43.00058106210114, -25.572092642401316`, -26.4}}], 
      Line3DBox[{{43.00058106210114, -25.572092642401316`, -26.4}, {
       42.95628950720083, -25.522639003566056`, -26.599999999999998`}, {
       42.91199795230052, -25.472720234000803`, -26.799999999999997`}, {
       42.86770639740021, -25.422335603727007`, -26.999999999999996`}, {
       42.8234148424999, -25.37148437440382, -27.199999999999996`}, {
       42.77912328759959, -25.320165799270043`, -27.399999999999995`}, {
       42.73483173269928, -25.268379123084884`, -27.599999999999994`}}], 
      Line3DBox[{{
       42.73483173269928, -25.268379123084884`, -27.599999999999994`}, {
       42.68833209888842, -25.216417851903657`, -27.799999999999994`}, {
       42.641832465077556`, -25.163985162060712`, -27.999999999999996`}, {
       42.5953328312667, -25.111080273907177`, -28.199999999999996`}, {
       42.54883319745584, -25.057702399029353`, -28.399999999999995`}, {
       42.50233356364498, -25.00385074018503, -28.599999999999998`}, {
       42.45583392983412, -24.94952449123899, -28.799999999999997`}}], 
      Line3DBox[{{
       42.45583392983412, -24.94952449123899, -28.799999999999997`}, {
       42.407090787201874`, -24.895016192622734`, -28.999999999999996`}, {
       42.358347644569626`, -24.84002975271551, -29.2}, {
       42.30960450193738, -24.78456433937903, -29.4}, {
       42.26086135930513, -24.728619111269097`, -29.599999999999998`}, {
       42.212118216672884`, -24.672193217765937`, -29.8}, {
       42.16337507404064, -24.615285798903585`, -30.}}], Line3DBox[{}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[{{46.78177891038993, -25.159066536044104`, 
       0.5555555555555566}, {
       48.61290833551179, -15.965888780036753`, -4.537037037037036}, {
       49.30458508337442, -6.772711024029402, -9.629629629629628}, {
       48.88072367068767, 2.420466731977946, -14.72222222222222}, {
       47.32675056510047, 11.613644487985301`, -19.814814814814813`}, {
       44.58698221398292, 20.806822243992652`, -24.907407407407405`}, {
       40.55385138137417, 29.999999999999996`, -29.999999999999996`}, {
       46.78177891038993, -25.159066536044104`, 0.5555555555555566}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {48.56594965366483, -15.965888780036753`, 
        5.462962962962963}, {49.229964243500234`, -6.772711024029402, 
        10.37037037037037}, {48.79641110370471, 2.420466731977946, 
        15.277777777777777`}, {47.250612135587446`, 11.613644487985301`, 
        20.185185185185183`}, {44.53802380571037, 20.806822243992645`, 
        25.092592592592588`}, {40.55385138137417, 29.999999999999996`, 
        29.999999999999996`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.652622993187705`, -25.068436413187353`, 
        5.462962962962963}, {46.27338475042863, -24.977806290330598`, 
        10.37037037037037}, {45.64108933184502, -24.887176167473847`, 
        15.277777777777777`}, {44.75067072742527, -24.79654604461709, 
        20.185185185185183`}, {43.59476222230107, -24.70591592176034, 
        25.092592592592588`}, {42.163375074040644`, -24.61528579890359, 
        29.999999999999996`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.652622993187705`, -25.068436413187353`, 
        5.462962962962963}, {46.27338475042863, -24.9778062903306, 
        10.37037037037037}, {45.64108933184502, -24.887176167473854`, 
        15.277777777777777`}, {44.75067072742527, -24.796546044617102`, 
        20.185185185185183`}, {43.59476222230107, -24.70591592176035, 
        25.092592592592588`}, {42.163375074040644`, -24.6152857989036, 
        29.999999999999996`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.649255901454424`, -25.12414286190992, 
        5.2629629629629635`}, {46.286669872965206`, -25.089219187775736`, 
        9.970370370370372}, {45.69140565286568, -25.054295513641552`, 
        14.677777777777779`}, {44.85908300259149, -25.019371839507368`, 
        19.385185185185186`}, {43.78339049127587, -24.984448165373184`, 
        24.092592592592595`}, {42.455833929834114`, -24.949524491239004`, 
        28.8}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.646110687033485`, -25.177285300550903`, 
        5.062962962962963}, {46.29950459831866, -25.1955040650577, 
        9.570370370370371}, {45.73966969816328, -25.213722829564496`, 
        14.07777777777778}, {44.96283491464304, -25.231941594071294`, 
        18.585185185185185`}, {43.96361832761991, -25.250160358578093`, 
        23.09259259259259}, {42.73483173269926, -25.26837912308489, 27.6}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.64318103138632, -25.227904220436972`, 
        4.862962962962962}, {46.31188481319769, -25.29674190482984, 
        9.17037037037037}, {45.78589081005431, -25.365579589222705`, 
        13.477777777777776`}, {45.061967189198626`, -25.434417273615573`, 
        17.78518518518518}, {44.13554769100003, -25.50325495800844, 
        22.09259259259259}, {43.00058106210115, -25.57209264240131, 
        26.399999999999995`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.64046103839594, -25.276037400912188`, 
        4.662962962962963}, {46.32380668755023, -25.39300826578027, 
        8.77037037037037}, {45.83007776403011, -25.509979130648354`, 
        12.877777777777778`}, {45.1565180014079, -25.626949995516437`, 
        16.985185185185184`}, {44.29927399750842, -25.74392086038452, 
        21.09259259259259}, {43.25328025959601, -25.860891725252603`, 25.2}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.637945209462416`, -25.321720069619328`, 
        4.462962962962963}, {46.33526665720932, -25.484373603194552`, 
        8.37037037037037}, {45.87223879666783, -25.647027136769776`, 
        12.277777777777777`}, {45.24652310827982, -25.809680670345, 
        16.185185185185183`}, {44.45488647448563, -25.972334203920223`, 
        20.092592592592588`}, {43.493114270308496`, -26.134987737495447`, 
        23.999999999999996`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.63562842096563, -25.364985047530876`, 
        4.2629629629629635`}, {46.34626140818615, -25.570903559017648`, 
        7.970370370370371}, {45.91238163093645, -25.77682207050442, 
        11.677777777777779`}, {45.33201596875263, -25.98274058199119, 
        15.385185185185186`}, {44.60246848248133, -26.188659093477966`, 
        19.09259259259259}, {43.72025540434413, -26.394577604964738`, 22.8}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.63350590385811, -25.405862880260806`, 
        4.062962962962964}, {46.3567878624451, -25.652659224477507`, 
        7.570370370370371}, {45.95051349915438, -25.89945556869421, 
        11.07777777777778}, {45.41302785270183, -26.146251912910913`, 
        14.585185185185187`}, {44.74209780755014, -26.393048257127614`, 
        18.092592592592595`}, {43.934864026176285`, -26.639844601344315`, 
        21.6}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.63157322517981, -25.444381956995752`, 
        3.862962962962963}, {46.36684316501689, -25.729697377947403`, 
        7.170370370370369}, {45.98664116382355, -26.01501279889905, 
        10.477777777777778`}, {45.4895879399334, -26.3003282198507, 
        13.785185185185183`}, {44.87384692668425, -26.58564364080235, 
        17.092592592592588`}, {44.137089179034746`, -26.870959061754, 20.4}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62982627131362, -25.480568618217884`, 
        3.662962962962964}, {46.37642467232327, -25.80207070039166, 
        6.770370370370371}, {46.020770936536664`, -26.12357278256544, 
        9.877777777777778}, {45.5617234100808, -26.445074864739215`, 
        12.985185185185186`}, {44.99778324884123, -26.766576946912995`, 
        16.09259259259259}, {44.327069150450924`, -27.08807902908677, 19.2}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62826123282146, -25.514447253247763`, 
        3.4629629629629632`}, {46.38552994160253, -25.869827970451418`, 
        6.370370370370369}, {46.0529086951307, -26.225208687655076`, 
        9.277777777777779}, {45.629459524212805`, -26.580589404858735`, 
        12.185185185185183`}, {45.11396933372815, -26.935970122062393`, 
        15.09259259259259}, {44.504931984357796`, -27.29135083926605, 18.}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.6268745907211, -25.546040388510125`, 
        3.2629629629629635`}, {46.394156721338305`, -25.933014240976146`, 
        5.97037037037037}, {46.08305989923805, -26.319988093442166`, 
        8.677777777777779}, {45.69281969886168, -26.70696194590819, 
        11.385185185185184`}, {45.22246309024348, -27.09393579837421, 
        14.092592592592592`}, {44.67079594448521, -27.480909650840232`, 
        16.8}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62566310408076, -25.575368767316036`, 
        3.0629629629629638`}, {46.40230294260641, -25.991670998587963`, 
        5.57037037037037}, {46.11122960436954, -26.407973229859895`, 
        8.07777777777778}, {45.7518255730963, -26.824275461131823`, 
        10.585185185185185`}, {45.32331795625089, -27.240577692403754`, 
        13.092592592592593`}, {44.82476993321622, -27.65687992367568, 
        15.600000000000001`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62462379882288, -25.602451421859055`, 
        2.862962962962964}, {46.409966711264076`, -26.045836307674, 
        5.170370370370371}, {46.1374224746461, -26.48922119348895, 
        7.477777777777779}, {45.8064970691898, -26.9326060793039, 
        9.785185185185187}, {45.41658306116031, -27.37599096511885, 
        12.092592592592593`}, {44.96695386956708, -27.819375850933795`, 
        14.400000000000002`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.623753957642194`, -25.627305738038743`, 
        2.6629629629629634`}, {46.417146300915746`, -26.09554494003338, 
        4.77037037037037}, {46.16164279428283, -26.56378414202802, 
        6.877777777777776}, {45.856852447366236`, -27.032023344022654`, 
        8.985185185185184}, {45.502303372614406`, -27.500262546017293`, 
        11.092592592592592`}, {45.09743902951044, -27.96850174801193, 
        13.199999999999998`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62305111095421, -25.649947513650062`, 
        2.4629629629629632`}, {46.423840146597186`, -26.140828491256023`, 
        4.37037037037037}, {46.18389447791644, -26.63170946886198, 
        6.277777777777776}, {45.90290835505142, -27.122590446467942`, 
        8.185185185185183}, {45.580519828424244`, -27.6134714240739, 
        10.092592592592592`}, {45.21630835146988, -28.10435240167986, 
        11.999999999999996`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62251302880115, -25.670391010411382`, 
        2.262962962962964}, {46.43004683912679, -26.18171548477866, 
        3.970370370370371}, {46.20418107985542, -26.693039959145935`, 
        5.677777777777778}, {45.944679871002336`, -27.204364433513213`, 
        7.385185185185185}, {45.651269454757994`, -27.71568890788049, 
        9.092592592592593}, {45.3236367094668, -28.22701338224777, 10.8}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.6221377136507, -25.68864900024448, 
        2.0629629629629638`}, {46.43576512007968, -26.21823146444486, 
        3.5703703703703713`}, {46.22250580232297, -26.74781392864524, 
        5.077777777777778}, {45.982180544642716`, -27.277396392845617`, 
        6.5851851851851855`}, {45.71458547146361, -27.806978857045994`, 
        8.092592592592593}, {45.41949115609056, -28.33656132124637, 
        9.600000000000001}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62192339403194, -25.7047328061673, 
        1.862962962962964}, {46.44099387734535, -26.250399076290496`, 
        3.170370370370372}, {46.23887150275385, -26.79606534641369, 
        4.47777777777778}, {46.01542243089065, -27.34173161653689, 
        5.7851851851851865`}, {45.77049738529401, -27.887397886660086`, 
        7.092592592592594}, {45.503931137185376`, -28.43306415678328, 
        8.400000000000002}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62186851895963, -25.71865233811231, 
        1.6629629629629634`}, {46.44573214123544, -26.278238140180516`, 
        2.7703703703703706`}, {46.25328070019762, -26.83782394224872, 
        3.8777777777777778`}, {46.04441612072728, -27.397409744316924`, 
        4.985185185185184}, {45.819031071703535`, -27.95699554638513, 
        6.092592592592592}, {45.577008679896664`, -28.516581348453336`, 
        7.199999999999998}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62197175310531, -25.730416123940124`, 
        1.4629629629629637`}, {46.44997908111205, -26.30176571183614, 
        2.370370370370371}, {46.265735580874306`, -26.873115299732156`, 
        3.2777777777777786`}, {46.069170767720536`, -27.444464887628175`, 
        4.185185185185185}, {45.860208845792116`, -28.015814475524195`, 
        5.092592592592593}, {45.63876855549269, -28.58716406342021, 6.}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62223197267893, -25.740031335878456`, 
        1.262962962962964}, {46.45373400251209, -26.320996135712807`, 
        1.9703703703703717`}, {46.27623800292123, -26.90196093554716, 
        2.6777777777777794`}, {46.089694110687574`, -27.482925735381514`, 
        3.3851851851851866`}, {45.894049522889986`, -28.06389053521586, 
        4.0925925925925934`}, {45.68924841816893, -28.644855335050217`, 
        4.800000000000002}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.6226482619916, -25.747503812580014`, 
        1.0629629629629642`}, {46.4569963447467, -26.335941089115924`, 
        1.5703703703703717`}, {46.28478950036393, -26.924378365651833`, 
        2.0777777777777793`}, {46.10599249264996, -27.512815642187743`, 
        2.585185185185187}, {45.92056846919833, -28.101252918723652`, 
        3.0925925925925943`}, {45.72847892085211, -28.689690195259566`, 
        3.600000000000002}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62321991067408, -25.752838076959048`, 
        0.8629629629629642}, {46.459765678958135`, -26.34660961787399, 
        1.1703703703703718`}, {46.29139128633814, -26.94038115878893, 
        1.4777777777777792`}, {46.118070876209245`, -27.534152699703874`, 
        1.785185185185187}, {45.939777642828815`, -28.127924240618817`, 
        2.0925925925925943`}, {45.756483808842034`, -28.72169578153376, 
        2.400000000000002}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62394641153152, -25.756037349934548`, 
        0.6629629629629644}, {46.462041706620695`, -26.353008163824992`, 
        0.7703703703703723}, {46.29604425558475, -26.949978977715435`, 
        0.8777777777777801}, {46.1259328554456, -27.546949791605883`, 
        0.9851851851851878}, {45.95168562551744, -28.143920605496326`, 
        1.0925925925925957`}, {45.773279991963406`, -28.74089141938677, 
        1.2000000000000037`}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.624827459019, -25.757103560177985`, 
        0.46296296296296385`}, {46.4638242584748, -26.355140584311865`, 
        0.3703703703703711}, {46.298748986234244`, -26.953177608445742`, 
        0.27777777777777846`}, {46.12958066441733, -27.551214632579622`, 
        0.18518518518518573`}, {45.95629764522394, -28.149251656713503`, 
        0.092592592592593}, {45.77887759574146, -28.747288680847383`, 
        3.3306690738754696`*^-16}, {46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62586294832707, -25.756037349934548`, 
        0.262962962962964}, {
        46.46511329388683, -26.353008163824992`, -0.029629629629628562`}, {
        46.29950574089257, -26.949978977715435`, -0.3222222222222212}, {
        46.1290151823175, -27.546949791605876`, -0.6148148148148137}, {
        45.95361558976556, -28.14392060549632, -0.9074074074074062}, {
        45.773279991963406`, -28.740891419386763`, -1.1999999999999988`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {46.62705297507124, -25.752838076959048`, 
        0.06296296296296439}, {
        46.46590890063024, -26.34660961787399, -0.4296296296296278}, {
        46.29831446703524, -26.940381158788934`, -0.92222222222222}, {
        46.12423593532054, -27.534152699703874`, -1.4148148148148123`}, {
        45.94363801157519, -28.127924240618817`, -1.9074074074074043`}, {
        45.756483808842034`, -28.72169578153376, -2.3999999999999964`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.628397835582774`, -25.747503812580014`, -0.1370370370370364}, {
        46.466211295086396`, -26.335941089115924`, -0.8296296296296294}, {
        46.29517479671239, -26.92437836565183, -1.5222222222222226`}, {
        46.11524109513053, -27.51281564218774, -2.2148148148148152`}, {
        45.92636012361399, -28.10125291872365, -2.907407407407408}, {
        45.72847892085211, -28.68969019525956, -3.600000000000002}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.62989802780328, -25.740031335878456`, -0.3370370370370359}, {
        46.46602082286658, -26.32099613571281, -1.2296296296296285`}, {
        46.29008604556235, -26.901960935547162`, -2.122222222222221}, {
        46.10202747422073, -27.482925735381517`, -3.0148148148148133`}, {
        45.901773786411056`, -28.06389053521587, -3.907407407407405}, {
        45.689248418168916`, -28.644855335050224`, -4.799999999999999}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.631554252789144`, -25.730416123940124`, -0.5370370370370362}, {
        46.465337959859525`, -26.30176571183614, -1.6296296296296289`}, {
        46.283047211127155`, -26.873115299732156`, -2.722222222222222}, {
        46.084590517732934`, -27.444464887628175`, -3.8148148148148144`}, {
        45.86986748614359, -28.015814475524195`, -4.907407407407408}, {
        45.63876855549269, -28.58716406342021, -6.000000000000001}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.63336741683665, -25.71865233811231, -0.7370370370370353}, {
        46.46416331371195, -26.278238140180516`, -2.029629629629627}, {
        46.27405697045822, -26.837823942248722`, -3.322222222222219}, {
        46.06292429198152, -27.397409744316928`, -4.614814814814811}, {
        45.83062630361084, -27.956995546385134`, -5.907407407407403}, {
        45.577008679896664`, -28.51658134845334, -7.199999999999995}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.63533863424274, -25.7047328061673, -0.9370370370370359}, {
        46.46249762575252, -26.250399076290496`, -2.4296296296296283`}, {
        46.263113676995886`, -26.796065346413688`, -3.922222222222221}, {
        46.03702146948608, -27.341731616536883`, -5.414814814814814}, {
        45.78403187389431, -27.88739788666008, -6.907407407407406}, {
        45.503931137185376`, -28.433064156783274`, -8.399999999999999}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.63746923072149, -25.68864900024448, -1.1370370370370364`}, {
        46.460341773372946`, -26.21823146444486, -2.8296296296296295`}, {
        46.250215356701474`, -26.747813928645236`, -4.522222222222223}, {
        46.00687331043092, -27.277396392845613`, -6.214814814814816}, {
        45.73006233643159, -27.80697885704599, -7.907407407407409}, {
        45.41949115609056, -28.336561321246368`, -9.600000000000001}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.63976074750073, -25.670391010411382`, -1.3370370370370352`}, {
        46.457696772883395`, -26.18171548477866, -3.229629629629627}, {
        46.23535970341469, -26.69303995914594, -5.122222222222219}, {
        45.972469640425814`, -27.204364433513213`, -7.0148148148148115`}, {
        45.66869227516416, -27.71568890788049, -8.907407407407403}, {
        45.3236367094668, -28.22701338224777, -10.799999999999994`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.642214946128874`, -25.649947513650062`, -1.5370370370370363`}, {
        46.45456378286333, -26.140828491256023`, -3.6296296296296293`}, {
        46.21854407340423, -26.631709468861985`, -5.722222222222222}, {
        45.933798824414936`, -27.122590446467942`, -7.814814814814816}, {
        45.599892648347165`, -27.613471424073904`, -9.907407407407408}, {
        45.21630835146988, -28.10435240167986, -12.}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.64483381402779, -25.62730573803874, -1.7370370370370356`}, {
        46.450944108031976`, -26.095544940033378`, -4.029629629629628}, {
        46.19976547907267, -26.563784142028013`, -6.32222222222222}, {
        45.89084773655232, -27.03202334402265, -8.614814814814812}, {
        45.52363070753201, -27.500262546017286`, -10.907407407407405`}, {
        45.09743902951044, -27.968501748011924`, -13.199999999999996`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.64761957083317, -25.602451421859055`, -1.9370370370370358`}, {
        46.446839203667835`, -26.045836307674, -4.429629629629629}, {
        46.179020581770274`, -26.48922119348895, -6.922222222222222}, {
        45.84360172583138, -26.9326060793039, -9.414814814814813}, {
        45.43986990514891, -27.37599096511885, -11.907407407407405`}, {
        44.96695386956708, -27.819375850933795`, -14.399999999999999`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.65057467557101, -25.575368767316036`, -2.137037037037036}, {
        46.442250680610755`, -25.991670998587963`, -4.829629629629629}, {
        46.15630568366544, -26.407973229859895`, -7.522222222222223}, {
        45.79204457722133, -26.824275461131823`, -10.214814814814813`}, {
        45.348569790025266`, -27.240577692403754`, -12.907407407407407`}, {
        44.82476993321622, -27.65687992367568, -15.600000000000001`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.653701834726064`, -25.546040388510125`, -2.3370370370370352`}, {
        46.437180310885424`, -25.933014240976146`, -5.229629629629628}, {
        46.13161671861086, -26.31998809344217, -8.122222222222218}, {
        45.736158468026844`, -26.70696194590819, -11.01481481481481}, {
        45.24968589007507, -27.09393579837421, -13.907407407407403`}, {
        44.67079594448521, -27.480909650840232`, -16.799999999999994`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.65700401126625, -25.514447253247763`, -2.537037037037036}, {
        46.43163003399064, -25.86982797045142, -5.629629629629629}, {
        46.1049492419361, -26.22520868765508, -8.722222222222221}, {
        45.675923919144594`, -26.58058940485874, -11.814814814814813`}, {
        45.14316958128384, -26.935970122062397`, -14.907407407407407`}, {
        44.504931984357796`, -27.291350839266055`, -18.}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.66048443469636, -25.48056861821788, -2.7370370370370356`}, {
        46.42560196390522, -25.80207070039166, -6.029629629629628}, {
        46.07629841908728, -26.12357278256544, -9.32222222222222}, {
        45.611319740845886`, -26.445074864739215`, -12.614814814814812`}, {
        45.028967941989904`, -26.76657694691299, -15.907407407407401`}, {
        44.327069150450924`, -27.08807902908677, -19.199999999999996`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.66414661222424, -25.444381956995752`, -2.937037037037036}, {
        46.419098396868634`, -25.729697377947403`, -6.429629629629629}, {
        46.04565901302338, -26.01501279889905, -9.92222222222222}, {
        45.54232297266144, -26.3003282198507, -13.414814814814813`}, {
        44.90702359132443, -26.58564364080235, -16.907407407407405`}, {
        44.137089179034746`, -26.870959061754, -20.4}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.66799434113467, -25.40586288026081, -3.1370370370370364`}, {
        46.41212182000204, -25.652659224477514`, -6.82962962962963}, {
        46.013025370266334`, -25.89945556869422, -10.522222222222222`}, {
        45.46890881688721, -26.14625191291092, -14.214814814814815`}, {
        44.777274510517884`, -26.393048257127624`, -17.90740740740741}, {
        43.934864026176285`, -26.63984460134433, -21.6}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.67203172247895, -25.364985047530876`, -3.3370370370370357`}, {
        46.404674920845, -25.570903559017644`, -7.2296296296296285`}, {
        45.978391405488054`, -25.776822070504416`, -11.12222222222222}, {
        45.39105056516448, -25.982740581991184`, -15.014814814814812`}, {
        44.639653845604855`, -26.188659093477956`, -18.907407407407405`}, {
        43.72025540434413, -26.394577604964724`, -22.799999999999997`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.67626317620301, -25.321720069619328`, -3.537037037037036}, {
        46.39676059789291, -25.48437360319455, -7.629629629629629}, {
        45.94175058450118, -25.647027136769772`, -11.72222222222222}, {
        45.30871951751284, -25.809680670344992`, -15.814814814814813`}, {
        44.494089689860374`, -25.972334203920216`, -19.90740740740741}, {
        43.493114270308496`, -26.134987737495436`, -23.999999999999996`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.680693457853835`, -25.276037400912188`, -3.737037037037035}, {
        46.388381972232466`, -25.39300826578027, -8.029629629629627}, {
        45.90309590550275, -25.509979130648354`, -12.32222222222222}, {
        45.2218848931101, -25.626949995516433`, -16.61481481481481}, {
        44.34050484407504, -25.743920860384517`, -20.9074074074074}, {
        43.253280259596025`, -25.8608917252526, -25.199999999999996`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.685327677023764`, -25.227904220436972`, -3.9370370370370353`}, {
        46.379542400385446`, -25.29674190482984, -8.429629629629627}, {
        45.8624198783982, -25.36557958922271, -12.922222222222217`}, {
        45.13051373201614, -25.434417273615573`, -17.41481481481481}, {
        44.178816552517205`, -25.50325495800844, -21.907407407407405`}, {
        43.00058106210115, -25.57209264240131, -26.39999999999999}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.69017131771382, -25.177285300550903`, -4.137037037037036}, {
        46.37024548848689, -25.1955040650577, -8.829629629629627}, {
        45.81971450201017, -25.213722829564496`, -13.52222222222222}, {
        45.03457078692668, -25.231941594071294`, -18.21481481481481}, {
        44.00893621213436, -25.250160358578093`, -22.9074074074074}, {
        42.73483173269926, -25.26837912308489, -27.599999999999998`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.69523026082368, -25.12414286190992, -4.337037037037035}, {
        46.36049510794146, -25.089219187775736`, -9.229629629629626}, {
        45.774971238947884`, -25.05429551364155, -14.122222222222218`}, {
        44.934018403914436`, -25.019371839507365`, -19.01481481481481}, {
        43.83076905220389, -24.98444816537318, -23.9074074074074}, {
        42.45583392983413, -24.949524491238996`, -28.799999999999994`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{46.78177891038993, -25.159066536044104`, 
        0.5555555555555566}, {
        46.70051080900522, -25.068436413187353`, -4.537037037037035}, {
        46.35029541272242, -24.9778062903306, -9.629629629629626}, {
        45.72818098788167, -24.88717616747385, -14.722222222222218`}, {
        44.82881639096725, -24.7965460446171, -19.81481481481481}, {
        43.64421378124938, -24.705915921760347`, -24.9074074074074}, {
        42.163375074040644`, -24.615285798903596`, -29.999999999999993`}, {
        46.78177891038993, -25.159066536044104`, 0.5555555555555566}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{42.163375074040644`, -24.615285798903592`, -30.}, {
        44.124146501313845`, -15.512738165752994`, -30.}, {
        45.17830350103817, -6.410190532602396, -30.}, {45.35591860625709, 
        2.6923571005482003`, -30.}, {44.661925938166775`, 
        11.7949047336988, -30.}, {43.07683108365508, 
        20.8974523668494, -30.}, {40.55385138137417, 
        29.999999999999993`, -30.}}], 
       Line3DBox[{{40.55385138137417, 30., -30.}, {43.27379053088815, 
        30., -20.}, {44.868329805051374`, 30., -10.}, {45.393920141694565`, 
        30.000000000000004`, 0.}, {44.868329805051374`, 30.000000000000004`, 
        10.}, {43.27379053088815, 30.000000000000004`, 20.}, {
        40.55385138137417, 30.000000000000004`, 30.}}], 
       Line3DBox[{{40.55385138137417, 30., 30.}, {43.07683108365508, 
        20.897452366849404`, 30.}, {44.66192593816676, 11.794904733698807`, 
        30.000000000000004`}, {45.35591860625709, 2.692357100548211, 
        30.000000000000004`}, {45.17830350103817, -6.410190532602385, 
        30.000000000000004`}, {44.124146501313845`, -15.512738165752978`, 
        30.000000000000007`}, {42.163375074040644`, -24.615285798903578`, 
        30.000000000000007`}}], Line3DBox[{}], 
       Line3DBox[{{42.163375074040644`, -24.6152857989036, 30.}, {
        42.21335121075238, -24.670992247626167`, 29.8}, {
        42.262833099683135`, -24.726698696348734`, 29.6}, {
        42.3118215356275, -24.7824051450713, 29.4}, {
        42.36031730377631, -24.83811159379387, 29.2}, {
        42.40832117978381, -24.893818042516436`, 29.}, {
        42.455833929834114`, -24.949524491239004`, 28.8}}], 
       Line3DBox[{{42.455833929834114`, -24.949524491239004`, 28.8}, {
        42.50354937186728, -25.002666929879986`, 28.6}, {
        42.550777505585216`, -25.055809368520965`, 28.400000000000002`}, {
        42.597519076623314`, -25.108951807161947`, 28.200000000000003`}, {
        42.643774821438114`, -25.16209424580293, 28.}, {
        42.689545467369044`, -25.21523668444391, 27.8}, {
        42.73483173269926, -25.26837912308489, 27.6}}], 
       Line3DBox[{{42.73483173269926, -25.26837912308489, 27.6}, {
        42.78032301140168, -25.31899804297096, 27.400000000000002`}, {
        42.82533347722439, -25.36961696285703, 27.2}, {
        42.86986382926219, -25.4202358827431, 27.}, {
        42.9139147578197, -25.47085480262917, 26.8}, {
        42.957486944468144`, -25.52147372251524, 26.599999999999998`}, {
        43.00058106210115, -25.57209264240131, 26.4}}], 
       Line3DBox[{{43.00058106210115, -25.57209264240131, 26.4}, {
        43.04388227489656, -25.620225822876524`, 26.2}, {
        43.0867087509009, -25.668359003351743`, 26.}, {
        43.1290611450538, -25.716492183826958`, 25.799999999999997`}, {
        43.170940103860474`, -25.764625364302173`, 25.599999999999998`}, {
        43.212346265443955`, -25.81275854477739, 25.4}, {
        43.25328025959601, -25.860891725252607`, 25.2}}], 
       Line3DBox[{{43.25328025959601, -25.860891725252607`, 25.2}, {
        43.29442321580764, -25.906574393959747`, 25.}, {
        43.33509711439345, -25.952257062666884`, 24.8}, {
        43.375302568312165`, -25.997939731374025`, 24.6}, {
        43.41504018241383, -26.043622400081166`, 24.4}, {
        43.45431055348757, -26.089305068788303`, 24.2}, {
        43.493114270308496`, -26.134987737495443`, 24.}}], 
       Line3DBox[{{43.493114270308496`, -26.134987737495443`, 24.}, {
        43.532128623100874`, -26.17825271540699, 23.8}, {
        43.570679220891535`, -26.22151769331854, 23.6}, {
        43.60876663664068, -26.264782671230087`, 23.400000000000002`}, {
        43.646391435497904`, -26.308047649141635`, 23.2}, {
        43.68355417484601, -26.351312627053183`, 23.}, {
        43.72025540434413, -26.39457760496473, 22.8}}], 
       Line3DBox[{{43.72025540434413, -26.39457760496473, 22.8}, {
        43.75716877018877, -26.43545543769466, 22.6}, {
        43.79362332564729, -26.476333270424593`, 22.400000000000002`}, {
        43.82961960548886, -26.517211103154523`, 22.200000000000003`}, {
        43.865158136944785`, -26.558088935884452`, 22.}, {
        43.90023943974876, -26.598966768614385`, 21.8}, {
        43.934864026176285`, -26.639844601344315`, 21.6}}], 
       Line3DBox[{{43.934864026176285`, -26.639844601344315`, 21.6}, {
        43.96970209306902, -26.67836367807926, 21.400000000000002`}, {
        44.00408595303456, -26.71688275481421, 21.2}, {
        44.03801610429866, -26.755401831549158`, 21.}, {
        44.071493037798746`, -26.793920908284104`, 20.8}, {
        44.104517237220605`, -26.832439985019054`, 20.599999999999998`}, {
        44.137089179034746`, -26.870959061754, 20.4}}], 
       Line3DBox[{{44.137089179034746`, -26.870959061754, 20.4}, {
        44.1698758045402, -26.90714572297613, 20.2}, {
        44.2022125007402, -26.943332384198257`, 20.}, {
        44.234099730818244`, -26.979519045420385`, 19.8}, {
        44.265537950897425`, -27.015705706642514`, 19.6}, {
        44.296527610074094`, -27.051892367864642`, 19.400000000000002`}, {
        44.327069150450924`, -27.08807902908677, 19.200000000000003`}}], 
       Line3DBox[{{44.327069150450924`, -27.08807902908677, 
        19.200000000000003`}, {44.35782645051688, -27.12195766411665, 
        19.000000000000004`}, {44.38813778698017, -27.155836299146532`, 
        18.8}, {44.41800358934849, -27.18971493417641, 18.6}, {
        44.44742428027706, -27.22359356920629, 18.400000000000002`}, {
        44.476400275599474`, -27.257472204236173`, 18.2}, {
        44.504931984357796`, -27.29135083926605, 18.}}], 
       Line3DBox[{{44.504931984357796`, -27.29135083926605, 18.}, {
        44.53368041372758, -27.322943974528414`, 17.8}, {
        44.56198654591114, -27.35453710979078, 17.6}, {
        44.589850777982434`, -27.386130245053142`, 17.4}, {
        44.617273500352454`, -27.417723380315504`, 17.2}, {
        44.64425509679721, -27.44931651557787, 17.}, {
        44.67079594448521, -27.480909650840232`, 16.8}}], 
       Line3DBox[{{44.67079594448521, -27.480909650840232`, 16.8}, {
        44.69755436943561, -27.51023802964614, 16.6}, {
        44.72387387577885, -27.53956640845205, 16.400000000000002`}, {
        44.74975482928228, -27.568894787257957`, 16.200000000000003`}, {
        44.775197589222344`, -27.598223166063864`, 16.}, {
        44.800202508410095`, -27.627551544869775`, 15.8}, {
        44.82476993321622, -27.65687992367568, 15.600000000000001`}}], 
       Line3DBox[{{44.82476993321622, -27.65687992367568, 
        15.600000000000001`}, {44.84955569726084, -27.6839625782187, 
        15.400000000000002`}, {44.873905643795624`, -27.71104523276172, 
        15.200000000000001`}, {44.897820108301374`, -27.73812788730474, 
        15.}, {44.921299419924, -27.765210541847757`, 14.8}, {
        44.94434390149763, -27.792293196390776`, 14.600000000000001`}, {
        44.96695386956708, -27.819375850933795`, 14.4}}], 
       Line3DBox[{{44.96695386956708, -27.819375850933795`, 14.4}, {
        44.98978285268794, -27.844230167113484`, 14.200000000000001`}, {
        45.01217885125605, -27.869084483293175`, 14.}, {
        45.03414217138629, -27.893938799472863`, 13.8}, {
        45.05567311299937, -27.91879311565255, 13.6}, {
        45.07677196984265, -27.943647431832243`, 13.399999999999999`}, {
        45.09743902951044, -27.96850174801193, 13.2}}], 
       Line3DBox[{{45.09743902951044, -27.96850174801193, 13.2}, {
        45.11832570141216, -27.991143523623254`, 13.}, {
        45.138781961975894`, -28.013785299234574`, 12.799999999999999`}, {
        45.15880808877782, -28.036427074845896`, 12.6}, {
        45.1784043533264, -28.05906885045722, 12.4}, {
        45.19757102108095, -28.08171062606854, 12.2}, {
        45.21630835146988, -28.10435240167986, 12.}}], 
       Line3DBox[{{45.21630835146988, -28.10435240167986, 12.}, {
        45.23526581929106, -28.124795898441178`, 11.8}, {
        45.253795196762326`, -28.1452393952025, 11.6}, {
        45.27189673366085, -28.165682891963815`, 11.4}, {
        45.28957067380885, -28.186126388725132`, 11.200000000000001`}, {
        45.30681725509025, -28.206569885486452`, 11.}, {
        45.3236367094668, -28.22701338224777, 10.8}}], 
       Line3DBox[{{45.3236367094668, -28.22701338224777, 10.8}, {
        45.34067676032883, -28.245271372080868`, 10.600000000000001`}, {
        45.35729079629006, -28.26352936191397, 10.4}, {
        45.373479039985526`, -28.28178735174707, 10.200000000000001`}, {
        45.3892417081953, -28.30004534158017, 10.000000000000002`}, {
        45.40457901185911, -28.318303331413272`, 9.8}, {
        45.41949115609056, -28.33656132124637, 9.600000000000001}}], 
       Line3DBox[{{45.41949115609056, -28.33656132124637, 
        9.600000000000001}, {45.43462429481666, -28.35264512716919, 
        9.400000000000002}, {45.44933325445888, -28.368728933092008`, 
        9.200000000000001}, {45.46361823108876, -28.384812739014826`, 
        9.000000000000002}, {45.47747941501048, -28.400896544937645`, 
        8.800000000000002}, {45.490916990773584`, -28.416980350860463`, 
        8.600000000000001}, {45.503931137185376`, -28.43306415678328, 
        8.400000000000002}}], 
       Line3DBox[{{45.503931137185376`, -28.43306415678328, 
        8.400000000000002}, {45.517166619478544`, -28.44698368872829, 
        8.200000000000001}, {45.52997952403983, -28.4609032206733, 
        8.000000000000002}, {45.54237002088115, -28.47482275261831, 
        7.800000000000001}, {45.554338274322916`, -28.48874228456332, 
        7.6000000000000005`}, {45.56588444300486, -28.502661816508326`, 
        7.3999999999999995`}, {45.577008679896664`, -28.516581348453336`, 
        7.199999999999999}}], 
       Line3DBox[{{45.577008679896664`, -28.516581348453336`, 
        7.199999999999999}, {45.58835454122713, -28.52834513428115, 
        6.999999999999999}, {45.599279196175516`, -28.54010892010896, 6.8}, {
        45.60978278912668, -28.551872705936773`, 6.6}, {
        45.61986545883829, -28.563636491764587`, 6.3999999999999995`}, {
        45.62952733845009, -28.575400277592397`, 6.2}, {
        45.63876855549269, -28.58716406342021, 6.}}], 
       Line3DBox[{{45.63876855549269, -28.58716406342021, 6.}, {
        45.64823163590859, -28.596779275358546`, 5.8}, {
        45.65727465507864, -28.60639448729688, 5.6000000000000005`}, {
        45.66589773212435, -28.616009699235214`, 5.4}, {
        45.67410098059348, -28.62562491117355, 5.2}, {
        45.68188450846756, -28.63524012311188, 5.000000000000001}, {
        45.68924841816893, -28.644855335050217`, 4.800000000000001}}], 
       Line3DBox[{{45.68924841816893, -28.644855335050217`, 
        4.800000000000001}, {45.69683438321205, -28.652327811751775`, 
        4.6000000000000005`}, {45.70400120907155, -28.659800288453333`, 
        4.400000000000001}, {45.71074898990295, -28.66727276515489, 
        4.200000000000001}, {45.717077814330665`, -28.67474524185645, 
        4.000000000000001}, {45.72298776545391, -28.682217718558007`, 
        3.800000000000001}, {45.72847892085211, -28.689690195259566`, 
        3.6000000000000014`}}], 
       Line3DBox[{{45.72847892085211, -28.689690195259566`, 
        3.6000000000000014`}, {45.734192278729466`, -28.6950244596386, 
        3.4000000000000017`}, {45.739487198922816`, -28.70035872401763, 
        3.200000000000002}, {45.74436375085436, -28.705692988396663`, 
        3.0000000000000018`}, {45.748821998447426`, -28.711027252775697`, 
        2.800000000000002}, {45.752862000130705`, -28.716361517154727`, 
        2.6000000000000023`}, {45.756483808842034`, -28.72169578153376, 
        2.400000000000002}}], 
       Line3DBox[{{45.756483808842034`, -28.72169578153376, 
        2.400000000000002}, {45.760327923976064`, -28.72489505450926, 
        2.2000000000000024`}, {45.763754084262686`, -28.728094327484765`, 
        2.000000000000002}, {45.76676233456027, -28.731293600460265`, 
        1.8000000000000025`}, {45.76935271425023, -28.734492873435766`, 
        1.6000000000000028`}, {45.77152525723966, -28.73769214641127, 
        1.4000000000000028`}, {45.773279991963406`, -28.74089141938677, 
        1.2000000000000028`}}], 
       Line3DBox[{{45.773279991963406`, -28.74089141938677, 
        1.2000000000000028`}, {45.775257095016684`, -28.741957629630207`, 
        1.0000000000000024`}, {45.77681650869617, -28.74302383987364, 
        0.8000000000000018}, {45.777958253403796`, -28.744090050117077`, 
        0.6000000000000014}, {45.778682344076216`, -28.745156260360513`, 
        0.4000000000000009}, {45.778988790185835`, -28.746222470603946`, 
        0.2000000000000004}, {45.77887759574146, -28.747288680847383`, 0.}}], 
       Line3DBox[{{45.77887759574146, -28.747288680847383`, 0.}, {
        45.778988790185835`, -28.746222470603946`, -0.19999999999999987`}, {
        45.778682344076216`, -28.74515626036051, -0.39999999999999974`}, {
        45.777958253403796`, -28.744090050117073`, -0.5999999999999996}, {
        45.77681650869617, -28.743023839873636`, -0.7999999999999995}, {
        45.775257095016684`, -28.7419576296302, -0.9999999999999992}, {
        45.773279991963406`, -28.740891419386763`, -1.1999999999999993`}}], 
       Line3DBox[{{
        45.773279991963406`, -28.740891419386763`, -1.1999999999999993`}, {
        45.77152525723966, -28.737692146411263`, -1.3999999999999992`}, {
        45.769352714250246`, -28.734492873435762`, -1.5999999999999992`}, {
        45.76676233456027, -28.731293600460262`, -1.799999999999999}, {
        45.763754084262686`, -28.72809432748476, -1.999999999999999}, {
        45.760327923976064`, -28.72489505450926, -2.199999999999999}, {
        45.756483808842034`, -28.72169578153376, -2.3999999999999986`}}], 
       Line3DBox[{{
        45.756483808842034`, -28.72169578153376, -2.3999999999999986`}, {
        45.752862000130705`, -28.716361517154727`, -2.599999999999999}, {
        45.748821998447426`, -28.711027252775693`, -2.7999999999999994`}, {
        45.74436375085436, -28.70569298839666, -3.}, {
        45.739487198922816`, -28.700358724017626`, -3.2}, {
        45.734192278729466`, -28.695024459638592`, -3.400000000000001}, {
        45.72847892085211, -28.68969019525956, -3.6000000000000014`}}], 
       Line3DBox[{{
        45.72847892085211, -28.68969019525956, -3.6000000000000014`}, {
        45.72298776545391, -28.682217718558004`, -3.8000000000000007`}, {
        45.717077814330665`, -28.674745241856446`, -4.}, {
        45.71074898990295, -28.66727276515489, -4.199999999999999}, {
        45.70400120907155, -28.659800288453336`, -4.399999999999999}, {
        45.69683438321205, -28.65232781175178, -4.599999999999998}, {
        45.689248418168916`, -28.644855335050224`, -4.799999999999997}}], 
       Line3DBox[{{
        45.689248418168916`, -28.644855335050224`, -4.799999999999997}, {
        45.68188450846755, -28.63524012311189, -4.999999999999997}, {
        45.67410098059348, -28.625624911173553`, -5.199999999999998}, {
        45.66589773212435, -28.616009699235217`, -5.399999999999999}, {
        45.65727465507864, -28.606394487296882`, -5.599999999999999}, {
        45.64823163590859, -28.596779275358546`, -5.8}, {
        45.63876855549269, -28.58716406342021, -6.}}], 
       Line3DBox[{{45.63876855549269, -28.58716406342021, -6.}, {
        45.62952733845009, -28.575400277592397`, -6.199999999999999}, {
        45.61986545883829, -28.563636491764587`, -6.399999999999999}, {
        45.60978278912668, -28.551872705936773`, -6.599999999999998}, {
        45.599279196175516`, -28.54010892010896, -6.799999999999997}, {
        45.58835454122713, -28.52834513428115, -6.9999999999999964`}, {
        45.577008679896664`, -28.516581348453336`, -7.199999999999996}}], 
       Line3DBox[{{
        45.577008679896664`, -28.516581348453336`, -7.199999999999996}, {
        45.56588444300486, -28.502661816508326`, -7.399999999999996}, {
        45.55433827432293, -28.488742284563315`, -7.599999999999997}, {
        45.542370020881165`, -28.474822752618305`, -7.799999999999997}, {
        45.52997952403983, -28.460903220673295`, -7.999999999999997}, {
        45.517166619478544`, -28.446983688728285`, -8.199999999999998}, {
        45.503931137185376`, -28.433064156783274`, -8.399999999999999}}], 
       Line3DBox[{{
        45.503931137185376`, -28.433064156783274`, -8.399999999999999}, {
        45.490916990773584`, -28.416980350860456`, -8.6}, {
        45.47747941501048, -28.400896544937638`, -8.799999999999999}, {
        45.46361823108876, -28.38481273901482, -9.}, {
        45.44933325445888, -28.368728933092, -9.200000000000001}, {
        45.43462429481666, -28.352645127169183`, -9.4}, {
        45.41949115609056, -28.336561321246364`, -9.600000000000001}}], 
       Line3DBox[{{
        45.41949115609056, -28.336561321246364`, -9.600000000000001}, {
        45.40457901185911, -28.318303331413265`, -9.8}, {
        45.3892417081953, -28.300045341580166`, -10.}, {
        45.373479039985526`, -28.281787351747067`, -10.2}, {
        45.35729079629007, -28.263529361913967`, -10.399999999999999`}, {
        45.34067676032883, -28.245271372080868`, -10.599999999999998`}, {
        45.3236367094668, -28.22701338224777, -10.799999999999997`}}], 
       Line3DBox[{{
        45.3236367094668, -28.22701338224777, -10.799999999999997`}, {
        45.30681725509025, -28.206569885486452`, -10.999999999999998`}, {
        45.28957067380885, -28.186126388725132`, -11.199999999999998`}, {
        45.27189673366085, -28.165682891963815`, -11.399999999999999`}, {
        45.253795196762326`, -28.1452393952025, -11.6}, {
        45.23526581929106, -28.124795898441178`, -11.799999999999999`}, {
        45.21630835146988, -28.10435240167986, -12.}}], 
       Line3DBox[{{45.21630835146988, -28.10435240167986, -12.}, {
        45.19757102108095, -28.08171062606854, -12.2}, {
        45.1784043533264, -28.059068850457216`, -12.399999999999999`}, {
        45.15880808877782, -28.036427074845893`, -12.599999999999998`}, {
        45.138781961975894`, -28.01378529923457, -12.799999999999997`}, {
        45.11832570141216, -27.991143523623247`, -12.999999999999996`}, {
        45.09743902951044, -27.968501748011924`, -13.199999999999996`}}], 
       Line3DBox[{{
        45.09743902951044, -27.968501748011924`, -13.199999999999996`}, {
        45.07677196984265, -27.943647431832236`, -13.399999999999997`}, {
        45.05567311299937, -27.918793115652548`, -13.599999999999996`}, {
        45.03414217138629, -27.89393879947286, -13.799999999999997`}, {
        45.01217885125605, -27.86908448329317, -13.999999999999998`}, {
        44.98978285268794, -27.844230167113484`, -14.199999999999998`}, {
        44.96695386956708, -27.819375850933795`, -14.399999999999999`}}], 
       Line3DBox[{{
        44.96695386956708, -27.819375850933795`, -14.399999999999999`}, {
        44.94434390149763, -27.792293196390776`, -14.6}, {
        44.921299419924, -27.765210541847757`, -14.799999999999999`}, {
        44.897820108301374`, -27.73812788730474, -15.}, {
        44.873905643795624`, -27.71104523276172, -15.200000000000001`}, {
        44.84955569726084, -27.6839625782187, -15.4}, {
        44.82476993321622, -27.65687992367568, -15.600000000000001`}}], 
       Line3DBox[{{
        44.82476993321622, -27.65687992367568, -15.600000000000001`}, {
        44.800202508410095`, -27.627551544869775`, -15.8}, {
        44.775197589222344`, -27.598223166063864`, -16.}, {
        44.74975482928228, -27.568894787257957`, -16.2}, {
        44.723873875778864`, -27.53956640845205, -16.4}, {
        44.69755436943561, -27.51023802964614, -16.599999999999998`}, {
        44.67079594448521, -27.480909650840232`, -16.799999999999997`}}], 
       Line3DBox[{{
        44.67079594448521, -27.480909650840232`, -16.799999999999997`}, {
        44.64425509679721, -27.44931651557787, -16.999999999999996`}, {
        44.617273500352454`, -27.417723380315504`, -17.2}, {
        44.589850777982434`, -27.386130245053142`, -17.4}, {
        44.56198654591114, -27.35453710979078, -17.599999999999998`}, {
        44.53368041372758, -27.322943974528414`, -17.8}, {
        44.504931984357796`, -27.29135083926605, -18.}}], 
       Line3DBox[{{44.504931984357796`, -27.29135083926605, -18.}, {
        44.476400275599474`, -27.257472204236173`, -18.2}, {
        44.44742428027706, -27.22359356920629, -18.4}, {
        44.41800358934849, -27.18971493417641, -18.599999999999998`}, {
        44.38813778698017, -27.155836299146532`, -18.799999999999997`}, {
        44.35782645051688, -27.12195766411665, -18.999999999999996`}, {
        44.327069150450924`, -27.08807902908677, -19.199999999999996`}}], 
       Line3DBox[{{
        44.327069150450924`, -27.08807902908677, -19.199999999999996`}, {
        44.296527610074094`, -27.051892367864642`, -19.399999999999995`}, {
        44.265537950897425`, -27.01570570664251, -19.599999999999998`}, {
        44.234099730818244`, -26.979519045420382`, -19.799999999999997`}, {
        44.2022125007402, -26.943332384198253`, -19.999999999999996`}, {
        44.169875804540226`, -26.90714572297612, -20.2}, {
        44.137089179034746`, -26.870959061753993`, -20.4}}], 
       Line3DBox[{{44.137089179034746`, -26.870959061753993`, -20.4}, {
        44.104517237220605`, -26.832439985019047`, -20.599999999999998`}, {
        44.071493037798746`, -26.793920908284104`, -20.8}, {
        44.03801610429866, -26.755401831549158`, -21.}, {
        44.00408595303456, -26.71688275481421, -21.2}, {
        43.96970209306902, -26.67836367807927, -21.400000000000002`}, {
        43.934864026176285`, -26.639844601344322`, -21.6}}], 
       Line3DBox[{{43.934864026176285`, -26.639844601344322`, -21.6}, {
        43.90023943974876, -26.59896676861439, -21.8}, {
        43.865158136944785`, -26.558088935884456`, -22.}, {
        43.82961960548886, -26.517211103154523`, -22.2}, {
        43.79362332564729, -26.47633327042459, -22.4}, {
        43.75716877018877, -26.435455437694657`, -22.599999999999998`}, {
        43.72025540434413, -26.394577604964724`, -22.799999999999997`}}], 
       Line3DBox[{{
        43.72025540434413, -26.394577604964724`, -22.799999999999997`}, {
        43.68355417484601, -26.351312627053176`, -22.999999999999996`}, {
        43.646391435497904`, -26.308047649141628`, -23.2}, {
        43.60876663664068, -26.26478267123008, -23.4}, {
        43.57067922089155, -26.221517693318532`, -23.599999999999998`}, {
        43.532128623100874`, -26.178252715406984`, -23.8}, {
        43.493114270308496`, -26.134987737495436`, -24.}}], 
       Line3DBox[{{43.493114270308496`, -26.134987737495436`, -24.}, {
        43.45431055348757, -26.089305068788295`, -24.2}, {
        43.41504018241383, -26.04362240008116, -24.4}, {
        43.375302568312165`, -25.997939731374018`, -24.599999999999998`}, {
        43.33509711439346, -25.952257062666877`, -24.799999999999997`}, {
        43.294423215807655`, -25.90657439395974, -24.999999999999996`}, {
        43.253280259596025`, -25.8608917252526, -25.199999999999996`}}], 
       Line3DBox[{{
        43.253280259596025`, -25.8608917252526, -25.199999999999996`}, {
        43.212346265443955`, -25.812758544777385`, -25.399999999999995`}, {
        43.170940103860474`, -25.76462536430217, -25.599999999999998`}, {
        43.1290611450538, -25.716492183826954`, -25.799999999999997`}, {
        43.08670875090091, -25.66835900335174, -25.999999999999996`}, {
        43.04388227489656, -25.620225822876524`, -26.2}, {
        43.00058106210115, -25.57209264240131, -26.4}}], 
       Line3DBox[{{43.00058106210115, -25.57209264240131, -26.4}, {
        42.957486944468144`, -25.52147372251524, -26.599999999999998`}, {
        42.9139147578197, -25.47085480262917, -26.799999999999997`}, {
        42.86986382926219, -25.4202358827431, -26.999999999999996`}, {
        42.82533347722439, -25.36961696285703, -27.199999999999996`}, {
        42.78032301140168, -25.31899804297096, -27.399999999999995`}, {
        42.73483173269926, -25.26837912308489, -27.599999999999994`}}], 
       Line3DBox[{{
        42.73483173269926, -25.26837912308489, -27.599999999999994`}, {
        42.689545467369044`, -25.21523668444391, -27.799999999999994`}, {
        42.643774821438114`, -25.162094245802926`, -27.999999999999996`}, {
        42.597519076623314`, -25.108951807161944`, -28.199999999999996`}, {
        42.550777505585216`, -25.05580936852096, -28.399999999999995`}, {
        42.50354937186728, -25.00266692987998, -28.599999999999998`}, {
        42.455833929834114`, -24.949524491238996`, -28.799999999999997`}}], 
       Line3DBox[{{
        42.455833929834114`, -24.949524491238996`, -28.799999999999997`}, {
        42.40832117978381, -24.89381804251643, -28.999999999999996`}, {
        42.36031730377633, -24.83811159379386, -29.2}, {
        42.3118215356275, -24.782405145071294`, -29.4}, {
        42.262833099683135`, -24.726698696348727`, -29.599999999999998`}, {
        42.21335121075239, -24.67099224762616, -29.8}, {
        42.163375074040644`, -24.615285798903592`, -30.}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
        26.65689665330767, -3.372643846726379, -30.}, {21.325517322646135`, 
        3.301884922618896, -30.}, {15.9941379919846, 
        9.97641369196417, -30.}, {10.662758661323068`, 
        16.650942461309448`, -30.}, {5.33137933066153, 
        23.32547123065472, -30.}, {0., 29.999999999999993`, -30.}, {
        31.988275983969203`, -10.047172616071654`, -30.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         26.65689665330767, -11.798285743622072`, -30.}, {
         21.325517322646135`, -13.54939887117249, -30.}, {
         15.994137991984601`, -15.30051199872291, -30.}, {
         10.662758661323071`, -17.05162512627333, -30.}, {
         5.331379330661537, -18.802738253823748`, -30.}, {
         3.552713678800501*^-15, -20.553851381374166`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         26.65689665330767, -11.79828574362207, -30.}, {
         21.325517322646135`, -13.549398871172489`, -30.}, {
         15.994137991984598`, -15.300511998722907`, -30.}, {
         10.662758661323068`, -17.051625126273322`, -30.}, {
         5.331379330661534, -18.80273825382374, -30.}, \
{-3.552713678800501*^-15, -20.55385138137416, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         26.797441236887803`, -11.844123395287172`, -30.}, {
         21.606606489806403`, -13.64107417450269, -30.}, {
         16.415771742725006`, -15.438024953718207`, -30.}, {
         11.22493699564361, -17.234975732933727`, -30.}, {
         6.03410224856221, -19.031926512149244`, -30.}, {
         0.8432675014808169, -20.828877291364762`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         26.93798582046794, -11.888521707558574`, -30.}, {
         21.887695656966677`, -13.729870799045493`, -30.}, {
         16.83740549346541, -15.571219890532415`, -30.}, {
         11.787115329964152`, -17.412568982019334`, -30.}, {
         6.736825166462889, -19.253918073506256`, -30.}, {
         1.6865350029616266`, -21.095267164993174`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.078530404048074`, -11.931493271983113`, -30.}, {
         22.16878482412695, -13.81581392789457, -30.}, {
         17.259039244205816`, -15.70013458380603, -30.}, {
         12.349293664284694`, -17.58445523971749, -30.}, {
         7.439548084363565, -19.468775895628944`, -30.}, {
         2.5298025044424364`, -21.353096551540403`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.21907498762821, -11.973050135980362`, -30.}, {
         22.44987399128722, -13.898927655889072`, -30.}, {
         17.680672994946228`, -15.82480517579778, -30.}, {
         12.911471998605236`, -17.750682695706487`, -30.}, {
         8.142271002264241, -19.676560215615197`, -30.}, {
         3.3730700059232532`, -21.602437735523907`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.359619571208345`, -12.013203821664051`, -30.}, {
         22.730963158447487`, -13.979235027256449`, -30.}, {
         18.102306745686633`, -15.945266232848846`, -30.}, {
         13.473650332925775`, -17.911297438441245`, -30.}, {
         8.844993920164917, -19.877328644033643`, -30.}, {
         4.216337507404063, -21.84335984962604, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.500164154788482`, -12.05196534353528, -30.}, {
         23.012052325607762`, -14.056758070998905`, -30.}, {
         18.523940496427038`, -16.06155079846253, -30.}, {
         14.035828667246319`, -18.066343525926158`, -30.}, {
         9.547716838065604, -20.07113625338978, -30.}, {
         5.05960500888488, -22.075928980853405`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.640708738368616`, -12.089345225116531`, -30.}, {
         23.293141492768033`, -14.131517834161409`, -30.}, {
         18.945574247167446`, -16.173690443206286`, -30.}, {
         14.598007001566861`, -18.215863052251166`, -30.}, {
         10.250439755966276`, -20.25803566129604, -30.}, {
         5.902872510365693, -22.300208270340917`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.781253321948753`, -12.125353514589941`, -30.}, {
         23.5742306599283, -14.20353441310823, -30.}, {
         19.36720799790785, -16.281715311626517`, -30.}, {
         15.1601853358874, -18.359896210144804`, -30.}, {
         10.953162673866952`, -20.43807710866309, -30.}, {
         6.746140011846503, -22.516258007181378`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         27.921797905528887`, -12.159999799498287`, -30.}, {
         23.855319827088575`, -14.272826982924919`, -30.}, {
         19.78884174864826, -16.385654166351554`, -30.}, {
         15.722363670207946`, -18.498481349778185`, -30.}, {
         11.655885591767635`, -20.61130853320482, -30.}, {
         7.58940751332732, -22.72413571663145, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.06234248910902, -12.193293220562662`, -30.}, {
         24.136408994248843`, -14.339413825053672`, -30.}, {
         20.21047549938866, -16.485534429544682`, -30.}, {
         16.284542004528483`, -18.63165503403569, -30.}, {
         12.3586085096683, -20.7777756385267, -30.}, {
         8.432675014808122, -22.92389624301771, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.20288707268916, -12.22524248466654, -30.}, {
         24.417498161409114`, -14.403312353261427`, -30.}, {
         20.632109250129073`, -16.581382221856312`, -30.}, {
         16.84672033884903, -18.759452090451198`, -30.}, {
         13.061331427568987`, -20.937521959046084`, -30.}, {
         9.275942516288946, -23.11559182764097, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.343431656269292`, -12.25585587705215, -30.}, {
         24.698587328569385`, -14.464539138032649`, -30.}, {
         21.053743000869474`, -16.673222399013145`, -30.}, {
         17.408898673169567`, -18.88190565999364, -30.}, {
         13.76405434546966, -21.090588920974138`, -30.}, {
         10.119210017769749`, -23.299272181954635`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.48397623984943, -12.285141272771419`, -30.}, {
         24.979676495729656`, -14.523109929471183`, -30.}, {
         21.475376751609883`, -16.76107858617095, -30.}, {
         17.97107700749011, -18.999047242870713`, -30.}, {
         14.466777263370341`, -21.237015899570476`, -30.}, {
         10.962477519250566`, -23.474984556270243`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.624520823429563`, -12.313106147430645`, -30.}, {
         25.260765662889927`, -14.579039678789634`, -30.}, {
         21.89701050235029, -16.844973210148623`, -30.}, {
         18.53325534181065, -19.110906741507616`, -30.}, {
         15.169500181271014`, -21.376840272866605`, -30.}, {
         11.80574502073138, -23.642773804225598`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.7650654070097, -12.339757587264891`, -30.}, {
         25.541854830050198`, -14.632342558458127`, -30.}, {
         22.318644253090696`, -16.924927529651363`, -30.}, {
         19.095433676131194`, -19.217512500844602`, -30.}, {
         15.87222309917169, -21.510097472037838`, -30.}, {
         12.649012522212189`, -23.802682443231078`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         28.905609990589834`, -12.365102298575394`, -30.}, {
         25.82294399721047, -14.683031981079132`, -30.}, {
         22.740278003831104`, -17.00096166358287, -30.}, {
         19.657612010451736`, -19.318891346086613`, -30.}, {
         16.57494601707237, -21.63682102859035, -30.}, {
         13.492280023693006`, -23.95475071109409, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.04615457416997, -12.38914661656066, -30.}, {
         26.10403316437074, -14.731120617049669`, -30.}, {
         23.16191175457151, -17.073094617538676`, -30.}, {
         20.219790344772278`, -19.415068618027682`, -30.}, {
         17.277668934973043`, -21.75704261851669, -30.}, {
         14.335547525173814`, -24.099016619005695`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.186699157750105`, -12.411896513569575`, -30.}, {
         26.38512233153101, -14.776620411067498`, -30.}, {
         23.583545505311914`, -17.14134430856542, -30.}, {
         20.78196867909282, -19.50606820606334, -30.}, {
         17.980391852873726`, -21.87079210356126, -30.}, {
         15.178815026654627`, -24.23551600105918, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.327243741330243`, -12.433357606802524`, -30.}, {
         26.666211498691283`, -14.819542597533392`, -30.}, {
         24.005179256052323`, -17.205727588264264`, -30.}, {
         21.344147013413362`, -19.59191257899513, -30.}, {
         18.683114770774402`, -21.978097569726003`, -30.}, {
         16.022082528135442`, -24.36428256045687, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.467788324910376`, -12.453535165484606`, -30.}, {
         26.947300665851554`, -14.85989771489756, -30.}, {
         24.42681300679273, -17.26626026431051, -30.}, {
         21.906325347733905`, -19.672622813723464`, -30.}, {
         19.385837688675082`, -22.078985363136418`, -30.}, {
         16.86535002961626, -24.485347912549372`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.608332908490514`, -12.472434117532966`, -30.}, {
         27.228389833011825`, -14.89769561899428, -30.}, {
         24.848446757533136`, -17.32295712045559, -30.}, {
         22.468503682054447`, -19.748218621916905`, -30.}, {
         20.088560606575758`, -22.17348012337822, -30.}, {
         17.70861753109707, -24.598741624839533`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.748877492070648`, -12.490059055738456`, -30.}, {
         27.509479000172096`, -14.932945495405258`, -30.}, {
         25.270080508273544`, -17.37583193507206, -30.}, {
         23.03068201637499, -19.818718374738864`, -30.}, {
         20.791283524476437`, -22.261604814405665`, -30.}, {
         18.551885032577882`, -24.70449125407247, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         29.889422075650785`, -12.50641424348028, -30.}, {
         27.790568167332367`, -14.965655870888908`, -30.}, {
         25.691714259013946`, -17.424897498297536`, -30.}, {
         23.592860350695528`, -19.884139125706163`, -30.}, {
         21.494006442377113`, -22.343380753114786`, -30.}, {
         19.39515253405869, -24.802622380523417`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.02996665923092, -12.521503619990543`, -30.}, {
         28.071657334492635`, -14.995834623909435`, -30.}, {
         26.113348009754354`, -17.470165627828326`, -30.}, {
         24.15503868501607, -19.944496631747214`, -30.}, {
         22.19672936027779, -22.418827635666105`, -30.}, {
         20.238420035539505`, -24.893158639584996`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.170511242811056`, -12.535330805184163`, -30.}, {
         28.35274650165291, -15.023488994296674`, -30.}, {
         26.534981760494762`, -17.51164718340918, -30.}, {
         24.717217019336616`, -19.999805372521692`, -30.}, {
         22.899452278178465`, -22.487963561634203`, -30.}, {
         21.081687537020322`, -24.97612175074671, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.31105582639119, -12.547899104068254`, -30.}, {
         28.633835668813177`, -15.048625592064855`, -30.}, {
         26.956615511235167`, -17.549352080061457`, -30.}, {
         25.279395353657154`, -20.050078568058055`, -30.}, {
         23.602175196079145`, -22.550805056054656`, -30.}, {
         21.924955038501132`, -25.051531544051258`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.451600409971327`, -12.559211510743689`, -30.}, {
         28.914924835973448`, -15.071250405415725`, -30.}, {
         27.378249261975576`, -17.58328930008776, -30.}, {
         25.841573687977696`, -20.095328194759794`, -30.}, {
         24.30489811397982, -22.60736708943183, -30.}, {
         22.768222539981945`, -25.119405984103864`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.59214499355146, -12.569270712010262`, -30.}, {
         29.19601400313372, -15.091368807948871`, -30.}, {
         27.79988301271598, -17.61346690388748, -30.}, {
         26.40375202229824, -20.135564999826087`, -30.}, {
         25.0076210318805, -22.657663095764697`, -30.}, {
         23.61149004146276, -25.179761191703307`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.732689577131595`, -12.578079090585735`, -30.}, {
         29.47710317029399, -15.108985565099818`, -30.}, {28.221516763456385`,
          -17.6398920396139, -30.}, {
         26.965930356618777`, -20.17079851412798, -30.}, {
         25.710343949781173`, -22.701704988642064`, -30.}, {
         24.454757542943568`, -25.232611463156147`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         30.873234160711732`, -12.585638727947819`, -30.}, {
         29.75819233745426, -15.124104839823985`, -30.}, {
         28.64315051419679, -17.66257095170015, -30.}, {
         27.528108690939323`, -20.201037063576315`, -30.}, {
         26.413066867681852`, -22.73950317545248, -30.}, {
         25.29802504442438, -25.277969287328645`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.01377874429187, -12.591951406807057`, -30.}, {
         30.039281504614532`, -15.136730197542459`, -30.}, {
         29.0647842649372, -17.681508988277862`, -30.}, {
         28.090287025259865`, -20.226287779013266`, -30.}, {
         27.115789785582532`, -22.77106656974867, -30.}, {
         26.1412925459052, -25.31584536048407, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.154323327872003`, -12.597018613217523`, -30.}, {
         30.320370671774803`, -15.146864610363393`, -30.}, {
         29.486418015677604`, -17.69671060750926, -30.}, {
         28.652465359580404`, -20.246556604655133`, -30.}, {
         27.818512703483208`, -22.796402601801, -30.}, {
         26.984560047386008`, -25.34624859894687, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.294867911452137`, -12.600841538331169`, -30.}, {
         30.601459838935074`, -15.154510460590684`, -30.}, {
         29.908051766418012`, -17.708179382850197`, -30.}, {
         29.21464369390095, -20.261848305109716`, -30.}, {
         28.521235621383884`, -22.815517227369227`, -30.}, {
         27.82782754886682, -25.369186149628746`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.435412495032274`, -12.603421079800665`, -30.}, {
         30.882549006095346`, -15.159669543529677`, -30.}, {
         30.329685517158417`, -17.715918007258686`, -30.}, {
         29.776822028221492`, -20.2721664709877, -30.}, {
         29.223958539284563`, -22.82841493471671, -30.}, {
         28.671095050347635`, -25.384663398445724`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.57595707861241, -12.604757842834637`, -30.}, {
         31.16363817325562, -15.162343069597618`, -30.}, {
         30.751319267898825`, -17.719928296360603`, -30.}, {
         30.339000362542034`, -20.277513523123584`, -30.}, {
         29.926681457185243`, -22.83509874988657, -30.}, {
         29.51436255182845, -25.39268397664955, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.716501662192545`, -12.604852140908154`, -30.}, {
         31.444727340415888`, -15.162531665744655`, -30.}, {
         31.17295301863923, -17.720211190581153`, -30.}, {
         30.901178696862573`, -20.277890715417655`, -30.}, {
         30.629404375085915`, -22.835570240254157`, -30.}, {
         30.357630053309258`, -25.393249765090655`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.85704624577268, -12.603703996130424`, -30.}, {
         31.72581650757616, -15.160235376189195`, -30.}, {
         31.594586769379635`, -17.716766756247967`, -30.}, {
         31.463357031183115`, -20.273298136306735`, -30.}, {
         31.33212729298659, -22.829829516365507`, -30.}, {
         31.20089755479007, -25.38636089642428, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         31.997590829352816`, -12.601313139270724`, -30.}, {
         32.00690567473643, -15.155453662469794`, -30.}, {
         32.016220520120044`, -17.709594185668863`, -30.}, {
         32.02553536550366, -20.263734708867936`, -30.}, {
         32.03485021088727, -22.817875232067003`, -30.}, {
         32.044165056270884`, -25.372015755266073`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.138135412932954`, -12.597679009442619`, -30.}, {
         32.2879948418967, -15.148185402813585`, -30.}, {
         32.43785427086045, -17.698691796184548`, -30.}, {
         32.58771369982419, -20.249198189555514`, -30.}, {
         32.73757312878794, -22.79970458292648, -30.}, {
         32.887432557751694`, -25.350210976297447`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.278679996513084`, -12.592800753445617`, -30.}, {
         32.56908400905697, -15.138428890819583`, -30.}, {
         32.85948802160085, -17.684057028193546`, -30.}, {
         33.14989203414474, -20.22968516556751, -30.}, {
         33.44029604668863, -22.775313302941473`, -30.}, {
         33.73070005923251, -25.320941440315437`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.41922458009322, -12.586677224762418`, -30.}, {
         32.85017317621724, -15.126181833453181`, -30.}, {
         33.281121772341265`, -17.665686442143944`, -30.}, {
         33.712070368465284`, -20.205191050834706`, -30.}, {
         34.1430189645893, -22.744695659525473`, -30.}, {
         34.57396756071332, -25.28420026821624, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.55976916367336, -12.579306982209092`, -30.}, {
         33.131262343377514`, -15.11144134834653, -30.}, {
         33.70275552308167, -17.643575714483966`, -30.}, {
         34.274248702785826`, -20.175710080621407`, -30.}, {
         34.84574188248998, -22.70784444675884, -30.}, {
         35.41723506219414, -25.239978812896283`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.700313747253496`, -12.57068828823434, -30.}, {
         33.41235151053778, -15.094203960397028`, -30.}, {
         34.124389273822075`, -17.617719632559712`, -30.}, {
         34.83642703710637, -20.1412353047224, -30.}, {
         35.548464800390654`, -22.664750976885088`, -30.}, {
         36.26050256367495, -25.188266649047776`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.840858330833626`, -12.56081910686326, -30.}, {
         33.69344067769806, -15.074465597654868`, -30.}, {
         34.54602302456248, -17.588112088446476`, -30.}, {
         35.39860537142691, -20.10175857923808, -30.}, {
         36.251187718291334`, -22.615405070029688`, -30.}, {
         37.103770065155764`, -25.129051560821296`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         32.98140291441376, -12.549697101279872`, -30.}, {
         33.974529844858324`, -15.052221586488091`, -30.}, {
         34.967656775302885`, -17.554746071696307`, -30.}, {
         35.960783705747446`, -20.057270556904527`, -30.}, {
         36.95391063619201, -22.559795042112746`, -30.}, {
         37.947037566636574`, -25.062319527320966`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.1219474979939, -12.53731963104162, -30.}, {
         34.2556190120186, -15.027466646011588`, -30.}, {
         35.3892905260433, -17.517613660981553`, -30.}, {
         36.52296204006799, -20.007760675951523`, -30.}, {
         37.656633554092686`, -22.497907690921487`, -30.}, {
         38.790305068117384`, -24.988054705891457`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.26249208157404, -12.523683748918167`, -30.}, {
         34.536708179178866`, -15.000194881764678`, -30.}, {
         35.8109242767837, -17.476706014611192`, -30.}, {
         37.08514037438854, -19.953217147457703`, -30.}, {
         38.359356471993365`, -22.429728280304214`, -30.}, {
         39.6335725695982, -24.90623941315073, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.40303666515417, -12.508786197345417`, -30.}, {
         34.817797346339134`, -14.97039977861918, -30.}, {
         36.23255802752411, -17.432013359892945`, -30.}, {
         37.64731870870907, -19.89362694116671, -30.}, {
         39.06207938989404, -22.355240522440468`, -30.}, {
         40.47684007107901, -24.816854103714235`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.543581248734306`, -12.492623404484885`, -30.}, {
         35.09888651349941, -14.938074192898117`, -30.}, {
         36.65419177826452, -17.38352498131135, -30.}, {
         38.20949704302962, -19.82897576972458, -30.}, {
         39.764802307794724`, -22.27442655813781, -30.}, {
         41.32010757255983, -24.719877346551044`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.68412583231444, -12.475191479876976`, -30.}, {
         35.37997568065968, -14.903210343682296`, -30.}, {
         37.075825529004916`, -17.331229207487617`, -30.}, {
         38.77167537735016, -19.759248071292937`, -30.}, {
         40.4675252256954, -22.18726693509826, -30.}, {
         42.16337507404064, -24.615285798903585`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.68412583231444, -12.475191479876976`, -30.}, {
         35.37997568065968, -14.9032103436823, -30.}, {
         37.07582552900492, -17.33122920748762, -30.}, {
         38.771675377350164`, -19.759248071292944`, -30.}, {
         40.4675252256954, -22.187266935098265`, -30.}, {
         42.163375074040644`, -24.61528579890359, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.731596405221254`, -12.293140527213964`, -30.}, {
         35.474916826473304`, -14.539108438356275`, -30.}, {
         37.218237247725355`, -16.785076349498585`, -30.}, {
         38.961557668977406`, -19.031044260640897`, -30.}, {
         40.70487809022946, -21.277012171783205`, -30.}, {
         42.4481985114815, -23.522980082925514`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.77677662070529, -12.111089574550952`, -30.}, {
         35.56527725744137, -14.175006533030253`, -30.}, {
         37.35377789417746, -16.23892349150955, -30.}, {
         39.14227853091355, -18.30284044998885, -30.}, {
         40.93077916764963, -20.366757408468146`, -30.}, {
         42.71927980438572, -22.430674366947446`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.81968651195307, -11.92903862188794, -30.}, {
         35.65109703993694, -13.810904627704225`, -30.}, {
         37.48250756792081, -15.692770633520514`, -30.}, {
         39.31391809590468, -17.5746366393368, -30.}, {
         41.14532862388855, -19.456502645153087`, -30.}, {
         42.97673915187242, -21.33836865096937, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.86034488969924, -11.746987669224929`, -30.}, {
         35.73241379542928, -13.446802722378203`, -30.}, {
         37.60448270115933, -15.146617775531478`, -30.}, {
         39.476551606889366`, -16.84643282868475, -30.}, {
         41.348620512619405`, -18.546247881838028`, -30.}, {
         43.22068941834945, -20.2460629349913, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.8987693863792, -11.564936716561917`, -30.}, {
         35.8092627887892, -13.08270081705218, -30.}, {
         37.719756191199195`, -14.600464917542443`, -30.}, {
         39.63024959360919, -16.118229018032707`, -30.}, {
         41.54074299601919, -17.63599311852297, -30.}, {
         43.45123639842919, -19.15375721901323, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.9349764968099, -11.382885763898905`, -30.}, {
         35.88167700965061, -12.718598911726154`, -30.}, {
         37.82837752249131, -14.054312059553403`, -30.}, {
         39.775078035332015`, -15.390025207380654`, -30.}, {
         41.721778548172715`, -16.725738355207906`, -30.}, {
         43.668479061013414`, -18.061451503035155`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.96898161563024, -11.200834811235893`, -30.}, {
         35.94968724729127, -12.35449700640013, -30.}, {
         37.93039287895231, -13.50815920156437, -30.}, {
         39.91109851061335, -14.661821396728609`, -30.}, {
         41.89180414227438, -15.815483591892846`, -30.}, {
         43.87250977393542, -16.969145787057084`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.00079907170949, -11.018783858572881`, -30.}, {
         36.01332215944977, -11.990395101074107`, -30.}, {
         38.025845247190055`, -12.962006343575334`, -30.}, {
         40.03836833493034, -13.93361758607656, -30.}, {
         42.050891422670624`, -14.905228828577787`, -30.}, {
         44.06341451041091, -15.876840071079013`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.03044215971172, -10.83673290590987, -30.}, {
         36.072608335454234`, -11.626293195748083`, -30.}, {
         38.11477451119675, -12.415853485586299`, -30.}, {
         40.156940686939265`, -13.205413775424514`, -30.}, {
         42.19910686268178, -13.994974065262728`, -30.}, {
         44.241273038424296`, -14.784534355100941`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.057923168985226`, -10.654681953246856`, -30.}, {
         36.12757035400126, -11.26219129042206, -30.}, {
         38.19721753901729, -11.869700627597261`, -30.}, {
         40.26686472403331, -12.477209964772463`, -30.}, {
         42.33651190904934, -13.084719301947667`, -30.}, {
         44.40615909406537, -13.692228639122868`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.08325340992887, -10.472631000583846`, -30.}, {
         36.17823083588855, -10.898089385096036`, -30.}, {
         38.273208261848225`, -11.323547769608227`, -30.}, {
         40.368185687807895`, -11.749006154120417`, -30.}, {
         42.46316311376757, -12.17446453863261, -30.}, {
         44.55814053972725, -12.5999229231448, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.10644323797173, -10.290580047920832`, -30.}, {
         36.22461049197427, -10.53398747977001, -30.}, {
         38.3427777459768, -10.777394911619188`, -30.}, {
         40.460944999979326`, -11.020802343468366`, -30.}, {
         42.57911225398186, -11.264209775317545`, -30.}, {
         44.69727950798439, -11.507617207166723`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.127502075288106`, -10.10852909525782, -30.}, {
         36.26672816660702, -10.169885574443985`, -30.}, {
         38.40595425792593, -10.231242053630151`, -30.}, {
         40.54518034924483, -10.292598532816317`, -30.}, {
         42.68440644056374, -10.353955012002482`, -30.}, {
         44.82363253188265, -10.415311491188648`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.146438430356795`, -9.92647814259481, -30.}, {
         36.304600876744395`, -9.805783669117965, -30.}, {
         38.462763323131995`, -9.685089195641119, -30.}, {
         40.62092576951959, -9.564394722164275, -30.}, {
         42.77908821590719, -9.443700248687431, -30.}, {
         44.93725066229479, -9.323005775210586, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.16325991546132, -9.744427189931796, -30.}, {
         36.33824384695344, -9.441681763791939, -30.}, {
         38.513227778445554`, -9.138936337652082, -30.}, {
         40.68821170993767, -8.836190911512224, -30.}, {
         42.86319564142979, -8.533445485372368, -30.}, {
         45.038179572921905`, -8.230700059232511, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.17797326221665, -9.562376237268785, -30.}, {
         36.3676705404641, -9.077579858465917, -30.}, {
         38.55736781871155, -8.592783479663048, -30.}, {
         40.74706509695899, -8.107987100860178, -30.}, {
         42.93676237520644, -7.623190722057311, -30.}, {
         45.12645965345389, -7.138394343254442, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.19058433519743, -9.380325284605773, -30.}, {
         36.39289268642565, -8.713477953139893, -30.}, {
         38.59520103765387, -8.046630621674012, -30.}, {
         40.7975093888821, -7.379783290208131, -30.}, {
         42.999817740110316`, -6.71293595874225, -30.}, {
         45.20212609133854, -6.04608862727637, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.201098143732686`, -9.198274331942761, -30.}, {
         36.41392030349618, -8.34937604781387, -30.}, {
         38.62674246325966, -7.500477763684977, -30.}, {
         40.83956462302314, -6.651579479556084, -30.}, {
         43.052386782786634`, -5.8026811954271915`, -30.}, {
         45.26520894255012, -4.953782911298299, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.209518851923185`, -9.01622337927975, -30.}, {
         36.43076171987717, -7.985274142487846, -30.}, {
         38.652004587831144`, -6.954324905695943, -30.}, {
         40.873247455785126`, -5.923375668904039, -30.}, {
         43.09449032373911, -4.892426432112135, -30.}, {
         45.315733191693084`, -3.861477195320231, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.21584978692811, -8.834172426616737, -30.}, {
         36.443423589887026`, -7.6211722371618205`, -30.}, {
         38.67099739284593, -6.408172047706905, -30.}, {
         40.89857119580484, -5.195171858251988, -30.}, {
         43.126144998763756`, -3.982171668797071, -30.}, {
         45.353718801722664`, -2.7691714793421554`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.22009344556014, -8.652121473953725, -30.}, {
         36.45191090715108, -7.257070331835797, -30.}, {
         38.683728368742024`, -5.862019189717868, -30.}, {
         40.91554583033296, -4.4669680475999405`, -30.}, {
         43.1473632919239, -3.071916905482012, -30.}, {
         45.379180753514845`, -1.6768657633640824`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.222251499219226`, -8.470070521290713, -30.}, {
         36.45622701446924, -6.892968426509772, -30.}, {
         38.690202529719265`, -5.315866331728831, -30.}, {
         40.92417804496928, -3.7387642369478904`, -30.}, {
         43.158153560219304`, -2.16166214216695, -30.}, {
         45.39212907546933, -0.5845600473860078, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.22232479718802, -8.288019568627702, -30.}, {
         36.45637361040685, -6.528866521183751, -30.}, {
         38.69042242362568, -4.769713473739799, -30.}, {
         40.9244712368445, -3.0105604262958474`, -30.}, {
         43.158520050063316`, -1.251407378851896, -30.}, {45.39256886328214, 
         0.5077456685920563, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.22031336830421, -8.10596861596469, -30.}, {
         36.45235075263923, -6.164764615857726, -30.}, {
         38.684388136974235`, -4.2235606157507615`, -30.}, {
         40.91642552130924, -2.2823566156437973`, -30.}, {
         43.14846290564426, -0.3411526155368332, -30.}, {45.38050028997927, 
         1.600051384570131, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.21621642101719, -7.923917663301678, -30.}, {
         36.44415685806517, -5.800662710531703, -30.}, {
         38.67209729511315, -3.6774077577617277`, -30.}, {
         40.90003773216113, -1.5541528049917517`, -30.}, {43.127978169209115`,
          0.5691021477782243, -30.}, {45.3559186062571, 
         2.6923571005481985`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.21003234182959, -7.741866710638666, -30.}, {
         36.431788699689974`, -5.436560805205677, -30.}, {
         38.65354505755037, -3.1312548997726894`, -30.}, {
         40.87530141541075, -0.8259489943397007, -30.}, {43.097057773271146`, 
         1.479356911093289, -30.}, {45.31881413113153, 
         3.784662816526275, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.201758692116464`, -7.559815757975652, -30.}, {
         36.415241400263724`, -5.072458899879652, -30.}, {
         38.628724108410985`, -2.585102041783651, -30.}, {
         40.842206816558246`, -0.09774518368764973, -30.}, {43.0556895247055, 
         2.38961167440835, -30.}, {45.26917223285277, 
         4.8769685325043515`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.191392203307224`, -7.377764805312641, -30.}, {
         36.394508422645245`, -4.708356994553628, -30.}, {
         38.597624641983266`, -2.0389491837946156`, -30.}, {40.80074086132129,
          0.6304586269643977, -30.}, {43.00385708065931, 
         3.2998664377234093`, -30.}, {45.20697329999733, 
         5.969274248482423, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.17892877040846, -7.195713852649629, -30.}, {
         36.36958155684773, -4.344255089227604, -30.}, {
         38.56023434328699, -1.49279632580558, -30.}, {40.75088712972625, 
         1.3586624376164451`, -30.}, {42.94153991616552, 
         4.21012120103847, -30.}, {45.132192702604776`, 
         7.061579964460494, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.164363443837274`, -7.013662899986617, -30.}, {
         36.34045090370534, -3.9801531839015807`, -30.}, {
         38.51653836357341, -0.9466434678165445, -30.}, {40.692625823441475`, 
         2.0868662482684925`, -30.}, {42.868713283309546`, 
         5.120375964353528, -30.}, {45.04480074317762, 
         8.153885680438565, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.14769041952712, -6.831611947323605, -30.}, {
         36.30710485508504, -3.616051278575557, -30.}, {
         38.466519290642964`, -0.40049060982750895`, -30.}, {
         40.625933726200884`, 2.81507005892054, -30.}, {42.785348161758805`, 
         6.030630727668585, -30.}, {44.944762597316725`, 
         9.246191396416636, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.1289030272598, -6.649560994660593, -30.}, {
         36.2695300705504, -3.2519493732495333`, -30.}, {38.410157113841, 
         0.1456622481615284, -30.}, {40.5507841571316, 
         3.5432738695725874`, -30.}, {42.691411200422195`, 
         6.940885490983648, -30.}, {44.8320382437128, 
         10.33849711239471, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.107993717168185`, -6.467510041997582, -30.}, {
         36.22771145036717, -2.8878474679235104`, -30.}, {38.34742918356615, 
         0.6918151061505622, -30.}, {40.46714691676514, 
         4.271477680224633, -30.}, {42.58686464996412, 
         7.851140254298704, -30.}, {44.7065823831631, 
         11.430802828372778`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.084954044345366`, -6.28545908933457, -30.}, {
         36.18163210472152, -2.5237455625974867`, -30.}, {38.278310165097686`,
          1.237967964139596, -30.}, {40.37498822547384, 
         4.9996814908766805`, -30.}, {42.471666285850006`, 
         8.761395017613763, -30.}, {44.56834434622617, 
         12.523108544350846`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.059774651485796`, -6.103408136671558, -30.}, {
         36.13127331900239, -2.159643657271462, -30.}, {38.20277198651899, 
         1.7841208221286315`, -30.}, {40.27427065403558, 
         5.72788530152873, -30.}, {42.34576932155218, 
         9.671649780928826, -30.}, {44.417267989068776`, 
         13.615414260328917`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.032445249473945`, -5.921357184008546, -30.}, {
         36.076614514978694`, -1.7955417519454375`, -30.}, {
         38.120783780483436`, 2.330273680117669, -30.}, {40.16495304598818, 
         6.456089112180779, -30.}, {42.20912231149292, 
         10.581904544243885`, -30.}, {44.25329157699767, 
         14.707719976306992`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         34.002954595824235`, -5.739306231345536, -30.}, {
         36.017633207679275`, -1.4314398466194174`, -30.}, {
         38.032311819534314`, 2.876426538106701, -30.}, {40.04699043138935, 
         7.184292922832819, -30.}, {42.061669043244386`, 
         11.492159307558941`, -30.}, {44.076347655099426`, 
         15.800025692285056`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.97129047086452, -5.557255278682522, -30.}, {
         35.95430495775983, -1.06733794129339, -30.}, {37.937319444655145`, 
         3.42257939609574, -30.}, {39.92033393155046, 
         7.912496733484874, -30.}, {41.90334841844577, 
         12.402414070874004`, -30.}, {43.88636290534109, 
         16.892331408263132`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.93743965154179, -5.37520432601951, -30.}, {
         35.88660331911437, -0.7032360359673664, -30.}, {37.83576698668696, 
         3.9687322540847774`, -30.}, {39.78493065425955, 
         8.640700544136921, -30.}, {41.73409432183213, 
         13.312668834189067`, -30.}, {43.68325798940472, 
         17.98463712424121, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.90138788271505, -5.193153373356498, -30.}, {
         35.8144997814609, -0.3391341306413427, -30.}, {37.727611680206756`, 
         4.514885112073813, -30.}, {39.6407235789526, 
         9.368904354788969, -30.}, {41.553835477698456`, 
         14.222923597504122`, -30.}, {43.4669473764443, 
         19.07694284021928, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.86311984578428, -5.011102420693486, -30.}, {35.73796370759936, 
         0.024967774684681032`, -30.}, {37.61280756941445, 
         5.0610379700628485`, -30.}, {39.48765143122953, 
         10.097108165441016`, -30.}, {41.36249529304461, 
         15.133178360819182`, -30.}, {43.2373391548597, 
         20.169248556197353`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.822619124487915`, -4.829051468030475, -30.}, {35.656962265006634`,
          0.38906968001070474`, -30.}, {37.491305405525345`, 
         5.607190828051882, -30.}, {39.32564854604406, 
         10.825311976093063`, -30.}, {41.159991686562776`, 
         16.043433124134246`, -30.}, {42.99433482708149, 
         21.261554272175417`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.77986816768223, -4.647000515367462, -30.}, {35.57146035139526, 
         0.7531715853367302, -30.}, {37.36305253510829, 
         6.153343686040921, -30.}, {39.15464471882132, 
         11.553515786745114`, -30.}, {40.946236902534345`, 
         16.953687887449306`, -30.}, {42.73782908624737, 
         22.353859988153495`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.734848248895744`, -4.464949562704451, -30.}, {35.481420513822286`,
          1.1172734906627522`, -30.}, {37.22799277874883, 
         6.699496544029957, -30.}, {38.97456504367537, 
         12.281719597397158`, -30.}, {40.72113730860191, 
         17.863942650764365`, -30.}, {42.46770957352845, 
         23.446165704131566`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.687539422428756`, -4.282898610041438, -30.}, {35.38680286088832, 
         1.4813753959887777`, -30.}, {37.08606629934787, 
         7.2456494020189925`, -30.}, {38.78532973780743, 
         13.00992340804921, -30.}, {40.48459317626698, 
         18.774197414079424`, -30.}, {42.183856614726544`, 
         24.538471420109637`, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.637920475743236`, -4.100847657378428, -30.}, {35.28756496751727, 
         1.8454773013147978`, -30.}, {36.9372094592913, 
         7.791802260008025, -30.}, {38.586853951065336`, 
         13.73812721870125, -30.}, {40.23649844283938, 
         19.684452177394476`, -30.}, {41.88614293461341, 
         25.6307771360877, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.585968877859976`, -3.9187967047154144`, -30.}, {35.18366177175075,
          2.209579206640825, -30.}, {36.78135466564152, 
         8.337955117997064, -30.}, {38.379047559532296`, 
         14.466331029353304`, -30.}, {39.97674045342307, 
         20.594706940709543`, -30.}, {41.57443334731384, 
         26.72308285206578, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.5316607234491, -3.7367457520524034`, -30.}, {35.075045462929005`, 
         2.573681111966847, -30.}, {36.6184302024089, 
         8.8841079759861, -30.}, {38.1618149418888, 
         15.194534840005348`, -30.}, {39.705199681368704`, 
         21.504961704024595`, -30.}, {41.2485844208486, 
         27.81538856804385, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.47497067226483, -3.5546947993893907`, -30.}, {34.96166536056045, 
         2.9377830172928725`, -30.}, {36.44836004885608, 
         9.430260833975135, -30.}, {37.93505473715171, 
         15.922738650657399`, -30.}, {39.42174942544734, 
         22.41521646733966, -30.}, {40.90844411374296, 
         28.90769428402192, -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.415871883536695`, -3.372643846726379, -30.}, {34.84346778310419, 
         3.301884922618896, -30.}, {36.27106368267168, 
         9.976413691964174, -30.}, {37.69865958223917, 
         16.650942461309448`, -30.}, {39.126255481806666`, 
         23.32547123065472, -30.}, {40.553851381374166`, 30., -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{31.988275983969203`, -10.047172616071654`, -30.}, {
         33.415871883536695`, -3.372643846726379, -30.}, {34.84346778310419, 
         3.301884922618896, -30.}, {36.27106368267168, 
         9.976413691964174, -30.}, {37.69865958223917, 
         16.650942461309448`, -30.}, {39.126255481806666`, 
         23.32547123065472, -30.}, {40.553851381374166`, 30., -30.}, {
         31.988275983969203`, -10.047172616071654`, -30.}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxd1As0VHkYAPApFD08ll2PjZAa8poxHsOo+TzuRVm76TWjaTxLSJKJUZIK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         "]]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
         26.65689665330767, -3.372643846726379, 30.}, {21.325517322646135`, 
         3.301884922618896, 30.}, {15.9941379919846, 9.97641369196417, 30.}, {
         10.662758661323068`, 16.650942461309448`, 30.}, {5.33137933066153, 
         23.32547123065472, 30.}, {0., 29.999999999999993`, 30.}, {
         31.988275983969203`, -10.047172616071654`, 30.}}], 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          26.65689665330767, -11.798285743622072`, 30.}, {
          21.325517322646135`, -13.54939887117249, 30.}, {
          15.994137991984601`, -15.30051199872291, 30.}, {
          10.662758661323071`, -17.05162512627333, 30.}, {
          5.331379330661537, -18.802738253823748`, 30.}, {
          3.552713678800501*^-15, -20.553851381374166`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          26.65689665330767, -11.79828574362207, 30.}, {
          21.325517322646135`, -13.549398871172489`, 30.}, {
          15.994137991984598`, -15.300511998722907`, 30.}, {
          10.662758661323068`, -17.051625126273322`, 30.}, {
          5.331379330661534, -18.80273825382374, 
          30.}, {-3.552713678800501*^-15, -20.55385138137416, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          26.797441236887803`, -11.844123395287172`, 30.}, {
          21.606606489806403`, -13.64107417450269, 30.}, {
          16.415771742725006`, -15.438024953718207`, 30.}, {
          11.22493699564361, -17.234975732933727`, 30.}, {
          6.03410224856221, -19.031926512149244`, 30.}, {
          0.8432675014808169, -20.828877291364762`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          26.93798582046794, -11.888521707558574`, 30.}, {
          21.887695656966677`, -13.729870799045493`, 30.}, {
          16.83740549346541, -15.571219890532415`, 30.}, {
          11.787115329964152`, -17.412568982019334`, 30.}, {
          6.736825166462889, -19.253918073506256`, 30.}, {
          1.6865350029616266`, -21.095267164993174`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.078530404048074`, -11.931493271983113`, 30.}, {
          22.16878482412695, -13.81581392789457, 30.}, {
          17.259039244205816`, -15.70013458380603, 30.}, {
          12.349293664284694`, -17.58445523971749, 30.}, {
          7.439548084363565, -19.468775895628944`, 30.}, {
          2.5298025044424364`, -21.353096551540403`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.21907498762821, -11.973050135980362`, 30.}, {
          22.44987399128722, -13.898927655889072`, 30.}, {
          17.680672994946228`, -15.82480517579778, 30.}, {
          12.911471998605236`, -17.750682695706487`, 30.}, {
          8.142271002264241, -19.676560215615197`, 30.}, {
          3.3730700059232532`, -21.602437735523907`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.359619571208345`, -12.013203821664051`, 30.}, {
          22.730963158447487`, -13.979235027256449`, 30.}, {
          18.102306745686633`, -15.945266232848846`, 30.}, {
          13.473650332925775`, -17.911297438441245`, 30.}, {
          8.844993920164917, -19.877328644033643`, 30.}, {
          4.216337507404063, -21.84335984962604, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.500164154788482`, -12.05196534353528, 30.}, {
          23.012052325607762`, -14.056758070998905`, 30.}, {
          18.523940496427038`, -16.06155079846253, 30.}, {
          14.035828667246319`, -18.066343525926158`, 30.}, {
          9.547716838065604, -20.07113625338978, 30.}, {
          5.05960500888488, -22.075928980853405`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.640708738368616`, -12.089345225116531`, 30.}, {
          23.293141492768033`, -14.131517834161409`, 30.}, {
          18.945574247167446`, -16.173690443206286`, 30.}, {
          14.598007001566861`, -18.215863052251166`, 30.}, {
          10.250439755966276`, -20.25803566129604, 30.}, {
          5.902872510365693, -22.300208270340917`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.781253321948753`, -12.125353514589941`, 30.}, {
          23.5742306599283, -14.20353441310823, 30.}, {
          19.36720799790785, -16.281715311626517`, 30.}, {
          15.1601853358874, -18.359896210144804`, 30.}, {
          10.953162673866952`, -20.43807710866309, 30.}, {
          6.746140011846503, -22.516258007181378`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          27.921797905528887`, -12.159999799498287`, 30.}, {
          23.855319827088575`, -14.272826982924919`, 30.}, {
          19.78884174864826, -16.385654166351554`, 30.}, {
          15.722363670207946`, -18.498481349778185`, 30.}, {
          11.655885591767635`, -20.61130853320482, 30.}, {
          7.58940751332732, -22.72413571663145, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.06234248910902, -12.193293220562662`, 30.}, {
          24.136408994248843`, -14.339413825053672`, 30.}, {
          20.21047549938866, -16.485534429544682`, 30.}, {
          16.284542004528483`, -18.63165503403569, 30.}, {
          12.3586085096683, -20.7777756385267, 30.}, {
          8.432675014808122, -22.92389624301771, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.20288707268916, -12.22524248466654, 30.}, {
          24.417498161409114`, -14.403312353261427`, 30.}, {
          20.632109250129073`, -16.581382221856312`, 30.}, {
          16.84672033884903, -18.759452090451198`, 30.}, {
          13.061331427568987`, -20.937521959046084`, 30.}, {
          9.275942516288946, -23.11559182764097, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.343431656269292`, -12.25585587705215, 30.}, {
          24.698587328569385`, -14.464539138032649`, 30.}, {
          21.053743000869474`, -16.673222399013145`, 30.}, {
          17.408898673169567`, -18.88190565999364, 30.}, {
          13.76405434546966, -21.090588920974138`, 30.}, {
          10.119210017769749`, -23.299272181954635`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.48397623984943, -12.285141272771419`, 30.}, {
          24.979676495729656`, -14.523109929471183`, 30.}, {
          21.475376751609883`, -16.76107858617095, 30.}, {
          17.97107700749011, -18.999047242870713`, 30.}, {
          14.466777263370341`, -21.237015899570476`, 30.}, {
          10.962477519250566`, -23.474984556270243`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.624520823429563`, -12.313106147430645`, 30.}, {
          25.260765662889927`, -14.579039678789634`, 30.}, {
          21.89701050235029, -16.844973210148623`, 30.}, {
          18.53325534181065, -19.110906741507616`, 30.}, {
          15.169500181271014`, -21.376840272866605`, 30.}, {
          11.80574502073138, -23.642773804225598`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.7650654070097, -12.339757587264891`, 30.}, {
          25.541854830050198`, -14.632342558458127`, 30.}, {
          22.318644253090696`, -16.924927529651363`, 30.}, {
          19.095433676131194`, -19.217512500844602`, 30.}, {
          15.87222309917169, -21.510097472037838`, 30.}, {
          12.649012522212189`, -23.802682443231078`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          28.905609990589834`, -12.365102298575394`, 30.}, {
          25.82294399721047, -14.683031981079132`, 30.}, {
          22.740278003831104`, -17.00096166358287, 30.}, {
          19.657612010451736`, -19.318891346086613`, 30.}, {
          16.57494601707237, -21.63682102859035, 30.}, {
          13.492280023693006`, -23.95475071109409, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.04615457416997, -12.38914661656066, 30.}, {
          26.10403316437074, -14.731120617049669`, 30.}, {
          23.16191175457151, -17.073094617538676`, 30.}, {
          20.219790344772278`, -19.415068618027682`, 30.}, {
          17.277668934973043`, -21.75704261851669, 30.}, {
          14.335547525173814`, -24.099016619005695`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.186699157750105`, -12.411896513569575`, 30.}, {
          26.38512233153101, -14.776620411067498`, 30.}, {
          23.583545505311914`, -17.14134430856542, 30.}, {
          20.78196867909282, -19.50606820606334, 30.}, {
          17.980391852873726`, -21.87079210356126, 30.}, {
          15.178815026654627`, -24.23551600105918, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.327243741330243`, -12.433357606802524`, 30.}, {
          26.666211498691283`, -14.819542597533392`, 30.}, {
          24.005179256052323`, -17.205727588264264`, 30.}, {
          21.344147013413362`, -19.59191257899513, 30.}, {
          18.683114770774402`, -21.978097569726003`, 30.}, {
          16.022082528135442`, -24.36428256045687, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.467788324910376`, -12.453535165484606`, 30.}, {
          26.947300665851554`, -14.85989771489756, 30.}, {
          24.42681300679273, -17.26626026431051, 30.}, {
          21.906325347733905`, -19.672622813723464`, 30.}, {
          19.385837688675082`, -22.078985363136418`, 30.}, {
          16.86535002961626, -24.485347912549372`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.608332908490514`, -12.472434117532966`, 30.}, {
          27.228389833011825`, -14.89769561899428, 30.}, {
          24.848446757533136`, -17.32295712045559, 30.}, {
          22.468503682054447`, -19.748218621916905`, 30.}, {
          20.088560606575758`, -22.17348012337822, 30.}, {
          17.70861753109707, -24.598741624839533`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.748877492070648`, -12.490059055738456`, 30.}, {
          27.509479000172096`, -14.932945495405258`, 30.}, {
          25.270080508273544`, -17.37583193507206, 30.}, {
          23.03068201637499, -19.818718374738864`, 30.}, {
          20.791283524476437`, -22.261604814405665`, 30.}, {
          18.551885032577882`, -24.70449125407247, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          29.889422075650785`, -12.50641424348028, 30.}, {
          27.790568167332367`, -14.965655870888908`, 30.}, {
          25.691714259013946`, -17.424897498297536`, 30.}, {
          23.592860350695528`, -19.884139125706163`, 30.}, {
          21.494006442377113`, -22.343380753114786`, 30.}, {
          19.39515253405869, -24.802622380523417`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.02996665923092, -12.521503619990543`, 30.}, {
          28.071657334492635`, -14.995834623909435`, 30.}, {
          26.113348009754354`, -17.470165627828326`, 30.}, {
          24.15503868501607, -19.944496631747214`, 30.}, {
          22.19672936027779, -22.418827635666105`, 30.}, {
          20.238420035539505`, -24.893158639584996`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.170511242811056`, -12.535330805184163`, 30.}, {
          28.35274650165291, -15.023488994296674`, 30.}, {
          26.534981760494762`, -17.51164718340918, 30.}, {
          24.717217019336616`, -19.999805372521692`, 30.}, {
          22.899452278178465`, -22.487963561634203`, 30.}, {
          21.081687537020322`, -24.97612175074671, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.31105582639119, -12.547899104068254`, 30.}, {
          28.633835668813177`, -15.048625592064855`, 30.}, {
          26.956615511235167`, -17.549352080061457`, 30.}, {
          25.279395353657154`, -20.050078568058055`, 30.}, {
          23.602175196079145`, -22.550805056054656`, 30.}, {
          21.924955038501132`, -25.051531544051258`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.451600409971327`, -12.559211510743689`, 30.}, {
          28.914924835973448`, -15.071250405415725`, 30.}, {
          27.378249261975576`, -17.58328930008776, 30.}, {
          25.841573687977696`, -20.095328194759794`, 30.}, {
          24.30489811397982, -22.60736708943183, 30.}, {
          22.768222539981945`, -25.119405984103864`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.59214499355146, -12.569270712010262`, 30.}, {
          29.19601400313372, -15.091368807948871`, 30.}, {
          27.79988301271598, -17.61346690388748, 30.}, {
          26.40375202229824, -20.135564999826087`, 30.}, {
          25.0076210318805, -22.657663095764697`, 30.}, {
          23.61149004146276, -25.179761191703307`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.732689577131595`, -12.578079090585735`, 30.}, {
          29.47710317029399, -15.108985565099818`, 30.}, {
          28.221516763456385`, -17.6398920396139, 30.}, {
          26.965930356618777`, -20.17079851412798, 30.}, {
          25.710343949781173`, -22.701704988642064`, 30.}, {
          24.454757542943568`, -25.232611463156147`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          30.873234160711732`, -12.585638727947819`, 30.}, {
          29.75819233745426, -15.124104839823985`, 30.}, {
          28.64315051419679, -17.66257095170015, 30.}, {
          27.528108690939323`, -20.201037063576315`, 30.}, {
          26.413066867681852`, -22.73950317545248, 30.}, {
          25.29802504442438, -25.277969287328645`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.01377874429187, -12.591951406807057`, 30.}, {
          30.039281504614532`, -15.136730197542459`, 30.}, {
          29.0647842649372, -17.681508988277862`, 30.}, {
          28.090287025259865`, -20.226287779013266`, 30.}, {
          27.115789785582532`, -22.77106656974867, 30.}, {
          26.1412925459052, -25.31584536048407, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.154323327872003`, -12.597018613217523`, 30.}, {
          30.320370671774803`, -15.146864610363393`, 30.}, {
          29.486418015677604`, -17.69671060750926, 30.}, {
          28.652465359580404`, -20.246556604655133`, 30.}, {
          27.818512703483208`, -22.796402601801, 30.}, {
          26.984560047386008`, -25.34624859894687, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.294867911452137`, -12.600841538331169`, 30.}, {
          30.601459838935074`, -15.154510460590684`, 30.}, {
          29.908051766418012`, -17.708179382850197`, 30.}, {
          29.21464369390095, -20.261848305109716`, 30.}, {
          28.521235621383884`, -22.815517227369227`, 30.}, {
          27.82782754886682, -25.369186149628746`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.435412495032274`, -12.603421079800665`, 30.}, {
          30.882549006095346`, -15.159669543529677`, 30.}, {
          30.329685517158417`, -17.715918007258686`, 30.}, {
          29.776822028221492`, -20.2721664709877, 30.}, {
          29.223958539284563`, -22.82841493471671, 30.}, {
          28.671095050347635`, -25.384663398445724`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.57595707861241, -12.604757842834637`, 30.}, {
          31.16363817325562, -15.162343069597618`, 30.}, {
          30.751319267898825`, -17.719928296360603`, 30.}, {
          30.339000362542034`, -20.277513523123584`, 30.}, {
          29.926681457185243`, -22.83509874988657, 30.}, {
          29.51436255182845, -25.39268397664955, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.716501662192545`, -12.604852140908154`, 30.}, {
          31.444727340415888`, -15.162531665744655`, 30.}, {
          31.17295301863923, -17.720211190581153`, 30.}, {
          30.901178696862573`, -20.277890715417655`, 30.}, {
          30.629404375085915`, -22.835570240254157`, 30.}, {
          30.357630053309258`, -25.393249765090655`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.85704624577268, -12.603703996130424`, 30.}, {
          31.72581650757616, -15.160235376189195`, 30.}, {
          31.594586769379635`, -17.716766756247967`, 30.}, {
          31.463357031183115`, -20.273298136306735`, 30.}, {
          31.33212729298659, -22.829829516365507`, 30.}, {
          31.20089755479007, -25.38636089642428, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          31.997590829352816`, -12.601313139270724`, 30.}, {
          32.00690567473643, -15.155453662469794`, 30.}, {
          32.016220520120044`, -17.709594185668863`, 30.}, {
          32.02553536550366, -20.263734708867936`, 30.}, {
          32.03485021088727, -22.817875232067003`, 30.}, {
          32.044165056270884`, -25.372015755266073`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.138135412932954`, -12.597679009442619`, 30.}, {
          32.2879948418967, -15.148185402813585`, 30.}, {
          32.43785427086045, -17.698691796184548`, 30.}, {
          32.58771369982419, -20.249198189555514`, 30.}, {
          32.73757312878794, -22.79970458292648, 30.}, {
          32.887432557751694`, -25.350210976297447`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.278679996513084`, -12.592800753445617`, 30.}, {
          32.56908400905697, -15.138428890819583`, 30.}, {
          32.85948802160085, -17.684057028193546`, 30.}, {
          33.14989203414474, -20.22968516556751, 30.}, {
          33.44029604668863, -22.775313302941473`, 30.}, {
          33.73070005923251, -25.320941440315437`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.41922458009322, -12.586677224762418`, 30.}, {
          32.85017317621724, -15.126181833453181`, 30.}, {
          33.281121772341265`, -17.665686442143944`, 30.}, {
          33.712070368465284`, -20.205191050834706`, 30.}, {
          34.1430189645893, -22.744695659525473`, 30.}, {
          34.57396756071332, -25.28420026821624, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.55976916367336, -12.579306982209092`, 30.}, {
          33.131262343377514`, -15.11144134834653, 30.}, {
          33.70275552308167, -17.643575714483966`, 30.}, {
          34.274248702785826`, -20.175710080621407`, 30.}, {
          34.84574188248998, -22.70784444675884, 30.}, {
          35.41723506219414, -25.239978812896283`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.700313747253496`, -12.57068828823434, 30.}, {
          33.41235151053778, -15.094203960397028`, 30.}, {
          34.124389273822075`, -17.617719632559712`, 30.}, {
          34.83642703710637, -20.1412353047224, 30.}, {
          35.548464800390654`, -22.664750976885088`, 30.}, {
          36.26050256367495, -25.188266649047776`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.840858330833626`, -12.56081910686326, 30.}, {
          33.69344067769806, -15.074465597654868`, 30.}, {
          34.54602302456248, -17.588112088446476`, 30.}, {
          35.39860537142691, -20.10175857923808, 30.}, {
          36.251187718291334`, -22.615405070029688`, 30.}, {
          37.103770065155764`, -25.129051560821296`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          32.98140291441376, -12.549697101279872`, 30.}, {
          33.974529844858324`, -15.052221586488091`, 30.}, {
          34.967656775302885`, -17.554746071696307`, 30.}, {
          35.960783705747446`, -20.057270556904527`, 30.}, {
          36.95391063619201, -22.559795042112746`, 30.}, {
          37.947037566636574`, -25.062319527320966`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.1219474979939, -12.53731963104162, 30.}, {
          34.2556190120186, -15.027466646011588`, 30.}, {
          35.3892905260433, -17.517613660981553`, 30.}, {
          36.52296204006799, -20.007760675951523`, 30.}, {
          37.656633554092686`, -22.497907690921487`, 30.}, {
          38.790305068117384`, -24.988054705891457`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.26249208157404, -12.523683748918167`, 30.}, {
          34.536708179178866`, -15.000194881764678`, 30.}, {
          35.8109242767837, -17.476706014611192`, 30.}, {
          37.08514037438854, -19.953217147457703`, 30.}, {
          38.359356471993365`, -22.429728280304214`, 30.}, {
          39.6335725695982, -24.90623941315073, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.40303666515417, -12.508786197345417`, 30.}, {
          34.817797346339134`, -14.97039977861918, 30.}, {
          36.23255802752411, -17.432013359892945`, 30.}, {
          37.64731870870907, -19.89362694116671, 30.}, {
          39.06207938989404, -22.355240522440468`, 30.}, {
          40.47684007107901, -24.816854103714235`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.543581248734306`, -12.492623404484885`, 30.}, {
          35.09888651349941, -14.938074192898117`, 30.}, {
          36.65419177826452, -17.38352498131135, 30.}, {
          38.20949704302962, -19.82897576972458, 30.}, {
          39.764802307794724`, -22.27442655813781, 30.}, {
          41.32010757255983, -24.719877346551044`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.68412583231444, -12.475191479876976`, 30.}, {
          35.37997568065968, -14.903210343682296`, 30.}, {
          37.075825529004916`, -17.331229207487617`, 30.}, {
          38.77167537735016, -19.759248071292937`, 30.}, {
          40.4675252256954, -22.18726693509826, 30.}, {
          42.16337507404064, -24.615285798903585`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.68412583231444, -12.475191479876976`, 30.}, {
          35.37997568065968, -14.9032103436823, 30.}, {
          37.07582552900492, -17.33122920748762, 30.}, {
          38.771675377350164`, -19.759248071292944`, 30.}, {
          40.4675252256954, -22.187266935098265`, 30.}, {
          42.163375074040644`, -24.61528579890359, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.731596405221254`, -12.293140527213964`, 30.}, {
          35.474916826473304`, -14.539108438356275`, 30.}, {
          37.218237247725355`, -16.785076349498585`, 30.}, {
          38.961557668977406`, -19.031044260640897`, 30.}, {
          40.70487809022946, -21.277012171783205`, 30.}, {
          42.4481985114815, -23.522980082925514`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.77677662070529, -12.111089574550952`, 30.}, {
          35.56527725744137, -14.175006533030253`, 30.}, {
          37.35377789417746, -16.23892349150955, 30.}, {
          39.14227853091355, -18.30284044998885, 30.}, {
          40.93077916764963, -20.366757408468146`, 30.}, {
          42.71927980438572, -22.430674366947446`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.81968651195307, -11.92903862188794, 30.}, {
          35.65109703993694, -13.810904627704225`, 30.}, {
          37.48250756792081, -15.692770633520514`, 30.}, {
          39.31391809590468, -17.5746366393368, 30.}, {
          41.14532862388855, -19.456502645153087`, 30.}, {
          42.97673915187242, -21.33836865096937, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.86034488969924, -11.746987669224929`, 30.}, {
          35.73241379542928, -13.446802722378203`, 30.}, {
          37.60448270115933, -15.146617775531478`, 30.}, {
          39.476551606889366`, -16.84643282868475, 30.}, {
          41.348620512619405`, -18.546247881838028`, 30.}, {
          43.22068941834945, -20.2460629349913, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.8987693863792, -11.564936716561917`, 30.}, {
          35.8092627887892, -13.08270081705218, 30.}, {
          37.719756191199195`, -14.600464917542443`, 30.}, {
          39.63024959360919, -16.118229018032707`, 30.}, {
          41.54074299601919, -17.63599311852297, 30.}, {
          43.45123639842919, -19.15375721901323, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.9349764968099, -11.382885763898905`, 30.}, {
          35.88167700965061, -12.718598911726154`, 30.}, {
          37.82837752249131, -14.054312059553403`, 30.}, {
          39.775078035332015`, -15.390025207380654`, 30.}, {
          41.721778548172715`, -16.725738355207906`, 30.}, {
          43.668479061013414`, -18.061451503035155`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.96898161563024, -11.200834811235893`, 30.}, {
          35.94968724729127, -12.35449700640013, 30.}, {
          37.93039287895231, -13.50815920156437, 30.}, {
          39.91109851061335, -14.661821396728609`, 30.}, {
          41.89180414227438, -15.815483591892846`, 30.}, {
          43.87250977393542, -16.969145787057084`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.00079907170949, -11.018783858572881`, 30.}, {
          36.01332215944977, -11.990395101074107`, 30.}, {
          38.025845247190055`, -12.962006343575334`, 30.}, {
          40.03836833493034, -13.93361758607656, 30.}, {
          42.050891422670624`, -14.905228828577787`, 30.}, {
          44.06341451041091, -15.876840071079013`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.03044215971172, -10.83673290590987, 30.}, {
          36.072608335454234`, -11.626293195748083`, 30.}, {
          38.11477451119675, -12.415853485586299`, 30.}, {
          40.156940686939265`, -13.205413775424514`, 30.}, {
          42.19910686268178, -13.994974065262728`, 30.}, {
          44.241273038424296`, -14.784534355100941`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.057923168985226`, -10.654681953246856`, 30.}, {
          36.12757035400126, -11.26219129042206, 30.}, {
          38.19721753901729, -11.869700627597261`, 30.}, {
          40.26686472403331, -12.477209964772463`, 30.}, {
          42.33651190904934, -13.084719301947667`, 30.}, {
          44.40615909406537, -13.692228639122868`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.08325340992887, -10.472631000583846`, 30.}, {
          36.17823083588855, -10.898089385096036`, 30.}, {
          38.273208261848225`, -11.323547769608227`, 30.}, {
          40.368185687807895`, -11.749006154120417`, 30.}, {
          42.46316311376757, -12.17446453863261, 30.}, {
          44.55814053972725, -12.5999229231448, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.10644323797173, -10.290580047920832`, 30.}, {
          36.22461049197427, -10.53398747977001, 30.}, {
          38.3427777459768, -10.777394911619188`, 30.}, {
          40.460944999979326`, -11.020802343468366`, 30.}, {
          42.57911225398186, -11.264209775317545`, 30.}, {
          44.69727950798439, -11.507617207166723`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.127502075288106`, -10.10852909525782, 30.}, {
          36.26672816660702, -10.169885574443985`, 30.}, {
          38.40595425792593, -10.231242053630151`, 30.}, {
          40.54518034924483, -10.292598532816317`, 30.}, {
          42.68440644056374, -10.353955012002482`, 30.}, {
          44.82363253188265, -10.415311491188648`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.146438430356795`, -9.92647814259481, 30.}, {
          36.304600876744395`, -9.805783669117965, 30.}, {
          38.462763323131995`, -9.685089195641119, 30.}, {
          40.62092576951959, -9.564394722164275, 30.}, {
          42.77908821590719, -9.443700248687431, 30.}, {
          44.93725066229479, -9.323005775210586, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.16325991546132, -9.744427189931796, 30.}, {
          36.33824384695344, -9.441681763791939, 30.}, {
          38.513227778445554`, -9.138936337652082, 30.}, {
          40.68821170993767, -8.836190911512224, 30.}, {
          42.86319564142979, -8.533445485372368, 30.}, {
          45.038179572921905`, -8.230700059232511, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.17797326221665, -9.562376237268785, 30.}, {
          36.3676705404641, -9.077579858465917, 30.}, {
          38.55736781871155, -8.592783479663048, 30.}, {
          40.74706509695899, -8.107987100860178, 30.}, {
          42.93676237520644, -7.623190722057311, 30.}, {
          45.12645965345389, -7.138394343254442, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.19058433519743, -9.380325284605773, 30.}, {
          36.39289268642565, -8.713477953139893, 30.}, {
          38.59520103765387, -8.046630621674012, 30.}, {
          40.7975093888821, -7.379783290208131, 30.}, {
          42.999817740110316`, -6.71293595874225, 30.}, {
          45.20212609133854, -6.04608862727637, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.201098143732686`, -9.198274331942761, 30.}, {
          36.41392030349618, -8.34937604781387, 30.}, {
          38.62674246325966, -7.500477763684977, 30.}, {
          40.83956462302314, -6.651579479556084, 30.}, {
          43.052386782786634`, -5.8026811954271915`, 30.}, {
          45.26520894255012, -4.953782911298299, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.209518851923185`, -9.01622337927975, 30.}, {
          36.43076171987717, -7.985274142487846, 30.}, {
          38.652004587831144`, -6.954324905695943, 30.}, {
          40.873247455785126`, -5.923375668904039, 30.}, {
          43.09449032373911, -4.892426432112135, 30.}, {
          45.315733191693084`, -3.861477195320231, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.21584978692811, -8.834172426616737, 30.}, {
          36.443423589887026`, -7.6211722371618205`, 30.}, {
          38.67099739284593, -6.408172047706905, 30.}, {
          40.89857119580484, -5.195171858251988, 30.}, {
          43.126144998763756`, -3.982171668797071, 30.}, {
          45.353718801722664`, -2.7691714793421554`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.22009344556014, -8.652121473953725, 30.}, {
          36.45191090715108, -7.257070331835797, 30.}, {
          38.683728368742024`, -5.862019189717868, 30.}, {
          40.91554583033296, -4.4669680475999405`, 30.}, {
          43.1473632919239, -3.071916905482012, 30.}, {
          45.379180753514845`, -1.6768657633640824`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.222251499219226`, -8.470070521290713, 30.}, {
          36.45622701446924, -6.892968426509772, 30.}, {
          38.690202529719265`, -5.315866331728831, 30.}, {
          40.92417804496928, -3.7387642369478904`, 30.}, {
          43.158153560219304`, -2.16166214216695, 30.}, {
          45.39212907546933, -0.5845600473860078, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.22232479718802, -8.288019568627702, 30.}, {
          36.45637361040685, -6.528866521183751, 30.}, {
          38.69042242362568, -4.769713473739799, 30.}, {
          40.9244712368445, -3.0105604262958474`, 30.}, {
          43.158520050063316`, -1.251407378851896, 30.}, {45.39256886328214, 
          0.5077456685920563, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.22031336830421, -8.10596861596469, 30.}, {
          36.45235075263923, -6.164764615857726, 30.}, {
          38.684388136974235`, -4.2235606157507615`, 30.}, {
          40.91642552130924, -2.2823566156437973`, 30.}, {
          43.14846290564426, -0.3411526155368332, 30.}, {45.38050028997927, 
          1.600051384570131, 30.}, {31.988275983969203`, -10.047172616071654`,
           30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.21621642101719, -7.923917663301678, 30.}, {
          36.44415685806517, -5.800662710531703, 30.}, {
          38.67209729511315, -3.6774077577617277`, 30.}, {
          40.90003773216113, -1.5541528049917517`, 30.}, {43.127978169209115`,
           0.5691021477782243, 30.}, {45.3559186062571, 2.6923571005481985`, 
          30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.21003234182959, -7.741866710638666, 30.}, {
          36.431788699689974`, -5.436560805205677, 30.}, {
          38.65354505755037, -3.1312548997726894`, 30.}, {
          40.87530141541075, -0.8259489943397007, 30.}, {43.097057773271146`, 
          1.479356911093289, 30.}, {45.31881413113153, 3.784662816526275, 
          30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.201758692116464`, -7.559815757975652, 30.}, {
          36.415241400263724`, -5.072458899879652, 30.}, {
          38.628724108410985`, -2.585102041783651, 30.}, {
          40.842206816558246`, -0.09774518368764973, 30.}, {43.0556895247055, 
          2.38961167440835, 30.}, {45.26917223285277, 4.8769685325043515`, 
          30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.191392203307224`, -7.377764805312641, 30.}, {
          36.394508422645245`, -4.708356994553628, 30.}, {
          38.597624641983266`, -2.0389491837946156`, 30.}, {40.80074086132129,
           0.6304586269643977, 30.}, {43.00385708065931, 3.2998664377234093`, 
          30.}, {45.20697329999733, 5.969274248482423, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.17892877040846, -7.195713852649629, 30.}, {
          36.36958155684773, -4.344255089227604, 30.}, {
          38.56023434328699, -1.49279632580558, 30.}, {40.75088712972625, 
          1.3586624376164451`, 30.}, {42.94153991616552, 4.21012120103847, 
          30.}, {45.132192702604776`, 7.061579964460494, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.164363443837274`, -7.013662899986617, 30.}, {
          36.34045090370534, -3.9801531839015807`, 30.}, {
          38.51653836357341, -0.9466434678165445, 30.}, {40.692625823441475`, 
          2.0868662482684925`, 30.}, {42.868713283309546`, 5.120375964353528, 
          30.}, {45.04480074317762, 8.153885680438565, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.14769041952712, -6.831611947323605, 30.}, {
          36.30710485508504, -3.616051278575557, 30.}, {
          38.466519290642964`, -0.40049060982750895`, 30.}, {
          40.625933726200884`, 2.81507005892054, 30.}, {42.785348161758805`, 
          6.030630727668585, 30.}, {44.944762597316725`, 9.246191396416636, 
          30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.1289030272598, -6.649560994660593, 30.}, {
          36.2695300705504, -3.2519493732495333`, 30.}, {38.410157113841, 
          0.1456622481615284, 30.}, {40.5507841571316, 3.5432738695725874`, 
          30.}, {42.691411200422195`, 6.940885490983648, 30.}, {
          44.8320382437128, 10.33849711239471, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.107993717168185`, -6.467510041997582, 30.}, {
          36.22771145036717, -2.8878474679235104`, 30.}, {38.34742918356615, 
          0.6918151061505622, 30.}, {40.46714691676514, 4.271477680224633, 
          30.}, {42.58686464996412, 7.851140254298704, 30.}, {
          44.7065823831631, 11.430802828372778`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.084954044345366`, -6.28545908933457, 30.}, {
          36.18163210472152, -2.5237455625974867`, 30.}, {38.278310165097686`,
           1.237967964139596, 30.}, {40.37498822547384, 4.9996814908766805`, 
          30.}, {42.471666285850006`, 8.761395017613763, 30.}, {
          44.56834434622617, 12.523108544350846`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.059774651485796`, -6.103408136671558, 30.}, {
          36.13127331900239, -2.159643657271462, 30.}, {38.20277198651899, 
          1.7841208221286315`, 30.}, {40.27427065403558, 5.72788530152873, 
          30.}, {42.34576932155218, 9.671649780928826, 30.}, {
          44.417267989068776`, 13.615414260328917`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.032445249473945`, -5.921357184008546, 30.}, {
          36.076614514978694`, -1.7955417519454375`, 30.}, {
          38.120783780483436`, 2.330273680117669, 30.}, {40.16495304598818, 
          6.456089112180779, 30.}, {42.20912231149292, 10.581904544243885`, 
          30.}, {44.25329157699767, 14.707719976306992`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          34.002954595824235`, -5.739306231345536, 30.}, {
          36.017633207679275`, -1.4314398466194174`, 30.}, {
          38.032311819534314`, 2.876426538106701, 30.}, {40.04699043138935, 
          7.184292922832819, 30.}, {42.061669043244386`, 11.492159307558941`, 
          30.}, {44.076347655099426`, 15.800025692285056`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.97129047086452, -5.557255278682522, 30.}, {
          35.95430495775983, -1.06733794129339, 30.}, {37.937319444655145`, 
          3.42257939609574, 30.}, {39.92033393155046, 7.912496733484874, 
          30.}, {41.90334841844577, 12.402414070874004`, 30.}, {
          43.88636290534109, 16.892331408263132`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.93743965154179, -5.37520432601951, 30.}, {
          35.88660331911437, -0.7032360359673664, 30.}, {37.83576698668696, 
          3.9687322540847774`, 30.}, {39.78493065425955, 8.640700544136921, 
          30.}, {41.73409432183213, 13.312668834189067`, 30.}, {
          43.68325798940472, 17.98463712424121, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.90138788271505, -5.193153373356498, 30.}, {
          35.8144997814609, -0.3391341306413427, 30.}, {37.727611680206756`, 
          4.514885112073813, 30.}, {39.6407235789526, 9.368904354788969, 
          30.}, {41.553835477698456`, 14.222923597504122`, 30.}, {
          43.4669473764443, 19.07694284021928, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.86311984578428, -5.011102420693486, 30.}, {35.73796370759936, 
          0.024967774684681032`, 30.}, {37.61280756941445, 
          5.0610379700628485`, 30.}, {39.48765143122953, 10.097108165441016`, 
          30.}, {41.36249529304461, 15.133178360819182`, 30.}, {
          43.2373391548597, 20.169248556197353`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.822619124487915`, -4.829051468030475, 30.}, {35.656962265006634`,
           0.38906968001070474`, 30.}, {37.491305405525345`, 
          5.607190828051882, 30.}, {39.32564854604406, 10.825311976093063`, 
          30.}, {41.159991686562776`, 16.043433124134246`, 30.}, {
          42.99433482708149, 21.261554272175417`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.77986816768223, -4.647000515367462, 30.}, {35.57146035139526, 
          0.7531715853367302, 30.}, {37.36305253510829, 6.153343686040921, 
          30.}, {39.15464471882132, 11.553515786745114`, 30.}, {
          40.946236902534345`, 16.953687887449306`, 30.}, {42.73782908624737, 
          22.353859988153495`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.734848248895744`, -4.464949562704451, 30.}, {35.481420513822286`,
           1.1172734906627522`, 30.}, {37.22799277874883, 6.699496544029957, 
          30.}, {38.97456504367537, 12.281719597397158`, 30.}, {
          40.72113730860191, 17.863942650764365`, 30.}, {42.46770957352845, 
          23.446165704131566`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.687539422428756`, -4.282898610041438, 30.}, {35.38680286088832, 
          1.4813753959887777`, 30.}, {37.08606629934787, 7.2456494020189925`, 
          30.}, {38.78532973780743, 13.00992340804921, 30.}, {
          40.48459317626698, 18.774197414079424`, 30.}, {42.183856614726544`, 
          24.538471420109637`, 30.}, {
          31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.637920475743236`, -4.100847657378428, 30.}, {35.28756496751727, 
          1.8454773013147978`, 30.}, {36.9372094592913, 7.791802260008025, 
          30.}, {38.586853951065336`, 13.73812721870125, 30.}, {
          40.23649844283938, 19.684452177394476`, 30.}, {41.88614293461341, 
          25.6307771360877, 30.}, {31.988275983969203`, -10.047172616071654`, 
          30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.585968877859976`, -3.9187967047154144`, 30.}, {35.18366177175075,
           2.209579206640825, 30.}, {36.78135466564152, 8.337955117997064, 
          30.}, {38.379047559532296`, 14.466331029353304`, 30.}, {
          39.97674045342307, 20.594706940709543`, 30.}, {41.57443334731384, 
          26.72308285206578, 30.}, {31.988275983969203`, -10.047172616071654`,
           30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.5316607234491, -3.7367457520524034`, 30.}, {35.075045462929005`, 
          2.573681111966847, 30.}, {36.6184302024089, 8.8841079759861, 30.}, {
          38.1618149418888, 15.194534840005348`, 30.}, {39.705199681368704`, 
          21.504961704024595`, 30.}, {41.2485844208486, 27.81538856804385, 
          30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.47497067226483, -3.5546947993893907`, 30.}, {34.96166536056045, 
          2.9377830172928725`, 30.}, {36.44836004885608, 9.430260833975135, 
          30.}, {37.93505473715171, 15.922738650657399`, 30.}, {
          39.42174942544734, 22.41521646733966, 30.}, {40.90844411374296, 
          28.90769428402192, 30.}, {31.988275983969203`, -10.047172616071654`,
           30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.415871883536695`, -3.372643846726379, 30.}, {34.84346778310419, 
          3.301884922618896, 30.}, {36.27106368267168, 9.976413691964174, 
          30.}, {37.69865958223917, 16.650942461309448`, 30.}, {
          39.126255481806666`, 23.32547123065472, 30.}, {40.553851381374166`, 
          30., 30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{31.988275983969203`, -10.047172616071654`, 30.}, {
          33.415871883536695`, -3.372643846726379, 30.}, {34.84346778310419, 
          3.301884922618896, 30.}, {36.27106368267168, 9.976413691964174, 
          30.}, {37.69865958223917, 16.650942461309448`, 30.}, {
          39.126255481806666`, 23.32547123065472, 30.}, {40.553851381374166`, 
          30., 30.}, {31.988275983969203`, -10.047172616071654`, 30.}}]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxd1As0lGkYAOCp2FC5LLsuGyEZcpsxLsPQvC7/75K1m24zmsa1REkyMUpS
IURoVdRI92whR7VpqyVKS7qo6bJdluQyaRSV07q2jqnvq/nP+c93znP+837v
977v/xmFxgSsmEyhUKLG3ykU+WcefLtSKFWP3ewac+xq5b1Szg8JCwynj/Sw
le4E/kwXy/sQG6bejg7TsUe+LjBGR9lVAbxt9TPDA7EXTnyvAgXvp/Cc9mMP
vskr2PFcHaCbt7brEXbBRBwtSNnzSmudpgPyjFdbRVkibeDpfVr/xA+7aCK+
HoSb6CaZp2KvnHryWM4yA6A1LxoIvuggt68hZJSK41Ol2KXfr1zinWMMhhFq
0fv0HeXyMQEFXRW9Yj/sY4eFTxqlc8DMZ8vewkTssjyp8Kz1/b3sY9jV6Tv5
8/3MgVn7Z2HSLeyy/OcCb7g7K+oD9jm1xe3Npy1BHGZH5eoykVdMnMsa2lj3
GnxdsIuoHMZJRRpwTjFK3JZjD5k4Lw0eF9TXsZOwm8aEDEScp0PeunwjryLs
ryfqYAuWuX2Z3HPYz/wRdcFsBQNqQ6f9LryFXVYfO/AzWz3tRAd2p7G4xFda
9qAVJNB/OYhdVjd7EEU+tqDPcEJeT2xmnbrmAC5lI2H5Bthl9XSEUsFSsYI1
dr+c9NEoARMs39StyWZh15iosxMI+A1jZl7YH4pzayxMnIHT+sD16a/YD0zU
3xlc6jNqjnKwB88s2iq9z4LSpobhbXzssr64gMRX6pcYir0n7IhH+XZXSAnq
fJsejl3Wr3nAcwKFsq887vRpxbUMNggKHbIlX8WR9RFAGl+xxiUIe3Lik7B9
sQDiTnr0SS52WX8BKD/+62gegN1Dv/Vago8b3E3x4V71xi7ruxtwZoVAjCt2
pasv53CM3EGw12WeLQ27bB7codTpVZqyEfZb4ZJ05qA7SP6ysPyghl02Jx4g
iGdS+0dw33cr9XbrtHiAoTjE/1O3/Px4Akf1Cle/BfvSsn7vwVJPWJV/+YVP
tfxcEdA3XMPfXozd+bP3y7kk/mA+34mA5yV3FdvT8P9FugXwNHgENHq8KIO1
+B7omvS8UXEzAee6+xeWLMH3kiVdMYctIuDQzsnDo/Pwfbhosod+3UUCsm00
j/CoDOSpu5qr8x4QILw/2+eSmi1yPbZwZcVbAsIT7Pp0/6Mhd6cKP+orkVDi
kGXdX2uD3Lq6T6ndgISE5NNJFflWyKWjaxRHGST4NzQ3rQ61QH6Ma2sa60WC
qeobHXOGOfLQTRsEwCVhbLFaRNcUKvK/rdY3rYkk4UEx7fxRsQnyvsAI8ccE
Eso7F0wJOW6MvCBTqPEylYRUq7gFBvGGyLOkG8Q2eSRU95ixL+TMRH5veKdn
axEJqzaufkq30UGusPbp8neHSdBRqUgou6uJvNJ3qD+ylIQMxguqf4cq8oxK
filZToIkYGWwB/U75Mw7Z8cyKknI63hIjxUP1XzxpkRdH3oVCYfIOuLCuXbk
dSL/Kva4t7HMH8ex29iov00NrHPjcWhBKpvuFA0ir/1w6squ8X1BnZL2LlMR
vrjDsutdt8fzbOvb6DdKqiL/LpvjIjhCQq1kSFlhmyZygwUvdJP3k6DOrY7O
bNNGnu1cX/l6vG7BjRtaVNkzka8Mb516OY2EJ6IivSZ/Q+TNQ1rDvUISJi8W
Nk9PNkZOtp9yTokiYe6Mpcm/lJsgr7t92Dc2kISA6/a03c9Mcf4ferfWeJOw
cbNWu3iaOfKeZfuUI+1JOGL//jdtlgXyRTdqnq42JKGpt4UIjLJCfuhldt11
ZRLeHa/8KCqyQS6NHFgi6CdA7cwNcUwHDXmZKOaT4BEBs6ddsNIYoSOnhG95
c+0SAY4RJ9KrNBnIg7WNjUIOEjC/fk/rQgs75PybPywntxAQNCuNOeBuj3zu
5UHrWD4BcZsE+XsDHZBz5hKS5ywCdjwK63Fc74i84qxGcYY2AQcYCz3+yWQi
T249bxTd7wlnct1FGw87IX/DtFTa0egJ9a/pAz9ddEae8tq9uKXEEx55Gflf
uctCnh6a2+kl8ITeo+on+RIXnI/UcH8H6QmTvpz/88r97BQ5p3zzYP8fSnIj
bA==
          "]], 
         {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
          Text3DBox[
           FormBox["\<\"{1, 1}\"\>", TraditionalForm], {
           0, -21.662914198577827`, 0}], Text3DBox[
           FormBox["\<\"{2, 1}\"\>", TraditionalForm], {
           42.0265505622142, 30., 0}], Text3DBox[
           FormBox["\<\"{3, 1}\"\>", TraditionalForm], {
           42.835077616402266`, -29.172883302750307`, 0}], Text3DBox[
           FormBox["\<\"{4, 1}\"\>", TraditionalForm], {
           46.78177891038993, -25.159066536044104`, 0.5555555555555566}], 
          Text3DBox[
           FormBox["\<\"{5, 1}\"\>", TraditionalForm], {
           31.988275983969203`, -10.047172616071654`, -30.}], Text3DBox[
           FormBox["\<\"{6, 1}\"\>", TraditionalForm], {
           31.988275983969203`, -10.047172616071654`, 30.}]}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{313.01843751951833`, 369.1599633399381},
  PlotRange:>All,
  ViewPoint->{-0.5389664598100987, 0.9967169869854545, 3.18842757531897},
  ViewVertical->{-0.3011906226444083, 0.9266383714182299, 
   0.2971484945467186}]], "Print",
 CellChangeTimes->CompressedData["
1:eJwdxVtImgEYBmCHVusmbKwYo9OkbeQClyNaWQujqDEYW1iNarGEbkZW/DgK
xEDssAJblJSpTVsJm1SmGRJEcw3rKiglGNIYQiesGBV2UIl97y4ennvS1sqm
GywWS0x0f6LG89Sg+EeB1YF5mW73/2W3N/HQT4H7gu48scVc0s1xhdU4ZUP4
FvNVgaSXaUHxSImnW0LzXCvWYXol8MKNZxreK7W0ao6ZwvbX4x48kDTpw7c4
9aYReulV0I47JO+WcWHf6RYOKy528Jcrdtwone3L4uLfH4uy8OyCt01Hr/aH
NfhZ7sA65nF1ATy4HyvT0ym9HjmOTZCP4af87/vYL1BE8P3HD7MN9OmkMwcn
e8NFuMVieY6N0eNqfPTG34CFj8wMXjOd67FAJrThwYK8Rbyt5bKN9Gebqh23
mE0KrFFK+/B0vvIvnmI62eM0R825idNrNel4oqZMhLX+X+U4EnJV4SelE2pc
fN1z/JV+INqL/0Y7PiQ22mlnRTOD03orunD00x0zXjWUex10ZejuLq47DHHn
6csz08lBRlD8D/mgA1o=
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"30.`", ",", 
           RowBox[{"-", "30.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.553851381374166`"}], ",", "30.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.55385138137416`"}], ",", "30.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.942619271714406`"}], ",", "28.8`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "21.31396388285856`"}], ",", "27.6`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "21.668096958538413`"}], ",", "26.4`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.005217243371575`"}], ",", "25.2`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.32551110067031`"}], ",", "24.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.629153078283068`"}], ",", "22.8`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.91630642680542`"}], ",", "21.6`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.187123574021754`"}], ",", "20.4`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.441746559019336`"}], ",", "19.200000000000003`"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.680307429042955`"}], ",", "18.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.902928601827966`"}], ",", "16.8`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.109723195852624`"}], ",", "15.600000000000001`"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.300795330686356`"}], ",", "14.4`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.476240399372358`"}], ",", "13.2`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.636145314567827`"}], ",", "12.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.780588729971512`"}], ",", "10.8`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.909641238390535`"}], ",", "9.600000000000001`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.02336554763781`"}], ",", "8.400000000000002`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.12181663530191`"}], ",", "7.199999999999999`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.205041883295237`"}], ",", "6.`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.273081192958173`"}], ",", "4.800000000000001`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.32596708137821`"}], ",", "3.6000000000000014`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.363724759470244`"}], ",", "2.400000000000002`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.38637219225815`"}], ",", "1.2000000000000028`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.393920141694565`"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.38637219225815`"}], ",", 
           RowBox[{"-", "1.1999999999999993`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.363724759470244`"}], ",", 
           RowBox[{"-", "2.3999999999999986`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.32596708137821`"}], ",", 
           RowBox[{"-", "3.6000000000000014`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.273081192958173`"}], ",", 
           RowBox[{"-", "4.799999999999997`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.205041883295237`"}], ",", 
           RowBox[{"-", "6.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.12181663530191`"}], ",", 
           RowBox[{"-", "7.199999999999996`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.02336554763781`"}], ",", 
           RowBox[{"-", "8.399999999999999`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.909641238390535`"}], ",", 
           RowBox[{"-", "9.600000000000001`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.780588729971512`"}], ",", 
           RowBox[{"-", "10.799999999999997`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.636145314567827`"}], ",", 
           RowBox[{"-", "12.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.476240399372386`"}], ",", 
           RowBox[{"-", "13.199999999999996`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.300795330686356`"}], ",", 
           RowBox[{"-", "14.399999999999999`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "24.109723195852624`"}], ",", 
           RowBox[{"-", "15.600000000000001`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.902928601827966`"}], ",", 
           RowBox[{"-", "16.799999999999997`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.680307429042955`"}], ",", 
           RowBox[{"-", "18.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.44174655901932`"}], ",", 
           RowBox[{"-", "19.199999999999996`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "23.187123574021754`"}], ",", 
           RowBox[{"-", "20.4`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.91630642680542`"}], ",", 
           RowBox[{"-", "21.6`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.629153078283068`"}], ",", 
           RowBox[{"-", "22.799999999999997`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.32551110067031`"}], ",", 
           RowBox[{"-", "24.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22.005217243371575`"}], ",", 
           RowBox[{"-", "25.199999999999996`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "21.668096958538413`"}], ",", 
           RowBox[{"-", "26.4`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "21.31396388285856`"}], ",", 
           RowBox[{"-", "27.599999999999994`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.942619271714406`"}], ",", 
           RowBox[{"-", "28.799999999999997`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.55385138137416`"}], ",", 
           RowBox[{"-", "30.`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.553851381374166`"}], ",", 
           RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Mirror", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374166`"}], ",", "30.`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374159`"}], ",", "30.`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.942619271714406`"}], ",", "28.8`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.313963882858559`"}], ",", "27.6`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.668096958538413`"}], ",", "26.4`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.005217243371575`"}], ",", "25.2`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.325511100670312`"}], ",", "24.`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.629153078283068`"}], ",", "22.8`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.91630642680542`"}], ",", "21.6`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.187123574021754`"}], ",", "20.4`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.441746559019336`"}], ",", 
             "19.200000000000003`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.680307429042955`"}], ",", "18.`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.902928601827966`"}], ",", "16.8`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.109723195852624`"}], ",", 
             "15.600000000000001`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.300795330686356`"}], ",", "14.4`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.476240399372358`"}], ",", "13.2`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.636145314567827`"}], ",", "12.`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.780588729971512`"}], ",", "10.8`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.909641238390535`"}], ",", 
             "9.600000000000001`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.023365547637809`"}], ",", 
             "8.400000000000002`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.121816635301911`"}], ",", 
             "7.199999999999999`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.205041883295237`"}], ",", "6.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.273081192958173`"}], ",", 
             "4.800000000000001`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.32596708137821`"}], ",", 
             "3.6000000000000014`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.363724759470244`"}], ",", 
             "2.400000000000002`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.38637219225815`"}], ",", 
             "1.2000000000000028`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.393920141694565`"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.38637219225815`"}], ",", 
             RowBox[{"-", "1.1999999999999993`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.363724759470244`"}], ",", 
             RowBox[{"-", "2.3999999999999986`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.32596708137821`"}], ",", 
             RowBox[{"-", "3.6000000000000014`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.273081192958173`"}], ",", 
             RowBox[{"-", "4.799999999999997`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.205041883295237`"}], ",", 
             RowBox[{"-", "6.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.121816635301911`"}], ",", 
             RowBox[{"-", "7.199999999999996`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.023365547637809`"}], ",", 
             RowBox[{"-", "8.399999999999999`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.909641238390535`"}], ",", 
             RowBox[{"-", "9.600000000000001`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.780588729971512`"}], ",", 
             RowBox[{"-", "10.799999999999997`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.636145314567827`"}], ",", 
             RowBox[{"-", "12.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.476240399372386`"}], ",", 
             RowBox[{"-", "13.199999999999996`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.300795330686356`"}], ",", 
             RowBox[{"-", "14.399999999999999`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.109723195852624`"}], ",", 
             RowBox[{"-", "15.600000000000001`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.902928601827966`"}], ",", 
             RowBox[{"-", "16.799999999999997`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.680307429042955`"}], ",", 
             RowBox[{"-", "18.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.441746559019322`"}], ",", 
             RowBox[{"-", "19.199999999999996`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.187123574021754`"}], ",", 
             RowBox[{"-", "20.4`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.91630642680542`"}], ",", 
             RowBox[{"-", "21.6`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.629153078283068`"}], ",", 
             RowBox[{"-", "22.799999999999997`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.325511100670312`"}], ",", 
             RowBox[{"-", "24.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.005217243371575`"}], ",", 
             RowBox[{"-", "25.199999999999996`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.668096958538413`"}], ",", 
             RowBox[{"-", "26.4`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.313963882858559`"}], ",", 
             RowBox[{"-", "27.599999999999994`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.942619271714406`"}], ",", 
             RowBox[{"-", "28.799999999999997`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374159`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374166`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "30.`"}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalScreen", "[", 
         RowBox[{"100", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "30.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.163375074040639`"}], ",", "30.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.163375074040644`"}], ",", "30.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.455833929834128`"}], ",", "28.8`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.73483173269927`"}], ",", "27.6`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.00058106210114`"}], ",", "26.4`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.253280259596025`"}], ",", "25.2`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.49311427030851`"}], ",", "24.`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.720255404344137`"}], ",", "22.8`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.934864026176271`"}], ",", "21.6`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.137089179034746`"}], ",", "20.4`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.327069150450917`"}], ",", 
              "19.200000000000003`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.504931984357796`"}], ",", "18.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.6707959444852`"}], ",", "16.8`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.824769933216217`"}], ",", 
              "15.600000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.966953869567071`"}], ",", "14.4`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.09743902951044`"}], ",", "13.2`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.216308351469877`"}], ",", "12.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.323636709466797`"}], ",", "10.8`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.419491156090565`"}], ",", 
              "9.600000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.503931137185361`"}], ",", 
              "8.400000000000002`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.577008679896672`"}], ",", 
              "7.199999999999999`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.638768555492675`"}], ",", "6.`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.689248418168937`"}], ",", 
              "4.800000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.728478920852112`"}], ",", 
              "3.6000000000000014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.756483808842034`"}], ",", 
              "2.400000000000002`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.773279991963413`"}], ",", 
              "1.2000000000000028`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.778877595741463`"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.77327999196342`"}], ",", 
              RowBox[{"-", "1.1999999999999993`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.756483808842027`"}], ",", 
              RowBox[{"-", "2.3999999999999986`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.728478920852112`"}], ",", 
              RowBox[{"-", "3.6000000000000014`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.689248418168944`"}], ",", 
              RowBox[{"-", "4.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.638768555492682`"}], ",", 
              RowBox[{"-", "6.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.577008679896664`"}], ",", 
              RowBox[{"-", "7.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.503931137185361`"}], ",", 
              RowBox[{"-", "8.399999999999999`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.419491156090572`"}], ",", 
              RowBox[{"-", "9.600000000000001`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.32363670946679`"}], ",", 
              RowBox[{"-", "10.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.216308351469877`"}], ",", 
              RowBox[{"-", "12.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "15.097439029510426`"}], ",", 
              RowBox[{"-", "13.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.966953869567071`"}], ",", 
              RowBox[{"-", "14.399999999999999`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.824769933216217`"}], ",", 
              RowBox[{"-", "15.600000000000001`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.6707959444852`"}], ",", 
              RowBox[{"-", "16.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.504931984357789`"}], ",", 
              RowBox[{"-", "18.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.327069150450917`"}], ",", 
              RowBox[{"-", "19.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "14.137089179034746`"}], ",", 
              RowBox[{"-", "20.4`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.934864026176271`"}], ",", 
              RowBox[{"-", "21.6`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.720255404344137`"}], ",", 
              RowBox[{"-", "22.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.493114270308503`"}], ",", 
              RowBox[{"-", "24.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.253280259596025`"}], ",", 
              RowBox[{"-", "25.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "13.00058106210114`"}], ",", 
              RowBox[{"-", "26.4`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.734831732699277`"}], ",", 
              RowBox[{"-", "27.599999999999994`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.455833929834121`"}], ",", 
              RowBox[{"-", "28.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.163375074040637`"}], ",", 
              RowBox[{"-", "30.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "12.163375074040639`"}], ",", 
              RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalScreen", "[", 
         RowBox[{
          RowBox[{"-", "100"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "30.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "24.61528579890359`"}], ",", "30.`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "24.6152857989036`"}], ",", "30.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "24.949524491239004`"}], ",", "28.8`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.26837912308489`"}], ",", "27.6`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.57209264240131`"}], ",", "26.4`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.860891725252607`"}], ",", "25.2`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.134987737495443`"}], ",", "24.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.39457760496473`"}], ",", "22.8`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.639844601344315`"}], ",", "21.6`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.870959061754`"}], ",", "20.4`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.08807902908677`"}], ",", 
              "19.200000000000003`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.29135083926605`"}], ",", "18.`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.480909650840232`"}], ",", "16.8`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.65687992367568`"}], ",", 
              "15.600000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.819375850933795`"}], ",", "14.4`"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.96850174801193`"}], ",", "13.2`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.10435240167986`"}], ",", "12.`"}], "}"}], ",", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.22701338224777`"}], ",", "10.8`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.33656132124637`"}], ",", 
              "9.600000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.43306415678328`"}], ",", 
              "8.400000000000002`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.516581348453336`"}], ",", 
              "7.199999999999999`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.58716406342021`"}], ",", "6.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.644855335050217`"}], ",", 
              "4.800000000000001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.689690195259566`"}], ",", 
              "3.6000000000000014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.72169578153376`"}], ",", 
              "2.400000000000002`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.74089141938677`"}], ",", 
              "1.2000000000000028`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.747288680847383`"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.740891419386763`"}], ",", 
              RowBox[{"-", "1.1999999999999993`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.72169578153376`"}], ",", 
              RowBox[{"-", "2.3999999999999986`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.68969019525956`"}], ",", 
              RowBox[{"-", "3.6000000000000014`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.644855335050224`"}], ",", 
              RowBox[{"-", "4.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.58716406342021`"}], ",", 
              RowBox[{"-", "6.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.516581348453336`"}], ",", 
              RowBox[{"-", "7.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.433064156783274`"}], ",", 
              RowBox[{"-", "8.399999999999999`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.336561321246364`"}], ",", 
              RowBox[{"-", "9.600000000000001`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.22701338224777`"}], ",", 
              RowBox[{"-", "10.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "28.10435240167986`"}], ",", 
              RowBox[{"-", "12.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.968501748011924`"}], ",", 
              RowBox[{"-", "13.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.819375850933795`"}], ",", 
              RowBox[{"-", "14.399999999999999`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.65687992367568`"}], ",", 
              RowBox[{"-", "15.600000000000001`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.480909650840232`"}], ",", 
              RowBox[{"-", "16.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.29135083926605`"}], ",", 
              RowBox[{"-", "18.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "27.08807902908677`"}], ",", 
              RowBox[{"-", "19.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.870959061753993`"}], ",", 
              RowBox[{"-", "20.4`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.639844601344322`"}], ",", 
              RowBox[{"-", "21.6`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.394577604964724`"}], ",", 
              RowBox[{"-", "22.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "26.134987737495436`"}], ",", 
              RowBox[{"-", "24.`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.8608917252526`"}], ",", 
              RowBox[{"-", "25.199999999999996`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.57209264240131`"}], ",", 
              RowBox[{"-", "26.4`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.26837912308489`"}], ",", 
              RowBox[{"-", "27.599999999999994`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "24.949524491238996`"}], ",", 
              RowBox[{"-", "28.799999999999997`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "24.615285798903592`"}], ",", 
              RowBox[{"-", "30.`"}]}], "}"}]}], "}"}]}], "]"}], ",", "50.`"}],
        "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "30.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "20.553851381374166`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "20.55385138137416`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"29.156732498519187`", ",", "20.828877291364762`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"28.313464997038373`", ",", "21.095267164993174`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"27.470197495557564`", ",", "21.353096551540403`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"26.62692999407675`", ",", "21.602437735523907`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"25.783662492595937`", ",", "21.84335984962604`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"24.940394991115124`", ",", "22.075928980853405`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"24.09712748963431`", ",", "22.300208270340917`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"23.253859988153497`", ",", "22.516258007181378`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"22.410592486672684`", ",", "22.72413571663145`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"21.567324985191874`", ",", "22.92389624301771`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"20.724057483711057`", ",", "23.11559182764097`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"19.880789982230247`", ",", "23.299272181954635`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19.037522480749434`", ",", "23.474984556270243`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"18.19425497926862`", ",", "23.642773804225598`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"17.35098747778781`", ",", "23.802682443231078`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"16.507719976306994`", ",", "23.954750711094093`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"15.664452474826183`", ",", "24.099016619005695`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"14.821184973345371`", ",", "24.23551600105918`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"13.977917471864558`", ",", "24.36428256045687`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"13.134649970383744`", ",", "24.485347912549372`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12.291382468902931`", ",", "24.598741624839533`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"11.448114967422118`", ",", "24.704491254072465`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10.604847465941308`", ",", "24.802622380523417`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9.761579964460495`", ",", "24.893158639584996`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"8.918312462979681`", ",", "24.976121750746714`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"8.075044961498868`", ",", "25.051531544051258`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"7.231777460018055`", ",", "25.119405984103864`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"6.388509958537242`", ",", "25.179761191703307`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"5.545242457056432`", ",", "25.232611463156147`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"4.7019749555756185`", ",", "25.277969287328645`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.858707454094805`", ",", "25.315845360484076`"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{"3.015439952613992`", ",", "25.34624859894687`"}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"2.1721724511331786`", ",", "25.369186149628746`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.3289049496523653`", ",", "25.384663398445724`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.48563744817155197`", ",", "25.39268397664955`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.3576300533092578`"}], ",", 
             "25.39324976509066`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.200897554790071`"}], ",", "25.38636089642428`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2.0441650562708844`"}], ",", 
             "25.372015755266077`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2.887432557751694`"}], ",", 
             "25.350210976297447`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3.730700059232511`"}], ",", 
             "25.320941440315437`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4.573967560713321`"}], ",", "25.28420026821624`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5.417235062194138`"}], ",", 
             "25.239978812896283`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "6.260502563674947`"}], ",", 
             "25.188266649047776`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7.103770065155764`"}], ",", 
             "25.129051560821296`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7.947037566636574`"}], ",", 
             "25.062319527320966`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "8.790305068117384`"}], ",", 
             "24.988054705891457`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "9.6335725695982`"}], ",", "24.90623941315073`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.47684007107901`"}], ",", 
             "24.816854103714235`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.320107572559827`"}], ",", 
             "24.719877346551044`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.163375074040637`"}], ",", 
             "24.615285798903585`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.163375074040644`"}], ",", 
             "24.61528579890359`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.448198511481507`"}], ",", 
             "23.522980082925518`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.719279804385721`"}], ",", 
             "22.430674366947446`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.976739151872422`"}], ",", 
             "21.33836865096937`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.220689418349451`"}], ",", "20.2460629349913`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.451236398429188`"}], ",", 
             "19.15375721901323`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.668479061013414`"}], ",", 
             "18.06145150303516`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.87250977393542`"}], ",", 
             "16.969145787057087`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.063414510410908`"}], ",", 
             "15.876840071079014`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.241273038424296`"}], ",", 
             "14.784534355100943`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.406159094065373`"}], ",", 
             "13.69222863912287`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.558140539727248`"}], ",", "12.5999229231448`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.69727950798439`"}], ",", 
             "11.507617207166728`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.823632531882652`"}], ",", 
             "10.415311491188655`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.937250662294787`"}], ",", 
             "9.323005775210584`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.038179572921905`"}], ",", 
             "8.230700059232511`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.126459653453892`"}], ",", "7.13839434325444`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.202126091338542`"}], ",", 
             "6.046088627276369`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.265208942550117`"}], ",", 
             "4.953782911298298`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.315733191693084`"}], ",", 
             "3.861477195320223`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.353718801722664`"}], ",", 
             "2.769171479342152`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.379180753514845`"}], ",", 
             "1.6768657633640807`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.392129075469327`"}], ",", 
             "0.5845600473860095`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.392568863282136`"}], ",", 
             RowBox[{"-", "0.5077456685920616`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.380500289979267`"}], ",", 
             RowBox[{"-", "1.6000513845701327`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.355918606257092`"}], ",", 
             RowBox[{"-", "2.6923571005482074`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.318814131131532`"}], ",", 
             RowBox[{"-", "3.7846628165262786`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.269172232852767`"}], ",", 
             RowBox[{"-", "4.87696853250435`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.20697329999733`"}], ",", 
             RowBox[{"-", "5.969274248482421`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.132192702604783`"}], ",", 
             RowBox[{"-", "7.061579964460492`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.044800743177618`"}], ",", 
             RowBox[{"-", "8.153885680438567`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.944762597316725`"}], ",", 
             RowBox[{"-", "9.246191396416638`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.832038243712802`"}], ",", 
             RowBox[{"-", "10.338497112394709`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.70658238316311`"}], ",", 
             RowBox[{"-", "11.43080282837278`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.56834434622617`"}], ",", 
             RowBox[{"-", "12.523108544350851`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.417267989068776`"}], ",", 
             RowBox[{"-", "13.615414260328922`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.253291576997668`"}], ",", 
             RowBox[{"-", "14.707719976306993`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.076347655099426`"}], ",", 
             RowBox[{"-", "15.800025692285065`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.886362905341088`"}], ",", 
             RowBox[{"-", "16.892331408263143`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.683257989404723`"}], ",", 
             RowBox[{"-", "17.984637124241214`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.466947376444296`"}], ",", 
             RowBox[{"-", "19.076942840219285`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.237339154859683`"}], ",", 
             RowBox[{"-", "20.169248556197356`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.994334827081488`"}], ",", 
             RowBox[{"-", "21.261554272175427`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.737829086247373`"}], ",", 
             RowBox[{"-", "22.3538599881535`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.467709573528452`"}], ",", 
             RowBox[{"-", "23.44616570413157`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.183856614726537`"}], ",", 
             RowBox[{"-", "24.53847142010964`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.886142934613403`"}], ",", 
             RowBox[{"-", "25.630777136087712`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.574433347313843`"}], ",", 
             RowBox[{"-", "26.723082852065783`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.248584420848601`"}], ",", 
             RowBox[{"-", "27.815388568043854`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.90844411374296`"}], ",", 
             RowBox[{"-", "28.907694284021932`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374159`"}], ",", 
             RowBox[{"-", "30.000000000000004`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374166`"}], ",", 
             RowBox[{"-", "30.`"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "30.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "20.553851381374166`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "20.55385138137416`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"29.156732498519187`", ",", 
             RowBox[{"-", "20.828877291364762`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"28.313464997038373`", ",", 
             RowBox[{"-", "21.095267164993174`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"27.470197495557564`", ",", 
             RowBox[{"-", "21.353096551540403`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"26.62692999407675`", ",", 
             RowBox[{"-", "21.602437735523907`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.783662492595937`", ",", 
             RowBox[{"-", "21.84335984962604`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"24.940394991115124`", ",", 
             RowBox[{"-", "22.075928980853405`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"24.09712748963431`", ",", 
             RowBox[{"-", "22.300208270340917`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"23.253859988153497`", ",", 
             RowBox[{"-", "22.516258007181378`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"22.410592486672684`", ",", 
             RowBox[{"-", "22.72413571663145`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"21.567324985191874`", ",", 
             RowBox[{"-", "22.92389624301771`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"20.724057483711057`", ",", 
             RowBox[{"-", "23.11559182764097`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19.880789982230247`", ",", 
             RowBox[{"-", "23.299272181954635`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"19.037522480749434`", ",", 
             RowBox[{"-", "23.474984556270243`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"18.19425497926862`", ",", 
             RowBox[{"-", "23.642773804225598`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"17.35098747778781`", ",", 
             RowBox[{"-", "23.802682443231078`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"16.507719976306994`", ",", 
             RowBox[{"-", "23.954750711094093`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"15.664452474826183`", ",", 
             RowBox[{"-", "24.099016619005695`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"14.821184973345371`", ",", 
             RowBox[{"-", "24.23551600105918`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"13.977917471864558`", ",", 
             RowBox[{"-", "24.36428256045687`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"13.134649970383744`", ",", 
             RowBox[{"-", "24.485347912549372`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"12.291382468902931`", ",", 
             RowBox[{"-", "24.598741624839533`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"11.448114967422118`", ",", 
             RowBox[{"-", "24.704491254072465`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10.604847465941308`", ",", 
             RowBox[{"-", "24.802622380523417`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"9.761579964460495`", ",", 
             RowBox[{"-", "24.893158639584996`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8.918312462979681`", ",", 
             RowBox[{"-", "24.976121750746714`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"8.075044961498868`", ",", 
             RowBox[{"-", "25.051531544051258`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"7.231777460018055`", ",", 
             RowBox[{"-", "25.119405984103864`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6.388509958537242`", ",", 
             RowBox[{"-", "25.179761191703307`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5.545242457056432`", ",", 
             RowBox[{"-", "25.232611463156147`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4.7019749555756185`", ",", 
             RowBox[{"-", "25.277969287328645`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.858707454094805`", ",", 
             RowBox[{"-", "25.315845360484076`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3.015439952613992`", ",", 
             RowBox[{"-", "25.34624859894687`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2.1721724511331786`", ",", 
             RowBox[{"-", "25.369186149628746`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.3289049496523653`", ",", 
             RowBox[{"-", "25.384663398445724`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.48563744817155197`", ",", 
             RowBox[{"-", "25.39268397664955`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.3576300533092578`"}], ",", 
             RowBox[{"-", "25.39324976509066`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.200897554790071`"}], ",", 
             RowBox[{"-", "25.38636089642428`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2.0441650562708844`"}], ",", 
             RowBox[{"-", "25.372015755266077`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2.887432557751694`"}], ",", 
             RowBox[{"-", "25.350210976297447`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3.730700059232511`"}], ",", 
             RowBox[{"-", "25.320941440315437`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4.573967560713321`"}], ",", 
             RowBox[{"-", "25.28420026821624`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5.417235062194138`"}], ",", 
             RowBox[{"-", "25.239978812896283`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "6.260502563674947`"}], ",", 
             RowBox[{"-", "25.188266649047776`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7.103770065155764`"}], ",", 
             RowBox[{"-", "25.129051560821296`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7.947037566636574`"}], ",", 
             RowBox[{"-", "25.062319527320966`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "8.790305068117384`"}], ",", 
             RowBox[{"-", "24.988054705891457`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "9.6335725695982`"}], ",", 
             RowBox[{"-", "24.90623941315073`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.47684007107901`"}], ",", 
             RowBox[{"-", "24.816854103714235`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.320107572559827`"}], ",", 
             RowBox[{"-", "24.719877346551044`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.163375074040637`"}], ",", 
             RowBox[{"-", "24.615285798903585`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.163375074040644`"}], ",", 
             RowBox[{"-", "24.61528579890359`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.448198511481507`"}], ",", 
             RowBox[{"-", "23.522980082925518`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.719279804385721`"}], ",", 
             RowBox[{"-", "22.430674366947446`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.976739151872422`"}], ",", 
             RowBox[{"-", "21.33836865096937`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.220689418349451`"}], ",", 
             RowBox[{"-", "20.2460629349913`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.451236398429188`"}], ",", 
             RowBox[{"-", "19.15375721901323`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.668479061013414`"}], ",", 
             RowBox[{"-", "18.06145150303516`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.87250977393542`"}], ",", 
             RowBox[{"-", "16.969145787057087`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.063414510410908`"}], ",", 
             RowBox[{"-", "15.876840071079014`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.241273038424296`"}], ",", 
             RowBox[{"-", "14.784534355100943`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.406159094065373`"}], ",", 
             RowBox[{"-", "13.69222863912287`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.558140539727248`"}], ",", 
             RowBox[{"-", "12.5999229231448`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.69727950798439`"}], ",", 
             RowBox[{"-", "11.507617207166728`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.823632531882652`"}], ",", 
             RowBox[{"-", "10.415311491188655`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.937250662294787`"}], ",", 
             RowBox[{"-", "9.323005775210584`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.038179572921905`"}], ",", 
             RowBox[{"-", "8.230700059232511`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.126459653453892`"}], ",", 
             RowBox[{"-", "7.13839434325444`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.202126091338542`"}], ",", 
             RowBox[{"-", "6.046088627276369`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.265208942550117`"}], ",", 
             RowBox[{"-", "4.953782911298298`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.315733191693084`"}], ",", 
             RowBox[{"-", "3.861477195320223`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.353718801722664`"}], ",", 
             RowBox[{"-", "2.769171479342152`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.379180753514845`"}], ",", 
             RowBox[{"-", "1.6768657633640807`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.392129075469327`"}], ",", 
             RowBox[{"-", "0.5845600473860095`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.392568863282136`"}], ",", 
             "0.5077456685920616`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.380500289979267`"}], ",", 
             "1.6000513845701327`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.355918606257092`"}], ",", 
             "2.6923571005482074`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.318814131131532`"}], ",", 
             "3.7846628165262786`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.269172232852767`"}], ",", "4.87696853250435`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.20697329999733`"}], ",", "5.969274248482421`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.132192702604783`"}], ",", 
             "7.061579964460492`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "15.044800743177618`"}], ",", 
             "8.153885680438567`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.944762597316725`"}], ",", 
             "9.246191396416638`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.832038243712802`"}], ",", 
             "10.338497112394709`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.70658238316311`"}], ",", "11.43080282837278`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.56834434622617`"}], ",", 
             "12.523108544350851`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.417267989068776`"}], ",", 
             "13.615414260328922`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.253291576997668`"}], ",", 
             "14.707719976306993`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "14.076347655099426`"}], ",", 
             "15.800025692285065`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.886362905341088`"}], ",", 
             "16.892331408263143`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.683257989404723`"}], ",", 
             "17.984637124241214`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.466947376444296`"}], ",", 
             "19.076942840219285`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "13.237339154859683`"}], ",", 
             "20.169248556197356`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.994334827081488`"}], ",", 
             "21.261554272175427`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.737829086247373`"}], ",", "22.3538599881535`"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.467709573528452`"}], ",", 
             "23.44616570413157`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.183856614726537`"}], ",", 
             "24.53847142010964`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.886142934613403`"}], ",", 
             "25.630777136087712`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.574433347313843`"}], ",", 
             "26.723082852065783`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "11.248584420848601`"}], ",", 
             "27.815388568043854`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.90844411374296`"}], ",", 
             "28.907694284021932`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374159`"}], ",", 
             "30.000000000000004`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10.553851381374166`"}], ",", "30.`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", "30.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdx00ogwEcx/FH8raLt8xLXhORHcZhZAc9LORAFkOSJlIyWt6Tk5eiJm9t
5t0Be0TYHHDgycuQFCM5sIOiGXlLKK//n8O3T9+wkmp5mQPDMCyVGfEz8hZk
Z8Vec0YoKeV5KEgXHsN8TSz/Tlr3TE4fZAmbpoD3BZIi+Kq+98kMtrNJ5qP2
HFI0dzTbT45l5/BQVmltGSCvZ5ynYEdfjBlelUtPoXNY97iWtGWFG+HFpG4d
6piBM7gdL76Gj3lSFx2ea/CAG78L0VAmzlIPknKJuhu2xWsPoc3N5QrWyytU
Q6QpWVQHV4R3erhZLbNBzc7LJ5x4WhMNkwUXXXFw1z0wCbYKUzNgbXJPHsz2
bimGwbq4GmgwNA7DxKbcBfjCFa7C774YxxHSP0jfAO0h1mZoYXo7oX506REK
blcdR8nKrwRXyLffhcDLhy0pHFJlpMMqX6ni/2f2W6HWO/LBQCo/1QKOvJk/
UC6RflEpNXD55LINKjTcBJw2L1qM5PlTwg0s/p72NJEBPPdsC7Wzfw53AlU=

  "]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3", "Subsection",
 CellChangeTimes->{3.505372334202929*^9, 3.505562591596203*^9}],

Cell[CellGroupData[{

Cell["\<\
clist3  = {Screen[{100,100}],
Move[Window[{100,100},5],{30,30},90],
Move[Screen[{100,100}],{30,-30},90],
Move[Move[Screen[{100,100}],{30,-20},90],0,0,90],
Move[Move[Screen[{100,100}],{30,-25},90],0,0,-90],
Move[Screen[{100,100}],50]}\
\>", "Input",
 CellChangeTimes->{{3.505367019143448*^9, 3.505367138444253*^9}, {
   3.5053671807046537`*^9, 3.505367182188649*^9}, {3.5053672846161823`*^9, 
   3.5053672910041323`*^9}, {3.5053694986436234`*^9, 
   3.5053695332722607`*^9}, {3.505369565125681*^9, 3.505369582393523*^9}, 
   3.5053696841970243`*^9, {3.5053699935893097`*^9, 3.505370014809224*^9}, {
   3.505562474999895*^9, 3.505562501935886*^9}, {3.505562541858404*^9, 
   3.505562605716846*^9}, 3.505562647797185*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"100", ",", "100"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Window", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"100", ",", "100"}], "}"}], ",", "5"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "30.`"}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "30.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", 
          RowBox[{"-", "20.`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.`"}], ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "0", ",", "25.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", "50.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505369583256447*^9, 3.505369685048155*^9, 3.505370015404882*^9, 
   3.505547884448133*^9, 3.505548886305489*^9, {3.505562491285421*^9, 
   3.505562503777738*^9}, {3.505562566644552*^9, 3.505562577285129*^9}, 
   3.5055626752517138`*^9, 3.506915355265602*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist3,LabelSurfaces->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.5055626497805433`*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[
    None], Polygon3DBox[{{80., 30., 0.}, {80., 35., 
     1.2246467991473532`*^-14}, {63.33333333333334, 35., 
     1.0205389992894611`*^-14}, {63.333333333333336`, 30., 0.}, {80., 30., 
     0.}}], Polygon3DBox[{{63.333333333333336`, 30., 0.}, {63.33333333333334, 
     35., 1.0205389992894611`*^-14}, {46.66666666666667, 35., 
     8.164311994315689*^-15}, {46.66666666666667, 30., 0.}, {
     63.333333333333336`, 30., 0.}}], 
    Polygon3DBox[{{46.66666666666667, 30., 0.}, {46.66666666666667, 35., 
     8.164311994315689*^-15}, {30.000000000000014`, 35., 
     6.123233995736768*^-15}, {30., 30., 0.}, {46.66666666666667, 30., 0.}}], 
    Polygon3DBox[{{30., 30., 0.}, {30., 35., 6.123233995736766*^-15}, {
     13.333333333333336`, 35., 4.0821559971578446`*^-15}, {
     13.333333333333343`, 30., 0.}, {30., 30., 0.}}], 
    Polygon3DBox[{{13.333333333333343`, 30., 0.}, {13.333333333333336`, 35., 
     4.0821559971578446`*^-15}, {-3.3333333333333286`, 35., 
     2.0410779985789227`*^-15}, {-3.3333333333333286`, 30., 0.}, {
     13.333333333333343`, 30., 0.}}], 
    Polygon3DBox[{{-3.3333333333333286`, 30., 0.}, {-3.3333333333333286`, 35.,
      2.041077998578923*^-15}, {-19.999999999999993`, 35., 
     1.0197233050851683`*^-30}, {-19.999999999999986`, 30., 
     0.}, {-3.3333333333333286`, 30., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDCBiDc4opnPhSG+AtleJPF/YPNtMcRDkP2F
YY4/hjjYmP/BGOJQ0zD8CwB8KUOV
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      Polygon3DBox[{{30., 30., -50.}, {29.999999999999993`, 35., -50.}, {
       29.999999999999996`, 35., -33.33333333333334}, {30., 
       30., -33.333333333333336`}, {30., 30., -50.}}], 
      Polygon3DBox[{{30., 30., -33.333333333333336`}, {29.999999999999996`, 
       35., -33.33333333333334}, {29.999999999999996`, 
       35., -16.66666666666667}, {29.999999999999996`, 
       30., -16.66666666666667}, {30., 30., -33.333333333333336`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., -16.66666666666667}, {
       29.999999999999996`, 35., -16.66666666666667}, {29.999999999999996`, 
       35., -1.4210854715202004`*^-14}, {29.999999999999996`, 30., 0.}, {
       29.999999999999996`, 30., -16.66666666666667}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 0.}, {29.999999999999996`, 35.,
        0.}, {29.999999999999996`, 35., 16.666666666666664`}, {
       29.999999999999996`, 30., 16.666666666666657`}, {29.999999999999996`, 
       30., 0.}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 16.666666666666657`}, {
       29.999999999999996`, 35., 16.666666666666664`}, {30., 35., 
       33.33333333333333}, {29.999999999999996`, 30., 33.33333333333333}, {
       29.999999999999996`, 30., 16.666666666666657`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 33.33333333333333}, {30., 35., 
       33.33333333333333}, {30., 35., 49.99999999999999}, {
       29.999999999999993`, 30., 49.999999999999986`}, {29.999999999999996`, 
       30., 33.33333333333333}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4oIo3OMLciSG+Gps5QPE12OyFm8Ngiy6+Apu/4OIOGOJQ
d+IIB88DABKSSsw=
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{80., 30., 50.}, {80., 35., 50.}, {63.333333333333336`, 35.,
         50.}, {63.333333333333336`, 30., 50.}, {80., 30., 50.}}], 
       Line3DBox[{{63.333333333333336`, 30., 50.}, {63.333333333333336`, 35., 
        50.}, {46.66666666666667, 35., 50.}, {46.66666666666667, 30., 50.}, {
        63.333333333333336`, 30., 50.}}], 
       Line3DBox[{{46.66666666666667, 30., 50.}, {46.66666666666667, 35., 
        50.}, {30.000000000000004`, 35., 50.}, {30.000000000000004`, 30., 
        50.}, {46.66666666666667, 30., 50.}}], 
       Line3DBox[{{30., 30., 50.}, {30., 35., 50.}, {13.333333333333336`, 35.,
         50.}, {13.333333333333336`, 30., 50.}, {30., 30., 50.}}], 
       Line3DBox[{{13.333333333333336`, 30., 50.}, {13.333333333333336`, 35., 
        50.}, {-3.3333333333333286`, 35., 50.}, {-3.3333333333333286`, 30., 
        50.}, {13.333333333333336`, 30., 50.}}], 
       Line3DBox[{{-3.3333333333333286`, 30., 50.}, {-3.3333333333333286`, 
        35., 50.}, {-19.999999999999986`, 35., 50.}, {-19.999999999999986`, 
        30., 50.}, {-3.3333333333333286`, 30., 50.}}], 
       Line3DBox[{{-20., 30., 50.}, {-20., 35., 50.}, {-20., 35., 
        33.333333333333336`}, {-20., 30., 33.333333333333336`}, {-20., 30., 
        50.}}], Line3DBox[{{-20., 30., 33.333333333333336`}, {-20., 35., 
        33.333333333333336`}, {-20., 35., 16.66666666666667}, {-20., 30., 
        16.66666666666667}, {-20., 30., 33.333333333333336`}}], 
       Line3DBox[{{-20., 30., 16.666666666666668`}, {-20., 35., 
        16.666666666666668`}, {-20., 35., 2.7755575615628914`*^-15}, {-20., 
        30., 2.7755575615628914`*^-15}, {-20., 30., 16.666666666666668`}}], 
       Line3DBox[{{-20., 30., 0.}, {-20., 35., 0.}, {-20., 
        35., -16.666666666666664`}, {-20., 30., -16.666666666666664`}, {-20., 
        30., 0.}}], 
       Line3DBox[{{-20., 30., -16.666666666666664`}, {-20., 
        35., -16.666666666666664`}, {-20., 35., -33.33333333333333}, {-20., 
        30., -33.33333333333333}, {-20., 30., -16.666666666666664`}}], 
       Line3DBox[{{-20., 30., -33.33333333333333}, {-20., 
        35., -33.33333333333333}, {-20., 35., -49.999999999999986`}, {-20., 
        30., -49.999999999999986`}, {-20., 30., -33.33333333333333}}], 
       Line3DBox[{{-20., 30., -50.}, {-20., 35., -50.}, {-3.3333333333333357`,
         35., -50.}, {-3.3333333333333357`, 30., -50.}, {-20., 30., -50.}}], 
       Line3DBox[{{-3.3333333333333357`, 30., -50.}, {-3.3333333333333357`, 
        35., -50.}, {13.333333333333329`, 35., -50.}, {13.333333333333329`, 
        30., -50.}, {-3.3333333333333357`, 30., -50.}}], 
       Line3DBox[{{13.333333333333332`, 30., -50.}, {13.333333333333332`, 
        35., -50.}, {29.999999999999996`, 35., -50.}, {29.999999999999996`, 
        30., -50.}, {13.333333333333332`, 30., -50.}}], 
       Line3DBox[{{30., 30., -50.}, {30., 35., -50.}, {46.666666666666664`, 
        35., -50.}, {46.666666666666664`, 30., -50.}, {30., 30., -50.}}], 
       Line3DBox[{{46.666666666666664`, 30., -50.}, {46.666666666666664`, 
        35., -50.}, {63.33333333333333, 35., -50.}, {63.33333333333333, 
        30., -50.}, {46.666666666666664`, 30., -50.}}], 
       Line3DBox[{{63.33333333333333, 30., -50.}, {63.33333333333333, 
        35., -50.}, {79.99999999999999, 35., -50.}, {79.99999999999999, 
        30., -50.}, {63.33333333333333, 30., -50.}}], 
       Line3DBox[{{80., 30., -50.}, {80., 35., -50.}, {80., 
        35., -33.333333333333336`}, {80., 30., -33.333333333333336`}, {80., 
        30., -50.}}], 
       Line3DBox[{{80., 30., -33.333333333333336`}, {80., 
        35., -33.333333333333336`}, {80., 35., -16.66666666666667}, {80., 
        30., -16.66666666666667}, {80., 30., -33.333333333333336`}}], 
       Line3DBox[{{80., 30., -16.666666666666668`}, {80., 
        35., -16.666666666666668`}, {80., 35., -2.7755575615628914`*^-15}, {
        80., 30., -2.7755575615628914`*^-15}, {80., 
        30., -16.666666666666668`}}], 
       Line3DBox[{{80., 30., 0.}, {80., 35., 0.}, {80., 35., 
        16.666666666666664`}, {80., 30., 16.666666666666664`}, {80., 30., 
        0.}}], Line3DBox[{{80., 30., 16.666666666666664`}, {80., 35., 
        16.666666666666664`}, {80., 35., 33.33333333333333}, {80., 30., 
        33.33333333333333}, {80., 30., 16.666666666666664`}}], 
       Line3DBox[{{80., 30., 33.33333333333333}, {80., 35., 
        33.33333333333333}, {80., 35., 49.999999999999986`}, {80., 30., 
        49.999999999999986`}, {80., 30., 33.33333333333333}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdgdgIqtXgYA/hnhYKAi4Y4gzQfgY4hvA
5mhhiDeAxbkOoIv/+Q8CxhjiEGCCIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENNwxAHACyzR4A=
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DSByC05wF08dWrQMABQ3wNWNwAQxxq8F50
8RUQ9Q7YxR0wxP/9BwEPDHGoOzHEV+MwZw0Oe6HutMXhTgx/rcARDlB34ggH
zwMAww1Otw==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., -30., -50.}, {-20., -30., -50.}, {-20., -30., 50.}, {
         80., -30., 50.}, {80., -30., -50.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCUyYHVq0DAH0M8LBQE3DHEmcC0HYb4
BrA5WhjiDWBxrgPo4n/+g4AxhjgqjW4+pjkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENozPAEAIHDTmo=
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa5ABMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBRZhNoQ==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., 50., -20.}, {-20., 50., -20.}, {-20., -50., -20.}, {
          80., -50., -20.}, {80., 50., -20.}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAZYOq1eBgD+GeFgoCLhjiDOBaTsM8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCG2CIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENozPAEAI/7P7U=
          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngcgtKUDTHz1KhBwwBBfAxY3wBCHGrgX
XXwFRL0DdnEHDPF//0HAA0Mc6k4M8dU4zFmDw16oO21xuBPDXytwhAPUnTjC
ARGeANwbRuw=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{80., -50., 25.}, {-20., -50., 25.}, {-20., 50., 25.}, {
           80., 50., 25.}, {80., -50., 25.}}]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDSBxhQgKfD6lUg4IAhvgYsboAhDmXsRRdf
AVHvgF3cAUP8338Q8MAQR7MH3Z0Y4mtw2Atl2OJw5wEc7sQQh7oTQxxKw8UB
ojtAeg==
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAZ4H0MVXrwIBBwzxNWBxAwxxKNiLLr4C
ot4Bu7gDhvi//yDggSGOysdwJ4b4Ghz2QoEtDndi+GsFjnCAuhNDHMo/AADs
dUB6
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{50., -50., -50.}, {50., 50., -50.}, {50., 50., 50.}, {
            50., -50., 50.}, {50., -50., -50.}}], 
           {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
            Text3DBox[
             FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
             FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
            Text3DBox[
             FormBox["\<\"{2, 2}\"\>", TraditionalForm], {30., 35., 0}], 
            Text3DBox[
             FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
            Text3DBox[
             FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 0, -20.}], 
            Text3DBox[
             FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, 25.}], 
            Text3DBox[
             FormBox["\<\"{6, 1}\"\>", TraditionalForm], {
             50., 0, 0}]}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{448.52071258766347`, 479.1749603877518},
  PlotRange:>All,
  ViewPoint->{-2.373475485058579, -0.8555571733646306, 2.254913755541499},
  ViewVertical->{-0.036412120698062996`, 0.2865873356507912, 
   0.9573619255594252}]], "Print",
 CellChangeTimes->{{3.505367172878573*^9, 3.505367185549945*^9}, 
   3.505367294486753*^9, {3.50536952664528*^9, 3.50536953651007*^9}, {
   3.505369585285687*^9, 3.505369606882863*^9}, 3.505369686820415*^9, 
   3.5053700228981543`*^9, 3.50537248631435*^9, 3.505562533551231*^9, {
   3.505562568873209*^9, 3.5055625789988747`*^9}, 3.505562675524939*^9, 
   3.506915359519766*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeldSurfaces[clist3]", "Input",
 CellChangeTimes->{3.505370279332316*^9, 3.5055626567573347`*^9, 
  3.5055749070006104`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -50., 0.}, {0, -33.333333333333336`, 0.}, {
     0, -16.66666666666667, 0.}, {0, -7.105427357601002*^-15, 0.}, {
     0, 16.666666666666657`, 0.}, {0, 33.333333333333314`, 0.}, {
     0, 49.999999999999986`, 0.}, {0, 50., 0.}, {
     0, 33.333333333333336`, 0.}, {0, 16.66666666666667, 0.}, {
     0, 7.105427357601002*^-15, 0.}, {0, -16.666666666666657`, 0.}, {
     0, -33.333333333333314`, 0.}, {0, -49.999999999999986`, 0.}, {
     0, -50., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -50.}, {0, 0., -33.333333333333336`}, {
      0, 0., -16.66666666666667}, {0, 0., -7.105427357601002*^-15}, {
      0, 0., 16.666666666666657`}, {0, 0., 33.333333333333314`}, {
      0, 0., 49.999999999999986`}, {0, 0., 50.}, {
      0, 0., 33.333333333333336`}, {0, 0., 16.66666666666667}, {
      0, 0., 7.105427357601002*^-15}, {0, 0., -16.666666666666657`}, {
      0, 0., -33.333333333333314`}, {0, 0., -49.999999999999986`}, {
      0, 0., -50.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
     0, -50, -50}}]}, 
   {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[
    None], Polygon3DBox[{{80., 30., 0.}, {80., 35., 
     1.2246467991473532`*^-14}, {63.33333333333334, 35., 
     1.0205389992894611`*^-14}, {63.333333333333336`, 30., 0.}, {80., 30., 
     0.}}], Polygon3DBox[{{63.333333333333336`, 30., 0.}, {63.33333333333334, 
     35., 1.0205389992894611`*^-14}, {46.66666666666667, 35., 
     8.164311994315689*^-15}, {46.66666666666667, 30., 0.}, {
     63.333333333333336`, 30., 0.}}], 
    Polygon3DBox[{{46.66666666666667, 30., 0.}, {46.66666666666667, 35., 
     8.164311994315689*^-15}, {30.000000000000014`, 35., 
     6.123233995736768*^-15}, {30., 30., 0.}, {46.66666666666667, 30., 0.}}], 
    Polygon3DBox[{{30., 30., 0.}, {30., 35., 6.123233995736766*^-15}, {
     13.333333333333336`, 35., 4.0821559971578446`*^-15}, {
     13.333333333333343`, 30., 0.}, {30., 30., 0.}}], 
    Polygon3DBox[{{13.333333333333343`, 30., 0.}, {13.333333333333336`, 35., 
     4.0821559971578446`*^-15}, {-3.3333333333333286`, 35., 
     2.0410779985789227`*^-15}, {-3.3333333333333286`, 30., 0.}, {
     13.333333333333343`, 30., 0.}}], 
    Polygon3DBox[{{-3.3333333333333286`, 30., 0.}, {-3.3333333333333286`, 35.,
      2.041077998578923*^-15}, {-19.999999999999993`, 35., 
     1.0197233050851683`*^-30}, {-19.999999999999986`, 30., 
     0.}, {-3.3333333333333286`, 30., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdg4wkdWrQMAfQzwsFATcMcSZUPgI8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCDCBiDc4opnPhSG+AtleJPF/YPNtMcRDkP2F
YY4/hjjYmP/BGOJQ0zD8CwB8KUOV
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      Polygon3DBox[{{30., 30., -50.}, {29.999999999999993`, 35., -50.}, {
       29.999999999999996`, 35., -33.33333333333334}, {30., 
       30., -33.333333333333336`}, {30., 30., -50.}}], 
      Polygon3DBox[{{30., 30., -33.333333333333336`}, {29.999999999999996`, 
       35., -33.33333333333334}, {29.999999999999996`, 
       35., -16.66666666666667}, {29.999999999999996`, 
       30., -16.66666666666667}, {30., 30., -33.333333333333336`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., -16.66666666666667}, {
       29.999999999999996`, 35., -16.66666666666667}, {29.999999999999996`, 
       35., -1.4210854715202004`*^-14}, {29.999999999999996`, 30., 0.}, {
       29.999999999999996`, 30., -16.66666666666667}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 0.}, {29.999999999999996`, 35.,
        0.}, {29.999999999999996`, 35., 16.666666666666664`}, {
       29.999999999999996`, 30., 16.666666666666657`}, {29.999999999999996`, 
       30., 0.}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 16.666666666666657`}, {
       29.999999999999996`, 35., 16.666666666666664`}, {30., 35., 
       33.33333333333333}, {29.999999999999996`, 30., 33.33333333333333}, {
       29.999999999999996`, 30., 16.666666666666657`}}], 
      Polygon3DBox[{{29.999999999999996`, 30., 33.33333333333333}, {30., 35., 
       33.33333333333333}, {30., 35., 49.99999999999999}, {
       29.999999999999993`, 30., 49.999999999999986`}, {29.999999999999996`, 
       30., 33.33333333333333}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc0ClPQ+gi69eBQIOGOJrwOIGGOJQg/eii6+A
qHfALu6AIf7vPwh4oIo3OMLciSG+Gps5QPE12OyFm8Ngiy6+Apu/4OIOGOJQ
d+IIB88DABKSSsw=
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{80., 30., 50.}, {80., 35., 50.}, {63.333333333333336`, 35.,
         50.}, {63.333333333333336`, 30., 50.}, {80., 30., 50.}}], 
       Line3DBox[{{63.333333333333336`, 30., 50.}, {63.333333333333336`, 35., 
        50.}, {46.66666666666667, 35., 50.}, {46.66666666666667, 30., 50.}, {
        63.333333333333336`, 30., 50.}}], 
       Line3DBox[{{46.66666666666667, 30., 50.}, {46.66666666666667, 35., 
        50.}, {30.000000000000004`, 35., 50.}, {30.000000000000004`, 30., 
        50.}, {46.66666666666667, 30., 50.}}], 
       Line3DBox[{{30., 30., 50.}, {30., 35., 50.}, {13.333333333333336`, 35.,
         50.}, {13.333333333333336`, 30., 50.}, {30., 30., 50.}}], 
       Line3DBox[{{13.333333333333336`, 30., 50.}, {13.333333333333336`, 35., 
        50.}, {-3.3333333333333286`, 35., 50.}, {-3.3333333333333286`, 30., 
        50.}, {13.333333333333336`, 30., 50.}}], 
       Line3DBox[{{-3.3333333333333286`, 30., 50.}, {-3.3333333333333286`, 
        35., 50.}, {-19.999999999999986`, 35., 50.}, {-19.999999999999986`, 
        30., 50.}, {-3.3333333333333286`, 30., 50.}}], 
       Line3DBox[{{-20., 30., 50.}, {-20., 35., 50.}, {-20., 35., 
        33.333333333333336`}, {-20., 30., 33.333333333333336`}, {-20., 30., 
        50.}}], Line3DBox[{{-20., 30., 33.333333333333336`}, {-20., 35., 
        33.333333333333336`}, {-20., 35., 16.66666666666667}, {-20., 30., 
        16.66666666666667}, {-20., 30., 33.333333333333336`}}], 
       Line3DBox[{{-20., 30., 16.666666666666668`}, {-20., 35., 
        16.666666666666668`}, {-20., 35., 2.7755575615628914`*^-15}, {-20., 
        30., 2.7755575615628914`*^-15}, {-20., 30., 16.666666666666668`}}], 
       Line3DBox[{{-20., 30., 0.}, {-20., 35., 0.}, {-20., 
        35., -16.666666666666664`}, {-20., 30., -16.666666666666664`}, {-20., 
        30., 0.}}], 
       Line3DBox[{{-20., 30., -16.666666666666664`}, {-20., 
        35., -16.666666666666664`}, {-20., 35., -33.33333333333333}, {-20., 
        30., -33.33333333333333}, {-20., 30., -16.666666666666664`}}], 
       Line3DBox[{{-20., 30., -33.33333333333333}, {-20., 
        35., -33.33333333333333}, {-20., 35., -49.999999999999986`}, {-20., 
        30., -49.999999999999986`}, {-20., 30., -33.33333333333333}}], 
       Line3DBox[{{-20., 30., -50.}, {-20., 35., -50.}, {-3.3333333333333357`,
         35., -50.}, {-3.3333333333333357`, 30., -50.}, {-20., 30., -50.}}], 
       Line3DBox[{{-3.3333333333333357`, 30., -50.}, {-3.3333333333333357`, 
        35., -50.}, {13.333333333333329`, 35., -50.}, {13.333333333333329`, 
        30., -50.}, {-3.3333333333333357`, 30., -50.}}], 
       Line3DBox[{{13.333333333333332`, 30., -50.}, {13.333333333333332`, 
        35., -50.}, {29.999999999999996`, 35., -50.}, {29.999999999999996`, 
        30., -50.}, {13.333333333333332`, 30., -50.}}], 
       Line3DBox[{{30., 30., -50.}, {30., 35., -50.}, {46.666666666666664`, 
        35., -50.}, {46.666666666666664`, 30., -50.}, {30., 30., -50.}}], 
       Line3DBox[{{46.666666666666664`, 30., -50.}, {46.666666666666664`, 
        35., -50.}, {63.33333333333333, 35., -50.}, {63.33333333333333, 
        30., -50.}, {46.666666666666664`, 30., -50.}}], 
       Line3DBox[{{63.33333333333333, 30., -50.}, {63.33333333333333, 
        35., -50.}, {79.99999999999999, 35., -50.}, {79.99999999999999, 
        30., -50.}, {63.33333333333333, 30., -50.}}], 
       Line3DBox[{{80., 30., -50.}, {80., 35., -50.}, {80., 
        35., -33.333333333333336`}, {80., 30., -33.333333333333336`}, {80., 
        30., -50.}}], 
       Line3DBox[{{80., 30., -33.333333333333336`}, {80., 
        35., -33.333333333333336`}, {80., 35., -16.66666666666667}, {80., 
        30., -16.66666666666667}, {80., 30., -33.333333333333336`}}], 
       Line3DBox[{{80., 30., -16.666666666666668`}, {80., 
        35., -16.666666666666668`}, {80., 35., -2.7755575615628914`*^-15}, {
        80., 30., -2.7755575615628914`*^-15}, {80., 
        30., -16.666666666666668`}}], 
       Line3DBox[{{80., 30., 0.}, {80., 35., 0.}, {80., 35., 
        16.666666666666664`}, {80., 30., 16.666666666666664`}, {80., 30., 
        0.}}], Line3DBox[{{80., 30., 16.666666666666664`}, {80., 35., 
        16.666666666666664`}, {80., 35., 33.33333333333333}, {80., 30., 
        33.33333333333333}, {80., 30., 16.666666666666664`}}], 
       Line3DBox[{{80., 30., 33.33333333333333}, {80., 35., 
        33.33333333333333}, {80., 35., 49.999999999999986`}, {80., 30., 
        49.999999999999986`}, {80., 30., 33.33333333333333}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQdgdgIqtXgYA/hnhYKAi4Y4gzQfgY4hvA
5mhhiDeAxbkOoIv/+Q8CxhjiEGCCIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENNwxAHACyzR4A=
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DSByC05wF08dWrQMABQ3wNWNwAQxxq8F50
8RUQ9Q7YxR0wxP/9BwEPDHGoOzHEV+MwZw0Oe6HutMXhTgx/rcARDlB34ggH
zwMAww1Otw==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., -30., -50.}, {-20., -30., -50.}, {-20., -30., 50.}, {
         80., -30., 50.}, {80., -30., -50.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYAyGiCUyYHVq0DAH0M8LBQE3DHEmcC0HYb4
BrA5WhjiDWBxrgPo4n/+g4AxhjgqjW4+pjkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENozPAEAIHDTmo=
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQnlDa5ABMfPUqEHDAEF8DFjfAEIcaaIsu
vgKi/gB2cQcM8X//QcADQxzqTgzx1TjMWYPDXqg79+JwJ4a/VuAIB6g7cYQD
IjwBRZhNoQ==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., 50., -20.}, {-20., 50., -20.}, {-20., -50., -20.}, {
          80., -50., -20.}, {80., 50., -20.}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWBAAZYOq1eBgD+GeFgoCLhjiDOBaTsM8Q1g
c7QwxBvA4lwH0MX//AcBYwxxCG2CIb4BhzkrcNj7D2y+LYZ4CA5/rcARDmBj
/gdjiENozPAEAI/7P7U=
          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQngcgtKUDTHz1KhBwwBBfAxY3wBCHGrgX
XXwFRL0DdnEHDPF//0HAA0Mc6k4M8dU4zFmDw16oO21xuBPDXytwhAPUnTjC
ARGeANwbRuw=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{80., -50., 25.}, {-20., -50., 25.}, {-20., 50., 25.}, {
           80., 50., 25.}, {80., -50., 25.}}]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdIDSBxhQgKfD6lUg4IAhvgYsboAhDmXsRRdf
AVHvgF3cAUP8338Q8MAQR7MH3Z0Y4mtw2Atl2OJw5wEc7sQQh7oTQxxKw8UB
ojtAeg==
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBAAZ4H0MVXrwIBBwzxNWBxAwxxKNiLLr4C
ot4Bu7gDhvi//yDggSGOysdwJ4b4Ghz2QoEtDndi+GsFjnCAuhNDHMo/AADs
dUB6
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{50., -50., -50.}, {50., 50., -50.}, {50., 50., 50.}, {
            50., -50., 50.}, {50., -50., -50.}}], 
           {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
            Text3DBox[
             FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
             FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., 30., 0}], 
            Text3DBox[
             FormBox["\<\"{2, 2}\"\>", TraditionalForm], {30., 35., 0}], 
            Text3DBox[
             FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., -30., 0}], 
            Text3DBox[
             FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 0, -20.}], 
            Text3DBox[
             FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 0, 25.}], 
            Text3DBox[
             FormBox["\<\"{6, 1}\"\>", TraditionalForm], {
             50., 0, 0}]}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{355.4896228471159, 306.0735004502597},
  PlotRange:>All,
  ViewPoint->{-1.275419801354445, -3.1060985716919083`, 0.4188746748688359},
  ViewVertical->{-0.2885267478875682, -0.40865090554815287`, 
   0.8658849537600813}]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.506915363412086*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5069153635162354`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The following surface data are not fully enclosed: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", 
            RowBox[{"tt$", "[", "1", "]"}]}], "}"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "25.`"}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"35.`", ",", 
            RowBox[{"tt$", "[", "1", "]"}]}], "}"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"35.`", ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"35.`", ",", "25.`"}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "30.`"}], ",", 
            RowBox[{"tt$", "[", "1", "]"}]}], "}"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"3", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"3", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "25.`"}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ss$", "[", "1", "]"}], ",", 
            RowBox[{"-", "20.`"}]}], "}"}], "}"}], ",", 
         RowBox[{"{", "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"35.`", ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"3", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "20.`"}]}], "}"}]}], "}"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ss$", "[", "1", "]"}], ",", "25.`"}], "}"}], "}"}], ",", 
         
         RowBox[{"{", "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "25.`"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"35.`", ",", "25.`"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"3", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"5", ",", "1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "25.`"}], "}"}]}], "}"}]}], "}"}]}], 
      "}"}]}], "}"}]}],
  SequenceForm[
  "The following surface data are not fully enclosed: ", {{{2, 1}, {{}, {{30., 
        $CellContext`tt$[1]}}}, {{{{2, 1}, {4, 1}}, {30., -20.}}, {{{2, 1}, {
       5, 1}}, {30., 25.}}}}, {{2, 2}, {{}, {{35., 
        $CellContext`tt$[1]}}}, {{{{2, 2}, {4, 1}}, {35., -20.}}, {{{2, 2}, {
       5, 1}}, {35., 25.}}}}, {{3, 1}, {{}, {{-30., 
        $CellContext`tt$[1]}}}, {{{{3, 1}, {4, 1}}, {-30., -20.}}, {{{3, 1}, {
       5, 1}}, {-30., 25.}}}}, {{4, 1}, {{{
        $CellContext`ss$[1], -20.}}, {}}, {{{{2, 1}, {4, 1}}, {
       30., -20.}}, {{{2, 2}, {4, 1}}, {35., -20.}}, {{{3, 1}, {4, 
       1}}, {-30., -20.}}}}, {{5, 1}, {{{
        $CellContext`ss$[1], 25.}}, {}}, {{{{2, 1}, {5, 1}}, {30., 25.}}, {{{
       2, 2}, {5, 1}}, {35., 25.}}, {{{3, 1}, {5, 1}}, {-30., 25.}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5069153635440483`*^9}],

Cell[BoxData["\<\"The calculation cannot continue. Aborting...\"\>"], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.50691536358274*^9}]
}, Open  ]],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.505549033731407*^9, 3.505549106433662*^9, 3.505549165132571*^9, 
   3.505549212580736*^9, 3.505549366477466*^9, {3.505549422681087*^9, 
   3.505549445201804*^9}, 3.505562676022599*^9, 3.505563354119606*^9, 
   3.5055634637162523`*^9, 3.5055640175416737`*^9, 3.506915363629195*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["4", "Subsection",
 CellChangeTimes->{3.505372334202929*^9, 3.505562591596203*^9, 
  3.505567048097353*^9}],

Cell[CellGroupData[{

Cell["LoadOpticaFiles[\"Engine\",\"*\"]", "Input",
 CellChangeTimes->{{3.5070917088549547`*^9, 3.507091718907111*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"Implementation/Engine/Basic.m\"\>", 
    ",", "\<\"/Users/barnhart/Library/Mathematica/Autoload/Optica/\
Implementation/Engine/Basic.m\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5070917263204803`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
clist4  = Flatten[{Screen[{130,130}],
Table[Move[Move[Screen[{100,140}],{25,-25},90],0,0,angle],{angle,0,360-120,\
120.}],
Move[Screen[{130,130}],60]}]\
\>", "Input",
 CellChangeTimes->{{3.505367019143448*^9, 3.505367138444253*^9}, {
   3.5053671807046537`*^9, 3.505367182188649*^9}, {3.5053672846161823`*^9, 
   3.5053672910041323`*^9}, {3.5053694986436234`*^9, 
   3.5053695332722607`*^9}, {3.505369565125681*^9, 3.505369582393523*^9}, 
   3.5053696841970243`*^9, {3.5053699935893097`*^9, 3.505370014809224*^9}, {
   3.505562474999895*^9, 3.505562501935886*^9}, {3.505562541858404*^9, 
   3.505562605716846*^9}, 3.505562647797185*^9, {3.505567051109438*^9, 
   3.505567108937701*^9}, {3.5056013609171133`*^9, 3.505601382168524*^9}, {
   3.505601435269061*^9, 3.505601438380622*^9}, {3.5056018448918667`*^9, 
   3.505601877488388*^9}, {3.5056778636677628`*^9, 3.505677882497719*^9}, {
   3.50696828733573*^9, 3.506968290885041*^9}, {3.506968517006113*^9, 
   3.5069685171384974`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"130", ",", "130"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "140"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", 
          RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "140"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", "12.499999999999995`", ",", 
          RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.4999999999999998`"}], ",", 
            "0.8660254037844388`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.8660254037844388`"}], ",", 
            RowBox[{"-", "0.4999999999999998`"}]}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "140"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "25.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.5000000000000004`"}], ",", 
            RowBox[{"-", "0.8660254037844384`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.8660254037844384`", ",", 
            RowBox[{"-", "0.5000000000000004`"}]}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"130", ",", "130"}], "}"}], "]"}], ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505369583256447*^9, 3.505369685048155*^9, 3.505370015404882*^9, 
   3.505547884448133*^9, 3.505548886305489*^9, {3.505562491285421*^9, 
   3.505562503777738*^9}, {3.505562566644552*^9, 3.505562577285129*^9}, 
   3.5055626752517138`*^9, 3.505567111348629*^9, {3.5056013661081543`*^9, 
   3.505601388519432*^9}, 3.505601439707024*^9, {3.505601849638083*^9, 
   3.505601878455101*^9}, {3.505677876968513*^9, 3.505677883211388*^9}, 
   3.5057129638032217`*^9, 3.506915388897087*^9, 3.506963226626169*^9, 
   3.506968291758038*^9, 3.506968521643507*^9, 3.507091756818234*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["clist4[[2]]", "Input",
 CellChangeTimes->{{3.5069682818779173`*^9, 3.506968282533004*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"25.`", ",", 
        RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.506968282915103*^9, 3.5069682933096867`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["clist4[[3]]", "Input",
 CellChangeTimes->{3.5069682984308367`*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"100", ",", "140"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"25.`", ",", "12.499999999999995`", ",", 
        RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "0.4999999999999998`"}], ",", "0.8660254037844388`"}], 
       "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.506968299451655*^9, 3.5069685242573957`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{Move[Screen[{140, 140}], {25., -25.}, 90.],Move[Screen[{140, \
140}], {25., 12.5, -21.6506}, {0, -0.5, 0.866025}],clist4[[3]]}];\
\>", "Input",
 CellChangeTimes->{{3.506968468759416*^9, 3.5069684804066467`*^9}, {
  3.506968529086529*^9, 3.506968550185678*^9}, {3.506968582333675*^9, 
  3.506968600405788*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO4AYVgegAmtXgUErwKxi2t5YIhD+RjiB0Dq
V/2yRxdfARY3PYDVnAY3osXX4DBnAQ57cblzFQ5/rcIRDmCAJdxwiQMAv58+
VA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{95., -25., -70.}, {-45., -25., -70.}, {-45., -25., 70.}, {
      95., -25., 70.}, {95., -25., -70.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihocDsAYWg6CB7ftaN3memBNatAwBRDfAFY/Jc9
ujiEb+mALg5WruWBXfxVIIY4mHsgnGjx1TjMWY3DXlzuPIDDXytwhAOucMMl
DgC9KXjB
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdBD+dtNoGr/HgSvTOJzdg30OwMQL5irNlH1l
fSDNoOr0x1o3uPgDK1cj6ytyB76ffB08Z4UDXBxCazoIHt+1o3eZKVw8erlH
WnuUg0PmF+vJR78rw8W3+U08w1fq5dCg9Ta86c0ve5g41+8cydPuQQ589uaa
zzZpORAS3wE1ZwGaOTFQe9PR7MXlzhs4/JUDDYdUtHDAFW7o4gAt+3Ub
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{-45., -48.12177119867933, -56.65061223906892}, {
      95., -48.12177119867933, -56.65061223906892}, {95., 73.12177119867934, 
      13.349412239068922`}, {-45., 73.12177119867934, 
      13.349412239068922`}, {-45., -48.12177119867933, \
-56.65061223906892}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOTw9z8IaDg8+93COmGZ6YHVq4BAyxdDPCwU
CK66YIgzgQ2yxBDfADJnlQKG+AKI+AF08T9gvgWGOMShlhjia3CYswKHvf8g
5mOIh+Dw1woc4QDm7scMN1zhCQA2J95e
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdHjnKWB+2j3IQYfj25f7m7QcYOIvtot+4Sv1
crgwjfVvyJtf9jDxL7e5qtqjHBwqF23Zeuq78gGY+N//IKDh8Ox3C+uEZaZw
8UX3wy5YX5E74H5ZPGLuCge4+IV87Reyr6wPzNHIXfup1g0ufneyQt40fo8D
H2sPMXkE+xAUv4LDnFVQez3Q7MXlzs9Qf1Wj+esZNBw2oIUDrnBDFwcAqFuI
Wg==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{75., 73.12177826491072, 13.349364905389017`}, {-25., 
      73.12177826491072, 
      13.349364905389017`}, {-25., -48.12177826491072, -56.650635094610955`}, \
{75., -48.12177826491072, -56.650635094610955`}, {75., 73.12177826491072, 
      13.349364905389017`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{359.75031135981584`, 391.429923138479},
  PlotRange:>All,
  ViewPoint->{-0.025971814776306668`, -2.6591243408654677`, 
   2.0924586506437874`},
  ViewVertical->{-0.022582117810035107`, -0.168029530673683, 
   0.9890978746167641}]], "Print",
 CellChangeTimes->{
  3.506968481474586*^9, 3.5069685305210543`*^9, {3.50696858414167*^9, 
   3.506968601579575*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist4,LabelSurfaces->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.5055626497805433`*^9, 3.505567117214204*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -65., 0.}, {0, -43.333333333333336`, 0.}, {
     0, -21.66666666666667, 0.}, {0, 0., 0.}, {0, 21.666666666666657`, 0.}, {
     0, 43.333333333333314`, 0.}, {0, 65., 0.}, {0, 65., 0.}, {
     0, 43.333333333333336`, 0.}, {0, 21.66666666666667, 0.}, {0, 0., 0.}, {
     0, -21.666666666666657`, 0.}, {0, -43.333333333333314`, 0.}, {
     0, -65., 0.}, {0, -65., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -65.}, {0, 0., -43.333333333333336`}, {
      0, 0., -21.66666666666667}, {0, 0., 0.}, {0, 0., 21.666666666666657`}, {
      0, 0., 43.333333333333314`}, {0, 0., 65.}, {0, 0., 65.}, {
      0, 0., 43.333333333333336`}, {0, 0., 21.66666666666667}, {0, 0., 0.}, {
      0, 0., -21.666666666666657`}, {0, 0., -43.333333333333314`}, {
      0, 0., -65.}, {0, 0., -65.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -65, -65}, {0, 65, -65}, {0, 65, 65}, {0, -65, 65}, {
     0, -65, -65}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO4AYVgegAmtXgUErwKxi2t5YIhD+RjiB0Dq
V/2yRxdfARY3PYDVnAY3osXX4DBnAQ57cblzFQ5/rcIRDmCAJdxwiQMAv58+
VA==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{95., -25., -70.}, {-45., -25., -70.}, {-45., -25., 70.}, {
      95., -25., 70.}, {95., -25., -70.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7w9z8IaDg8+93COmGZ6YHVq4DgVSB2cS0P
DHGIQZYY4gdA6lf9skcXXwEWNz2A1ZwGN6LF1+AwZwEOe3G5cxUOf63CEQ64
wg2XOADMSNQY
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdHjnKWB+2j3IQYfj25f7m7QcYOIvtot+4Sv1
crgwjfVvyJtf9jDxL7e5qtqjHBwqF23Zeuq78gGY+N//IKDh8Ox3C+uEZaZw
8UX3wy5YX5E74H5ZPGLuCge4+IV87Reyr6wPzNHIXfup1g0ufneyQt40fo8D
H2sPMXkE+xAUv4LDnFVQez3Q7MXlzs9Qf1Wj+esZNBw2oIUDrnBDFwcAqFuI
Wg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{95., 73.12177826491072, 13.349364905389017`}, {-45., 
       73.12177826491072, 
       13.349364905389017`}, {-45., -48.12177826491072, \
-56.650635094610955`}, {95., -48.12177826491072, -56.650635094610955`}, {95., 
       73.12177826491072, 13.349364905389017`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7ABmZoOjz+3cI6YZmpw+pVQPAqELu4lgeG
OMQgSwzxAyD1q37Zo4uvAIubHsBqToMb0eJrcJizAIe9uNy5Coe/VuEIB1zh
hkscAIdZc0w=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdLg2WSFvGr/HgW+1h5g8gn0cYOIn87VfyL6y
PrBAI3ftp1o3uHjP/bAL1lfkDnhcFo+Yu8IBLs4GpjUdHv9uYZ2wzBQu/uU2
V1V7lINDzqItW099V4aLP9su+oWv1MuhYDrr35A3v/bDxN96Cpifdg9y8OL4
9uX+Jq0DhMRfQM2ZgGYOzN4sNHtxubMFh7+OQsNhHlo44Ao3dHEA/pB4iQ==

        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{95., -48.121778264910674`, 
        56.65063509461099}, {-45., -48.121778264910674`, 
        56.65063509461099}, {-45., 73.1217782649107, -13.34936490538907}, {
        95., 73.1217782649107, -13.34936490538907}, {
        95., -48.121778264910674`, 56.65063509461099}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwcwBTDgEHGFCAn8PqVSDgiiG+BixuiiHOgBX4
OayAqHfALu6KIQ51D9Hiq3GYswaHvQTceQCHOzHEoe4hKA4AP/A1Zg==
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BABg4BB9DFV68CAVcM8TVgcVMMcVSAEF8B
Ue+AXdwVQxzqHqLFV+MwZw0Oewm48wAOd2KIQ92DUxwA5SI1Zg==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -65., -65.}, {60., 65., -65.}, {60., 65., 65.}, {
         60., -65., 65.}, {60., -65., -65.}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {25., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{449.8763891017427, 452.87506319499164`},
  PlotRange:>All,
  ViewPoint->{3.3596875428314306`, 0.3156056387597356, -0.25078416083632443`},
  
  ViewVertical->{0.5907921231181095, 0.6862240604808635, 
   0.4388753912634381}]], "Print",
 CellChangeTimes->{{3.505367172878573*^9, 3.505367185549945*^9}, 
   3.505367294486753*^9, {3.50536952664528*^9, 3.50536953651007*^9}, {
   3.505369585285687*^9, 3.505369606882863*^9}, 3.505369686820415*^9, 
   3.5053700228981543`*^9, 3.50537248631435*^9, 3.505562533551231*^9, {
   3.505562568873209*^9, 3.5055625789988747`*^9}, 3.505562675524939*^9, 
   3.505567117832035*^9, {3.505601368669711*^9, 3.5056013898984947`*^9}, 
   3.505601441905809*^9, {3.505601851910084*^9, 3.505601879892481*^9}, {
   3.505677879032402*^9, 3.5056778851773357`*^9}, 3.506963230443699*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?RecoverInput", "Input",
 CellChangeTimes->{{3.505690709442224*^9, 3.5056907130485764`*^9}}],

Cell[BoxData[
 StyleBox["\<\"RecoverInput[opticalsystem] reconstructs new input expressions \
for the specified opticalsystem and is used internally by Optica to determine \
the Out cell format.\\n\\n The output format of RecoverInput is controlled by \
the Option Print. The option Drop specifies a list of names of rules not to \
be returned by RecoverInput. A value of Default is used to pad incomplete \
components. Numbers are reconstructed with the length given by NumberLength. \
The whole reconstruction can be forced to return a string representing \
InputForm[opticalsystem] with SetOptions[RecoverInput, Active -> False].\"\>",
   "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5056907143504*^9},
 CellTags->"Info3505669113-8970513"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" meldresults = MeldSurfaces[clist4]", "Input",
 CellChangeTimes->{
  3.505370279332316*^9, 3.5055626567573347`*^9, 3.505567132597028*^9, {
   3.505574893006414*^9, 3.505574893459938*^9}, 3.5055913566094847`*^9, 
   3.505605955647138*^9, {3.505653936517612*^9, 3.505654000116438*^9}, {
   3.505660895078951*^9, 3.5056608981160316`*^9}, {3.505661486627521*^9, 
   3.505661501588562*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -65., 0.}, {0, -43.333333333333336`, 0.}, {
     0, -21.66666666666667, 0.}, {0, 0., 0.}, {0, 21.666666666666657`, 0.}, {
     0, 43.333333333333314`, 0.}, {0, 65., 0.}, {0, 65., 0.}, {
     0, 43.333333333333336`, 0.}, {0, 21.66666666666667, 0.}, {0, 0., 0.}, {
     0, -21.666666666666657`, 0.}, {0, -43.333333333333314`, 0.}, {
     0, -65., 0.}, {0, -65., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -65.}, {0, 0., -43.333333333333336`}, {
      0, 0., -21.66666666666667}, {0, 0., 0.}, {0, 0., 21.666666666666657`}, {
      0, 0., 43.333333333333314`}, {0, 0., 65.}, {0, 0., 65.}, {
      0, 0., 43.333333333333336`}, {0, 0., 21.66666666666667}, {0, 0., 0.}, {
      0, 0., -21.666666666666657`}, {0, 0., -43.333333333333314`}, {
      0, 0., -65.}, {0, 0., -65.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -65, -65}, {0, 65, -65}, {0, 65, 65}, {0, -65, 65}, {
     0, -65, -65}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOQAYVgegAmtXgUEWr4Y4mGhQHDVBUOcCcLH
EN8AMmeVAob4Aoj4AXTxP/9BwAJDHJWPEF+Dw5wVOOz9BzEfQzwEh79W4AgH
sDH7McMNDLCEJwApfkia
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{75., -25., -70.}, {-25., -25., -70.}, {-25., -25., 70.}, {
      75., -25., 70.}, {75., -25., -70.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOTw9z8IaDg8+93COmGZ6YHVq4BAyxdDPCwU
CK66YIgzgQ2yxBDfADJnlQKG+AKI+AF08T9gvgWGOMShlhjia3CYswKHvf8g
5mOIh+Dw1woc4QDm7scMN1zhCQA2J95e
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdHjnKWB+2j3IQYfj25f7m7QcYOIvtot+4Sv1
crgwjfVvyJtf9jDxL7e5qtqjHBwqF23Zeuq78gGY+N//IKDh8Ox3C+uEZaZw
8UX3wy5YX5E74H5ZPGLuCge4+IV87Reyr6wPzNHIXfup1g0ufneyQt40fo8D
H2sPMXkE+xAUv4LDnFVQez3Q7MXlzs9Qf1Wj+esZNBw2oIUDrnBDFwcAqFuI
Wg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., 73.12177826491072, 13.349364905389017`}, {-25., 
       73.12177826491072, 
       13.349364905389017`}, {-25., -48.12177826491072, \
-56.650635094610955`}, {75., -48.12177826491072, -56.650635094610955`}, {75., 
       73.12177826491072, 13.349364905389017`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOTABmZoOjz+3cI6YZmpw+pVQKDliyEeFgoE
V10wxJnAfEsM8Q0gc1YpYIgvgIgfQBf/8x8ELDDEIQ61xBBfg8OcFTjs/Qcx
H0M8BIe/VuAIB7Ax+zHDDVd4AgDxKX2S
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdLg2WSFvGr/HgW+1h5g8gn0cYOIn87VfyL6y
PrBAI3ftp1o3uHjP/bAL1lfkDnhcFo+Yu8IBLs4GpjUdHv9uYZ2wzBQu/uU2
V1V7lINDzqItW099V4aLP9su+oWv1MuhYDrr35A3v/bDxN96Cpifdg9y8OL4
9uX+Jq0DhMRfQM2ZgGYOzN4sNHtxubMFh7+OQsNhHlo44Ao3dHEA/pB4iQ==

        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{75., -48.121778264910674`, 
        56.65063509461099}, {-25., -48.121778264910674`, 
        56.65063509461099}, {-25., 73.1217782649107, -13.34936490538907}, {
        75., 73.1217782649107, -13.34936490538907}, {
        75., -48.121778264910674`, 56.65063509461099}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwcwBTDgEHGFCAn8PqVSDgiiG+BixuiiHOgBX4
OayAqHfALu6KIQ51D9Hiq3GYswaHvQTceQCHOzHEoe4hKA4AP/A1Zg==
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BABg4BB9DFV68CAVcM8TVgcVMMcVSAEF8B
Ue+AXdwVQxzqHqLFV+MwZw0Oewm48wAOd2KIQ92DUxwA5SI1Zg==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -65., -65.}, {60., 65., -65.}, {60., 65., 65.}, {
         60., -65., 65.}, {60., -65., -65.}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {25., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.50709179568125*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091796305459*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
    49.999999999999986`, 0}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917967274218`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], {
    ArrowBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}}], 
    ArrowBox[{{-25., 43.30127018922196}, {49.999999999999986`, 0}}], 
    ArrowBox[{{49.999999999999986`, 0}, {-25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091797515366*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091797606785*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   LineBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091797763682*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091797811081*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917979046917`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., -43.30127018922192}, {25., 
   43.30127018922196}, {-35., 43.30127018922196}, {-35., -43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091797986586*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], {
    ArrowBox[{{25., -43.30127018922192}, {25., 43.30127018922196}}], 
    ArrowBox[{{25., 43.30127018922196}, {-35., 43.30127018922196}}], 
    ArrowBox[{{-35., 43.30127018922196}, {-35., -43.30127018922192}}], 
    ArrowBox[{{-35., -43.30127018922192}, {25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917984473457`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922196"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
     43.30127018922196}, {-35., -43.30127018922192}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917985197697`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], 
   LineBox[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917987538757`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922196"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
     43.30127018922196}, {-35., -43.30127018922192}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091798786828*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917988562613`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., 43.30127018922191}, {
   25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
   43.30127018922191}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.5070917989136457`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], {
    ArrowBox[{{25., 43.30127018922191}, {25., -43.30127018922191}}], 
    ArrowBox[{{25., -43.30127018922191}, {-35., -43.30127018922191}}], 
    ArrowBox[{{-35., -43.30127018922191}, {-35., 43.30127018922191}}], 
    ArrowBox[{{-35., 43.30127018922191}, {25., 43.30127018922191}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799110256*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922191"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922191"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., 43.30127018922191}, {
     25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
     43.30127018922191}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799191127*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], 
   LineBox[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.50709179935216*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922191"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922191"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., 43.30127018922191}, {
     25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
     43.30127018922191}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799383685*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799465659*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., -43.30127018922196}, {25., 
   43.30127018922192}, {-35., 43.30127018922192}, {-35., -43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799516464*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], {
    ArrowBox[{{25., -43.30127018922196}, {25., 43.30127018922192}}], 
    ArrowBox[{{25., 43.30127018922192}, {-35., 43.30127018922192}}], 
    ArrowBox[{{-35., 43.30127018922192}, {-35., -43.30127018922196}}], 
    ArrowBox[{{-35., -43.30127018922196}, {25., -43.30127018922196}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.50709179961272*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922192"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922192"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
     43.30127018922192}, {-35., -43.30127018922196}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799672895*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -70.}, {-50., 70.}, {50., 70.}, {
    50., -70.}, {-50., -70.}}], 
   LineBox[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799825807*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922192"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922192"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
     43.30127018922192}, {-35., -43.30127018922196}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.50709179991607*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091799967805*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
    49.999999999999986`, 0}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091800054587*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], {
    ArrowBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}}], 
    ArrowBox[{{-25., 43.30127018922196}, {49.999999999999986`, 0}}], 
    ArrowBox[{{49.999999999999986`, 0}, {-25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091800200056*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.50709180027562*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   LineBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091800396697*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091800480022*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
     0, -4.166666666666669, -7.2168783648703085`}, {
     0, -8.333333333333334, -14.433756729740631`}, {
     0, -12.499999999999998`, -21.650635094610955`}, {
     0, -16.66666666666666, -28.867513459481277`}, {
     0, -20.83333333333332, -36.08439182435159}, {
     0, -24.99999999999999, -43.301270189221924`}, {
     0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, -4.16666666666667, 7.216878364870338}, {
      0, -8.333333333333336, 14.433756729740661`}, {
      0, -12.5, 21.650635094610983`}, {
      0, -16.666666666666664`, 28.86751345948131}, {
      0, -20.83333333333333, 36.084391824351634`}, {
      0, -24.999999999999993`, 43.30127018922195}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, 8.333333333333327, 1.4210854715202004`*^-14}, {
      0, 16.66666666666666, 1.4210854715202004`*^-14}, {
      0, 24.999999999999993`, 1.4210854715202004`*^-14}, {
      0, 33.33333333333332, 1.4210854715202004`*^-14}, {
      0, 41.66666666666665, 1.4210854715202004`*^-14}, {
      0, 49.999999999999986`, 1.4210854715202004`*^-14}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -25., -43.30127018922192}, {0, -25., 43.30127018922196}, {
      0, 49.999999999999986`, 0.}, {0, -25., -43.30127018922192}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgee/W5hnbDM9QC6+D3/jTGi92xwiOtg
iDOgAIT4HYh6B+ziNhjiUPcQLX4Phzn3cNhLwJ0Y/rqDIxxwhRtMHAAzM0zw

      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.30127018922194}, {
      0., -25., -43.30127018922194}, {0., -25., 43.30127018922194}, {
      60., -25., 43.30127018922194}, {60., -25., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc/j7HwQ0HJ79bmGdsMz0AETcE4e4Cw5xOxzi
JjjEVXCIMzCQJo7LHFz24nInLn/hCgdc4YYpDgBHOqyJ
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/j7HwQ8HCB8mb0w8X8g4f1ODh/8N8aI3pM5
gCL+38LhEVhc5wCqORoOz363sE5YZgoXh9AP9twGq7eBi/+HqD/w4uK7yLNc
TujmH3gENseVoDguc3DZi8uduPyFKxxwhRu6OABnF5j7
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 49.99999999999998, -2.4868995751603507`*^-14}, {0., 
       49.99999999999998, -2.4868995751603507`*^-14}, {
       0., -24.999999999999993`, -43.30127018922191}, {
       60., -24.999999999999993`, -43.30127018922191}, {60., 
       49.99999999999998, -2.4868995751603507`*^-14}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2AD05oOj3+3sE5YZuoAEffEIe6CQ9wOh7gJ
DnEVHOIMDKSJ4zIHl7243InLX7jCAVe4YYoDAAJLS70=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/j9HwQsDjz/3cI6YZmrA0z8B1hc48Dri+8i
z3I5wcUhNI/tHf+NMaL3bODibGBa0+Ex2BxTuDgTmLZ0uAJWr4NqzgEnh2Ng
cRk08z2htMJeQuKMUHMOoZmDy15c7oTQAhj++gYNh1do4YAr3NDFAWlzZfA=

        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{60., -24.999999999999982`, 43.301270189221945`}, {
        0., -24.999999999999982`, 43.301270189221945`}, {0., 
        50., -2.842170943040401*^-14}, {60., 50., -2.842170943040401*^-14}, {
        60., -24.999999999999982`, 43.301270189221945`}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[{{60., -4.736951571734001*^-15, 
        1.4210854715202004`*^-14}, {
        60., -4.166666666666669, -7.2168783648703085`}, {
        60., -8.333333333333334, -14.433756729740631`}, {
        60., -12.499999999999998`, -21.650635094610955`}, {
        60., -16.66666666666666, -28.867513459481277`}, {
        60., -20.83333333333332, -36.08439182435159}, {
        60., -24.99999999999999, -43.301270189221924`}, {
        60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., -4.16666666666667, 7.216878364870338}, {60., -8.333333333333336,
          14.433756729740661`}, {60., -12.5, 21.650635094610983`}, {
         60., -16.666666666666664`, 28.86751345948131}, {
         60., -20.83333333333333, 36.084391824351634`}, {
         60., -24.999999999999993`, 43.30127018922195}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., 8.333333333333327, 1.4210854715202004`*^-14}, {60., 
         16.66666666666666, 1.4210854715202004`*^-14}, {60., 
         24.999999999999993`, 1.4210854715202004`*^-14}, {60., 
         33.33333333333332, 1.4210854715202004`*^-14}, {60., 
         41.66666666666665, 1.4210854715202004`*^-14}, {60., 
         49.999999999999986`, 1.4210854715202004`*^-14}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -25., -43.30127018922192}, {60., -25., 
         43.30127018922196}, {60., 49.999999999999986`, 0.}, {
         60., -25., -43.30127018922192}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {30., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{349.0165361780221, 382.67735210649533`},
  PlotRange:>All,
  ViewPoint->{-1.4258342883729782`, -1.455225534512054, 2.7017244910989775`},
  ViewVertical->{-0.4225141158571833, 0.5361674858523444, 
   0.8358855153959575}]], "Print",
 CellChangeTimes->{3.505690035080529*^9, 3.506963249301108*^9, 
  3.507091800897242*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", 
           RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", 
          RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", "12.499999999999995`", ",", 
          RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.4999999999999998`"}], ",", 
            "0.8660254037844388`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.8660254037844388`"}], ",", 
            RowBox[{"-", "0.4999999999999998`"}]}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922196`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
         "25.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.5000000000000004`"}], ",", 
            RowBox[{"-", "0.8660254037844384`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.8660254037844384`", ",", 
            RowBox[{"-", "0.5000000000000004`"}]}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}], "]"}], 
        ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505605956483212*^9, 3.505606077139576*^9, 3.505606168219707*^9, 
   3.505608673008129*^9, 3.505608735153067*^9, 3.505608841719863*^9, 
   3.505608916829858*^9, 3.505609384390295*^9, {3.5056366235038023`*^9, 
   3.505636650545619*^9}, 3.505637068917802*^9, 3.505637646085022*^9, 
   3.505637775539896*^9, 3.505638721062496*^9, 3.5056389713975058`*^9, 
   3.5056392211151247`*^9, 3.505639307551936*^9, 3.505639422156644*^9, 
   3.505640825831201*^9, 3.505641258213925*^9, 3.50564203042892*^9, 
   3.505642095662059*^9, 3.505642212640609*^9, 3.505642615175447*^9, 
   3.505651701614766*^9, 3.5056518565772543`*^9, 3.505651889889751*^9, 
   3.50565199827686*^9, 3.505653191369047*^9, 3.505653355493888*^9, 
   3.505653505828933*^9, 3.50565354891108*^9, 3.505653699765582*^9, {
   3.5056538968828783`*^9, 3.505653941203401*^9}, {3.5056539801396933`*^9, 
   3.505654001264879*^9}, 3.50565404337263*^9, 3.50565411247007*^9, 
   3.505658085436083*^9, 3.505658606383223*^9, 3.505659196062468*^9, 
   3.5056592371666317`*^9, 3.5056597535122967`*^9, 3.505660047227809*^9, 
   3.505660108974165*^9, 3.5056602128145638`*^9, 3.5056602619471493`*^9, 
   3.505660479084897*^9, 3.505660556266713*^9, 3.505660821751574*^9, 
   3.505660949308414*^9, 3.505661503341066*^9, 3.50566155828878*^9, 
   3.505661971904319*^9, 3.505670817339922*^9, 3.5056709643474617`*^9, 
   3.505671044114626*^9, 3.505671176052651*^9, 3.505671279160528*^9, 
   3.505671350272089*^9, 3.5056778966738043`*^9, 3.505690035287653*^9, 
   3.506963251071039*^9, 3.507091801089992*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Column[Flatten[clist4]]", "Input",
 CellChangeTimes->{{3.506967899059567*^9, 3.506967911323882*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"130", ",", "130"}], "}"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]},
    {
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", 
            RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]},
    {
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", "12.499999999999995`", ",", 
            RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.4999999999999998`"}], ",", 
            "0.8660254037844388`"}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]},
    {
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "25.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.5000000000000004`"}], ",", 
            RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]},
    {
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"130", ",", "130"}], "}"}], "]"}], ",", "60.`"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.506967902410193*^9, 3.506967911624444*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{Move[Screen[{140, 140}], {25., -25.}, 90.], Move[Screen[{140, \
140}], {25., 12.5, -21.6506}, {0, -0.5, 0.866025}]}];\
\>", "Input",
 CellChangeTimes->{{3.507087809087788*^9, 3.507087825135111*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO4AYVgegAmtXgUErwKxi2t5YIhD+RjiB0Dq
V/2yRxdfARY3PYDVnAY3osXX4DBnAQ57cblzFQ5/rcIRDmCAJdxwiQMAv58+
VA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{95., -25., -70.}, {-45., -25., -70.}, {-45., -25., 70.}, {
      95., -25., 70.}, {95., -25., -70.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihocDsAYWg6CB7ftaN3memBNatAwBRDfAFY/Jc9
ujiEb+mALg5WruWBXfxVIIY4mHsgnGjx1TjMWY3DXlzuPIDDXytwhAOucMMl
DgC9KXjB
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdBD+dtNoGr/HgSvTOJzdg30OwMQL5irNlH1l
fSDNoOr0x1o3uPgDK1cj6ytyB76ffB08Z4UDXBxCazoIHt+1o3eZKVw8erlH
WnuUg0PmF+vJR78rw8W3+U08w1fq5dCg9Ta86c0ve5g41+8cydPuQQ589uaa
zzZpORAS3wE1ZwGaOTFQe9PR7MXlzhs4/JUDDYdUtHDAFW7o4gAt+3Ub
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{-45., -48.12177119867933, -56.65061223906892}, {
      95., -48.12177119867933, -56.65061223906892}, {95., 73.12177119867934, 
      13.349412239068922`}, {-45., 73.12177119867934, 
      13.349412239068922`}, {-45., -48.12177119867933, \
-56.65061223906892}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{375.0399295584189, 416.0783065209556},
  PlotRange:>All,
  ViewPoint->{0.20860731623169748`, -2.556552232336345, 2.2069262948613977`},
  ViewVertical->{-0.0023129480511156555`, 0.09019488027413747, 
   0.9969419814477363}]], "Print",
 CellChangeTimes->{3.50708783507043*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., \
-43.3013}, {-35., 43.3013}}], {25., -25.}, 90.],
Move[Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., \
43.3013}}],{25,-25},90],0,0,{angle,0}]},PlotType->Full3D]\
\>", "Input",
 CellChangeTimes->{{3.5070879503384047`*^9, 3.507088003414247*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle$$ = 120., $CellContext`maxangle$$ = 
    120, $CellContext`minangle$$ = -90, \
$CellContext`staticpolygons111532120112191649644676$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhjwc4DQlgcYkEGDN3ZxBk8c6t1wqHfBod4Rh3o7
HOKWOMRNcIjr4RBXwSEugkMcbj+R4rjMwWUvLnfi8heucMARbjjDGVe84IpH
XPGOK53gSFdYxAH4fisX
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhiwc4DQlgdKVKb/n7DM9QC6OLdnsNY5LicMcbfb
cqvE7tlgiEPMMcWhXgdD3AMsLoMhzoACEOIOEPUO6OIuEPMxxKHuwaHeBkOc
C+JfHOa4Ei3OjcMcNxz24nKnGw5/eeAIBwYUgBFuB7CHA2a84IpHFxzxzoUj
neBKVzBxAO2Qgs4=
       "], {{60., -25., -43.3013}, {0., -25., -43.3013}, {
       0., -25., 43.3013}, {60., -25., 43.3013}, {60., -25., -43.3013}}}]}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`angle$$], 0.}, -10, 10}, {
      Hold[
       Style[
        Grid[{{"angle", 
           InputField[
            Dynamic[$CellContext`minangle$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable15931532120112191649760099; $CellContext`angle$$, \
($CellContext`angle$$ = #)& ], {
             Dynamic[$CellContext`minangle$$], 
             Dynamic[$CellContext`maxangle$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxangle$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`nonexistantvariable15931532120112191649760099; \
$CellContext`angle$$, ($CellContext`angle$$ = #)& ]}}]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minangle$$], -10}}, {{
       Hold[$CellContext`maxangle$$], 10}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{"angle"}, {$CellContext`angle$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`angle$$ -> {-10, 
              10}}}; Optica`Optica`$OpticalSystemScript = 
         "{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, \
{-35., 43.3013}}], {25., -25.}, 90.], Move[Screen[{{25., 43.3013}, {25., \
-43.3013}, {-35., -43.3013}, {-35., 43.3013}}], {25., {-25*Cos[angle*Degree], \
-25.}, {-25*Sin[angle*Degree], 0}}, {0, {Cos[angle*Degree], 1.}, \
{Sin[angle*Degree], 0}}, SymbolicValues -> {angle -> 0.}]}"; Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "angle"}, {$CellContext`angle$$}}]]]]], ImageSize -> 
        Automatic]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`staticpolygons111532120112191649644676$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhjwc4DQlgcYkEGDN3ZxBk8c6t1wqHfBod4Rh3o7
HOKWOMRNcIjr4RBXwSEugkMcbj+R4rjMwWUvLnfi8heucMARbjjDGVe84IpH
XPGOK53gSFdYxAH4fisX
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhiwc4DQlgdKVKb/n7DM9QC6OLdnsNY5LicMcbfb
cqvE7tlgiEPMMcWhXgdD3AMsLoMhzoACEOIOEPUO6OIuEPMxxKHuwaHeBkOc
C+JfHOa4Ei3OjcMcNxz24nKnGw5/eeAIBwYUgBFuB7CHA2a84IpHFxzxzoUj
neBKVzBxAO2Qgs4=
          "], {{60., -25., -43.3013}, {0., -25., -43.3013}, {
          0., -25., 43.3013}, {60., -25., 43.3013}, {
          60., -25., -43.3013}}}]}}}}, Typeset`size$$ = {
    815., {552.84375, 558.15625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`angle$11747$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle$$ = 0., $CellContext`maxangle$$ = 
        10, $CellContext`minangle$$ = -10, \
$CellContext`staticpolygons111532120112191649644676$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhjwc4DQlgcYkEGDN3ZxBk8c6t1wqHfBod4Rh3o7
HOKWOMRNcIjr4RBXwSEugkMcbj+R4rjMwWUvLnfi8heucMARbjjDGVe84IpH
XPGOK53gSFdYxAH4fisX
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhiwc4DQlgdKVKb/n7DM9QC6OLdnsNY5LicMcbfb
cqvE7tlgiEPMMcWhXgdD3AMsLoMhzoACEOIOEPUO6OIuEPMxxKHuwaHeBkOc
C+JfHOa4Ei3OjcMcNxz24nKnGw5/eeAIBwYUgBFuB7CHA2a84IpHFxzxzoUj
neBKVzBxAO2Qgs4=
            "], {{60., -25., -43.3013}, {
            0., -25., -43.3013}, {0., -25., 43.3013}, {60., -25., 43.3013}, {
            60., -25., -43.3013}}}]}}, "ControllerVariables" :> {
        Hold[$CellContext`angle$$, $CellContext`angle$11747$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         OpenerView[{"Full3D", 
           Show[{
             Graphics3D[{{
                Opacity[
                1], $CellContext`staticpolygons111532120112191649644676$$, 
                Dynamic[{
                  GrayLevel[0], 
                  AbsoluteThickness[0.5], 
                  Line[
                   (Map[
                    Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}, {28, 54}, {55, 
                    59}}]& )[
                    $CellContext`lines121532120112191649715322[$CellContext`\
angle$$]]]}], 
                Opacity[1]}}]}, {
            PlotLabel -> None, ImageSize -> 800, AspectRatio -> Automatic}]}, 
          True], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`angle$$, 0.}, -10, 10, ControlType -> 
         None}, 
        Style[
         Grid[{{"angle", 
            InputField[
             Dynamic[$CellContext`minangle$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable15931532120112191649760099; $CellContext`angle$$, \
($CellContext`angle$$ = #)& ], {
              Dynamic[$CellContext`minangle$$], 
              Dynamic[$CellContext`maxangle$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxangle$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable15931532120112191649760099; $CellContext`angle$$, \
($CellContext`angle$$ = #)& ]}}]], {{$CellContext`minangle$$, -10}, 
         ControlType -> None}, {{$CellContext`maxangle$$, 10}, ControlType -> 
         None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{"angle"}, {$CellContext`angle$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`angle$$ -> {-10, 
               10}}}; Optica`Optica`$OpticalSystemScript = 
          "{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, \
{-35., 43.3013}}], {25., -25.}, 90.], Move[Screen[{{25., 43.3013}, {25., \
-43.3013}, {-35., -43.3013}, {-35., 43.3013}}], {25., {-25*Cos[angle*Degree], \
-25.}, {-25*Sin[angle*Degree], 0}}, {0, {Cos[angle*Degree], 1.}, \
{Sin[angle*Degree], 0}}, SymbolicValues -> {angle -> 0.}]}"; Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "angle"}, {$CellContext`angle$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`staticpolygons111532120112191649644676$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhjwc4DQlgcYkEGDN3ZxBk8c6t1wqHfBod4Rh3o7
HOKWOMRNcIjr4RBXwSEugkMcbj+R4rjMwWUvLnfi8heucMARbjjDGVe84IpH
XPGOK53gSFdYxAH4fisX
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmBhiwc4DQlgdKVKb/n7DM9QC6OLdnsNY5LicMcbfb
cqvE7tlgiEPMMcWhXgdD3AMsLoMhzoACEOIOEPUO6OIuEPMxxKHuwaHeBkOc
C+JfHOa4Ei3OjcMcNxz24nKnGw5/eeAIBwYUgBFuB7CHA2a84IpHFxzxzoUj
neBKVzBxAO2Qgs4=
             "], {{60., -25., -43.3013}, {
             0., -25., -43.3013}, {0., -25., 43.3013}, {60., -25., 43.3013}, {
             60., -25., -43.3013}}}]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1}, SynchronousInitialization -> True, 
        BaseStyle -> {DynamicEvaluationTimeout -> 40}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {614.34375, 619.65625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`lines121532120112191649715322 = 
      Compile[{$CellContext`angle}, {{
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         55., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         50., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         45., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         40., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         35., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         25., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         20., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         15., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         10., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         5., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         0., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         0., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         5., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         10., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         15., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         20., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         25., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         35., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         40., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         45., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         50., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         55., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          36.08441666666666 
           Sin[0.017453292519943295` $CellContext`angle], (-36.08441666666666)
             Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          28.867533333333334` 
           Sin[0.017453292519943295` $CellContext`angle], \
(-28.867533333333334`) Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          21.65065 Sin[0.017453292519943295` $CellContext`angle], (-21.65065) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          14.433766666666667` 
           Sin[0.017453292519943295` $CellContext`angle], \
(-14.433766666666667`) Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          7.216883333333335 
           Sin[0.017453292519943295` $CellContext`angle], (-7.216883333333335)
             Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          7.216883333333328 Sin[0.017453292519943295` $CellContext`angle], 
          7.216883333333328 Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          14.433766666666664` Sin[0.017453292519943295` $CellContext`angle], 
          14.433766666666664` Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 21.65065 
          Sin[0.017453292519943295` $CellContext`angle], 
          21.65065 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          28.867533333333327` Sin[0.017453292519943295` $CellContext`angle], 
          28.867533333333327` Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          36.084416666666655` Sin[0.017453292519943295` $CellContext`angle], 
          36.084416666666655` Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 43.3013 
          Sin[0.017453292519943295` $CellContext`angle], 
          43.3013 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 43.3013 
          Sin[0.017453292519943295` $CellContext`angle], 
          43.3013 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          36.08441666666666 Sin[0.017453292519943295` $CellContext`angle], 
          36.08441666666666 Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          28.867533333333334` Sin[0.017453292519943295` $CellContext`angle], 
          28.867533333333334` Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 21.65065 
          Sin[0.017453292519943295` $CellContext`angle], 
          21.65065 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          14.433766666666667` Sin[0.017453292519943295` $CellContext`angle], 
          14.433766666666667` Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 
          7.216883333333335 Sin[0.017453292519943295` $CellContext`angle], 
          7.216883333333335 Cos[0.017453292519943295` $CellContext`angle] - 
          25. Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          0. Sin[0.017453292519943295` $CellContext`angle], 
          0. Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          7.216883333333328 
           Sin[0.017453292519943295` $CellContext`angle], (-7.216883333333328)
             Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          14.433766666666664` 
           Sin[0.017453292519943295` $CellContext`angle], \
(-14.433766666666664`) Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          21.65065 Sin[0.017453292519943295` $CellContext`angle], (-21.65065) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          28.867533333333327` 
           Sin[0.017453292519943295` $CellContext`angle], \
(-28.867533333333327`) Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          36.084416666666655` 
           Sin[0.017453292519943295` $CellContext`angle], \
(-36.084416666666655`) Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         30., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         0., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         0., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 43.3013 
          Sin[0.017453292519943295` $CellContext`angle], 
          43.3013 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] - 43.3013 
          Sin[0.017453292519943295` $CellContext`angle], 
          43.3013 Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}, {
         60., (-25.) Cos[0.017453292519943295` $CellContext`angle] + 
          43.3013 Sin[0.017453292519943295` $CellContext`angle], (-43.3013) 
           Cos[0.017453292519943295` $CellContext`angle] - 25. 
          Sin[0.017453292519943295` $CellContext`angle]}}]; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->40],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5070880213147373`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, \
{-35., 43.3013}}], {25., -25.}, 90.], 
\tMove[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., \
43.3013}}], {25., 12.5, -21.6506}, {0, -0.5, 0.866025}]}];\
\>", "Input",
 CellChangeTimes->{{3.507087809087788*^9, 3.507087825135111*^9}, {
  3.507087875886359*^9, 3.50708788652359*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgdKVKb/n7DM9QC6uNttuVVi92xwiOtg
iDOgAIS4C0S9A3ZxGwxxqHuIFnfDYY4bDnsJuBPDXy44wgFXuMHEAZ0VSUQ=

       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.3013}, {0., -25., -43.3013}, {0., -25., 
      43.3013}, {60., -25., 43.3013}, {60., -25., -43.3013}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOQChNR0Ej+/a0bvM9AADCkAXV3HALm6CQ9wO
h7gLDnFPEsVxmYPLXlzuxOUvnOFwgFhxANLRUgU=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcVjw40w6I4PlAZWa1bP7l7kegIlrfdt9n5FB
88BsOZuNZ7ic4OIMDAuS9v++u0+5aWav8D0bJHEQ0HQQPL5rR+8yU7h41993
5QwMlg7/xHcc57+ngyp+wMlhm/NXa457MnDxgJpnmxkYPIHmaQRy6/PZExKH
mbMJzRxc9uJyJwNDA1Z/aUDDYRZaOOAKN3RxAAaSb9w=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{-10., -25.00002144579105, -43.301257570965646`}, {
      50., -25.00002144579105, -43.301257570965646`}, {50., 50.00002144579105,
       0.00005757096564096287}, {-10., 50.00002144579105, 
      0.00005757096564096287}, {-10., -25.00002144579105, \
-43.301257570965646`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{325.5019138368043, 443.164856677723},
  PlotRange:>All,
  ViewPoint->{-0.18185060908357953`, -2.8171299495004054`, 1.86566588745246},
  ViewVertical->{-0.0940857853438269, -0.0523976257440196, 
   0.9960710216577706}]], "Print",
 CellChangeTimes->{3.5070878875574417`*^9}]
}, Open  ]],

Cell["\<\
ShowSystem[{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, \
{-35., 43.3013}}], {25., -25.}, 90.], 
\tMove[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., \
43.3013}}], {25., 12.5, -21.6506}, {0, -0.5, 0.866025}]}];\
\>", "Input",
 CellChangeTimes->{{3.507087809087788*^9, 3.507087825135111*^9}, {
   3.507087875886359*^9, 3.50708788652359*^9}, 3.507088152497582*^9}],

Cell[CellGroupData[{

Cell["\<\
ComponentTransformation/.(Surfaces/.Move[Screen[100], {25., 12.5, -21.6506}, \
{0, -0.5, 0.866025}])\
\>", "Input",
 CellChangeTimes->{{3.5070881983570004`*^9, 3.507088248311801*^9}, {
  3.5070887529226103`*^9, 3.507088753232367*^9}, {3.50708881643489*^9, 
  3.5070888418244057`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25.`", ",", "12.5`", ",", 
      RowBox[{"-", "21.6506`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "0.5000001748438417`"}], ",", "0.8660253028382762`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.8660253028382762`", ",", "0.5000001748438417`"}], 
       "}"}]}], "}"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.507088195792932*^9, 3.507088248832149*^9}, 
   3.5070887620101967`*^9, {3.50708882002396*^9, 3.507088871830682*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ComponentTransformation/.(Surfaces/.Move[Screen[100], {25., 12.5, -21.6506}, \
{0, 0.5, 0.866025}])\
\>", "Input",
 CellChangeTimes->{{3.5070881983570004`*^9, 3.507088248311801*^9}, {
  3.5070887529226103`*^9, 3.507088753232367*^9}, {3.50708881643489*^9, 
  3.5070888418244057`*^9}, {3.507088921153681*^9, 3.5070889524782257`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25.`", ",", "12.5`", ",", 
      RowBox[{"-", "21.6506`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0.5000001748438417`", ",", "0.8660253028382762`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.`"}], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "0.8660253028382762`"}], ",", "0.5000001748438417`"}], 
       "}"}]}], "}"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.507088932467512*^9, 3.507088953201262*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ComponentTransformation/.(Surfaces/.Move[Move[Screen[100],{25,-25},90.1],0,0,\
0])\
\>", "Input",
 CellChangeTimes->{{3.5070882540035048`*^9, 3.507088258842086*^9}, {
   3.50708875837755*^9, 3.507088758745081*^9}, 3.507088989755727*^9, {
   3.5070891307083197`*^9, 3.5070891379869337`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25.`", ",", 
      RowBox[{"-", "25.`"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.001745328365898139`"}], ",", "0.9999984769132877`", 
        ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.9999984769132877`"}], ",", 
        RowBox[{"-", "0.001745328365898139`"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.507088190448642*^9, 3.507088259488867*^9, 3.5070887596356688`*^9, 
   3.507088873819438*^9, 3.50708899289048*^9, {3.5070891317984*^9, 
   3.507089138578265*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move[Move[Screen[100],{25,-25},90],0,0,90.1]", "Input",
 CellChangeTimes->{{3.507089005463951*^9, 3.507089089526189*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"Screen", "[", "100", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"25.`", ",", "0.04363320914745347`", ",", 
        RowBox[{"-", "24.999961922832192`"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "0.001745328365898139`"}], ",", "0.9999984769132877`"}], 
       "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.507088800999646*^9, 3.507088876993618*^9, {3.507089006207004*^9, 
   3.507089090109627*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move[Move[Screen[100],{25,-25},90],0,0,0]", "Input",
 CellChangeTimes->{{3.507089005463951*^9, 3.507089117618361*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"Screen", "[", "100", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"25.`", ",", 
        RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.507089118213727*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, \
{-35., 43.3013}}], {25., -25.}, 90.],
Move[Move[Screen[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., \
43.3013}}],{25,-25},90],0,0,120]}];\
\>", "Input",
 CellChangeTimes->{{3.5070881053830347`*^9, 3.507088117036276*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgdKVKb/n7DM9QC6uNttuVVi92xwiOtg
iDOgAIS4C0S9A3ZxGwxxqHuIFnfDYY4bDnsJuBPDXy44wgFXuMHEAZ0VSUQ=

       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.3013}, {0., -25., -43.3013}, {0., -25., 
      43.3013}, {60., -25., 43.3013}, {60., -25., -43.3013}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc/j7HwQ0HJ79bmGdsMz0AETcE4e4Cw5xOxzi
JjjEVXCIMzCQJo7LHFz24nInLn/hCgdc4YYpDgBHOqyJ
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/gTOfEGA4OnAwNDgqCr03s7mPiKZwkTGA44
OYhYXjsodE/mAIo4g6WDdtevrSL3dODif/+DgIbDs98trBOWmcLFGRgMrsrw
PNq3bRPPBtF7NnDxxbOaHZkYNA8cNvFae5bLCS7+Z7PSRkYGywM6An1NE5a5
EhRfDjXnCJo5DAwBWO3F5c5lUH/poPlrOTQcJNDCAVe4oYsDAEfMdfM=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., 50.00002581689111, 0.000014905389019048698`}, {0., 
      50.00002581689111, 0.000014905389019048698`}, {
      0., -25.000025816891124`, -43.30128509461096}, {
      60., -25.000025816891124`, -43.30128509461096}, {60., 50.00002581689111,
       0.000014905389019048698`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{260.886657984584, 377.0192557297679},
  PlotRange:>All,
  ViewPoint->{0.5181985019873728, -3.1707697002052386`, 1.0619274084410972`},
  ViewVertical->{0.0684123088499909, -0.3514812834106193, 
   0.9513669988659458}]], "Print",
 CellChangeTimes->{3.507088117614059*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[meldresults[[{2,3,4}]],Axes->True];", "Input",
 CellChangeTimes->{{3.506967955082554*^9, 3.506967985394807*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgee/W5hnbDM9QC6+D3/jTGi92xwiOtg
iDOgAIT4HYh6B+ziNhjiUPcQLX4Phzn3cNhLwJ0Y/rqDIxxwhRtMHAAzM0zw

       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.30127018922194}, {
      0., -25., -43.30127018922194}, {0., -25., 43.30127018922194}, {
      60., -25., 43.30127018922194}, {60., -25., -43.30127018922194}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOfD3PwhoODz73cI6YZnpAZgMdnEVB+ziJjjE
7XCIu+AQ9yRRHJc5uOzF5U5c/sIZDjjCDVMcANDOrYs=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcfj3HwQsDjz63cI6YZnrAZg4WPi/xoEXF99F
nuVygotD6Ad7bvtvjBG9ZwMX/wtR7/AMbI7pATTzHR6B1eugiu93cvgAFpdB
M8cDao/MXkLiuMzBZS8ud+LyF65wwBVu6OIAE7Ccng==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{-10., -24.999999999999993`, -43.30127018922191}, {
      50., -24.999999999999993`, -43.30127018922191}, {50., 
      49.99999999999998, -2.4868995751603507`*^-14}, {-10., 
      49.99999999999998, -2.4868995751603507`*^-14}, {-10., \
-24.999999999999993`, -43.30127018922191}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOcAGpjUdHv9uYZ2wzNQBJoNdXMUBu7gJDnE7
HOIuOMQ9SRTHZQ4ue3G5E5e/cIYDjnDDFAcAi99Mvw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcYDQnlBaYS9MnBFEHXByOOS/MUb0nowDTJwJ
TFs6XAGL68DF2cC0psPj3y2sE5aZwsUhtIDtHbB6G7j4t/8goHHg1cV3kWe5
nODiv8HiFgeeg81xJSj+A2rOazRzIDQPhr243InLXwzQcDiGFg64wg1dHACR
jlus
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{-10., 50., -2.842170943040401*^-14}, {50., 
      50., -2.842170943040401*^-14}, {50., -24.999999999999982`, 
      43.301270189221945`}, {-10., -24.999999999999982`, 
      43.301270189221945`}, {-10., 50., -2.842170943040401*^-14}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{350.0598390532131, 431.62873367679754`},
  PlotRange:>All,
  ViewPoint->{-0.16176281401042783`, -3.3756003331223927`, 0.1707488888028797},
  ViewVertical->{-0.030584562143791627`, -0.6339812454188606, 
   0.8354278528121971}]], "Print",
 CellChangeTimes->{{3.5069679697270737`*^9, 3.506967985933238*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["meldresults", "Input",
 CellChangeTimes->{{3.506963843926187*^9, 3.5069638476796417`*^9}, {
  3.506968674779146*^9, 3.506968676752431*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DisplayForm", "[", 
    RowBox[{"HoldForm", "[", 
     RowBox[{"Screen", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "25."}], ",", " ", 
          RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
        " ", 
        RowBox[{"{", 
         RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}], "]"}],
      "]"}], "]"}], ",", " ", "\n", "  ", 
   RowBox[{"DisplayForm", "[", 
    RowBox[{"HoldForm", "[", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", 
            RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", "43.30127018922196"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", "43.30127018922196"}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", 
            RowBox[{"-", "43.30127018922192"}]}], "}"}]}], "}"}], "]"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "25."}]}], "}"}], ",", " ", "90."}], "]"}], "]"}], 
    "]"}], ",", " ", "\n", "  ", 
   RowBox[{"DisplayForm", "[", 
    RowBox[{"HoldForm", "[", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", "43.30127018922191"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", 
            RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", 
            RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", "43.30127018922191"}], "}"}]}], 
         "}"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "12.499999999999995", ",", " ", 
         RowBox[{"-", "21.65063509461097"}]}], "}"}], ",", " ", "\n", "     ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "0.4999999999999998"}], ",", " ", 
         "0.8660254037844388"}], "}"}]}], "]"}], "]"}], "]"}], ",", " ", 
   RowBox[{"DisplayForm", "[", 
    RowBox[{"HoldForm", "[", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", 
            RowBox[{"-", "43.30127018922196"}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"25.", ",", " ", "43.30127018922192"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", "43.30127018922192"}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "35."}], ",", " ", 
            RowBox[{"-", "43.30127018922196"}]}], "}"}]}], "}"}], "]"}], ",", 
       " ", "\n", "     ", 
       RowBox[{"{", 
        RowBox[{
        "25.", ",", " ", "12.50000000000001", ",", " ", "21.65063509461096"}],
         "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "0.5000000000000004"}], ",", " ", 
         RowBox[{"-", "0.8660254037844384"}]}], "}"}]}], "]"}], "]"}], "]"}], 
   ",", " ", "\n", "  ", 
   RowBox[{"DisplayForm", "[", 
    RowBox[{"HoldForm", "[", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "25."}], ",", " ", 
            RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}], 
        "]"}], ",", " ", "60."}], "]"}], "]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.506968697970625*^9},
 FormatType->"InputForm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics[{
\tLine[{{25., -43.3013}, {25., 43.3013}, {-35., 43.3013}, {-35., -43.3013}}],
\tLine[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., 43.3013}}],
\tLine[{{25., -43.3013}, {25., 43.3013}, {-35., 43.3013}, {-35., -43.3013}}]}
]]\
\>", "Input",
 CellChangeTimes->{{3.506967566400071*^9, 3.5069676564670362`*^9}, {
  3.50696777239506*^9, 3.50696777296006*^9}}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{25., -43.3013}, {25., 43.3013}, {-35., 
    43.3013}, {-35., -43.3013}}], 
   LineBox[{{25., 43.3013}, {25., -43.3013}, {-35., -43.3013}, {-35., 
    43.3013}}], 
   LineBox[{{25., -43.3013}, {25., 43.3013}, {-35., 
    43.3013}, {-35., -43.3013}}]}]], "Output",
 CellChangeTimes->{{3.506967578553143*^9, 3.5069675851489153`*^9}, 
   3.506967657477147*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Window[{{w1,100},{w2,100}},10]//InputForm", "Input",
 CellChangeTimes->{{3.505690091866118*^9, 3.5056901046540422`*^9}, {
  3.505690626508853*^9, 3.50569064320074*^9}}],

Cell["\<\
Component[ComponentID -> 7305, ComponentDescription -> \
ComponentDescription[Window[{{w1, 100}, {w2, 100}}, 10, ComponentLabel -> \
\"\", SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, \
{0, 0, 1}}}, 
    ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, \
{0., 0., 1.}}}]], TranslationVector -> {0., 0., 0.}, RotationMatrix -> {{1., \
0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, Labels -> {\"W\"}, 
 LabelPositions -> {{5., -50. - 1.*Offy, -50. - 1.*Offz}}, EdgeStyle -> \
{FillStyle -> {}, LineStyle -> {}}, CrossStyle -> {FillStyle -> {}, LineStyle \
-> {}}, CatalogInformation -> {}, 
 Surfaces -> {{ComponentID -> 7305, SurfaceID -> 7288, SurfaceContinuation -> \
False, SurfaceFunction -> ({0, #1, #2} & ), ActiveComponent -> True, \
SurfaceLabel -> PlanarShape, SurfaceValue -> Infinity, 
    SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
ActiveRegion -> 1., ComponentMedium -> BK7, JacobianMatrix -> Function[{RayL, \
SCx, SCy, RTx, RTy, RTz}, {{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], 
    SymbolicJacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, RTz}, \
{{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], SurfaceRayIntersections -> \
Automatic, RotationMatrix -> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
    TranslationVector -> {0., 0., 0.}, ComponentTransformation -> {{0., 0., \
0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, SymbolicValues -> {w1 -> \
100, w2 -> 100}, SymbolicTranslationVector -> {0, 0, 0}, 
    SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, \
SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SurfaceCenter -> {0, 0, 0}, SurfaceBoundary -> {100., 100.}, 
    InsideSurfaceBoundaryQ -> InsideSurfaceBoundaryQ[{_Real, _Real}, {{3, 0, \
0}, {3, 0, 1}, {1, 0, 5}}, {6, 0, 3, 0, 0}, {{1, 7}, {8, 50., 2}, {39, 0, 2, \
0}, {3, 0, 19}, {8, -50., 2}, {39, 2, 0, 1}, {3, 1, 12}, {8, -50., 2}, {39, \
2, 1, 2}, 
       {3, 2, 5}, {8, 50., 2}, {39, 1, 2, 3}, {10, 3, 5}, {4, 3}, {6, False, \
4}, {10, 4, 5}, {10, 5, 3}, {4, 3}, {6, False, 2}, {10, 2, 3}, {10, 3, 5}, \
{4, 3}, {6, False, 1}, {10, 1, 5}, {2}}, 
      Function[{SCx, SCy}, SCx <= 50. && SCx >= -50. && SCy >= -50. && SCy <= \
50.], Evaluate], OffAxis -> {0, 0}, CheckLimits -> False, \
SymbolicSurfaceValue -> Infinity, SymbolicSurfaceFunction -> ({0, #1, #2} & ), 
    SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
SymbolicSurfaceBoundary -> {w1, w2}, SurpressMissedRays -> False, \
SymbolicOffAxis -> {0, 0}, SymbolicRefractiveModels -> {}, 
    SurfaceIntersectionFunction -> \
CompiledSurfaceIntersectionFunction[{_Real, _Real, _Real, _Real, _Real, \
_Real}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, \
{3, 2, 1}}, {8, 1, 10, 0, 4}, 
      {{1, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {7, 0, \
0}, {15, 0, 0, 6}, {34, 7, 6, 0, 0}, {43, 0, 1}, {3, 1, 75}, {7, 1, 0}, {94, \
260, 2, 0, 0, 3, 0, 3, 3, 0, 7}, {21, 0, 7, 6}, {24, 6, 7}, {21, 0, 4, 6}, \
{7, 1, 0}, 
       {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 8}, {21, 6, 8, 6}, {24, 6, 8}, {18, \
1, 8, 6}, {21, 0, 5, 8}, {7, 1, 0}, {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 9}, \
{21, 8, 9, 8}, {24, 8, 9}, {18, 2, 9, 8}, {67, 7, 6, 8, 3, 0}, {7, 1, 0}, 
       {70, 0, 0, 0, 0, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 7, 3, 0, 6, 3, \
0, 8}, {8, 0., 7}, {39, 7, 8, 0}, {3, 0, 34}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, \
{8, 50., 7}, {39, 8, 7, 2}, {3, 2, 25}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, {8, \
-50., 7}, 
       {39, 7, 8, 3}, {3, 3, 16}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, -50., \
7}, {39, 7, 8, 4}, {3, 4, 7}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, 50., 7}, \
{39, 8, 7, 5}, {10, 5, 7}, {4, 3}, {6, False, 6}, {10, 6, 7}, {10, 7, 5}, {4, \
3}, 
       {6, False, 4}, {10, 4, 5}, {10, 5, 7}, {4, 3}, {6, False, 3}, {10, 3, \
7}, {10, 7, 5}, {4, 3}, {6, False, 2}, {10, 2, 5}, {3, 5, 10}, {7, 1, 0}, \
{70, 0, 0, 0, 0, 8}, {7, 2, 0}, {70, 0, 0, 0, 0, 7}, {7, 3, 0}, {70, 0, 0, 0, \
0, 6}, 
       {67, 8, 7, 6, 3, 1}, {46, 1, 3}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 2}, \
{46, 2, 3}, {68, 3, 0}, {46, 0, 1}, {4, 3}, {45, {{-1., 0., 0.}}, 3, 1, 3, \
3}, {46, 3, 1}, {2}}, 
      Function[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] != 0, \
{(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 50. && #1[[2]] >= -50. && #1[[3]] \
>= -50. && #1[[3]] <= 50.), {#1[[1]], #1[[2]], #1[[3]]}, {-1., 0., 0.}] & )[
          {-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - (RSx*RTz)/RTx}]}, {{-1., \
0., 0.}}]], Evaluate], BoundaryChecked -> True, \
SymbolicSurfaceIntersectionFunction -> 
     SurfaceIntersectionFunction[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] \
!= 0, {(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 0.5*w1 && #1[[2]] >= -0.5*w1 \
&& #1[[3]] >= -0.5*w2 && #1[[3]] <= 0.5*w2), {#1[[1]], #1[[2]], #1[[3]]}, 
           {-1., 0., 0.}] & )[{-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - \
(RSx*RTz)/RTx}]}, {{-1., 0., 0.}}]], SymbolicSurfaceApproximation -> \
{Automatic}, SurfaceStyle -> {FillStyle -> {}, LineStyle -> {}}}, 
   {ComponentID -> 7305, SurfaceID -> 7289, SurfaceContinuation -> False, \
SurfaceFunction -> ({0, #1, #2} & ), ActiveComponent -> True, SurfaceLabel -> \
PlanarShape, SurfaceValue -> Infinity, 
    SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
ActiveRegion -> -1., JacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, \
RTz}, {{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], 
    SymbolicJacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, RTz}, \
{{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], SurfaceRayIntersections -> \
Automatic, RotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, \
TranslationVector -> {10., 0, 0}, 
    ComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SymbolicValues -> {w1 -> 100, w2 -> 100}, SymbolicTranslationVector -> \
{10, 0, 0}, SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
    SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, \
0, 1}}}, SurfaceCenter -> {10., 0, 0}, SurfaceBoundary -> {100., 100.}, 
    InsideSurfaceBoundaryQ -> InsideSurfaceBoundaryQ[{_Real, _Real}, {{3, 0, \
0}, {3, 0, 1}, {1, 0, 5}}, {6, 0, 3, 0, 0}, {{1, 7}, {8, 50., 2}, {39, 0, 2, \
0}, {3, 0, 19}, {8, -50., 2}, {39, 2, 0, 1}, {3, 1, 12}, {8, -50., 2}, {39, \
2, 1, 2}, 
       {3, 2, 5}, {8, 50., 2}, {39, 1, 2, 3}, {10, 3, 5}, {4, 3}, {6, False, \
4}, {10, 4, 5}, {10, 5, 3}, {4, 3}, {6, False, 2}, {10, 2, 3}, {10, 3, 5}, \
{4, 3}, {6, False, 1}, {10, 1, 5}, {2}}, 
      Function[{SCx, SCy}, SCx <= 50. && SCx >= -50. && SCy >= -50. && SCy <= \
50.], Evaluate], OffAxis -> {0., 0.}, CheckLimits -> False, \
SymbolicSurfaceValue -> Infinity, SymbolicSurfaceFunction -> ({0, #1, #2} & ), 
    SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
SymbolicSurfaceBoundary -> {w1, w2}, SurpressMissedRays -> False, \
SymbolicOffAxis -> {0, 0}, SymbolicRefractiveModels -> {}, 
    SurfaceIntersectionFunction -> \
CompiledSurfaceIntersectionFunction[{_Real, _Real, _Real, _Real, _Real, \
_Real}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, \
{3, 2, 1}}, {8, 1, 10, 0, 4}, 
      {{1, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {7, 0, \
0}, {15, 0, 0, 6}, {34, 7, 6, 0, 0}, {43, 0, 1}, {3, 1, 75}, {7, 1, 0}, {94, \
260, 2, 0, 0, 3, 0, 3, 3, 0, 7}, {21, 0, 7, 6}, {24, 6, 7}, {21, 0, 4, 6}, \
{7, 1, 0}, 
       {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 8}, {21, 6, 8, 6}, {24, 6, 8}, {18, \
1, 8, 6}, {21, 0, 5, 8}, {7, 1, 0}, {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 9}, \
{21, 8, 9, 8}, {24, 8, 9}, {18, 2, 9, 8}, {67, 7, 6, 8, 3, 0}, {7, 1, 0}, 
       {70, 0, 0, 0, 0, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 7, 3, 0, 6, 3, \
0, 8}, {8, 0., 7}, {39, 7, 8, 0}, {3, 0, 34}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, \
{8, 50., 7}, {39, 8, 7, 2}, {3, 2, 25}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, {8, \
-50., 7}, 
       {39, 7, 8, 3}, {3, 3, 16}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, -50., \
7}, {39, 7, 8, 4}, {3, 4, 7}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, 50., 7}, \
{39, 8, 7, 5}, {10, 5, 7}, {4, 3}, {6, False, 6}, {10, 6, 7}, {10, 7, 5}, {4, \
3}, 
       {6, False, 4}, {10, 4, 5}, {10, 5, 7}, {4, 3}, {6, False, 3}, {10, 3, \
7}, {10, 7, 5}, {4, 3}, {6, False, 2}, {10, 2, 5}, {3, 5, 10}, {7, 1, 0}, \
{70, 0, 0, 0, 0, 8}, {7, 2, 0}, {70, 0, 0, 0, 0, 7}, {7, 3, 0}, {70, 0, 0, 0, \
0, 6}, 
       {67, 8, 7, 6, 3, 1}, {46, 1, 3}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 2}, \
{46, 2, 3}, {68, 3, 0}, {46, 0, 1}, {4, 3}, {45, {{-1., 0., 0.}}, 3, 1, 3, \
3}, {46, 3, 1}, {2}}, 
      Function[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] != 0, \
{(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 50. && #1[[2]] >= -50. && #1[[3]] \
>= -50. && #1[[3]] <= 50.), {#1[[1]], #1[[2]], #1[[3]]}, {-1., 0., 0.}] & )[
          {-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - (RSx*RTz)/RTx}]}, {{-1., \
0., 0.}}]], Evaluate], BoundaryChecked -> True, \
SymbolicSurfaceIntersectionFunction -> 
     SurfaceIntersectionFunction[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] \
!= 0, {(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 0.5*w1 && #1[[2]] >= -0.5*w1 \
&& #1[[3]] >= -0.5*w2 && #1[[3]] <= 0.5*w2), {#1[[1]], #1[[2]], #1[[3]]}, 
           {-1., 0., 0.}] & )[{-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - \
(RSx*RTz)/RTx}]}, {{-1., 0., 0.}}]], SymbolicSurfaceApproximation -> \
{Automatic}, SurfaceStyle -> {FillStyle -> {}, LineStyle -> {}}}}, 
 Deflections -> {{{DeflectionID -> 7278, DeflectionLabel -> Refraction, \
ComponentLabel -> Window, Options -> {}, AddTo -> {NewRay}, ReplaceFor -> \
{ReplaceFor}, TakeFrom -> {OriginalRay}, 
     DeflectionFunction -> {Refraction, {False, Automatic, {IntrinsicMedium, \
BK7}}, 
       {False, {{IntrinsicMedium}, {IndicesAABK7AA0, BK7, {Temperature, \
Tension, {Transpose[SurfaceNormalMatrix] . {1, 0, 0}, \
Transpose[SurfaceNormalMatrix] . {0, 1, 0}, Transpose[SurfaceNormalMatrix] . \
{0, 0, 1}}} & }}, Automatic, False, 
        False, 7278, OriginalRay}}, SymbolicDeflectionFunction -> \
{Refraction, {IntrinsicMedium, BK7}, Intensity -> {IntrinsicMedium, BK7}, \
FresnelReflections -> False, Theory -> Automatic}}}, 
   {{DeflectionID -> 7285, DeflectionLabel -> Refraction, ComponentLabel -> \
Window, Options -> {}, AddTo -> {NewRay}, ReplaceFor -> {ReplaceFor}, \
TakeFrom -> {OriginalRay}, 
     DeflectionFunction -> {Refraction, {False, Automatic, {IntrinsicMedium, \
BK7}}, 
       {False, {{IntrinsicMedium}, {IndicesAABK7AA0, BK7, {Temperature, \
Tension, {Transpose[SurfaceNormalMatrix] . {1, 0, 0}, \
Transpose[SurfaceNormalMatrix] . {0, 1, 0}, Transpose[SurfaceNormalMatrix] . \
{0, 0, 1}}} & }}, Automatic, False, 
        False, 7285, OriginalRay}}, SymbolicDeflectionFunction -> \
{Refraction, {IntrinsicMedium, BK7}, Intensity -> {IntrinsicMedium, BK7}, \
FresnelReflections -> False, Theory -> Automatic}}}, 
   {{DeflectionID -> 7295, DeflectionLabel -> Resonate, ComponentLabel -> \
Window, Options -> {}, AddTo -> {CreatedRay}, ReplaceFor -> {ReplaceFor}, \
TakeFrom -> {CreatedRay, OriginalRay}, 
     DeflectionFunction -> {Resonate, False, {CreatedRay, OriginalRay}}}}}, \
EntranceCoordinates -> {{0., 0., 0.}, {10., 0., 0.}}, 
 ConfinedPaths -> {{{SurfaceNumber -> 1, DeflectionNumber -> {1, 3}}}, \
{{SurfaceNumber -> 2, DeflectionNumber -> {2, 3}}}}, 
 RenderedSurfaces -> {{SurfaceNumber -> 1, PlotFactor -> {1., 1.}, FillOffset \
-> {0, 0}, RenderType -> Empty}, {SurfaceNumber -> 2, PlotFactor -> {1., 1.}, \
FillOffset -> {0, 0}, RenderType -> Empty}, 
   {SurfaceNumber -> {1, 2}, PlotFactor -> {1., 1.}, FillOffset -> {{0, 0}, \
{0, 0}}, RenderType -> Mesh}}, 
 RenderedPolygons -> {{{{SurfaceNumber -> 1, StartPoint -> {-0.5*w1, 0.}, \
FinishPoint -> {0.5*w1, 0.}}, {SurfaceNumber -> 2, StartPoint -> {0.5*w1, \
0.}, FinishPoint -> {-0.5*w1, 0.}}}, {PlotFactor -> 1., RenderType -> {Fill, \
Trace}}}, 
   {{{SurfaceNumber -> 1, StartPoint -> {0., -0.5*w2}, FinishPoint -> {0., \
0.5*w2}}, {SurfaceNumber -> 2, StartPoint -> {0., 0.5*w2}, FinishPoint -> \
{0., -0.5*w2}}}, {PlotFactor -> 1., RenderType -> {Fill, Trace}}}}, 
 Options -> {ComponentLabel -> Window, GraphicDesign -> Automatic, \
WaveFrontID -> False}]\
\>", "Output",
 CellChangeTimes->{3.505690106225499*^9, 3.505690644023218*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["?ComponentRendering", "Input",
 CellChangeTimes->{{3.5056910670822487`*^9, 3.505691070927794*^9}}],

Cell[BoxData[
 StyleBox["\<\"ComponentRendering[component, options] is a generic building \
block that contructs information about the rendering of a component. \
\\n\\nComponentRendering defines how each surface within component is \
graphically rendered. If the component parameter contains multiple surfaces, \
then ComponentRendering also graphically connects the edges of the different \
surfaces together. GraphicDesign is an option to ComponentRendering that \
characterizes the component rendering. GraphicDesign has possible five \
styles. These are Automatic, Sketch, Wire, Solid, and Off. These styles are \
also options of ComponentRendering that characterize the rendering at a \
primitive level and are further defined with SurfaceRendering, EdgeRendering, \
and CrossRendering, although EdgeRendering does not apply to single-surfaced \
components. The component rendering can be controlled either by giving \
separate rendering commands for each suboption or by using the GraphicDesign \
option. See also: GraphicDesign, SurfaceRendering, EdgeRendering, and \
CrossRendering.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.505691071612064*^9},
 CellTags->"Info3505669471-5301645"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RecoverInput[Window[{100,100},10],Print->String]//InputForm", "Input",
 CellChangeTimes->{{3.5056911666135674`*^9, 3.5056912047179117`*^9}}],

Cell["\<\
DisplayForm[StyleBox[\"Window[{100, 100}, 10]\", Rule[FontColor, \
RGBColor[0.`, 0.392193`, 0.`]]]]\
\>", "Output",
 CellChangeTimes->{{3.505691188974234*^9, 3.5056912052237167`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Location[ComponentRendering]", "Input",
 CellChangeTimes->{{3.505691290776236*^9, 3.505691292425219*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Using\"\>", 
     ",", "\<\"Optica/Interface/Genetics/Genetics.m\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Options\"\>", 
     ",", "\<\"Optica/Implementation/Genetics/Genetics.m\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Definition\"\>", 
     ",", "\<\"Optica/Implementation/Genetics/Genetics.m\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.505691293417222*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
InputForm[ComponentRendering[Window[{100,100},10]/.{(SurfaceBoundary->_)->(\
SurfaceBoundary->{{-25., -43.3013}, {-25., 43.3013}, {50., \
0}}),(SymbolicSurfaceBoundary->_)->(SymbolicSurfaceBoundary->{{-25., \
-43.3013}, {-25., 43.3013}, {50., 0}})}]]\
\>", "Input",
 CellChangeTimes->{{3.5056909406607523`*^9, 3.5056910442979183`*^9}, {
  3.5056915467422113`*^9, 3.505691554924205*^9}}],

Cell["\<\
Component[ComponentID -> 7808, ComponentDescription -> \
ComponentDescription[ComponentRendering[Window[{100, 100}, 10, ComponentLabel \
-> \"\", SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, \
0}, {0, 0, 1}}}, 
     ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, \
{0., 0., 1.}}}], ComponentLabel -> \"\"]], TranslationVector -> {0., 0., 0.}, \
RotationMatrix -> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, Labels -> \
{\"W\"}, 
 LabelPositions -> {{5., -50. - 1.*Offy, -50. - 1.*Offz}}, EdgeStyle -> \
{FillStyle -> {}, LineStyle -> {}}, CrossStyle -> {FillStyle -> {}, LineStyle \
-> {}}, CatalogInformation -> {}, 
 Surfaces -> {{ComponentID -> 7808, SurfaceID -> 7811, SurfaceContinuation -> \
False, SurfaceFunction -> ({0, #1, #2} & ), ActiveComponent -> True, \
SurfaceLabel -> PlanarShape, SurfaceValue -> Infinity, 
    SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
ActiveRegion -> 1., ComponentMedium -> BK7, JacobianMatrix -> Function[{RayL, \
SCx, SCy, RTx, RTy, RTz}, {{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], 
    SymbolicJacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, RTz}, \
{{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], SurfaceRayIntersections -> \
Automatic, RotationMatrix -> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
    TranslationVector -> {0., 0., 0.}, ComponentTransformation -> {{0., 0., \
0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, SymbolicValues -> {}, \
SymbolicTranslationVector -> {0, 0, 0}, 
    SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, \
SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SurfaceCenter -> {0, 0, 0}, SurfaceBoundary -> {{-25., -43.3013}, \
{-25., 43.3013}, {50., 0}}, 
    InsideSurfaceBoundaryQ -> InsideSurfaceBoundaryQ[{_Real, _Real}, {{3, 0, \
0}, {3, 0, 1}, {1, 0, 5}}, {6, 0, 3, 0, 0}, {{1, 7}, {8, 50., 2}, {39, 0, 2, \
0}, {3, 0, 19}, {8, -50., 2}, {39, 2, 0, 1}, {3, 1, 12}, {8, -50., 2}, {39, \
2, 1, 2}, 
       {3, 2, 5}, {8, 50., 2}, {39, 1, 2, 3}, {10, 3, 5}, {4, 3}, {6, False, \
4}, {10, 4, 5}, {10, 5, 3}, {4, 3}, {6, False, 2}, {10, 2, 3}, {10, 3, 5}, \
{4, 3}, {6, False, 1}, {10, 1, 5}, {2}}, 
      Function[{SCx, SCy}, SCx <= 50. && SCx >= -50. && SCy >= -50. && SCy <= \
50.], Evaluate], OffAxis -> {0, 0}, CheckLimits -> False, \
SymbolicSurfaceValue -> Infinity, SymbolicSurfaceFunction -> ({0, #1, #2} & ), 
    SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
SymbolicSurfaceBoundary -> {{-25., -43.3013}, {-25., 43.3013}, {50., 0}}, \
SurpressMissedRays -> False, SymbolicOffAxis -> {0, 0}, \
SymbolicRefractiveModels -> {}, 
    SurfaceIntersectionFunction -> \
CompiledSurfaceIntersectionFunction[{_Real, _Real, _Real, _Real, _Real, \
_Real}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, \
{3, 2, 1}}, {8, 1, 10, 0, 4}, 
      {{1, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {7, 0, \
0}, {15, 0, 0, 6}, {34, 7, 6, 0, 0}, {43, 0, 1}, {3, 1, 75}, {7, 1, 0}, {94, \
260, 2, 0, 0, 3, 0, 3, 3, 0, 7}, {21, 0, 7, 6}, {24, 6, 7}, {21, 0, 4, 6}, \
{7, 1, 0}, 
       {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 8}, {21, 6, 8, 6}, {24, 6, 8}, {18, \
1, 8, 6}, {21, 0, 5, 8}, {7, 1, 0}, {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 9}, \
{21, 8, 9, 8}, {24, 8, 9}, {18, 2, 9, 8}, {67, 7, 6, 8, 3, 0}, {7, 1, 0}, 
       {70, 0, 0, 0, 0, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 7, 3, 0, 6, 3, \
0, 8}, {8, 0., 7}, {39, 7, 8, 0}, {3, 0, 34}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, \
{8, 50., 7}, {39, 8, 7, 2}, {3, 2, 25}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, {8, \
-50., 7}, 
       {39, 7, 8, 3}, {3, 3, 16}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, -50., \
7}, {39, 7, 8, 4}, {3, 4, 7}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, 50., 7}, \
{39, 8, 7, 5}, {10, 5, 7}, {4, 3}, {6, False, 6}, {10, 6, 7}, {10, 7, 5}, {4, \
3}, 
       {6, False, 4}, {10, 4, 5}, {10, 5, 7}, {4, 3}, {6, False, 3}, {10, 3, \
7}, {10, 7, 5}, {4, 3}, {6, False, 2}, {10, 2, 5}, {3, 5, 10}, {7, 1, 0}, \
{70, 0, 0, 0, 0, 8}, {7, 2, 0}, {70, 0, 0, 0, 0, 7}, {7, 3, 0}, {70, 0, 0, 0, \
0, 6}, 
       {67, 8, 7, 6, 3, 1}, {46, 1, 3}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 2}, \
{46, 2, 3}, {68, 3, 0}, {46, 0, 1}, {4, 3}, {45, {{-1., 0., 0.}}, 3, 1, 3, \
3}, {46, 3, 1}, {2}}, 
      Function[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] != 0, \
{(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 50. && #1[[2]] >= -50. && #1[[3]] \
>= -50. && #1[[3]] <= 50.), {#1[[1]], #1[[2]], #1[[3]]}, {-1., 0., 0.}] & )[
          {-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - (RSx*RTz)/RTx}]}, {{-1., \
0., 0.}}]], Evaluate], BoundaryChecked -> True, SurfaceStyle -> {FillStyle -> \
{}, LineStyle -> {}}}, 
   {ComponentID -> 7808, SurfaceID -> 7812, SurfaceContinuation -> False, \
SurfaceFunction -> ({0, #1, #2} & ), ActiveComponent -> True, SurfaceLabel -> \
PlanarShape, SurfaceValue -> Infinity, 
    SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
ActiveRegion -> -1., JacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, \
RTz}, {{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], 
    SymbolicJacobianMatrix -> Function[{RayL, SCx, SCy, RTx, RTy, RTz}, \
{{RTx, 0, 0}, {RTy, -1, 0}, {RTz, 0, -1}}], SurfaceRayIntersections -> \
Automatic, RotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, \
TranslationVector -> {10., 0, 0}, 
    ComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SymbolicValues -> {}, SymbolicTranslationVector -> {10, 0, 0}, \
SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
    SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, \
0, 1}}}, SurfaceCenter -> {10., 0, 0}, SurfaceBoundary -> {{-25., -43.3013}, \
{-25., 43.3013}, {50., 0}}, 
    InsideSurfaceBoundaryQ -> InsideSurfaceBoundaryQ[{_Real, _Real}, {{3, 0, \
0}, {3, 0, 1}, {1, 0, 5}}, {6, 0, 3, 0, 0}, {{1, 7}, {8, 50., 2}, {39, 0, 2, \
0}, {3, 0, 19}, {8, -50., 2}, {39, 2, 0, 1}, {3, 1, 12}, {8, -50., 2}, {39, \
2, 1, 2}, 
       {3, 2, 5}, {8, 50., 2}, {39, 1, 2, 3}, {10, 3, 5}, {4, 3}, {6, False, \
4}, {10, 4, 5}, {10, 5, 3}, {4, 3}, {6, False, 2}, {10, 2, 3}, {10, 3, 5}, \
{4, 3}, {6, False, 1}, {10, 1, 5}, {2}}, 
      Function[{SCx, SCy}, SCx <= 50. && SCx >= -50. && SCy >= -50. && SCy <= \
50.], Evaluate], OffAxis -> {0., 0.}, CheckLimits -> False, \
SymbolicSurfaceValue -> Infinity, SymbolicSurfaceFunction -> ({0, #1, #2} & ), 
    SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}} & ), \
SymbolicSurfaceBoundary -> {{-25., -43.3013}, {-25., 43.3013}, {50., 0}}, \
SurpressMissedRays -> False, SymbolicOffAxis -> {0, 0}, \
SymbolicRefractiveModels -> {}, 
    SurfaceIntersectionFunction -> \
CompiledSurfaceIntersectionFunction[{_Real, _Real, _Real, _Real, _Real, \
_Real}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, \
{3, 2, 1}}, {8, 1, 10, 0, 4}, 
      {{1, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {7, 0, \
0}, {15, 0, 0, 6}, {34, 7, 6, 0, 0}, {43, 0, 1}, {3, 1, 75}, {7, 1, 0}, {94, \
260, 2, 0, 0, 3, 0, 3, 3, 0, 7}, {21, 0, 7, 6}, {24, 6, 7}, {21, 0, 4, 6}, \
{7, 1, 0}, 
       {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 8}, {21, 6, 8, 6}, {24, 6, 8}, {18, \
1, 8, 6}, {21, 0, 5, 8}, {7, 1, 0}, {94, 260, 2, 0, 0, 3, 0, 3, 3, 0, 9}, \
{21, 8, 9, 8}, {24, 8, 9}, {18, 2, 9, 8}, {67, 7, 6, 8, 3, 0}, {7, 1, 0}, 
       {70, 0, 0, 0, 0, 7}, {8, 1.*^-10, 6}, {94, 270, 3, 0, 7, 3, 0, 6, 3, \
0, 8}, {8, 0., 7}, {39, 7, 8, 0}, {3, 0, 34}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, \
{8, 50., 7}, {39, 8, 7, 2}, {3, 2, 25}, {7, 2, 0}, {70, 0, 0, 0, 0, 8}, {8, \
-50., 7}, 
       {39, 7, 8, 3}, {3, 3, 16}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, -50., \
7}, {39, 7, 8, 4}, {3, 4, 7}, {7, 3, 0}, {70, 0, 0, 0, 0, 8}, {8, 50., 7}, \
{39, 8, 7, 5}, {10, 5, 7}, {4, 3}, {6, False, 6}, {10, 6, 7}, {10, 7, 5}, {4, \
3}, 
       {6, False, 4}, {10, 4, 5}, {10, 5, 7}, {4, 3}, {6, False, 3}, {10, 3, \
7}, {10, 7, 5}, {4, 3}, {6, False, 2}, {10, 2, 5}, {3, 5, 10}, {7, 1, 0}, \
{70, 0, 0, 0, 0, 8}, {7, 2, 0}, {70, 0, 0, 0, 0, 7}, {7, 3, 0}, {70, 0, 0, 0, \
0, 6}, 
       {67, 8, 7, 6, 3, 1}, {46, 1, 3}, {4, 3}, {45, {-1., 0., 0.}, 3, 3, 2}, \
{46, 2, 3}, {68, 3, 0}, {46, 0, 1}, {4, 3}, {45, {{-1., 0., 0.}}, 3, 1, 3, \
3}, {46, 3, 1}, {2}}, 
      Function[{RSx, RSy, RSz, RTx, RTy, RTz}, If[Chop[RTx] != 0, \
{(If[N[Chop[#1[[1]]]] >= 0. && (#1[[2]] <= 50. && #1[[2]] >= -50. && #1[[3]] \
>= -50. && #1[[3]] <= 50.), {#1[[1]], #1[[2]], #1[[3]]}, {-1., 0., 0.}] & )[
          {-(RSx/RTx), RSy - (RSx*RTy)/RTx, RSz - (RSx*RTz)/RTx}]}, {{-1., \
0., 0.}}]], Evaluate], BoundaryChecked -> True, SurfaceStyle -> {FillStyle -> \
{}, LineStyle -> {}}}}, 
 Deflections -> {{{DeflectionID -> 7769, DeflectionLabel -> Refraction, \
ComponentLabel -> Window, Options -> {}, AddTo -> {NewRay}, ReplaceFor -> \
{ReplaceFor}, TakeFrom -> {OriginalRay}, 
     DeflectionFunction -> {Refraction, {False, Automatic, {IntrinsicMedium, \
BK7}}, 
       {False, {{IntrinsicMedium}, {IndicesAABK7AA0, BK7, {Temperature, \
Tension, {Transpose[SurfaceNormalMatrix] . {1, 0, 0}, \
Transpose[SurfaceNormalMatrix] . {0, 1, 0}, Transpose[SurfaceNormalMatrix] . \
{0, 0, 1}}} & }}, Automatic, False, 
        False, 7769, OriginalRay}}, SymbolicDeflectionFunction -> \
{Refraction, {IntrinsicMedium, BK7}, Intensity -> {IntrinsicMedium, BK7}, \
FresnelReflections -> False, Theory -> Automatic}}}, 
   {{DeflectionID -> 7776, DeflectionLabel -> Refraction, ComponentLabel -> \
Window, Options -> {}, AddTo -> {NewRay}, ReplaceFor -> {ReplaceFor}, \
TakeFrom -> {OriginalRay}, 
     DeflectionFunction -> {Refraction, {False, Automatic, {IntrinsicMedium, \
BK7}}, 
       {False, {{IntrinsicMedium}, {IndicesAABK7AA0, BK7, {Temperature, \
Tension, {Transpose[SurfaceNormalMatrix] . {1, 0, 0}, \
Transpose[SurfaceNormalMatrix] . {0, 1, 0}, Transpose[SurfaceNormalMatrix] . \
{0, 0, 1}}} & }}, Automatic, False, 
        False, 7776, OriginalRay}}, SymbolicDeflectionFunction -> \
{Refraction, {IntrinsicMedium, BK7}, Intensity -> {IntrinsicMedium, BK7}, \
FresnelReflections -> False, Theory -> Automatic}}}, 
   {{DeflectionID -> 7786, DeflectionLabel -> Resonate, ComponentLabel -> \
Window, Options -> {}, AddTo -> {CreatedRay}, ReplaceFor -> {ReplaceFor}, \
TakeFrom -> {CreatedRay, OriginalRay}, 
     DeflectionFunction -> {Resonate, False, {CreatedRay, OriginalRay}}}}}, \
EntranceCoordinates -> {{0., 0., 0.}, {10., 0., 0.}}, 
 ConfinedPaths -> {{{SurfaceNumber -> 1, DeflectionNumber -> {1, 3}}}, \
{{SurfaceNumber -> 2, DeflectionNumber -> {2, 3}}}}, 
 RenderedSurfaces -> {{SurfaceNumber -> 1, PlotFactor -> {1., 1.}, FillOffset \
-> {0, 0}, RenderType -> Empty}, {SurfaceNumber -> 2, PlotFactor -> {1., 1.}, \
FillOffset -> {0, 0}, RenderType -> Empty}, 
   {SurfaceNumber -> {1, 2}, PlotFactor -> {1., 1.}, FillOffset -> {{0, 0}, \
{0, 0}}, RenderType -> Mesh}}, 
 RenderedPolygons -> {{{{SurfaceNumber -> 1, StartPoint -> {0., 0.}, \
FinishPoint -> {-25., -43.3013}}, {SurfaceNumber -> 2, StartPoint -> {-25., \
-43.3013}, FinishPoint -> {0., 0.}}}, {PlotFactor -> 1., RenderType -> {Fill, \
Trace}}}, 
   {{{SurfaceNumber -> 1, StartPoint -> {0., 0.}, FinishPoint -> {-25., \
43.3013}}, {SurfaceNumber -> 2, StartPoint -> {-25., 43.3013}, FinishPoint -> \
{0., 0.}}}, {PlotFactor -> 1., RenderType -> {Fill, Trace}}}, 
   {{{SurfaceNumber -> 1, StartPoint -> {0., 0.}, FinishPoint -> {50., 0}}, \
{SurfaceNumber -> 2, StartPoint -> {50., 0}, FinishPoint -> {0., 0.}}}, \
{PlotFactor -> 1., RenderType -> {Fill, Trace}}}}, 
 Options -> {ComponentLabel -> ComponentRendering, CompoundExpression -> \
True, GraphicDesign -> Automatic, WaveFrontID -> False}]\
\>", "Output",
 CellChangeTimes->{{3.505691017253948*^9, 3.5056910456305*^9}, 
   3.5056915567782907`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[clist4,LabelSurfaces->True,PlotType->FrontView,Frame->True];\
\>", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.5055626497805433`*^9, 3.505567117214204*^9, {3.505669545940049*^9, 
   3.5056695872325287`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    LineBox[{{-65., 0.}, {-43.333333333333336`, 0.}, {-21.66666666666667, 
    0.}, {0., 0.}, {21.666666666666657`, 0.}, {43.333333333333314`, 0.}, {65.,
     0.}, {65., 0.}, {43.333333333333336`, 0.}, {21.66666666666667, 0.}, {0., 
    0.}, {-21.666666666666657`, 0.}, {-43.333333333333314`, 0.}, {-65., 
    0.}, {-65., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{0., -65.}, {0., -43.333333333333336`}, {
     0., -21.66666666666667}, {0., 0.}, {0., 21.666666666666657`}, {0., 
     43.333333333333314`}, {0., 65.}, {0., 65.}, {0., 43.333333333333336`}, {
     0., 21.66666666666667}, {0., 0.}, {0., -21.666666666666657`}, {
     0., -43.333333333333314`}, {0., -65.}, {0., -65.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{-65, -65}, {65, -65}, {65, 65}, {-65, 65}, {-65, -65}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], LineBox[{{-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 
     0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 
     0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{-25., -70.}, {-25., -46.66666666666667}, {-25., \
-23.333333333333336`}, {-25., 0.}, {-25., 23.33333333333333}, {-25., 
      46.66666666666666}, {-25., 70.}, {-25., 70.}, {-25., 
      46.66666666666667}, {-25., 23.333333333333336`}, {-25., 
      0.}, {-25., -23.33333333333333}, {-25., -46.66666666666666}, {-25., \
-70.}, {-25., -70.}}]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{-25., -70.}, {-25., -70.}, {-25., 70.}, {-25., 
      70.}, {-25., -70.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], LineBox[{{12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{73.12177826491072, 13.349364905389017`}, {52.91451884327381, 
       1.682698238722356}, {32.707259421636905`, -9.983968427944307}, {
       12.499999999999995`, -21.65063509461097}, {-7.707259421636907, \
-33.317301761277626`}, {-27.91451884327381, -44.98396842794429}, \
{-48.12177826491072, -56.650635094610955`}, {-48.12177826491072, \
-56.650635094610955`}, {-27.914518843273825`, -44.98396842794429}, \
{-7.707259421636914, -33.31730176127763}, {
       12.499999999999995`, -21.65063509461097}, {
       32.7072594216369, -9.98396842794431}, {52.9145188432738, 
       1.6826982387223488`}, {73.12177826491072, 13.349364905389017`}, {
       73.12177826491072, 13.349364905389017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{73.12177826491072, 13.349364905389017`}, {73.12177826491072, 
       13.349364905389017`}, {-48.12177826491072, -56.650635094610955`}, \
{-48.12177826491072, -56.650635094610955`}, {73.12177826491072, 
       13.349364905389017`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], LineBox[{{12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{-48.121778264910674`, 
        56.65063509461099}, {-27.914518843273786`, 
        44.98396842794432}, {-7.707259421636888, 33.31730176127763}, {
        12.50000000000001, 21.65063509461096}, {32.707259421636905`, 
        9.983968427944284}, {52.9145188432738, -1.6826982387223914`}, {
        73.1217782649107, -13.34936490538907}, {
        73.1217782649107, -13.34936490538907}, {
        52.91451884327381, -1.6826982387223985`}, {32.707259421636905`, 
        9.98396842794428}, {12.50000000000001, 
        21.65063509461096}, {-7.707259421636881, 
        33.31730176127763}, {-27.914518843273772`, 
        44.983968427944305`}, {-48.121778264910674`, 
        56.65063509461099}, {-48.121778264910674`, 56.65063509461099}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{-48.121778264910674`, 
        56.65063509461099}, {-48.121778264910674`, 56.65063509461099}, {
        73.1217782649107, -13.34936490538907}, {
        73.1217782649107, -13.34936490538907}, {-48.121778264910674`, 
        56.65063509461099}}], 
       {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
        InsetBox["\<\"S1\"\>", {-66., -66.}, {0., 0.}], 
        InsetBox["\<\"S2\"\>", {-25., -71.}, {0., 0.}], 
        InsetBox["\<\"S3\"\>", {73.98780366869515, 13.84936490538902}, \
{0., 0.}], 
        InsetBox["\<\"S4\"\>", {-48.987803668695115`, 57.15063509461099}, \
{0., 0.}]}, 
       {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
        InsetBox["\<\"{1, 1}\"\>", {0, 0}], 
        InsetBox["\<\"{2, 1}\"\>", {-25., 0}], 
        InsetBox["\<\"{3, 1}\"\>", {12.499999999999995`, -21.65063509461097}],
         InsetBox["\<\"{4, 1}\"\>", \
{12.50000000000001, 21.65063509461096}]}}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{{3.5056695626528397`*^9, 3.505669587870141*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Complement", "Input",
 CellChangeTimes->{{3.505670226151197*^9, 3.505670229546414*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Complement\\\", \\\"[\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"all\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"]\\\"}]\\) gives the elements in \
\\!\\(\\*SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"all\\\", \
\\\"TI\\\"]]\\) which are not in any of the \\!\\(\\*SubscriptBox[StyleBox[\\\
\"e\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Complement"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.505670231483348*^9},
 CellTags->"Info3505648630-9982230"]
}, Open  ]],

Cell["\<\
Map[#[[2]]{{{2, 1}, {{-120.00000000000001`, {-25., -43.30127018922192}}, \
{-111.03751102542182`, {-25., -65.}}, {111.03751102542182`, {-25., 65.}}, \
{119.99999999999999`, {-25., 43.30127018922196}}}, {-120.00000000000001`, \
119.99999999999999`}}, {{3, 1}, {{-120.00000000000001`, {-25., \
-43.30127018922192}}}, {-120.00000000000001`, -3.256887993818645*^-14}}, {{4, \
1}, {{-6.106664988409954*^-15, {49.999999999999986`, 0}}, \
{119.99999999999999`, {-25., 43.30127018922196}}}, {-3.256887993818645*^-14, \
119.99999999999999`}}}\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.505678661316992*^9, 3.505678669249304*^9}}],

Cell[CellGroupData[{

Cell["\<\
collectSurfacePoints[meldresults]\
\>", "Input",
 CellChangeTimes->{3.5056701221347017`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959693953*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "120.00000000000001`"}], ",", "179.99999999999997`", ",", 
     "119.99999999999999`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-120.00000000000001`, 179.99999999999997`, 
   119.99999999999999`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879596974773`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["shiftedpointangles ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959700912*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "120.00000000000001`"}], ",", 
     RowBox[{"-", "60.00000000000002`"}], ",", 
     RowBox[{"-", "3.256887993818645`*^-14"}]}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-120.00000000000001`, -60.00000000000002, \
-3.256887993818645*^-14}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959704797*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "25.`"}], ",", 
      RowBox[{"-", "43.30127018922192`"}]}], "}"}], "}"}]}],
  SequenceForm["shiftedpointangles ", {{-25., -43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879597086353`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.256887993818645`*^-14"}], ",", "60.00000000000001`", ",",
      "119.99999999999999`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-3.256887993818645*^-14, 60.00000000000001, 
   119.99999999999999`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959712047*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{49.999999999999986`, 0}, {-25., 
    43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.50568795971568*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   PointBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]}]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959719153*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879597229023`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "56.18873895053564`"}], ",", "2.714073328182201`*^-14", ",",
      "56.188738950535644`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-56.18873895053564, 2.714073328182201*^-14, 
   56.188738950535644`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959726403*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., -43.30127018922192}, {25., 
   43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959730032*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.5994185635171`"}], ",", 
     RowBox[{"-", "93.96323496744978`"}], ",", 
     RowBox[{"-", "56.18873895053564`"}]}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.5994185635171, -93.96323496744978, \
-56.18873895053564}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879597654343`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{-35., -43.30127018922192}, {
   25., -43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879598090973`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "56.188738950535644`", ",", "93.96323496744978`", ",", 
     "125.59941856351708`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {56.188738950535644`, 93.96323496744978, 
   125.59941856351708`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959859765*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., 43.30127018922196}, {-35., 
   43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959910437*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.5994185635171`"}], ",", "179.99999999999997`", ",", 
     "125.59941856351708`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.5994185635171, 179.99999999999997`, 
   125.59941856351708`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687959958613*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["shiftedpointangles ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960006221*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   PointBox[{{-35., -43.30127018922192}, {-35., 43.30127018922196}, {
    25., -43.30127018922192}, {25., 43.30127018922196}}]}]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960056953*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960117106*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "56.18873895053562`"}], ",", "0.`", ",", 
     "56.18873895053562`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-56.18873895053562, 0., 56.18873895053562}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.50568796015359*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., -43.30127018922191}, {25., 
   43.30127018922191}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879602030373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "56.18873895053562`", ",", "93.96323496744978`", ",", 
     "125.5994185635171`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {56.18873895053562, 93.96323496744978, 
   125.5994185635171}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960247428*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., 43.30127018922191}, {-35., 
   43.30127018922191}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.50568796028741*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.5994185635171`"}], ",", 
     RowBox[{"-", "93.96323496744978`"}], ",", 
     RowBox[{"-", "56.18873895053562`"}]}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.5994185635171, -93.96323496744978, \
-56.18873895053562}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960322646*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{-35., -43.30127018922191}, {
   25., -43.30127018922191}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960381514*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.5994185635171`"}], ",", "180.`", ",", 
     "125.5994185635171`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.5994185635171, 180., 125.5994185635171}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879604262743`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["shiftedpointangles ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960472039*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   PointBox[{{-35., -43.30127018922191}, {-35., 43.30127018922191}, {
    25., -43.30127018922191}, {25., 43.30127018922191}}]}]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879605092487`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879605569897`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "56.188738950535644`"}], ",", 
     RowBox[{"-", "2.714073328182201`*^-14"}], ",", "56.18873895053564`"}], 
    "}"}]}],
  SequenceForm[
  "crosspointangles ", {-56.188738950535644`, -2.714073328182201*^-14, 
   56.18873895053564}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.50568796061508*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., -43.30127018922196}, {25., 
   43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879606908903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.59941856351708`"}], ",", 
     RowBox[{"-", "93.96323496744978`"}], ",", 
     RowBox[{"-", "56.188738950535644`"}]}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.59941856351708`, -93.96323496744978, \
-56.188738950535644`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960720789*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{-35., -43.30127018922196}, {
   25., -43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960759097*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "56.18873895053564`", ",", "93.96323496744978`", ",", 
     "125.5994185635171`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {56.18873895053564, 93.96323496744978, 
   125.5994185635171}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960816174*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{25., 43.30127018922192}, {-35., 
   43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879608603497`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.59941856351708`"}], ",", 
     RowBox[{"-", "179.99999999999997`"}], ",", "125.5994185635171`"}], 
    "}"}]}],
  SequenceForm[
  "crosspointangles ", {-125.59941856351708`, -179.99999999999997`, 
   125.5994185635171}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960917638*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["shiftedpointangles ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687960975088*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   PointBox[{{-35., -43.30127018922196}, {-35., 43.30127018922192}, {
    25., -43.30127018922196}, {25., 43.30127018922192}}]}]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961019107*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879610632153`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "120.00000000000001`"}], ",", "179.99999999999997`", ",", 
     "119.99999999999999`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-120.00000000000001`, 179.99999999999997`, 
   119.99999999999999`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961110017*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["shiftedpointangles ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.5056879611666822`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "120.00000000000001`"}], ",", 
     RowBox[{"-", "60.00000000000002`"}], ",", 
     RowBox[{"-", "3.256887993818645`*^-14"}]}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-120.00000000000001`, -60.00000000000002, \
-3.256887993818645*^-14}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961208099*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "25.`"}], ",", 
      RowBox[{"-", "43.30127018922192`"}]}], "}"}], "}"}]}],
  SequenceForm["shiftedpointangles ", {{-25., -43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961242646*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"crosspointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.256887993818645`*^-14"}], ",", "60.00000000000001`", ",",
      "119.99999999999999`"}], "}"}]}],
  SequenceForm[
  "crosspointangles ", {-3.256887993818645*^-14, 60.00000000000001, 
   119.99999999999999`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961309651*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"shiftedpointangles \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "shiftedpointangles ", {{49.999999999999986`, 0}, {-25., 
    43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.50568796137635*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   PointBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]}]], "Print",
 CellChangeTimes->{{3.505670122543339*^9, 3.505670140095771*^9}, 
   3.505670175232552*^9, 3.505670257062004*^9, 3.50567031316681*^9, {
   3.5056713743251762`*^9, 3.50567139475377*^9}, 3.5056714955293093`*^9, 
   3.5056715366042747`*^9, 3.505671678748048*^9, 3.5056717118272753`*^9, 
   3.505671830412558*^9, 3.505672544223488*^9, 3.505673928217737*^9, 
   3.505674024435647*^9, 3.50567414275414*^9, 3.5056742326834087`*^9, 
   3.5056743098641043`*^9, 3.505674349819408*^9, 3.505674509827916*^9, {
   3.505674855813531*^9, 3.50567488502291*^9}, 3.505674921565468*^9, 
   3.505675067543585*^9, 3.5056780686662693`*^9, 3.505678119998522*^9, {
   3.505678172700955*^9, 3.505678189768989*^9}, 3.505678421760284*^9, 
   3.50567864097572*^9, {3.505678716694022*^9, 3.5056787368036833`*^9}, 
   3.505679029568315*^9, 3.5056790904193974`*^9, 3.505683805701009*^9, {
   3.5056842814361897`*^9, 3.505684304504053*^9}, 3.505684510780945*^9, 
   3.505687790874834*^9, 3.505687961436079*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.`"}], ",", 
         RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", 
         RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", 
         RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", 
         RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", 
         RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", 
         RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", 
         RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.`"}], ",", 
         RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5056701235438557`*^9, 3.505670140800292*^9}, 
   3.505670175779729*^9, 3.505670257773755*^9, 3.5056703142383013`*^9, {
   3.505671375424253*^9, 3.5056713963095837`*^9}, 3.505671496369266*^9, 
   3.505671537813387*^9, 3.505671679470376*^9, 3.50567171293178*^9, 
   3.505671831223242*^9, 3.5056725449823523`*^9, 3.5056739288201723`*^9, 
   3.505674024764461*^9, 3.505674143342189*^9, 3.505674233357216*^9, 
   3.505674310520135*^9, 3.505674350147789*^9, 3.505674510068365*^9, {
   3.505674856166378*^9, 3.505674885360592*^9}, 3.505674922329451*^9, 
   3.5056750678696117`*^9, 3.505678069160282*^9, 3.50567812044648*^9, {
   3.505678173186407*^9, 3.5056781902679653`*^9}, 3.505678422597453*^9, 
   3.505678640982431*^9, {3.505678716707185*^9, 3.5056787380495033`*^9}, 
   3.5056790306511087`*^9, 3.5056790935862017`*^9, 3.5056838085728416`*^9, {
   3.5056842817911053`*^9, 3.505684304615903*^9}, 3.505684511112637*^9, 
   3.505687792757559*^9, 3.505687961511965*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Depth[{{49.99999999999994 - 1.732050807568875*tt$[1], tt$[1]}}]\
\>", "Input",
 CellChangeTimes->{{3.505713074306924*^9, 3.505713075868034*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.505713076472423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["final = MeldSurfaces[clist4]", "Input",
 CellChangeTimes->{{3.505712993060445*^9, 3.5057130020556297`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -65., 0.}, {0, -43.333333333333336`, 0.}, {
     0, -21.66666666666667, 0.}, {0, 0., 0.}, {0, 21.666666666666657`, 0.}, {
     0, 43.333333333333314`, 0.}, {0, 65., 0.}, {0, 65., 0.}, {
     0, 43.333333333333336`, 0.}, {0, 21.66666666666667, 0.}, {0, 0., 0.}, {
     0, -21.666666666666657`, 0.}, {0, -43.333333333333314`, 0.}, {
     0, -65., 0.}, {0, -65., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -65.}, {0, 0., -43.333333333333336`}, {
      0, 0., -21.66666666666667}, {0, 0., 0.}, {0, 0., 21.666666666666657`}, {
      0, 0., 43.333333333333314`}, {0, 0., 65.}, {0, 0., 65.}, {
      0, 0., 43.333333333333336`}, {0, 0., 21.66666666666667}, {0, 0., 0.}, {
      0, 0., -21.666666666666657`}, {0, 0., -43.333333333333314`}, {
      0, 0., -65.}, {0, 0., -65.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -65, -65}, {0, 65, -65}, {0, 65, 65}, {0, -65, 65}, {
     0, -65, -65}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO4AYVgegAmtXgUErwKxi2t5YIhD+RjiB0Dq
V/2yRxdfARY3PYDVnAY3osXX4DBnAQ57cblzFQ5/rcIRDmCAJdxwiQMAv58+
VA==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{95., -25., -70.}, {-45., -25., -70.}, {-45., -25., 70.}, {
      95., -25., 70.}, {95., -25., -70.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7w9z8IaDg8+93COmGZ6YHVq4DgVSB2cS0P
DHGIQZYY4gdA6lf9skcXXwEWNz2A1ZwGN6LF1+AwZwEOe3G5cxUOf63CEQ64
wg2XOADMSNQY
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdHjnKWB+2j3IQYfj25f7m7QcYOIvtot+4Sv1
crgwjfVvyJtf9jDxL7e5qtqjHBwqF23Zeuq78gGY+N//IKDh8Ox3C+uEZaZw
8UX3wy5YX5E74H5ZPGLuCge4+IV87Reyr6wPzNHIXfup1g0ufneyQt40fo8D
H2sPMXkE+xAUv4LDnFVQez3Q7MXlzs9Qf1Wj+esZNBw2oIUDrnBDFwcAqFuI
Wg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{95., 73.12177826491072, 13.349364905389017`}, {-45., 
       73.12177826491072, 
       13.349364905389017`}, {-45., -48.12177826491072, \
-56.650635094610955`}, {95., -48.12177826491072, -56.650635094610955`}, {95., 
       73.12177826491072, 13.349364905389017`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7ABmZoOjz+3cI6YZmpw+pVQPAqELu4lgeG
OMQgSwzxAyD1q37Zo4uvAIubHsBqToMb0eJrcJizAIe9uNy5Coe/VuEIB1zh
hkscAIdZc0w=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdLg2WSFvGr/HgW+1h5g8gn0cYOIn87VfyL6y
PrBAI3ftp1o3uHjP/bAL1lfkDnhcFo+Yu8IBLs4GpjUdHv9uYZ2wzBQu/uU2
V1V7lINDzqItW099V4aLP9su+oWv1MuhYDrr35A3v/bDxN96Cpifdg9y8OL4
9uX+Jq0DhMRfQM2ZgGYOzN4sNHtxubMFh7+OQsNhHlo44Ao3dHEA/pB4iQ==

        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{95., -48.121778264910674`, 
        56.65063509461099}, {-45., -48.121778264910674`, 
        56.65063509461099}, {-45., 73.1217782649107, -13.34936490538907}, {
        95., 73.1217782649107, -13.34936490538907}, {
        95., -48.121778264910674`, 56.65063509461099}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwcwBTDgEHGFCAn8PqVSDgiiG+BixuiiHOgBX4
OayAqHfALu6KIQ51D9Hiq3GYswaHvQTceQCHOzHEoe4hKA4AP/A1Zg==
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BABg4BB9DFV68CAVcM8TVgcVMMcVSAEF8B
Ue+AXdwVQxzqHqLFV+MwZw0Oewm48wAOd2KIQ92DUxwA5SI1Zg==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -65., -65.}, {60., 65., -65.}, {60., 65., 65.}, {
         60., -65., 65.}, {60., -65., -65.}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {25., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398425098*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153985773087`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
    49.999999999999986`, 0}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153985807953`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], {
    ArrowBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}}], 
    ArrowBox[{{-25., 43.30127018922196}, {49.999999999999986`, 0}}], 
    ArrowBox[{{49.999999999999986`, 0}, {-25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398588896*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398636486*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   LineBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.50691539868458*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398722987*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398765945*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., -43.30127018922192}, {25., 
   43.30127018922196}, {-35., 43.30127018922196}, {-35., -43.30127018922192}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.50691539880354*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], {
    ArrowBox[{{25., -43.30127018922192}, {25., 43.30127018922196}}], 
    ArrowBox[{{25., 43.30127018922196}, {-35., 43.30127018922196}}], 
    ArrowBox[{{-35., 43.30127018922196}, {-35., -43.30127018922192}}], 
    ArrowBox[{{-35., -43.30127018922192}, {25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398855959*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922196"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
     43.30127018922196}, {-35., -43.30127018922192}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.50691539890627*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   LineBox[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915398957219*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922196"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
     43.30127018922196}, {-35., -43.30127018922192}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., -43.30127018922192}, {25., 43.30127018922196}, {-35., 
    43.30127018922196}, {-35., -43.30127018922192}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153990076027`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399067313*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., 43.30127018922191}, {
   25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
   43.30127018922191}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.50691539910013*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], {
    ArrowBox[{{25., 43.30127018922191}, {25., -43.30127018922191}}], 
    ArrowBox[{{25., -43.30127018922191}, {-35., -43.30127018922191}}], 
    ArrowBox[{{-35., -43.30127018922191}, {-35., 43.30127018922191}}], 
    ArrowBox[{{-35., 43.30127018922191}, {25., 43.30127018922191}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153991456614`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922191"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922191"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., 43.30127018922191}, {
     25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
     43.30127018922191}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399191188*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   LineBox[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153992421*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922191"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922191"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922191"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., 43.30127018922191}, {
     25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
     43.30127018922191}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., 43.30127018922191}, {
    25., -43.30127018922191}, {-35., -43.30127018922191}, {-35., 
    43.30127018922191}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.50691539928841*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399335767*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "35.`"}], ",", 
       RowBox[{"-", "43.30127018922196`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{25., -43.30127018922196}, {25., 
   43.30127018922192}, {-35., 43.30127018922192}, {-35., -43.30127018922196}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399373275*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], {
    ArrowBox[{{25., -43.30127018922196}, {25., 43.30127018922192}}], 
    ArrowBox[{{25., 43.30127018922192}, {-35., 43.30127018922192}}], 
    ArrowBox[{{-35., 43.30127018922192}, {-35., -43.30127018922196}}], 
    ArrowBox[{{-35., -43.30127018922196}, {25., -43.30127018922196}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399426959*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922192"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922192"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
     43.30127018922192}, {-35., -43.30127018922196}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153994758787`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-70., -70.}, {-70., 70.}, {70., 70.}, {
    70., -70.}, {-70., -70.}}], 
   LineBox[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399526125*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "43.30127018922192"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", "43.30127018922192"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "35."}], ",", " ", 
         RowBox[{"-", "43.30127018922196"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
     43.30127018922192}, {-35., -43.30127018922196}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{25., -43.30127018922196}, {25., 43.30127018922192}, {-35., 
    43.30127018922192}, {-35., -43.30127018922196}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153995836143`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399622426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
    49.999999999999986`, 0}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399659227*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], {
    ArrowBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}}], 
    ArrowBox[{{-25., 43.30127018922196}, {49.999999999999986`, 0}}], 
    ArrowBox[{{49.999999999999986`, 0}, {-25., -43.30127018922192}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153997105293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399760234*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-65., -65.}, {-65., 65.}, {65., 65.}, {
    65., -65.}, {-65., -65.}}], 
   LineBox[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.506915399810087*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "43.30127018922192"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "43.30127018922196"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"49.999999999999986", ",", " ", "0"}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
      49.999999999999986`, 0}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -43.30127018922192}, {-25., 43.30127018922196}, {
     49.999999999999986`, 0}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153998601637`*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
     0, -4.166666666666669, -7.2168783648703085`}, {
     0, -8.333333333333334, -14.433756729740631`}, {
     0, -12.499999999999998`, -21.650635094610955`}, {
     0, -16.66666666666666, -28.867513459481277`}, {
     0, -20.83333333333332, -36.08439182435159}, {
     0, -24.99999999999999, -43.301270189221924`}, {
     0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, -4.16666666666667, 7.216878364870338}, {
      0, -8.333333333333336, 14.433756729740661`}, {
      0, -12.5, 21.650635094610983`}, {
      0, -16.666666666666664`, 28.86751345948131}, {
      0, -20.83333333333333, 36.084391824351634`}, {
      0, -24.999999999999993`, 43.30127018922195}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, 8.333333333333327, 1.4210854715202004`*^-14}, {
      0, 16.66666666666666, 1.4210854715202004`*^-14}, {
      0, 24.999999999999993`, 1.4210854715202004`*^-14}, {
      0, 33.33333333333332, 1.4210854715202004`*^-14}, {
      0, 41.66666666666665, 1.4210854715202004`*^-14}, {
      0, 49.999999999999986`, 1.4210854715202004`*^-14}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -25., -43.30127018922192}, {0, -25., 43.30127018922196}, {
      0, 49.999999999999986`, 0.}, {0, -25., -43.30127018922192}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgee/W5hnbDM9QC6+D3/jTGi92xwiOtg
iDOgAIT4HYh6B+ziNhjiUPcQLX4Phzn3cNhLwJ0Y/rqDIxxwhRtMHAAzM0zw

      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.30127018922194}, {
      0., -25., -43.30127018922194}, {0., -25., 43.30127018922194}, {
      60., -25., 43.30127018922194}, {60., -25., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOfD3PwhoODz73cI6YZnpAZgMdnEVB+ziJjjE
7XCIu+AQ9yRRHJc5uOzF5U5c/sIZDjjCDVMcANDOrYs=
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcfj3HwQsDjz63cI6YZnrAZg4WPi/xoEXF99F
nuVygotD6Ad7bvtvjBG9ZwMX/wtR7/AMbI7pATTzHR6B1eugiu93cvgAFpdB
M8cDao/MXkLiuMzBZS8ud+LyF65wwBVu6OIAE7Ccng==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-10., -24.999999999999993`, -43.30127018922191}, {
       50., -24.999999999999993`, -43.30127018922191}, {50., 
       49.99999999999998, -2.4868995751603507`*^-14}, {-10., 
       49.99999999999998, -2.4868995751603507`*^-14}, {-10., \
-24.999999999999993`, -43.30127018922191}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOcAGpjUdHv9uYZ2wzNQBJoNdXMUBu7gJDnE7
HOIuOMQ9SRTHZQ4ue3G5E5e/cIYDjnDDFAcAi99Mvw==
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcYDQnlBaYS9MnBFEHXByOOS/MUb0nowDTJwJ
TFs6XAGL68DF2cC0psPj3y2sE5aZwsUhtIDtHbB6G7j4t/8goHHg1cV3kWe5
nODiv8HiFgeeg81xJSj+A2rOazRzIDQPhr243InLXwzQcDiGFg64wg1dHACR
jlus
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{-10., 50., -2.842170943040401*^-14}, {50., 
        50., -2.842170943040401*^-14}, {50., -24.999999999999982`, 
        43.301270189221945`}, {-10., -24.999999999999982`, 
        43.301270189221945`}, {-10., 50., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[{{60., -4.736951571734001*^-15, 
        1.4210854715202004`*^-14}, {
        60., -4.166666666666669, -7.2168783648703085`}, {
        60., -8.333333333333334, -14.433756729740631`}, {
        60., -12.499999999999998`, -21.650635094610955`}, {
        60., -16.66666666666666, -28.867513459481277`}, {
        60., -20.83333333333332, -36.08439182435159}, {
        60., -24.99999999999999, -43.301270189221924`}, {
        60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., -4.16666666666667, 7.216878364870338}, {60., -8.333333333333336,
          14.433756729740661`}, {60., -12.5, 21.650635094610983`}, {
         60., -16.666666666666664`, 28.86751345948131}, {
         60., -20.83333333333333, 36.084391824351634`}, {
         60., -24.999999999999993`, 43.30127018922195}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., 8.333333333333327, 1.4210854715202004`*^-14}, {60., 
         16.66666666666666, 1.4210854715202004`*^-14}, {60., 
         24.999999999999993`, 1.4210854715202004`*^-14}, {60., 
         33.33333333333332, 1.4210854715202004`*^-14}, {60., 
         41.66666666666665, 1.4210854715202004`*^-14}, {60., 
         49.999999999999986`, 1.4210854715202004`*^-14}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -25., -43.30127018922192}, {60., -25., 
         43.30127018922196}, {60., 49.999999999999986`, 0.}, {
         60., -25., -43.30127018922192}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {20., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {20., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{330.8387629181295, 417.50202745533437`},
  PlotRange:>All,
  ViewPoint->{-0.28278022117575075`, -1.749326326275979, 2.8826884588365735`},
  
  ViewVertical->{-0.2976702780839894, 0.4301914878247621, 
   0.8962762787269706}]], "Print",
 CellChangeTimes->{3.505713002839603*^9, 3.505713219099958*^9, 
  3.505713285782217*^9, 3.50571347961266*^9, 3.505713535929927*^9, 
  3.505713621907838*^9, 3.505713709414599*^9, 3.505734474306205*^9, 
  3.505734520380948*^9, 3.5069153999474897`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", 
           RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", 
          RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922191`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922191`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922191`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"25.`", ",", "12.499999999999995`", ",", 
          RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "0.4999999999999998`"}], ",", "0.8660254037844388`"}], 
         "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "43.30127018922196`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", "43.30127018922192`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", "43.30127018922192`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "35.`"}], ",", 
             RowBox[{"-", "43.30127018922196`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
         "25.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "0.5000000000000004`"}], ",", 
          RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", 
             RowBox[{"-", "43.30127018922192`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", "43.30127018922196`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"49.999999999999986`", ",", "0"}], "}"}]}], "}"}], "]"}], 
        ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.505713004287187*^9, 3.505713219898158*^9, 
  3.505713286607992*^9, 3.505713480639937*^9, 3.505713536898794*^9, 
  3.5057136228125267`*^9, 3.505713710259611*^9, 3.505734475780097*^9, 
  3.5057345214677057`*^9, 3.506915400027851*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["clist4", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"130", ",", "130"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", 
            RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", "12.499999999999995`", ",", 
            RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.4999999999999998`"}], ",", 
            "0.8660254037844388`"}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"140", ",", "140"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "25.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.5000000000000004`"}], ",", 
            RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]}], "}"}], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"130", ",", "130"}], "}"}], "]"}], ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.505714521241706*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaBuildDate", "Input",
 CellChangeTimes->{{3.505714199967309*^9, 3.505714203285285*^9}, 
   3.505714451537018*^9}],

Cell[BoxData["\<\"Dec 13, 2010\"\>"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.505714204032074*^9, 3.505714451538435*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[final,LabelSurfaces->True,Axes->True];\
\>", "Input",
 CellChangeTimes->{{3.505713631352746*^9, 3.505713641864678*^9}, 
   3.505713798815284*^9, {3.505731271639041*^9, 3.505731274177528*^9}}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
     0, -4.166666666666669, -7.2168783648703085`}, {
     0, -8.333333333333334, -14.433756729740631`}, {
     0, -12.499999999999998`, -21.650635094610955`}, {
     0, -16.66666666666666, -28.867513459481277`}, {
     0, -20.83333333333332, -36.08439182435159}, {
     0, -24.99999999999999, -43.301270189221924`}, {
     0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, 8.333333333333327, 1.4210854715202004`*^-14}, {
      0, 16.66666666666666, 1.4210854715202004`*^-14}, {
      0, 24.999999999999993`, 1.4210854715202004`*^-14}, {
      0, 33.33333333333332, 1.4210854715202004`*^-14}, {
      0, 41.66666666666665, 1.4210854715202004`*^-14}, {
      0, 49.999999999999986`, 1.4210854715202004`*^-14}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
      0, -4.16666666666667, 7.216878364870338}, {
      0, -8.333333333333336, 14.433756729740661`}, {
      0, -12.5, 21.650635094610983`}, {
      0, -16.666666666666664`, 28.86751345948131}, {
      0, -20.83333333333333, 36.084391824351634`}, {
      0, -24.999999999999993`, 43.30127018922195}, {
      0, -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -25., -43.30127018922192}, {0, 49.999999999999986`, 0.}, {
      0, -25., 43.30127018922196}, {0, -25., -43.30127018922192}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgee/W5hnbDM9QC6+D3/jTGi92xwiOtg
iDOgAIT4HYh6B+ziNhjiUPcQLX4Phzn3cNhLwJ0Y/rqDIxxwhRtMHAAzM0zw

      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -43.30127018922194}, {
      0., -25., -43.30127018922194}, {0., -25., 43.30127018922194}, {
      60., -25., 43.30127018922194}, {60., -25., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOfD3PwhoODz73cI6YZnpAZgMdnEVB+ziJjjE
7XCIu+AQ9yRRHJc5uOzF5U5c/sIZDjjCDVMcANDOrYs=
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcfj3HwQsDjz63cI6YZnrAZg4WPi/xoEXF99F
nuVygotD6Ad7bvtvjBG9ZwMX/wtR7/AMbI7pATTzHR6B1eugiu93cvgAFpdB
M8cDao/MXkLiuMzBZS8ud+LyF65wwBVu6OIAE7Ccng==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-10., -24.999999999999993`, -43.30127018922191}, {
       50., -24.999999999999993`, -43.30127018922191}, {50., 
       49.99999999999998, -2.4868995751603507`*^-14}, {-10., 
       49.99999999999998, -2.4868995751603507`*^-14}, {-10., \
-24.999999999999993`, -43.30127018922191}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQOcAGpjUdHv9uYZ2wzNQBJoNdXMUBu7gJDnE7
HOIuOMQ9SRTHZQ4ue3G5E5e/cIYDjnDDFAcAi99Mvw==
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgwcYDQnlBaYS9MnBFEHXByOOS/MUb0nowDTJwJ
TFs6XAGL68DF2cC0psPj3y2sE5aZwsUhtIDtHbB6G7j4t/8goHHg1cV3kWe5
nODiv8HiFgeeg81xJSj+A2rOazRzIDQPhr243InLXwzQcDiGFg64wg1dHACR
jlus
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{-10., 50., -2.842170943040401*^-14}, {50., 
        50., -2.842170943040401*^-14}, {50., -24.999999999999982`, 
        43.301270189221945`}, {-10., -24.999999999999982`, 
        43.301270189221945`}, {-10., 50., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[{{60., -4.736951571734001*^-15, 
        1.4210854715202004`*^-14}, {
        60., -4.166666666666669, -7.2168783648703085`}, {
        60., -8.333333333333334, -14.433756729740631`}, {
        60., -12.499999999999998`, -21.650635094610955`}, {
        60., -16.66666666666666, -28.867513459481277`}, {
        60., -20.83333333333332, -36.08439182435159}, {
        60., -24.99999999999999, -43.301270189221924`}, {
        60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., 8.333333333333327, 1.4210854715202004`*^-14}, {60., 
         16.66666666666666, 1.4210854715202004`*^-14}, {60., 
         24.999999999999993`, 1.4210854715202004`*^-14}, {60., 
         33.33333333333332, 1.4210854715202004`*^-14}, {60., 
         41.66666666666665, 1.4210854715202004`*^-14}, {60., 
         49.999999999999986`, 1.4210854715202004`*^-14}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         60., -4.16666666666667, 7.216878364870338}, {60., -8.333333333333336,
          14.433756729740661`}, {60., -12.5, 21.650635094610983`}, {
         60., -16.666666666666664`, 28.86751345948131}, {
         60., -20.83333333333333, 36.084391824351634`}, {
         60., -24.999999999999993`, 43.30127018922195}, {
         60., -4.736951571734001*^-15, 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -25., -43.30127018922192}, {60., 49.999999999999986`,
          0.}, {60., -25., 43.30127018922196}, {
         60., -25., -43.30127018922192}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {20., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {20., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{352.9797798015008, 445.93014953363144`},
  PlotRange:>All,
  ViewPoint->{-0.003277489006393651, -3.257576121609655, -0.9155255703607724},
  
  ViewVertical->{0.01782584265596141, -0.9090146372617033, 
   0.6164914340829097}]], "Print",
 CellChangeTimes->{3.505713642695491*^9, 3.505713713409953*^9, 
  3.505713800251321*^9, 3.505731274908038*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[final,PlotType->FrontView,LabelSurfaces->True,Frame->True];\
\>", "Input",
 CellChangeTimes->{{3.505713631352746*^9, 3.505713641864678*^9}, 
   3.505713798815284*^9, {3.505731271639041*^9, 3.505731274177528*^9}, {
   3.5057313362637*^9, 3.5057313482263393`*^9}, {3.505731386773958*^9, 
   3.505731388458474*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    LineBox[{{-4.736951571734001*^-15, 
    1.4210854715202004`*^-14}, {-4.166666666666669, -7.2168783648703085`}, \
{-8.333333333333334, -14.433756729740631`}, {-12.499999999999998`, \
-21.650635094610955`}, {-16.66666666666666, -28.867513459481277`}, \
{-20.83333333333332, -36.08439182435159}, {-24.99999999999999, \
-43.301270189221924`}, {-4.736951571734001*^-15, 
    1.4210854715202004`*^-14}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{-4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
     8.333333333333327, 1.4210854715202004`*^-14}, {16.66666666666666, 
     1.4210854715202004`*^-14}, {24.999999999999993`, 
     1.4210854715202004`*^-14}, {33.33333333333332, 
     1.4210854715202004`*^-14}, {41.66666666666665, 
     1.4210854715202004`*^-14}, {49.999999999999986`, 
     1.4210854715202004`*^-14}, {-4.736951571734001*^-15, 
     1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{-4.736951571734001*^-15, 
     1.4210854715202004`*^-14}, {-4.16666666666667, 
     7.216878364870338}, {-8.333333333333336, 14.433756729740661`}, {-12.5, 
     21.650635094610983`}, {-16.666666666666664`, 
     28.86751345948131}, {-20.83333333333333, 
     36.084391824351634`}, {-24.999999999999993`, 
     43.30127018922195}, {-4.736951571734001*^-15, 
     1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{-25., -43.30127018922192}, {49.999999999999986`, 0.}, {-25., 
     43.30127018922196}, {-25., -43.30127018922192}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], LineBox[{{-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 
     0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 
     0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}, {-25., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{-25., -43.30127018922194}, {-25., -28.867513459481295`}, \
{-25., -14.433756729740647`}, {-25., 0.}, {-25., 14.433756729740644`}, {-25., 
      28.867513459481287`}, {-25., 43.30127018922194}, {-25., 
      43.30127018922194}, {-25., 28.867513459481295`}, {-25., 
      14.433756729740647`}, {-25., 
      0.}, {-25., -14.433756729740644`}, {-25., -28.867513459481287`}, {-25., \
-43.30127018922194}, {-25., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{-25., -43.30127018922194}, {-25., -43.30127018922194}, {-25., 
      43.30127018922194}, {-25., 
      43.30127018922194}, {-25., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], LineBox[{{12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}, {
      12.499999999999995`, -21.65063509461097}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-24.999999999999993`, -43.30127018922191}, \
{-12.499999999999998`, -36.0843918243516}, {-1.7763568394002505`*^-15, \
-28.867513459481284`}, {12.499999999999995`, -21.65063509461097}, {
       24.999999999999993`, -14.433756729740654`}, {
       37.499999999999986`, -7.21687836487034}, {
       49.99999999999998, -2.4868995751603507`*^-14}, {
       49.99999999999998, -2.4868995751603507`*^-14}, {
       37.499999999999986`, -7.21687836487034}, {
       24.999999999999993`, -14.433756729740654`}, {
       12.499999999999995`, -21.65063509461097}, {-1.7763568394002505`*^-15, \
-28.867513459481284`}, {-12.499999999999998`, -36.0843918243516}, \
{-24.999999999999993`, -43.30127018922191}, {-24.999999999999993`, \
-43.30127018922191}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-24.999999999999993`, -43.30127018922191}, \
{-24.999999999999993`, -43.30127018922191}, {
       49.99999999999998, -2.4868995751603507`*^-14}, {
       49.99999999999998, -2.4868995751603507`*^-14}, {-24.999999999999993`, \
-43.30127018922191}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], LineBox[{{12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}, {12.50000000000001, 21.65063509461096}, {
       12.50000000000001, 21.65063509461096}, {12.50000000000001, 
       21.65063509461096}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{50., -2.842170943040401*^-14}, {37.50000000000001, 
        7.216878364870299}, {25.000000000000007`, 14.43375672974063}, {
        12.50000000000001, 21.65063509461096}, {1.4210854715202004`*^-14, 
        28.867513459481287`}, {-12.499999999999982`, 
        36.08439182435161}, {-24.999999999999982`, 
        43.301270189221945`}, {-24.999999999999982`, 
        43.301270189221945`}, {-12.499999999999986`, 36.08439182435162}, {
        1.2434497875801753`*^-14, 28.867513459481287`}, {12.50000000000001, 
        21.65063509461096}, {25.000000000000007`, 14.43375672974063}, {37.5, 
        7.216878364870302}, {50., -2.842170943040401*^-14}, {
        50., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{50., -2.842170943040401*^-14}, {
        50., -2.842170943040401*^-14}, {-24.999999999999982`, 
        43.301270189221945`}, {-24.999999999999982`, 43.301270189221945`}, {
        50., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], LineBox[{{-4.736951571734001*^-15, 
        1.4210854715202004`*^-14}, {-4.166666666666669, \
-7.2168783648703085`}, {-8.333333333333334, -14.433756729740631`}, \
{-12.499999999999998`, -21.650635094610955`}, {-16.66666666666666, \
-28.867513459481277`}, {-20.83333333333332, -36.08439182435159}, \
{-24.99999999999999, -43.301270189221924`}, {-4.736951571734001*^-15, 
        1.4210854715202004`*^-14}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.736951571734001*^-15, 1.4210854715202004`*^-14}, {
         8.333333333333327, 1.4210854715202004`*^-14}, {16.66666666666666, 
         1.4210854715202004`*^-14}, {24.999999999999993`, 
         1.4210854715202004`*^-14}, {33.33333333333332, 
         1.4210854715202004`*^-14}, {41.66666666666665, 
         1.4210854715202004`*^-14}, {49.999999999999986`, 
         1.4210854715202004`*^-14}, {-4.736951571734001*^-15, 
         1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.736951571734001*^-15, 
         1.4210854715202004`*^-14}, {-4.16666666666667, 
         7.216878364870338}, {-8.333333333333336, 
         14.433756729740661`}, {-12.5, 
         21.650635094610983`}, {-16.666666666666664`, 
         28.86751345948131}, {-20.83333333333333, 
         36.084391824351634`}, {-24.999999999999993`, 
         43.30127018922195}, {-4.736951571734001*^-15, 
         1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-25., -43.30127018922192}, {49.999999999999986`, 0.}, {-25.,
          43.30127018922196}, {-25., -43.30127018922192}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
         InsetBox["\<\"S1\"\>", {-38.49999999999999, -44.30127018922194}, \
{0., 0.}], InsetBox["\<\"S2\"\>", {-25., -44.30127018922194}, {0., 0.}], 
         InsetBox["\<\"S3\"\>", {-25.86602540378443, -43.80127018922192}, \
{0., 0.}], 
         InsetBox["\<\"S4\"\>", {50.86602540378444, -0.4999999999999969}, \
{0., 0.}], 
         InsetBox["\<\"S5\"\>", {-38.49999999999999, -44.30127018922194}, \
{0., 0.}]}, 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
         InsetBox["\<\"{1, 1}\"\>", {0, 0}], 
         InsetBox["\<\"{2, 1}\"\>", {-25., 0}], 
         InsetBox["\<\"{3, 1}\"\>", \
{12.499999999999995`, -21.65063509461097}], 
         InsetBox["\<\"{4, 1}\"\>", {12.50000000000001, 21.65063509461096}], 
         InsetBox["\<\"{5, 1}\"\>", {0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.505731348848167*^9, 3.505731389090453*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[final,PlotType->SideView,LabelSurfaces->True,Frame->True];\
\>", "Input",
 CellChangeTimes->{{3.505713631352746*^9, 3.505713641864678*^9}, 
   3.505713798815284*^9, {3.505731271639041*^9, 3.505731274177528*^9}, {
   3.5057313362637*^9, 3.5057313839469843`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    LineBox[{{0, 1.4210854715202004`*^-14}, {0, -7.2168783648703085`}, {
     0, -14.433756729740631`}, {0, -21.650635094610955`}, {
     0, -28.867513459481277`}, {0, -36.08439182435159}, {
     0, -43.301270189221924`}, {0, 1.4210854715202004`*^-14}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{0, 1.4210854715202004`*^-14}, {0, 1.4210854715202004`*^-14}, {
      0, 1.4210854715202004`*^-14}, {0, 1.4210854715202004`*^-14}, {
      0, 1.4210854715202004`*^-14}, {0, 1.4210854715202004`*^-14}, {
      0, 1.4210854715202004`*^-14}, {0, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{0, 1.4210854715202004`*^-14}, {0, 7.216878364870338}, {
      0, 14.433756729740661`}, {0, 21.650635094610983`}, {
      0, 28.86751345948131}, {0, 36.084391824351634`}, {
      0, 43.30127018922195}, {0, 1.4210854715202004`*^-14}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{0, -43.30127018922192}, {0, 0.}, {0, 43.30127018922196}, {
      0, -43.30127018922192}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], LineBox[{{60., 0.}, {50., 0.}, {40., 0.}, {30., 0.}, {20., 0.}, {
     10., 0.}, {0., 0.}, {0., 0.}, {10., 0.}, {20., 0.}, {30., 0.}, {40., 
     0.}, {50., 0.}, {60., 0.}, {60., 0.}}], 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{30., -43.30127018922194}, {30., -28.867513459481295`}, {
      30., -14.433756729740647`}, {30., 0.}, {30., 14.433756729740644`}, {30.,
       28.867513459481287`}, {30., 43.30127018922194}, {30., 
      43.30127018922194}, {30., 28.867513459481295`}, {30., 
      14.433756729740647`}, {30., 0.}, {30., -14.433756729740644`}, {
      30., -28.867513459481287`}, {30., -43.30127018922194}, {
      30., -43.30127018922194}}]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{60., -43.30127018922194}, {0., -43.30127018922194}, {0., 
      43.30127018922194}, {60., 43.30127018922194}, {60., -43.30127018922194}}
      ]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], LineBox[{{-10., -21.65063509461097}, {0., -21.65063509461097}, {
      10., -21.65063509461097}, {20., -21.65063509461097}, {
      30., -21.65063509461097}, {40., -21.65063509461097}, {
      50., -21.65063509461097}, {50., -21.65063509461097}, {
      40., -21.65063509461097}, {30., -21.65063509461097}, {
      20., -21.65063509461097}, {10., -21.65063509461097}, {
      0., -21.65063509461097}, {-10., -21.65063509461097}, {-10., \
-21.65063509461097}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{20., -43.30127018922191}, {20., -36.0843918243516}, {
       20., -28.867513459481284`}, {20., -21.65063509461097}, {
       20., -14.433756729740654`}, {20., -7.21687836487034}, {
       20., -2.4868995751603507`*^-14}, {20., -2.4868995751603507`*^-14}, {
       20., -7.21687836487034}, {20., -14.433756729740654`}, {
       20., -21.65063509461097}, {20., -28.867513459481284`}, {
       20., -36.0843918243516}, {20., -43.30127018922191}, {
       20., -43.30127018922191}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-10., -43.30127018922191}, {50., -43.30127018922191}, {
       50., -2.4868995751603507`*^-14}, {-10., -2.4868995751603507`*^-14}, \
{-10., -43.30127018922191}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], LineBox[{{-10., 21.65063509461096}, {0., 21.65063509461096}, {
       10., 21.65063509461096}, {20., 21.65063509461096}, {30., 
       21.65063509461096}, {40., 21.65063509461096}, {50., 
       21.65063509461096}, {50., 21.65063509461096}, {40., 
       21.65063509461096}, {30., 21.65063509461096}, {20., 
       21.65063509461096}, {10., 21.65063509461096}, {0., 
       21.65063509461096}, {-10., 21.65063509461096}, {-10., 
       21.65063509461096}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{20., -2.842170943040401*^-14}, {20., 7.216878364870299}, {
        20., 14.43375672974063}, {20., 21.65063509461096}, {20., 
        28.867513459481287`}, {20., 36.08439182435161}, {20., 
        43.301270189221945`}, {20., 43.301270189221945`}, {20., 
        36.08439182435162}, {20., 28.867513459481287`}, {20., 
        21.65063509461096}, {20., 14.43375672974063}, {20., 
        7.216878364870302}, {20., -2.842170943040401*^-14}, {
        20., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{-10., -2.842170943040401*^-14}, {
        50., -2.842170943040401*^-14}, {50., 43.301270189221945`}, {-10., 
        43.301270189221945`}, {-10., -2.842170943040401*^-14}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], LineBox[{{60., 1.4210854715202004`*^-14}, {
        60., -7.2168783648703085`}, {60., -14.433756729740631`}, {
        60., -21.650635094610955`}, {60., -28.867513459481277`}, {
        60., -36.08439182435159}, {60., -43.301270189221924`}, {60., 
        1.4210854715202004`*^-14}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{60., 1.4210854715202004`*^-14}, {60., 
         1.4210854715202004`*^-14}, {60., 1.4210854715202004`*^-14}, {60., 
         1.4210854715202004`*^-14}, {60., 1.4210854715202004`*^-14}, {60., 
         1.4210854715202004`*^-14}, {60., 1.4210854715202004`*^-14}, {60., 
         1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{60., 1.4210854715202004`*^-14}, {60., 7.216878364870338}, {
         60., 14.433756729740661`}, {60., 21.650635094610983`}, {60., 
         28.86751345948131}, {60., 36.084391824351634`}, {60., 
         43.30127018922195}, {60., 1.4210854715202004`*^-14}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{60., -43.30127018922192}, {60., 0.}, {60., 
         43.30127018922196}, {60., -43.30127018922192}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
         InsetBox["\<\"S1\"\>", {0., -44.30127018922194}, {0., 0.}], 
         InsetBox["\<\"S2\"\>", {56., -44.30127018922194}, {0., 0.}], 
         InsetBox["\<\"S3\"\>", {-5.999999999999999, -43.80127018922192}, \
{0., 0.}], InsetBox["\<\"S4\"\>", {-6., -0.4999999999999969}, {0., 0.}], 
         InsetBox["\<\"S5\"\>", {60., -44.30127018922194}, {0., 0.}]}, 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
         InsetBox["\<\"{1, 1}\"\>", {0, 0}], 
         InsetBox["\<\"{2, 1}\"\>", {30., 0}], 
         InsetBox["\<\"{3, 1}\"\>", {20., -21.65063509461097}], 
         InsetBox["\<\"{4, 1}\"\>", {20., 21.65063509461096}], 
         InsetBox["\<\"{5, 1}\"\>", {60., 0}]}}}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{{3.505731379148343*^9, 3.505731384520402*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXX+MG1V+n8QbNmFzR3NH2pSQU5JNOEh23Ui9qAhdSSxBOQ6OCZceIVeT
QoEJ6aXCoggYIIgdTk1HKac4B4rbIMwJGRF8cDIiZ4FkcfhUYkEdVdZV5hQr
bJr6TrFOLvL+Ma0s9dP3a8az9thsdrO3dvha2reeN+993+f7471579nv4+/c
9+hDD/7dfY/uu/++tbc8cl/soX33//3av3j4EZYVWqRpix5ifz9bqw2x99C0
aQl/7eOJpn1N/Auh2aij7jTF1TUqr1GvwxGFoX1dpEMsaaLZbIr/jtNcrIqy
+qjVRWFtc0DeRjePV2s0WCqvLrRuo0ddCXHYD1u9mqjX6qLeUqn1KvFvGdAo
w9aZVXQbhcmGKFxMxmDEU4gbUaTKjrZBlF3CkjqShg47lYShmyg7bpPLxL2s
HWWSo0gXJoWcejEJ3YgjFTcQS5WVHA68hnhEemKxSJcgVXG6lL+cJQ0kefmo
hbhtIV2sBcl3tXeKceh2sQcEJrJZQYzFQdiwYJkmMuVGUPmNHoKa0NxKJhHT
YyjUmrwsYpEYUikbeizNDT4sbfvHyiaNgo2IAoJqht2JQSBv5BHWTFRZqVFl
22rGgGZkIW9b0GJZ7VrXtk4BkXBcuXRSAM8IQXVYWhjZarOlmFNiCG1M8gBt
VJDN5YLKu8Udx40TditioNwMFC9RjjDpdVTKZZTLFRRSMWa+JCr1X/dE1Kg3
VBNMdLhrE27xyRQLIjMvDVGwEDbfR9bQYGSl0/NmGLFsVZl6hRdSDgs/EzHT
ZCFlsnQ5YkYMmYpsvFFkrrAKUtM8lypbYMGCCANQaEDqeBlrIAIzLxtrlOKs
EZuhhBfojQL0sMhionKstg1VGPGwBqtQV/2VlZ3MIGqkpeO6lJVDDe+VVZha
BPkzgeVcDzjlBO8xsFg/iEUj7H0E8fSrnyPaYf1NR+E/A0W7lk9HNdhFaS+H
Kx4+hKeY+FxdmqoYD0OzCsryX1GWr9eqqFbFH7M8T0dQV0Hlt3opHkHY7QwM
gh3WkW9AWy/kDHuAXATMTSLo6/ANMsL2Ik/I1rQ43OAqWJFpStdyFqLxYrdy
rbGliVImgWiYj0cW/uOjnsXzcRM5fq8cF127i3QvAIR0kxUx8G/Bkr1+kmFB
ricKcJo1JNhoF/6nFPNWhIemF7YRz/zuGMMHO9fEfLwJm7n2wNbcyC7YLLJz
tZaD2yLb8UU2s3SEmcMNlYQKKW8gaDqQz0quI28qisp/B9fxjMGeVDlLh5mt
dpXfcsskLCOBcjEBnasXXN4tXk6bUM92JAq1zyte4WMMK2qyTmTFM6g16ywe
W5HOY7UV6atUrSYb/Iopg/ldmrtZSYkhvSoCmg/vYkh3R3TRiBrR1eiuAvly
Yb4qe9SEVTCjWUbUGxOrcnz0DbuowDaTomhzMiM6fbEeWKXlIf5ATuXk2FNN
s97MQi+4Gc9DXHaE5ems33SB1BrWS8wzZgbVhoNmdxXaH7hWXtmYAUvpfFgX
5hNDfGtYlyZnc7JaGclYhAEqaHKiNYSSOzuJ6mx20uiYnKRTYnJS8k9OWJfK
sWpaRJmbB0VJPeltOTNwbVDLx9nDWYZSNJ4XunUtW2A2iERk2WQpUK47K+Hh
EFaR002emOhENRXKUa5DR9lrvN5aYSaIwLBTKFYbfECU05G0nI401Kjqm+E6
bIbbkJ122gxX9WNtXOWxgqg3ps+EecQ21Ox4cc9yPM/pWm5zQN61rgv9g4q8
r12n7jl19oipuZMVNlesN4TBMH0yP5P3X1XqatqdEHPPVi4D5q4O4Jtj+/Mu
C8gbnmG5ueRd7DYGETO1MTd5QfEs8xYs/GUbS1nX98YNdX/aKntogSzW716m
NtwQGpKPN3e3RlMbHUFFh8WTpu6tS2XE8U0Z9kD63E4i7sxP1/iyP0+8mtWM
mI2YiSTipo4Ie7LLMtO2W6h7UButciMdYVTNmiJU4qkkTD0MM10SZXRvB47L
iaGsZody5tYZjnxZZvJ6ZhxJthQOR9hEuyH7jxY2YFsm7Ew5NIt51XL3Tqtr
ehNI/nBQE0O173A5Ww7bMDOTqnpZrFs8ea0Ns+sCmtp8kfOuVFbPWwYyk2oC
W+H7NIbYh+NT+KiVlUuJSh65ckN570tiW8gws559k2ylajC1xIik8rJsWZOs
eM/GXpb9AwWlm6NKCV0GQtxCPF0UO8IrlEWbjZranGiKzT0uV+0W+He9/kcU
X4ZGTS2lmlWkYmFo3nqb73uZYrEiZ+iXyU1qpU61kJJDWq7mjtwlW4epFoYz
1K+L2ZqO4y5nkGfjZbLsqIgZEhu2ltx2hpUpe6uT1qaS9r+qaL2UVgEV4VuI
brzmmMR4UeBUjxcOtYa0KdeAESsj1l2L1b0aE8NVTV2I8z7HWgwFM7ZaRqsq
reW1FrFQrKlpkyvYafPdCCstHyMRM42qKO2IrWBv8cV3h/S0CI9htwkmkO9R
cZuki3LVznePnXLa63zRRME16wznmCs86R1mFK9aMQMzyqMrzPuWV5w5Lazp
rN9D6Jo2LbFabttYcfXlG8laOKlklmHFUpiaZJITckNyMhuTGyTT9K3DZmiS
FVmrkrJYOMmFtqGz5vgHKk1coL6ew7pYE0qhSs5iD/vsV7ziDWRY9OkxG3aM
9eFIQppo+s6G1HeYOwVmJIKYbSOmqw0dJjUfj3rjfTxf9VANq5Tvo4V1E3Gb
d3/d23ssJQ2vXrIkM2c8EgWbsZxJ8w+QuPFhMOfyvWBXjlNXGxXNpvZ/Ik9+
7FZXmxVsYdB6NHh7BsJMvCjfqJN7C01ePOST4LhlZ/R8OnPmDPbv348jR44w
TXh6OZ76m5tx1fjN2KlvZ3XG8cihIzjyDw9j+8aN2Mi7wTf+GoeOHPlDUTyE
2267DStXrsTOnTu13SIN4aabbsL4+Li4GlN5mzZt4u/E1d0q7/bbb8ddd90l
JG1W8mzm0auuuspTaRbLuY8//hjvvPOOuFquHN9mMi8M+TaLuxn35JNPYtu2
beJqt8orlUp4/vnnxdWYyjt48KDX5t0qr1ar4YUXXhBX7iP0s88+w9VXX32x
VHHFEkyCSTAJJsEcCJjeus/3HZXuxfsKulwCLBWfteoR9clu57dCum8o9ZU2
cj7EJ2xsCl0po8S/51Hgn0EbyFd+E/QlDG1AVGOTUaeSFV8IMU1T/cUQO/gv
uI2vWiyLrQjkR8JG/E0c6PzSw6AoGhJf0Wn/PkaV9Sv+uaYttCqJYHXEFwQ6
vl4gJS1Rc33+Uup5kOdTtSW+ibncy5Lf0Mgyj+UqeRhimRP4Yf2AeEiutJaJ
BbvYjGALuXrwZ+GD0rvcYdDh34dwv9DQ+Wn0gGjTeh619iEH5Hk0IE98gkkw
CSbBJJgEk2ASTBdmNpsV2+V9DnNArEkwBxHmtC8X/b7BLfYQzOCzsX6zHMEk
mASTYBJMgkkwCSbBJJgEk2ASzL6FSYvd2VqOYBLMXjCfeuqpDpjvvvtux/Zq
JBIhaxJMgkkwCSbBJJgEk2ASTIJJi93+sRzBJJgEk2ASzN8LzB0q73QuhUzx
vK8pljrnUT5dd1VwKWiK6SSyZclIMdp/GukivQyYymNcm1AUkB4Nt0ssKTiE
J0wc+8UprpzMXoo2JjLZtlPEHeOCUqNv9V3OUJ5UKIP5s53TKSH/6TdPTle4
k8qb5x2NHcX5/la4nsP27UcxxZXrYLbm76dw9nQVp2T4SvHDbfzassrh6ATO
9nM4h3Bygrn0sGBAaVFtuizS9Vaef7xZ7KrsZ7EWLwfJcQ2xXHWhVN63bx9O
nDjBxPI0JJgv1q9fL67GVB5Xg70TV2tFuhQnfvY8/mx8L34q8t/Gi8/sR2Sd
JFBNvn1isar64osvCkINfiXzhnHipz/C9ev24rgUyf6OY++39uJVdndU1bv1
1lu9Jl1ohw4d8vI2qbzXXnsNBw4cmA/LRKNRHD9+nInlaQg7duzAmjVrxNWY
ynv88cf5O3G1VqTDOP6TH+IbX/srvCzzcfy1n+DAXVuxw0ywGrIePws7Ojoq
rha79V79Ibb66x1/GQ98+wEcY3dHVT0ejG57mwMwbFJ5x44dE8G7IH1kqRjy
t48fZv0+gA3ZHfqX+7uIfLXzM4vXedjRw309BPIH8lnYd0SRPTvVTk+sZAVp
20mPfDZn4w5TcJbNk7YX++C/nLcsEfKmptRzWrIRe3L9Q6HLqedMTXltzZOq
7lHmQlwXt11+aSNdGWDCgNYB7QZShoHspCPe5zPvI91JFjAgWnXjCrCzipNs
Ehb/7RMRYDVYlyJXgPeqZaHrCdR7cQX0v6ZuoDotcnHxiwCpyd92ZRLoJwaE
rGWhILn/BaljvFQL4gsYMG+glhc/GMCLaCzIhC4DSxsw7F3wn2hq478nKgGC
STAJJsEkmASTYBJMgkkwCSbBpO/FLJiD6TwAwSSYBJNgEkyCSTAJJsEkmAST
YM4fTFrsztZyBJNgEkyCSTAJ5kDAnCkFC1mTYBJMgkkwCealBZMWu7O1HMEk
mASTYBJMgkkwCSbBnAVM73xxs3X66urBgH65SPlBOXngTzfjSMZNhCMmSg14
58pavzuufUnl9WJtUVoHsba4pC9+I6yfgUj+YkbqJdJvL1fk1OkckpnSdJFw
cLp0Fr+TtpTT9iWerc4XM0hmy+KY+CJpzrmcIJcmHhGUIYaZdcsiGdZgZH4d
8AvoNdXe8g4emQ52GEUk8/3YE9zeMySSCXLBOhd/q0W1nmnR1eTON7kLLrAV
v1fWeeFWh62Ne+dhOT9Oo+mdwDybsfGPb3/CnaNMOqxags/cUzi6/Q7BP6K8
NKIcGXDQ3fPMzLy1XJznrymalirzDD9Ib773r9C19l9xF1QPI241jwgHCGK3
cYlwvvXAo9Md1pMIp7vDhnwt1hCPSA2ZDVIVx2vsaGmK+027wNY6HbdcWP0w
t/oUkDE0aGEDtmXCzpSllGYZBmvymz/6kHvPdV45awsk/E+d7Ebx8ITfea2R
qCmOGc/yTP+I58Ua0qZkpIhYGdFqxw/TA15H8/H5SEe1E/VIPp8n5MDm6tWL
z6e709qac0qI6TYmeXw3Ksjmyl5zPIt57kKaC/baeUyM34GTUzyuG179rKEj
WZFX58+exX/97rOW13jagB0WRBIydhbhpB1bhMzZZofT5sRP4A2RDJmIKiYq
XZRHziW5EosJkw1AlTwMSR2ihshhPzeRfLX4hry2/A/hmfASdXddQHuTGUQN
OcgMKT18D/N2TF3b6vRbCPWTE8wWR8XjJqRMXbJ1mPmWJDUhaPmszoaBaT47
ndy+CFos1+6zYKqFXj47deoUbrzxRuzZs4eJ4ekIS+/Gn7KyN9y5h+fgzj/f
ghv03eL9nuid2LKK2WvV9biblV4u6gzjnu/fijWrtmL3PffIcru/jTUrtooy
IVEmhA0bNmBoaAhbtmxhivB0GFvC1+CKZasxvmULz2F/Y1j91dXYzO6OijIh
rFy5Ut3bom1SeZzcaXh4WFytU3lbwhvx5ZHVCHvyQxjbsAorVn/dLcHSERdD
628GGK688soODGNjY1i1ahUsy2IYeBpi6dO4dd2fwHjaYhhk3uM/2IU/Yvb8
y9gzXh6P32XLlvniN9DRonNmz6Ojc9ZnTD7x1ltvMS+dO3eOPULe/+f9uO6W
/Zh48gFW6ha8/ck51hK/F0Lllz+Gdt0EfsWuZPlhnPskg5uvfZLn8Rycq7yN
W64T16yGrLd//35cf/314mqxW69VTtY79yscvP8g/p3d3aHqvffee4Lzil+t
E+nSVnufVlD5VNX99Oe4QfsufvnpOdnkCJ544gkltgNW1+bOnDmDI0eOTOv4
YrBVjz6nnGZ9Rz7PookWPUkHv4brmcMTi/jDrsMzzlzoNeQQOMSWHXXUG3Ii
xtIVLmCPkQrtNFNK3HL/yChfvemoug+MfgKsCmwzCUkjkhGDebGh5nZtY2Pv
1nqMjdIdNn+mCSqgIgzdQolPzZuudkv97nAbRL3Kymq6zzm5CdZtcp5zvFlk
J0PIjGeRLZAtjqw27qseLujJkdXTBX5KLjbZcdmfovE8rxrsgp6t9XCB5L/K
TUQxkT0t6pWSBrOpnH8mSw2vCeUG3/zTQTmXZD1I9yzpVHOIbmdTmSY61lwX
zmmy3rvjMXR5LFz+yUAQM1f3BWo745eDhtNUq6TpK/glPeT6LTmqUExNtaZ0
SjhfUrljfeeif8gzQdOZalGLXmo7KwSTYBJMgkkwCSbBJJgEk2ASzL6ASd+5
m63lCCbBJJgE81KByc8a8d+u6HOYA2JNgkkwCSbBJJgEk2D2CUxa7M7WcgST
YBJMgkkwCSbBJJgEk2ASzEsQZhALVTabJeL/gYNJi93ZWo5gEkyCSTAJJsEk
mASTYBLMeYI5F0aSBYbu/ix7IS6P/7mnFI10JYi6I9RVUl9qxUkTUoaB7KQ4
mIp85n2kZ89nscBaSbodfvJ8EpZuoizOPgaSPWgDotJS8Y+ltSx0PYH6hfMg
9JE2btj5GYESYQ2pyd/O+NA/U8WDN59qLPEt613cWctCQR4VFwRU8VJtLkfi
+8QbqOURVcOaxmJM6NJ5nnwuWrnHiXtxZimNgzizRufHAMPeRRONhjjU7GOs
uPCD3EGa627pHlRVx35xims+Q6qqeTLGXKYSnpItQimPusYpxqHbRamE4nh6
+s2TXOGZcjz1rcY+biSnjgrnRStXUEjFEDaSqNR5SElupFMyuEPKKL24kfpW
26UenZBTTgg5lm0hFuW8VRHEsxW37/jHrpkwGC2QxuvWrcPDDz/MxPI0hK1b
twriHX41pvJWr17N34mrtSJl93+wC+tXb8PfsvzvbduK7+5j9/dsw9Xf3M1q
yHo7duzwZC126+3bhdErt+EhKY/9PYRtY9vwALs7qupdccUVXnsurjVr1nh5
m1Tegw8+iL179y5MIHC2Fj9zHJttGQmUiwnovplVYBQ47VHgdfL+jfs2chpI
phjOqKPHi0rWcr+6qlBPupi+1ZaX9ohZvMdhJRVF2C74nBmkcU92lj7UeIdX
upN5xR++QcwrfagObTwQTIJJMAkmwfziwKRvgMzWcgSTYBJMgkkwCSbBJJgE
84sJM4gTRZXpJ5gDYk2CSTDnDSYtdmdrOYJJMAkmwSSYBJNgEkyCSTAJJsEk
mH0Lkxa7s7UcwewjmEHEIn0Ic0CsSTAJJsEkmASTYBLMhYc5wGf7vcPVThF6
JA5x2nNgz/TLZcoI+Mm6aqWMEj+OWEghohnIV34jDie3nevXBk21Zhk6ux21
LFixqChqxN/EgcE94O8ewua/gG0LHUoiFp1L4qA/HxSypolcJQ9DHAur9/VB
f49BolmBFdGgRRIMceDv3g9KgLmDnFNJQXPPIl7c0/0L8rS5OMfz6XlOMAkm
wSSYBJNgMpivv/46PvroIyaWpyHce++92LBhA1555RUGk6chPPfcc9i1a5e4
GlN5O3fu5O/E1d0q76WXXhIkFX55H374oSDVmANMzo3D99RPnDjBxPI0hDfe
eAOPPfYYnn32WQaTpyE888wzMNnkk1+NqTx1Pa3cyy+/zKUISZuUPO6tDz74
YDYwRfqd2anmz9u8QHljAXndZ4dfVHUuC8gbnmG5ueRd7DYGETO1MTd5FP4D
jZnamN/w52+0O3midoW0Rf8PS7xldw==\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist4,LabelSurfaces->True,Axes->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.5055626497805433`*^9, 3.505567117214204*^9, {3.505731411540978*^9, 
   3.505731415778537*^9}}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -65., 0.}, {0, -43.333333333333336`, 0.}, {
     0, -21.66666666666667, 0.}, {0, 0., 0.}, {0, 21.666666666666657`, 0.}, {
     0, 43.333333333333314`, 0.}, {0, 65., 0.}, {0, 65., 0.}, {
     0, 43.333333333333336`, 0.}, {0, 21.66666666666667, 0.}, {0, 0., 0.}, {
     0, -21.666666666666657`, 0.}, {0, -43.333333333333314`, 0.}, {
     0, -65., 0.}, {0, -65., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -65.}, {0, 0., -43.333333333333336`}, {
      0, 0., -21.66666666666667}, {0, 0., 0.}, {0, 0., 21.666666666666657`}, {
      0, 0., 43.333333333333314`}, {0, 0., 65.}, {0, 0., 65.}, {
      0, 0., 43.333333333333336`}, {0, 0., 21.66666666666667}, {0, 0., 0.}, {
      0, 0., -21.666666666666657`}, {0, 0., -43.333333333333314`}, {
      0, 0., -65.}, {0, 0., -65.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -65, -65}, {0, 65, -65}, {0, 65, 65}, {0, -65, 65}, {
     0, -65, -65}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO4AYVgegAmtXgUErwKxi2t5YIhD+RjiB0Dq
V/2yRxdfARY3PYDVnAY3osXX4DBnAQ57cblzFQ5/rcIRDmCAJdxwiQMAv58+
VA==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB8BUQ+ABdPGwUBBwxyFujiHOgAIQ4iEQ
9Q7Yxd0xxKHuIVo8DIc5YTjsJeBODH+F4AgHqHtwigMAVD00KQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{95., -25., -70.}, {-45., -25., -70.}, {-45., -25., 70.}, {
      95., -25., 70.}, {95., -25., -70.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7w9z8IaDg8+93COmGZ6YHVq4DgVSB2cS0P
DHGIQZYY4gdA6lf9skcXXwEWNz2A1ZwGN6LF1+AwZwEOe3G5cxUOf63CEQ64
wg2XOADMSNQY
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdHjnKWB+2j3IQYfj25f7m7QcYOIvtot+4Sv1
crgwjfVvyJtf9jDxL7e5qtqjHBwqF23Zeuq78gGY+N//IKDh8Ox3C+uEZaZw
8UX3wy5YX5E74H5ZPGLuCge4+IV87Reyr6wPzNHIXfup1g0ufneyQt40fo8D
H2sPMXkE+xAUv4LDnFVQez3Q7MXlzs9Qf1Wj+esZNBw2oIUDrnBDFwcAqFuI
Wg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{95., 73.12177826491072, 13.349364905389017`}, {-45., 
       73.12177826491072, 
       13.349364905389017`}, {-45., -48.12177826491072, \
-56.650635094610955`}, {95., -48.12177826491072, -56.650635094610955`}, {95., 
       73.12177826491072, 13.349364905389017`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EO7ABmZoOjz+3cI6YZmpw+pVQPAqELu4lgeG
OMQgSwzxAyD1q37Zo4uvAIubHsBqToMb0eJrcJizAIe9uNy5Coe/VuEIB1zh
hkscAIdZc0w=
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdLg2WSFvGr/HgW+1h5g8gn0cYOIn87VfyL6y
PrBAI3ftp1o3uHjP/bAL1lfkDnhcFo+Yu8IBLs4GpjUdHv9uYZ2wzBQu/uU2
V1V7lINDzqItW099V4aLP9su+oWv1MuhYDrr35A3v/bDxN96Cpifdg9y8OL4
9uX+Jq0DhMRfQM2ZgGYOzN4sNHtxubMFh7+OQsNhHlo44Ao3dHEA/pB4iQ==

        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{95., -48.121778264910674`, 
        56.65063509461099}, {-45., -48.121778264910674`, 
        56.65063509461099}, {-45., 73.1217782649107, -13.34936490538907}, {
        95., 73.1217782649107, -13.34936490538907}, {
        95., -48.121778264910674`, 56.65063509461099}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwcwBTDgEHGFCAn8PqVSDgiiG+BixuiiHOgBX4
OayAqHfALu6KIQ51D9Hiq3GYswaHvQTceQCHOzHEoe4hKA4AP/A1Zg==
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BABg4BB9DFV68CAVcM8TVgcVMMcVSAEF8B
Ue+AXdwVQxzqHqLFV+MwZw0Oewm48wAOd2KIQ92DUxwA5SI1Zg==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., -65., -65.}, {60., 65., -65.}, {60., 65., 65.}, {
         60., -65., 65.}, {60., -65., -65.}}], 
        {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], Text3DBox[
          FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
          FormBox["\<\"{2, 1}\"\>", TraditionalForm], {25., -25., 0}], 
         Text3DBox[
          FormBox["\<\"{3, 1}\"\>", TraditionalForm], {25., 
          12.499999999999995`, -21.65063509461097}], Text3DBox[
          FormBox["\<\"{4, 1}\"\>", TraditionalForm], {25., 12.50000000000001,
           21.65063509461096}], Text3DBox[
          FormBox["\<\"{5, 1}\"\>", TraditionalForm], {60., 0, 0}]}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{340.2635845654864, 334.77378790218773`},
  PlotRange:>All,
  ViewPoint->{-0.07412274664793174, 0.1868992279643387, 3.3778061662883685`},
  ViewVertical->{-0.022525925654735025`, 0.8307754002677779, 
   0.5724504617826162}]], "Print",
 CellChangeTimes->{{3.505367172878573*^9, 3.505367185549945*^9}, 
   3.505367294486753*^9, {3.50536952664528*^9, 3.50536953651007*^9}, {
   3.505369585285687*^9, 3.505369606882863*^9}, 3.505369686820415*^9, 
   3.5053700228981543`*^9, 3.50537248631435*^9, 3.505562533551231*^9, {
   3.505562568873209*^9, 3.5055625789988747`*^9}, 3.505562675524939*^9, 
   3.505567117832035*^9, {3.505601368669711*^9, 3.5056013898984947`*^9}, 
   3.505601441905809*^9, {3.505601851910084*^9, 3.505601879892481*^9}, {
   3.505677879032402*^9, 3.5056778851773357`*^9}, 3.505731416284747*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["5", "Subsection",
 CellChangeTimes->{3.505372334202929*^9, 3.505562591596203*^9, 
  3.505567048097353*^9, 3.5056014130720043`*^9}],

Cell[CellGroupData[{

Cell["\<\
clist5  = {Screen[{80,80}],
Table[Move[Move[Screen[{100,60}],{30,-25},90],0,0,angle],{angle,0,360-60,60.}],
Move[Screen[{80,80}],60]}\
\>", "Input",
 CellChangeTimes->{{3.505367019143448*^9, 3.505367138444253*^9}, {
   3.5053671807046537`*^9, 3.505367182188649*^9}, {3.5053672846161823`*^9, 
   3.5053672910041323`*^9}, {3.5053694986436234`*^9, 
   3.5053695332722607`*^9}, {3.505369565125681*^9, 3.505369582393523*^9}, 
   3.5053696841970243`*^9, {3.5053699935893097`*^9, 3.505370014809224*^9}, {
   3.505562474999895*^9, 3.505562501935886*^9}, {3.505562541858404*^9, 
   3.505562605716846*^9}, 3.505562647797185*^9, {3.505567051109438*^9, 
   3.505567108937701*^9}, {3.5056013609171133`*^9, 3.505601382168524*^9}, 
   3.505601420445469*^9, {3.5057146324842863`*^9, 3.505714638174058*^9}, {
   3.506962719992187*^9, 3.5069627291732283`*^9}, {3.5069630555954*^9, 
   3.506963080636714*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{"80", ",", "80"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", 
            RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", 
            RowBox[{"-", "12.500000000000004`"}], ",", 
            RowBox[{"-", "21.650635094610966`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0.5000000000000001`", ",", "0.8660254037844386`"}], 
           "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", "12.499999999999995`", ",", 
            RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.4999999999999998`"}], ",", 
            "0.8660254037844388`"}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", "25.`"}], "}"}], ",", 
          RowBox[{"-", "90.`"}], ",", "180"}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "30.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "0.5000000000000004`"}], ",", 
            RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm], ",", 
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", 
           RowBox[{"{", 
            RowBox[{"100", ",", "60"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"30.`", ",", 
            RowBox[{"-", "12.5`"}], ",", "21.650635094610966`"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"0", ",", "0.5`", ",", 
            RowBox[{"-", "0.8660254037844386`"}]}], "}"}]}], "]"}],
        HoldForm],
       FontColor->RGBColor[0., 0.392193, 0.]],
      DisplayForm]}], "}"}], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"80", ",", "80"}], "}"}], "]"}], ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505369583256447*^9, 3.505369685048155*^9, 3.505370015404882*^9, 
   3.505547884448133*^9, 3.505548886305489*^9, {3.505562491285421*^9, 
   3.505562503777738*^9}, {3.505562566644552*^9, 3.505562577285129*^9}, 
   3.5055626752517138`*^9, 3.505567111348629*^9, {3.5056013661081543`*^9, 
   3.505601388519432*^9}, 3.50571463941293*^9, 3.506915441597348*^9, {
   3.506962723586059*^9, 3.506962730279545*^9}, {3.5069630572418947`*^9, 
   3.506963081331666*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[clist5,LabelSurfaces->True];", "Input",
 CellChangeTimes->{{3.5053671554511747`*^9, 3.5053671720046377`*^9}, 
   3.505369603610338*^9, 3.505370022357233*^9, 3.505372485391864*^9, 
   3.5055626497805433`*^9, 3.505567117214204*^9, 3.5056014231807613`*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -40., 0.}, {0, -26.666666666666668`, 0.}, {
     0, -13.333333333333336`, 0.}, {0, 0., 0.}, {
     0, 13.333333333333329`, 0.}, {0, 26.666666666666657`, 0.}, {
     0, 40., 0.}, {0, 40., 0.}, {0, 26.666666666666668`, 0.}, {
     0, 13.333333333333336`, 0.}, {0, 0., 0.}, {
     0, -13.333333333333329`, 0.}, {0, -26.666666666666657`, 0.}, {
     0, -40., 0.}, {0, -40., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -40.}, {0, 0., -26.666666666666668`}, {
      0, 0., -13.333333333333336`}, {0, 0., 0.}, {
      0, 0., 13.333333333333329`}, {0, 0., 26.666666666666657`}, {
      0, 0., 40.}, {0, 0., 40.}, {0, 0., 26.666666666666668`}, {
      0, 0., 13.333333333333336`}, {0, 0., 0.}, {
      0, 0., -13.333333333333329`}, {0, 0., -26.666666666666657`}, {
      0, 0., -40.}, {0, 0., -40.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -40, -40}, {0, 40, -40}, {0, 40, 40}, {0, -40, 40}, {
     0, -40, -40}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQlgdgIqtXgYA/hnhYKAi4Y4gzgUk7DPEN
YHO0MMQbwOJcB9DF//wHAWMMcQgwwRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcShpmGIAwD4fkc1
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgeg/APYxU1wiKvgEMdlvooDDvNxiNuR
KI7LHFz24nTnAeziuMIBV7jZHQAA6qMhDQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{80., -25., -30.}, {-20., -25., -30.}, {-20., -25., 30.}, {
      80., -25., 30.}, {80., -25., -30.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWAC05oHnv5uYZ2wzPTA6lUg4I8hHhYKAu4Y
4hC+HYb4BrA5WhjiDWBxrgPo4n/+g4AxhjjEnSYY4htwmLMCh73/wObbYoiH
4PDXChzhADbmfzCGOK7wBADNTosP
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc9jTv7RY7ZuWw+faQ0wewU4HYOJL9t9xMfYQ
dnj2u4V1wjJ7uHiCg/LuM9v5DjwFi1vBxZnAtCZU3BQu/m367Aw2TVOouAFc
/LW++UWeS7YHTn7n5FbwVYeLf0h+OafT1vnAhPfCYg6zpAiK4zIHl7243InL
X7jCAVe4oYsDAC/KesY=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{80., 13.480762113533153`, -36.65063509461097}, {-20., 
       13.480762113533153`, -36.65063509461097}, {-20., -38.48076211353316, \
-6.650635094610962}, {80., -38.48076211353316, -6.650635094610962}, {80., 
       13.480762113533153`, -36.65063509461097}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcfj7HwQ0HJ79bmGdsMz0wOpVIOCPIR4WCgLu
GOJMYHPsMMQ3gM3RwhBvAItzHUAX/wPmG2OIQ9xpgiG+AYc5K3DY+w/Mt8UQ
D8HhrxU4wgHM/R+MIY4rPAEFNtz5
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/iQ/HJOp62zw4L3wmIOs6QOwMRf6Ztf5Llk
63DuOye3gq86XPzL9NkZbJqmDs9+t7BOWGYAF//7HwQ0oOKmcHEXB+XdZ7bz
QcWt4OLb9t9xMfYQPvAULG4PFz/av7RY7ZvWgU+1h5g8gp0IiuMyB5e9uNyJ
y1+4wgFXuKGLAwAWDoOn
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{80., 38.48076211353316, -6.650635094610976}, {-20., 
        38.48076211353316, -6.650635094610976}, {-20., -13.480762113533169`, \
-36.65063509461096}, {80., -13.480762113533169`, -36.65063509461096}, {80., 
        38.48076211353316, -6.650635094610976}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQllCaoWH1KhDwxxAPCwUBdwxxJjBlhyG+
AWyOFoZ4A1ic6wC6+J//IGCMIQ6hTDDEN+AwZwUOe/+BzbfFEA/B4a8VOMIB
bMz/YAxxCIUZngC8fkc1
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlg6ofHRxExziKjjEGRpwqD+Aw3wc4nYk
iuMyB5e9ON3pgF0cVzjgCjc7BwBvZxoN
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., 25., 30.}, {-20., 25., 30.}, {-20., 25., -30.}, {80.,
          25., -30.}, {80., 25., 30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWAD05oOj3+3sE5YZuqwehUI+GOIh4WCgDuG
OBOYb4chvgFsjhaGeANYnOsAuvif/yBgjCEOcacJhvgGHOaswGHvP7D5thji
ITj8tQJHOICN+R+MIY4rPAHAOHwt
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc9jWv7RY7ZvWgS+1h5g8gp0cYOIz9t9xMfYQ
PvDsdwvrhGX2cPESB+XdZ7bzOTwBi1vBxdnAtKbDY7C4KVz8x/TZGWyapg6P
wOIGcPE3+uYXeS7ZOhz8zsmt4KsOF/+Q/HJOp62zQ817YTGHWVIExXGZg8te
XO7E5S9c4YAr3NDFAeZKcJE=
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., -13.480762113533142`, 
          36.650635094610976`}, {-20., -13.480762113533142`, 
          36.650635094610976`}, {-20., 38.48076211353316, 
          6.650635094610944}, {80., 38.48076211353316, 6.650635094610944}, {
          80., -13.480762113533142`, 36.650635094610976`}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQmgee/m5hnbDM1GH1KhDwxxAPCwUBdwxx
JjDfDkN8A9gcLQzxBrA41wF08T//QcAYQxzCN8EQ34DDnBU47P0HNt8WQzwE
h79W4AgHsDH/gzHEcYUnAMPzg3E=
          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/iQ/HJOp63zgSnvhcUcZkk5wMRf6Ztf5Llk
e+DUd05uBV91uPjX6bMz2DRNDzz93cI6YZkBXBxCa0LFTeHiEQ7Ku89s54OK
W8HFV+y/42LsIewAEbeHi+/rX1qs9k3L4VPtISaPYCeC4rjMwWUvLnfi8heu
cMAVbujiADywc4c=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{80., -38.48076211353316, 
           6.650635094610966}, {-20., -38.48076211353316, 
           6.650635094610966}, {-20., 13.480762113533157`, 
           36.65063509461096}, {80., 13.480762113533157`, 
           36.65063509461096}, {80., -38.48076211353316, 
           6.650635094610966}}]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQLgcYUICfw+pVIGCFIb4GLK6FIc6AFfg5
rICod8AuboUhDnUP0eKrcZizBoe9BNx5AIc7McSh7iEoDgAYuTOS
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BAAS4H0MVXrwIBKwzxNWBxLQxxVIAQXwFR
74Bd3ApDHOoeosVX4zBnDQ57CbjzAA53YohD3YNTHADMizOS
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., -40., -40.}, {60., 40., -40.}, {60., 40., 40.}, {
            60., -40., 40.}, {60., -40., -40.}}], 
           {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
            Text3DBox[
             FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
             FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
            Text3DBox[
             FormBox["\<\"{3, 1}\"\>", TraditionalForm], {
             30., -12.500000000000004`, -21.650635094610966`}], Text3DBox[
             FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 
             12.499999999999995`, -21.65063509461097}], Text3DBox[
             FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 25., 0}], 
            Text3DBox[
             FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., 
             12.50000000000001, 21.65063509461096}], Text3DBox[
             FormBox["\<\"{7, 1}\"\>", TraditionalForm], {30., -12.5, 
             21.650635094610966`}], Text3DBox[
             FormBox["\<\"{8, 1}\"\>", TraditionalForm], {
             60., 0, 0}]}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{385.3303498579734, 386.75557182898945`},
  PlotRange:>All,
  ViewPoint->{3.3749757270764307`, 0.07030244926478495, -0.2336587410569045},
  ViewVertical->{0.6779849889764353, 0.9018301456413743, 
   0.17600551885255167`}]], "Print",
 CellChangeTimes->{{3.505367172878573*^9, 3.505367185549945*^9}, 
   3.505367294486753*^9, {3.50536952664528*^9, 3.50536953651007*^9}, {
   3.505369585285687*^9, 3.505369606882863*^9}, 3.505369686820415*^9, 
   3.5053700228981543`*^9, 3.50537248631435*^9, 3.505562533551231*^9, {
   3.505562568873209*^9, 3.5055625789988747`*^9}, 3.505562675524939*^9, 
   3.505567117832035*^9, {3.505601368669711*^9, 3.5056013898984947`*^9}, 
   3.505714641122675*^9, 3.506915445430346*^9, 3.5069627322978153`*^9, {
   3.506963058945709*^9, 3.506963083159243*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["final5 = MeldSurfaces[clist5]", "Input",
 CellChangeTimes->{
  3.505370279332316*^9, 3.5055626567573347`*^9, 3.505567132597028*^9, {
   3.505574893006414*^9, 3.505574893459938*^9}, 3.5055913566094847`*^9, 
   3.50560142518108*^9, {3.505714652897509*^9, 3.50571465758223*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, -40., 0.}, {0, -26.666666666666668`, 0.}, {
     0, -13.333333333333336`, 0.}, {0, 0., 0.}, {
     0, 13.333333333333329`, 0.}, {0, 26.666666666666657`, 0.}, {
     0, 40., 0.}, {0, 40., 0.}, {0, 26.666666666666668`, 0.}, {
     0, 13.333333333333336`, 0.}, {0, 0., 0.}, {
     0, -13.333333333333329`, 0.}, {0, -26.666666666666657`, 0.}, {
     0, -40., 0.}, {0, -40., 0.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -40.}, {0, 0., -26.666666666666668`}, {
      0, 0., -13.333333333333336`}, {0, 0., 0.}, {
      0, 0., 13.333333333333329`}, {0, 0., 26.666666666666657`}, {
      0, 0., 40.}, {0, 0., 40.}, {0, 0., 26.666666666666668`}, {
      0, 0., 13.333333333333336`}, {0, 0., 0.}, {
      0, 0., -13.333333333333329`}, {0, 0., -26.666666666666657`}, {
      0, 0., -40.}, {0, 0., -40.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -40, -40}, {0, 40, -40}, {0, 40, 40}, {0, -40, 40}, {
     0, -40, -40}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQlgdgIqtXgYA/hnhYKAi4Y4gzgUk7DPEN
YHO0MMQbwOJcB9DF//wHAWMMcQgwwRDfgMOcFTjs/Qc23xZDPASHv1bgCAew
Mf+DMcShpmGIAwD4fkc1
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgeg/APYxU1wiKvgEMdlvooDDvNxiNuR
KI7LHFz24nTnAeziuMIBV7jZHQAA6qMhDQ==
      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{80., -25., -30.}, {-20., -25., -30.}, {-20., -25., 30.}, {
      80., -25., 30.}, {80., -25., -30.}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWAC05oHnv5uYZ2wzPTA6lUg4I8hHhYKAu4Y
4hC+HYb4BrA5WhjiDWBxrgPo4n/+g4AxhjjEnSYY4htwmLMCh73/wObbYoiH
4PDXChzhADbmfzCGOK7wBADNTosP
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc9jTv7RY7ZuWw+faQ0wewU4HYOJL9t9xMfYQ
dnj2u4V1wjJ7uHiCg/LuM9v5DjwFi1vBxZnAtCZU3BQu/m367Aw2TVOouAFc
/LW++UWeS7YHTn7n5FbwVYeLf0h+OafT1vnAhPfCYg6zpAiK4zIHl7243InL
X7jCAVe4oYsDAC/KesY=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{80., 13.480762113533153`, -36.65063509461097}, {-20., 
       13.480762113533153`, -36.65063509461097}, {-20., -38.48076211353316, \
-6.650635094610962}, {80., -38.48076211353316, -6.650635094610962}, {80., 
       13.480762113533153`, -36.65063509461097}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcfj7HwQ0HJ79bmGdsMz0wOpVIOCPIR4WCgLu
GOJMYHPsMMQ3gM3RwhBvAItzHUAX/wPmG2OIQ9xpgiG+AYc5K3DY+w/Mt8UQ
D8HhrxU4wgHM/R+MIY4rPAEFNtz5
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/iQ/HJOp62zw4L3wmIOs6QOwMRf6Ztf5Llk
63DuOye3gq86XPzL9NkZbJqmDs9+t7BOWGYAF//7HwQ0oOKmcHEXB+XdZ7bz
QcWt4OLb9t9xMfYQPvAULG4PFz/av7RY7ZvWgU+1h5g8gp0IiuMyB5e9uNyJ
y1+4wgFXuKGLAwAWDoOn
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{80., 38.48076211353316, -6.650635094610976}, {-20., 
        38.48076211353316, -6.650635094610976}, {-20., -13.480762113533169`, \
-36.65063509461096}, {80., -13.480762113533169`, -36.65063509461096}, {80., 
        38.48076211353316, -6.650635094610976}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQllCaoWH1KhDwxxAPCwUBdwxxJjBlhyG+
AWyOFoZ4A1ic6wC6+J//IGCMIQ6hTDDEN+AwZwUOe/+BzbfFEA/B4a8VOMIB
bMz/YAxxCIUZngC8fkc1
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlg6ofHRxExziKjjEGRpwqD+Aw3wc4nYk
iuMyB5e9ON3pgF0cVzjgCjc7BwBvZxoN
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{80., 25., 30.}, {-20., 25., 30.}, {-20., 25., -30.}, {80.,
          25., -30.}, {80., 25., 30.}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcWAD05oOj3+3sE5YZuqwehUI+GOIh4WCgDuG
OBOYb4chvgFsjhaGeANYnOsAuvif/yBgjCEOcacJhvgGHOaswGHvP7D5thji
ITj8tQJHOICN+R+MIY4rPAHAOHwt
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc9jWv7RY7ZvWgS+1h5g8gp0cYOIz9t9xMfYQ
PvDsdwvrhGX2cPESB+XdZ7bzOTwBi1vBxdnAtKbDY7C4KVz8x/TZGWyapg6P
wOIGcPE3+uYXeS7ZOhz8zsmt4KsOF/+Q/HJOp62zQ817YTGHWVIExXGZg8te
XO7E5S9c4YAr3NDFAeZKcJE=
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{80., -13.480762113533142`, 
          36.650635094610976`}, {-20., -13.480762113533142`, 
          36.650635094610976`}, {-20., 38.48076211353316, 
          6.650635094610944}, {80., 38.48076211353316, 6.650635094610944}, {
          80., -13.480762113533142`, 36.650635094610976`}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgIcYDQmgee/m5hnbDM1GH1KhDwxxAPCwUBdwxx
JjDfDkN8A9gcLQzxBrA41wF08T//QcAYQxzCN8EQ34DDnBU47P0HNt8WQzwE
h79W4AgHsDH/gzHEcYUnAMPzg3E=
          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc/iQ/HJOp63zgSnvhcUcZkk5wMRf6Ztf5Llk
e+DUd05uBV91uPjX6bMz2DRNDzz93cI6YZkBXBxCa0LFTeHiEQ7Ku89s54OK
W8HFV+y/42LsIewAEbeHi+/rX1qs9k3L4VPtISaPYCeC4rjMwWUvLnfi8heu
cMAVbujiADywc4c=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{80., -38.48076211353316, 
           6.650635094610966}, {-20., -38.48076211353316, 
           6.650635094610966}, {-20., 13.480762113533157`, 
           36.65063509461096}, {80., 13.480762113533157`, 
           36.65063509461096}, {80., -38.48076211353316, 
           6.650635094610966}}]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQLgcYUICfw+pVIGCFIb4GLK6FIc6AFfg5
rICod8AuboUhDnUP0eKrcZizBoe9BNx5AIc7McSh7iEoDgAYuTOS
           "]], 
          {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2BAAS4H0MVXrwIBKwzxNWBxLQxxVIAQXwFR
74Bd3ApDHOoeosVX4zBnDQ57CbjzAA53YohD3YNTHADMizOS
            "]]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., -40., -40.}, {60., 40., -40.}, {60., 40., 40.}, {
            60., -40., 40.}, {60., -40., -40.}}], 
           {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
            Text3DBox[
             FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
             FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
            Text3DBox[
             FormBox["\<\"{3, 1}\"\>", TraditionalForm], {
             30., -12.500000000000004`, -21.650635094610966`}], Text3DBox[
             FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 
             12.499999999999995`, -21.65063509461097}], Text3DBox[
             FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 25., 0}], 
            Text3DBox[
             FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., 
             12.50000000000001, 21.65063509461096}], Text3DBox[
             FormBox["\<\"{7, 1}\"\>", TraditionalForm], {30., -12.5, 
             21.650635094610966`}], Text3DBox[
             FormBox["\<\"{8, 1}\"\>", TraditionalForm], {
             60., 0, 0}]}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{394.04132482389485`, 384.5113898910221},
  PlotRange:>All,
  ViewPoint->{3.3666606644695762`, 0.3215832335344993, -0.11036391721379656`},
  
  ViewVertical->{0.6405119323736034, 0.4464327920287412, 
   0.7661747174669633}]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963101956264*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102488381*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -14.433756729740642`}, {-25., 
    14.433756729740642`}, {0, 28.86751345948129}, {25., 
    14.433756729740631`}, {25., -14.433756729740649`}, {
    0, -28.867513459481287`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102518435*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-40., -40.}, {-40., 40.}, {40., 40.}, {
    40., -40.}, {-40., -40.}}], {
    ArrowBox[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}}], 
    ArrowBox[{{-25., 14.433756729740642`}, {0, 28.86751345948129}}], 
    ArrowBox[{{0, 28.86751345948129}, {25., 14.433756729740631`}}], 
    ArrowBox[{{25., 14.433756729740631`}, {25., -14.433756729740649`}}], 
    ArrowBox[{{25., -14.433756729740649`}, {0, -28.867513459481287`}}], 
    ArrowBox[{{0, -28.867513459481287`}, {-25., -14.433756729740642`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102570065*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "14.433756729740642"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "28.86751345948129"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "14.433756729740631"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "14.433756729740649"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "28.867513459481287"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
      0, 28.86751345948129}, {25., 14.433756729740631`}, {
      25., -14.433756729740649`}, {0, -28.867513459481287`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631026138268`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-40., -40.}, {-40., 40.}, {40., 40.}, {
    40., -40.}, {-40., -40.}}], 
   LineBox[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631026614237`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "14.433756729740642"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "28.86751345948129"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "14.433756729740631"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "14.433756729740649"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "28.867513459481287"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
      0, 28.86751345948129}, {25., 14.433756729740631`}, {
      25., -14.433756729740649`}, {0, -28.867513459481287`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102700789*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {2, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102745597*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740644`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740644`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -14.433756729740644`}, {30., 
   14.433756729740644`}, {-30., 
   14.433756729740644`}, {-30., -14.433756729740644`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102778489*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., -14.433756729740644`}, {30., 14.433756729740644`}}], 
    ArrowBox[{{30., 14.433756729740644`}, {-30., 14.433756729740644`}}], 
    ArrowBox[{{-30., 14.433756729740644`}, {-30., -14.433756729740644`}}], 
    ArrowBox[{{-30., -14.433756729740644`}, {30., -14.433756729740644`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102817*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740644"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740644"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740644"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740644"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -14.433756729740644`}, {30., 14.433756729740644`}, {-30.,
      14.433756729740644`}, {-30., -14.433756729740644`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -14.433756729740644`}, {30., 14.433756729740644`}, {-30., 
    14.433756729740644`}, {-30., -14.433756729740644`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631028623533`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., -14.433756729740644`}, {30., 14.433756729740644`}, {-30., 
    14.433756729740644`}, {-30., -14.433756729740644`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.50696310290432*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740644"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740644"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740644"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740644"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -14.433756729740644`}, {30., 14.433756729740644`}, {-30.,
      14.433756729740644`}, {-30., -14.433756729740644`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -14.433756729740644`}, {30., 14.433756729740644`}, {-30., 
    14.433756729740644`}, {-30., -14.433756729740644`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631029467697`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {3, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963102991235*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740642`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740642`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 14.433756729740642`}, {
   30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
   14.433756729740642`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631030281353`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., 14.433756729740642`}, {30., -14.433756729740642`}}], 
    ArrowBox[{{30., -14.433756729740642`}, {-30., -14.433756729740642`}}], 
    ArrowBox[{{-30., -14.433756729740642`}, {-30., 14.433756729740642`}}], 
    ArrowBox[{{-30., 14.433756729740642`}, {30., 14.433756729740642`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631030718937`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740642"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740642"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740642`}, {
     30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
     14.433756729740642`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., 14.433756729740642`}, {
    30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
    14.433756729740642`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103123108*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., 14.433756729740642`}, {
    30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
    14.433756729740642`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103170545*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740642"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740642"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740642`}, {
     30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
     14.433756729740642`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., 14.433756729740642`}, {
    30., -14.433756729740642`}, {-30., -14.433756729740642`}, {-30., 
    14.433756729740642`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103218059*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {4, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103269383*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740645`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 14.433756729740645`}, {
   30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
   14.433756729740645`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103317671*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., 14.433756729740645`}, {30., -14.433756729740647`}}], 
    ArrowBox[{{30., -14.433756729740647`}, {-30., -14.433756729740647`}}], 
    ArrowBox[{{-30., -14.433756729740647`}, {-30., 14.433756729740645`}}], 
    ArrowBox[{{-30., 14.433756729740645`}, {30., 14.433756729740645`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103368692*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740645"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740647"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740647"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740645"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740645`}, {
     30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
     14.433756729740645`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., 14.433756729740645`}, {
    30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
    14.433756729740645`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103418632*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., 14.433756729740645`}, {
    30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
    14.433756729740645`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103496067*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740645"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740647"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740647"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740645"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740645`}, {
     30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
     14.433756729740645`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., 14.433756729740645`}, {
    30., -14.433756729740647`}, {-30., -14.433756729740647`}, {-30., 
    14.433756729740645`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631035345173`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {5, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.50696310357948*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740647`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 14.433756729740647`}, {
   30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
   14.433756729740647`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103618431*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., 14.433756729740647`}, {30., -14.433756729740633`}}], 
    ArrowBox[{{30., -14.433756729740633`}, {-30., -14.433756729740633`}}], 
    ArrowBox[{{-30., -14.433756729740633`}, {-30., 14.433756729740647`}}], 
    ArrowBox[{{-30., 14.433756729740647`}, {30., 14.433756729740647`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631036768713`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740647"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740633"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740633"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740647"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740647`}, {
     30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
     14.433756729740647`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., 14.433756729740647`}, {
    30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
    14.433756729740647`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631037655*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., 14.433756729740647`}, {
    30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
    14.433756729740647`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103824148*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740647"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740633"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740633"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740647"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740647`}, {
     30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
     14.433756729740647`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., 14.433756729740647`}, {
    30., -14.433756729740633`}, {-30., -14.433756729740633`}, {-30., 
    14.433756729740647`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103871299*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {6, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103917942*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740637`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., 14.433756729740637`}, {
   30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
   14.433756729740637`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963103975754*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., 14.433756729740637`}, {30., -14.433756729740653`}}], 
    ArrowBox[{{30., -14.433756729740653`}, {-30., -14.433756729740653`}}], 
    ArrowBox[{{-30., -14.433756729740653`}, {-30., 14.433756729740637`}}], 
    ArrowBox[{{-30., 14.433756729740637`}, {30., 14.433756729740637`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104018812*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740637"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740653"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740653"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740637"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740637`}, {
     30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
     14.433756729740637`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., 14.433756729740637`}, {
    30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
    14.433756729740637`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104068265*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., 14.433756729740637`}, {
    30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
    14.433756729740637`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104126863*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740637"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740653"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740653"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740637"}], "}"}]}], 
      "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., 14.433756729740637`}, {
     30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
     14.433756729740637`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., 14.433756729740637`}, {
    30., -14.433756729740653`}, {-30., -14.433756729740653`}, {-30., 
    14.433756729740637`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631041737013`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"7", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {7, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104222341*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30.`", ",", 
       RowBox[{"-", "14.433756729740645`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.`", ",", "14.433756729740653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", "14.433756729740653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.`"}], ",", 
       RowBox[{"-", "14.433756729740645`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{30., -14.433756729740645`}, {30., 
   14.433756729740653`}, {-30., 
   14.433756729740653`}, {-30., -14.433756729740645`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631042707357`*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], {
    ArrowBox[{{30., -14.433756729740645`}, {30., 14.433756729740653`}}], 
    ArrowBox[{{30., 14.433756729740653`}, {-30., 14.433756729740653`}}], 
    ArrowBox[{{-30., 14.433756729740653`}, {-30., -14.433756729740645`}}], 
    ArrowBox[{{-30., -14.433756729740645`}, {30., -14.433756729740645`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.5069631043242598`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740645"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740653"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740653"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740645"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -14.433756729740645`}, {30., 14.433756729740653`}, {-30.,
      14.433756729740653`}, {-30., -14.433756729740645`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{30., -14.433756729740645`}, {30., 14.433756729740653`}, {-30., 
    14.433756729740653`}, {-30., -14.433756729740645`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104373088*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-50., -30.}, {-50., 30.}, {50., 30.}, {
    50., -30.}, {-50., -30.}}], 
   LineBox[{{30., -14.433756729740645`}, {30., 14.433756729740653`}, {-30., 
    14.433756729740653`}, {-30., -14.433756729740645`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104424809*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", 
         RowBox[{"-", "14.433756729740645"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"30.", ",", " ", "14.433756729740653"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", "14.433756729740653"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30."}], ",", " ", 
         RowBox[{"-", "14.433756729740645"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{30., -14.433756729740645`}, {30., 14.433756729740653`}, {-30.,
      14.433756729740653`}, {-30., -14.433756729740645`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{30., -14.433756729740645`}, {30., 14.433756729740653`}, {-30., 
    14.433756729740653`}, {-30., -14.433756729740645`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104496677*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New surface surfaceid \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"8", ",", "1"}], "}"}]}],
  SequenceForm["New surface surfaceid ", {8, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104530911*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cornerpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", 
       RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25.`", ",", 
       RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "cornerpoints ", {{-25., -14.433756729740642`}, {-25., 
    14.433756729740642`}, {0, 28.86751345948129}, {25., 
    14.433756729740631`}, {25., -14.433756729740649`}, {
    0, -28.867513459481287`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104569072*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-40., -40.}, {-40., 40.}, {40., 40.}, {
    40., -40.}, {-40., -40.}}], {
    ArrowBox[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}}], 
    ArrowBox[{{-25., 14.433756729740642`}, {0, 28.86751345948129}}], 
    ArrowBox[{{0, 28.86751345948129}, {25., 14.433756729740631`}}], 
    ArrowBox[{{25., 14.433756729740631`}, {25., -14.433756729740649`}}], 
    ArrowBox[{{25., -14.433756729740649`}, {0, -28.867513459481287`}}], 
    ArrowBox[{{0, -28.867513459481287`}, {-25., -14.433756729740642`}}]}},
  Frame->True]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104673027*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sortedsurfacepoints 2 \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "14.433756729740642"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "28.86751345948129"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "14.433756729740631"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "14.433756729740649"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "28.867513459481287"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
      0, 28.86751345948129}, {25., 14.433756729740631`}, {
      25., -14.433756729740649`}, {0, -28.867513459481287`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["sortedsurfacepoints 2 ", 
   InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104719392*^9}],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-40., -40.}, {-40., 40.}, {40., 40.}, {
    40., -40.}, {-40., -40.}}], 
   LineBox[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]},
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104767024*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"surface aperture points \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", 
         RowBox[{"-", "14.433756729740642"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25."}], ",", " ", "14.433756729740642"}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "28.86751345948129"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", "14.433756729740631"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"25.", ",", " ", 
         RowBox[{"-", "14.433756729740649"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"-", "28.867513459481287"}]}], "}"}]}], "}"}],
     ShowStringCharacters->True,
     NumberMarks->True],
    InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
      0, 28.86751345948129}, {25., 14.433756729740631`}, {
      25., -14.433756729740649`}, {0, -28.867513459481287`}}],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["surface aperture points ", 
   InputForm[{{-25., -14.433756729740642`}, {-25., 14.433756729740642`}, {
     0, 28.86751345948129}, {25., 14.433756729740631`}, {
     25., -14.433756729740649`}, {0, -28.867513459481287`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104816985*^9}],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
     0, -4.166666666666667, -2.4056261216234422`}, {
     0, -8.333333333333334, -4.811252243246883}, {
     0, -12.5, -7.216878364870324}, {
     0, -16.666666666666668`, -9.622504486493762}, {
     0, -20.833333333333332`, -12.028130608117202`}, {
     0, -25., -14.433756729740644`}, {0, 0., -2.3684757858670005`*^-15}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
      0, -4.166666666666667, 2.405626121623438}, {
      0, -8.333333333333334, 4.811252243246877}, {
      0, -12.5, 7.216878364870318}, {
      0, -16.666666666666668`, 9.622504486493758}, {
      0, -20.833333333333332`, 12.028130608117198`}, {
      0, -25., 14.43375672974064}, {0, 0., -2.3684757858670005`*^-15}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
      0, 0., 4.811252243246879}, {0, 0., 9.622504486493762}, {
      0, 0., 14.433756729740644`}, {0, 0., 19.245008972987524`}, {
      0, 0., 24.056261216234407`}, {0, 0., 28.867513459481287`}, {
      0, 0., -2.3684757858670005`*^-15}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
      0, 4.166666666666666, 2.405626121623437}, {
      0, 8.333333333333332, 4.811252243246876}, {
      0, 12.499999999999998`, 7.216878364870314}, {
      0, 16.666666666666664`, 9.622504486493755}, {
      0, 20.833333333333332`, 12.028130608117193`}, {
      0, 24.999999999999996`, 14.433756729740631`}, {
      0, 0., -2.3684757858670005`*^-15}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
      0, 4.166666666666667, -2.405626121623443}, {
      0, 8.333333333333334, -4.8112522432468845`}, {
      0, 12.5, -7.216878364870325}, {
      0, 16.666666666666668`, -9.622504486493765}, {
      0, 20.833333333333336`, -12.028130608117207`}, {
      0, 25., -14.433756729740647`}, {0, 0., -2.3684757858670005`*^-15}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
      0, 0., -4.811252243246883}, {0, 0., -9.622504486493762}, {
      0, 0., -14.433756729740642`}, {0, 0., -19.245008972987524`}, {
      0, 0., -24.056261216234404`}, {0, 0., -28.867513459481284`}, {
      0, 0., -2.3684757858670005`*^-15}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{0, -25., -14.433756729740642`}, {
      0, -25., 14.433756729740642`}, {0, 0., 28.86751345948129}, {
      0, 25., 14.433756729740631`}, {0, 25., -14.433756729740649`}, {
      0, 0., -28.867513459481287`}, {0, -25., -14.433756729740642`}}]}, 
   {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
    None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
     "]], 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgfu+G+MEb2ncwBd3M607MUOO2Uc4sIY
4gwoACFuA1HvgF1cGUMc6h6ixe1wmGOHw14C7sTwlw2OcMAVbjBxAKd7RjI=

      "]]}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -14.433756729740644`}, {
      0., -25., -14.433756729740644`}, {0., -25., 14.433756729740644`}, {
      60., -25., 14.433756729740644`}, {60., -25., -14.433756729740644`}}]}, 
    {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
     None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2AC05oHnv5uYZ2wzPQARNwTh7gLDnE7HOIm
OMRVcIgzMJAmjsscXPbicicuf+EKB1zhhikOAA9hWp8=
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQP/bc8d8YI3rP5gBMfMMqEBA4YNK5yN6u
zAouvgYsrnCg99BkpXQ+C7g4I5jWPPD0dwvrhGWmcPHVYPUGB+xMy17ssDOG
i4eCwFWTA9Py0k8/vGYAF4fQlgcg7tEhKB6Gw5w1UHtt0exlxuHOdVB/9aD5
awuOcIDQLHvRww09PAEBM3Go
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., -5.329070518200751*^-15, -28.867513459481287`}, {
       0., -5.329070518200751*^-15, -28.867513459481287`}, {
       0., -25., -14.433756729740644`}, {60., -25., -14.433756729740644`}, {
       60., -5.329070518200751*^-15, -28.867513459481287`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgT4+x8ENBye/W5hnbDM9ABEVMUBu7gJDnE7HOIu
OMQ9cYj7kSiOyxxc9uJyJy5/4QoHXOGGKQ4APX6r+w==
       "]], 
      {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQHHvv+G+MEb1ncwAmvmAVCAg4mHYusrcr
s4KLLwOLKzj0HZqslM5nARf/8x8ENBye/W5hnbDMFC6+EqzewMHetOzFDjtj
uHhIKBBcNXGYnpd++uE1A7g42Jj/Fg4PwO7RgYtDaEuH+2jioTjMWQW11w7N
3n843LkC6q9eNH8twhEO0ADECDf08AQA+S17hg==
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       Line3DBox[{{0., -1.0658141036401503`*^-14, -28.867513459481287`}, {
        60., -1.0658141036401503`*^-14, -28.867513459481287`}, {60., 
        25., -14.433756729740649`}, {0., 25., -14.433756729740649`}, {
        0., -1.0658141036401503`*^-14, -28.867513459481287`}}]}, 
      {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
       None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQllCaoQFCeeIQd8EhbodD3ASHuAoOcRgg
VhyXObjsxeVOXP7CFQ64wg1THAD+ghbF
        "]], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlg63/DfGiN7TcUAXtzEte7HDThmHuDCG
ONTgBhzqD+AwH0Mc6h6ixXGZg8teAu4kOhxwhRtMHAAfTz8g
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{60., 25., 14.43375672974064}, {0., 25., 
         14.43375672974064}, {0., 25., -14.43375672974064}, {60., 
         25., -14.43375672974064}, {60., 25., 14.43375672974064}}]}, 
       {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
        None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgRgA5OaDo9/t7BOWGbqABFVccAuboJD3A6HuAsO
cU8c4n4kiuMyB5e9uNyJy1+4wgFXuGGKAwD4gEsv
         "]], 
        {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc2AC05YOV/w3xoje03GAiUeEAsFVE4dJeemn
H14zgIuvWwUCBg7WpmUvdtgZw8XZwLSmw+PfLawTlpnCxTeB1Ss4dB+arJTO
ZwEX3wMWF3Aw7lxkb1dmBReH0AK2d8DusSEovgNqjgmaORtx2IvLnWtx+Csc
Gg6T0cIBV7ihiwMAq65hBQ==
          "]]}, 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         Line3DBox[{{0., 25.000000000000007`, 14.43375672974063}, {60., 
          25.000000000000007`, 14.43375672974063}, {60., 
          1.4210854715202004`*^-14, 28.867513459481287`}, {0., 
          1.4210854715202004`*^-14, 28.867513459481287`}, {0., 
          25.000000000000007`, 14.43375672974063}}]}, 
        {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
         None], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQmgee/m5hnbDMFMr3xCHugkPcDoe4CQ5x
FRziMECsOC5zcNmLy524/IUrHHCFG6Y4AAYGUwE=
          "]], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc2AE05YHbvlvjBG9p+MAEw8LBYKrJgem5qWf
fnjNAC6+ehUIGBywNS17scPO2AHVHM0DT3+3sE5YZgoXBytfpXCg99BkpXQ+
C7j4CrC4wAHTzkX2dmVWcHGYy+6A3WODJv7B5i6a+DIc5uCy9z8YaGC4E5e/
cIUDAzTc7qCFG3p4AgDqbm3t
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{60., -25.000000000000004`, 14.43375672974064}, {
           0., -25.000000000000004`, 14.43375672974064}, {0., 
           3.552713678800501*^-15, 28.86751345948129}, {60., 
           3.552713678800501*^-15, 28.86751345948129}, {
           60., -25.000000000000004`, 14.43375672974064}}]}, 
         {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], 
          EdgeForm[None], 
          Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {
           60., -4.166666666666667, -2.4056261216234422`}, {
           60., -8.333333333333334, -4.811252243246883}, {
           60., -12.5, -7.216878364870324}, {
           60., -16.666666666666668`, -9.622504486493762}, {
           60., -20.833333333333332`, -12.028130608117202`}, {
           60., -25., -14.433756729740644`}, {60., 
           0., -2.3684757858670005`*^-15}}], 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {
            60., -4.166666666666667, 2.405626121623438}, {
            60., -8.333333333333334, 4.811252243246877}, {60., -12.5, 
            7.216878364870318}, {60., -16.666666666666668`, 
            9.622504486493758}, {60., -20.833333333333332`, 
            12.028130608117198`}, {60., -25., 14.43375672974064}, {60., 
            0., -2.3684757858670005`*^-15}}]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 0., 
            4.811252243246879}, {60., 0., 9.622504486493762}, {60., 0., 
            14.433756729740644`}, {60., 0., 19.245008972987524`}, {60., 0., 
            24.056261216234407`}, {60., 0., 28.867513459481287`}, {60., 
            0., -2.3684757858670005`*^-15}}]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
            4.166666666666666, 2.405626121623437}, {60., 8.333333333333332, 
            4.811252243246876}, {60., 12.499999999999998`, 
            7.216878364870314}, {60., 16.666666666666664`, 
            9.622504486493755}, {60., 20.833333333333332`, 
            12.028130608117193`}, {60., 24.999999999999996`, 
            14.433756729740631`}, {60., 0., -2.3684757858670005`*^-15}}]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
            4.166666666666667, -2.405626121623443}, {60., 
            8.333333333333334, -4.8112522432468845`}, {60., 
            12.5, -7.216878364870325}, {60., 
            16.666666666666668`, -9.622504486493765}, {60., 
            20.833333333333336`, -12.028130608117207`}, {60., 
            25., -14.433756729740647`}, {60., 
            0., -2.3684757858670005`*^-15}}]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
            0., -4.811252243246883}, {60., 0., -9.622504486493762}, {60., 
            0., -14.433756729740642`}, {60., 0., -19.245008972987524`}, {60., 
            0., -24.056261216234404`}, {60., 0., -28.867513459481284`}, {60., 
            0., -2.3684757858670005`*^-15}}]}, 
          {GrayLevel[0], AbsoluteThickness[0.5], 
           Line3DBox[{{60., -25., -14.433756729740642`}, {60., -25., 
            14.433756729740642`}, {60., 0., 28.86751345948129}, {60., 25., 
            14.433756729740631`}, {60., 25., -14.433756729740649`}, {60., 
            0., -28.867513459481287`}, {60., -25., -14.433756729740642`}}], 
           {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
            Text3DBox[
             FormBox["\<\"{1, 1}\"\>", TraditionalForm], {0, 0, 0}], Text3DBox[
             FormBox["\<\"{2, 1}\"\>", TraditionalForm], {30., -25., 0}], 
            Text3DBox[
             FormBox["\<\"{3, 1}\"\>", TraditionalForm], {
             30., -12.500000000000004`, -21.650635094610966`}], Text3DBox[
             FormBox["\<\"{4, 1}\"\>", TraditionalForm], {30., 
             12.499999999999995`, -21.65063509461097}], Text3DBox[
             FormBox["\<\"{5, 1}\"\>", TraditionalForm], {30., 25., 0}], 
            Text3DBox[
             FormBox["\<\"{6, 1}\"\>", TraditionalForm], {30., 
             12.50000000000001, 21.65063509461096}], Text3DBox[
             FormBox["\<\"{7, 1}\"\>", TraditionalForm], {30., -12.5, 
             21.650635094610966`}], Text3DBox[
             FormBox["\<\"{8, 1}\"\>", TraditionalForm], {
             60., 0, 0}]}}}}}}}}}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{369.5264754054431, 396.970708061729},
  PlotRange:>All,
  ViewPoint->{1.5594179016791978`, -1.411180762034872, -2.6508083040433412`},
  ViewVertical->{
   0.967079702303148, -0.2816425232751558, -0.10220329817142634`}]], "Print",
 CellChangeTimes->{
  3.505549030910034*^9, 3.505549103601309*^9, 3.5055491649934807`*^9, 
   3.505549212577608*^9, 3.505549365529244*^9, {3.505549422583241*^9, 
   3.505549445184539*^9}, 3.505562675666389*^9, 3.505563354035701*^9, 
   3.5055634633213367`*^9, 3.505564016447858*^9, 3.5055671339342327`*^9, 
   3.505570770430044*^9, 3.505571345713052*^9, 3.505571454832447*^9, 
   3.505571564854784*^9, 3.505571967378665*^9, 3.5055720159462013`*^9, 
   3.505572596510379*^9, 3.505574983988605*^9, 3.505575075377512*^9, 
   3.505575166226212*^9, 3.505575203519685*^9, {3.505575373605205*^9, 
   3.505575403319029*^9}, 3.505575508322913*^9, 3.505590072803577*^9, 
   3.505590103548705*^9, 3.505591043872974*^9, 3.5055910863962*^9, 
   3.505591357019271*^9, 3.505591517783874*^9, 3.50559175653384*^9, 
   3.505714658825343*^9, 3.506915457930294*^9, 3.506962743477103*^9, 
   3.506963104941039*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Screen", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", 
           RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"25.`", ",", 
           RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740644`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740644`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740644`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740644`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740642`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740642`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "12.500000000000004`"}], ",", 
          RowBox[{"-", "21.650635094610966`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "0", ",", "0.5000000000000001`", ",", "0.8660254037844386`"}], 
         "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740645`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740645`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "12.499999999999995`", ",", 
          RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "0.4999999999999998`"}], ",", "0.8660254037844388`"}], 
         "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740647`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740647`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", "25.`"}], "}"}], ",", 
        RowBox[{"-", "90.`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740637`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740637`"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "30.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "0.5000000000000004`"}], ",", 
          RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"30.`", ",", 
             RowBox[{"-", "14.433756729740645`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"30.`", ",", "14.433756729740653`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", "14.433756729740653`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "30.`"}], ",", 
             RowBox[{"-", "14.433756729740645`"}]}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"30.`", ",", 
          RowBox[{"-", "12.5`"}], ",", "21.650635094610966`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.5000000000000001`", ",", 
          RowBox[{"-", "0.8660254037844388`"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", 
             RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
           
           RowBox[{"{", 
            RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"25.`", ",", 
             RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}], "]"}], 
        ",", "60.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.505714660554605*^9, 3.5069154581827707`*^9, 
  3.506962744332725*^9, 3.506963105039064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[final5]", "Input",
 CellChangeTimes->{{3.5057146793048143`*^9, 3.505714698778201*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, -4.166666666666667, -2.4056261216234422`}, {
        0, -8.333333333333334, -4.811252243246883}, {
        0, -12.5, -7.216878364870324}, {
        0, -16.666666666666668`, -9.622504486493762}, {
        0, -20.833333333333332`, -12.028130608117202`}, {
        0, -25., -14.433756729740644`}, {0, 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, -4.166666666666667, 2.405626121623438}, {
        0, -8.333333333333334, 4.811252243246877}, {
        0, -12.5, 7.216878364870318}, {
        0, -16.666666666666668`, 9.622504486493758}, {
        0, -20.833333333333332`, 12.028130608117198`}, {
        0, -25., 14.43375672974064}, {0, 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, 0., 4.811252243246879}, {0, 0., 9.622504486493762}, {
        0, 0., 14.433756729740644`}, {0, 0., 19.245008972987524`}, {
        0, 0., 24.056261216234407`}, {0, 0., 28.867513459481287`}, {
        0, 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, 4.166666666666666, 2.405626121623437}, {
        0, 8.333333333333332, 4.811252243246876}, {
        0, 12.499999999999998`, 7.216878364870314}, {
        0, 16.666666666666664`, 9.622504486493755}, {
        0, 20.833333333333332`, 12.028130608117193`}, {
        0, 24.999999999999996`, 14.433756729740631`}, {
        0, 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, 4.166666666666667, -2.405626121623443}, {
        0, 8.333333333333334, -4.8112522432468845`}, {
        0, 12.5, -7.216878364870325}, {
        0, 16.666666666666668`, -9.622504486493765}, {
        0, 20.833333333333336`, -12.028130608117207`}, {
        0, 25., -14.433756729740647`}, {
        0, 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 0., -2.3684757858670005`*^-15}, {
        0, 0., -4.811252243246883}, {0, 0., -9.622504486493762}, {
        0, 0., -14.433756729740642`}, {0, 0., -19.245008972987524`}, {
        0, 0., -24.056261216234404`}, {0, 0., -28.867513459481284`}, {
        0, 0., -2.3684757858670005`*^-15}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{0, -25., -14.433756729740642`}, {
       0, -25., 14.433756729740642`}, {0, 0., 28.86751345948129}, {
       0, 25., 14.433756729740631`}, {0, 25., -14.433756729740649`}, {
       0, 0., -28.867513459481287`}, {0, -25., -14.433756729740642`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQlgcYUIAnDnEXHOJ2OMRNcIir4BCHAWLF
cZmDy15c7sTlL1zhgCvcMMUBOpEWxQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlgfu+G+MEb2ncwBd3M607MUOO2Uc4sIY
4gwoACFuA1HvgF1cGUMc6h6ixe1wmGOHw14C7sTwlw2OcMAVbjBxAKd7RjI=

       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -14.433756729740644`}, {
      0., -25., -14.433756729740644`}, {0., -25., 14.433756729740644`}, {
      60., -25., 14.433756729740644`}, {
      60., -25., -14.433756729740644`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc2AC05oHnv5uYZ2wzPQARNwTh7gLDnE7HOIm
OMRVcIgzMJAmjsscXPbicicuf+EKB1zhhikOAA9hWp8=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQP/bc8d8YI3rP5gBMfMMqEBA4YNK5yN6u
zAouvgYsrnCg99BkpXQ+C7g4I5jWPPD0dwvrhGWmcPHVYPUGB+xMy17ssDOG
i4eCwFWTA9Py0k8/vGYAF4fQlgcg7tEhKB6Gw5w1UHtt0exlxuHOdVB/9aD5
awuOcIDQLHvRww09PAEBM3Go
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -5.329070518200751*^-15, -28.867513459481287`}, {
      0., -5.329070518200751*^-15, -28.867513459481287`}, {
      0., -25., -14.433756729740644`}, {60., -25., -14.433756729740644`}, {
      60., -5.329070518200751*^-15, -28.867513459481287`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgT4+x8ENBye/W5hnbDM9ABEVMUBu7gJDnE7HOIu
OMQ9cYj7kSiOyxxc9uJyJy5/4QoHXOGGKQ4APX6r+w==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQHHvv+G+MEb1ncwAmvmAVCAg4mHYusrcr
s4KLLwOLKzj0HZqslM5nARf/8x8ENBye/W5hnbDMFC6+EqzewMHetOzFDjtj
uHhIKBBcNXGYnpd++uE1A7g42Jj/Fg4PwO7RgYtDaEuH+2jioTjMWQW11w7N
3n843LkC6q9eNH8twhEO0ADECDf08AQA+S17hg==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{0., -1.0658141036401503`*^-14, -28.867513459481287`}, {
      60., -1.0658141036401503`*^-14, -28.867513459481287`}, {60., 
      25., -14.433756729740649`}, {0., 25., -14.433756729740649`}, {
      0., -1.0658141036401503`*^-14, -28.867513459481287`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQllCaoQFCeeIQd8EhbodD3ASHuAoOcRgg
VhyXObjsxeVOXP7CFQ64wg1THAD+ghbF
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc4DQlg63/DfGiN7TcUAXtzEte7HDThmHuDCG
ONTgBhzqD+AwH0Mc6h6ixXGZg8teAu4kOhxwhRtMHAAfTz8g
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., 25., 14.43375672974064}, {0., 25., 14.43375672974064}, {
      0., 25., -14.43375672974064}, {60., 25., -14.43375672974064}, {60., 25.,
       14.43375672974064}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgRgA5OaDo9/t7BOWGbqABFVccAuboJD3A6HuAsO
cU8c4n4kiuMyB5e9uNyJy1+4wgFXuGGKAwD4gEsv
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc2AC05YOV/w3xoje03GAiUeEAsFVE4dJeemn
H14zgIuvWwUCBg7WpmUvdtgZw8XZwLSmw+PfLawTlpnCxTeB1Ss4dB+arJTO
ZwEX3wMWF3Aw7lxkb1dmBReH0AK2d8DusSEovgNqjgmaORtx2IvLnWtx+Csc
Gg6T0cIBV7ihiwMAq65hBQ==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{0., 25.000000000000007`, 14.43375672974063}, {60., 
      25.000000000000007`, 14.43375672974063}, {60., 1.4210854715202004`*^-14,
       28.867513459481287`}, {0., 1.4210854715202004`*^-14, 
      28.867513459481287`}, {0., 25.000000000000007`, 
      14.43375672974063}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwc4DQmgee/m5hnbDMFMr3xCHugkPcDoe4CQ5x
FRziMECsOC5zcNmLy524/IUrHHCFG6Y4AAYGUwE=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwc2AE05YHbvlvjBG9p+MAEw8LBYKrJgem5qWf
fnjNAC6+ehUIGBywNS17scPO2AHVHM0DT3+3sE5YZgoXBytfpXCg99BkpXQ+
C7j4CrC4wAHTzkX2dmVWcHGYy+6A3WODJv7B5i6a+DIc5uCy9z8YaGC4E5e/
cIUDAzTc7qCFG3p4AgDqbm3t
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25.000000000000004`, 14.43375672974064}, {
      0., -25.000000000000004`, 14.43375672974064}, {0., 
      3.552713678800501*^-15, 28.86751345948129}, {60., 
      3.552713678800501*^-15, 28.86751345948129}, {60., -25.000000000000004`, 
      14.43375672974064}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {
       60., -4.166666666666667, -2.4056261216234422`}, {
       60., -8.333333333333334, -4.811252243246883}, {
       60., -12.5, -7.216878364870324}, {
       60., -16.666666666666668`, -9.622504486493762}, {
       60., -20.833333333333332`, -12.028130608117202`}, {
       60., -25., -14.433756729740644`}, {60., 
       0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {
       60., -4.166666666666667, 2.405626121623438}, {60., -8.333333333333334, 
       4.811252243246877}, {60., -12.5, 7.216878364870318}, {
       60., -16.666666666666668`, 9.622504486493758}, {
       60., -20.833333333333332`, 12.028130608117198`}, {60., -25., 
       14.43375672974064}, {60., 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 0., 
       4.811252243246879}, {60., 0., 9.622504486493762}, {60., 0., 
       14.433756729740644`}, {60., 0., 19.245008972987524`}, {60., 0., 
       24.056261216234407`}, {60., 0., 28.867513459481287`}, {60., 
       0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
       4.166666666666666, 2.405626121623437}, {60., 8.333333333333332, 
       4.811252243246876}, {60., 12.499999999999998`, 7.216878364870314}, {
       60., 16.666666666666664`, 9.622504486493755}, {60., 
       20.833333333333332`, 12.028130608117193`}, {60., 24.999999999999996`, 
       14.433756729740631`}, {60., 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
       4.166666666666667, -2.405626121623443}, {60., 
       8.333333333333334, -4.8112522432468845`}, {60., 
       12.5, -7.216878364870325}, {60., 
       16.666666666666668`, -9.622504486493765}, {60., 
       20.833333333333336`, -12.028130608117207`}, {60., 
       25., -14.433756729740647`}, {60., 0., -2.3684757858670005`*^-15}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60., 0., -2.3684757858670005`*^-15}, {60., 
       0., -4.811252243246883}, {60., 0., -9.622504486493762}, {60., 
       0., -14.433756729740642`}, {60., 0., -19.245008972987524`}, {60., 
       0., -24.056261216234404`}, {60., 0., -28.867513459481284`}, {60., 
       0., -2.3684757858670005`*^-15}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{60., -25., -14.433756729740642`}, {60., -25., 
      14.433756729740642`}, {60., 0., 28.86751345948129}, {60., 25., 
      14.433756729740631`}, {60., 25., -14.433756729740649`}, {60., 
      0., -28.867513459481287`}, {60., -25., -14.433756729740642`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{383.29303481847916`, 466.81767602210505`},
  PlotRange:>All,
  ViewPoint->{3.014387514586565, -0.17021349199013816`, -1.5279055203281244`},
  
  ViewVertical->{0.9592740957872923, 0.21674504231143898`, 
   0.22570524109698928`}]], "Print",
 CellChangeTimes->{3.505714700013214*^9, 3.506963140280034*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"ShowSystem", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "25.`"}], ",", 
            RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"25.`", ",", 
            RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}], "]"}], 
       ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740644`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740644`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740644`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740644`"}]}], "}"}]}], "}"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", 
           RowBox[{"-", "25.`"}]}], "}"}], ",", "90.`"}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740642`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740642`"}], "}"}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", 
           RowBox[{"-", "12.500000000000004`"}], ",", 
           RowBox[{"-", "21.650635094610966`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "0", ",", "0.5000000000000001`", ",", "0.8660254037844386`"}], 
          "}"}]}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740645`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740647`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740645`"}], "}"}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", "12.499999999999995`", ",", 
           RowBox[{"-", "21.65063509461097`"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "0.4999999999999998`"}], ",", "0.8660254037844388`"}],
           "}"}]}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740647`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740633`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740647`"}], "}"}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", "25.`"}], "}"}], ",", 
         RowBox[{"-", "90.`"}], ",", "180"}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740637`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740653`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740637`"}], "}"}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "30.`", ",", "12.50000000000001`", ",", "21.65063509461096`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "0.5000000000000004`"}], ",", 
           RowBox[{"-", "0.8660254037844384`"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"30.`", ",", 
              RowBox[{"-", "14.433756729740645`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"30.`", ",", "14.433756729740653`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", "14.433756729740653`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "30.`"}], ",", 
              RowBox[{"-", "14.433756729740645`"}]}], "}"}]}], "}"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"30.`", ",", 
           RowBox[{"-", "12.5`"}], ",", "21.650635094610966`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.5000000000000001`", ",", 
           RowBox[{"-", "0.8660254037844388`"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.`"}], ",", 
              RowBox[{"-", "14.433756729740642`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "25.`"}], ",", "14.433756729740642`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "28.86751345948129`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"25.`", ",", "14.433756729740631`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"25.`", ",", 
              RowBox[{"-", "14.433756729740649`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"-", "28.867513459481287`"}]}], "}"}]}], "}"}], "]"}], 
         ",", "60.`"}], "]"}]}], "}"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.505714700013214*^9, 3.506963140384287*^9}]
}, Open  ]],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.505714700199872*^9, 3.506963140433239*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["More Tests", "Subsection",
 CellChangeTimes->{{3.505735691232229*^9, 3.5057356923814573`*^9}}],

Cell["\<\
segments = {{{30., -20.553851381374166}, {30., 30.}}, {{-10.553851381374166, \
30.}, {30., 30.}}, {{-12.163375074040623, -24.61528579890359}, \
{-12.779360164683673, -24.534057110553}, {-13.366495540940875, \
-24.452828422202412}, 
    {-13.928430050571333, -24.371599733851824}, {-14.46810036258051, \
-24.290371045501235}, {-14.98791167341614, -24.209142357150647}, \
{-15.489863406722572, -24.12791366880006}, {-15.975639085435684, \
-24.04668498044947}, 
    {-16.446672119844028, -23.96545629209888}, {-16.90419496005613, \
-23.884227603748293}, {-17.34927648283631, -23.802998915397705}, \
{-17.782850882481824, -23.721770227047116}, {-18.205740312869725, \
-23.640541538696528}, 
    {-18.618672857405624, -23.55931285034594}, {-19.02229695391474, \
-23.47808416199535}, {-19.417193093624846, -23.396855473644763}, \
{-19.803883398659174, -23.315626785294175}, {-20.182839530171226, \
-23.234398096943586}, 
    {-20.554489269596885, -23.153169408592998}, {-20.919222035431495, \
-23.07194072024241}, {-21.277393538724848, -22.99071203189182}, \
{-21.629329736176164, -22.909483343541233}, {-21.97533020618977, \
-22.828254655190644}, 
    {-22.315671047635927, -22.747025966840056}, {-22.65060738130204, \
-22.665797278489464}, {-22.98037551864349, -22.58456859013888}, \
{-23.305194850380957, -22.503339901788287}, {-23.625269497953944, \
-22.422111213437702}, 
    {-23.940789763248457, -22.34088252508711}, {-24.25193340592762, \
-22.259653836736522}, {-24.558866772785173, -22.178425148385934}, \
{-24.861745799554242, -22.097196460035345}, {-25.16071690235141, \
-22.015967771684757}, 
    {-25.45591777326579, -21.93473908333417}, {-25.747478092400495, \
-21.85351039498358}, {-26.035520166848897, -21.77228170663299}, \
{-26.320159505567695, -21.691053018282403}, {-26.601505337838173, \
-21.609824329931815}, 
    {-26.87966108193922, -21.528595641581227}, {-27.154724769755653, \
-21.447366953230638}, {-27.426789432283567, -21.36613826488005}, \
{-27.69594345034738, -21.28490957652946}, {-27.96227087429123, \
-21.203680888178873}, 
    {-28.225851715936038, -21.122452199828285}, {-28.486762215688195, \
-21.041223511477696}, {-28.74507508733783, -20.959994823127108}, \
{-29.00085974278343, -20.87876613477652}, {-29.25418249865959, \
-20.79753744642593}, 
    {-29.505106766618265, -20.716308758075343}, {-29.753693228817536, \
-20.635080069724754}, {-30., -20.553851381374166}}, {{-12.163375074040644, \
-24.61528579890359}, {-12.448198511481507, -23.522980082925518}, 
    {-12.719279804385721, -22.430674366947446}, {-12.976739151872422, \
-21.33836865096937}, {-13.220689418349451, -20.2460629349913}, \
{-13.451236398429188, -19.15375721901323}, {-13.668479061013414, \
-18.06145150303516}, 
    {-13.87250977393542, -16.969145787057087}, {-14.063414510410908, \
-15.876840071079014}, {-14.241273038424296, -14.784534355100943}, \
{-14.406159094065373, -13.69222863912287}, {-14.558140539727248, \
-12.5999229231448}, 
    {-14.69727950798439, -11.507617207166728}, {-14.823632531882652, \
-10.415311491188655}, {-14.937250662294787, -9.323005775210584}, \
{-15.038179572921905, -8.230700059232511}, {-15.126459653453892, \
-7.13839434325444}, 
    {-15.202126091338542, -6.046088627276369}, {-15.265208942550117, \
-4.953782911298298}, {-15.315733191693084, -3.861477195320223}, \
{-15.353718801722664, -2.769171479342152}, {-15.379180753514845, \
-1.6768657633640807}, 
    {-15.392129075469327, -0.5845600473860095}, {-15.392568863282136, \
0.5077456685920616}, {-15.380500289979267, 1.6000513845701327}, \
{-15.355918606257092, 2.6923571005482074}, {-15.318814131131532, \
3.7846628165262786}, 
    {-15.269172232852767, 4.87696853250435}, {-15.20697329999733, \
5.969274248482421}, {-15.132192702604783, 7.061579964460492}, \
{-15.044800743177618, 8.153885680438567}, {-14.944762597316725, \
9.246191396416638}, 
    {-14.832038243712802, 10.338497112394709}, {-14.70658238316311, \
11.43080282837278}, {-14.56834434622617, 12.523108544350851}, \
{-14.417267989068776, 13.615414260328922}, {-14.253291576997668, \
14.707719976306993}, 
    {-14.076347655099426, 15.800025692285065}, {-13.886362905341088, \
16.892331408263143}, {-13.683257989404723, 17.984637124241214}, \
{-13.466947376444296, 19.076942840219285}, {-13.237339154859683, \
20.169248556197356}, 
    {-12.994334827081488, 21.261554272175427}, {-12.737829086247373, \
22.3538599881535}, {-12.467709573528452, 23.44616570413157}, \
{-12.183856614726537, 24.53847142010964}, {-11.886142934613403, \
25.630777136087712}, 
    {-11.574433347313843, 26.723082852065783}, {-11.248584420848601, \
27.815388568043854}, {-10.90844411374296, 28.907694284021932}, \
{-10.553851381374159, 30.000000000000004}}};\
\>", "Input",
 CellChangeTimes->{{3.50573582416112*^9, 3.505735828949635*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{1680, 958},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3505553327-7028263"->{
  Cell[902, 35, 1067, 20, 70, "Print",
   CellTags->"Info3505553327-7028263"]},
 "Info3505648630-9982230"->{
  Cell[898194, 18811, 960, 18, 43, "Print",
   CellTags->"Info3505648630-9982230"]},
 "Info3505669113-8970513"->{
  Cell[761039, 15873, 750, 11, 95, "Print",
   CellTags->"Info3505669113-8970513"]},
 "Info3505669471-5301645"->{
  Cell[863584, 18207, 1208, 17, 131, "Print",
   CellTags->"Info3505669471-5301645"]},
 "Info3505671025-6384412"->{
  Cell[110180, 2654, 2625, 42, 76, "Print",
   CellTags->"Info3505671025-6384412"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3505553327-7028263", 1234603, 25805},
 {"Info3505648630-9982230", 1234712, 25808},
 {"Info3505669113-8970513", 1234826, 25811},
 {"Info3505669471-5301645", 1234940, 25814},
 {"Info3505671025-6384412", 1235056, 25817}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 95, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[687, 27, 92, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[804, 32, 95, 1, 27, "Input"],
Cell[902, 35, 1067, 20, 70, "Print",
 CellTags->"Info3505553327-7028263"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2006, 60, 281, 5, 27, "Input"],
Cell[2290, 67, 1189, 39, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3516, 111, 269, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[3810, 120, 26635, 448, 418, "Print"],
Cell[30448, 570, 943, 28, 20, "Print"]
}, Open  ]],
Cell[31406, 601, 176, 2, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31631, 609, 65, 1, 26, "Subsection"],
Cell[CellGroupData[{
Cell[31721, 614, 114, 1, 27, "Input"],
Cell[31838, 617, 12745, 335, 223, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44620, 957, 680, 13, 92, "Input"],
Cell[45303, 972, 3068, 100, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48408, 1077, 222, 3, 27, "Input"],
Cell[48633, 1082, 5872, 119, 364, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54542, 1206, 189, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[54756, 1213, 5613, 115, 398, "Print"],
Cell[60372, 1330, 537, 11, 20, "Print"],
Cell[60912, 1343, 916, 24, 20, "Print"],
Cell[61831, 1369, 612, 12, 362, "Print"],
Cell[62446, 1383, 1207, 31, 20, "Print"],
Cell[63656, 1416, 528, 11, 362, "Print"],
Cell[64187, 1429, 1211, 31, 20, "Print"],
Cell[65401, 1462, 536, 11, 20, "Print"],
Cell[65940, 1475, 916, 24, 20, "Print"],
Cell[66859, 1501, 612, 12, 362, "Print"],
Cell[67474, 1515, 1207, 31, 20, "Print"],
Cell[68684, 1548, 528, 11, 362, "Print"],
Cell[69215, 1561, 1213, 31, 20, "Print"],
Cell[70431, 1594, 539, 11, 20, "Print"],
Cell[70973, 1607, 918, 24, 20, "Print"],
Cell[71894, 1633, 611, 12, 362, "Print"],
Cell[72508, 1647, 1207, 31, 20, "Print"],
Cell[73718, 1680, 530, 11, 362, "Print"],
Cell[74251, 1693, 1210, 31, 20, "Print"],
Cell[75464, 1726, 537, 11, 20, "Print"],
Cell[76004, 1739, 916, 24, 20, "Print"],
Cell[76923, 1765, 612, 12, 362, "Print"],
Cell[77538, 1779, 1209, 31, 20, "Print"],
Cell[78750, 1812, 528, 11, 362, "Print"],
Cell[79281, 1825, 1211, 31, 20, "Print"],
Cell[80495, 1858, 537, 11, 20, "Print"],
Cell[81035, 1871, 918, 24, 20, "Print"],
Cell[81956, 1897, 612, 12, 362, "Print"],
Cell[82571, 1911, 1207, 31, 20, "Print"],
Cell[83781, 1944, 528, 11, 362, "Print"],
Cell[84312, 1957, 1211, 31, 20, "Print"],
Cell[85526, 1990, 536, 11, 20, "Print"],
Cell[86065, 2003, 916, 24, 20, "Print"],
Cell[86984, 2029, 611, 12, 362, "Print"],
Cell[87598, 2043, 1209, 31, 20, "Print"],
Cell[88810, 2076, 530, 11, 362, "Print"],
Cell[89343, 2089, 1211, 31, 20, "Print"],
Cell[90557, 2122, 4898, 105, 350, "Print"]
}, Open  ]],
Cell[95470, 2230, 5620, 174, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101127, 2409, 142, 3, 27, "Input"],
Cell[101272, 2414, 4669, 101, 371, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[105990, 2521, 91, 1, 26, "Subsection"],
Cell[CellGroupData[{
Cell[106106, 2526, 758, 15, 105, "Input"],
Cell[106867, 2543, 3176, 103, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110080, 2651, 97, 1, 27, "Input"],
Cell[110180, 2654, 2625, 42, 76, "Print",
 CellTags->"Info3505671025-6384412"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112842, 2701, 171, 2, 27, "Input"],
Cell[113016, 2705, 9518, 148, 572, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[122571, 2858, 232, 5, 21, "Input"],
Cell[122806, 2865, 414, 5, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123257, 2875, 223, 3, 27, "Input"],
Cell[123483, 2880, 9343, 174, 1010, "Print"]
}, Open  ]],
Cell[132841, 3057, 773, 12, 53, "Input"],
Cell[CellGroupData[{
Cell[133639, 3073, 158, 3, 27, "Input"],
Cell[133800, 3078, 361, 12, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134198, 3095, 215, 4, 27, "Input"],
Cell[134416, 3101, 525, 16, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134978, 3122, 230, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[135233, 3130, 9968, 187, 380, "Print"],
Cell[145204, 3319, 851, 18, 20, "Print"],
Cell[146058, 3339, 1292, 32, 20, "Print"],
Cell[147353, 3373, 986, 19, 362, "Print"],
Cell[148342, 3394, 13060, 307, 156, "Print"],
Cell[161405, 3703, 2889, 50, 362, "Print"],
Cell[164297, 3755, 13064, 307, 156, "Print"],
Cell[177364, 4064, 851, 18, 20, "Print"],
Cell[178218, 4084, 1292, 32, 20, "Print"],
Cell[179513, 4118, 990, 19, 362, "Print"],
Cell[180506, 4139, 13115, 307, 156, "Print"],
Cell[193624, 4448, 2887, 50, 362, "Print"],
Cell[196514, 4500, 13119, 307, 156, "Print"],
Cell[209636, 4809, 851, 18, 20, "Print"],
Cell[210490, 4829, 1288, 32, 20, "Print"],
Cell[211781, 4863, 986, 19, 362, "Print"],
Cell[212770, 4884, 13083, 305, 156, "Print"],
Cell[225856, 5191, 2897, 49, 362, "Print"],
Cell[228756, 5242, 13087, 305, 156, "Print"],
Cell[241846, 5549, 847, 18, 20, "Print"],
Cell[242696, 5569, 1290, 32, 20, "Print"],
Cell[243989, 5603, 982, 19, 362, "Print"],
Cell[244974, 5624, 12768, 300, 156, "Print"],
Cell[257745, 5926, 2828, 49, 362, "Print"],
Cell[260576, 5977, 12776, 300, 156, "Print"],
Cell[273355, 6279, 847, 18, 20, "Print"],
Cell[274205, 6299, 1366, 34, 20, "Print"],
Cell[275574, 6335, 1063, 22, 362, "Print"],
Cell[276640, 6359, 20032, 482, 321, "Print"],
Cell[296675, 6843, 3020, 55, 362, "Print"],
Cell[299698, 6900, 20036, 482, 321, "Print"],
Cell[319737, 7384, 847, 18, 20, "Print"],
Cell[320587, 7404, 1353, 33, 20, "Print"],
Cell[321943, 7439, 1063, 22, 362, "Print"],
Cell[323009, 7463, 20793, 483, 321, "Print"],
Cell[343805, 7948, 3024, 55, 362, "Print"],
Cell[346832, 8005, 20805, 483, 321, "Print"],
Cell[367640, 8490, 269859, 4419, 377, "Print"]
}, Open  ]],
Cell[637514, 12912, 67132, 1689, 613, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[704695, 14607, 87, 1, 26, "Subsection"],
Cell[CellGroupData[{
Cell[704807, 14612, 728, 14, 92, "Input"],
Cell[705538, 14628, 3150, 102, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[708725, 14735, 224, 3, 27, "Input"],
Cell[708952, 14740, 13451, 233, 487, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[722440, 14978, 130, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[722595, 14984, 13391, 233, 314, "Print"],
Cell[735989, 15219, 541, 11, 20, "Print"],
Cell[736533, 15232, 7756, 226, 66, "Print"],
Cell[744292, 15460, 382, 5, 20, "Print"]
}, Open  ]],
Cell[744689, 15468, 340, 5, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[745078, 15479, 112, 2, 26, "Subsection"],
Cell[CellGroupData[{
Cell[745215, 15485, 118, 1, 27, "Input"],
Cell[745336, 15488, 272, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[745645, 15499, 995, 17, 53, "Input"],
Cell[746643, 15518, 3401, 99, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[750081, 15622, 96, 1, 27, "Input"],
Cell[750180, 15625, 457, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[750674, 15645, 72, 1, 27, "Input"],
Cell[750749, 15648, 627, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[751413, 15672, 331, 6, 27, "Input"],
Cell[751747, 15680, 3160, 66, 399, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754944, 15751, 246, 3, 27, "Input"],
Cell[755193, 15756, 5708, 109, 461, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[760938, 15870, 98, 1, 27, "Input"],
Cell[761039, 15873, 750, 11, 95, "Print",
 CellTags->"Info3505669113-8970513"]
}, Open  ]],
Cell[CellGroupData[{
Cell[761826, 15889, 391, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[762242, 15899, 5046, 98, 440, "Print"],
Cell[767291, 15999, 323, 8, 20, "Print"],
Cell[767617, 16009, 686, 19, 20, "Print"],
Cell[768306, 16030, 444, 9, 362, "Print"],
Cell[768753, 16041, 1007, 28, 20, "Print"],
Cell[769763, 16071, 349, 9, 362, "Print"],
Cell[770115, 16082, 1011, 28, 20, "Print"],
Cell[771129, 16112, 325, 8, 20, "Print"],
Cell[771457, 16122, 818, 22, 20, "Print"],
Cell[772278, 16146, 517, 10, 440, "Print"],
Cell[772798, 16158, 1182, 31, 20, "Print"],
Cell[773983, 16191, 377, 9, 440, "Print"],
Cell[774363, 16202, 1184, 31, 20, "Print"],
Cell[775550, 16235, 325, 8, 20, "Print"],
Cell[775878, 16245, 824, 23, 20, "Print"],
Cell[776705, 16270, 515, 10, 440, "Print"],
Cell[777223, 16282, 1183, 32, 20, "Print"],
Cell[778409, 16316, 379, 10, 440, "Print"],
Cell[778791, 16328, 1187, 32, 20, "Print"],
Cell[779981, 16362, 323, 8, 20, "Print"],
Cell[780307, 16372, 818, 22, 20, "Print"],
Cell[781128, 16396, 514, 10, 440, "Print"],
Cell[781645, 16408, 1180, 31, 20, "Print"],
Cell[782828, 16441, 375, 9, 440, "Print"],
Cell[783206, 16452, 1183, 31, 20, "Print"],
Cell[784392, 16485, 323, 8, 20, "Print"],
Cell[784718, 16495, 684, 19, 20, "Print"],
Cell[785405, 16516, 444, 9, 362, "Print"],
Cell[785852, 16527, 1006, 28, 20, "Print"],
Cell[786861, 16557, 349, 9, 362, "Print"],
Cell[787213, 16568, 1011, 28, 20, "Print"],
Cell[788227, 16598, 7042, 130, 391, "Print"]
}, Open  ]],
Cell[795284, 16731, 6495, 171, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[801816, 16907, 106, 1, 27, "Input"],
Cell[801925, 16910, 2486, 82, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[804448, 16997, 220, 4, 27, "Input"],
Cell[804671, 17003, 2102, 44, 424, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[806810, 17052, 350, 6, 40, "Input"],
Cell[807163, 17060, 25483, 450, 1251, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[832683, 17515, 389, 7, 34, "Input"],
Cell[833075, 17524, 2063, 43, 451, "Print"]
}, Open  ]],
Cell[835153, 17570, 412, 7, 40, "Input"],
Cell[CellGroupData[{
Cell[835590, 17581, 294, 6, 27, "Input"],
Cell[835887, 17589, 703, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[836627, 17613, 341, 6, 27, "Input"],
Cell[836971, 17621, 654, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[837662, 17645, 300, 6, 27, "Input"],
Cell[837965, 17653, 790, 23, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[838792, 17681, 127, 1, 27, "Input"],
Cell[838922, 17684, 623, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[839582, 17708, 124, 1, 27, "Input"],
Cell[839709, 17711, 372, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[840118, 17729, 322, 6, 40, "Input"],
Cell[840443, 17737, 2083, 43, 385, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[842563, 17785, 129, 1, 27, "Input"],
Cell[842695, 17788, 2950, 60, 440, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[845682, 17853, 145, 2, 27, "Input"],
Cell[845830, 17857, 4362, 120, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[850229, 17982, 392, 8, 79, "Input"],
Cell[850624, 17992, 398, 9, 447, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[851059, 18006, 174, 2, 27, "Input"],
Cell[851236, 18010, 12204, 189, 793, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[863477, 18204, 104, 1, 21, "Input"],
Cell[863584, 18207, 1208, 17, 131, "Print",
 CellTags->"Info3505669471-5301645"]
}, Open  ]],
Cell[CellGroupData[{
Cell[864829, 18229, 146, 1, 27, "Input"],
Cell[864978, 18232, 193, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[865208, 18241, 111, 1, 27, "Input"],
Cell[865322, 18244, 475, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[865834, 18262, 396, 7, 27, "Input"],
Cell[866233, 18271, 11750, 186, 754, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[878020, 18462, 338, 6, 21, "Input"],
Cell[878361, 18470, 19699, 333, 365, 6376, 113, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[898097, 18808, 94, 1, 27, "Input"],
Cell[898194, 18811, 960, 18, 43, "Print",
 CellTags->"Info3505648630-9982230"]
}, Open  ]],
Cell[899169, 18832, 649, 11, 53, "Input"],
Cell[CellGroupData[{
Cell[899843, 18847, 102, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[899970, 18854, 1189, 20, 20, "Print"],
Cell[901162, 18876, 1361, 24, 20, "Print"],
Cell[902526, 18902, 1173, 19, 20, "Print"],
Cell[903702, 18923, 1399, 25, 26, "Print"],
Cell[905104, 18950, 1321, 23, 20, "Print"],
Cell[906428, 18975, 1363, 24, 26, "Print"],
Cell[907794, 19001, 1428, 27, 20, "Print"],
Cell[909225, 19030, 1207, 19, 367, "Print"],
Cell[910435, 19051, 1191, 20, 20, "Print"],
Cell[911629, 19073, 1363, 24, 26, "Print"],
Cell[912995, 19099, 1430, 27, 20, "Print"],
Cell[914428, 19128, 1388, 25, 20, "Print"],
Cell[915819, 19155, 1480, 29, 20, "Print"],
Cell[917302, 19186, 1339, 24, 20, "Print"],
Cell[918644, 19212, 1430, 27, 20, "Print"],
Cell[920077, 19241, 1356, 24, 20, "Print"],
Cell[921436, 19267, 1173, 19, 20, "Print"],
Cell[922612, 19288, 1233, 19, 367, "Print"],
Cell[923848, 19309, 1189, 20, 20, "Print"],
Cell[925040, 19331, 1315, 23, 20, "Print"],
Cell[926358, 19356, 1432, 27, 20, "Print"],
Cell[927793, 19385, 1333, 24, 20, "Print"],
Cell[929129, 19411, 1429, 27, 20, "Print"],
Cell[930561, 19440, 1386, 25, 20, "Print"],
Cell[931950, 19467, 1478, 29, 20, "Print"],
Cell[933431, 19498, 1322, 23, 20, "Print"],
Cell[934756, 19523, 1173, 19, 20, "Print"],
Cell[935932, 19544, 1235, 19, 367, "Print"],
Cell[937170, 19565, 1191, 20, 20, "Print"],
Cell[938364, 19587, 1383, 25, 26, "Print"],
Cell[939750, 19614, 1432, 27, 20, "Print"],
Cell[941185, 19643, 1392, 25, 20, "Print"],
Cell[942580, 19670, 1478, 29, 20, "Print"],
Cell[944061, 19701, 1333, 24, 20, "Print"],
Cell[945397, 19727, 1432, 27, 20, "Print"],
Cell[946832, 19756, 1377, 25, 20, "Print"],
Cell[948212, 19783, 1173, 19, 20, "Print"],
Cell[949388, 19804, 1233, 19, 367, "Print"],
Cell[950624, 19825, 1191, 20, 20, "Print"],
Cell[951818, 19847, 1359, 24, 20, "Print"],
Cell[953180, 19873, 1175, 19, 20, "Print"],
Cell[954358, 19894, 1399, 25, 26, "Print"],
Cell[955760, 19921, 1319, 23, 20, "Print"],
Cell[957082, 19946, 1363, 24, 26, "Print"],
Cell[958448, 19972, 1428, 27, 20, "Print"],
Cell[959879, 20001, 1207, 19, 367, "Print"]
}, Open  ]],
Cell[961101, 20023, 3795, 105, 43, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[964933, 20133, 154, 3, 21, "Input"],
Cell[965090, 20138, 70, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[965197, 20144, 113, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[965335, 20149, 5150, 100, 390, "Print"],
Cell[970488, 20251, 484, 10, 20, "Print"],
Cell[970975, 20263, 845, 21, 20, "Print"],
Cell[971823, 20286, 603, 11, 362, "Print"],
Cell[972429, 20299, 1166, 30, 20, "Print"],
Cell[973598, 20331, 507, 11, 362, "Print"],
Cell[974108, 20344, 1170, 30, 20, "Print"],
Cell[975281, 20376, 482, 10, 20, "Print"],
Cell[975766, 20388, 976, 24, 20, "Print"],
Cell[976745, 20414, 674, 12, 362, "Print"],
Cell[977422, 20428, 1338, 33, 20, "Print"],
Cell[978763, 20463, 534, 11, 362, "Print"],
Cell[979300, 20476, 1345, 33, 20, "Print"],
Cell[980648, 20511, 482, 10, 20, "Print"],
Cell[981133, 20523, 980, 25, 20, "Print"],
Cell[982116, 20550, 676, 12, 362, "Print"],
Cell[982795, 20564, 1342, 34, 20, "Print"],
Cell[984140, 20600, 537, 12, 362, "Print"],
Cell[984680, 20614, 1345, 34, 20, "Print"],
Cell[986028, 20650, 482, 10, 20, "Print"],
Cell[986513, 20662, 977, 24, 20, "Print"],
Cell[987493, 20688, 674, 12, 362, "Print"],
Cell[988170, 20702, 1341, 33, 20, "Print"],
Cell[989514, 20737, 534, 11, 362, "Print"],
Cell[990051, 20750, 1345, 33, 20, "Print"],
Cell[991399, 20785, 482, 10, 20, "Print"],
Cell[991884, 20797, 843, 21, 20, "Print"],
Cell[992730, 20820, 605, 11, 362, "Print"],
Cell[993338, 20833, 1166, 30, 20, "Print"],
Cell[994507, 20865, 508, 11, 362, "Print"],
Cell[995018, 20878, 1172, 30, 20, "Print"],
Cell[996193, 20910, 7198, 133, 426, "Print"]
}, Closed]],
Cell[1003406, 21046, 4524, 135, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1007967, 21186, 23, 0, 27, "Input"],
Cell[1007993, 21188, 2327, 76, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1010357, 21269, 125, 2, 27, "Input"],
Cell[1010485, 21273, 161, 3, 27, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1010683, 21281, 212, 4, 21, "Input"],
Cell[1010898, 21287, 7060, 131, 454, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1017995, 21423, 333, 6, 27, "Input"],
Cell[1018331, 21431, 23222, 396, 356, 9126, 163, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1041590, 21832, 282, 5, 27, "Input"],
Cell[1041875, 21839, 14826, 248, 439, 6922, 117, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1056738, 22092, 307, 4, 27, "Input"],
Cell[1057048, 22098, 5722, 109, 343, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1062819, 22213, 136, 2, 26, "Subsection"],
Cell[CellGroupData[{
Cell[1062980, 22219, 900, 15, 53, "Input"],
Cell[1063883, 22236, 4406, 134, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1068326, 22375, 270, 3, 27, "Input"],
Cell[1068599, 22380, 8580, 164, 395, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1077216, 22549, 281, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[1077522, 22557, 8941, 172, 393, "Print"],
Cell[1086466, 22731, 1128, 20, 20, "Print"],
Cell[1087597, 22753, 1881, 41, 20, "Print"],
Cell[1089481, 22796, 8960, 148, 362, 578, 10, "CachedBoxData", "BoxData", \
"Print"],
Cell[1098444, 22946, 2336, 50, 20, "Print"],
Cell[1100783, 22998, 7150, 120, 362, 352, 8, "CachedBoxData", "BoxData", \
"Print"],
Cell[1107936, 23120, 2338, 50, 20, "Print"],
Cell[1110277, 23172, 1128, 20, 20, "Print"],
Cell[1111408, 23194, 1639, 35, 20, "Print"],
Cell[1113050, 23231, 5117, 86, 232, 442, 8, "CachedBoxData", "BoxData", \
"Print"],
Cell[1118170, 23319, 2007, 43, 20, "Print"],
Cell[1120180, 23364, 3824, 66, 232, 294, 7, "CachedBoxData", "BoxData", \
"Print"],
Cell[1124007, 23432, 2011, 43, 20, "Print"],
Cell[1126021, 23477, 1128, 20, 20, "Print"],
Cell[1127152, 23499, 1641, 35, 20, "Print"],
Cell[1128796, 23536, 1338, 22, 232, "Print"],
Cell[1130137, 23560, 2015, 45, 20, "Print"],
Cell[1132155, 23607, 1193, 22, 232, "Print"],
Cell[1133351, 23631, 2019, 45, 20, "Print"],
Cell[1135373, 23678, 1128, 20, 20, "Print"],
Cell[1136504, 23700, 1639, 35, 20, "Print"],
Cell[1138146, 23737, 1336, 22, 232, "Print"],
Cell[1139485, 23761, 2015, 45, 20, "Print"],
Cell[1141503, 23808, 1193, 22, 232, "Print"],
Cell[1142699, 23832, 2021, 45, 20, "Print"],
Cell[1144723, 23879, 1127, 20, 20, "Print"],
Cell[1145853, 23901, 1639, 35, 20, "Print"],
Cell[1147495, 23938, 1338, 22, 232, "Print"],
Cell[1148836, 23962, 2013, 45, 20, "Print"],
Cell[1150852, 24009, 1193, 22, 232, "Print"],
Cell[1152048, 24033, 2019, 45, 20, "Print"],
Cell[1154070, 24080, 1128, 20, 20, "Print"],
Cell[1155201, 24102, 1639, 35, 20, "Print"],
Cell[1156843, 24139, 1336, 22, 232, "Print"],
Cell[1158182, 24163, 2015, 45, 20, "Print"],
Cell[1160200, 24210, 1193, 22, 232, "Print"],
Cell[1161396, 24234, 2021, 45, 20, "Print"],
Cell[1163420, 24281, 1128, 20, 20, "Print"],
Cell[1164551, 24303, 1641, 35, 20, "Print"],
Cell[1166195, 24340, 1338, 22, 232, "Print"],
Cell[1167536, 24364, 2005, 43, 20, "Print"],
Cell[1169544, 24409, 1188, 21, 232, "Print"],
Cell[1170735, 24432, 2009, 43, 20, "Print"],
Cell[1172747, 24477, 1128, 20, 20, "Print"],
Cell[1173878, 24499, 1881, 41, 20, "Print"],
Cell[1175762, 24542, 1472, 24, 362, "Print"],
Cell[1177237, 24568, 2334, 50, 20, "Print"],
Cell[1179574, 24620, 7148, 120, 362, 352, 8, "CachedBoxData", "BoxData", \
"Print"],
Cell[1186725, 24742, 2338, 50, 20, "Print"],
Cell[1189066, 24794, 13098, 238, 405, "Print"]
}, Closed]],
Cell[1202179, 25035, 8120, 241, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1210336, 25281, 103, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[1210464, 25286, 11286, 209, 475, "Print"],
Cell[1221753, 25497, 7437, 197, 111, "Print"]
}, Open  ]],
Cell[1229205, 25697, 129, 1, 27, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1229383, 25704, 100, 1, 26, "Subsection"],
Cell[1229486, 25707, 4786, 84, 287, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
