(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1357705,      77736]*)
(*NotebookOutlinePosition[   1391013,      78586]*)
(*  CellTagsIndexPosition[   1390424,      78566]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "'s Built-in Prisms & Corner Cubes"
}], "Section"],

Cell[CellGroupData[{

Cell["HollowCornerCube[diameter, options]", "Subsection",
  CellTags->"HollowCornerCube"],

Cell[CellGroupData[{

Cell["?HollowCornerCube", "Input",
  CellTags->"HollowCornerCube"],

Cell[BoxData[
    \("HollowCornerCube[diameter, options] refers to a three-sided \
retro-reflective mirror arrangement having a single circular entrance/exit \
face that is located in the y-z plane and three reflecting surfaces that are \
arranged about the positive x-axis. \n\nHollowCornerCube behaves like a \
corner cube. There can be two different forms of HollowCornerCube: with \
FullForm -> True, the reflective surfaces have square boundaries; with \
FullForm -> False, the reflective surfaces have polygonal boundaries that \
shorten the overall thickness of the reflector. For Baffled -> True, \
HollowCornerCube is created with a circular-shaped absorbing annulus placed \
at the entrance plane. See also: SolidCornerCube, WedgePrism, RoofPrism, \
RhomboidPrism, and PentaPrism."\)], "Print",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{HollowCornerCube[50,FullForm->False,Baffled->False],\
Boundary[60,GraphicDesign->Off]}, PlotType->FrontView, AspectRatio->1];\
\>", \
"Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.550641 0.017022 0.516578 0.0159214 [
[.02381 .02381 -30 -4.5 ]
[.02381 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.52404 .30114 m
.97619 .28677 L
.55064 .51658 L
.52404 .30114 L
F
.52404 .30114 m
.55064 .51658 L
.12509 .28677 L
.52404 .30114 L
F
.52404 .30114 m
.12509 .28677 L
.44425 .11442 L
.52404 .30114 L
F
.52404 .30114 m
.44425 .11442 L
.65703 .11442 L
.52404 .30114 L
F
.52404 .30114 m
.65703 .11442 L
.97619 .28677 L
.52404 .30114 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.55064 .51658 m
.12509 .28677 L
.44425 .11442 L
.65703 .11442 L
.97619 .28677 L
.55064 .51658 L
s
.5 g
.36446 .64584 m
.12509 .28677 L
.55064 .51658 L
.36446 .64584 L
F
.36446 .64584 m
.55064 .51658 L
.55064 .97619 L
.36446 .64584 L
F
.36446 .64584 m
.55064 .97619 L
.23148 .80384 L
.36446 .64584 L
F
.36446 .64584 m
.23148 .80384 L
.12509 .63148 L
.36446 .64584 L
F
.36446 .64584 m
.12509 .63148 L
.12509 .28677 L
.36446 .64584 L
F
0 g
.55064 .51658 m
.55064 .97619 L
.23148 .80384 L
.12509 .63148 L
.12509 .28677 L
.55064 .51658 L
s
.5 g
.76342 .60276 m
.55064 .97619 L
.55064 .51658 L
.76342 .60276 L
F
.76342 .60276 m
.55064 .51658 L
.97619 .28677 L
.76342 .60276 L
F
.76342 .60276 m
.97619 .28677 L
.97619 .63148 L
.76342 .60276 L
F
.76342 .60276 m
.97619 .63148 L
.8698 .80384 L
.76342 .60276 L
F
.76342 .60276 m
.8698 .80384 L
.55064 .97619 L
.76342 .60276 L
F
0 g
.55064 .51658 m
.97619 .28677 L
.97619 .63148 L
.8698 .80384 L
.55064 .97619 L
.55064 .51658 L
s
0 0 0 r
[(CornerCube)] .02381 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{166, 166},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002V0000YR000`400?l00000o`00003oYP3oool0
0:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3o
ool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool000L0oooo0`0000030?oo
o`<000000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000000000000P3oool20000
00<0oooo0`0000030?ooo`<0000000@0oooo00000000000000000P3oool200000780oooo00060?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00P00001d0?ooo`001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0
00000?ooo`@0000000D0oooo0000003oool0oooo000000060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@00001a0?ooo`001@3oool00`000000oooo0?ooo`040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0K`3oool000D0oooo00<000000?ooo`3o
ool01@3oool3000000030?ooo`000000000000@000000`3oool2000000060?ooo`00000000000000
003oool000001@3oool2000000040?ooo`000000oooo0?ooo`<000000P3oool200000780oooo0006
0?ooo`030000003oool0oooo008000005`3oool00`000000oooo0?ooo`02000000H0oooo00<00000
0?ooo`3oool0MP3oool000L0oooo0P0000000`3oool000000?ooo`0G0?ooo`80000000<0oooo0000
003oool0103oool2000007P0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0
oooo002V0?ooo`00E`3ooolP000002l0oooo001E0?ooo`800000801oOgl2000002d0oooo001C0?oo
o`800000901oOgl2000002/0oooo001B0?ooo`030000001oOgl0Ogmo02H0Ogmo00<000000?ooo`3o
ool0:03oool00500oooo0P00000Z07moO`800000:03oool004h0oooo0P00000^07moO`8000009P3o
ool004`0oooo0P00000b07moO`800000903oool004X0oooo0P00000f07moO`8000008P3oool004P0
oooo0P00000j07moO`800000803oool004L0oooo00<0000007moO`1oOgl0?01oOgl00`000000oooo
0?ooo`0M0?ooo`00A@3oool200000400Ogmo0P00000M0?ooo`00@`3oool2000004@0Ogmo0P00000K
0?ooo`00@@3oool2000004P0Ogmo0P00000I0?ooo`00?`3oool2000004`0Ogmo0P00000G0?ooo`00
?@3oool200000500Ogmo0P00000E0?ooo`00?03oool00`000000Ogmo07moO`1B07moO`030000003o
ool0oooo0180oooo000j0?ooo`800000EP1oOgl200000180oooo000h0?ooo`800000FP1oOgl20000
0100oooo000f0?ooo`800000GP1oOgl2000000h0oooo000d0?ooo`800000HP1oOgl2000000`0oooo
000b0?ooo`800000IP1oOgl2000000X0oooo000a0?ooo`030000001oOgl0Ogmo06P0Ogmo00<00000
0?ooo`3oool01`3oool002l0oooo0P00001/07moO`8000001`3oool002d0oooo0P00001`07moO`80
00001@3oool002`0oooo0P00001b07moO`800000103oool002`0oooo00@0000007moO`0000000000
KP1oOgl20000000307moO`000000oooo00<0oooo000/0?ooo`040000001oOgl0Ogmo07moO`800000
JP1oOgl2000000<0Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`1V07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00P3o
ool002`0oooo00<0000007moO`1oOgl0101oOgl2000006@0Ogmo0P00000607moO`030000003oool0
oooo0080oooo000/0?ooo`030000001oOgl0Ogmo00H0Ogmo0P00001P07moO`800000201oOgl00`00
0000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0807moO`800000G01oOgl2000000X0
Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl02P1oOgl2000005P0Ogmo
0P00000<07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0D`1oOgl2000000h0Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<00000
07moO`1oOgl03@1oOgl200000540Ogmo0P00000@07moO`030000003oool0oooo0080oooo000/0?oo
o`030000001oOgl0Ogmo00l0Ogmo0P00001>07moO`030000001oOgl0Ogmo0100Ogmo00<000000?oo
o`3oool00P3oool002`0oooo00<0000007moO`1oOgl04@1oOgl2000004X0Ogmo0P00000C07moO`03
0000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo01<0Ogmo0P00001607moO`800000
5@1oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0E07moO`030000001o
Ogl0Ogmo0440Ogmo0P00000G07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0
Ogmo01H0Ogmo0P00000o07moO`8000006@1oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`00
0000Ogmo07moO`0H07moO`800000>`1oOgl2000001/0Ogmo00<000000?ooo`3oool00P3oool002`0
oooo00<0000007moO`1oOgl06P1oOgl2000003P0Ogmo00<0000007moO`1oOgl06`1oOgl00`000000
oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0L07moO`800000=01oOgl2000001h0Ogmo
00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl07P1oOgl200000300Ogmo0P00
000P07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo0200Ogmo00<00000
07moO`1oOgl0:`1oOgl200000280Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007mo
O`1oOgl08@1oOgl2000002T0Ogmo0P00000T07moO`030000003oool0oooo0080oooo000/0?ooo`03
0000001oOgl0Ogmo02<0Ogmo0P00000U07moO`8000009P1oOgl00`000000oooo0?ooo`020?ooo`00
;03oool00`000000Ogmo07moO`0U07moO`8000008P1oOgl00`000000Ogmo07moO`0V07moO`030000
003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo02L0Ogmo0P00000N07moO`800000:@1o
Ogl00`000000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0Y07moO`030000001oOgl0
Ogmo01T0Ogmo0P00000[07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo
02X0Ogmo0P00000G07moO`800000;@1oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`000000
Ogmo07moO`0/07moO`8000004`1oOgl2000002l0Ogmo00<000000?ooo`3oool00P3oool002`0oooo
00<0000007moO`1oOgl0;P1oOgl2000000l0Ogmo0P00000a07moO`030000003oool0oooo0080oooo
000/0?ooo`030000001oOgl0Ogmo0300Ogmo0P00000;07moO`800000<`1oOgl00`000000oooo0?oo
o`020?ooo`00;03oool00`000000Ogmo07moO`0b07moO`030000001oOgl0Ogmo00L0Ogmo00<00000
07moO`1oOgl0<`1oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0c07mo
O`8000001@1oOgl2000003H0Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1o
Ogl0=@1oOgl20000000307moO`000000000003P0Ogmo00<000000?ooo`3oool00P3oool002`0oooo
00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0h07moO`030000003oool0oooo0080oooo
000/0?ooo`030000001oOgl0Ogmo03L0Ogmo00<0000007moO`1oOgl0>01oOgl00`000000oooo0?oo
o`020?ooo`00;03oool00`000000Ogmo07moO`0g07moO`030000001oOgl0Ogmo03P0Ogmo00<00000
0?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0h07mo
O`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo03L0Ogmo00<0000007moO`1o
Ogl0>01oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0g07moO`030000
001oOgl0Ogmo03P0Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl0=`1o
Ogl00`000000Ogmo07moO`0h07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0
Ogmo03L0Ogmo00<0000007moO`1oOgl0>01oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`00
0000Ogmo07moO`0g07moO`030000001oOgl0Ogmo03P0Ogmo00<000000?ooo`3oool00P3oool002`0
oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0h07moO`030000003oool0oooo0080
oooo000/0?ooo`030000001oOgl0Ogmo03L0Ogmo00<0000007moO`1oOgl0>01oOgl00`000000oooo
0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0g07moO`030000001oOgl0Ogmo03P0Ogmo00<0
00000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl0=`1oOgl00`000000Ogmo07moO`0h
07moO`030000003oool0oooo0080oooo000/0?ooo`030000001oOgl0Ogmo03L0Ogmo00<0000007mo
O`1oOgl0>01oOgl00`000000oooo0?ooo`020?ooo`00;03oool00`000000Ogmo07moO`0g07moO`03
0000001oOgl0Ogmo03P0Ogmo00<000000?ooo`3oool00P3oool002`0oooo00<0000007moO`1oOgl0
=`1oOgl00`000000Ogmo07moO`0h07moO`030000003oool0oooo0080oooo000/0?ooo`030000001o
Ogl0Ogmo03L0Ogmo00<0000007moO`1oOgl0>01oOgl00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000Ogmo07moO`0g07moO`030000001oOgl0Ogmo03P0Ogmo00<000000?ooo`3oool00P3oool0
02d0oooo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07moO`0g07moO`030000003oool0oooo
00<0oooo000]0?ooo`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl0=P1oOgl00`000000
oooo0?ooo`040?ooo`00;P3oool00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03H0Ogmo
00<000000?ooo`3oool0103oool002l0oooo00<0000007moO`1oOgl0=01oOgl00`000000Ogmo07mo
O`0e07moO`030000003oool0oooo00D0oooo000_0?ooo`030000001oOgl0Ogmo03@0Ogmo00<00000
07moO`1oOgl0=@1oOgl00`000000oooo0?ooo`050?ooo`00<03oool00`000000Ogmo07moO`0c07mo
O`030000001oOgl0Ogmo03@0Ogmo00<000000?ooo`3oool01P3oool00300oooo00<0000007moO`1o
Ogl0<`1oOgl00`000000Ogmo07moO`0c07moO`030000003oool0oooo00L0oooo000a0?ooo`030000
001oOgl0Ogmo0380Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`070?ooo`00<P3o
ool00`000000Ogmo07moO`0a07moO`030000001oOgl0Ogmo0380Ogmo00<000000?ooo`3oool0203o
ool00380oooo00<0000007moO`1oOgl0<@1oOgl00`000000Ogmo07moO`0a07moO`030000003oool0
oooo00T0oooo000c0?ooo`030000001oOgl0Ogmo0300Ogmo00<0000007moO`1oOgl0<@1oOgl00`00
0000oooo0?ooo`090?ooo`00<`3oool00`000000Ogmo07moO`0`07moO`030000001oOgl0Ogmo0300
Ogmo00<000000?ooo`3oool02P3oool003@0oooo00<0000007moO`1oOgl0;`1oOgl00`000000Ogmo
07moO`0`07moO`030000003oool0oooo00X0oooo000d0?ooo`030000001oOgl0Ogmo02l0Ogmo00<0
000007moO`1oOgl0;`1oOgl00`000000oooo0?ooo`0;0?ooo`00=@3oool00`000000Ogmo07moO`0^
07moO`030000001oOgl0Ogmo02h0Ogmo00<000000?ooo`3oool0303oool003H0oooo00<0000007mo
O`1oOgl0;@1oOgl00`000000Ogmo07moO`0^07moO`030000003oool0oooo00`0oooo000f0?ooo`03
0000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl0;@1oOgl00`000000oooo0?ooo`0=0?ooo`00
=`3oool00`000000Ogmo07moO`0/07moO`030000001oOgl0Ogmo02`0Ogmo00<000000?ooo`3oool0
3P3oool003L0oooo00<0000007moO`1oOgl0;01oOgl00`000000Ogmo07moO`0/07moO`030000003o
ool0oooo00h0oooo000h0?ooo`030000001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl0:`1oOgl0
0`000000oooo0?ooo`0?0?ooo`00>@3oool00`000000Ogmo07moO`0Z07moO`030000001oOgl0Ogmo
02/0Ogmo00<000000?ooo`3oool03`3oool003T0oooo00<0000007moO`1oOgl0:P1oOgl00`000000
Ogmo07moO`0Z07moO`030000003oool0oooo0100oooo000j0?ooo`800000:P1oOgl00`000000Ogmo
07moO`0X07moO`8000004`3oool003`0oooo0P00000X07moO`030000001oOgl0Ogmo02H0Ogmo0P00
000E0?ooo`00?P3oool2000002H0Ogmo00<0000007moO`1oOgl0901oOgl2000001L0oooo00100?oo
o`800000901oOgl00`000000Ogmo07moO`0R07moO`8000006@3oool00480oooo0P00000R07moO`03
0000001oOgl0Ogmo0200Ogmo0P00000K0?ooo`00A03oool200000200Ogmo00<0000007moO`1oOgl0
7P1oOgl2000001d0oooo00160?ooo`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1oOgl07@1o
Ogl00`000000oooo0?ooo`0M0?ooo`00A`3oool2000001d0Ogmo00<0000007moO`1oOgl06`1oOgl2
00000200oooo00190?ooo`8000006`1oOgl00`000000Ogmo07moO`0I07moO`8000008P3oool004/0
oooo0P00000I07moO`030000001oOgl0Ogmo01L0Ogmo0P00000T0?ooo`00C@3oool2000001L0Ogmo
00<0000007moO`1oOgl05@1oOgl2000002H0oooo001?0?ooo`8000005@1oOgl00`000000Ogmo07mo
O`0C07moO`800000:03oool00540oooo0P00000C07moO`030000001oOgl0Ogmo0140Ogmo0P00000Z
0?ooo`00D`3oool200000140Ogmo00<0000007moO`1oOgl03`1oOgl2000002`0oooo001E0?ooo`80
00003`1oOgl00`000000Ogmo07moO`0=07moO`800000;P3oool005L0oooo0P00000=07moO`030000
001oOgl0Ogmo00/0Ogmo0P00000`0?ooo`00F@3oool2000000/0Ogmo00<0000007moO`1oOgl02@1o
Ogl200000380oooo001K0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0201oOgl0
0`000000oooo0?ooo`0b0?ooo`00G03oool2000000P0Ogmo00<0000007moO`1oOgl01P1oOgl20000
03D0oooo001N0?ooo`8000001P1oOgl00`000000Ogmo07moO`0407moO`800000=`3oool00600oooo
0P00000407moO`030000001oOgl0Ogmo0080Ogmo0P00000i0?ooo`00HP3oool200000080Ogmo00<0
000007moO`1oOgl00P00000k0?ooo`00I03oool5000003d0oooo001V0?ooo`030000003oool0oooo
03d0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3o
ool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00YP3oool00:H0oooo002V0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 165}, {165, 0}} -> {-43.6946, -38.7849, 0.42481, \
0.454175}},
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{HollowCornerCube[50,FullForm->False],Boundary[60]},\
PlotType->FrontView, AspectRatio->1];\
\>", "Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.509852 0.0155446 0.509852 0.0155446 [
[.02381 .02381 -30 -4.5 ]
[.02381 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.48556 .29951 m
.89847 .28548 L
.50985 .50985 L
.48556 .29951 L
F
.48556 .29951 m
.50985 .50985 L
.12124 .28548 L
.48556 .29951 L
F
.48556 .29951 m
.12124 .28548 L
.4127 .11721 L
.48556 .29951 L
F
.48556 .29951 m
.4127 .11721 L
.60701 .11721 L
.48556 .29951 L
F
.48556 .29951 m
.60701 .11721 L
.89847 .28548 L
.48556 .29951 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50985 .50985 m
.12124 .28548 L
.4127 .11721 L
.60701 .11721 L
.89847 .28548 L
.50985 .50985 L
s
.5 g
.33983 .63606 m
.12124 .28548 L
.50985 .50985 L
.33983 .63606 L
F
.33983 .63606 m
.50985 .50985 L
.50985 .95859 L
.33983 .63606 L
F
.33983 .63606 m
.50985 .95859 L
.21839 .79031 L
.33983 .63606 L
F
.33983 .63606 m
.21839 .79031 L
.12124 .62204 L
.33983 .63606 L
F
.33983 .63606 m
.12124 .62204 L
.12124 .28548 L
.33983 .63606 L
F
0 g
.50985 .50985 m
.50985 .95859 L
.21839 .79031 L
.12124 .62204 L
.12124 .28548 L
.50985 .50985 L
s
.5 g
.70416 .59399 m
.50985 .95859 L
.50985 .50985 L
.70416 .59399 L
F
.70416 .59399 m
.50985 .50985 L
.89847 .28548 L
.70416 .59399 L
F
.70416 .59399 m
.89847 .28548 L
.89847 .62204 L
.70416 .59399 L
F
.70416 .59399 m
.89847 .62204 L
.80131 .79031 L
.70416 .59399 L
F
.70416 .59399 m
.80131 .79031 L
.50985 .95859 L
.70416 .59399 L
F
0 g
.50985 .50985 m
.89847 .28548 L
.89847 .62204 L
.80131 .79031 L
.50985 .95859 L
.50985 .50985 L
s
.5 g
.89847 .50985 m
.91851 .50985 L
.90458 .61562 L
.88523 .61043 L
.89847 .50985 L
F
.88523 .61043 m
.90458 .61562 L
.86376 .71418 L
.8464 .70416 L
.88523 .61043 L
F
.8464 .70416 m
.86376 .71418 L
.79881 .79881 L
.78464 .78464 L
.8464 .70416 L
F
.78464 .78464 m
.79881 .79881 L
.71418 .86376 L
.70416 .8464 L
.78464 .78464 L
F
.70416 .8464 m
.71418 .86376 L
.61562 .90458 L
.61043 .88523 L
.70416 .8464 L
F
.61043 .88523 m
.61562 .90458 L
.50985 .91851 L
.50985 .89847 L
.61043 .88523 L
F
.50985 .89847 m
.50985 .91851 L
.40408 .90458 L
.40927 .88523 L
.50985 .89847 L
F
.40927 .88523 m
.40408 .90458 L
.30552 .86376 L
.31554 .8464 L
.40927 .88523 L
F
.31554 .8464 m
.30552 .86376 L
.22089 .79881 L
.23506 .78464 L
.31554 .8464 L
F
.23506 .78464 m
.22089 .79881 L
.15595 .71418 L
.1733 .70416 L
.23506 .78464 L
F
.1733 .70416 m
.15595 .71418 L
.11512 .61562 L
.13448 .61043 L
.1733 .70416 L
F
.13448 .61043 m
.11512 .61562 L
.1012 .50985 L
.12124 .50985 L
.13448 .61043 L
F
.12124 .50985 m
.1012 .50985 L
.11512 .40408 L
.13448 .40927 L
.12124 .50985 L
F
.13448 .40927 m
.11512 .40408 L
.15595 .30552 L
.1733 .31554 L
.13448 .40927 L
F
.1733 .31554 m
.15595 .30552 L
.22089 .22089 L
.23506 .23506 L
.1733 .31554 L
F
.23506 .23506 m
.22089 .22089 L
.30552 .15595 L
.31554 .1733 L
.23506 .23506 L
F
.31554 .1733 m
.30552 .15595 L
.40408 .11512 L
.40927 .13448 L
.31554 .1733 L
F
.40927 .13448 m
.40408 .11512 L
.50985 .1012 L
.50985 .12124 L
.40927 .13448 L
F
.50985 .12124 m
.50985 .1012 L
.61562 .11512 L
.61043 .13448 L
.50985 .12124 L
F
.61043 .13448 m
.61562 .11512 L
.71418 .15595 L
.70416 .1733 L
.61043 .13448 L
F
.70416 .1733 m
.71418 .15595 L
.79881 .22089 L
.78464 .23506 L
.70416 .1733 L
F
.78464 .23506 m
.79881 .22089 L
.86376 .30552 L
.8464 .31554 L
.78464 .23506 L
F
.8464 .31554 m
.86376 .30552 L
.90458 .40408 L
.88523 .40927 L
.8464 .31554 L
F
.88523 .40927 m
.90458 .40408 L
.91851 .50985 L
.89847 .50985 L
.88523 .40927 L
F
.91851 .50985 m
.93855 .50985 L
.92394 .62081 L
.90458 .61562 L
.91851 .50985 L
F
.90458 .61562 m
.92394 .62081 L
.88111 .7242 L
.86376 .71418 L
.90458 .61562 L
F
.86376 .71418 m
.88111 .7242 L
.81298 .81298 L
.79881 .79881 L
.86376 .71418 L
F
.79881 .79881 m
.81298 .81298 L
.7242 .88111 L
.71418 .86376 L
.79881 .79881 L
F
.71418 .86376 m
.7242 .88111 L
.62081 .92394 L
.61562 .90458 L
.71418 .86376 L
F
.61562 .90458 m
.62081 .92394 L
.50985 .93855 L
.50985 .91851 L
.61562 .90458 L
F
.50985 .91851 m
.50985 .93855 L
.3989 .92394 L
.40408 .90458 L
.50985 .91851 L
F
.40408 .90458 m
.3989 .92394 L
.2955 .88111 L
.30552 .86376 L
.40408 .90458 L
F
.30552 .86376 m
.2955 .88111 L
.20672 .81298 L
.22089 .79881 L
.30552 .86376 L
F
.22089 .79881 m
.20672 .81298 L
.13859 .7242 L
.15595 .71418 L
.22089 .79881 L
F
.15595 .71418 m
.13859 .7242 L
.09576 .62081 L
.11512 .61562 L
.15595 .71418 L
F
.11512 .61562 m
.09576 .62081 L
.08116 .50985 L
.1012 .50985 L
.11512 .61562 L
F
.1012 .50985 m
.08116 .50985 L
.09576 .3989 L
.11512 .40408 L
.1012 .50985 L
F
.11512 .40408 m
.09576 .3989 L
.13859 .2955 L
.15595 .30552 L
.11512 .40408 L
F
.15595 .30552 m
.13859 .2955 L
.20672 .20672 L
.22089 .22089 L
.15595 .30552 L
F
.22089 .22089 m
.20672 .20672 L
.2955 .13859 L
.30552 .15595 L
.22089 .22089 L
F
.30552 .15595 m
.2955 .13859 L
.3989 .09576 L
.40408 .11512 L
.30552 .15595 L
F
.40408 .11512 m
.3989 .09576 L
.50985 .08116 L
.50985 .1012 L
.40408 .11512 L
F
.50985 .1012 m
.50985 .08116 L
.62081 .09576 L
.61562 .11512 L
.50985 .1012 L
F
.61562 .11512 m
.62081 .09576 L
.7242 .13859 L
.71418 .15595 L
.61562 .11512 L
F
.71418 .15595 m
.7242 .13859 L
.81298 .20672 L
.79881 .22089 L
.71418 .15595 L
F
.79881 .22089 m
.81298 .20672 L
.88111 .2955 L
.86376 .30552 L
.79881 .22089 L
F
.86376 .30552 m
.88111 .2955 L
.92394 .3989 L
.90458 .40408 L
.86376 .30552 L
F
.90458 .40408 m
.92394 .3989 L
.93855 .50985 L
.91851 .50985 L
.90458 .40408 L
F
.93855 .50985 m
.95859 .50985 L
.9433 .62599 L
.92394 .62081 L
.93855 .50985 L
F
.92394 .62081 m
.9433 .62599 L
.89847 .73422 L
.88111 .7242 L
.92394 .62081 L
F
.88111 .7242 m
.89847 .73422 L
.82715 .82715 L
.81298 .81298 L
.88111 .7242 L
F
.81298 .81298 m
.82715 .82715 L
.73422 .89847 L
.7242 .88111 L
.81298 .81298 L
F
.7242 .88111 m
.73422 .89847 L
.62599 .9433 L
.62081 .92394 L
.7242 .88111 L
F
.62081 .92394 m
.62599 .9433 L
.50985 .95859 L
.50985 .93855 L
.62081 .92394 L
F
.50985 .93855 m
.50985 .95859 L
.39371 .9433 L
.3989 .92394 L
.50985 .93855 L
F
.3989 .92394 m
.39371 .9433 L
.28548 .89847 L
.2955 .88111 L
.3989 .92394 L
F
.2955 .88111 m
.28548 .89847 L
.19255 .82715 L
.20672 .81298 L
.2955 .88111 L
F
.20672 .81298 m
.19255 .82715 L
.12124 .73422 L
.13859 .7242 L
.20672 .81298 L
F
.13859 .7242 m
.12124 .73422 L
.07641 .62599 L
.09576 .62081 L
.13859 .7242 L
F
.09576 .62081 m
.07641 .62599 L
.06112 .50985 L
.08116 .50985 L
.09576 .62081 L
F
.08116 .50985 m
.06112 .50985 L
.07641 .39371 L
.09576 .3989 L
.08116 .50985 L
F
.09576 .3989 m
.07641 .39371 L
.12124 .28548 L
.13859 .2955 L
.09576 .3989 L
F
.13859 .2955 m
.12124 .28548 L
.19255 .19255 L
.20672 .20672 L
.13859 .2955 L
F
.20672 .20672 m
.19255 .19255 L
.28548 .12124 L
.2955 .13859 L
.20672 .20672 L
F
.2955 .13859 m
.28548 .12124 L
.39371 .07641 L
.3989 .09576 L
.2955 .13859 L
F
.3989 .09576 m
.39371 .07641 L
.50985 .06112 L
.50985 .08116 L
.3989 .09576 L
F
.50985 .08116 m
.50985 .06112 L
.62599 .07641 L
.62081 .09576 L
.50985 .08116 L
F
.62081 .09576 m
.62599 .07641 L
.73422 .12124 L
.7242 .13859 L
.62081 .09576 L
F
.7242 .13859 m
.73422 .12124 L
.82715 .19255 L
.81298 .20672 L
.7242 .13859 L
F
.81298 .20672 m
.82715 .19255 L
.89847 .28548 L
.88111 .2955 L
.81298 .20672 L
F
.88111 .2955 m
.89847 .28548 L
.9433 .39371 L
.92394 .3989 L
.88111 .2955 L
F
.92394 .3989 m
.9433 .39371 L
.95859 .50985 L
.93855 .50985 L
.92394 .3989 L
F
0 g
.89847 .50985 m
.88523 .61043 L
.8464 .70416 L
.78464 .78464 L
.70416 .8464 L
.61043 .88523 L
.50985 .89847 L
.40927 .88523 L
.31554 .8464 L
.23506 .78464 L
.1733 .70416 L
.13448 .61043 L
.12124 .50985 L
.13448 .40927 L
.1733 .31554 L
.23506 .23506 L
.31554 .1733 L
.40927 .13448 L
.50985 .12124 L
.61043 .13448 L
.70416 .1733 L
.78464 .23506 L
.8464 .31554 L
.88523 .40927 L
.89847 .50985 L
s
.95859 .50985 m
.9433 .62599 L
.89847 .73422 L
.82715 .82715 L
.73422 .89847 L
.62599 .9433 L
.50985 .95859 L
.39371 .9433 L
.28548 .89847 L
.19255 .82715 L
.12124 .73422 L
.07641 .62599 L
.06112 .50985 L
.07641 .39371 L
.12124 .28548 L
.19255 .19255 L
.28548 .12124 L
.39371 .07641 L
.50985 .06112 L
.62599 .07641 L
.73422 .12124 L
.82715 .19255 L
.89847 .28548 L
.9433 .39371 L
.95859 .50985 L
s
.97619 .04351 m
.04351 .04351 L
.04351 .97619 L
.97619 .97619 L
.97619 .04351 L
s
.04351 .04351 m
.04351 .04351 L
.04351 .97619 L
.04351 .97619 L
.04351 .04351 L
s
.04351 .04351 m
.97619 .04351 L
.97619 .97619 L
.04351 .97619 L
.04351 .04351 L
s
.97619 .04351 m
.97619 .04351 L
.97619 .97619 L
.97619 .97619 L
.97619 .04351 L
s
.04351 .04351 m
.97619 .04351 L
.97619 .04351 L
.04351 .04351 L
.04351 .04351 L
s
.97619 .97619 m
.04351 .97619 L
.04351 .97619 L
.97619 .97619 L
.97619 .97619 L
s
0 0 0 r
[(CornerCube)] .02381 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{174, 174},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000[R000`400?l00000o`00003o[P3oool0
0:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3o
ool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool000L0oooo0`0000030?oo
o`<000000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000000000000P3oool20000
00<0oooo0`0000030?ooo`<0000000@0oooo00000000000000000P3oool2000007X0oooo00060?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00P00001l0?ooo`001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0
00000?ooo`@0000000D0oooo0000003oool0oooo000000060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@00001i0?ooo`001@3oool00`000000oooo0?ooo`040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0M`3oool000D0oooo00<000000?ooo`3o
ool01@3oool3000000030?ooo`000000000000@000000`3oool2000000060?ooo`00000000000000
003oool000001@3oool2000000040?ooo`000000oooo0?ooo`<000000P3oool2000007D0oooo00<0
00000?ooo`3oool00P3oool000H0oooo00<000000?ooo`3oool00P00000E0?ooohX00000103oool0
00L0oooo0P0000000`3oool000000?ooo`0D0?ooo`030000003oool0oooo0080000000<0oooo0000
003oool0103oool2000007/0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3o
ool0?P3oool9000003l0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0
=@3oool9000000T0Ogmo2@00000f0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003o
ool0oooo0300oooo1@00000K07moO`D00000<@3oool00`000000oooo0?ooo`020?ooo`00803oool0
0`000000oooo0?ooo`0^0?ooo`8000009@1oOgl2000002l0oooo00<000000?ooo`3oool00P3oool0
0200oooo00<000000?ooo`3oool0:`3oool3000002T0Ogmo0`00000/0?ooo`030000003oool0oooo
0080oooo000P0?ooo`030000003oool0oooo02T0oooo0P00000_07moO`800000:P3oool00`000000
oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`800000<`1oOgl2000002P0oooo
00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0903oool3000003L0Ogmo0`00
000U0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0280oooo0P00000m
07moO`8000008`3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0P0?oo
o`800000701oOgl9000001`0Ogmo0P00000Q0?ooo`030000003oool0oooo0080oooo000P0?ooo`03
0000003oool0oooo01l0oooo00<0000007moO`1oOgl05@1oOgl7000000T0Ogmo1`00000G07moO`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0
7@3oool2000001<0Ogmo1@00000G07moO`@00000501oOgl00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0080oooo000P0?ooo`030000003oool0oooo01`0oooo00<0000007moO`1oOgl0401o
Ogl300000200Ogmo0`00000B07moO`8000007@3oool00`000000oooo0?ooo`020?ooo`00803oool0
0`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00l0Ogmo0P00000V07moO`8000004P1oOgl0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo
01T0oooo0P00000@07moO`800000:P1oOgl200000140Ogmo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0H0?ooo`030000001oOgl0Ogmo00d0
Ogmo0`00000^07moO`<000003`1oOgl00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo000P0?ooo`030000003oool0oooo01H0oooo0P00000>07moO`800000=01oOgl2000000h0Ogmo
0P00000H0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo01D0oooo00<0
000007moO`1oOgl0301oOgl2000003P0Ogmo0P00000>07moO`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo03X0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo01<0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0l07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0C0?ooo`03
0000001oOgl0Ogmo00X0Ogmo0P00001007moO`800000301oOgl00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0180oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`1207moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0A0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl0A01oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo0140oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0403oool0
0`000000Ogmo07moO`0907moO`800000B01oOgl2000000/0Ogmo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo
00P0Ogmo00<0000007moO`1oOgl0BP1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool03`3oool00`000000
Ogmo07moO`0807moO`030000001oOgl0Ogmo04`0Ogmo00<0000007moO`1oOgl0201oOgl00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00h0oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`1>07moO`030000001oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?oo
o`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0CP1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00200oooo00<00000
0?ooo`3oool03@3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo0500Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000P0?oo
o`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`1B07mo
O`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`00803oool00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl0E01oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00200oooo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo05H0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl01`1o
Ogl00`000000Ogmo07moO`1H07moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`1oOgl0F01oOgl00`000000Ogmo07moO`0907moO`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool02@3oool00`00
0000Ogmo07moO`0707moO`030000001oOgl0Ogmo05X0Ogmo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00P0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`1L07moO`030000001oOgl0Ogmo00P0
Ogmo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo
0?ooo`080?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0GP1oOgl00`000000Ogmo
07moO`0707moO`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00200oooo00<0
00000?ooo`3oool01`3oool00`000000Ogmo07moO`0607moO`800000H@1oOgl00`000000Ogmo07mo
O`0607moO`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00200oooo00<00000
0?ooo`3oool01`3oool00`000000Ogmo07moO`0607moO`040000001oOgl00000000005d0Ogmo0`00
000907moO`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00200oooo00<00000
0?ooo`3oool01`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl0F@1oOgl01@000000Ogmo07moO`1oOgl0000000P0Ogmo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`060?ooo`030000001oOgl0
Ogmo00H0Ogmo00<0000007moO`1oOgl00`1oOgl2000005L0Ogmo0P00000407moO`030000001oOgl0
Ogmo00H0Ogmo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00803oool00`00
0000oooo0?ooo`060?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl01@1oOgl20000
05<0Ogmo0P00000707moO`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`050?ooo`030000001oOgl0Ogmo00H0
Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`1?07moO`030000001oOgl0Ogmo00L0
Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000P0?ooo`030000003oool0oooo00D0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo
07moO`0907moO`800000C@1oOgl2000000X0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0;07moO`800000B@1oOgl2000000d0Ogmo00<0
000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo000P
0?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0>
07moO`800000A@1oOgl2000000l0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00@0oooo00<0000007mo
O`1oOgl01P1oOgl00`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo0440Ogmo00<0000007mo
O`1oOgl0401oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00200oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0707moO`03
0000001oOgl0Ogmo0140Ogmo0P00000o07moO`8000004`1oOgl00`000000Ogmo07moO`0607moO`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0
0`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01@0Ogmo0P00000k07moO`800000
5P1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00200oooo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0707moO`030000001o
Ogl0Ogmo01H0Ogmo0P00000g07moO`800000601oOgl00`000000Ogmo07moO`0607moO`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool00P3oool0
0`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl0<`1oOgl0
0`000000Ogmo07moO`0H07moO`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo
00H0Ogmo00<0000007moO`1oOgl06P1oOgl200000340Ogmo0P00000L07moO`030000001oOgl0Ogmo
00D0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000
oooo0?ooo`020?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0701oOgl2000002d0
Ogmo0P00000N07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo00H0Ogmo
00<0000007moO`1oOgl07P1oOgl00`000000Ogmo07moO`0Y07moO`030000001oOgl0Ogmo01h0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
000P0?ooo`050000003oool0oooo0?ooo`0000002@1oOgl00`000000Ogmo07moO`0O07moO`800000
9`1oOgl200000240Ogmo00<0000007moO`1oOgl01P1oOgl01@000000oooo0?ooo`3oool0000000@0
oooo000P0?ooo`050000003oool0oooo0?ooo`0000002@1oOgl00`000000Ogmo07moO`0Q07moO`80
00008`1oOgl2000002<0Ogmo00<0000007moO`1oOgl01P1oOgl01@000000oooo0?ooo`3oool00000
00@0oooo000P0?ooo`050000003oool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0T07mo
O`8000007`1oOgl2000002H0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0
000000@0oooo000P0?ooo`050000003oool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0V
07moO`030000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl09P1oOgl00`000000Ogmo07moO`05
07moO`050000003oool0oooo0?ooo`000000103oool00200oooo00D000000?ooo`3oool0oooo0000
000807moO`030000001oOgl0Ogmo02L0Ogmo0P00000I07moO`800000:@1oOgl00`000000Ogmo07mo
O`0507moO`050000003oool0oooo0?ooo`000000103oool00200oooo00D000000?ooo`3oool0oooo
0000000807moO`030000001oOgl0Ogmo02T0Ogmo0P00000E07moO`800000:`1oOgl00`000000Ogmo
07moO`0507moO`050000003oool0oooo0?ooo`000000103oool00200oooo00D000000?ooo`3oool0
oooo0000000807moO`030000001oOgl0Ogmo02/0Ogmo0P00000A07moO`800000;@1oOgl00`000000
Ogmo07moO`0507moO`050000003oool0oooo0?ooo`000000103oool00200oooo00D000000?ooo`3o
ool0oooo0000000807moO`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl03@1oOgl00`00
0000Ogmo07moO`0]07moO`030000001oOgl0Ogmo00D0Ogmo00D000000?ooo`3oool0oooo00000004
0?ooo`00803oool01@000000oooo0?ooo`3oool0000000P0Ogmo00<0000007moO`1oOgl0;P1oOgl2
000000/0Ogmo0P00000`07moO`030000001oOgl0Ogmo00D0Ogmo00D000000?ooo`3oool0oooo0000
00040?ooo`00803oool010000000oooo0?ooo`00000807moO`030000001oOgl0Ogmo0340Ogmo0P00
000707moO`800000<`1oOgl00`000000Ogmo07moO`0507moO`040000003oool0oooo000000@0oooo
000P0?ooo`040000003oool0oooo000000P0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo03<0Ogmo00<0000007moO`1oOgl01@1oOgl010000000oooo
0?ooo`0000040?ooo`00803oool010000000oooo0?ooo`00000807moO`030000001oOgl0Ogmo03@0
Ogmo0P0000000`1oOgl000000000000f07moO`030000001oOgl0Ogmo00D0Ogmo00@000000?ooo`3o
ool00000103oool00200oooo00@000000?ooo`3oool00000201oOgl00`000000Ogmo07moO`0f07mo
O`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl01@1oOgl010000000oooo0?ooo`000004
0?ooo`00803oool010000000oooo0?ooo`00000807moO`030000001oOgl0Ogmo03H0Ogmo00<00000
07moO`1oOgl0=P1oOgl00`000000Ogmo07moO`0507moO`040000003oool0oooo000000@0oooo000P
0?ooo`040000003oool0oooo000000P0Ogmo00<0000007moO`1oOgl0=P1oOgl00`000000Ogmo07mo
O`0f07moO`030000001oOgl0Ogmo00D0Ogmo00@000000?ooo`3oool00000103oool00200oooo00@0
00000?ooo`3oool00000201oOgl00`000000Ogmo07moO`0f07moO`030000001oOgl0Ogmo03H0Ogmo
00<0000007moO`1oOgl01@1oOgl010000000oooo0?ooo`0000040?ooo`00803oool010000000oooo
0?ooo`00000807moO`030000001oOgl0Ogmo03H0Ogmo00<0000007moO`1oOgl0=P1oOgl00`000000
Ogmo07moO`0507moO`040000003oool0oooo000000@0oooo000P0?ooo`050000003oool0oooo0?oo
o`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03D0Ogmo00<0000007mo
O`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?ooo`050000003oool0oooo
0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03D0Ogmo00<00000
07moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?ooo`050000003oool0
oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03D0Ogmo00<0
000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?ooo`050000003o
ool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03D0Ogmo
00<0000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?ooo`050000
003oool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo03D0
Ogmo00<0000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?ooo`05
0000003oool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0Ogmo
03D0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P0?oo
o`050000003oool0oooo0?ooo`000000201oOgl00`000000Ogmo07moO`0e07moO`030000001oOgl0
Ogmo03D0Ogmo00<0000007moO`1oOgl01@1oOgl01@000000oooo0?ooo`3oool0000000@0oooo000P
0?ooo`050000003oool0oooo0?ooo`0000002@1oOgl00`000000Ogmo07moO`0d07moO`030000001o
Ogl0Ogmo03@0Ogmo00<0000007moO`1oOgl01P1oOgl01@000000oooo0?ooo`3oool0000000@0oooo
000P0?ooo`050000003oool0oooo0?ooo`0000002@1oOgl00`000000Ogmo07moO`0d07moO`030000
001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl01P1oOgl01@000000oooo0?ooo`3oool0000000@0
oooo000P0?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo
07moO`0d07moO`030000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<0
000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0d07moO`030000001oOgl0Ogmo03@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000P
0?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0d
07moO`030000001oOgl0Ogmo03@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<0000007mo
O`1oOgl01`1oOgl00`000000Ogmo07moO`0c07moO`030000001oOgl0Ogmo03<0Ogmo00<0000007mo
O`1oOgl01P1oOgl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000P0?ooo`03
0000003oool0oooo0080oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0c07moO`03
0000001oOgl0Ogmo03<0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
1P1oOgl00`000000Ogmo07moO`0c07moO`030000001oOgl0Ogmo0380Ogmo00<0000007moO`1oOgl0
1P1oOgl00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0b07moO`030000001o
Ogl0Ogmo0380Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo000P0?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0b07moO`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl01`1oOgl0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo
00@0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0a07moO`030000001oOgl0Ogmo
0340Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo000P0?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl01`1oOgl00`000000
Ogmo07moO`0a07moO`030000001oOgl0Ogmo0340Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00D0oooo
00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0a07moO`030000001oOgl0Ogmo0300Ogmo
00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
000P0?ooo`030000003oool0oooo00D0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07mo
O`0`07moO`030000001oOgl0Ogmo0300Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00H0oooo00<00000
07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0`07moO`030000001oOgl0Ogmo02l0Ogmo00<00000
07moO`1oOgl01`1oOgl00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000P0?oo
o`030000003oool0oooo00H0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0`07mo
O`030000001oOgl0Ogmo02l0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00L0oooo00<0000007moO`1o
Ogl01P1oOgl00`000000Ogmo07moO`0_07moO`030000001oOgl0Ogmo02h0Ogmo00<0000007moO`1o
Ogl01`1oOgl00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000P0?ooo`030000
003oool0oooo00L0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0_07moO`030000
001oOgl0Ogmo02h0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00L0oooo00<0000007moO`1oOgl01`1o
Ogl00`000000Ogmo07moO`0^07moO`030000001oOgl0Ogmo02d0Ogmo00<0000007moO`1oOgl01`1o
Ogl00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0
oooo00P0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0]07moO`030000001oOgl0
Ogmo02`0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000P0?ooo`030000003oool0oooo00P0oooo00<0000007moO`1oOgl0201oOgl00`00
0000Ogmo07moO`0/07moO`030000001oOgl0Ogmo02/0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0/07moO`030000001oOgl0Ogmo02/0
Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo000P0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo
07moO`0[07moO`030000001oOgl0Ogmo02X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00X0oooo00<0
000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0Z07moO`030000001oOgl0Ogmo02T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000P
0?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0Y
07moO`030000001oOgl0Ogmo02P0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00`0oooo00<0000007mo
O`1oOgl01`1oOgl00`000000Ogmo07moO`0Y07moO`030000001oOgl0Ogmo02P0Ogmo00<0000007mo
O`1oOgl0201oOgl00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000P0?ooo`03
0000003oool0oooo00`0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0X07moO`03
0000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo00d0oooo00<0000007moO`1oOgl0
201oOgl00`000000Ogmo07moO`0W07moO`030000001oOgl0Ogmo02H0Ogmo00<0000007moO`1oOgl0
201oOgl00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003o
ool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl2000002L0Ogmo00<0000007moO`1oOgl0901o
Ogl2000000X0Ogmo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00803oool0
0`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0901oOgl0
0`000000Ogmo07moO`0S07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl08`1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000
oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo00X0Ogmo0P00000S07moO`030000001oOgl0Ogmo0200
Ogmo0P00000<07moO`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00200oooo
00<000000?ooo`3oool04@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo0200Ogmo
00<0000007moO`1oOgl07`1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0140oooo
00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool04P3oool00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo01l0Ogmo00<0000007moO`1oOgl07P1oOgl00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00200oooo00<00000
0?ooo`3oool04`3oool2000000`0Ogmo0P00000O07moO`030000001oOgl0Ogmo01`0Ogmo0P00000<
07moO`8000005@3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0E0?oo
o`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0701oOgl00`000000Ogmo07moO`0K07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`00803oool00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl06`1oOgl00`000000Ogmo07moO`0J07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`030000
001oOgl0Ogmo00/0Ogmo0P00000K07moO`030000001oOgl0Ogmo01P0Ogmo0P00000=07moO`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0603o
ool2000000d0Ogmo0`00000H07moO`030000001oOgl0Ogmo01D0Ogmo0`00000>07moO`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool06P3oool0
0`000000Ogmo07moO`0=07moO`8000005P1oOgl00`000000Ogmo07moO`0C07moO`8000003`1oOgl2
000001/0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool06`3oool00`00
0000Ogmo07moO`0>07moO`800000501oOgl00`000000Ogmo07moO`0A07moO`800000401oOgl00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo01`0
oooo0P00000@07moO`<000004@1oOgl00`000000Ogmo07moO`0>07moO`<000004@1oOgl00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo01h0oooo
00<0000007moO`1oOgl0401oOgl2000000l0Ogmo00<0000007moO`1oOgl0301oOgl2000001<0Ogmo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?oo
o`0O0?ooo`030000001oOgl0Ogmo0140Ogmo1@00000:07moO`030000001oOgl0Ogmo00P0Ogmo1000
000D07moO`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00200oooo00<00000
0?ooo`3oool0803oool00`000000Ogmo07moO`0E07moO`L000000`1oOgl010000000Ogmo07moO`1o
Ogl7000001L0Ogmo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`00803oool0
0`000000oooo0?ooo`0Q0?ooo`800000701oOgl7000001`0Ogmo0P00000R0?ooo`030000003oool0
oooo0080oooo000P0?ooo`030000003oool0oooo02<0oooo0`00000i07moO`<00000903oool00`00
0000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0V0?ooo`<00000<`1oOgl3000002L0
oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool0:@3oool2000002l0Ogmo
0P00000Z0?ooo`030000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo02/0oooo0`00
000Y07moO`<00000;03oool00`000000oooo0?ooo`020?ooo`00803oool00`000000oooo0?ooo`0^
0?ooo`<000008`1oOgl3000002l0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?oo
o`3oool0<@3oool4000001/0Ogmo1000000b0?ooo`030000003oool0oooo0080oooo000P0?ooo`03
0000003oool0oooo03D0oooo1P00000?07moO`H00000=P3oool00`000000oooo0?ooo`020?ooo`00
803oool00`000000oooo0?ooo`0k0?ooo`D000001@1oOgl5000003`0oooo00<000000?ooo`3oool0
0P3oool00200oooo00<000000?ooo`3oool0@03oool500000440oooo00<000000?ooo`3oool00P3o
ool00200oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`020?ooo`00803ooon:0000
00@0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3o
ool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00[P3oool00:h0oooo002^0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 173}, {173, 0}} -> {-44.4427, -38.8434, 0.43916, \
0.43916}},
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->TopView,AspectRatio->1];", "Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238098 0.015873 0.5 0.015873 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.23441 .5 m
.26681 .89683 L
.59082 .5 L
.23441 .5 L
F
.23441 .5 m
.59082 .5 L
.26681 .10317 L
.23441 .5 L
F
.23441 .5 m
.26681 .10317 L
.02381 .40079 L
.23441 .5 L
F
.23441 .5 m
.02381 .40079 L
.02381 .59921 L
.23441 .5 L
F
.23441 .5 m
.02381 .59921 L
.26681 .89683 L
.23441 .5 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.59082 .5 m
.26681 .10317 L
.02381 .40079 L
.02381 .59921 L
.26681 .89683 L
.59082 .5 L
s
.5 g
.23441 .28175 m
.26681 .10317 L
.59082 .5 L
.23441 .28175 L
F
.23441 .28175 m
.59082 .5 L
.26681 .5 L
.23441 .28175 L
F
.23441 .28175 m
.26681 .5 L
.02381 .20238 L
.23441 .28175 L
F
.23441 .28175 m
.02381 .20238 L
.02381 .10317 L
.23441 .28175 L
F
.23441 .28175 m
.02381 .10317 L
.26681 .10317 L
.23441 .28175 L
F
0 g
.59082 .5 m
.26681 .5 L
.02381 .20238 L
.02381 .10317 L
.26681 .10317 L
.59082 .5 L
s
.5 g
.23441 .71825 m
.26681 .5 L
.59082 .5 L
.23441 .71825 L
F
.23441 .71825 m
.59082 .5 L
.26681 .89683 L
.23441 .71825 L
F
.23441 .71825 m
.26681 .89683 L
.02381 .89683 L
.23441 .71825 L
F
.23441 .71825 m
.02381 .89683 L
.02381 .79762 L
.23441 .71825 L
F
.23441 .71825 m
.02381 .79762 L
.26681 .5 L
.23441 .71825 L
F
0 g
.59082 .5 m
.26681 .89683 L
.02381 .89683 L
.02381 .79762 L
.26681 .5 L
.59082 .5 L
s
.5 g
.02381 .89683 m
.02381 .90706 L
.02381 .90357 L
.02381 .89343 L
.02381 .89683 L
F
.02381 .90706 m
.02381 .91729 L
.02381 .91372 L
.02381 .90357 L
.02381 .90706 L
F
.02381 .91729 m
.02381 .92752 L
.02381 .92386 L
.02381 .91372 L
.02381 .91729 L
F
.02381 .92752 m
.02381 .93775 L
.02381 .93401 L
.02381 .92386 L
.02381 .92752 L
F
.02381 .93775 m
.02381 .94798 L
.02381 .94415 L
.02381 .93401 L
.02381 .93775 L
F
.02381 .94798 m
.02381 .95821 L
.02381 .95429 L
.02381 .94415 L
.02381 .94798 L
F
.02381 .89343 m
.02381 .90357 L
.02381 .89319 L
.02381 .8833 L
.02381 .89343 L
F
.02381 .90357 m
.02381 .91372 L
.02381 .90307 L
.02381 .89319 L
.02381 .90357 L
F
.02381 .91372 m
.02381 .92386 L
.02381 .91295 L
.02381 .90307 L
.02381 .91372 L
F
.02381 .92386 m
.02381 .93401 L
.02381 .92284 L
.02381 .91295 L
.02381 .92386 L
F
.02381 .93401 m
.02381 .94415 L
.02381 .93272 L
.02381 .92284 L
.02381 .93401 L
F
.02381 .94415 m
.02381 .95429 L
.02381 .9426 L
.02381 .93272 L
.02381 .94415 L
F
.02381 .8833 m
.02381 .89319 L
.02381 .87607 L
.02381 .86662 L
.02381 .8833 L
F
.02381 .89319 m
.02381 .90307 L
.02381 .88552 L
.02381 .87607 L
.02381 .89319 L
F
.02381 .90307 m
.02381 .91295 L
.02381 .89498 L
.02381 .88552 L
.02381 .90307 L
F
.02381 .91295 m
.02381 .92284 L
.02381 .90443 L
.02381 .89498 L
.02381 .91295 L
F
.02381 .92284 m
.02381 .93272 L
.02381 .91388 L
.02381 .90443 L
.02381 .92284 L
F
.02381 .93272 m
.02381 .9426 L
.02381 .92333 L
.02381 .91388 L
.02381 .93272 L
F
.02381 .86662 m
.02381 .87607 L
.02381 .85252 L
.02381 .84366 L
.02381 .86662 L
F
.02381 .87607 m
.02381 .88552 L
.02381 .86138 L
.02381 .85252 L
.02381 .87607 L
F
.02381 .88552 m
.02381 .89498 L
.02381 .87024 L
.02381 .86138 L
.02381 .88552 L
F
.02381 .89498 m
.02381 .90443 L
.02381 .8791 L
.02381 .87024 L
.02381 .89498 L
F
.02381 .90443 m
.02381 .91388 L
.02381 .88796 L
.02381 .8791 L
.02381 .90443 L
F
.02381 .91388 m
.02381 .92333 L
.02381 .89683 L
.02381 .88796 L
.02381 .91388 L
F
.02381 .84366 m
.02381 .85252 L
.02381 .82294 L
.02381 .81482 L
.02381 .84366 L
F
.02381 .85252 m
.02381 .86138 L
.02381 .83106 L
.02381 .82294 L
.02381 .85252 L
F
.02381 .86138 m
.02381 .87024 L
.02381 .83917 L
.02381 .83106 L
.02381 .86138 L
F
.02381 .87024 m
.02381 .8791 L
.02381 .84729 L
.02381 .83917 L
.02381 .87024 L
F
.02381 .8791 m
.02381 .88796 L
.02381 .85541 L
.02381 .84729 L
.02381 .8791 L
F
.02381 .88796 m
.02381 .89683 L
.02381 .86353 L
.02381 .85541 L
.02381 .88796 L
F
.02381 .81482 m
.02381 .82294 L
.02381 .78783 L
.02381 .7806 L
.02381 .81482 L
F
.02381 .82294 m
.02381 .83106 L
.02381 .79507 L
.02381 .78783 L
.02381 .82294 L
F
.02381 .83106 m
.02381 .83917 L
.02381 .8023 L
.02381 .79507 L
.02381 .83106 L
F
.02381 .83917 m
.02381 .84729 L
.02381 .80954 L
.02381 .8023 L
.02381 .83917 L
F
.02381 .84729 m
.02381 .85541 L
.02381 .81677 L
.02381 .80954 L
.02381 .84729 L
F
.02381 .85541 m
.02381 .86353 L
.02381 .82401 L
.02381 .81677 L
.02381 .85541 L
F
.02381 .7806 m
.02381 .78783 L
.02381 .7478 L
.02381 .74157 L
.02381 .7806 L
F
.02381 .78783 m
.02381 .79507 L
.02381 .75403 L
.02381 .7478 L
.02381 .78783 L
F
.02381 .79507 m
.02381 .8023 L
.02381 .76026 L
.02381 .75403 L
.02381 .79507 L
F
.02381 .8023 m
.02381 .80954 L
.02381 .76649 L
.02381 .76026 L
.02381 .8023 L
F
.02381 .80954 m
.02381 .81677 L
.02381 .77271 L
.02381 .76649 L
.02381 .80954 L
F
.02381 .81677 m
.02381 .82401 L
.02381 .77894 L
.02381 .77271 L
.02381 .81677 L
F
.02381 .74157 m
.02381 .7478 L
.02381 .70353 L
.02381 .69841 L
.02381 .74157 L
F
.02381 .7478 m
.02381 .75403 L
.02381 .70864 L
.02381 .70353 L
.02381 .7478 L
F
.02381 .75403 m
.02381 .76026 L
.02381 .71376 L
.02381 .70864 L
.02381 .75403 L
F
.02381 .76026 m
.02381 .76649 L
.02381 .71888 L
.02381 .71376 L
.02381 .76026 L
F
.02381 .76649 m
.02381 .77271 L
.02381 .72399 L
.02381 .71888 L
.02381 .76649 L
F
.02381 .77271 m
.02381 .77894 L
.02381 .72911 L
.02381 .72399 L
.02381 .77271 L
F
.02381 .69841 m
.02381 .70353 L
.02381 .65577 L
.02381 .65186 L
.02381 .69841 L
F
.02381 .70353 m
.02381 .70864 L
.02381 .65969 L
.02381 .65577 L
.02381 .70353 L
F
.02381 .70864 m
.02381 .71376 L
.02381 .6636 L
.02381 .65969 L
.02381 .70864 L
F
.02381 .71376 m
.02381 .71888 L
.02381 .66752 L
.02381 .6636 L
.02381 .71376 L
F
.02381 .71888 m
.02381 .72399 L
.02381 .67144 L
.02381 .66752 L
.02381 .71888 L
F
.02381 .72399 m
.02381 .72911 L
.02381 .67535 L
.02381 .67144 L
.02381 .72399 L
F
.02381 .65186 m
.02381 .65577 L
.02381 .60535 L
.02381 .60271 L
.02381 .65186 L
F
.02381 .65577 m
.02381 .65969 L
.02381 .608 L
.02381 .60535 L
.02381 .65577 L
F
.02381 .65969 m
.02381 .6636 L
.02381 .61065 L
.02381 .608 L
.02381 .65969 L
F
.02381 .6636 m
.02381 .66752 L
.02381 .6133 L
.02381 .61065 L
.02381 .6636 L
F
.02381 .66752 m
.02381 .67144 L
.02381 .61595 L
.02381 .6133 L
.02381 .66752 L
F
.02381 .67144 m
.02381 .67535 L
.02381 .61859 L
.02381 .61595 L
.02381 .67144 L
F
.02381 .60271 m
.02381 .60535 L
.02381 .55313 L
.02381 .5518 L
.02381 .60271 L
F
.02381 .60535 m
.02381 .608 L
.02381 .55447 L
.02381 .55313 L
.02381 .60535 L
F
.02381 .608 m
.02381 .61065 L
.02381 .5558 L
.02381 .55447 L
.02381 .608 L
F
.02381 .61065 m
.02381 .6133 L
.02381 .55714 L
.02381 .5558 L
.02381 .61065 L
F
.02381 .6133 m
.02381 .61595 L
.02381 .55847 L
.02381 .55714 L
.02381 .6133 L
F
.02381 .61595 m
.02381 .61859 L
.02381 .55981 L
.02381 .55847 L
.02381 .61595 L
F
.02381 .5518 m
.02381 .55313 L
.02381 .5 L
.02381 .5 L
.02381 .5518 L
F
.02381 .55313 m
.02381 .55447 L
.02381 .5 L
.02381 .5 L
.02381 .55313 L
F
.02381 .55447 m
.02381 .5558 L
.02381 .5 L
.02381 .5 L
.02381 .55447 L
F
.02381 .5558 m
.02381 .55714 L
.02381 .5 L
.02381 .5 L
.02381 .5558 L
F
.02381 .55714 m
.02381 .55847 L
.02381 .5 L
.02381 .5 L
.02381 .55714 L
F
.02381 .55847 m
.02381 .55981 L
.02381 .5 L
.02381 .5 L
.02381 .55847 L
F
.02381 .5 m
.02381 .5 L
.02381 .44687 L
.02381 .4482 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .44553 L
.02381 .44687 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .4442 L
.02381 .44553 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .44286 L
.02381 .4442 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .44153 L
.02381 .44286 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .44019 L
.02381 .44153 L
.02381 .5 L
F
.02381 .4482 m
.02381 .44687 L
.02381 .39465 L
.02381 .39729 L
.02381 .4482 L
F
.02381 .44687 m
.02381 .44553 L
.02381 .392 L
.02381 .39465 L
.02381 .44687 L
F
.02381 .44553 m
.02381 .4442 L
.02381 .38935 L
.02381 .392 L
.02381 .44553 L
F
.02381 .4442 m
.02381 .44286 L
.02381 .3867 L
.02381 .38935 L
.02381 .4442 L
F
.02381 .44286 m
.02381 .44153 L
.02381 .38405 L
.02381 .3867 L
.02381 .44286 L
F
.02381 .44153 m
.02381 .44019 L
.02381 .38141 L
.02381 .38405 L
.02381 .44153 L
F
.02381 .39729 m
.02381 .39465 L
.02381 .34423 L
.02381 .34814 L
.02381 .39729 L
F
.02381 .39465 m
.02381 .392 L
.02381 .34031 L
.02381 .34423 L
.02381 .39465 L
F
.02381 .392 m
.02381 .38935 L
.02381 .3364 L
.02381 .34031 L
.02381 .392 L
F
.02381 .38935 m
.02381 .3867 L
.02381 .33248 L
.02381 .3364 L
.02381 .38935 L
F
.02381 .3867 m
.02381 .38405 L
.02381 .32856 L
.02381 .33248 L
.02381 .3867 L
F
.02381 .38405 m
.02381 .38141 L
.02381 .32465 L
.02381 .32856 L
.02381 .38405 L
F
.02381 .34814 m
.02381 .34423 L
.02381 .29647 L
.02381 .30159 L
.02381 .34814 L
F
.02381 .34423 m
.02381 .34031 L
.02381 .29136 L
.02381 .29647 L
.02381 .34423 L
F
.02381 .34031 m
.02381 .3364 L
.02381 .28624 L
.02381 .29136 L
.02381 .34031 L
F
.02381 .3364 m
.02381 .33248 L
.02381 .28112 L
.02381 .28624 L
.02381 .3364 L
F
.02381 .33248 m
.02381 .32856 L
.02381 .27601 L
.02381 .28112 L
.02381 .33248 L
F
.02381 .32856 m
.02381 .32465 L
.02381 .27089 L
.02381 .27601 L
.02381 .32856 L
F
.02381 .30159 m
.02381 .29647 L
.02381 .2522 L
.02381 .25843 L
.02381 .30159 L
F
.02381 .29647 m
.02381 .29136 L
.02381 .24597 L
.02381 .2522 L
.02381 .29647 L
F
.02381 .29136 m
.02381 .28624 L
.02381 .23974 L
.02381 .24597 L
.02381 .29136 L
F
.02381 .28624 m
.02381 .28112 L
.02381 .23351 L
.02381 .23974 L
.02381 .28624 L
F
.02381 .28112 m
.02381 .27601 L
.02381 .22729 L
.02381 .23351 L
.02381 .28112 L
F
.02381 .27601 m
.02381 .27089 L
.02381 .22106 L
.02381 .22729 L
.02381 .27601 L
F
.02381 .25843 m
.02381 .2522 L
.02381 .21217 L
.02381 .2194 L
.02381 .25843 L
F
.02381 .2522 m
.02381 .24597 L
.02381 .20493 L
.02381 .21217 L
.02381 .2522 L
F
.02381 .24597 m
.02381 .23974 L
.02381 .1977 L
.02381 .20493 L
.02381 .24597 L
F
.02381 .23974 m
.02381 .23351 L
.02381 .19046 L
.02381 .1977 L
.02381 .23974 L
F
.02381 .23351 m
.02381 .22729 L
.02381 .18323 L
.02381 .19046 L
.02381 .23351 L
F
.02381 .22729 m
.02381 .22106 L
.02381 .17599 L
.02381 .18323 L
.02381 .22729 L
F
.02381 .2194 m
.02381 .21217 L
.02381 .17706 L
.02381 .18518 L
.02381 .2194 L
F
.02381 .21217 m
.02381 .20493 L
.02381 .16894 L
.02381 .17706 L
.02381 .21217 L
F
.02381 .20493 m
.02381 .1977 L
.02381 .16083 L
.02381 .16894 L
.02381 .20493 L
F
.02381 .1977 m
.02381 .19046 L
.02381 .15271 L
.02381 .16083 L
.02381 .1977 L
F
.02381 .19046 m
.02381 .18323 L
.02381 .14459 L
.02381 .15271 L
.02381 .19046 L
F
.02381 .18323 m
.02381 .17599 L
.02381 .13647 L
.02381 .14459 L
.02381 .18323 L
F
.02381 .18518 m
.02381 .17706 L
.02381 .14748 L
.02381 .15634 L
.02381 .18518 L
F
.02381 .17706 m
.02381 .16894 L
.02381 .13862 L
.02381 .14748 L
.02381 .17706 L
F
.02381 .16894 m
.02381 .16083 L
.02381 .12976 L
.02381 .13862 L
.02381 .16894 L
F
.02381 .16083 m
.02381 .15271 L
.02381 .1209 L
.02381 .12976 L
.02381 .16083 L
F
.02381 .15271 m
.02381 .14459 L
.02381 .11204 L
.02381 .1209 L
.02381 .15271 L
F
.02381 .14459 m
.02381 .13647 L
.02381 .10317 L
.02381 .11204 L
.02381 .14459 L
F
.02381 .15634 m
.02381 .14748 L
.02381 .12393 L
.02381 .13338 L
.02381 .15634 L
F
.02381 .14748 m
.02381 .13862 L
.02381 .11448 L
.02381 .12393 L
.02381 .14748 L
F
.02381 .13862 m
.02381 .12976 L
.02381 .10502 L
.02381 .11448 L
.02381 .13862 L
F
.02381 .12976 m
.02381 .1209 L
.02381 .09557 L
.02381 .10502 L
.02381 .12976 L
F
.02381 .1209 m
.02381 .11204 L
.02381 .08612 L
.02381 .09557 L
.02381 .1209 L
F
.02381 .11204 m
.02381 .10317 L
.02381 .07667 L
.02381 .08612 L
.02381 .11204 L
F
.02381 .13338 m
.02381 .12393 L
.02381 .10681 L
.02381 .1167 L
.02381 .13338 L
F
.02381 .12393 m
.02381 .11448 L
.02381 .09693 L
.02381 .10681 L
.02381 .12393 L
F
.02381 .11448 m
.02381 .10502 L
.02381 .08705 L
.02381 .09693 L
.02381 .11448 L
F
.02381 .10502 m
.02381 .09557 L
.02381 .07716 L
.02381 .08705 L
.02381 .10502 L
F
.02381 .09557 m
.02381 .08612 L
.02381 .06728 L
.02381 .07716 L
.02381 .09557 L
F
.02381 .08612 m
.02381 .07667 L
.02381 .0574 L
.02381 .06728 L
.02381 .08612 L
F
.02381 .1167 m
.02381 .10681 L
.02381 .09643 L
.02381 .10657 L
.02381 .1167 L
F
.02381 .10681 m
.02381 .09693 L
.02381 .08628 L
.02381 .09643 L
.02381 .10681 L
F
.02381 .09693 m
.02381 .08705 L
.02381 .07614 L
.02381 .08628 L
.02381 .09693 L
F
.02381 .08705 m
.02381 .07716 L
.02381 .06599 L
.02381 .07614 L
.02381 .08705 L
F
.02381 .07716 m
.02381 .06728 L
.02381 .05585 L
.02381 .06599 L
.02381 .07716 L
F
.02381 .06728 m
.02381 .0574 L
.02381 .04571 L
.02381 .05585 L
.02381 .06728 L
F
.02381 .10657 m
.02381 .09643 L
.02381 .09294 L
.02381 .10317 L
.02381 .10657 L
F
.02381 .09643 m
.02381 .08628 L
.02381 .08271 L
.02381 .09294 L
.02381 .09643 L
F
.02381 .08628 m
.02381 .07614 L
.02381 .07248 L
.02381 .08271 L
.02381 .08628 L
F
.02381 .07614 m
.02381 .06599 L
.02381 .06225 L
.02381 .07248 L
.02381 .07614 L
F
.02381 .06599 m
.02381 .05585 L
.02381 .05202 L
.02381 .06225 L
.02381 .06599 L
F
.02381 .05585 m
.02381 .04571 L
.02381 .04179 L
.02381 .05202 L
.02381 .05585 L
F
.02381 .10317 m
.02381 .09294 L
.02381 .09643 L
.02381 .10657 L
.02381 .10317 L
F
.02381 .09294 m
.02381 .08271 L
.02381 .08628 L
.02381 .09643 L
.02381 .09294 L
F
.02381 .08271 m
.02381 .07248 L
.02381 .07614 L
.02381 .08628 L
.02381 .08271 L
F
.02381 .07248 m
.02381 .06225 L
.02381 .06599 L
.02381 .07614 L
.02381 .07248 L
F
.02381 .06225 m
.02381 .05202 L
.02381 .05585 L
.02381 .06599 L
.02381 .06225 L
F
.02381 .05202 m
.02381 .04179 L
.02381 .04571 L
.02381 .05585 L
.02381 .05202 L
F
.02381 .10657 m
.02381 .09643 L
.02381 .10681 L
.02381 .1167 L
.02381 .10657 L
F
.02381 .09643 m
.02381 .08628 L
.02381 .09693 L
.02381 .10681 L
.02381 .09643 L
F
.02381 .08628 m
.02381 .07614 L
.02381 .08705 L
.02381 .09693 L
.02381 .08628 L
F
.02381 .07614 m
.02381 .06599 L
.02381 .07716 L
.02381 .08705 L
.02381 .07614 L
F
.02381 .06599 m
.02381 .05585 L
.02381 .06728 L
.02381 .07716 L
.02381 .06599 L
F
.02381 .05585 m
.02381 .04571 L
.02381 .0574 L
.02381 .06728 L
.02381 .05585 L
F
.02381 .1167 m
.02381 .10681 L
.02381 .12393 L
.02381 .13338 L
.02381 .1167 L
F
.02381 .10681 m
.02381 .09693 L
.02381 .11448 L
.02381 .12393 L
.02381 .10681 L
F
.02381 .09693 m
.02381 .08705 L
.02381 .10502 L
.02381 .11448 L
.02381 .09693 L
F
.02381 .08705 m
.02381 .07716 L
.02381 .09557 L
.02381 .10502 L
.02381 .08705 L
F
.02381 .07716 m
.02381 .06728 L
.02381 .08612 L
.02381 .09557 L
.02381 .07716 L
F
.02381 .06728 m
.02381 .0574 L
.02381 .07667 L
.02381 .08612 L
.02381 .06728 L
F
.02381 .13338 m
.02381 .12393 L
.02381 .14748 L
.02381 .15634 L
.02381 .13338 L
F
.02381 .12393 m
.02381 .11448 L
.02381 .13862 L
.02381 .14748 L
.02381 .12393 L
F
.02381 .11448 m
.02381 .10502 L
.02381 .12976 L
.02381 .13862 L
.02381 .11448 L
F
.02381 .10502 m
.02381 .09557 L
.02381 .1209 L
.02381 .12976 L
.02381 .10502 L
F
.02381 .09557 m
.02381 .08612 L
.02381 .11204 L
.02381 .1209 L
.02381 .09557 L
F
.02381 .08612 m
.02381 .07667 L
.02381 .10317 L
.02381 .11204 L
.02381 .08612 L
F
.02381 .15634 m
.02381 .14748 L
.02381 .17706 L
.02381 .18518 L
.02381 .15634 L
F
.02381 .14748 m
.02381 .13862 L
.02381 .16894 L
.02381 .17706 L
.02381 .14748 L
F
.02381 .13862 m
.02381 .12976 L
.02381 .16083 L
.02381 .16894 L
.02381 .13862 L
F
.02381 .12976 m
.02381 .1209 L
.02381 .15271 L
.02381 .16083 L
.02381 .12976 L
F
.02381 .1209 m
.02381 .11204 L
.02381 .14459 L
.02381 .15271 L
.02381 .1209 L
F
.02381 .11204 m
.02381 .10317 L
.02381 .13647 L
.02381 .14459 L
.02381 .11204 L
F
.02381 .18518 m
.02381 .17706 L
.02381 .21217 L
.02381 .2194 L
.02381 .18518 L
F
.02381 .17706 m
.02381 .16894 L
.02381 .20493 L
.02381 .21217 L
.02381 .17706 L
F
.02381 .16894 m
.02381 .16083 L
.02381 .1977 L
.02381 .20493 L
.02381 .16894 L
F
.02381 .16083 m
.02381 .15271 L
.02381 .19046 L
.02381 .1977 L
.02381 .16083 L
F
.02381 .15271 m
.02381 .14459 L
.02381 .18323 L
.02381 .19046 L
.02381 .15271 L
F
.02381 .14459 m
.02381 .13647 L
.02381 .17599 L
.02381 .18323 L
.02381 .14459 L
F
.02381 .2194 m
.02381 .21217 L
.02381 .2522 L
.02381 .25843 L
.02381 .2194 L
F
.02381 .21217 m
.02381 .20493 L
.02381 .24597 L
.02381 .2522 L
.02381 .21217 L
F
.02381 .20493 m
.02381 .1977 L
.02381 .23974 L
.02381 .24597 L
.02381 .20493 L
F
.02381 .1977 m
.02381 .19046 L
.02381 .23351 L
.02381 .23974 L
.02381 .1977 L
F
.02381 .19046 m
.02381 .18323 L
.02381 .22729 L
.02381 .23351 L
.02381 .19046 L
F
.02381 .18323 m
.02381 .17599 L
.02381 .22106 L
.02381 .22729 L
.02381 .18323 L
F
.02381 .25843 m
.02381 .2522 L
.02381 .29647 L
.02381 .30159 L
.02381 .25843 L
F
.02381 .2522 m
.02381 .24597 L
.02381 .29136 L
.02381 .29647 L
.02381 .2522 L
F
.02381 .24597 m
.02381 .23974 L
.02381 .28624 L
.02381 .29136 L
.02381 .24597 L
F
.02381 .23974 m
.02381 .23351 L
.02381 .28112 L
.02381 .28624 L
.02381 .23974 L
F
.02381 .23351 m
.02381 .22729 L
.02381 .27601 L
.02381 .28112 L
.02381 .23351 L
F
.02381 .22729 m
.02381 .22106 L
.02381 .27089 L
.02381 .27601 L
.02381 .22729 L
F
.02381 .30159 m
.02381 .29647 L
.02381 .34423 L
.02381 .34814 L
.02381 .30159 L
F
.02381 .29647 m
.02381 .29136 L
.02381 .34031 L
.02381 .34423 L
.02381 .29647 L
F
.02381 .29136 m
.02381 .28624 L
.02381 .3364 L
.02381 .34031 L
.02381 .29136 L
F
.02381 .28624 m
.02381 .28112 L
.02381 .33248 L
.02381 .3364 L
.02381 .28624 L
F
.02381 .28112 m
.02381 .27601 L
.02381 .32856 L
.02381 .33248 L
.02381 .28112 L
F
.02381 .27601 m
.02381 .27089 L
.02381 .32465 L
.02381 .32856 L
.02381 .27601 L
F
.02381 .34814 m
.02381 .34423 L
.02381 .39465 L
.02381 .39729 L
.02381 .34814 L
F
.02381 .34423 m
.02381 .34031 L
.02381 .392 L
.02381 .39465 L
.02381 .34423 L
F
.02381 .34031 m
.02381 .3364 L
.02381 .38935 L
.02381 .392 L
.02381 .34031 L
F
.02381 .3364 m
.02381 .33248 L
.02381 .3867 L
.02381 .38935 L
.02381 .3364 L
F
.02381 .33248 m
.02381 .32856 L
.02381 .38405 L
.02381 .3867 L
.02381 .33248 L
F
.02381 .32856 m
.02381 .32465 L
.02381 .38141 L
.02381 .38405 L
.02381 .32856 L
F
.02381 .39729 m
.02381 .39465 L
.02381 .44687 L
.02381 .4482 L
.02381 .39729 L
F
.02381 .39465 m
.02381 .392 L
.02381 .44553 L
.02381 .44687 L
.02381 .39465 L
F
.02381 .392 m
.02381 .38935 L
.02381 .4442 L
.02381 .44553 L
.02381 .392 L
F
.02381 .38935 m
.02381 .3867 L
.02381 .44286 L
.02381 .4442 L
.02381 .38935 L
F
.02381 .3867 m
.02381 .38405 L
.02381 .44153 L
.02381 .44286 L
.02381 .3867 L
F
.02381 .38405 m
.02381 .38141 L
.02381 .44019 L
.02381 .44153 L
.02381 .38405 L
F
.02381 .4482 m
.02381 .44687 L
.02381 .5 L
.02381 .5 L
.02381 .4482 L
F
.02381 .44687 m
.02381 .44553 L
.02381 .5 L
.02381 .5 L
.02381 .44687 L
F
.02381 .44553 m
.02381 .4442 L
.02381 .5 L
.02381 .5 L
.02381 .44553 L
F
.02381 .4442 m
.02381 .44286 L
.02381 .5 L
.02381 .5 L
.02381 .4442 L
F
.02381 .44286 m
.02381 .44153 L
.02381 .5 L
.02381 .5 L
.02381 .44286 L
F
.02381 .44153 m
.02381 .44019 L
.02381 .5 L
.02381 .5 L
.02381 .44153 L
F
.02381 .5 m
.02381 .5 L
.02381 .55313 L
.02381 .5518 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .55447 L
.02381 .55313 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .5558 L
.02381 .55447 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .55714 L
.02381 .5558 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .55847 L
.02381 .55714 L
.02381 .5 L
F
.02381 .5 m
.02381 .5 L
.02381 .55981 L
.02381 .55847 L
.02381 .5 L
F
.02381 .5518 m
.02381 .55313 L
.02381 .60535 L
.02381 .60271 L
.02381 .5518 L
F
.02381 .55313 m
.02381 .55447 L
.02381 .608 L
.02381 .60535 L
.02381 .55313 L
F
.02381 .55447 m
.02381 .5558 L
.02381 .61065 L
.02381 .608 L
.02381 .55447 L
F
.02381 .5558 m
.02381 .55714 L
.02381 .6133 L
.02381 .61065 L
.02381 .5558 L
F
.02381 .55714 m
.02381 .55847 L
.02381 .61595 L
.02381 .6133 L
.02381 .55714 L
F
.02381 .55847 m
.02381 .55981 L
.02381 .61859 L
.02381 .61595 L
.02381 .55847 L
F
.02381 .60271 m
.02381 .60535 L
.02381 .65577 L
.02381 .65186 L
.02381 .60271 L
F
.02381 .60535 m
.02381 .608 L
.02381 .65969 L
.02381 .65577 L
.02381 .60535 L
F
.02381 .608 m
.02381 .61065 L
.02381 .6636 L
.02381 .65969 L
.02381 .608 L
F
.02381 .61065 m
.02381 .6133 L
.02381 .66752 L
.02381 .6636 L
.02381 .61065 L
F
.02381 .6133 m
.02381 .61595 L
.02381 .67144 L
.02381 .66752 L
.02381 .6133 L
F
.02381 .61595 m
.02381 .61859 L
.02381 .67535 L
.02381 .67144 L
.02381 .61595 L
F
.02381 .65186 m
.02381 .65577 L
.02381 .70353 L
.02381 .69841 L
.02381 .65186 L
F
.02381 .65577 m
.02381 .65969 L
.02381 .70864 L
.02381 .70353 L
.02381 .65577 L
F
.02381 .65969 m
.02381 .6636 L
.02381 .71376 L
.02381 .70864 L
.02381 .65969 L
F
.02381 .6636 m
.02381 .66752 L
.02381 .71888 L
.02381 .71376 L
.02381 .6636 L
F
.02381 .66752 m
.02381 .67144 L
.02381 .72399 L
.02381 .71888 L
.02381 .66752 L
F
.02381 .67144 m
.02381 .67535 L
.02381 .72911 L
.02381 .72399 L
.02381 .67144 L
F
.02381 .69841 m
.02381 .70353 L
.02381 .7478 L
.02381 .74157 L
.02381 .69841 L
F
.02381 .70353 m
.02381 .70864 L
.02381 .75403 L
.02381 .7478 L
.02381 .70353 L
F
.02381 .70864 m
.02381 .71376 L
.02381 .76026 L
.02381 .75403 L
.02381 .70864 L
F
.02381 .71376 m
.02381 .71888 L
.02381 .76649 L
.02381 .76026 L
.02381 .71376 L
F
.02381 .71888 m
.02381 .72399 L
.02381 .77271 L
.02381 .76649 L
.02381 .71888 L
F
.02381 .72399 m
.02381 .72911 L
.02381 .77894 L
.02381 .77271 L
.02381 .72399 L
F
.02381 .74157 m
.02381 .7478 L
.02381 .78783 L
.02381 .7806 L
.02381 .74157 L
F
.02381 .7478 m
.02381 .75403 L
.02381 .79507 L
.02381 .78783 L
.02381 .7478 L
F
.02381 .75403 m
.02381 .76026 L
.02381 .8023 L
.02381 .79507 L
.02381 .75403 L
F
.02381 .76026 m
.02381 .76649 L
.02381 .80954 L
.02381 .8023 L
.02381 .76026 L
F
.02381 .76649 m
.02381 .77271 L
.02381 .81677 L
.02381 .80954 L
.02381 .76649 L
F
.02381 .77271 m
.02381 .77894 L
.02381 .82401 L
.02381 .81677 L
.02381 .77271 L
F
.02381 .7806 m
.02381 .78783 L
.02381 .82294 L
.02381 .81482 L
.02381 .7806 L
F
.02381 .78783 m
.02381 .79507 L
.02381 .83106 L
.02381 .82294 L
.02381 .78783 L
F
.02381 .79507 m
.02381 .8023 L
.02381 .83917 L
.02381 .83106 L
.02381 .79507 L
F
.02381 .8023 m
.02381 .80954 L
.02381 .84729 L
.02381 .83917 L
.02381 .8023 L
F
.02381 .80954 m
.02381 .81677 L
.02381 .85541 L
.02381 .84729 L
.02381 .80954 L
F
.02381 .81677 m
.02381 .82401 L
.02381 .86353 L
.02381 .85541 L
.02381 .81677 L
F
.02381 .81482 m
.02381 .82294 L
.02381 .85252 L
.02381 .84366 L
.02381 .81482 L
F
.02381 .82294 m
.02381 .83106 L
.02381 .86138 L
.02381 .85252 L
.02381 .82294 L
F
.02381 .83106 m
.02381 .83917 L
.02381 .87024 L
.02381 .86138 L
.02381 .83106 L
F
.02381 .83917 m
.02381 .84729 L
.02381 .8791 L
.02381 .87024 L
.02381 .83917 L
F
.02381 .84729 m
.02381 .85541 L
.02381 .88796 L
.02381 .8791 L
.02381 .84729 L
F
.02381 .85541 m
.02381 .86353 L
.02381 .89683 L
.02381 .88796 L
.02381 .85541 L
F
.02381 .84366 m
.02381 .85252 L
.02381 .87607 L
.02381 .86662 L
.02381 .84366 L
F
.02381 .85252 m
.02381 .86138 L
.02381 .88552 L
.02381 .87607 L
.02381 .85252 L
F
.02381 .86138 m
.02381 .87024 L
.02381 .89498 L
.02381 .88552 L
.02381 .86138 L
F
.02381 .87024 m
.02381 .8791 L
.02381 .90443 L
.02381 .89498 L
.02381 .87024 L
F
.02381 .8791 m
.02381 .88796 L
.02381 .91388 L
.02381 .90443 L
.02381 .8791 L
F
.02381 .88796 m
.02381 .89683 L
.02381 .92333 L
.02381 .91388 L
.02381 .88796 L
F
.02381 .86662 m
.02381 .87607 L
.02381 .89319 L
.02381 .8833 L
.02381 .86662 L
F
.02381 .87607 m
.02381 .88552 L
.02381 .90307 L
.02381 .89319 L
.02381 .87607 L
F
.02381 .88552 m
.02381 .89498 L
.02381 .91295 L
.02381 .90307 L
.02381 .88552 L
F
.02381 .89498 m
.02381 .90443 L
.02381 .92284 L
.02381 .91295 L
.02381 .89498 L
F
.02381 .90443 m
.02381 .91388 L
.02381 .93272 L
.02381 .92284 L
.02381 .90443 L
F
.02381 .91388 m
.02381 .92333 L
.02381 .9426 L
.02381 .93272 L
.02381 .91388 L
F
.02381 .8833 m
.02381 .89319 L
.02381 .90357 L
.02381 .89343 L
.02381 .8833 L
F
.02381 .89319 m
.02381 .90307 L
.02381 .91372 L
.02381 .90357 L
.02381 .89319 L
F
.02381 .90307 m
.02381 .91295 L
.02381 .92386 L
.02381 .91372 L
.02381 .90307 L
F
.02381 .91295 m
.02381 .92284 L
.02381 .93401 L
.02381 .92386 L
.02381 .91295 L
F
.02381 .92284 m
.02381 .93272 L
.02381 .94415 L
.02381 .93401 L
.02381 .92284 L
F
.02381 .93272 m
.02381 .9426 L
.02381 .95429 L
.02381 .94415 L
.02381 .93272 L
F
.02381 .89343 m
.02381 .90357 L
.02381 .90706 L
.02381 .89683 L
.02381 .89343 L
F
.02381 .90357 m
.02381 .91372 L
.02381 .91729 L
.02381 .90706 L
.02381 .90357 L
F
.02381 .91372 m
.02381 .92386 L
.02381 .92752 L
.02381 .91729 L
.02381 .91372 L
F
.02381 .92386 m
.02381 .93401 L
.02381 .93775 L
.02381 .92752 L
.02381 .92386 L
F
.02381 .93401 m
.02381 .94415 L
.02381 .94798 L
.02381 .93775 L
.02381 .93401 L
F
.02381 .94415 m
.02381 .95429 L
.02381 .95821 L
.02381 .94798 L
.02381 .94415 L
F
0 g
.02381 .89683 m
.02381 .89343 L
.02381 .8833 L
.02381 .86662 L
.02381 .84366 L
.02381 .81482 L
.02381 .7806 L
.02381 .74157 L
.02381 .69841 L
.02381 .65186 L
.02381 .60271 L
.02381 .5518 L
.02381 .5 L
.02381 .4482 L
.02381 .39729 L
.02381 .34814 L
.02381 .30159 L
.02381 .25843 L
.02381 .2194 L
.02381 .18518 L
.02381 .15634 L
.02381 .13338 L
.02381 .1167 L
.02381 .10657 L
.02381 .10317 L
.02381 .10657 L
.02381 .1167 L
.02381 .13338 L
.02381 .15634 L
.02381 .18518 L
.02381 .2194 L
.02381 .25843 L
.02381 .30159 L
.02381 .34814 L
.02381 .39729 L
.02381 .4482 L
.02381 .5 L
.02381 .5518 L
.02381 .60271 L
.02381 .65186 L
.02381 .69841 L
.02381 .74157 L
.02381 .7806 L
.02381 .81482 L
.02381 .84366 L
.02381 .86662 L
.02381 .8833 L
.02381 .89343 L
.02381 .89683 L
s
.02381 .95821 m
.02381 .95429 L
.02381 .9426 L
.02381 .92333 L
.02381 .89683 L
.02381 .86353 L
.02381 .82401 L
.02381 .77894 L
.02381 .72911 L
.02381 .67535 L
.02381 .61859 L
.02381 .55981 L
.02381 .5 L
.02381 .44019 L
.02381 .38141 L
.02381 .32465 L
.02381 .27089 L
.02381 .22106 L
.02381 .17599 L
.02381 .13647 L
.02381 .10317 L
.02381 .07667 L
.02381 .0574 L
.02381 .04571 L
.02381 .04179 L
.02381 .04571 L
.02381 .0574 L
.02381 .07667 L
.02381 .10317 L
.02381 .13647 L
.02381 .17599 L
.02381 .22106 L
.02381 .27089 L
.02381 .32465 L
.02381 .38141 L
.02381 .44019 L
.02381 .5 L
.02381 .55981 L
.02381 .61859 L
.02381 .67535 L
.02381 .72911 L
.02381 .77894 L
.02381 .82401 L
.02381 .86353 L
.02381 .89683 L
.02381 .92333 L
.02381 .9426 L
.02381 .95429 L
.02381 .95821 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{170, 170},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002Z0000ZR000`400?l00000o`00003oZP3oool0
0:X0oooo002Z0?ooo`00ZP3oool000@0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`020?ooo`00103ooonQ000000D0oooo00040?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool00`3oool000@0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`00
103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool000@0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?oo
o`00103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00<0oooo00040?ooobX00000
MP3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0V07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl09`1oOgl0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo
02P0Ogmo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000
Ogmo07moO`0Y07moO`030000003oool0oooo0740oooo00<000000?ooo`3oool00`3oool000@0oooo
00<0000007moO`1oOgl0:P1oOgl00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00<0oooo
00040?ooo`030000001oOgl0Ogmo02X0Ogmo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`030?ooo`00103oool00`000000Ogmo07moO`0[07moO`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0;01oOgl00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02d0Ogmo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0^07moO`030000
003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0;P1o
Ogl00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0
Ogmo02l0Ogmo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`030?ooo`00103oool00`00
0000Ogmo07moO`0`07moO`030000003oool0oooo06X0oooo00<000000?ooo`3oool00`3oool000@0
oooo00<0000007moO`1oOgl0<@1oOgl00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00<0
oooo00040?ooo`030000001oOgl0Ogmo0380Ogmo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0b07moO`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo03@0Ogmo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`030?ooo`00103oool2000003H0Ogmo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0000000f07moO`030000
003oool0oooo06@0oooo00<000000?ooo`3oool00`3oool000@0oooo00@000000?ooo`3oool00000
=P1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00<0oooo00040?ooo`050000003o
ool0oooo0?ooo`000000=@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00<0oooo
00040?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0080oooo00<00000
07moO`1oOgl0=01oOgl00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00<0oooo00040?oo
o`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00@0oooo00<0000007moO`1o
Ogl0=01oOgl00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000
003oool0oooo00D0oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00H0oooo00<0000007moO`1oOgl0<`1o
Ogl00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0
oooo00H0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00<0oooo00040?ooo`030000003oool0oooo00L0oooo00<0000007moO`1oOgl0=01oOgl00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00P0
oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00<0
oooo00040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00X0oooo00<0
000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00<0oooo0004
0?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00X0oooo0P00000f07mo
O`030000003oool0oooo05P0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3o
ool02@3oool010000000Ogmo07moO`00000f07moO`030000003oool0oooo05L0oooo00<000000?oo
o`3oool00`3oool000@0oooo00<000000?ooo`3oool0203oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo03<0Ogmo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`030?ooo`00
103oool00`000000oooo0?ooo`070?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
<`1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003o
ool0oooo00H0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0c07moO`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01P3oool0
0`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo03@0Ogmo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000001oOgl0Ogmo
00P0Ogmo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0c07moO`030000003oool0oooo05<0oooo00<000000?ooo`3oool00`3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo03<0Ogmo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?oo
o`020?ooo`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0080oooo00<00000
07moO`1oOgl03`1oOgl00`000000Ogmo07moO`0c07moO`030000003oool0oooo0500oooo00<00000
0?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0oooo0000000B07moO`030000001oOgl0
Ogmo03@0Ogmo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`00103oool01000
0000oooo0?ooo`00000D07moO`030000001oOgl0Ogmo03<0Ogmo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0000000F07moO`030000001oOgl0Ogmo
03<0Ogmo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`030?ooo`00103oool2000001P0
Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00<0
oooo00040?ooo`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01P0Ogmo00<0
000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00<0oooo0004
0?ooo`030000001oOgl0Ogmo01T0Ogmo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01X0Ogmo00<0000007mo
O`1oOgl0<`1oOgl00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0oooo00040?ooo`03
0000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01`0Ogmo00<0000007moO`1oOgl0
<`1oOgl00`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001o
Ogl0Ogmo01d0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1oOgl0=01oOgl0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo
01h0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000001oOgl0Ogmo01l0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo0200Ogmo
00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo
00040?ooo`030000001oOgl0Ogmo0240Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo0240Ogmo00<00000
07moO`1oOgl0=01oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo00<0oooo00040?oo
o`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02<0Ogmo00<0000007moO`1o
Ogl0<`1oOgl00`000000oooo0?ooo`110?ooo`030000003oool0oooo00<0oooo00040?ooo`030000
001oOgl0Ogmo02@0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`100?ooo`030000
003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02D0Ogmo00<0000007moO`1oOgl0<`1o
Ogl00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0
Ogmo02H0Ogmo=`0000100?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo
02H0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000001oOgl0Ogmo02D0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02@0Ogmo
00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`100?ooo`030000003oool0oooo00<0oooo
00040?ooo`030000001oOgl0Ogmo02<0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo0280Ogmo00<00000
07moO`1oOgl0<`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo00<0oooo00040?oo
o`030000001oOgl0Ogmo0240Ogmo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo0240Ogmo00<0000007moO`1o
Ogl0<`1oOgl00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo00040?ooo`030000
001oOgl0Ogmo0200Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01l0Ogmo00<0000007moO`1oOgl0<`1o
Ogl00`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0
Ogmo01h0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1oOgl0=01oOgl00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01d0
Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`170?ooo`030000003oool0oooo00<0
oooo00040?ooo`030000001oOgl0Ogmo01`0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01/0Ogmo00<0
000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo00<0oooo0004
0?ooo`030000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01T0Ogmo00<0000007mo
O`1oOgl0=01oOgl00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0oooo00040?ooo`03
0000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo01P0Ogmo00<0000007moO`1oOgl0
<`1oOgl00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00<0oooo00040?ooo`800000601o
Ogl00`000000Ogmo07moO`0c07moO`030000003oool0oooo04d0oooo00<000000?ooo`3oool00`3o
ool000@0oooo00<000000?ooo`0000005P1oOgl00`000000Ogmo07moO`0c07moO`030000003oool0
oooo04h0oooo00<000000?ooo`3oool00`3oool000@0oooo00@000000?ooo`3oool00000501oOgl0
0`000000Ogmo07moO`0c07moO`030000003oool0oooo04l0oooo00<000000?ooo`3oool00`3oool0
00@0oooo00D000000?ooo`3oool0oooo0000000B07moO`030000001oOgl0Ogmo03@0Ogmo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`020?oo
o`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0080oooo00<0000007moO`1o
Ogl03P1oOgl00`000000Ogmo07moO`0c07moO`030000003oool0oooo0540oooo00<000000?ooo`3o
ool00`3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo03<0Ogmo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`030?ooo`00103o
ool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0<`1o
Ogl00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0
oooo00D0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0d07moO`030000003oool0
oooo05<0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01P3oool00`00
0000Ogmo07moO`0607moO`030000001oOgl0Ogmo03@0Ogmo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000001oOgl0Ogmo00H0
Ogmo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0
oooo00040?ooo`030000003oool0oooo00L0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0c07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0
00000?ooo`3oool0203oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo03<0Ogmo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`09
0?ooo`040000001oOgl0Ogmo000003H0Ogmo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`030?ooo`00103oool00`000000oooo0?ooo`0:0?ooo`800000=P1oOgl00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00/0oooo00<0000007mo
O`1oOgl0<`1oOgl00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo00040?ooo`03
0000003oool0oooo00X0oooo00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
<`1oOgl00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003o
ool0oooo00P0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00<0oooo00040?ooo`030000003oool0oooo00L0oooo00<0000007moO`1oOgl0=01oOgl0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo
00H0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000003oool0oooo00H0oooo00<0000007moO`1oOgl0<`1oOgl00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00D0oooo
00<0000007moO`1oOgl0<`1oOgl00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00<0oooo
00040?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
07moO`1oOgl0=01oOgl00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00<0oooo00040?oo
o`030000003oool0oooo0080oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0080oooo00<0000007moO`1o
Ogl0<`1oOgl00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00<0oooo00040?ooo`050000
003oool0oooo0?ooo`000000=@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00<0
oooo00040?ooo`040000003oool0oooo000003H0Ogmo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`030?ooo`00103oool00`000000oooo0000000f07moO`030000003oool0oooo06@0oooo
00<000000?ooo`3oool00`3oool000@0oooo0P00000f07moO`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0=01oOgl00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo03<0Ogmo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0b07moO`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0
<P1oOgl00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001o
Ogl0Ogmo0340Ogmo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`00103oool0
0`000000Ogmo07moO`0`07moO`030000003oool0oooo06X0oooo00<000000?ooo`3oool00`3oool0
00@0oooo00<0000007moO`1oOgl0;`1oOgl00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00<0oooo00040?ooo`030000001oOgl0Ogmo02h0Ogmo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0^07moO`030000003oool0oooo06`0oooo
00<000000?ooo`3oool00`3oool000@0oooo00<0000007moO`1oOgl0;@1oOgl00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02`0Ogmo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000Ogmo07moO`0[07mo
O`030000003oool0oooo06l0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0000007moO`1o
Ogl0:P1oOgl00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000
001oOgl0Ogmo02X0Ogmo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`030?ooo`00103o
ool00`000000Ogmo07moO`0Y07moO`030000003oool0oooo0740oooo00<000000?ooo`3oool00`3o
ool000@0oooo00<0000007moO`1oOgl0:01oOgl00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00<0oooo00040?ooo`030000001oOgl0Ogmo02L0Ogmo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`030?ooo`00103ooolZ000007H0oooo00<000000?ooo`3oool00`3oool000@0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?oo
o`00103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0W@3o
ool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo00<0oooo00040?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool000@0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool00`3oool000@0ooooXP0000040?ooo`00ZP3oool00:X0oooo002Z0?ooo`00ZP3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 169}, {169, 0}} -> {-1.50033, -31.5003, 0.372785, \
0.372785}},
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{HollowCornerCube[50, FullForm->True, \
Baffled->False],Boundary[60]},PlotType->FrontView, AspectRatio->1];\
\>", \
"Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.509852 0.0155446 0.509852 0.0155446 [
[.02381 .02381 -30 -4.5 ]
[.02381 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.50985 .06112 m
.12124 .28548 L
.50985 .50985 L
.89847 .28548 L
.50985 .06112 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50985 .06112 m
.12124 .28548 L
.50985 .50985 L
.89847 .28548 L
.50985 .06112 L
s
.5 g
.12124 .73422 m
.50985 .95859 L
.50985 .50985 L
.12124 .28548 L
.12124 .73422 L
F
0 g
.12124 .73422 m
.50985 .95859 L
.50985 .50985 L
.12124 .28548 L
.12124 .73422 L
s
.5 g
.89847 .73422 m
.89847 .28548 L
.50985 .50985 L
.50985 .95859 L
.89847 .73422 L
F
0 g
.89847 .73422 m
.89847 .28548 L
.50985 .50985 L
.50985 .95859 L
.89847 .73422 L
s
.97619 .04351 m
.04351 .04351 L
.04351 .97619 L
.97619 .97619 L
.97619 .04351 L
s
.04351 .04351 m
.04351 .04351 L
.04351 .97619 L
.04351 .97619 L
.04351 .04351 L
s
.04351 .04351 m
.97619 .04351 L
.97619 .97619 L
.04351 .97619 L
.04351 .04351 L
s
.97619 .04351 m
.97619 .04351 L
.97619 .97619 L
.97619 .97619 L
.97619 .04351 L
s
.04351 .04351 m
.97619 .04351 L
.97619 .04351 L
.04351 .04351 L
.04351 .04351 L
s
.97619 .97619 m
.04351 .97619 L
.04351 .97619 L
.97619 .97619 L
.97619 .97619 L
s
0 0 0 r
[(CornerCube)] .02381 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{196, 196},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000340000a2000`400?l00000o`00003oa03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool000L0oooo0`0000030?oo
o`<000000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000000000000P3oool20000
00<0oooo0`0000030?ooo`<0000000@0oooo00000000000000000P3oool200000900oooo00060?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00P00002B0?ooo`001@3oool00`000000
oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0
00000?ooo`@0000000D0oooo0000003oool0oooo000000060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@00002?0?ooo`001@3oool00`000000oooo0?ooo`040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0S@3oool000D0oooo00<000000?ooo`3o
ool01@3oool3000000030?ooo`000000000000@000000`3oool2000000060?ooo`00000000000000
003oool000001@3oool2000000040?ooo`000000oooo0?ooo`<000000P3oool200000900oooo0006
0?ooo`030000003oool0oooo008000005P3ooonO000000@0oooo00070?ooo`80000000<0oooo0000
003oool05@3oool01P000000oooo000000000000oooo000000D0oooo0P00002@0?ooo`030000003o
ool0oooo00<0oooo000Q0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool00`3oool0
0240oooo00<000000?ooo`3oool0B`3oool3000004`0oooo00<000000?ooo`3oool00`3oool00240
oooo00<000000?ooo`3oool0B@3oool2000000<0Ogmo0P00001:0?ooo`030000003oool0oooo00<0
oooo000Q0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo04H0oooo0P00
000907moO`800000A`3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`14
0?ooo`8000003@1oOgl2000004D0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?oo
o`3oool0@P3oool200000140Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`030?oo
o`008@3oool00`000000oooo0?ooo`110?ooo`030000001oOgl0Ogmo0180Ogmo0P0000120?ooo`03
0000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo03l0oooo0P00000G07moO`800000
@03oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0m0?ooo`8000006`1o
Ogl2000003h0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0>`3oool2
000001l0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`008@3oool00`00
0000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo0200Ogmo0P00000k0?ooo`030000003oool0oooo
00<0oooo000Q0?ooo`030000003oool0oooo03P0oooo0P00000U07moO`800000>@3oool00`000000
oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`800000:@1oOgl00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0
000007moO`1oOgl0:P1oOgl2000003H0oooo00<000000?ooo`3oool00`3oool00240oooo00<00000
0?ooo`3oool0<`3oool2000002l0Ogmo0P00000d0?ooo`030000003oool0oooo00<0oooo000Q0?oo
o`030000003oool0oooo0340oooo0P00000c07moO`800000<P3oool00`000000oooo0?ooo`030?oo
o`008@3oool00`000000oooo0?ooo`0_0?ooo`800000=`1oOgl00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl0
>01oOgl2000002l0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0;03o
ool2000003d0Ogmo0P00000]0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0
oooo02X0oooo0P00001107moO`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool0
0240oooo00<000000?ooo`3oool0:03oool2000004@0Ogmo0P00000Z0?ooo`030000003oool0oooo
00<0oooo000Q0?ooo`030000003oool0oooo02L0oooo00<0000007moO`1oOgl0AP1oOgl2000002P0
oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool09@3oool2000004/0Ogmo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?oo
o`0S0?ooo`800000CP1oOgl2000002D0oooo00<000000?ooo`3oool00`3oool00240oooo00<00000
0?ooo`3oool08@3oool200000580Ogmo0P00000S0?ooo`030000003oool0oooo00<0oooo000Q0?oo
o`030000003oool0oooo0200oooo00<0000007moO`1oOgl0E01oOgl200000240oooo00<000000?oo
o`3oool00`3oool00240oooo00<000000?ooo`3oool07P3oool2000005T0Ogmo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0L0?ooo`800000
G01oOgl2000001h0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool06P3o
ool200000600Ogmo0P00000L0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0
oooo01T0oooo00<0000007moO`1oOgl0HP1oOgl00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo000Q0?ooo`030000003oool0oooo01L0oooo0P00001V07moO`8000006@3oool00`00
0000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0E0?ooo`800000JP1oOgl2000001L0
oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0503oool00`000000Ogmo
07moO`1/07moO`8000005@3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?oo
o`0B0?ooo`800000L@1oOgl00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000Q
0?ooo`030000003oool0oooo0100oooo0P00001d07moO`8000004P3oool00`000000oooo0?ooo`03
0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`800000N01oOgl200000100oooo00<000000?oo
o`3oool00`3oool00240oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`1j07moO`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0
2`3oool2000007h0Ogmo0P00000=0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003o
ool0oooo00X0oooo0P00002007moO`800000303oool00`000000oooo0?ooo`030?ooo`008@3oool0
0`000000oooo0?ooo`0:0?ooo`040000001oOgl00000000007`0Ogmo0P0000000`1oOgl000000?oo
o`0;0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00D00000
07moO`1oOgl0Ogmo0000001j07moO`050000001oOgl0Ogmo07moO`000000303oool00`000000oooo
0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo0080Ogmo0P00
001f07moO`800000101oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q
0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0101oOgl200000780Ogmo0P000006
07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?oo
o`3oool02P3oool00`000000Ogmo07moO`0607moO`800000K`1oOgl00`000000Ogmo07moO`0607mo
O`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3o
ool02P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo06X0Ogmo0P00000907moO`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0
2P3oool00`000000Ogmo07moO`0907moO`800000J01oOgl2000000/0Ogmo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001o
Ogl0Ogmo00/0Ogmo0P00001T07moO`8000003@1oOgl00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl03@1oOgl2
00000640Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl03`1oOgl00`00
0000Ogmo07moO`1L07moO`800000401oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0401oOgl2000005X0
Ogmo0P00000B07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo
00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0B07moO`800000E`1oOgl00`000000Ogmo
07moO`0B07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<0
00000?ooo`3oool02P3oool00`000000Ogmo07moO`0D07moO`030000001oOgl0Ogmo0580Ogmo0P00
000E07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<00000
0?ooo`3oool02P3oool00`000000Ogmo07moO`0E07moO`800000D01oOgl2000001L0Ogmo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?oo
o`030000001oOgl0Ogmo01L0Ogmo0P00001<07moO`8000006@1oOgl00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1o
Ogl06@1oOgl2000004T0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0
6`1oOgl00`000000Ogmo07moO`1407moO`800000701oOgl00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0701o
Ogl200000480Ogmo0P00000N07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0N07moO`800000?`1oOgl0
0`000000Ogmo07moO`0N07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0P07moO`800000>`1oOgl20000
0240Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000
oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl0=P1oOgl2000002<0
Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo
0?ooo`0:0?ooo`030000001oOgl0Ogmo02<0Ogmo0P00000e07moO`030000001oOgl0Ogmo02<0Ogmo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?oo
o`0:0?ooo`030000001oOgl0Ogmo02D0Ogmo0P00000a07moO`8000009P1oOgl00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl09`1oOgl2000002d0Ogmo0P00000X07moO`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0Y07mo
O`030000001oOgl0Ogmo02P0Ogmo0P00000Z07moO`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0Z07moO`80
00009`1oOgl00`000000Ogmo07moO`0Z07moO`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0/07moO`800000
8`1oOgl2000002d0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3o
ool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo02h0Ogmo0P00000O07moO`800000;`1o
Ogl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0
oooo00X0oooo00<0000007moO`1oOgl0<01oOgl00`000000Ogmo07moO`0K07moO`030000001oOgl0
Ogmo02l0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`00
0000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo0340Ogmo0P00000I07moO`800000<P1oOgl00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0
oooo00<0000007moO`1oOgl0<`1oOgl2000001D0Ogmo0P00000d07moO`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo
07moO`0e07moO`030000001oOgl0Ogmo0100Ogmo0P00000f07moO`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07mo
O`0f07moO`8000003`1oOgl00`000000Ogmo07moO`0f07moO`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0h
07moO`8000002`1oOgl2000003T0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03X0Ogmo0P00000707mo
O`800000>`1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`03
0000003oool0oooo00X0oooo00<0000007moO`1oOgl0?01oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo03/0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
8@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03d0Ogmo0P0000000`1oOgl00000
0000000n07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<0
00000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:
0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007mo
O`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`03
0000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
8@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0
?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003o
ool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool0
0`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo
03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`000000
Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo
00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?oo
o`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07mo
O`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1o
Ogl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000
003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3o
ool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0
Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`00
0000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240
oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0
Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo
0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0
000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o
07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007mo
O`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`03
0000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0
2P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001o
Ogl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl0
0`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo
03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000
oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo
00<0000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07mo
O`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<00000
07moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?oo
o`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1oOgl00`000000Ogmo07moO`0n07mo
O`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3o
ool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000
001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl0?`1o
Ogl00`000000Ogmo07moO`0n07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool00240oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0o07moO`030000001oOgl0
Ogmo03h0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`00
0000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo03l0Ogmo00<0000007moO`1oOgl0?P1oOgl00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00X0
oooo0P00001007moO`030000001oOgl0Ogmo03d0Ogmo0P00000<0?ooo`030000003oool0oooo00<0
oooo000Q0?ooo`030000003oool0oooo00`0oooo0P00000n07moO`030000001oOgl0Ogmo03/0Ogmo
0P00000>0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo00h0oooo00<0
000007moO`1oOgl0>`1oOgl00`000000Ogmo07moO`0j07moO`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool03`3oool2000003/0Ogmo00<00000
07moO`1oOgl0>01oOgl200000140oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?oo
o`3oool04@3oool2000003T0Ogmo00<0000007moO`1oOgl0=P1oOgl2000001<0oooo00<000000?oo
o`3oool00`3oool00240oooo00<000000?ooo`3oool04`3oool2000003L0Ogmo00<0000007moO`1o
Ogl0=@1oOgl00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000
003oool0oooo01D0oooo00<0000007moO`1oOgl0=01oOgl00`000000Ogmo07moO`0c07moO`800000
5P3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`800000=01o
Ogl00`000000Ogmo07moO`0a07moO`800000603oool00`000000oooo0?ooo`030?ooo`008@3oool0
0`000000oooo0?ooo`0H0?ooo`800000<P1oOgl00`000000Ogmo07moO`0_07moO`8000006P3oool0
0`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0J0?ooo`800000<01oOgl00`00
0000Ogmo07moO`0^07moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00240
oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0]07moO`030000001oOgl0Ogmo02`0
Ogmo0P00000M0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo01d0oooo
0P00000]07moO`030000001oOgl0Ogmo02X0Ogmo0P00000O0?ooo`030000003oool0oooo00<0oooo
000Q0?ooo`030000003oool0oooo01l0oooo0P00000[07moO`030000001oOgl0Ogmo02T0Ogmo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0Q
0?ooo`030000001oOgl0Ogmo02P0Ogmo00<0000007moO`1oOgl09`1oOgl200000280oooo00<00000
0?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool08P3oool2000002P0Ogmo00<0000007mo
O`1oOgl09@1oOgl2000002@0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3o
ool0903oool2000002H0Ogmo00<0000007moO`1oOgl08`1oOgl2000002H0oooo00<000000?ooo`3o
ool00`3oool00240oooo00<000000?ooo`3oool09P3oool2000002@0Ogmo00<0000007moO`1oOgl0
8P1oOgl00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003o
ool0oooo02P0oooo00<0000007moO`1oOgl08@1oOgl00`000000Ogmo07moO`0P07moO`800000:@3o
ool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0Y0?ooo`8000008@1oOgl0
0`000000Ogmo07moO`0N07moO`800000:`3oool00`000000oooo0?ooo`030?ooo`008@3oool00`00
0000oooo0?ooo`0[0?ooo`8000007`1oOgl00`000000Ogmo07moO`0M07moO`030000003oool0oooo
02/0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0;@3oool2000001d0
Ogmo00<0000007moO`1oOgl06`1oOgl2000002h0oooo00<000000?ooo`3oool00`3oool00240oooo
00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0J07moO`030000001oOgl0Ogmo01T0Ogmo
0P00000`0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo0300oooo0P00
000J07moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`030?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`800000601oOgl00`000000Ogmo07moO`0F
07moO`800000<`3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`0d0?oo
o`8000005P1oOgl00`000000Ogmo07moO`0D07moO`800000=@3oool00`000000oooo0?ooo`030?oo
o`008@3oool00`000000oooo0?ooo`0f0?ooo`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1o
Ogl04P1oOgl2000003L0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0
=`3oool2000001<0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo03T0oooo0P00000A07moO`030000001o
Ogl0Ogmo00l0Ogmo0P00000j0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0
oooo03/0oooo0P00000?07moO`030000001oOgl0Ogmo00d0Ogmo0P00000l0?ooo`030000003oool0
oooo00<0oooo000Q0?ooo`030000003oool0oooo03d0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool00240
oooo00<000000?ooo`3oool0?P3oool2000000`0Ogmo00<0000007moO`1oOgl02P1oOgl2000003l0
oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0@03oool2000000X0Ogmo
00<0000007moO`1oOgl0201oOgl200000440oooo00<000000?ooo`3oool00`3oool00240oooo00<0
00000?ooo`3oool0@P3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00H0Ogmo0P00
00130?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo04<0oooo0P000007
07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`03
0?ooo`008@3oool00`000000oooo0?ooo`150?ooo`8000001@1oOgl00`000000Ogmo07moO`0307mo
O`800000AP3oool00`000000oooo0?ooo`030?ooo`008@3oool00`000000oooo0?ooo`170?ooo`80
00000`1oOgl010000000Ogmo07moO`1oOgl2000004P0oooo00<000000?ooo`3oool00`3oool00240
oooo00<000000?ooo`3oool0B@3oool010000000Ogmo07moO`00000207moO`030000003oool0oooo
04P0oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0BP3oool5000004/0
oooo00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00<0oooo000Q0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0VP3oool2000000@0oooo000Q0?oo
oih000001@3oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo
00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 195}, {195, 0}} -> {-42.6861, -37.8333, 0.380606, \
0.380606}},
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
LineOfRays[40,NumberOfRays->7],
Move[HollowCornerCube[50],50],
Boundary[100,GraphicDesign->Off]},PlotType->TopView,AspectRatio->1];\
\>", \
"Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0104859 0.523307 0.0156884 [
[.51695 .02381 -30 -4.5 ]
[.51695 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5481 .52331 m
.76215 .1311 L
.97619 .52331 L
.76215 .91552 L
.5481 .52331 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.5481 .52331 m
.76215 .1311 L
.97619 .52331 L
.76215 .91552 L
.5481 .52331 L
s
.5 g
.5481 .1311 m
.76215 .52331 L
.97619 .52331 L
.76215 .1311 L
.5481 .1311 L
F
0 g
.5481 .1311 m
.76215 .52331 L
.97619 .52331 L
.76215 .1311 L
.5481 .1311 L
s
.5 g
.5481 .91552 m
.76215 .91552 L
.97619 .52331 L
.76215 .52331 L
.5481 .91552 L
F
0 g
.5481 .91552 m
.76215 .91552 L
.97619 .52331 L
.76215 .52331 L
.5481 .91552 L
s
.5 g
.5481 .91552 m
.5481 .93574 L
.5481 .92169 L
.5481 .90215 L
.5481 .91552 L
F
.5481 .90215 m
.5481 .92169 L
.5481 .88048 L
.5481 .86297 L
.5481 .90215 L
F
.5481 .86297 m
.5481 .88048 L
.5481 .81494 L
.5481 .80064 L
.5481 .86297 L
F
.5481 .80064 m
.5481 .81494 L
.5481 .72952 L
.5481 .71941 L
.5481 .80064 L
F
.5481 .71941 m
.5481 .72952 L
.5481 .63005 L
.5481 .62482 L
.5481 .71941 L
F
.5481 .62482 m
.5481 .63005 L
.5481 .52331 L
.5481 .52331 L
.5481 .62482 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .41656 L
.5481 .4218 L
.5481 .52331 L
F
.5481 .4218 m
.5481 .41656 L
.5481 .31709 L
.5481 .3272 L
.5481 .4218 L
F
.5481 .3272 m
.5481 .31709 L
.5481 .23167 L
.5481 .24597 L
.5481 .3272 L
F
.5481 .24597 m
.5481 .23167 L
.5481 .16613 L
.5481 .18364 L
.5481 .24597 L
F
.5481 .18364 m
.5481 .16613 L
.5481 .12493 L
.5481 .14446 L
.5481 .18364 L
F
.5481 .14446 m
.5481 .12493 L
.5481 .11087 L
.5481 .1311 L
.5481 .14446 L
F
.5481 .1311 m
.5481 .11087 L
.5481 .12493 L
.5481 .14446 L
.5481 .1311 L
F
.5481 .14446 m
.5481 .12493 L
.5481 .16613 L
.5481 .18364 L
.5481 .14446 L
F
.5481 .18364 m
.5481 .16613 L
.5481 .23167 L
.5481 .24597 L
.5481 .18364 L
F
.5481 .24597 m
.5481 .23167 L
.5481 .31709 L
.5481 .3272 L
.5481 .24597 L
F
.5481 .3272 m
.5481 .31709 L
.5481 .41656 L
.5481 .4218 L
.5481 .3272 L
F
.5481 .4218 m
.5481 .41656 L
.5481 .52331 L
.5481 .52331 L
.5481 .4218 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .63005 L
.5481 .62482 L
.5481 .52331 L
F
.5481 .62482 m
.5481 .63005 L
.5481 .72952 L
.5481 .71941 L
.5481 .62482 L
F
.5481 .71941 m
.5481 .72952 L
.5481 .81494 L
.5481 .80064 L
.5481 .71941 L
F
.5481 .80064 m
.5481 .81494 L
.5481 .88048 L
.5481 .86297 L
.5481 .80064 L
F
.5481 .86297 m
.5481 .88048 L
.5481 .92169 L
.5481 .90215 L
.5481 .86297 L
F
.5481 .90215 m
.5481 .92169 L
.5481 .93574 L
.5481 .91552 L
.5481 .90215 L
F
.5481 .93574 m
.5481 .95597 L
.5481 .94122 L
.5481 .92169 L
.5481 .93574 L
F
.5481 .92169 m
.5481 .94122 L
.5481 .898 L
.5481 .88048 L
.5481 .92169 L
F
.5481 .88048 m
.5481 .898 L
.5481 .82924 L
.5481 .81494 L
.5481 .88048 L
F
.5481 .81494 m
.5481 .82924 L
.5481 .73964 L
.5481 .72952 L
.5481 .81494 L
F
.5481 .72952 m
.5481 .73964 L
.5481 .63529 L
.5481 .63005 L
.5481 .72952 L
F
.5481 .63005 m
.5481 .63529 L
.5481 .52331 L
.5481 .52331 L
.5481 .63005 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .41133 L
.5481 .41656 L
.5481 .52331 L
F
.5481 .41656 m
.5481 .41133 L
.5481 .30698 L
.5481 .31709 L
.5481 .41656 L
F
.5481 .31709 m
.5481 .30698 L
.5481 .21737 L
.5481 .23167 L
.5481 .31709 L
F
.5481 .23167 m
.5481 .21737 L
.5481 .14861 L
.5481 .16613 L
.5481 .23167 L
F
.5481 .16613 m
.5481 .14861 L
.5481 .10539 L
.5481 .12493 L
.5481 .16613 L
F
.5481 .12493 m
.5481 .10539 L
.5481 .09065 L
.5481 .11087 L
.5481 .12493 L
F
.5481 .11087 m
.5481 .09065 L
.5481 .10539 L
.5481 .12493 L
.5481 .11087 L
F
.5481 .12493 m
.5481 .10539 L
.5481 .14861 L
.5481 .16613 L
.5481 .12493 L
F
.5481 .16613 m
.5481 .14861 L
.5481 .21737 L
.5481 .23167 L
.5481 .16613 L
F
.5481 .23167 m
.5481 .21737 L
.5481 .30698 L
.5481 .31709 L
.5481 .23167 L
F
.5481 .31709 m
.5481 .30698 L
.5481 .41133 L
.5481 .41656 L
.5481 .31709 L
F
.5481 .41656 m
.5481 .41133 L
.5481 .52331 L
.5481 .52331 L
.5481 .41656 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .63529 L
.5481 .63005 L
.5481 .52331 L
F
.5481 .63005 m
.5481 .63529 L
.5481 .73964 L
.5481 .72952 L
.5481 .63005 L
F
.5481 .72952 m
.5481 .73964 L
.5481 .82924 L
.5481 .81494 L
.5481 .72952 L
F
.5481 .81494 m
.5481 .82924 L
.5481 .898 L
.5481 .88048 L
.5481 .81494 L
F
.5481 .88048 m
.5481 .898 L
.5481 .94122 L
.5481 .92169 L
.5481 .88048 L
F
.5481 .92169 m
.5481 .94122 L
.5481 .95597 L
.5481 .93574 L
.5481 .92169 L
F
.5481 .95597 m
.5481 .97619 L
.5481 .96076 L
.5481 .94122 L
.5481 .95597 L
F
.5481 .94122 m
.5481 .96076 L
.5481 .91552 L
.5481 .898 L
.5481 .94122 L
F
.5481 .898 m
.5481 .91552 L
.5481 .84354 L
.5481 .82924 L
.5481 .898 L
F
.5481 .82924 m
.5481 .84354 L
.5481 .74975 L
.5481 .73964 L
.5481 .82924 L
F
.5481 .73964 m
.5481 .74975 L
.5481 .64052 L
.5481 .63529 L
.5481 .73964 L
F
.5481 .63529 m
.5481 .64052 L
.5481 .52331 L
.5481 .52331 L
.5481 .63529 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .40609 L
.5481 .41133 L
.5481 .52331 L
F
.5481 .41133 m
.5481 .40609 L
.5481 .29686 L
.5481 .30698 L
.5481 .41133 L
F
.5481 .30698 m
.5481 .29686 L
.5481 .20307 L
.5481 .21737 L
.5481 .30698 L
F
.5481 .21737 m
.5481 .20307 L
.5481 .1311 L
.5481 .14861 L
.5481 .21737 L
F
.5481 .14861 m
.5481 .1311 L
.5481 .08585 L
.5481 .10539 L
.5481 .14861 L
F
.5481 .10539 m
.5481 .08585 L
.5481 .07042 L
.5481 .09065 L
.5481 .10539 L
F
.5481 .09065 m
.5481 .07042 L
.5481 .08585 L
.5481 .10539 L
.5481 .09065 L
F
.5481 .10539 m
.5481 .08585 L
.5481 .1311 L
.5481 .14861 L
.5481 .10539 L
F
.5481 .14861 m
.5481 .1311 L
.5481 .20307 L
.5481 .21737 L
.5481 .14861 L
F
.5481 .21737 m
.5481 .20307 L
.5481 .29686 L
.5481 .30698 L
.5481 .21737 L
F
.5481 .30698 m
.5481 .29686 L
.5481 .40609 L
.5481 .41133 L
.5481 .30698 L
F
.5481 .41133 m
.5481 .40609 L
.5481 .52331 L
.5481 .52331 L
.5481 .41133 L
F
.5481 .52331 m
.5481 .52331 L
.5481 .64052 L
.5481 .63529 L
.5481 .52331 L
F
.5481 .63529 m
.5481 .64052 L
.5481 .74975 L
.5481 .73964 L
.5481 .63529 L
F
.5481 .73964 m
.5481 .74975 L
.5481 .84354 L
.5481 .82924 L
.5481 .73964 L
F
.5481 .82924 m
.5481 .84354 L
.5481 .91552 L
.5481 .898 L
.5481 .82924 L
F
.5481 .898 m
.5481 .91552 L
.5481 .96076 L
.5481 .94122 L
.5481 .898 L
F
.5481 .94122 m
.5481 .96076 L
.5481 .97619 L
.5481 .95597 L
.5481 .94122 L
F
0 g
.5481 .91552 m
.5481 .90215 L
.5481 .86297 L
.5481 .80064 L
.5481 .71941 L
.5481 .62482 L
.5481 .52331 L
.5481 .4218 L
.5481 .3272 L
.5481 .24597 L
.5481 .18364 L
.5481 .14446 L
.5481 .1311 L
.5481 .14446 L
.5481 .18364 L
.5481 .24597 L
.5481 .3272 L
.5481 .4218 L
.5481 .52331 L
.5481 .62482 L
.5481 .71941 L
.5481 .80064 L
.5481 .86297 L
.5481 .90215 L
.5481 .91552 L
s
.5481 .97619 m
.5481 .96076 L
.5481 .91552 L
.5481 .84354 L
.5481 .74975 L
.5481 .64052 L
.5481 .52331 L
.5481 .40609 L
.5481 .29686 L
.5481 .20307 L
.5481 .1311 L
.5481 .08585 L
.5481 .07042 L
.5481 .08585 L
.5481 .1311 L
.5481 .20307 L
.5481 .29686 L
.5481 .40609 L
.5481 .52331 L
.5481 .64052 L
.5481 .74975 L
.5481 .84354 L
.5481 .91552 L
.5481 .96076 L
.5481 .97619 L
s
.039 .916 .04 r
.02381 .20954 m
.5481 .20954 L
s
0 0 0 r
2 Mabswid
.5481 .20954 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31413 m
.5481 .31413 L
s
0 0 0 r
2 Mabswid
.5481 .31413 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .41872 m
.5481 .41872 L
s
0 0 0 r
2 Mabswid
.5481 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52331 m
.5481 .52331 L
s
0 0 0 r
2 Mabswid
.5481 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .6279 m
.5481 .6279 L
s
0 0 0 r
2 Mabswid
.5481 .6279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .73248 m
.5481 .73248 L
s
0 0 0 r
2 Mabswid
.5481 .73248 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .83707 m
.5481 .83707 L
s
0 0 0 r
2 Mabswid
.5481 .83707 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .20954 m
.71934 .20954 L
s
0 0 0 r
2 Mabswid
.71934 .20954 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .31413 m
.80496 .31413 L
s
0 0 0 r
2 Mabswid
.80496 .31413 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .41872 m
.89057 .41872 L
s
0 0 0 r
2 Mabswid
.89057 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .52331 m
.97619 .52331 L
s
0 0 0 r
2 Mabswid
.97619 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .6279 m
.89057 .6279 L
s
0 0 0 r
2 Mabswid
.89057 .6279 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .73248 m
.80496 .73248 L
s
0 0 0 r
2 Mabswid
.80496 .73248 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .83707 m
.71934 .83707 L
s
0 0 0 r
2 Mabswid
.71934 .83707 Mdot
.039 .916 .04 r
.5 Mabswid
.71934 .20954 m
.80496 .52331 L
s
0 0 0 r
2 Mabswid
.80496 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .31413 m
.86203 .52331 L
s
0 0 0 r
2 Mabswid
.86203 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.89057 .41872 m
.91911 .52331 L
s
0 0 0 r
2 Mabswid
.91911 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52331 m
.97619 .52331 L
s
0 0 0 r
2 Mabswid
.97619 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.89057 .6279 m
.91911 .52331 L
s
0 0 0 r
2 Mabswid
.91911 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .73248 m
.86203 .52331 L
s
0 0 0 r
2 Mabswid
.86203 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.71934 .83707 m
.80496 .52331 L
s
0 0 0 r
2 Mabswid
.80496 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .52331 m
.71934 .83707 L
s
0 0 0 r
2 Mabswid
.71934 .83707 Mdot
.039 .916 .04 r
.5 Mabswid
.86203 .52331 m
.80496 .73248 L
s
0 0 0 r
2 Mabswid
.80496 .73248 Mdot
.039 .916 .04 r
.5 Mabswid
.91911 .52331 m
.89057 .6279 L
s
0 0 0 r
2 Mabswid
.89057 .6279 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52331 m
.97619 .52331 L
s
0 0 0 r
2 Mabswid
.97619 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.91911 .52331 m
.89057 .41872 L
s
0 0 0 r
2 Mabswid
.89057 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.86203 .52331 m
.80496 .31413 L
s
0 0 0 r
2 Mabswid
.80496 .31413 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .52331 m
.71934 .20954 L
s
0 0 0 r
2 Mabswid
.71934 .20954 Mdot
.039 .916 .04 r
.5 Mabswid
.71934 .83707 m
.5481 .83707 L
s
0 0 0 r
2 Mabswid
.5481 .83707 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .73248 m
.5481 .73248 L
s
0 0 0 r
2 Mabswid
.5481 .73248 Mdot
.039 .916 .04 r
.5 Mabswid
.89057 .6279 m
.5481 .6279 L
s
0 0 0 r
2 Mabswid
.5481 .6279 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52331 m
.5481 .52331 L
s
0 0 0 r
2 Mabswid
.5481 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.89057 .41872 m
.5481 .41872 L
s
0 0 0 r
2 Mabswid
.5481 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.80496 .31413 m
.5481 .31413 L
s
0 0 0 r
2 Mabswid
.5481 .31413 Mdot
.039 .916 .04 r
.5 Mabswid
.71934 .20954 m
.5481 .20954 L
s
0 0 0 r
2 Mabswid
.5481 .20954 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .83707 m
.02381 .83707 L
s
0 0 0 r
2 Mabswid
.02381 .83707 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .73248 m
.02381 .73248 L
s
0 0 0 r
2 Mabswid
.02381 .73248 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .6279 m
.02381 .6279 L
s
0 0 0 r
2 Mabswid
.02381 .6279 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .52331 m
.02381 .52331 L
s
0 0 0 r
2 Mabswid
.02381 .52331 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .41872 m
.02381 .41872 L
s
0 0 0 r
2 Mabswid
.02381 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .31413 m
.02381 .31413 L
s
0 0 0 r
2 Mabswid
.02381 .31413 Mdot
.039 .916 .04 r
.5 Mabswid
.5481 .20954 m
.02381 .20954 L
s
0 0 0 r
2 Mabswid
.02381 .20954 Mdot
[(CornerCube)] .51695 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{190, 190},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 189}, {189, 0}} -> {-2.2711, -33.3566, 0.504588, \
0.337259}},
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
CircleOfRays[35,NumberOfRays->7],
Move[HollowCornerCube[50,FullForm->False],{50,0,5}],
Boundary[100,GraphicDesign->Off]},PlotType->TopView,AspectRatio->1];\
\>", \
"Input",
  CellTags->"HollowCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0111278 0.524358 0.0157117 [
[.57925 .02381 -30 -4.5 ]
[.57925 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.76557 .52261 m
.72566 .93662 L
.97619 .57327 L
.76557 .52261 L
F
.76557 .52261 m
.97619 .57327 L
.77416 .15402 L
.76557 .52261 L
F
.76557 .52261 m
.77416 .15402 L
.58626 .42653 L
.76557 .52261 L
F
.76557 .52261 m
.58626 .42653 L
.57414 .62218 L
.76557 .52261 L
F
.76557 .52261 m
.57414 .62218 L
.72566 .93662 L
.76557 .52261 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.76557 .52261 m
.72566 .93662 L
.97619 .57327 L
.76557 .52261 L
s
.76557 .52261 m
.97619 .57327 L
.77416 .15402 L
.76557 .52261 L
s
.76557 .52261 m
.77416 .15402 L
.58626 .42653 L
.76557 .52261 L
s
.76557 .52261 m
.58626 .42653 L
.57414 .62218 L
.76557 .52261 L
s
.76557 .52261 m
.57414 .62218 L
.72566 .93662 L
.76557 .52261 L
s
.5 g
.77466 .37588 m
.77416 .15402 L
.97619 .57327 L
.77466 .37588 L
F
.77466 .37588 m
.97619 .57327 L
.74991 .54532 L
.77466 .37588 L
F
.77466 .37588 m
.74991 .54532 L
.59838 .23088 L
.77466 .37588 L
F
.77466 .37588 m
.59838 .23088 L
.60445 .13306 L
.77466 .37588 L
F
.77466 .37588 m
.60445 .13306 L
.77416 .15402 L
.77466 .37588 L
F
0 g
.77466 .37588 m
.77416 .15402 L
.97619 .57327 L
.77466 .37588 L
s
.77466 .37588 m
.97619 .57327 L
.74991 .54532 L
.77466 .37588 L
s
.77466 .37588 m
.74991 .54532 L
.59838 .23088 L
.77466 .37588 L
s
.77466 .37588 m
.59838 .23088 L
.60445 .13306 L
.77466 .37588 L
s
.77466 .37588 m
.60445 .13306 L
.77416 .15402 L
.77466 .37588 L
s
.5 g
.75193 .74272 m
.74991 .54532 L
.97619 .57327 L
.75193 .74272 L
F
.75193 .74272 m
.97619 .57327 L
.72566 .93662 L
.75193 .74272 L
F
.75193 .74272 m
.72566 .93662 L
.55595 .91566 L
.75193 .74272 L
F
.75193 .74272 m
.55595 .91566 L
.56201 .81783 L
.75193 .74272 L
F
.75193 .74272 m
.56201 .81783 L
.74991 .54532 L
.75193 .74272 L
F
0 g
.75193 .74272 m
.74991 .54532 L
.97619 .57327 L
.75193 .74272 L
s
.75193 .74272 m
.97619 .57327 L
.72566 .93662 L
.75193 .74272 L
s
.75193 .74272 m
.72566 .93662 L
.55595 .91566 L
.75193 .74272 L
s
.75193 .74272 m
.55595 .91566 L
.56201 .81783 L
.75193 .74272 L
s
.75193 .74272 m
.56201 .81783 L
.74991 .54532 L
.75193 .74272 L
s
.5 g
.55595 .91566 m
.5547 .93583 L
.55557 .92181 L
.55678 .90232 L
.55595 .91566 L
F
.55678 .90232 m
.55557 .92181 L
.55812 .88071 L
.5592 .86323 L
.55678 .90232 L
F
.5592 .86323 m
.55812 .88071 L
.56217 .81532 L
.56305 .80105 L
.5592 .86323 L
F
.56305 .80105 m
.56217 .81532 L
.56745 .7301 L
.56808 .72001 L
.56305 .80105 L
F
.56808 .72001 m
.56745 .7301 L
.5736 .63086 L
.57392 .62563 L
.56808 .72001 L
F
.57392 .62563 m
.5736 .63086 L
.5802 .52436 L
.5802 .52436 L
.57392 .62563 L
F
.5802 .52436 m
.5802 .52436 L
.5868 .41786 L
.58647 .42308 L
.5802 .52436 L
F
.58647 .42308 m
.5868 .41786 L
.59295 .31862 L
.59232 .32871 L
.58647 .42308 L
F
.59232 .32871 m
.59295 .31862 L
.59823 .2334 L
.59734 .24767 L
.59232 .32871 L
F
.59734 .24767 m
.59823 .2334 L
.60228 .16801 L
.6012 .18548 L
.59734 .24767 L
F
.6012 .18548 m
.60228 .16801 L
.60483 .1269 L
.60362 .14639 L
.6012 .18548 L
F
.60362 .14639 m
.60483 .1269 L
.6057 .11288 L
.60445 .13306 L
.60362 .14639 L
F
.60445 .13306 m
.6057 .11288 L
.60483 .1269 L
.60362 .14639 L
.60445 .13306 L
F
.60362 .14639 m
.60483 .1269 L
.60228 .16801 L
.6012 .18548 L
.60362 .14639 L
F
.6012 .18548 m
.60228 .16801 L
.59823 .2334 L
.59734 .24767 L
.6012 .18548 L
F
.59734 .24767 m
.59823 .2334 L
.59295 .31862 L
.59232 .32871 L
.59734 .24767 L
F
.59232 .32871 m
.59295 .31862 L
.5868 .41786 L
.58647 .42308 L
.59232 .32871 L
F
.58647 .42308 m
.5868 .41786 L
.5802 .52436 L
.5802 .52436 L
.58647 .42308 L
F
.5802 .52436 m
.5802 .52436 L
.5736 .63086 L
.57392 .62563 L
.5802 .52436 L
F
.57392 .62563 m
.5736 .63086 L
.56745 .7301 L
.56808 .72001 L
.57392 .62563 L
F
.56808 .72001 m
.56745 .7301 L
.56217 .81532 L
.56305 .80105 L
.56808 .72001 L
F
.56305 .80105 m
.56217 .81532 L
.55812 .88071 L
.5592 .86323 L
.56305 .80105 L
F
.5592 .86323 m
.55812 .88071 L
.55557 .92181 L
.55678 .90232 L
.5592 .86323 L
F
.55678 .90232 m
.55557 .92181 L
.5547 .93583 L
.55595 .91566 L
.55678 .90232 L
F
.5547 .93583 m
.55345 .95601 L
.55436 .9413 L
.55557 .92181 L
.5547 .93583 L
F
.55557 .92181 m
.55436 .9413 L
.55704 .89818 L
.55812 .88071 L
.55557 .92181 L
F
.55812 .88071 m
.55704 .89818 L
.56129 .82958 L
.56217 .81532 L
.55812 .88071 L
F
.56217 .81532 m
.56129 .82958 L
.56683 .74019 L
.56745 .7301 L
.56217 .81532 L
F
.56745 .7301 m
.56683 .74019 L
.57328 .63608 L
.5736 .63086 L
.56745 .7301 L
F
.5736 .63086 m
.57328 .63608 L
.5802 .52436 L
.5802 .52436 L
.5736 .63086 L
F
.5802 .52436 m
.5802 .52436 L
.58712 .41264 L
.5868 .41786 L
.5802 .52436 L
F
.5868 .41786 m
.58712 .41264 L
.59357 .30853 L
.59295 .31862 L
.5868 .41786 L
F
.59295 .31862 m
.59357 .30853 L
.59911 .21913 L
.59823 .2334 L
.59295 .31862 L
F
.59823 .2334 m
.59911 .21913 L
.60336 .15053 L
.60228 .16801 L
.59823 .2334 L
F
.60228 .16801 m
.60336 .15053 L
.60603 .10741 L
.60483 .1269 L
.60228 .16801 L
F
.60483 .1269 m
.60603 .10741 L
.60695 .0927 L
.6057 .11288 L
.60483 .1269 L
F
.6057 .11288 m
.60695 .0927 L
.60603 .10741 L
.60483 .1269 L
.6057 .11288 L
F
.60483 .1269 m
.60603 .10741 L
.60336 .15053 L
.60228 .16801 L
.60483 .1269 L
F
.60228 .16801 m
.60336 .15053 L
.59911 .21913 L
.59823 .2334 L
.60228 .16801 L
F
.59823 .2334 m
.59911 .21913 L
.59357 .30853 L
.59295 .31862 L
.59823 .2334 L
F
.59295 .31862 m
.59357 .30853 L
.58712 .41264 L
.5868 .41786 L
.59295 .31862 L
F
.5868 .41786 m
.58712 .41264 L
.5802 .52436 L
.5802 .52436 L
.5868 .41786 L
F
.5802 .52436 m
.5802 .52436 L
.57328 .63608 L
.5736 .63086 L
.5802 .52436 L
F
.5736 .63086 m
.57328 .63608 L
.56683 .74019 L
.56745 .7301 L
.5736 .63086 L
F
.56745 .7301 m
.56683 .74019 L
.56129 .82958 L
.56217 .81532 L
.56745 .7301 L
F
.56217 .81532 m
.56129 .82958 L
.55704 .89818 L
.55812 .88071 L
.56217 .81532 L
F
.55812 .88071 m
.55704 .89818 L
.55436 .9413 L
.55557 .92181 L
.55812 .88071 L
F
.55557 .92181 m
.55436 .9413 L
.55345 .95601 L
.5547 .93583 L
.55557 .92181 L
F
.55345 .95601 m
.5522 .97619 L
.55316 .96079 L
.55436 .9413 L
.55345 .95601 L
F
.55436 .9413 m
.55316 .96079 L
.55595 .91566 L
.55704 .89818 L
.55436 .9413 L
F
.55704 .89818 m
.55595 .91566 L
.5604 .84385 L
.56129 .82958 L
.55704 .89818 L
F
.56129 .82958 m
.5604 .84385 L
.5662 .75027 L
.56683 .74019 L
.56129 .82958 L
F
.56683 .74019 m
.5662 .75027 L
.57295 .6413 L
.57328 .63608 L
.56683 .74019 L
F
.57328 .63608 m
.57295 .6413 L
.5802 .52436 L
.5802 .52436 L
.57328 .63608 L
F
.5802 .52436 m
.5802 .52436 L
.58745 .40741 L
.58712 .41264 L
.5802 .52436 L
F
.58712 .41264 m
.58745 .40741 L
.5942 .29844 L
.59357 .30853 L
.58712 .41264 L
F
.59357 .30853 m
.5942 .29844 L
.6 .20486 L
.59911 .21913 L
.59357 .30853 L
F
.59911 .21913 m
.6 .20486 L
.60445 .13306 L
.60336 .15053 L
.59911 .21913 L
F
.60336 .15053 m
.60445 .13306 L
.60724 .08792 L
.60603 .10741 L
.60336 .15053 L
F
.60603 .10741 m
.60724 .08792 L
.6082 .07252 L
.60695 .0927 L
.60603 .10741 L
F
.60695 .0927 m
.6082 .07252 L
.60724 .08792 L
.60603 .10741 L
.60695 .0927 L
F
.60603 .10741 m
.60724 .08792 L
.60445 .13306 L
.60336 .15053 L
.60603 .10741 L
F
.60336 .15053 m
.60445 .13306 L
.6 .20486 L
.59911 .21913 L
.60336 .15053 L
F
.59911 .21913 m
.6 .20486 L
.5942 .29844 L
.59357 .30853 L
.59911 .21913 L
F
.59357 .30853 m
.5942 .29844 L
.58745 .40741 L
.58712 .41264 L
.59357 .30853 L
F
.58712 .41264 m
.58745 .40741 L
.5802 .52436 L
.5802 .52436 L
.58712 .41264 L
F
.5802 .52436 m
.5802 .52436 L
.57295 .6413 L
.57328 .63608 L
.5802 .52436 L
F
.57328 .63608 m
.57295 .6413 L
.5662 .75027 L
.56683 .74019 L
.57328 .63608 L
F
.56683 .74019 m
.5662 .75027 L
.5604 .84385 L
.56129 .82958 L
.56683 .74019 L
F
.56129 .82958 m
.5604 .84385 L
.55595 .91566 L
.55704 .89818 L
.56129 .82958 L
F
.55704 .89818 m
.55595 .91566 L
.55316 .96079 L
.55436 .9413 L
.55704 .89818 L
F
.55436 .9413 m
.55316 .96079 L
.5522 .97619 L
.55345 .95601 L
.55436 .9413 L
F
0 g
.55595 .91566 m
.55678 .90232 L
.5592 .86323 L
.56305 .80105 L
.56808 .72001 L
.57392 .62563 L
.5802 .52436 L
.58647 .42308 L
.59232 .32871 L
.59734 .24767 L
.6012 .18548 L
.60362 .14639 L
.60445 .13306 L
.60362 .14639 L
.6012 .18548 L
.59734 .24767 L
.59232 .32871 L
.58647 .42308 L
.5802 .52436 L
.57392 .62563 L
.56808 .72001 L
.56305 .80105 L
.5592 .86323 L
.55678 .90232 L
.55595 .91566 L
s
.5522 .97619 m
.55316 .96079 L
.55595 .91566 L
.5604 .84385 L
.5662 .75027 L
.57295 .6413 L
.5802 .52436 L
.58745 .40741 L
.5942 .29844 L
.6 .20486 L
.60445 .13306 L
.60724 .08792 L
.6082 .07252 L
.60724 .08792 L
.60445 .13306 L
.6 .20486 L
.5942 .29844 L
.58745 .40741 L
.5802 .52436 L
.57295 .6413 L
.5662 .75027 L
.5604 .84385 L
.55595 .91566 L
.55316 .96079 L
.5522 .97619 L
s
.039 .916 .04 r
.02381 .79931 m
.56316 .79931 L
s
0 0 0 r
2 Mabswid
.56316 .79931 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .69579 m
.56958 .69579 L
s
0 0 0 r
2 Mabswid
.56958 .69579 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46317 m
.58399 .46317 L
s
0 0 0 r
2 Mabswid
.58399 .46317 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27663 m
.59555 .27663 L
s
0 0 0 r
2 Mabswid
.59555 .27663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27663 m
.59555 .27663 L
s
0 0 0 r
2 Mabswid
.59555 .27663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46317 m
.58399 .46317 L
s
0 0 0 r
2 Mabswid
.58399 .46317 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .69579 m
.56958 .69579 L
s
0 0 0 r
2 Mabswid
.56958 .69579 Mdot
.039 .916 .04 r
.5 Mabswid
.56316 .79931 m
.7409 .79931 L
s
0 0 0 r
2 Mabswid
.7409 .79931 Mdot
.039 .916 .04 r
.5 Mabswid
.56958 .69579 m
.72762 .69579 L
s
0 0 0 r
2 Mabswid
.72762 .69579 Mdot
.039 .916 .04 r
.5 Mabswid
.58399 .46317 m
.77437 .46317 L
s
0 0 0 r
2 Mabswid
.77437 .46317 Mdot
.039 .916 .04 r
.5 Mabswid
.59555 .27663 m
.70621 .27663 L
s
0 0 0 r
2 Mabswid
.70621 .27663 Mdot
.039 .916 .04 r
.5 Mabswid
.59555 .27663 m
.81455 .27663 L
s
0 0 0 r
2 Mabswid
.81455 .27663 Mdot
.039 .916 .04 r
.5 Mabswid
.58399 .46317 m
.71349 .46317 L
s
0 0 0 r
2 Mabswid
.71349 .46317 Mdot
.039 .916 .04 r
.5 Mabswid
.56958 .69579 m
.75246 .69579 L
s
0 0 0 r
2 Mabswid
.75246 .69579 Mdot
.039 .916 .04 r
.5 Mabswid
.7409 .79931 m
.84548 .55713 L
s
0 0 0 r
2 Mabswid
.84548 .55713 Mdot
.039 .916 .04 r
.5 Mabswid
.72762 .69579 m
.84108 .43302 L
s
0 0 0 r
2 Mabswid
.84108 .43302 Mdot
.039 .916 .04 r
.5 Mabswid
.77437 .46317 m
.80565 .65782 L
s
0 0 0 r
2 Mabswid
.80565 .65782 Mdot
.039 .916 .04 r
.5 Mabswid
.70621 .27663 m
.78339 .75688 L
s
0 0 0 r
2 Mabswid
.78339 .75688 Mdot
.039 .916 .04 r
.5 Mabswid
.81455 .27663 m
.82591 .34729 L
s
0 0 0 r
2 Mabswid
.82591 .34729 Mdot
.039 .916 .04 r
.5 Mabswid
.71349 .46317 m
.81647 .4383 L
s
0 0 0 r
2 Mabswid
.81647 .4383 Mdot
.039 .916 .04 r
.5 Mabswid
.75246 .69579 m
.82597 .67804 L
s
0 0 0 r
2 Mabswid
.82597 .67804 Mdot
.039 .916 .04 r
.5 Mabswid
.84548 .55713 m
.81175 .34723 L
s
0 0 0 r
2 Mabswid
.81175 .34723 Mdot
.039 .916 .04 r
.5 Mabswid
.84108 .43302 m
.76764 .45076 L
s
0 0 0 r
2 Mabswid
.76764 .45076 Mdot
.039 .916 .04 r
.5 Mabswid
.80565 .65782 m
.69985 .68337 L
s
0 0 0 r
2 Mabswid
.69985 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.78339 .75688 m
.73458 .86992 L
s
0 0 0 r
2 Mabswid
.73458 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.82591 .34729 m
.60024 .86992 L
s
0 0 0 r
2 Mabswid
.60024 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.81647 .4383 m
.71065 .68337 L
s
0 0 0 r
2 Mabswid
.71065 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.82597 .67804 m
.78945 .45076 L
s
0 0 0 r
2 Mabswid
.78945 .45076 Mdot
.039 .916 .04 r
.5 Mabswid
.81175 .34723 m
.59117 .34723 L
s
0 0 0 r
2 Mabswid
.59117 .34723 Mdot
.039 .916 .04 r
.5 Mabswid
.76764 .45076 m
.58476 .45076 L
s
0 0 0 r
2 Mabswid
.58476 .45076 Mdot
.039 .916 .04 r
.5 Mabswid
.69985 .68337 m
.57035 .68337 L
s
0 0 0 r
2 Mabswid
.57035 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.73458 .86992 m
.55879 .86992 L
s
0 0 0 r
2 Mabswid
.55879 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.60024 .86992 m
.55879 .86992 L
s
0 0 0 r
2 Mabswid
.55879 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.71065 .68337 m
.57035 .68337 L
s
0 0 0 r
2 Mabswid
.57035 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.78945 .45076 m
.58476 .45076 L
s
0 0 0 r
2 Mabswid
.58476 .45076 Mdot
.039 .916 .04 r
.5 Mabswid
.59117 .34723 m
.02381 .34723 L
s
0 0 0 r
2 Mabswid
.02381 .34723 Mdot
.039 .916 .04 r
.5 Mabswid
.58476 .45076 m
.02381 .45076 L
s
0 0 0 r
2 Mabswid
.02381 .45076 Mdot
.039 .916 .04 r
.5 Mabswid
.57035 .68337 m
.02381 .68337 L
s
0 0 0 r
2 Mabswid
.02381 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.55879 .86992 m
.02381 .86992 L
s
0 0 0 r
2 Mabswid
.02381 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.55879 .86992 m
.02381 .86992 L
s
0 0 0 r
2 Mabswid
.02381 .86992 Mdot
.039 .916 .04 r
.5 Mabswid
.57035 .68337 m
.02381 .68337 L
s
0 0 0 r
2 Mabswid
.02381 .68337 Mdot
.039 .916 .04 r
.5 Mabswid
.58476 .45076 m
.02381 .45076 L
s
0 0 0 r
2 Mabswid
.02381 .45076 Mdot
[(CornerCube)] .57925 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{185, 185},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002i0000^B000`400?l00000o`00003o^@3oool0
0;T0oooo002i0?ooo`00E03oool3000000<0oooo0`0000020?ooo`80000000<0oooo0000003oool0
0P0000000`3oool00000000000020?ooo`8000000`3oool3000000<0oooo0`000000103oool00000
0000000000020?ooo`800000>03oool005<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`02000003X0oooo001B0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00@000000?ooo`000000oooo100000001@3oool000000?ooo`3oool0
000000H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05000003L0oooo001B0?oo
o`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
103oool00`000000oooo000000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo
0?ooo`0e0?ooo`00DP3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000000000001000
00030?ooo`80000000H0oooo00000000000000000?ooo`0000050?ooo`80000000@0oooo0000003o
ool0oooo0`0000020?ooo`800000>03oool005<0oooo00<000000?ooo`3oool00P00000G0?ooo`03
0000003oool0oooo008000001P3oool00`000000oooo0?ooo`0l0?ooo`00E03oool2000000030?oo
o`000000oooo01L0oooo0P0000000`3oool000000?ooo`040?ooo`800000?P3oool00;T0oooo002i
0?ooo`00^@3oool00;T0oooo001_0?ooo`030000003oool0oooo04L0oooo001_0?ooo`030000003o
ool0oooo04L0oooo001_0?ooo`030000003oool0oooo04L0oooo001_0?ooo`030000003oool0oooo
04L0oooo001_0?ooo`030000003oool0oooo04L0oooo001_0?ooo`030000003oool0oooo04L0oooo
001_0?ooo`030000003oool0oooo04L0oooo001_0?ooo`030000003oool0oooo04L0oooo001_0?oo
o`030000003oool0oooo04L0oooo001_0?ooo`030000003oool0oooo04L0oooo001_0?ooo`030000
003oool0oooo04L0oooo001_0?ooo`D00000A@3oool006l0oooo00<0000007moO`1oOgl00P1oOgl8
000003d0oooo001_0?ooo`8000002`1oOgl7000003H0oooo001_0?ooo`030000001oOgl000000140
Ogmo2000000^0?ooo`00K`3oool00`000000Ogmo0000000I07moO`@00000:P3oool006h0oooo00D0
Ogmo0000001oOgl0Ogmo0000000K07moO`030000003oool0oooo02P0oooo001^0?ooo`0307moO`00
0000Ogmo0080Ogmo00<0000007moO`1oOgl0601oOgl2000002T0oooo001^0?ooo`8000000`1oOgl0
0`000000Ogmo07moO`0H07moO`800000:@3oool006h0oooo0P00000407moO`030000001oOgl0Ogmo
01L0Ogmo00<0000007moO`000000:03oool006h0oooo0P00000507moO`030000001oOgl0Ogmo01H0
Ogmo00<0000007moO`000000:03oool006h0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0E07moO`040000001oOgl0Ogmo000002L0oooo001^0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl05@1oOgl010000000Ogmo07moO`00000W0?ooo`00KP3oool00`000000Ogmo
07moO`0607moO`030000001oOgl0Ogmo01@0Ogmo00D0000007moO`1oOgl0Ogmo0000000V0?ooo`00
KP3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01<0Ogmo00D0000007moO`1oOgl0
Ogmo0000000V0?ooo`00KP3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0S0?ooo`00KP3oool00`000000Ogmo07mo
O`0807moO`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0S0?ooo`00K@3oool2000000/0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo0280oooo001]0?ooo`8000002`1oOgl00`000000Ogmo07moO`0A07mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool006d0oooo0`00000;07moO`03
0000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`00
K@3oool20000000307moO`000000Ogmo00X0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo0240oooo001]0?ooo`<0000000<0Ogmo0000001oOgl02@1o
Ogl00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08@3o
ool006d0oooo0`00000207moO`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl03P1oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo0200oooo001]0?ooo`040000003oool0oooo
00000080Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0=07moO`030000001oOgl0
Ogmo00D0Ogmo00<000000?ooo`3oool0803oool006d0oooo00@000000?ooo`3oool000000`1oOgl2
000000T0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0607moO`030000003oool0
oooo01l0oooo001]0?ooo`050000003oool0oooo0?ooo`000000101oOgl00`000000Ogmo07moO`06
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`0O
0?ooo`00K@3oool01@000000oooo0?ooo`3oool0000000D0Ogmo00<0000007moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool07P3oool0
00@0ooooTP09jPX00`000000Ogmo0000000P0?ooo`00K@3oool2000000<0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`0300WZ2P000000Ogmo00X0Ogmo00<0000007moO`1o
Ogl0101oOgl01@09jPX0000007moO`1oOgl0000001l0oooo001]0?ooo`030000003oool0oooo0080
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`0300WZ2P000000Ogmo00X0
Ogmo00<0000007moO`1oOgl0101oOgl01@09jPX0Ogmo07moO`1oOgl0000001l0oooo001/0?ooo`80
00001@3oool00`000000Ogmo07moO`0507moO`800000101oOgl00`09jPX0Ogmo0000000:07moO`03
0000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0L0?ooo`00
K03oool2000000D0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0207moO`0300WZ
2P000000Ogmo00T0Ogmo00<0000007moO`1oOgl01@1oOgl01@09jPX0Ogmo07moO`1oOgl0000001h0
oooo001/0?ooo`8000001P3oool00`000000Ogmo07moO`0707moO`070000001oOgl0Ogmo07moO`09
jPX0Ogmo0000000907moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`00
0000oooo0?ooo`0K0?ooo`00K03oool2000000H0oooo00<0000007moO`1oOgl0201oOgl010000000
Ogmo07moO`09jPX207moO`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl01@1oOgl00`09
jPX0Ogmo07moO`0207moO`030000003oool0oooo01/0oooo001/0?ooo`8000001`3oool00`000000
Ogmo07moO`0807moO`030000001oOgl02NX:0080Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06P3oool006`0oooo
0P0000070?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000000WZ2P1oOgl00P1oOgl00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0J0?ooo`00K03oool2000000P0oooo00<0000007moO`1oOgl02@1oOgl00`09jPX0000007mo
O`0207moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`09jPX0Ogmo07mo
O`0407moO`030000003oool0oooo01T0oooo001/0?ooo`800000203oool00`000000Ogmo07moO`0:
07moO`0500WZ2P000000Ogmo07moO`0000001P1oOgl00`000000Ogmo07moO`0507moO`0300WZ2P1o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool06@3oool006`0oooo0P0000090?ooo`030000001oOgl0
Ogmo00T0Ogmo00<02NX:07moO`0000000P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00H0Ogmo00<02NX:07moO`1oOgl0101oOgl00`000000oooo0?ooo`0H0?ooo`00K03oool20000
00T0oooo00<0000007moO`1oOgl02@1oOgl01009jPX0Ogmo07moO`00000207moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0407moO`030000003oool0
oooo01P0oooo00030?ooo`800000J009jPX00`0000002NX:00WZ2P0V00WZ2P0307moO`09jPX00000
00H0Ogmo00<000000?ooo`3oool05`3oool000<0oooo0P00001W0?ooo`8000001`3oool010000000
Ogmo07moO`00000:07moO`0300WZ2P1oOgl0Ogmo0080Ogmo0`00000307moO`030000001oOgl0Ogmo
00<0Ogmo0P0000000`1oOgl02NX:0000000607moO`030000003oool0oooo01L0oooo001/0?ooo`03
0000003oool0oooo00D0oooo00D0000007moO`1oOgl0Ogmo0000000:07moO`0300WZ2P1oOgl0Ogmo
00@0Ogmo0P00000207moO`030000001oOgl0Ogmo00@0Ogmo0P09jPX907moO`030000003oool0oooo
01H0oooo001/0?ooo`030000003oool0oooo00D0oooo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00@0Ogmo0P0000000`1oOgl0000007moO`0507moO`80
2NX:2@1oOgl00`000000oooo0?ooo`0F0?ooo`00K03oool00`000000oooo0?ooo`040?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0507moO`030000
001oOgl0000000L0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo0?ooo`0E0?ooo`00K03o
ool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01`1o
Ogl00`09jPX0Ogmo07moO`0607moO`8000001P1oOgl200WZ2PX0Ogmo00<000000?ooo`3oool05@3o
ool006/0oooo0P0000050?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01`1oOgl0
0`09jPX0Ogmo07moO`0707moO`8000001@1oOgl200WZ2PX0Ogmo00<000000?ooo`3oool05@3oool0
06/0oooo0P0000040?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P1oOgl00`09
jPX0Ogmo07moO`0707moO`030000001oOgl0000000<0Ogmo00<02NX:07moO`09jPX02`1oOgl00`00
0000oooo0?ooo`0D0?ooo`00J`3oool2000000<0oooo00<0000007moO`1oOgl0201oOgl00`000000
Ogmo07moO`0607moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00@0000007moO`1oOgl000000P1oOgl00`09
jPX0Ogmo00WZ2P0;07moO`030000003oool0oooo01@0oooo001[0?ooo`8000000`3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl01P1oOgl01P000000
Ogmo07moO`1oOgl0000000WZ2P80Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`0C
0?ooo`00J`3oool200000080oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0607mo
O`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl01009jPX0Ogmo07moO`09jPX<
07moO`030000003oool0oooo01<0oooo001[0?ooo`80000000<0oooo0000001oOgl03@1oOgl00`00
0000Ogmo07moO`0507moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl01@09
jPX0000007moO`1oOgl02NX:00`0Ogmo00<000000?ooo`3oool04P3oool006/0oooo0`00000?07mo
O`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0207mo
O`0600WZ2P1oOgl0Ogmo0000001oOgl02NX:301oOgl00`000000oooo0?ooo`0B0?ooo`00J`3oool3
00000100Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0507moO`030000001oOgl0
Ogmo0080Ogmo00H02NX:07moO`1oOgl0Ogmo00000009jPX=07moO`030000003oool0oooo0140oooo
001[0?ooo`8000004@1oOgl00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00D0Ogmo00D0
000007moO`1oOgl0Ogmo00WZ2P0507moO`0300WZ2P1oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
4@3oool006/0oooo0P00000B07moO`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl0101o
Ogl01@000000Ogmo07moO`1oOgl02NX:00D0Ogmo00<02NX:0000001oOgl0301oOgl00`000000oooo
0?ooo`0@0?ooo`00J`3oool400000100Ogmo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07mo
O`0307moO`050000001oOgl0Ogmo07moO`09jPX01P1oOgl400WZ2P030000001oOgl0Ogmo00P0Ogmo
00<000000?ooo`3oool0403oool006/0oooo0P00000207moO`8000003P1oOgl00`000000Ogmo07mo
O`0407moO`0300WZ2P1oOgl0Ogmo00<0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0307moO`D02NX:
00<0Ogmo0000000000002`1oOgl00`000000oooo0?ooo`0?0?ooo`00J`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0307moO`040000001oOgl0Ogmo07moO`D02NX:00<0000000WZ2P1oOgl00P09jPX00`1oOgl00000
07moO`0:07moO`030000003oool0oooo00l0oooo00030?ooo`800000IP3oool2000000D0Ogmo0P00
000<07moO`030000001oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00`1oOgl2000000802NX:0P00
000307moO`0300WZ2P1oOgl0Ogmo00802NX:0P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo00h0oooo00030?ooo`800000I`09jPX00`0000002NX:00WZ2P0S00WZ2P<0Ogmo00@02NX:
07moO`1oOgl02NX:101oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00h0oooo001Z
0?ooo`8000002P1oOgl2000000T0Ogmo0`0000000`1oOgl02NX:00WZ2P0200WZ2P<0Ogmo0P000000
1009jPX0Ogmo07moO`09jPX207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX01@1oOgl00`000000Ogmo
07moO`0807moO`030000003oool0oooo00d0oooo00040?ooofH02NX:00<0000000WZ2P09jPX05@09
jPX00`0000002NX:00WZ2P0800WZ2P0500000009jPX0Ogmo07moO`09jPX00P1oOgl01@09jPX0Ogmo
07moO`1oOgl02NX:00H0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0=0?ooo`00
J`3oool00`000000Ogmo07moO`0<07moO`8000001P1oOgl00`000000Ogmo07moO`0207moO`0600WZ
2P1oOgl0Ogmo07moO`000000Ogmo0P09jPX207moO`0400WZ2P1oOgl0Ogmo00WZ2P80Ogmo0P09jPX7
07moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0303oool006X0oooo0P00000@07mo
O`030000001oOgl0Ogmo00@0Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0307moO`040000001oOgl0
2NX:00WZ2P<0Ogmo0P09jPX307moO`0300WZ2P1oOgl02NX:00L0Ogmo00<0000007moO`1oOgl01P1o
Ogl00`000000oooo0?ooo`0<0?ooo`00JP3oool200000140Ogmo0P00000407moO`050000001oOgl0
Ogmo07moO`09jPX00`1oOgl010000000Ogmo00WZ2P09jPX307moO`802NX:0P1oOgl01009jPX0Ogmo
07moO`09jPX807moO`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool02`3oool006X0oooo
0P00000C07moO`8000000`1oOgl010000000Ogmo07moO`09jPX307moO`0500000009jPX0Ogmo07mo
O`09jPX00P1oOgl01@09jPX0Ogmo07moO`1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl01`1oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo00/0oooo001Z0?ooo`8000005@1oOgl20000
000307moO`000000Ogmo0080Ogmo00D02NX:07moO`1oOgl0000000WZ2P0207moO`0400WZ2P1oOgl0
Ogmo00WZ2P80Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0:07moO`030000001oOgl0Ogmo00D0Ogmo
00<000000?ooo`3oool02P3oool006X0oooo0P00000G07moO`<000000P1oOgl01009jPX0Ogmo07mo
O`09jPX307moO`0400WZ2P1oOgl02NX:00WZ2P80Ogmo00D02NX:07moO`1oOgl0Ogmo00WZ2P0;07mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool02P3oool006X0oooo00<0000007moO`1o
Ogl0601oOgl01`000000Ogmo07moO`09jPX0Ogmo00000009jPX00`1oOgl01009jPX0Ogmo00WZ2P09
jPX207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX0301oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0Ogmo01T0Ogmo00H0000007moO`09jPX0Ogmo
00000009jPX307moO`802NX:00@0Ogmo00WZ2P1oOgl02NX:1@1oOgl00`09jPX0Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool006X0oooo00<0000007moO`1o
Ogl06@1oOgl01@000000Ogmo00WZ2P1oOgl02NX:00@0Ogmo0P09jPX207moO`802NX:1@1oOgl00`09
jPX0Ogmo07moO`0;07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool02@3oool006X0
oooo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0200WZ2PD0Ogmo00@02NX:07moO`1o
Ogl02NX:1P1oOgl00`09jPX0Ogmo07moO`0<07moO`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool0203oool006X0oooo00<0000007moO`1oOgl06P1oOgl010000000Ogmo00WZ2P00000407mo
O`802NX:0P1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00d0Ogmo00D0000007mo
O`1oOgl0Ogmo0000000:0?ooo`00JP3oool00`000000Ogmo07moO`0J07moO`040000001oOgl02NX:
000000@0Ogmo0P09jPX00`1oOgl02NX:00WZ2P0607moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00D00000
07moO`1oOgl0Ogmo000000090?ooo`00JP3oool00`000000Ogmo07moO`0J07moO`0300000009jPX0
2NX:00@0Ogmo00@02NX:07moO`09jPX0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00@0
000007moO`1oOgl000002@3oool006X0oooo00<0000007moO`1oOgl0601oOgl20000000307moO`09
jPX02NX:00@0Ogmo00@02NX:07moO`09jPX0Ogmo0P09jPX607moO`0300WZ2P1oOgl0Ogmo0100Ogmo
00@0000007moO`1oOgl00000203oool006X0oooo00<0000007moO`1oOgl05P1oOgl2000000<0Ogmo
0P09jPX30000000300WZ2P1oOgl0Ogmo00802NX:00<0Ogmo00WZ2P1oOgl01P1oOgl00`09jPX0Ogmo
07moO`0@07moO`030000001oOgl0000000P0oooo001Z0?ooo`030000001oOgl0Ogmo01@0Ogmo0P00
000407moO`0400WZ2P1oOgl0000000WZ2P80Ogmo00D02NX:000000000000000000WZ2P0200000003
00WZ2P000000000000@0Ogmo00<02NX:07moO`1oOgl04@1oOgl00`000000Ogmo000000070?ooo`00
JP3oool00`000000Ogmo07moO`0B07moO`8000001P1oOgl01P09jPX0000000000009jPX0Ogmo00WZ
2P<0Ogmo0P09jPX207moO`0300WZ2P1oOgl0Ogmo00@0000000@02NX:00000000000000004@1oOgl2
000000L0oooo001Z0?ooo`030000001oOgl0Ogmo0100Ogmo0P00000707moO`0700WZ2P000000Ogmo
00000009jPX0Ogmo00WZ2P0307moO`802NX:0P1oOgl00`09jPX0Ogmo07moO`0407moO`8000000P1o
Ogl8000000X0Ogmo0P0000060?ooo`00JP3oool00`000000Ogmo07moO`0>07moO`8000002@1oOgl0
1`09jPX0000007moO`0000002NX:07moO`09jPX00P1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ
2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl02P1oOgl900000080Ogmo00<000000?ooo`3oool0
103oool006X0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0807moO`0500WZ2P00
0000Ogmo07moO`0000000P09jPX307moO`0300WZ2P1oOgl02NX:0080Ogmo00<02NX:07moO`1oOgl0
0`1oOgl00`09jPX0Ogmo07moO`0C07moO`@000001@3oool006T0oooo0P00000=07moO`8000002`1o
Ogl01@09jPX0Ogmo07moO`1oOgl0000000802NX:0`1oOgl00`09jPX0Ogmo00WZ2P0207moO`0300WZ
2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0501oOgl00`000000Ogmo000000050?ooo`00J@3o
ool2000000/0Ogmo0P00000=07moO`0500WZ2P1oOgl0Ogmo07moO`0000000P09jPX207moO`0700WZ
2P1oOgl0Ogmo07moO`09jPX0Ogmo00WZ2P0407moO`0300WZ2P1oOgl0Ogmo01@0Ogmo00<0000007mo
O`0000001P3oool006T0oooo00<0000007moO`1oOgl0201oOgl2000000h0Ogmo00<02NX:07moO`1o
Ogl00P1oOgl00`0000002NX:00WZ2P0207moO`0500WZ2P1oOgl0Ogmo07moO`09jPX00P1oOgl01@09
jPX0Ogmo07moO`1oOgl02NX:01@0Ogmo0P0000000`1oOgl000000?ooo`060?ooo`00J@3oool00`00
0000Ogmo07moO`0607moO`8000003`1oOgl00`0000002NX:07moO`0307moO`0500WZ2P1oOgl02NX:
07moO`09jPX0101oOgl01009jPX0Ogmo07moO`09jPX207moO`0300WZ2P1oOgl0Ogmo0180Ogmo00D0
000007moO`1oOgl0Ogmo000000070?ooo`00J@3oool00`000000Ogmo07moO`0407moO`8000004@1o
Ogl00`09jPX0Ogmo07moO`0307moO`0500WZ2P1oOgl02NX:07moO`09jPX0101oOgl01009jPX0Ogmo
07moO`09jPX207moO`0300WZ2P1oOgl0Ogmo0140Ogmo00D0000007moO`1oOgl0Ogmo000000080?oo
o`00J@3oool00`000000Ogmo07moO`0207moO`8000004P1oOgl00`0000002NX:07moO`0307moO`03
00WZ2P000000Ogmo00802NX:1@1oOgl01P09jPX0Ogmo07moO`09jPX0Ogmo00WZ2Q80Ogmo0P000003
07moO`030000003oool0oooo00L0oooo001Y0?ooo`030000001oOgl0Ogmo008000004`1oOgl00`00
00002NX:07moO`0407moO`0300WZ2P000000Ogmo00802NX:1@1oOgl01P09jPX0Ogmo07moO`09jPX0
Ogmo00WZ2Q40Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`070?ooo`00J@3oool3
000001@0Ogmo00<0000007moO`09jPX01@1oOgl01@09jPX0000007moO`1oOgl02NX:00H0Ogmo00D0
2NX:07moO`09jPX0Ogmo00WZ2P0@07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
203oool006T0oooo00<0000007moO`1oOgl0501oOgl00`000000Ogmo00WZ2P0407moO`0400WZ2P1o
Ogl0000007moO`802NX:1P1oOgl01009jPX0Ogmo00WZ2P09jPX?07moO`8000001@1oOgl00`000000
oooo0?ooo`090?ooo`00J@3oool00`000000Ogmo07moO`0C07moO`030000001oOgl02NX:00D0Ogmo
00@02NX:07moO`000000Ogmo0P09jPX607moO`0400WZ2P1oOgl0Ogmo00WZ2Ph0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0:0?ooo`00J@3oool2000001<0Ogmo00@0000007moO`1o
Ogl02NX:101oOgl01`09jPX0Ogmo07moO`0000002NX:07moO`09jPX01P1oOgl01009jPX0Ogmo00WZ
2P09jPX=07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool02P3oool006T0oooo0P00
000C07moO`030000001oOgl02NX:00D0Ogmo00L02NX:07moO`1oOgl0000000WZ2P1oOgl02NX:00H0
Ogmo00@02NX:07moO`09jPX02NX:2`1oOgl2000000L0Ogmo00<000000?ooo`3oool02`3oool006T0
oooo00<000000?ooo`0000004@1oOgl010000000Ogmo07moO`09jPX407moO`0500WZ2P1oOgl0Ogmo
07moO`09jPX00P1oOgl00`09jPX0Ogmo07moO`0407moO`802NX:00<0Ogmo00WZ2P1oOgl02@1oOgl0
0`000000Ogmo07moO`0607moO`030000003oool0oooo00`0oooo001Y0?ooo`030000003oool00000
0100Ogmo00D0000007moO`1oOgl0Ogmo00WZ2P0407moO`0600WZ2P1oOgl0Ogmo07moO`09jPX00000
0P1oOgl00`09jPX0Ogmo07moO`0407moO`0300WZ2P1oOgl02NX:00T0Ogmo00<0000007moO`1oOgl0
1`1oOgl00`000000oooo0?ooo`0<0?ooo`00J@3oool010000000oooo0?ooo`00000?07moO`040000
001oOgl0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1oOgl00P1oOgl01@09jPX0000007moO`1oOgl02NX:
00D0Ogmo0P0000000`1oOgl02NX:07moO`0607moO`8000002@1oOgl00`000000oooo0?ooo`0=0?oo
o`00J@3oool010000000oooo0?ooo`00000>07moO`050000001oOgl0Ogmo07moO`09jPX0101oOgl0
1`09jPX0Ogmo07moO`1oOgl02NX:07moO`0000000P1oOgl00`09jPX0Ogmo07moO`0207moO`<02NX:
00<0Ogmo00WZ2P1oOgl01@1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo00h0oooo
001Y0?ooo`050000003oool0oooo0?ooo`000000301oOgl01@000000Ogmo07moO`1oOgl02NX:00D0
Ogmo00L02NX:07moO`1oOgl0Ogmo00WZ2P1oOgl000000080Ogmo1@09jPX00`1oOgl02NX:07moO`02
07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0>
0?ooo`00J@3oool01@000000oooo0?ooo`3oool0000000`0Ogmo00D0000007moO`1oOgl0Ogmo00WZ
2P0407moO`0400WZ2P1oOgl0Ogmo07moO`L02NX:101oOgl00`09jPX0Ogmo07moO`0207moO`0500WZ
2P1oOgl0Ogmo07moO`0000002`1oOgl00`000000oooo0?ooo`0?0?ooo`00J03oool2000000@0oooo
00<0000007moO`1oOgl0201oOgl01@000000Ogmo07moO`1oOgl02NX:00D0Ogmo1@09jPX207moO`04
0000001oOgl0Ogmo00WZ2P@0Ogmo00<02NX:07moO`1oOgl00`09jPX3000000/0Ogmo00<000000?oo
o`3oool0403oool000<0oooo0P00001T00WZ2P0300000009jPX02NX:01L02NX:00@0000007moO`1o
Ogl02NX:0`1oOgl01@000000Ogmo07moO`1oOgl02NX:0080Ogmo1009jPX207moO`8000003@1oOgl0
0`000000oooo0?ooo`0@0?ooo`000`3oool2000006<0oooo0P0000050?ooo`030000001oOgl0Ogmo
00H0Ogmo00<0000007moO`1oOgl00P1oOgl00`09jPX0Ogmo07moO`0400000080Ogmo00D02NX:07mo
O`1oOgl0Ogmo0000000307moO`@02NX:1@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo0140oooo001X0?ooo`8000001@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
0080Ogmo00<02NX:07moO`1oOgl01P1oOgl0100000002NX:07moO`1oOgl20000000407moO`09jPX0
2NX:00WZ2P80Ogmo00@02NX:07moO`1oOgl0Ogmo0P00000=07moO`030000003oool0oooo0180oooo
00040?ooohD02NX:00<0000000WZ2P09jPX00P1oOgl00`09jPX0Ogmo00WZ2P0307moO`030000001o
Ogl0Ogmo00d0Ogmo00<000000?ooo`3oool04P3oool006P0oooo00<000000?ooo`3oool01@3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<02NX:07moO`1oOgl0301oOgl0
1`000000Ogmo07moO`1oOgl02NX:07moO`09jPX00P1oOgl00`000000Ogmo07moO`0=07moO`030000
003oool0oooo01<0oooo001X0?ooo`030000003oool0oooo00D0oooo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0307moO`0300WZ2P1oOgl0Ogmo00`0Ogmo00@0000007moO`1oOgl0Ogmo
0P09jPX00`1oOgl000000000000?07moO`030000003oool0oooo01@0oooo001X0?ooo`030000003o
ool0oooo00H0oooo00@0000007moO`1oOgl000001@1oOgl00`09jPX0Ogmo07moO`0=07moO`030000
001oOgl0Ogmo0080Ogmo00<02NX:0000001oOgl03`1oOgl00`000000oooo0?ooo`0E0?ooo`00J03o
ool00`000000oooo0?ooo`060?ooo`040000001oOgl0Ogmo000000D0Ogmo00<02NX:07moO`1oOgl0
3@1oOgl00`000000Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool0
5@3oool006P0oooo00<000000?ooo`3oool01`3oool2000000H0Ogmo00<02NX:07moO`1oOgl03@1o
Ogl010000000Ogmo07moO`00000200WZ2Q00Ogmo00<000000?ooo`3oool05P3oool006P0oooo00<0
00000?ooo`3oool01`3oool00`000000Ogmo07moO`0407moO`0300WZ2P1oOgl0Ogmo00h0Ogmo00@0
000007moO`000000Ogmo0P09jPX?07moO`030000003oool0oooo01L0oooo001X0?ooo`030000003o
ool0oooo00L0oooo00<0000007moO`1oOgl0101oOgl00`09jPX0Ogmo07moO`0>07moO`80000000@0
Ogmo00WZ2P1oOgl02NX:3`1oOgl00`000000oooo0?ooo`0G0?ooo`00J03oool00`000000oooo0?oo
o`060?ooo`030000001oOgl0Ogmo00@0Ogmo00<02NX:07moO`1oOgl03P1oOgl200000080Ogmo00<0
2NX:07moO`09jPX03P1oOgl00`000000oooo0?ooo`0H0?ooo`00J03oool00`000000oooo0?ooo`05
0?ooo`030000001oOgl0Ogmo00D0Ogmo00<02NX:07moO`1oOgl02`1oOgl30000000407moO`000000
Ogmo00WZ2P<0Ogmo00<02NX:07moO`1oOgl02P1oOgl00`000000oooo0?ooo`0I0?ooo`00J03oool0
0`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`1oOgl02@1oOgl2
0000000707moO`000000Ogmo07moO`000000Ogmo00WZ2P0207moO`800000301oOgl00`000000oooo
0?ooo`0I0?ooo`00J03oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
2NX:07moO`1oOgl01`1oOgl300000080Ogmo00L0000007moO`1oOgl0Ogmo0000001oOgl02NX:0080
Ogmo00<0000000WZ2P1oOgl02P1oOgl00`000000oooo0?ooo`0J0?ooo`00I`3oool2000000D0oooo
00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07moO`0507moO`800000101oOgl00`000000Ogmo
07moO`0207moO`0300000009jPX0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0201oOgl00`000000oooo
0?ooo`0K0?ooo`00I`3oool2000000@0oooo00<0000007moO`1oOgl01P1oOgl00`09jPX0Ogmo07mo
O`0307moO`<000001@1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00<0
2NX:07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0K0?ooo`00I`3oool2000000@0oooo00<00000
07moO`1oOgl01P1oOgl01009jPX0Ogmo07moO`1oOgl2000000L0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`0000002NX:07moO`0307moO`0300WZ2P1oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0703o
ool006L0oooo0P0000030?ooo`030000001oOgl0Ogmo00H0Ogmo00<02NX:07moO`0000000P000008
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000000WZ2P1oOgl00P1oOgl00`09jPX0Ogmo07moO`08
07moO`030000003oool0oooo01d0oooo001W0?ooo`8000000P3oool00`000000Ogmo07moO`0707mo
O`0300WZ2P000000Ogmo00P0Ogmo0P00000707moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<02NX:07mo
O`1oOgl0201oOgl00`000000oooo0?ooo`0M0?ooo`00I`3oool200000080oooo00<0000007moO`1o
Ogl0101oOgl30000000300WZ2P1oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01`1oOgl00`09jPX0
Ogmo07moO`0207moO`0300WZ2P1oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool07P3oool006L0oooo
0P0000000`3oool0000007moO`0407moO`8000000P1oOgl00`09jPX0Ogmo07moO`0707moO`030000
001oOgl0Ogmo00H0Ogmo0P0000001@09jPX0Ogmo07moO`1oOgl02NX:00T0Ogmo00<000000?ooo`3o
ool07`3oool000@0ooooP`09jPX00`0000002NX:0000000307moO`0300WZ2P1oOgl0Ogmo00L0Ogmo
00<000000?ooo`3oool07`3oool006L0oooo00@000000?ooo`000000Ogmo0P00000607moO`0300WZ
2P1oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02@1oOgl01@000000Ogmo07moO`1oOgl02NX:00T0
Ogmo00<000000?ooo`3oool0803oool006L0oooo1000000807moO`0300WZ2P1oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl02P1oOgl01@000000Ogmo07moO`1oOgl02NX:00P0Ogmo00<000000?ooo`3o
ool08@3oool006L0oooo00<0000007moO`1oOgl0201oOgl00`09jPX0Ogmo07moO`0507moO`030000
001oOgl0Ogmo00/0Ogmo00@0000007moO`1oOgl02NX:201oOgl00`000000oooo0?ooo`0R0?ooo`00
I`3oool00`000000Ogmo07moO`0807moO`0300WZ2P1oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
301oOgl010000000Ogmo07moO`09jPX807moO`030000003oool0oooo0280oooo001W0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<02NX:07moO`1oOgl00P1oOgl2000000l0Ogmo00@0000007moO`1oOgl0
2NX:1`1oOgl00`000000oooo0?ooo`0S0?ooo`00IP3oool2000000T0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0?07moO`030000001oOgl02NX:00L0Ogmo00<000000?ooo`3oool0
903oool006H0oooo0P00000907moO`0500WZ2P1oOgl0Ogmo07moO`0000004P1oOgl00`000000Ogmo
00WZ2P0707moO`030000003oool0oooo02@0oooo001V0?ooo`800000201oOgl01@09jPX0Ogmo07mo
O`1oOgl000000180Ogmo00<0000007moO`09jPX01`1oOgl00`000000oooo0?ooo`0U0?ooo`00IP3o
ool2000000P0Ogmo00@02NX:07moO`1oOgl000004`1oOgl00`000000Ogmo00WZ2P0607moO`030000
003oool0oooo02H0oooo001V0?ooo`8000001`1oOgl01009jPX0Ogmo07moO`00000D07moO`030000
0009jPX0Ogmo00H0Ogmo00<000000?ooo`3oool09P3oool006H0oooo0P00000707moO`0300WZ2P1o
Ogl0000001D0Ogmo00<0000000WZ2P1oOgl01@1oOgl00`000000oooo0?ooo`0W0?ooo`000`3oool2
00000640oooo0P00000507moO`80000000<02NX:0000001oOgl0501oOgl20000000300WZ2P1oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool000<0oooo0P00001R00WZ2P0300000009jPX02NX:
01h02NX:1P1oOgl00`000000oooo0?ooo`0X0?ooo`00IP3oool2000000D0Ogmo00<0000007moO`1o
Ogl05`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02T0oooo001V0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02X0oooo001V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0601o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo02X0oooo001V0?ooo`050000001oOgl0
Ogmo07moO`0000006`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02/0oooo001V
0?ooo`040000001oOgl0Ogmo000001`0Ogmo00D0000007moO`1oOgl0Ogmo0000000^0?ooo`00IP3o
ool00`000000Ogmo0000000M07moO`040000001oOgl0Ogmo000002l0oooo001V0?ooo`8000007P1o
Ogl010000000Ogmo07moO`00000_0?ooo`00IP3oool5000001/0Ogmo00<0000007moO`000000<03o
ool006H0oooo00<000000?ooo`3oool00P3oool800000180Ogmo00<0000007moO`000000<@3oool0
06H0oooo00<000000?ooo`3oool02P3oool7000000/0Ogmo00<0000007moO`000000<@3oool006D0
oooo00<0Ogmo0000003oool04P3oool8000000<0Ogmo0P00000b0?ooo`00I@3oool00`1oOgl00000
0?ooo`0J0?ooo`@00000<`3oool006D0oooo00<000000?ooo`3oool0D@3oool006D0oooo00<00000
0?ooo`3oool0D@3oool006D0oooo00<000000?ooo`3oool0D@3oool006D0oooo00<000000?ooo`3o
ool0D@3oool006D0oooo00<000000?ooo`3oool0D@3oool006D0oooo00<000000?ooo`3oool0D@3o
ool006D0oooo00<000000?ooo`3oool0D@3oool00;T0oooo002i0?ooo`00^@3oool00;T0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 184}, {184, 0}} -> {-2.16987, -33.4162, 0.488725, \
0.346139}},
  CellTags->"HollowCornerCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SolidCornerCube[diameter, length, options]", "Subsection",
  CellTags->"SolidCornerCube"],

Cell[CellGroupData[{

Cell["?SolidCornerCube", "Input",
  CellTags->"SolidCornerCube"],

Cell[BoxData[
    \("SolidRetroReflector[diameter, length, options] refers to a four-sided \
retro-reflective prism arrangement having a single circular entrance/exit \
face located in the y-z plane and its length  located along the positive \
x-axis, with three internally reflecting surfaces. \n\nSolidRetroReflector \
behaves like a corner cube. Normally, the length parameter specifies the \
overall distance from the entrance face to the corner vertex, however, if \
either zero or a tiny value is given for length, then SolidRetroReflector is \
created with the minimum length configuration. If the Mirrored->True option \
is given, the three corner surfaces are reflectorized. Otherwise, they are \
refractive surfaces that can also internally reflect. For Baffled->False, the \
side surface panels are refractive surfaces. If the Baffled->True option is \
given, the side surface panels absorb any rays hitting them. There can be two \
different forms of SolidRetroReflector: with FullForm->True, the internal \
reflective surfaces have square boundaries and the entrance face is \
hexagonal; with FullForm->False, the internal reflective surfaces have \
partially rounded boundaries and the entrance face is circular. See also: \
HollowRetroReflector, Wedge, RoofPrism, AmiciRoofPrism, RhomboidalPrism, and \
PentaPrism."\)], "Print",
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[SolidCornerCube[50,0],PlotType->TopView, \
AspectRatio->1];\
\>", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0269374 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .97619 m
.02381 .97212 L
.02381 .95996 L
.02381 .93994 L
.02381 .91239 L
.02381 .87779 L
.02381 .83672 L
.02381 .78989 L
.02381 .7381 L
.02381 .68223 L
.02381 .62325 L
.02381 .56216 L
.02381 .5 L
.02381 .43784 L
.02381 .37675 L
.02381 .31777 L
.02381 .2619 L
.02381 .21011 L
.02381 .16328 L
.02381 .12221 L
.02381 .08761 L
.02381 .06006 L
.02381 .04004 L
.02381 .02788 L
.02381 .02381 L
.02381 .02788 L
.02381 .04004 L
.02381 .06006 L
.02381 .08761 L
.02381 .12221 L
.02381 .16328 L
.02381 .21011 L
.02381 .2619 L
.02381 .31777 L
.02381 .37675 L
.02381 .43784 L
.02381 .5 L
.02381 .56216 L
.02381 .62325 L
.02381 .68223 L
.02381 .7381 L
.02381 .78989 L
.02381 .83672 L
.02381 .87779 L
.02381 .91239 L
.02381 .93994 L
.02381 .95996 L
.02381 .97212 L
.02381 .97619 L
s
.02381 .65081 m
.02381 .6392 L
.02381 .62744 L
.02381 .61551 L
.02381 .60341 L
.02381 .59114 L
.02381 .5787 L
.02381 .56607 L
.02381 .55326 L
.02381 .54026 L
.02381 .52705 L
.02381 .51363 L
.02381 .5 L
.02381 .5 L
.06349 .5 L
.10317 .5 L
.14286 .5 L
.18254 .5 L
.22222 .5 L
.2619 .5 L
.30159 .5 L
.34127 .5 L
.38095 .5 L
.42063 .5 L
.46032 .5 L
.5 .5 L
.5 .5 L
.49524 .50286 L
.49048 .50571 L
.48572 .50855 L
.48095 .51138 L
.47619 .5142 L
.47143 .51701 L
.46667 .51981 L
.46191 .5226 L
.45715 .52538 L
.45238 .52816 L
.44762 .53092 L
.44286 .53368 L
.44286 .53368 L
.43847 .53642 L
.43408 .53916 L
.42969 .54189 L
.4253 .54461 L
.4209 .54732 L
.41651 .55003 L
.41212 .55272 L
.40773 .55541 L
.40334 .55809 L
.39895 .56076 L
Mistroke
.39456 .56342 L
.39016 .56607 L
.39016 .56607 L
.38611 .56872 L
.38206 .57136 L
.378 .57399 L
.37395 .57661 L
.3699 .57922 L
.36584 .58183 L
.36179 .58442 L
.35774 .58701 L
.35368 .5896 L
.34963 .59217 L
.34557 .59474 L
.34152 .5973 L
.34152 .5973 L
.33778 .59985 L
.33404 .60239 L
.3303 .60493 L
.32656 .60746 L
.32282 .60998 L
.31908 .6125 L
.31534 .61501 L
.3116 .61751 L
.30786 .62 L
.30412 .62249 L
.30038 .62496 L
.29664 .62744 L
.29664 .62744 L
.2932 .6299 L
.28976 .63236 L
.28631 .63481 L
.28287 .63725 L
.27942 .63969 L
.27598 .64212 L
.27254 .64454 L
.26909 .64696 L
.26565 .64936 L
.26221 .65177 L
.25876 .65416 L
.25532 .65655 L
.25532 .65655 L
.25216 .65893 L
.249 .6613 L
.24584 .66367 L
.24268 .66603 L
.23952 .66839 L
.23636 .67073 L
.2332 .67308 L
.23004 .67541 L
Mistroke
.22688 .67774 L
.22372 .68006 L
.22056 .68237 L
.2174 .68468 L
.2174 .68468 L
.21451 .68698 L
.21163 .68927 L
.20874 .69156 L
.20586 .69384 L
.20297 .69612 L
.20009 .69838 L
.1972 .70065 L
.19432 .7029 L
.19143 .70515 L
.18855 .70739 L
.18566 .70963 L
.18278 .71186 L
.18278 .71186 L
.18016 .71408 L
.17755 .71629 L
.17494 .7185 L
.17232 .72071 L
.16971 .7229 L
.16709 .72509 L
.16448 .72728 L
.16186 .72945 L
.15925 .73162 L
.15663 .73379 L
.15402 .73594 L
.1514 .7381 L
.1514 .7381 L
.14906 .74024 L
.14671 .74238 L
.14437 .74451 L
.14202 .74664 L
.13968 .74875 L
.13733 .75087 L
.13498 .75297 L
.13264 .75507 L
.13029 .75716 L
.12795 .75925 L
.1256 .76133 L
.12326 .7634 L
.12326 .7634 L
.12118 .76547 L
.1191 .76753 L
.11703 .76959 L
.11495 .77163 L
.11288 .77367 L
.1108 .77571 L
Mistroke
.10873 .77774 L
.10665 .77976 L
.10458 .78177 L
.1025 .78378 L
.10043 .78578 L
.09835 .78778 L
.09835 .78778 L
.09655 .78977 L
.09475 .79175 L
.09295 .79372 L
.09115 .79569 L
.08935 .79765 L
.08755 .79961 L
.08575 .80156 L
.08395 .8035 L
.08215 .80543 L
.08035 .80736 L
.07855 .80928 L
.07675 .8112 L
.07675 .8112 L
.07523 .8131 L
.07371 .815 L
.0722 .8169 L
.07068 .81879 L
.06916 .82067 L
.06765 .82254 L
.06613 .82441 L
.06461 .82627 L
.0631 .82812 L
.06158 .82996 L
.06006 .8318 L
.05855 .83363 L
.05855 .83363 L
.05733 .83546 L
.05611 .83727 L
.05489 .83908 L
.05367 .84089 L
.05245 .84268 L
.05123 .84447 L
.05 .84625 L
.04878 .84802 L
.04756 .84979 L
.04634 .85155 L
.04512 .8533 L
.0439 .85504 L
.0439 .85504 L
.043 .85678 L
.04209 .85851 L
.04118 .86023 L
.04028 .86194 L
Mistroke
.03937 .86365 L
.03846 .86535 L
.03756 .86704 L
.03665 .86872 L
.03574 .87039 L
.03484 .87206 L
.03393 .87372 L
.03302 .87537 L
.03302 .87537 L
.03245 .87701 L
.03188 .87864 L
.03132 .88027 L
.03075 .88189 L
.03018 .8835 L
.02961 .8851 L
.02904 .88669 L
.02847 .88827 L
.0279 .88985 L
.02733 .89141 L
.02676 .89297 L
.02619 .89452 L
.02619 .89452 L
.026 .89606 L
.0258 .89759 L
.0256 .89911 L
.0254 .90063 L
.0252 .90213 L
.025 .90363 L
.0248 .90511 L
.0246 .90659 L
.02441 .90805 L
.02421 .90951 L
.02401 .91096 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .90063 L
.02381 .88827 L
Mistroke
.02381 .87537 L
.02381 .86194 L
.02381 .84802 L
.02381 .83363 L
.02381 .81879 L
.02381 .8035 L
.02381 .78778 L
.02381 .77163 L
.02381 .75507 L
.02381 .7381 L
.02381 .7381 L
.02381 .73427 L
.02381 .73042 L
.02381 .72655 L
.02381 .72266 L
.02381 .71875 L
.02381 .71482 L
.02381 .71087 L
.02381 .70689 L
.02381 .7029 L
.02381 .69889 L
.02381 .69485 L
.02381 .6908 L
.02381 .6908 L
.02381 .69029 L
.02381 .68978 L
.02381 .68927 L
.02381 .68876 L
.02381 .68825 L
.02381 .68774 L
.02381 .68723 L
.02381 .68672 L
.02381 .68621 L
.02381 .6857 L
.02381 .68519 L
.02381 .68468 L
.02381 .68468 L
.02381 .68402 L
.02381 .68336 L
.02381 .6827 L
.02381 .68204 L
.02381 .68138 L
.02381 .68072 L
.02381 .68006 L
.02381 .67939 L
.02381 .67873 L
.02381 .67807 L
.02381 .6774 L
.02381 .67674 L
.02381 .67674 L
Mistroke
.02381 .67585 L
.02381 .67497 L
.02381 .67408 L
.02381 .67319 L
.02381 .6723 L
.02381 .6714 L
.02381 .67051 L
.02381 .66962 L
.02381 .66872 L
.02381 .66783 L
.02381 .66693 L
.02381 .66603 L
.02381 .66603 L
.02381 .66477 L
.02381 .66351 L
.02381 .66225 L
.02381 .66099 L
.02381 .65972 L
.02381 .65845 L
.02381 .65718 L
.02381 .65591 L
.02381 .65464 L
.02381 .65336 L
.02381 .65209 L
.02381 .65081 L
Mfstroke
.02381 .5 m
.02381 .48637 L
.02381 .47295 L
.02381 .45974 L
.02381 .44674 L
.02381 .43393 L
.02381 .4213 L
.02381 .40886 L
.02381 .39659 L
.02381 .38449 L
.02381 .37256 L
.02381 .3608 L
.02381 .34919 L
.02381 .34919 L
.02381 .34791 L
.02381 .34664 L
.02381 .34536 L
.02381 .34409 L
.02381 .34282 L
.02381 .34155 L
.02381 .34028 L
.02381 .33901 L
.02381 .33775 L
.02381 .33649 L
.02381 .33523 L
.02381 .33397 L
.02381 .33397 L
.02381 .33307 L
.02381 .33217 L
.02381 .33128 L
.02381 .33038 L
.02381 .32949 L
.02381 .3286 L
.02381 .3277 L
.02381 .32681 L
.02381 .32592 L
.02381 .32503 L
.02381 .32415 L
.02381 .32326 L
.02381 .32326 L
.02381 .3226 L
.02381 .32193 L
.02381 .32127 L
.02381 .32061 L
.02381 .31994 L
.02381 .31928 L
.02381 .31862 L
.02381 .31796 L
.02381 .3173 L
.02381 .31664 L
Mistroke
.02381 .31598 L
.02381 .31532 L
.02381 .31532 L
.02381 .31481 L
.02381 .3143 L
.02381 .31379 L
.02381 .31328 L
.02381 .31277 L
.02381 .31226 L
.02381 .31175 L
.02381 .31124 L
.02381 .31073 L
.02381 .31022 L
.02381 .30971 L
.02381 .3092 L
.02381 .3092 L
.02381 .30515 L
.02381 .30111 L
.02381 .2971 L
.02381 .29311 L
.02381 .28913 L
.02381 .28518 L
.02381 .28125 L
.02381 .27734 L
.02381 .27345 L
.02381 .26958 L
.02381 .26573 L
.02381 .2619 L
.02381 .2619 L
.02381 .24493 L
.02381 .22837 L
.02381 .21222 L
.02381 .1965 L
.02381 .18121 L
.02381 .16637 L
.02381 .15198 L
.02381 .13806 L
.02381 .12463 L
.02381 .11173 L
.02381 .09937 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
Mistroke
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02401 .08904 L
.02421 .09049 L
.02441 .09195 L
.0246 .09341 L
.0248 .09489 L
.025 .09637 L
.0252 .09787 L
.0254 .09937 L
.0256 .10089 L
.0258 .10241 L
.026 .10394 L
.02619 .10548 L
.02619 .10548 L
.02676 .10703 L
.02733 .10859 L
.0279 .11015 L
.02847 .11173 L
.02904 .11331 L
.02961 .1149 L
.03018 .1165 L
.03075 .11811 L
.03132 .11973 L
.03188 .12136 L
.03245 .12299 L
.03302 .12463 L
.03302 .12463 L
.03393 .12628 L
.03484 .12794 L
.03574 .12961 L
.03665 .13128 L
.03756 .13296 L
.03846 .13465 L
.03937 .13635 L
.04028 .13806 L
.04118 .13977 L
.04209 .14149 L
.043 .14322 L
.0439 .14496 L
.0439 .14496 L
.04512 .1467 L
.04634 .14845 L
.04756 .15021 L
.04878 .15198 L
.05 .15375 L
.05123 .15553 L
Mistroke
.05245 .15732 L
.05367 .15911 L
.05489 .16092 L
.05611 .16273 L
.05733 .16454 L
.05855 .16637 L
.05855 .16637 L
.06006 .1682 L
.06158 .17004 L
.0631 .17188 L
.06461 .17373 L
.06613 .17559 L
.06765 .17746 L
.06916 .17933 L
.07068 .18121 L
.0722 .1831 L
.07371 .185 L
.07523 .1869 L
.07675 .1888 L
.07675 .1888 L
.07855 .19072 L
.08035 .19264 L
.08215 .19457 L
.08395 .1965 L
.08575 .19844 L
.08755 .20039 L
.08935 .20235 L
.09115 .20431 L
.09295 .20628 L
.09475 .20825 L
.09655 .21023 L
.09835 .21222 L
.09835 .21222 L
.10043 .21422 L
.1025 .21622 L
.10458 .21823 L
.10665 .22024 L
.10873 .22226 L
.1108 .22429 L
.11288 .22633 L
.11495 .22837 L
.11703 .23041 L
.1191 .23247 L
.12118 .23453 L
.12326 .2366 L
.12326 .2366 L
.1256 .23867 L
.12795 .24075 L
.13029 .24284 L
.13264 .24493 L
Mistroke
.13498 .24703 L
.13733 .24913 L
.13968 .25125 L
.14202 .25336 L
.14437 .25549 L
.14671 .25762 L
.14906 .25976 L
.1514 .2619 L
.1514 .2619 L
.15402 .26406 L
.15663 .26621 L
.15925 .26838 L
.16186 .27055 L
.16448 .27272 L
.16709 .27491 L
.16971 .2771 L
.17232 .27929 L
.17494 .2815 L
.17755 .28371 L
.18016 .28592 L
.18278 .28814 L
.18278 .28814 L
.18566 .29037 L
.18855 .29261 L
.19143 .29485 L
.19432 .2971 L
.1972 .29935 L
.20009 .30162 L
.20297 .30388 L
.20586 .30616 L
.20874 .30844 L
.21163 .31073 L
.21451 .31302 L
.2174 .31532 L
.2174 .31532 L
.22056 .31763 L
.22372 .31994 L
.22688 .32226 L
.23004 .32459 L
.2332 .32692 L
.23636 .32927 L
.23952 .33161 L
.24268 .33397 L
.24584 .33633 L
.249 .3387 L
.25216 .34107 L
.25532 .34345 L
.25532 .34345 L
.25876 .34584 L
.26221 .34823 L
Mistroke
.26565 .35064 L
.26909 .35304 L
.27254 .35546 L
.27598 .35788 L
.27942 .36031 L
.28287 .36275 L
.28631 .36519 L
.28976 .36764 L
.2932 .3701 L
.29664 .37256 L
.29664 .37256 L
.30038 .37504 L
.30412 .37751 L
.30786 .38 L
.3116 .38249 L
.31534 .38499 L
.31908 .3875 L
.32282 .39002 L
.32656 .39254 L
.3303 .39507 L
.33404 .39761 L
.33778 .40015 L
.34152 .4027 L
.34152 .4027 L
.34557 .40526 L
.34963 .40783 L
.35368 .4104 L
.35774 .41299 L
.36179 .41558 L
.36584 .41817 L
.3699 .42078 L
.37395 .42339 L
.378 .42601 L
.38206 .42864 L
.38611 .43128 L
.39016 .43393 L
.39016 .43393 L
.39456 .43658 L
.39895 .43924 L
.40334 .44191 L
.40773 .44459 L
.41212 .44728 L
.41651 .44997 L
.4209 .45268 L
.4253 .45539 L
.42969 .45811 L
.43408 .46084 L
.43847 .46358 L
.44286 .46632 L
.44286 .46632 L
Mistroke
.44762 .46908 L
.45238 .47184 L
.45715 .47462 L
.46191 .4774 L
.46667 .48019 L
.47143 .48299 L
.47619 .4858 L
.48095 .48862 L
.48572 .49145 L
.49048 .49429 L
.49524 .49714 L
.5 .5 L
.5 .5 L
.46032 .5 L
.42063 .5 L
.38095 .5 L
.34127 .5 L
.30159 .5 L
.2619 .5 L
.22222 .5 L
.18254 .5 L
.14286 .5 L
.10317 .5 L
.06349 .5 L
.02381 .5 L
Mfstroke
.02381 .03343 m
.02381 .03602 L
.02381 .03893 L
.02381 .04217 L
.02381 .04574 L
.02381 .04966 L
.02381 .05393 L
.02381 .05856 L
.02381 .06356 L
.02381 .06896 L
.02381 .07475 L
.02381 .08096 L
.02381 .08761 L
.02381 .08761 L
.06349 .08761 L
.10317 .08761 L
.14286 .08761 L
.18254 .08761 L
.22222 .08761 L
.2619 .08761 L
.30159 .08761 L
.34127 .08761 L
.38095 .08761 L
.42063 .08761 L
.46032 .08761 L
.5 .08761 L
.5 .08761 L
.49524 .08618 L
.49048 .08478 L
.48572 .0834 L
.48095 .08204 L
.47619 .08069 L
.47143 .07937 L
.46667 .07806 L
.46191 .07677 L
.45715 .0755 L
.45238 .07425 L
.44762 .07302 L
.44286 .0718 L
.44286 .0718 L
.43847 .0706 L
.43408 .06942 L
.42969 .06826 L
.4253 .06711 L
.4209 .06599 L
.41651 .06488 L
.41212 .06378 L
.40773 .0627 L
.40334 .06164 L
.39895 .0606 L
Mistroke
.39456 .05957 L
.39016 .05856 L
.39016 .05856 L
.38611 .05756 L
.38206 .05659 L
.378 .05562 L
.37395 .05468 L
.3699 .05374 L
.36584 .05283 L
.36179 .05193 L
.35774 .05104 L
.35368 .05017 L
.34963 .04932 L
.34557 .04848 L
.34152 .04766 L
.34152 .04766 L
.33778 .04685 L
.33404 .04606 L
.3303 .04528 L
.32656 .04451 L
.32282 .04377 L
.31908 .04303 L
.31534 .04231 L
.3116 .04161 L
.30786 .04092 L
.30412 .04024 L
.30038 .03958 L
.29664 .03893 L
.29664 .03893 L
.2932 .0383 L
.28976 .03768 L
.28631 .03707 L
.28287 .03648 L
.27942 .03591 L
.27598 .03534 L
.27254 .03479 L
.26909 .03426 L
.26565 .03374 L
.26221 .03323 L
.25876 .03274 L
.25532 .03225 L
.25532 .03225 L
.25216 .03179 L
.249 .03134 L
.24584 .0309 L
.24268 .03047 L
.23952 .03006 L
.23636 .02966 L
.2332 .02927 L
.23004 .0289 L
Mistroke
.22688 .02854 L
.22372 .0282 L
.22056 .02786 L
.2174 .02754 L
.2174 .02754 L
.21451 .02724 L
.21163 .02695 L
.20874 .02667 L
.20586 .0264 L
.20297 .02615 L
.20009 .02591 L
.1972 .02568 L
.19432 .02547 L
.19143 .02526 L
.18855 .02508 L
.18566 .0249 L
.18278 .02474 L
.18278 .02474 L
.18016 .02459 L
.17755 .02446 L
.17494 .02433 L
.17232 .02422 L
.16971 .02413 L
.16709 .02404 L
.16448 .02397 L
.16186 .02391 L
.15925 .02387 L
.15663 .02384 L
.15402 .02382 L
.1514 .02381 L
.1514 .02381 L
.14906 .02382 L
.14671 .02384 L
.14437 .02387 L
.14202 .02391 L
.13968 .02397 L
.13733 .02404 L
.13498 .02413 L
.13264 .02422 L
.13029 .02433 L
.12795 .02446 L
.1256 .02459 L
.12326 .02474 L
.12326 .02474 L
.12118 .0249 L
.1191 .02508 L
.11703 .02526 L
.11495 .02547 L
.11288 .02568 L
.1108 .02591 L
Mistroke
.10873 .02615 L
.10665 .0264 L
.10458 .02667 L
.1025 .02695 L
.10043 .02724 L
.09835 .02754 L
.09835 .02754 L
.09655 .02786 L
.09475 .0282 L
.09295 .02854 L
.09115 .0289 L
.08935 .02927 L
.08755 .02966 L
.08575 .03006 L
.08395 .03047 L
.08215 .0309 L
.08035 .03134 L
.07855 .03179 L
.07675 .03225 L
.07675 .03225 L
.07523 .03274 L
.07371 .03323 L
.0722 .03374 L
.07068 .03426 L
.06916 .03479 L
.06765 .03534 L
.06613 .03591 L
.06461 .03648 L
.0631 .03707 L
.06158 .03768 L
.06006 .0383 L
.05855 .03893 L
.05855 .03893 L
.05733 .03958 L
.05611 .04024 L
.05489 .04092 L
.05367 .04161 L
.05245 .04231 L
.05123 .04303 L
.05 .04377 L
.04878 .04451 L
.04756 .04528 L
.04634 .04606 L
.04512 .04685 L
.0439 .04766 L
.0439 .04766 L
.043 .04848 L
.04209 .04932 L
.04118 .05017 L
.04028 .05104 L
Mistroke
.03937 .05193 L
.03846 .05283 L
.03756 .05374 L
.03665 .05468 L
.03574 .05562 L
.03484 .05659 L
.03393 .05756 L
.03302 .05856 L
.03302 .05856 L
.03245 .05957 L
.03188 .0606 L
.03132 .06164 L
.03075 .0627 L
.03018 .06378 L
.02961 .06488 L
.02904 .06599 L
.02847 .06711 L
.0279 .06826 L
.02733 .06942 L
.02676 .0706 L
.02619 .0718 L
.02619 .0718 L
.026 .07302 L
.0258 .07425 L
.0256 .0755 L
.0254 .07677 L
.0252 .07806 L
.025 .07937 L
.0248 .08069 L
.0246 .08204 L
.02441 .0834 L
.02421 .08478 L
.02401 .08618 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .07677 L
.02381 .06711 L
Mistroke
.02381 .05856 L
.02381 .05104 L
.02381 .04451 L
.02381 .03893 L
.02381 .03426 L
.02381 .03047 L
.02381 .02754 L
.02381 .02547 L
.02381 .02422 L
.02381 .02381 L
.02381 .02381 L
.02381 .02383 L
.02381 .02389 L
.02381 .02399 L
.02381 .02414 L
.02381 .02432 L
.02381 .02454 L
.02381 .02481 L
.02381 .02512 L
.02381 .02547 L
.02381 .02586 L
.02381 .02629 L
.02381 .02676 L
.02381 .02676 L
.02381 .02682 L
.02381 .02688 L
.02381 .02695 L
.02381 .02701 L
.02381 .02707 L
.02381 .02714 L
.02381 .02721 L
.02381 .02727 L
.02381 .02734 L
.02381 .02741 L
.02381 .02748 L
.02381 .02754 L
.02381 .02754 L
.02381 .02763 L
.02381 .02773 L
.02381 .02782 L
.02381 .02791 L
.02381 .028 L
.02381 .0281 L
.02381 .0282 L
.02381 .02829 L
.02381 .02839 L
.02381 .02849 L
.02381 .02859 L
.02381 .02869 L
.02381 .02869 L
Mistroke
.02381 .02883 L
.02381 .02897 L
.02381 .02911 L
.02381 .02925 L
.02381 .0294 L
.02381 .02955 L
.02381 .0297 L
.02381 .02985 L
.02381 .03 L
.02381 .03015 L
.02381 .03031 L
.02381 .03047 L
.02381 .03047 L
.02381 .0307 L
.02381 .03092 L
.02381 .03116 L
.02381 .03139 L
.02381 .03164 L
.02381 .03188 L
.02381 .03213 L
.02381 .03238 L
.02381 .03264 L
.02381 .0329 L
.02381 .03316 L
.02381 .03343 L
Mfstroke
.02381 .08761 m
.02381 .09459 L
.02381 .1018 L
.02381 .10921 L
.02381 .11682 L
.02381 .12463 L
.02381 .13263 L
.02381 .1408 L
.02381 .14915 L
.02381 .15768 L
.02381 .16637 L
.02381 .17522 L
.02381 .18424 L
.02381 .18424 L
.02381 .18525 L
.02381 .18626 L
.02381 .18728 L
.02381 .18829 L
.02381 .18931 L
.02381 .19033 L
.02381 .19136 L
.02381 .19238 L
.02381 .19341 L
.02381 .19444 L
.02381 .19547 L
.02381 .1965 L
.02381 .1965 L
.02381 .19724 L
.02381 .19798 L
.02381 .19872 L
.02381 .19946 L
.02381 .20021 L
.02381 .20095 L
.02381 .2017 L
.02381 .20244 L
.02381 .20319 L
.02381 .20394 L
.02381 .20468 L
.02381 .20543 L
.02381 .20543 L
.02381 .206 L
.02381 .20656 L
.02381 .20712 L
.02381 .20769 L
.02381 .20825 L
.02381 .20882 L
.02381 .20938 L
.02381 .20995 L
.02381 .21052 L
.02381 .21109 L
Mistroke
.02381 .21165 L
.02381 .21222 L
.02381 .21222 L
.02381 .21267 L
.02381 .21311 L
.02381 .21355 L
.02381 .214 L
.02381 .21444 L
.02381 .21488 L
.02381 .21533 L
.02381 .21577 L
.02381 .21622 L
.02381 .21667 L
.02381 .21711 L
.02381 .21756 L
.02381 .21756 L
.02381 .22114 L
.02381 .22474 L
.02381 .22837 L
.02381 .23201 L
.02381 .23568 L
.02381 .23936 L
.02381 .24307 L
.02381 .24679 L
.02381 .25054 L
.02381 .25431 L
.02381 .2581 L
.02381 .2619 L
.02381 .2619 L
.02381 .27929 L
.02381 .2971 L
.02381 .31532 L
.02381 .33397 L
.02381 .35304 L
.02381 .37256 L
.02381 .39254 L
.02381 .41299 L
.02381 .43393 L
.02381 .45539 L
.02381 .4774 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
Mistroke
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02401 .49714 L
.02421 .49429 L
.02441 .49145 L
.0246 .48862 L
.0248 .4858 L
.025 .48299 L
.0252 .48019 L
.0254 .4774 L
.0256 .47462 L
.0258 .47184 L
.026 .46908 L
.02619 .46632 L
.02619 .46632 L
.02676 .46358 L
.02733 .46084 L
.0279 .45811 L
.02847 .45539 L
.02904 .45268 L
.02961 .44997 L
.03018 .44728 L
.03075 .44459 L
.03132 .44191 L
.03188 .43924 L
.03245 .43658 L
.03302 .43393 L
.03302 .43393 L
.03393 .43128 L
.03484 .42864 L
.03574 .42601 L
.03665 .42339 L
.03756 .42078 L
.03846 .41817 L
.03937 .41558 L
.04028 .41299 L
.04118 .4104 L
.04209 .40783 L
.043 .40526 L
.0439 .4027 L
.0439 .4027 L
.04512 .40015 L
.04634 .39761 L
.04756 .39507 L
.04878 .39254 L
.05 .39002 L
.05123 .3875 L
Mistroke
.05245 .38499 L
.05367 .38249 L
.05489 .38 L
.05611 .37751 L
.05733 .37504 L
.05855 .37256 L
.05855 .37256 L
.06006 .3701 L
.06158 .36764 L
.0631 .36519 L
.06461 .36275 L
.06613 .36031 L
.06765 .35788 L
.06916 .35546 L
.07068 .35304 L
.0722 .35064 L
.07371 .34823 L
.07523 .34584 L
.07675 .34345 L
.07675 .34345 L
.07855 .34107 L
.08035 .3387 L
.08215 .33633 L
.08395 .33397 L
.08575 .33161 L
.08755 .32927 L
.08935 .32692 L
.09115 .32459 L
.09295 .32226 L
.09475 .31994 L
.09655 .31763 L
.09835 .31532 L
.09835 .31532 L
.10043 .31302 L
.1025 .31073 L
.10458 .30844 L
.10665 .30616 L
.10873 .30388 L
.1108 .30162 L
.11288 .29935 L
.11495 .2971 L
.11703 .29485 L
.1191 .29261 L
.12118 .29037 L
.12326 .28814 L
.12326 .28814 L
.1256 .28592 L
.12795 .28371 L
.13029 .2815 L
.13264 .27929 L
Mistroke
.13498 .2771 L
.13733 .27491 L
.13968 .27272 L
.14202 .27055 L
.14437 .26838 L
.14671 .26621 L
.14906 .26406 L
.1514 .2619 L
.1514 .2619 L
.15402 .25976 L
.15663 .25762 L
.15925 .25549 L
.16186 .25336 L
.16448 .25125 L
.16709 .24913 L
.16971 .24703 L
.17232 .24493 L
.17494 .24284 L
.17755 .24075 L
.18016 .23867 L
.18278 .2366 L
.18278 .2366 L
.18566 .23453 L
.18855 .23247 L
.19143 .23041 L
.19432 .22837 L
.1972 .22633 L
.20009 .22429 L
.20297 .22226 L
.20586 .22024 L
.20874 .21823 L
.21163 .21622 L
.21451 .21422 L
.2174 .21222 L
.2174 .21222 L
.22056 .21023 L
.22372 .20825 L
.22688 .20628 L
.23004 .20431 L
.2332 .20235 L
.23636 .20039 L
.23952 .19844 L
.24268 .1965 L
.24584 .19457 L
.249 .19264 L
.25216 .19072 L
.25532 .1888 L
.25532 .1888 L
.25876 .1869 L
.26221 .185 L
Mistroke
.26565 .1831 L
.26909 .18121 L
.27254 .17933 L
.27598 .17746 L
.27942 .17559 L
.28287 .17373 L
.28631 .17188 L
.28976 .17004 L
.2932 .1682 L
.29664 .16637 L
.29664 .16637 L
.30038 .16454 L
.30412 .16273 L
.30786 .16092 L
.3116 .15911 L
.31534 .15732 L
.31908 .15553 L
.32282 .15375 L
.32656 .15198 L
.3303 .15021 L
.33404 .14845 L
.33778 .1467 L
.34152 .14496 L
.34152 .14496 L
.34557 .14322 L
.34963 .14149 L
.35368 .13977 L
.35774 .13806 L
.36179 .13635 L
.36584 .13465 L
.3699 .13296 L
.37395 .13128 L
.378 .12961 L
.38206 .12794 L
.38611 .12628 L
.39016 .12463 L
.39016 .12463 L
.39456 .12299 L
.39895 .12136 L
.40334 .11973 L
.40773 .11811 L
.41212 .1165 L
.41651 .1149 L
.4209 .11331 L
.4253 .11173 L
.42969 .11015 L
.43408 .10859 L
.43847 .10703 L
.44286 .10548 L
.44286 .10548 L
Mistroke
.44762 .10394 L
.45238 .10241 L
.45715 .10089 L
.46191 .09937 L
.46667 .09787 L
.47143 .09637 L
.47619 .09489 L
.48095 .09341 L
.48572 .09195 L
.49048 .09049 L
.49524 .08904 L
.5 .08761 L
.5 .08761 L
.46032 .08761 L
.42063 .08761 L
.38095 .08761 L
.34127 .08761 L
.30159 .08761 L
.2619 .08761 L
.22222 .08761 L
.18254 .08761 L
.14286 .08761 L
.10317 .08761 L
.06349 .08761 L
.02381 .08761 L
Mfstroke
.02381 .81576 m
.02381 .82478 L
.02381 .83363 L
.02381 .84232 L
.02381 .85085 L
.02381 .8592 L
.02381 .86737 L
.02381 .87537 L
.02381 .88318 L
.02381 .89079 L
.02381 .8982 L
.02381 .90541 L
.02381 .91239 L
.02381 .91239 L
.06349 .91239 L
.10317 .91239 L
.14286 .91239 L
.18254 .91239 L
.22222 .91239 L
.2619 .91239 L
.30159 .91239 L
.34127 .91239 L
.38095 .91239 L
.42063 .91239 L
.46032 .91239 L
.5 .91239 L
.5 .91239 L
.49524 .91096 L
.49048 .90951 L
.48572 .90805 L
.48095 .90659 L
.47619 .90511 L
.47143 .90363 L
.46667 .90213 L
.46191 .90063 L
.45715 .89911 L
.45238 .89759 L
.44762 .89606 L
.44286 .89452 L
.44286 .89452 L
.43847 .89297 L
.43408 .89141 L
.42969 .88985 L
.4253 .88827 L
.4209 .88669 L
.41651 .8851 L
.41212 .8835 L
.40773 .88189 L
.40334 .88027 L
.39895 .87864 L
Mistroke
.39456 .87701 L
.39016 .87537 L
.39016 .87537 L
.38611 .87372 L
.38206 .87206 L
.378 .87039 L
.37395 .86872 L
.3699 .86704 L
.36584 .86535 L
.36179 .86365 L
.35774 .86194 L
.35368 .86023 L
.34963 .85851 L
.34557 .85678 L
.34152 .85504 L
.34152 .85504 L
.33778 .8533 L
.33404 .85155 L
.3303 .84979 L
.32656 .84802 L
.32282 .84625 L
.31908 .84447 L
.31534 .84268 L
.3116 .84089 L
.30786 .83908 L
.30412 .83727 L
.30038 .83546 L
.29664 .83363 L
.29664 .83363 L
.2932 .8318 L
.28976 .82996 L
.28631 .82812 L
.28287 .82627 L
.27942 .82441 L
.27598 .82254 L
.27254 .82067 L
.26909 .81879 L
.26565 .8169 L
.26221 .815 L
.25876 .8131 L
.25532 .8112 L
.25532 .8112 L
.25216 .80928 L
.249 .80736 L
.24584 .80543 L
.24268 .8035 L
.23952 .80156 L
.23636 .79961 L
.2332 .79765 L
.23004 .79569 L
Mistroke
.22688 .79372 L
.22372 .79175 L
.22056 .78977 L
.2174 .78778 L
.2174 .78778 L
.21451 .78578 L
.21163 .78378 L
.20874 .78177 L
.20586 .77976 L
.20297 .77774 L
.20009 .77571 L
.1972 .77367 L
.19432 .77163 L
.19143 .76959 L
.18855 .76753 L
.18566 .76547 L
.18278 .7634 L
.18278 .7634 L
.18016 .76133 L
.17755 .75925 L
.17494 .75716 L
.17232 .75507 L
.16971 .75297 L
.16709 .75087 L
.16448 .74875 L
.16186 .74664 L
.15925 .74451 L
.15663 .74238 L
.15402 .74024 L
.1514 .7381 L
.1514 .7381 L
.14906 .73594 L
.14671 .73379 L
.14437 .73162 L
.14202 .72945 L
.13968 .72728 L
.13733 .72509 L
.13498 .7229 L
.13264 .72071 L
.13029 .7185 L
.12795 .71629 L
.1256 .71408 L
.12326 .71186 L
.12326 .71186 L
.12118 .70963 L
.1191 .70739 L
.11703 .70515 L
.11495 .7029 L
.11288 .70065 L
.1108 .69838 L
Mistroke
.10873 .69612 L
.10665 .69384 L
.10458 .69156 L
.1025 .68927 L
.10043 .68698 L
.09835 .68468 L
.09835 .68468 L
.09655 .68237 L
.09475 .68006 L
.09295 .67774 L
.09115 .67541 L
.08935 .67308 L
.08755 .67073 L
.08575 .66839 L
.08395 .66603 L
.08215 .66367 L
.08035 .6613 L
.07855 .65893 L
.07675 .65655 L
.07675 .65655 L
.07523 .65416 L
.07371 .65177 L
.0722 .64936 L
.07068 .64696 L
.06916 .64454 L
.06765 .64212 L
.06613 .63969 L
.06461 .63725 L
.0631 .63481 L
.06158 .63236 L
.06006 .6299 L
.05855 .62744 L
.05855 .62744 L
.05733 .62496 L
.05611 .62249 L
.05489 .62 L
.05367 .61751 L
.05245 .61501 L
.05123 .6125 L
.05 .60998 L
.04878 .60746 L
.04756 .60493 L
.04634 .60239 L
.04512 .59985 L
.0439 .5973 L
.0439 .5973 L
.043 .59474 L
.04209 .59217 L
.04118 .5896 L
.04028 .58701 L
Mistroke
.03937 .58442 L
.03846 .58183 L
.03756 .57922 L
.03665 .57661 L
.03574 .57399 L
.03484 .57136 L
.03393 .56872 L
.03302 .56607 L
.03302 .56607 L
.03245 .56342 L
.03188 .56076 L
.03132 .55809 L
.03075 .55541 L
.03018 .55272 L
.02961 .55003 L
.02904 .54732 L
.02847 .54461 L
.0279 .54189 L
.02733 .53916 L
.02676 .53642 L
.02619 .53368 L
.02619 .53368 L
.026 .53092 L
.0258 .52816 L
.0256 .52538 L
.0254 .5226 L
.0252 .51981 L
.025 .51701 L
.0248 .5142 L
.0246 .51138 L
.02441 .50855 L
.02421 .50571 L
.02401 .50286 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5226 L
.02381 .54461 L
Mistroke
.02381 .56607 L
.02381 .58701 L
.02381 .60746 L
.02381 .62744 L
.02381 .64696 L
.02381 .66603 L
.02381 .68468 L
.02381 .7029 L
.02381 .72071 L
.02381 .7381 L
.02381 .7381 L
.02381 .7419 L
.02381 .74569 L
.02381 .74946 L
.02381 .75321 L
.02381 .75693 L
.02381 .76064 L
.02381 .76432 L
.02381 .76799 L
.02381 .77163 L
.02381 .77526 L
.02381 .77886 L
.02381 .78244 L
.02381 .78244 L
.02381 .78289 L
.02381 .78333 L
.02381 .78378 L
.02381 .78423 L
.02381 .78467 L
.02381 .78512 L
.02381 .78556 L
.02381 .786 L
.02381 .78645 L
.02381 .78689 L
.02381 .78733 L
.02381 .78778 L
.02381 .78778 L
.02381 .78835 L
.02381 .78891 L
.02381 .78948 L
.02381 .79005 L
.02381 .79062 L
.02381 .79118 L
.02381 .79175 L
.02381 .79231 L
.02381 .79288 L
.02381 .79344 L
.02381 .794 L
.02381 .79457 L
.02381 .79457 L
Mistroke
.02381 .79532 L
.02381 .79606 L
.02381 .79681 L
.02381 .79756 L
.02381 .7983 L
.02381 .79905 L
.02381 .79979 L
.02381 .80054 L
.02381 .80128 L
.02381 .80202 L
.02381 .80276 L
.02381 .8035 L
.02381 .8035 L
.02381 .80453 L
.02381 .80556 L
.02381 .80659 L
.02381 .80762 L
.02381 .80864 L
.02381 .80967 L
.02381 .81069 L
.02381 .81171 L
.02381 .81272 L
.02381 .81374 L
.02381 .81475 L
.02381 .81576 L
Mfstroke
.02381 .91239 m
.02381 .91904 L
.02381 .92525 L
.02381 .93104 L
.02381 .93644 L
.02381 .94144 L
.02381 .94607 L
.02381 .95034 L
.02381 .95426 L
.02381 .95783 L
.02381 .96107 L
.02381 .96398 L
.02381 .96657 L
.02381 .96657 L
.02381 .96684 L
.02381 .9671 L
.02381 .96736 L
.02381 .96762 L
.02381 .96787 L
.02381 .96812 L
.02381 .96836 L
.02381 .96861 L
.02381 .96884 L
.02381 .96908 L
.02381 .9693 L
.02381 .96953 L
.02381 .96953 L
.02381 .96969 L
.02381 .96985 L
.02381 .97 L
.02381 .97015 L
.02381 .9703 L
.02381 .97045 L
.02381 .9706 L
.02381 .97075 L
.02381 .97089 L
.02381 .97103 L
.02381 .97117 L
.02381 .97131 L
.02381 .97131 L
.02381 .97141 L
.02381 .97151 L
.02381 .97161 L
.02381 .97171 L
.02381 .9718 L
.02381 .9719 L
.02381 .972 L
.02381 .97209 L
.02381 .97218 L
.02381 .97227 L
Mistroke
.02381 .97237 L
.02381 .97246 L
.02381 .97246 L
.02381 .97252 L
.02381 .97259 L
.02381 .97266 L
.02381 .97273 L
.02381 .97279 L
.02381 .97286 L
.02381 .97293 L
.02381 .97299 L
.02381 .97305 L
.02381 .97312 L
.02381 .97318 L
.02381 .97324 L
.02381 .97324 L
.02381 .97371 L
.02381 .97414 L
.02381 .97453 L
.02381 .97488 L
.02381 .97519 L
.02381 .97546 L
.02381 .97568 L
.02381 .97586 L
.02381 .97601 L
.02381 .97611 L
.02381 .97617 L
.02381 .97619 L
.02381 .97619 L
.02381 .97578 L
.02381 .97453 L
.02381 .97246 L
.02381 .96953 L
.02381 .96574 L
.02381 .96107 L
.02381 .95549 L
.02381 .94896 L
.02381 .94144 L
.02381 .93289 L
.02381 .92323 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
Mistroke
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .91239 L
.02401 .91382 L
.02421 .91522 L
.02441 .9166 L
.0246 .91796 L
.0248 .91931 L
.025 .92063 L
.0252 .92194 L
.0254 .92323 L
.0256 .9245 L
.0258 .92575 L
.026 .92698 L
.02619 .9282 L
.02619 .9282 L
.02676 .9294 L
.02733 .93058 L
.0279 .93174 L
.02847 .93289 L
.02904 .93401 L
.02961 .93512 L
.03018 .93622 L
.03075 .9373 L
.03132 .93836 L
.03188 .9394 L
.03245 .94043 L
.03302 .94144 L
.03302 .94144 L
.03393 .94244 L
.03484 .94341 L
.03574 .94438 L
.03665 .94532 L
.03756 .94626 L
.03846 .94717 L
.03937 .94807 L
.04028 .94896 L
.04118 .94983 L
.04209 .95068 L
.043 .95152 L
.0439 .95234 L
.0439 .95234 L
.04512 .95315 L
.04634 .95394 L
.04756 .95472 L
.04878 .95549 L
.05 .95623 L
.05123 .95697 L
Mistroke
.05245 .95769 L
.05367 .95839 L
.05489 .95908 L
.05611 .95976 L
.05733 .96042 L
.05855 .96107 L
.05855 .96107 L
.06006 .9617 L
.06158 .96232 L
.0631 .96293 L
.06461 .96352 L
.06613 .96409 L
.06765 .96466 L
.06916 .96521 L
.07068 .96574 L
.0722 .96626 L
.07371 .96677 L
.07523 .96726 L
.07675 .96775 L
.07675 .96775 L
.07855 .96821 L
.08035 .96866 L
.08215 .9691 L
.08395 .96953 L
.08575 .96994 L
.08755 .97034 L
.08935 .97073 L
.09115 .9711 L
.09295 .97146 L
.09475 .9718 L
.09655 .97214 L
.09835 .97246 L
.09835 .97246 L
.10043 .97276 L
.1025 .97305 L
.10458 .97333 L
.10665 .9736 L
.10873 .97385 L
.1108 .97409 L
.11288 .97432 L
.11495 .97453 L
.11703 .97474 L
.1191 .97492 L
.12118 .9751 L
.12326 .97526 L
.12326 .97526 L
.1256 .97541 L
.12795 .97554 L
.13029 .97567 L
.13264 .97578 L
Mistroke
.13498 .97587 L
.13733 .97596 L
.13968 .97603 L
.14202 .97609 L
.14437 .97613 L
.14671 .97616 L
.14906 .97618 L
.1514 .97619 L
.1514 .97619 L
.15402 .97618 L
.15663 .97616 L
.15925 .97613 L
.16186 .97609 L
.16448 .97603 L
.16709 .97596 L
.16971 .97587 L
.17232 .97578 L
.17494 .97567 L
.17755 .97554 L
.18016 .97541 L
.18278 .97526 L
.18278 .97526 L
.18566 .9751 L
.18855 .97492 L
.19143 .97474 L
.19432 .97453 L
.1972 .97432 L
.20009 .97409 L
.20297 .97385 L
.20586 .9736 L
.20874 .97333 L
.21163 .97305 L
.21451 .97276 L
.2174 .97246 L
.2174 .97246 L
.22056 .97214 L
.22372 .9718 L
.22688 .97146 L
.23004 .9711 L
.2332 .97073 L
.23636 .97034 L
.23952 .96994 L
.24268 .96953 L
.24584 .9691 L
.249 .96866 L
.25216 .96821 L
.25532 .96775 L
.25532 .96775 L
.25876 .96726 L
.26221 .96677 L
Mistroke
.26565 .96626 L
.26909 .96574 L
.27254 .96521 L
.27598 .96466 L
.27942 .96409 L
.28287 .96352 L
.28631 .96293 L
.28976 .96232 L
.2932 .9617 L
.29664 .96107 L
.29664 .96107 L
.30038 .96042 L
.30412 .95976 L
.30786 .95908 L
.3116 .95839 L
.31534 .95769 L
.31908 .95697 L
.32282 .95623 L
.32656 .95549 L
.3303 .95472 L
.33404 .95394 L
.33778 .95315 L
.34152 .95234 L
.34152 .95234 L
.34557 .95152 L
.34963 .95068 L
.35368 .94983 L
.35774 .94896 L
.36179 .94807 L
.36584 .94717 L
.3699 .94626 L
.37395 .94532 L
.378 .94438 L
.38206 .94341 L
.38611 .94244 L
.39016 .94144 L
.39016 .94144 L
.39456 .94043 L
.39895 .9394 L
.40334 .93836 L
.40773 .9373 L
.41212 .93622 L
.41651 .93512 L
.4209 .93401 L
.4253 .93289 L
.42969 .93174 L
.43408 .93058 L
.43847 .9294 L
.44286 .9282 L
.44286 .9282 L
Mistroke
.44762 .92698 L
.45238 .92575 L
.45715 .9245 L
.46191 .92323 L
.46667 .92194 L
.47143 .92063 L
.47619 .91931 L
.48095 .91796 L
.48572 .9166 L
.49048 .91522 L
.49524 .91382 L
.5 .91239 L
.5 .91239 L
.46032 .91239 L
.42063 .91239 L
.38095 .91239 L
.34127 .91239 L
.30159 .91239 L
.2619 .91239 L
.22222 .91239 L
.18254 .91239 L
.14286 .91239 L
.10317 .91239 L
.06349 .91239 L
.02381 .91239 L
Mfstroke
.97619 .5 m
.5 .08761 L
.45606 .1011 L
.41351 .1158 L
.37239 .13174 L
.33272 .14894 L
.29456 .16743 L
.25795 .18728 L
.223 .20856 L
.18982 .23137 L
.15854 .25583 L
.12936 .28211 L
.10253 .31043 L
.07841 .34109 L
.05748 .37451 L
.04047 .41133 L
.02855 .45255 L
.02381 .5 L
.02855 .54745 L
.04047 .58867 L
.05748 .62549 L
.07841 .65891 L
.10253 .68957 L
.12936 .71789 L
.15854 .74417 L
.18982 .76863 L
.223 .79144 L
.25795 .81272 L
.29456 .83257 L
.33272 .85106 L
.37239 .86826 L
.41351 .8842 L
.45606 .8989 L
.5 .91239 L
.97619 .5 L
s
.97619 .5 m
.5 .5 L
.45606 .47423 L
.41351 .44845 L
.37239 .42268 L
.33272 .3969 L
.29456 .37113 L
.25795 .34535 L
.223 .31958 L
.18982 .2938 L
.15854 .26803 L
.12936 .24225 L
.10253 .21648 L
.07841 .19071 L
.05748 .16493 L
.04047 .13916 L
.02855 .11338 L
.02381 .08761 L
.02855 .06594 L
.04047 .05048 L
.05748 .03944 L
.07841 .03179 L
.10253 .02691 L
.12936 .02437 L
.15854 .02386 L
.18982 .02518 L
.223 .02814 L
.25795 .03264 L
.29456 .03856 L
.33272 .04584 L
.37239 .05442 L
.41351 .06426 L
.45606 .07532 L
.5 .08761 L
.97619 .5 L
s
.97619 .5 m
.5 .91239 L
.45606 .92468 L
.41351 .93574 L
.37239 .94558 L
.33272 .95416 L
.29456 .96144 L
.25795 .96736 L
.223 .97186 L
.18982 .97482 L
.15854 .97614 L
.12936 .97563 L
.10253 .97309 L
.07841 .96821 L
.05748 .96056 L
.04047 .94952 L
.02855 .93406 L
.02381 .91239 L
.02855 .88662 L
.04047 .86084 L
.05748 .83507 L
.07841 .80929 L
.10253 .78352 L
.12936 .75775 L
.15854 .73197 L
.18982 .7062 L
.223 .68042 L
.25795 .65465 L
.29456 .62887 L
.33272 .6031 L
.37239 .57732 L
.41351 .55155 L
.45606 .52577 L
.5 .5 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{157, 157},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 156}, {156, 0}} -> {-0.884068, -26.2503, 0.237971, \
0.336542}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%]", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.26571 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.13389 1.33863 0 1.33863 [
[ 0 0 0 0 ]
[ 1 1.26571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.26571 L
0 1.26571 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.44969 .69857 m
.45238 .7072 L
s
.44693 .69005 m
.44969 .69857 L
s
.44411 .68165 m
.44693 .69005 L
s
.45238 .7072 m
.455 .71596 L
s
.4532 .70988 m
.46476 .75232 L
s
.43931 .66802 m
.4532 .70988 L
s
.44122 .67334 m
.44411 .68165 L
s
.455 .71596 m
.45755 .72484 L
s
.43826 .66514 m
.44122 .67334 L
s
.45755 .72484 m
.46003 .73386 L
s
.42326 .62723 m
.43931 .66802 L
s
.43524 .65704 m
.43826 .66514 L
s
.46003 .73386 m
.46243 .74301 L
s
.43216 .64902 m
.43524 .65704 L
s
.46243 .74301 m
.46476 .75232 L
s
.43181 .64814 m
.43216 .64902 L
s
.43146 .64726 m
.43181 .64814 L
s
.43112 .64637 m
.43146 .64726 L
s
.43077 .64549 m
.43112 .64637 L
s
.43042 .64461 m
.43077 .64549 L
s
.43007 .64373 m
.43042 .64461 L
s
.42972 .64286 m
.43007 .64373 L
s
.42936 .64198 m
.42972 .64286 L
s
.48211 .74693 m
.46476 .75232 L
s
.46476 .75232 m
.46696 .76164 L
s
.46476 .75232 m
.46476 .75232 L
s
.46476 .75232 m
.47385 .79486 L
s
.42901 .6411 m
.42936 .64198 L
s
.42866 .64023 m
.42901 .6411 L
s
.4283 .63936 m
.42866 .64023 L
s
.42795 .63848 m
.4283 .63936 L
s
.42795 .63848 m
.42795 .63848 L
s
.4277 .63786 m
.42795 .63848 L
s
.42744 .63724 m
.4277 .63786 L
s
.42719 .63662 m
.42744 .63724 L
s
.42693 .636 m
.42719 .63662 L
s
.42667 .63537 m
.42693 .636 L
s
.42642 .63476 m
.42667 .63537 L
s
.42616 .63414 m
.42642 .63476 L
s
.42591 .63352 m
.42616 .63414 L
s
.46696 .76164 m
.46902 .77081 L
s
.42565 .6329 m
.42591 .63352 L
s
.42539 .63228 m
.42565 .6329 L
s
.42513 .63166 m
.42539 .63228 L
s
.42487 .63105 m
.42513 .63166 L
s
.42487 .63105 m
.42487 .63105 L
s
.42468 .63058 m
.42487 .63105 L
s
.42449 .63012 m
.42468 .63058 L
s
.42429 .62966 m
.42449 .63012 L
s
.4241 .6292 m
.42429 .62966 L
s
.4239 .62874 m
.4241 .6292 L
s
.42371 .62828 m
.4239 .62874 L
s
.42351 .62782 m
.42371 .62828 L
s
.42332 .62736 m
.42351 .62782 L
s
.42312 .6269 m
.42332 .62736 L
s
.40521 .58797 m
.42326 .62723 L
s
.42292 .62644 m
.42312 .6269 L
s
.42273 .62598 m
.42292 .62644 L
s
.42253 .62552 m
.42273 .62598 L
s
.42253 .62552 m
.42253 .62552 L
s
.42238 .62516 m
.42253 .62552 L
s
.46902 .77081 m
.47093 .77984 L
s
.42222 .62481 m
.42238 .62516 L
s
.42207 .62445 m
.42222 .62481 L
s
.42192 .62409 m
.42207 .62445 L
s
.42176 .62374 m
.42192 .62409 L
s
.42161 .62338 m
.42176 .62374 L
s
.42146 .62303 m
.42161 .62338 L
s
.4213 .62267 m
.42146 .62303 L
s
.42115 .62232 m
.4213 .62267 L
s
.42099 .62196 m
.42115 .62232 L
s
.42084 .62161 m
.42099 .62196 L
s
.42068 .62125 m
.42084 .62161 L
s
.42068 .62125 m
.42068 .62125 L
s
.41944 .61842 m
.42068 .62125 L
s
.41819 .6156 m
.41944 .61842 L
s
.47093 .77984 m
.4727 .78876 L
s
.41694 .61279 m
.41819 .6156 L
s
.41567 .60999 m
.41694 .61279 L
s
.41439 .6072 m
.41567 .60999 L
s
.48211 .74693 m
.49955 .74151 L
s
.4727 .78876 m
.47434 .79755 L
s
.41311 .60442 m
.41439 .6072 L
s
.41181 .60165 m
.41311 .60442 L
s
.47385 .79486 m
.48035 .837 L
s
.41051 .59889 m
.41181 .60165 L
s
.47434 .79755 m
.47585 .80623 L
s
.4092 .59615 m
.41051 .59889 L
s
.40788 .59341 m
.4092 .59615 L
s
.40655 .59068 m
.40788 .59341 L
s
.47585 .80623 m
.47724 .8148 L
s
.40521 .58797 m
.40655 .59068 L
s
.40521 .58797 m
.40521 .58797 L
s
.39907 .57587 m
.40521 .58797 L
s
.38535 .55072 m
.40521 .58797 L
s
.51709 .73606 m
.49955 .74151 L
s
.47724 .8148 m
.47851 .82326 L
s
.47851 .82326 m
.47966 .83163 L
s
.39275 .56397 m
.39907 .57587 L
s
.47966 .83163 m
.4807 .8399 L
s
.53473 .73059 m
.51709 .73606 L
s
.48035 .837 m
.48413 .87823 L
s
.38623 .55226 m
.39275 .56397 L
s
.4807 .8399 m
.48162 .84809 L
s
.48162 .84809 m
.48244 .85618 L
s
.37951 .54075 m
.38623 .55226 L
s
.55247 .72508 m
.53473 .73059 L
s
.36389 .51598 m
.38535 .55072 L
s
.48244 .85618 m
.48252 .85707 L
s
.48244 .85618 m
.48244 .85618 L
s
.48252 .85707 m
.4826 .85797 L
s
.4826 .85797 m
.48268 .85886 L
s
.48268 .85886 m
.48276 .85975 L
s
.48276 .85975 m
.48284 .86064 L
s
.48284 .86064 m
.48292 .86153 L
s
.48292 .86153 m
.48299 .86241 L
s
.48299 .86241 m
.48307 .8633 L
s
.48307 .8633 m
.48314 .86419 L
s
.48314 .86419 m
.48321 .86507 L
s
.37258 .52943 m
.37951 .54075 L
s
.48321 .86507 m
.48328 .86596 L
s
.48328 .86596 m
.48335 .86684 L
s
.48335 .86684 m
.4834 .86747 L
s
.48335 .86684 m
.48335 .86684 L
s
.4834 .86747 m
.48345 .8681 L
s
.5703 .71954 m
.55247 .72508 L
s
.48345 .8681 m
.48349 .86873 L
s
.48349 .86873 m
.48354 .86935 L
s
.47439 .57712 m
.4725 .57594 L
s
.47628 .5783 m
.47439 .57712 L
s
.47816 .57948 m
.47628 .5783 L
s
.4725 .57594 m
.47061 .57477 L
s
.48005 .58066 m
.47816 .57948 L
s
.46638 .5723 m
.48874 .58603 L
s
.44428 .55813 m
.46638 .5723 L
s
.47061 .57477 m
.46871 .57361 L
s
.48193 .58185 m
.48005 .58066 L
s
.46871 .57361 m
.46681 .57244 L
s
.48381 .58305 m
.48193 .58185 L
s
.46681 .57244 m
.46491 .57128 L
s
.48354 .86935 m
.48359 .86998 L
s
.48381 .58305 m
.48381 .58305 L
s
.4858 .5842 m
.48381 .58305 L
s
.46491 .57128 m
.46301 .57013 L
s
.46301 .57013 m
.4611 .56898 L
s
.4878 .58537 m
.4858 .5842 L
s
.4611 .56898 m
.45932 .56779 L
s
.4611 .56898 m
.4611 .56898 L
s
.48979 .58653 m
.4878 .58537 L
s
.48874 .58603 m
.51137 .59938 L
s
.45932 .56779 m
.45752 .5666 L
s
.48359 .86998 m
.48363 .87061 L
s
.49178 .5877 m
.48979 .58653 L
s
.45752 .5666 m
.45573 .56542 L
s
.49376 .58887 m
.49178 .5877 L
s
.45573 .56542 m
.45393 .56424 L
s
.49575 .59005 m
.49376 .58887 L
s
.45393 .56424 m
.45213 .56307 L
s
.48363 .87061 m
.48368 .87124 L
s
.49773 .59123 m
.49575 .59005 L
s
.45213 .56307 m
.45033 .5619 L
s
.49971 .59242 m
.49773 .59123 L
s
.45033 .5619 m
.44853 .56073 L
s
.48368 .87124 m
.48372 .87186 L
s
.50169 .59361 m
.49971 .59242 L
s
.44853 .56073 m
.44672 .55957 L
s
.50367 .5948 m
.50169 .59361 L
s
.44672 .55957 m
.44491 .55841 L
s
.48372 .87186 m
.48376 .87249 L
s
.50564 .596 m
.50367 .5948 L
s
.42244 .54344 m
.44428 .55813 L
s
.44491 .55841 m
.4431 .55726 L
s
.50762 .5972 m
.50564 .596 L
s
.48376 .87249 m
.4838 .87311 L
s
.4431 .55726 m
.44128 .5561 L
s
.50762 .5972 m
.50762 .5972 L
s
.50971 .59836 m
.50762 .5972 L
s
.44128 .5561 m
.43946 .55495 L
s
.5118 .59953 m
.50971 .59836 L
s
.4838 .87311 m
.48385 .87374 L
s
.43946 .55495 m
.43946 .55495 L
s
.43946 .55495 m
.43776 .55377 L
s
.51137 .59938 m
.53431 .61241 L
s
.51389 .60071 m
.5118 .59953 L
s
.48385 .87374 m
.48389 .87436 L
s
.43776 .55377 m
.43606 .55259 L
s
.51598 .60188 m
.51389 .60071 L
s
.43606 .55259 m
.43435 .55141 L
s
.48389 .87436 m
.48392 .87483 L
s
.48389 .87436 m
.48389 .87436 L
s
.51806 .60306 m
.51598 .60188 L
s
.43435 .55141 m
.43264 .55023 L
s
.48392 .87483 m
.48395 .8753 L
s
.52014 .60425 m
.51806 .60306 L
s
.48395 .8753 m
.48398 .87576 L
s
.43264 .55023 m
.43093 .54906 L
s
.52223 .60544 m
.52014 .60425 L
s
.48398 .87576 m
.48401 .87623 L
s
.43093 .54906 m
.42921 .54789 L
s
.52431 .60664 m
.52223 .60544 L
s
.48401 .87623 m
.48403 .8767 L
s
.42921 .54789 m
.42749 .54673 L
s
.48403 .8767 m
.48406 .87717 L
s
.52638 .60783 m
.52431 .60664 L
s
.42749 .54673 m
.42577 .54557 L
s
.48406 .87717 m
.48409 .87763 L
s
.52846 .60904 m
.52638 .60783 L
s
.42577 .54557 m
.42404 .54441 L
s
.48409 .87763 m
.48412 .8781 L
s
.36543 .51831 m
.37258 .52943 L
s
.53053 .61025 m
.52846 .60904 L
s
.48412 .8781 m
.48415 .87856 L
s
.42404 .54441 m
.42232 .54326 L
s
.48413 .87823 m
.48509 .91804 L
s
.48415 .87856 m
.48417 .87903 L
s
.5326 .61146 m
.53053 .61025 L
s
.40083 .52812 m
.42244 .54344 L
s
.42232 .54326 m
.42058 .54211 L
s
.48417 .87903 m
.4842 .87949 L
s
.5326 .61146 m
.5326 .61146 L
s
.5348 .61263 m
.5326 .61146 L
s
.42058 .54211 m
.41885 .54096 L
s
.4842 .87949 m
.48423 .87996 L
s
.53431 .61241 m
.55756 .62515 L
s
.537 .61381 m
.5348 .61263 L
s
.48423 .87996 m
.48425 .88032 L
s
.48423 .87996 m
.48423 .87996 L
s
.41885 .54096 m
.41723 .53977 L
s
.41885 .54096 m
.41885 .54096 L
s
.48425 .88032 m
.48427 .88068 L
s
.53919 .615 m
.537 .61381 L
s
.48427 .88068 m
.48429 .88104 L
s
.41723 .53977 m
.41562 .53859 L
s
.48429 .88104 m
.4843 .8814 L
s
.4843 .8814 m
.48432 .88176 L
s
.54138 .61618 m
.53919 .615 L
s
.41562 .53859 m
.41399 .53741 L
s
.48432 .88176 m
.48434 .88212 L
s
.48434 .88212 m
.48436 .88248 L
s
.54357 .61738 m
.54138 .61618 L
s
.58824 .71397 m
.5703 .71954 L
s
.41399 .53741 m
.41237 .53624 L
s
.48436 .88248 m
.48438 .88284 L
s
.48438 .88284 m
.4844 .8832 L
s
.54576 .61857 m
.54357 .61738 L
s
.41237 .53624 m
.41074 .53507 L
s
.4844 .8832 m
.48442 .88356 L
s
.48442 .88356 m
.48443 .88392 L
s
.54795 .61978 m
.54576 .61857 L
s
.48443 .88392 m
.48445 .88428 L
s
.41074 .53507 m
.40911 .5339 L
s
.48445 .88428 m
.48458 .88715 L
s
.48445 .88428 m
.48445 .88428 L
s
.55014 .62098 m
.54795 .61978 L
s
.40911 .5339 m
.40747 .53273 L
s
.55232 .62219 m
.55014 .62098 L
s
.40747 .53273 m
.40583 .53157 L
s
.5545 .62341 m
.55232 .62219 L
s
.40583 .53157 m
.40419 .53041 L
s
.55668 .62463 m
.5545 .62341 L
s
.48458 .88715 m
.4847 .89001 L
s
.40419 .53041 m
.40255 .52926 L
s
.55886 .62586 m
.55668 .62463 L
s
.40255 .52926 m
.4009 .52811 L
s
.55756 .62515 m
.58114 .63765 L
s
.55886 .62586 m
.55886 .62586 L
s
.56117 .62704 m
.55886 .62586 L
s
.37947 .51202 m
.40083 .52812 L
s
.4009 .52811 m
.39925 .52696 L
s
.56348 .62824 m
.56117 .62704 L
s
.39925 .52696 m
.39772 .52577 L
s
.39925 .52696 m
.39925 .52696 L
s
.4847 .89001 m
.48481 .89286 L
s
.56579 .62943 m
.56348 .62824 L
s
.39772 .52577 m
.39618 .52459 L
s
.35805 .50739 m
.36543 .51831 L
s
.5681 .63063 m
.56579 .62943 L
s
.39618 .52459 m
.39465 .52341 L
s
.5704 .63184 m
.5681 .63063 L
s
.39465 .52341 m
.3931 .52223 L
s
.48481 .89286 m
.48489 .8957 L
s
.57271 .63305 m
.5704 .63184 L
s
.34105 .48423 m
.36389 .51598 L
s
.3931 .52223 m
.39156 .52106 L
s
.57501 .63427 m
.57271 .63305 L
s
.39156 .52106 m
.39001 .51989 L
s
.60627 .70836 m
.58824 .71397 L
s
.48489 .8957 m
.48497 .89853 L
s
.57731 .63549 m
.57501 .63427 L
s
.39001 .51989 m
.38846 .51872 L
s
.57961 .63672 m
.57731 .63549 L
s
.38846 .51872 m
.38691 .51756 L
s
.58191 .63795 m
.57961 .63672 L
s
.38691 .51756 m
.38535 .5164 L
s
.48497 .89853 m
.48503 .90134 L
s
.58114 .63765 m
.6051 .64992 L
s
.58421 .63919 m
.58191 .63795 L
s
.38535 .5164 m
.38379 .51524 L
s
.5865 .64043 m
.58421 .63919 L
s
.38379 .51524 m
.38222 .51409 L
s
.5865 .64043 m
.5865 .64043 L
s
.58894 .64163 m
.5865 .64043 L
s
.38222 .51409 m
.38065 .51294 L
s
.48503 .90134 m
.48507 .90415 L
s
.38065 .51294 m
.37921 .51174 L
s
.38065 .51294 m
.38065 .51294 L
s
.59137 .64284 m
.58894 .64163 L
s
.35836 .4949 m
.37947 .51202 L
s
.37921 .51174 m
.37776 .51056 L
s
.59381 .64405 m
.59137 .64284 L
s
.48507 .90415 m
.48511 .90695 L
s
.35042 .49666 m
.35805 .50739 L
s
.37776 .51056 m
.37631 .50937 L
s
.59624 .64527 m
.59381 .64405 L
s
.37631 .50937 m
.37486 .50819 L
s
.59868 .64649 m
.59624 .64527 L
s
.37486 .50819 m
.3734 .50701 L
s
.48511 .90695 m
.48512 .90974 L
s
.60111 .64772 m
.59868 .64649 L
s
.62441 .70273 m
.60627 .70836 L
s
.3734 .50701 m
.37194 .50583 L
s
.60354 .64896 m
.60111 .64772 L
s
.37194 .50583 m
.37047 .50466 L
s
.60597 .6502 m
.60354 .64896 L
s
.48512 .90974 m
.48512 .91251 L
s
.6051 .64992 m
.62944 .662 L
s
.37047 .50466 m
.369 .50349 L
s
.60839 .65145 m
.60597 .6502 L
s
.369 .50349 m
.36753 .50233 L
s
.61082 .6527 m
.60839 .65145 L
s
.48512 .91251 m
.48511 .91528 L
s
.36753 .50233 m
.36605 .50117 L
s
.61325 .65396 m
.61082 .6527 L
s
.36605 .50117 m
.36457 .50001 L
s
.61567 .65522 m
.61325 .65396 L
s
.48511 .91528 m
.48509 .91804 L
s
.36457 .50001 m
.36308 .49885 L
s
.61567 .65522 m
.61567 .65522 L
s
.61825 .65644 m
.61567 .65522 L
s
.36308 .49885 m
.36173 .49765 L
s
.36308 .49885 m
.36308 .49885 L
s
.62083 .65767 m
.61825 .65644 L
s
.34253 .48614 m
.35042 .49666 L
s
.36173 .49765 m
.36038 .49646 L
s
.48509 .91804 m
.48478 .93033 L
s
.48509 .91804 m
.48509 .91804 L
s
.48509 .91804 m
.48314 .95588 L
s
.48509 .91804 m
.45646 .89131 L
s
.48509 .91804 m
.48509 .91804 L
s
.62341 .6589 m
.62083 .65767 L
s
.36038 .49646 m
.35902 .49527 L
s
.64264 .69707 m
.62441 .70273 L
s
.62598 .66014 m
.62341 .6589 L
s
.35902 .49527 m
.35765 .49408 L
s
.33753 .47642 m
.35836 .4949 L
s
.62856 .66138 m
.62598 .66014 L
s
.35765 .49408 m
.35628 .49289 L
s
.63113 .66263 m
.62856 .66138 L
s
.62944 .662 m
.65421 .6739 L
s
.35628 .49289 m
.35491 .49171 L
s
.63371 .66389 m
.63113 .66263 L
s
.35491 .49171 m
.35353 .49053 L
s
.63628 .66515 m
.63371 .66389 L
s
.35353 .49053 m
.35215 .48935 L
s
.63885 .66642 m
.63628 .66515 L
s
.35215 .48935 m
.35077 .48818 L
s
.64142 .6677 m
.63885 .66642 L
s
.35077 .48818 m
.34938 .48701 L
s
.64399 .66898 m
.64142 .6677 L
s
.34938 .48701 m
.34798 .48585 L
s
.48478 .93033 m
.48418 .94242 L
s
.33436 .47584 m
.34253 .48614 L
s
.64264 .69707 m
.66098 .69137 L
s
.64656 .67027 m
.64399 .66898 L
s
.34798 .48585 m
.34658 .48469 L
s
.64656 .67027 m
.64656 .67027 L
s
.64931 .67151 m
.64656 .67027 L
s
.60338 .80358 m
.60485 .80134 L
s
.60338 .80358 m
.60338 .80358 L
s
.60204 .80579 m
.60338 .80358 L
s
.60485 .80134 m
.60632 .79908 L
s
.60256 .80488 m
.58804 .828 L
s
.61735 .78155 m
.60256 .80488 L
s
.60632 .79908 m
.60778 .79683 L
s
.60778 .79683 m
.60924 .79456 L
s
.60069 .80798 m
.60204 .80579 L
s
.60924 .79456 m
.61069 .7923 L
s
.31708 .45595 m
.34105 .48423 L
s
.61069 .7923 m
.61214 .79002 L
s
.59934 .81018 m
.60069 .80798 L
s
.34658 .48469 m
.34533 .48348 L
s
.34658 .48469 m
.34658 .48469 L
s
.61214 .79002 m
.61358 .78774 L
s
.59799 .81236 m
.59934 .81018 L
s
.61358 .78774 m
.61502 .78546 L
s
.61502 .78546 m
.61645 .78317 L
s
.59663 .81455 m
.59799 .81236 L
s
.63242 .75799 m
.61735 .78155 L
s
.61645 .78317 m
.61788 .78088 L
s
.59527 .81673 m
.59663 .81455 L
s
.61788 .78088 m
.6193 .77858 L
s
.5939 .8189 m
.59527 .81673 L
s
.6193 .77858 m
.62072 .77627 L
s
.59252 .82107 m
.5939 .8189 L
s
.62072 .77627 m
.62228 .77392 L
s
.62072 .77627 m
.62072 .77627 L
s
.59114 .82323 m
.59252 .82107 L
s
.62228 .77392 m
.62383 .77156 L
s
.58976 .82539 m
.59114 .82323 L
s
.65205 .67276 m
.64931 .67151 L
s
.62383 .77156 m
.62538 .76919 L
s
.58837 .82754 m
.58976 .82539 L
s
.58698 .8297 m
.58837 .82754 L
s
.58804 .828 m
.57378 .85093 L
s
.62538 .76919 m
.62692 .76682 L
s
.58698 .8297 m
.58698 .8297 L
s
.58571 .8318 m
.58698 .8297 L
s
.34533 .48348 m
.34407 .48227 L
s
.62692 .76682 m
.62846 .76444 L
s
.58444 .83391 m
.58571 .8318 L
s
.62846 .76444 m
.62999 .76206 L
s
.58316 .836 m
.58444 .83391 L
s
.62999 .76206 m
.63152 .75967 L
s
.58188 .8381 m
.58316 .836 L
s
.63152 .75967 m
.63304 .75727 L
s
.64778 .73417 m
.63242 .75799 L
s
.58059 .84019 m
.58188 .8381 L
s
.65479 .67402 m
.65205 .67276 L
s
.63304 .75727 m
.63456 .75487 L
s
.5793 .84227 m
.58059 .84019 L
s
.63456 .75487 m
.63608 .75246 L
s
.34407 .48227 m
.34281 .48106 L
s
.578 .84436 m
.5793 .84227 L
s
.63608 .75246 m
.63758 .75005 L
s
.5767 .84643 m
.578 .84436 L
s
.63758 .75005 m
.63909 .74763 L
s
.65421 .6739 m
.67943 .68564 L
s
.5754 .84851 m
.5767 .84643 L
s
.63909 .74763 m
.64074 .74515 L
s
.63909 .74763 m
.63909 .74763 L
s
.65752 .67528 m
.65479 .67402 L
s
.57408 .85057 m
.5754 .84851 L
s
.64074 .74515 m
.64239 .74267 L
s
.34281 .48106 m
.34154 .47986 L
s
.57378 .85093 m
.55977 .8737 L
s
.57277 .85264 m
.57408 .85057 L
s
.64239 .74267 m
.64404 .74018 L
s
.57145 .8547 m
.57277 .85264 L
s
.64404 .74018 m
.64567 .73769 L
s
.57145 .8547 m
.57145 .8547 L
s
.57025 .85672 m
.57145 .8547 L
s
.66026 .67655 m
.65752 .67528 L
s
.64567 .73769 m
.64731 .73519 L
s
.56904 .85874 m
.57025 .85672 L
s
.34154 .47986 m
.34026 .47867 L
s
.64731 .73519 m
.64894 .73268 L
s
.56783 .86075 m
.56904 .85874 L
s
.66344 .71006 m
.64778 .73417 L
s
.64894 .73268 m
.65056 .73017 L
s
.56662 .86275 m
.56783 .86075 L
s
.5654 .86476 m
.56662 .86275 L
s
.65056 .73017 m
.65218 .72764 L
s
.663 .67783 m
.66026 .67655 L
s
.34026 .47867 m
.33899 .47747 L
s
.56418 .86676 m
.5654 .86476 L
s
.65218 .72764 m
.65379 .72512 L
s
.56295 .86875 m
.56418 .86676 L
s
.65379 .72512 m
.6554 .72258 L
s
.66098 .69137 m
.67943 .68564 L
s
.56172 .87075 m
.56295 .86875 L
s
.6554 .72258 m
.65701 .72004 L
s
.66574 .67911 m
.663 .67783 L
s
.33899 .47747 m
.3377 .47629 L
s
.56048 .87273 m
.56172 .87075 L
s
.65701 .72004 m
.6586 .71749 L
s
.55924 .87472 m
.56048 .87273 L
s
.48418 .94242 m
.48328 .95432 L
s
.6586 .71749 m
.66037 .71488 L
s
.6586 .71749 m
.6586 .71749 L
s
.55977 .8737 m
.54603 .89632 L
s
.55799 .8767 m
.55924 .87472 L
s
.31708 .45595 m
.33753 .47642 L
s
.66848 .6804 m
.66574 .67911 L
s
.66037 .71488 m
.66213 .71226 L
s
.3377 .47629 m
.33641 .4751 L
s
.55673 .87867 m
.55799 .8767 L
s
.32589 .46577 m
.33436 .47584 L
s
.66213 .71226 m
.66388 .70963 L
s
.55673 .87867 m
.55673 .87867 L
s
.5556 .88061 m
.55673 .87867 L
s
.67943 .68564 m
.66344 .71006 L
s
.66388 .70963 m
.66563 .707 L
s
.55446 .88254 m
.5556 .88061 L
s
.67122 .6817 m
.66848 .6804 L
s
.33641 .4751 m
.33512 .47392 L
s
.55332 .88447 m
.55446 .88254 L
s
.66563 .707 m
.66737 .70436 L
s
.55217 .8864 m
.55332 .88447 L
s
.66737 .70436 m
.66911 .70171 L
s
.67395 .68301 m
.67122 .6817 L
s
.33512 .47392 m
.33382 .47274 L
s
.55102 .88832 m
.55217 .8864 L
s
.66911 .70171 m
.67084 .69905 L
s
.54986 .89024 m
.55102 .88832 L
s
.67084 .69905 m
.67257 .69639 L
s
.54869 .89215 m
.54986 .89024 L
s
.33382 .47274 m
.33252 .47157 L
s
.67669 .68432 m
.67395 .68301 L
s
.67257 .69639 m
.67429 .69371 L
s
.54753 .89407 m
.54869 .89215 L
s
.67429 .69371 m
.67601 .69103 L
s
.54635 .89597 m
.54753 .89407 L
s
.33252 .47157 m
.33121 .4704 L
s
.67943 .68564 m
.67669 .68432 L
s
.67601 .69103 m
.67772 .68834 L
s
.54517 .89788 m
.54635 .89597 L
s
.54603 .89632 m
.53255 .91881 L
s
.67772 .68834 m
.67943 .68564 L
s
.54399 .89978 m
.54517 .89788 L
s
.33121 .4704 m
.33007 .46917 L
s
.33121 .4704 m
.33121 .4704 L
s
.79001 .58781 m
.67943 .68564 L
s
.67943 .68564 m
.79001 .58781 L
s
.67943 .68564 m
.67943 .68564 L
s
.5428 .90167 m
.54399 .89978 L
s
.5428 .90167 m
.5428 .90167 L
s
.54173 .90353 m
.5428 .90167 L
s
.54066 .90539 m
.54173 .90353 L
s
.33007 .46917 m
.32891 .46795 L
s
.53958 .90724 m
.54066 .90539 L
s
.53849 .90908 m
.53958 .90724 L
s
.32891 .46795 m
.32775 .46673 L
s
.48328 .95432 m
.48207 .96602 L
s
.5374 .91093 m
.53849 .90908 L
s
.53631 .91277 m
.5374 .91093 L
s
.32775 .46673 m
.32659 .46552 L
s
.48314 .95588 m
.47822 .99121 L
s
.53521 .91461 m
.53631 .91277 L
s
.31708 .45595 m
.32589 .46577 L
s
.5341 .91644 m
.53521 .91461 L
s
.32659 .46552 m
.32542 .46431 L
s
.53299 .91827 m
.5341 .91644 L
s
.53187 .9201 m
.53299 .91827 L
s
.53255 .91881 m
.51935 .9412 L
s
.32542 .46431 m
.32424 .4631 L
s
.53075 .92192 m
.53187 .9201 L
s
.52963 .92374 m
.53075 .92192 L
s
.32424 .4631 m
.32306 .4619 L
s
.52963 .92374 m
.52963 .92374 L
s
.52862 .92552 m
.52963 .92374 L
s
.52761 .9273 m
.52862 .92552 L
s
.32306 .4619 m
.32188 .4607 L
s
.52659 .92907 m
.52761 .9273 L
s
.52557 .93084 m
.52659 .92907 L
s
.32188 .4607 m
.32069 .45951 L
s
.52454 .93261 m
.52557 .93084 L
s
.32069 .45951 m
.31949 .45832 L
s
.52351 .93438 m
.52454 .93261 L
s
.52247 .93614 m
.52351 .93438 L
s
.48207 .96602 m
.48053 .97753 L
s
.31949 .45832 m
.31829 .45713 L
s
.52142 .9379 m
.52247 .93614 L
s
.52038 .93965 m
.52142 .9379 L
s
.31829 .45713 m
.31708 .45595 L
s
.51932 .9414 m
.52038 .93965 L
s
.51935 .9412 m
.50645 .96351 L
s
.51826 .94315 m
.51932 .9414 L
s
.30034 .43625 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.30816 .44665 m
.31708 .45595 L
s
.29227 .43164 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31435 .50108 L
s
.45646 .89131 m
.42698 .86378 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31708 .45595 L
s
.31708 .45595 m
.31605 .45471 L
s
.31708 .45595 m
.31708 .45595 L
s
.5172 .94489 m
.51826 .94315 L
s
.5172 .94489 m
.5172 .94489 L
s
.51625 .9466 m
.5172 .94489 L
s
.31605 .45471 m
.31501 .45349 L
s
.5153 .9483 m
.51625 .9466 L
s
.31501 .45349 m
.31398 .45227 L
s
.51435 .95 m
.5153 .9483 L
s
.51339 .9517 m
.51435 .95 L
s
.31398 .45227 m
.31296 .45107 L
s
.51242 .95339 m
.51339 .9517 L
s
.51145 .95508 m
.51242 .95339 L
s
.31296 .45107 m
.31193 .44988 L
s
.51048 .95677 m
.51145 .95508 L
s
.48053 .97753 m
.47866 .98884 L
s
.50949 .95845 m
.51048 .95677 L
s
.31193 .44988 m
.31091 .44871 L
s
.50851 .96013 m
.50949 .95845 L
s
.31091 .44871 m
.30989 .44754 L
s
.50751 .96181 m
.50851 .96013 L
s
.50652 .96348 m
.50751 .96181 L
s
.30989 .44754 m
.30887 .44639 L
s
.50645 .96351 m
.4939 .98573 L
s
.50551 .96515 m
.50652 .96348 L
s
.29936 .43809 m
.30816 .44665 L
s
.30887 .44639 m
.30785 .44524 L
s
.50551 .96515 m
.50551 .96515 L
s
.50463 .96678 m
.50551 .96515 L
s
.50375 .96841 m
.50463 .96678 L
s
.30785 .44524 m
.30684 .44411 L
s
.50286 .97003 m
.50375 .96841 L
s
.30684 .44411 m
.30582 .443 L
s
.50196 .97165 m
.50286 .97003 L
s
.50106 .97327 m
.50196 .97165 L
s
.30582 .443 m
.30481 .44189 L
s
.50015 .97488 m
.50106 .97327 L
s
.47866 .98884 m
.47644 .99994 L
s
.30481 .44189 m
.30397 .44073 L
s
.30481 .44189 m
.30481 .44189 L
s
.49924 .97649 m
.50015 .97488 L
s
.49832 .9781 m
.49924 .97649 L
s
.30397 .44073 m
.30312 .43958 L
s
.47822 .99121 m
.47028 1.02344 L
s
.4974 .9797 m
.49832 .9781 L
s
.30312 .43958 m
.30228 .43845 L
s
.49647 .9813 m
.4974 .9797 L
s
.49553 .9829 m
.49647 .9813 L
s
.30228 .43845 m
.30144 .43732 L
s
.49459 .98449 m
.49553 .9829 L
s
.29067 .43024 m
.29936 .43809 L
s
.30144 .43732 m
.3006 .43621 L
s
.49459 .98449 m
.49459 .98449 L
s
.49378 .98605 m
.49459 .98449 L
s
.4939 .98573 m
.48176 1.00789 L
s
.49296 .9876 m
.49378 .98605 L
s
.28887 .41971 m
.30034 .43625 L
s
.3006 .43621 m
.29977 .43511 L
s
.49213 .98914 m
.49296 .9876 L
s
.29977 .43511 m
.29893 .43402 L
s
.4913 .99069 m
.49213 .98914 L
s
.47644 .99994 m
.47385 1.01083 L
s
.49047 .99223 m
.4913 .99069 L
s
.29893 .43402 m
.2981 .43293 L
s
.48963 .99376 m
.49047 .99223 L
s
.2981 .43293 m
.29727 .43186 L
s
.48878 .9953 m
.48963 .99376 L
s
.29727 .43186 m
.29644 .4308 L
s
.48793 .99683 m
.48878 .9953 L
s
.26693 .41178 m
.29227 .43164 L
s
.31435 .50108 m
.31154 .54736 L
s
.48707 .99835 m
.48793 .99683 L
s
.29644 .4308 m
.29562 .42975 L
s
.4862 .99988 m
.48707 .99835 L
s
.28208 .42306 m
.29067 .43024 L
s
.29562 .42975 m
.29479 .42871 L
s
.48533 1.0014 m
.4862 .99988 L
s
.29479 .42871 m
.29412 .42762 L
s
.29479 .42871 m
.29479 .42871 L
s
.48445 1.00291 m
.48533 1.0014 L
s
.48445 1.00291 m
.48445 1.00291 L
s
.48371 1.00438 m
.48445 1.00291 L
s
.29412 .42762 m
.29345 .42655 L
s
.48296 1.00585 m
.48371 1.00438 L
s
.42698 .86378 m
.39659 .8354 L
s
.29345 .42655 m
.29278 .42548 L
s
.47385 1.01083 m
.47088 1.0215 L
s
.48221 1.00732 m
.48296 1.00585 L
s
.29278 .42548 m
.29212 .42442 L
s
.48145 1.00878 m
.48221 1.00732 L
s
.48176 1.00789 m
.47016 1.02999 L
s
.48069 1.01024 m
.48145 1.00878 L
s
.29212 .42442 m
.29145 .42338 L
s
.47991 1.0117 m
.48069 1.01024 L
s
.29145 .42338 m
.29079 .42234 L
s
.47914 1.01315 m
.47991 1.0117 L
s
.29079 .42234 m
.29013 .42131 L
s
.27357 .41651 m
.28208 .42306 L
s
.47835 1.0146 m
.47914 1.01315 L
s
.29013 .42131 m
.28947 .4203 L
s
.47756 1.01604 m
.47835 1.0146 L
s
.47676 1.01748 m
.47756 1.01604 L
s
.28947 .4203 m
.28881 .41929 L
s
.2812 .4054 m
.28887 .41971 L
s
.47596 1.01892 m
.47676 1.01748 L
s
.28881 .41929 m
.28816 .41829 L
s
.47088 1.0215 m
.46749 1.03192 L
s
.47514 1.02035 m
.47596 1.01892 L
s
.28816 .41829 m
.2875 .4173 L
s
.47514 1.02035 m
.47514 1.02035 L
s
.47448 1.02174 m
.47514 1.02035 L
s
.47028 1.02344 m
.45933 1.05199 L
s
.2875 .4173 m
.28685 .41632 L
s
.47381 1.02312 m
.47448 1.02174 L
s
.28685 .41632 m
.28634 .4153 L
s
.28685 .41632 m
.28685 .41632 L
s
.47314 1.0245 m
.47381 1.02312 L
s
.47245 1.02588 m
.47314 1.0245 L
s
.28634 .4153 m
.28583 .41429 L
s
.26515 .41058 m
.27357 .41651 L
s
.47177 1.02725 m
.47245 1.02588 L
s
.28583 .41429 m
.28533 .41328 L
s
.47107 1.02862 m
.47177 1.02725 L
s
.28533 .41328 m
.28482 .41229 L
s
.47036 1.02998 m
.47107 1.02862 L
s
.28482 .41229 m
.28432 .4113 L
s
.47016 1.02999 m
.45933 1.05199 L
s
.46965 1.03135 m
.47036 1.02998 L
s
.46749 1.03192 m
.46365 1.0421 L
s
.28432 .4113 m
.28382 .41033 L
s
.46894 1.0327 m
.46965 1.03135 L
s
.31154 .54736 m
.30867 .59482 L
s
.46821 1.03405 m
.46894 1.0327 L
s
.28382 .41033 m
.28332 .40936 L
s
.2414 .39685 m
.26693 .41178 L
s
.46748 1.0354 m
.46821 1.03405 L
s
.28332 .40936 m
.28283 .4084 L
s
.46674 1.03675 m
.46748 1.0354 L
s
.28283 .4084 m
.28233 .40745 L
s
.2568 .40524 m
.26515 .41058 L
s
.46674 1.03675 m
.46674 1.03675 L
s
.46616 1.03804 m
.46674 1.03675 L
s
.28233 .40745 m
.28184 .40651 L
s
.46558 1.03933 m
.46616 1.03804 L
s
.28184 .40651 m
.28135 .40558 L
s
.46499 1.04062 m
.46558 1.03933 L
s
.28135 .40558 m
.28086 .40466 L
s
.27649 .3928 m
.2812 .4054 L
s
.46439 1.0419 m
.46499 1.04062 L
s
.28086 .40466 m
.28051 .4037 L
s
.28086 .40466 m
.28086 .40466 L
s
.46365 1.0421 m
.45933 1.05199 L
s
.46379 1.04318 m
.46439 1.0419 L
s
.39659 .8354 m
.36526 .80614 L
s
.28051 .4037 m
.28016 .40274 L
s
.46318 1.04445 m
.46379 1.04318 L
s
.28016 .40274 m
.27981 .4018 L
s
.46255 1.04572 m
.46318 1.04445 L
s
.46193 1.04698 m
.46255 1.04572 L
s
.27981 .4018 m
.27946 .40086 L
s
.24852 .4005 m
.2568 .40524 L
s
.46129 1.04824 m
.46193 1.04698 L
s
.27946 .40086 m
.27911 .39993 L
s
.46064 1.0495 m
.46129 1.04824 L
s
.27911 .39993 m
.27877 .39901 L
s
.45999 1.05075 m
.46064 1.0495 L
s
.27877 .39901 m
.27843 .3981 L
s
.45933 1.05199 m
.45999 1.05075 L
s
.27843 .3981 m
.27809 .3972 L
s
.45933 1.05199 m
.45121 1.07034 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45462 1.06132 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.44539 1.07628 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45933 1.05199 m
.45933 1.05199 L
s
.45885 1.05318 m
.45933 1.05199 L
s
.27809 .3972 m
.27775 .3963 L
s
.45836 1.05435 m
.45885 1.05318 L
s
.27775 .3963 m
.27742 .39542 L
s
.45787 1.05551 m
.45836 1.05435 L
s
.24031 .39633 m
.24852 .4005 L
s
.27742 .39542 m
.27708 .39454 L
s
.45738 1.05666 m
.45787 1.05551 L
s
.27708 .39454 m
.27675 .39368 L
s
.45688 1.0578 m
.45738 1.05666 L
s
.30867 .59482 m
.30572 .64352 L
s
.27675 .39368 m
.27655 .39277 L
s
.27675 .39368 m
.27675 .39368 L
s
.45638 1.05892 m
.45688 1.0578 L
s
.27426 .38157 m
.27649 .3928 L
s
.27655 .39277 m
.27635 .39187 L
s
.45587 1.06003 m
.45638 1.05892 L
s
.27635 .39187 m
.27615 .39098 L
s
.45537 1.06113 m
.45587 1.06003 L
s
.27615 .39098 m
.27596 .39009 L
s
.45462 1.06132 m
.44964 1.06987 L
s
.45485 1.06221 m
.45537 1.06113 L
s
.21606 .38729 m
.2414 .39685 L
s
.27596 .39009 m
.27577 .38922 L
s
.45433 1.06329 m
.45485 1.06221 L
s
.23217 .39274 m
.24031 .39633 L
s
.27577 .38922 m
.27558 .38835 L
s
.45381 1.06435 m
.45433 1.06329 L
s
.27558 .38835 m
.27539 .3875 L
s
.45329 1.0654 m
.45381 1.06435 L
s
.27539 .3875 m
.2752 .38665 L
s
.45329 1.0654 m
.45329 1.0654 L
s
.45293 1.06639 m
.45329 1.0654 L
s
.45257 1.06737 m
.45293 1.06639 L
s
.2752 .38665 m
.27502 .38581 L
s
.45221 1.06834 m
.45257 1.06737 L
s
.27502 .38581 m
.27483 .38498 L
s
.45185 1.06929 m
.45221 1.06834 L
s
.27483 .38498 m
.27465 .38415 L
s
.36526 .80614 m
.33294 .77597 L
s
.44964 1.06987 m
.44441 1.07767 L
s
.45148 1.07024 m
.45185 1.06929 L
s
.27465 .38415 m
.27448 .38334 L
s
.22408 .38973 m
.23217 .39274 L
s
.45121 1.07034 m
.44645 1.08322 L
s
.4511 1.07117 m
.45148 1.07024 L
s
.27448 .38334 m
.27443 .38248 L
s
.27448 .38334 m
.27448 .38334 L
s
.45073 1.07209 m
.4511 1.07117 L
s
.27443 .38248 m
.27438 .38164 L
s
.45035 1.073 m
.45073 1.07209 L
s
.27438 .38164 m
.27433 .3808 L
s
.27418 .37151 m
.27426 .38157 L
s
.44996 1.0739 m
.45035 1.073 L
s
.27433 .3808 m
.27429 .37997 L
s
.44958 1.07478 m
.44996 1.0739 L
s
.27429 .37997 m
.27425 .37915 L
s
.44539 1.07628 m
.42854 1.09573 L
s
.44919 1.07566 m
.44958 1.07478 L
s
.27425 .37915 m
.27421 .37833 L
s
.30572 .64352 m
.30269 .6935 L
s
.44879 1.07652 m
.44919 1.07566 L
s
.44441 1.07767 m
.43893 1.08475 L
s
.21606 .38729 m
.22408 .38973 L
s
.27421 .37833 m
.27418 .37753 L
s
.44879 1.07652 m
.44879 1.07652 L
s
.44855 1.07734 m
.44879 1.07652 L
s
.27418 .37753 m
.27414 .37673 L
s
.44831 1.07814 m
.44855 1.07734 L
s
.27414 .37673 m
.27411 .37594 L
s
.44807 1.07893 m
.44831 1.07814 L
s
.27411 .37594 m
.27408 .37516 L
s
.44782 1.0797 m
.44807 1.07893 L
s
.27408 .37516 m
.27405 .37439 L
s
.44757 1.08047 m
.44782 1.0797 L
s
.27405 .37439 m
.27403 .37363 L
s
.44732 1.08123 m
.44757 1.08047 L
s
.21606 .38729 m
.21606 .38729 L
s
.21429 .38683 m
.21606 .38729 L
s
.19134 .38351 m
.21606 .38729 L
s
.27403 .37363 m
.27413 .37282 L
s
.27403 .37363 m
.27403 .37363 L
s
.44707 1.08197 m
.44732 1.08123 L
s
.43893 1.08475 m
.43321 1.09115 L
s
.44681 1.08271 m
.44707 1.08197 L
s
.27413 .37282 m
.27424 .37203 L
s
.21252 .3864 m
.21429 .38683 L
s
.44654 1.08343 m
.44681 1.08271 L
s
.27424 .37203 m
.27434 .37124 L
s
.44645 1.08322 m
.44412 1.09216 L
s
.27603 .36248 m
.27418 .37151 L
s
.21075 .38599 m
.21252 .3864 L
s
.44628 1.08415 m
.44654 1.08343 L
s
.27434 .37124 m
.27445 .37046 L
s
.44601 1.08485 m
.44628 1.08415 L
s
.27445 .37046 m
.27457 .36969 L
s
.20899 .38562 m
.21075 .38599 L
s
.44574 1.08554 m
.44601 1.08485 L
s
.27457 .36969 m
.27468 .36893 L
s
.44574 1.08554 m
.44574 1.08554 L
s
.44561 1.08618 m
.44574 1.08554 L
s
.20722 .38527 m
.20899 .38562 L
s
.27468 .36893 m
.2748 .36818 L
s
.33294 .77597 m
.29959 .74482 L
s
.44549 1.08682 m
.44561 1.08618 L
s
.43321 1.09115 m
.42726 1.09689 L
s
.20547 .38496 m
.20722 .38527 L
s
.2748 .36818 m
.27492 .36743 L
s
.44536 1.08744 m
.44549 1.08682 L
s
.27492 .36743 m
.27504 .3667 L
s
.20371 .38467 m
.20547 .38496 L
s
.44522 1.08805 m
.44536 1.08744 L
s
.27504 .3667 m
.27517 .36597 L
s
.44509 1.08865 m
.44522 1.08805 L
s
.30269 .6935 m
.29959 .74482 L
s
.20196 .38442 m
.20371 .38467 L
s
.27517 .36597 m
.2753 .36525 L
s
.44495 1.08924 m
.44509 1.08865 L
s
.2753 .36525 m
.27543 .36454 L
s
.20021 .38419 m
.20196 .38442 L
s
.44481 1.08982 m
.44495 1.08924 L
s
.27543 .36454 m
.27568 .36379 L
s
.27543 .36454 m
.27543 .36454 L
s
.44466 1.09039 m
.44481 1.08982 L
s
.42854 1.09573 m
.40893 1.10978 L
s
.19846 .384 m
.20021 .38419 L
s
.27568 .36379 m
.27595 .36304 L
s
.44451 1.09095 m
.44466 1.09039 L
s
.42726 1.09689 m
.42108 1.10198 L
s
.44436 1.0915 m
.44451 1.09095 L
s
.19672 .38383 m
.19846 .384 L
s
.27595 .36304 m
.27621 .36231 L
s
.27965 .35437 m
.27603 .36248 L
s
.44421 1.09204 m
.44436 1.0915 L
s
.27621 .36231 m
.27648 .36158 L
s
.19498 .3837 m
.19672 .38383 L
s
.44405 1.09256 m
.44421 1.09204 L
s
.44412 1.09216 m
.44372 1.098 L
s
.27648 .36158 m
.27675 .36086 L
s
.44405 1.09256 m
.44405 1.09256 L
s
.44404 1.09304 m
.44405 1.09256 L
s
.19498 .3837 m
.19498 .3837 L
s
.19476 .38368 m
.19498 .3837 L
s
.19454 .38367 m
.19476 .38368 L
s
.27675 .36086 m
.27702 .36015 L
s
.19433 .38365 m
.19454 .38367 L
s
.19411 .38364 m
.19433 .38365 L
s
.19389 .38363 m
.19411 .38364 L
s
.19368 .38362 m
.19389 .38363 L
s
.44402 1.09351 m
.44404 1.09304 L
s
.19346 .3836 m
.19368 .38362 L
s
.19324 .38359 m
.19346 .3836 L
s
.27702 .36015 m
.27729 .35945 L
s
.19302 .38358 m
.19324 .38359 L
s
.19281 .38357 m
.19302 .38358 L
s
.19259 .38356 m
.19281 .38357 L
s
.444 1.09398 m
.44402 1.09351 L
s
.19237 .38355 m
.19259 .38356 L
s
.19237 .38355 m
.19237 .38355 L
s
.1921 .38354 m
.19237 .38355 L
s
.19182 .38353 m
.1921 .38354 L
s
.27729 .35945 m
.27757 .35876 L
s
.19154 .38352 m
.19182 .38353 L
s
.19126 .38351 m
.19154 .38352 L
s
.44397 1.09443 m
.444 1.09398 L
s
.16767 .38587 m
.19134 .38351 L
s
.19098 .3835 m
.19126 .38351 L
s
.42108 1.10198 m
.41467 1.10643 L
s
.1907 .3835 m
.19098 .3835 L
s
.27757 .35876 m
.27785 .35808 L
s
.19043 .38349 m
.1907 .3835 L
s
.19015 .38348 m
.19043 .38349 L
s
.44395 1.09487 m
.44397 1.09443 L
s
.18987 .38348 m
.19015 .38348 L
s
.18959 .38348 m
.18987 .38348 L
s
.18931 .38347 m
.18959 .38348 L
s
.27785 .35808 m
.27814 .3574 L
s
.18904 .38347 m
.18931 .38347 L
s
.44392 1.09529 m
.44395 1.09487 L
s
.18904 .38347 m
.18904 .38347 L
s
.18867 .38347 m
.18904 .38347 L
s
.1883 .38347 m
.18867 .38347 L
s
.18793 .38347 m
.1883 .38347 L
s
.27814 .3574 m
.27842 .35673 L
s
.44389 1.09571 m
.44392 1.09529 L
s
.18756 .38347 m
.18793 .38347 L
s
.18719 .38347 m
.18756 .38347 L
s
.18682 .38348 m
.18719 .38347 L
s
.27842 .35673 m
.27871 .35607 L
s
.44385 1.09612 m
.44389 1.09571 L
s
.18645 .38349 m
.18682 .38348 L
s
.18608 .38349 m
.18645 .38349 L
s
.18571 .3835 m
.18608 .38349 L
s
.27871 .35607 m
.27913 .35538 L
s
.27871 .35607 m
.27871 .35607 L
s
.44382 1.09652 m
.44385 1.09612 L
s
.18534 .38351 m
.18571 .3835 L
s
.18497 .38353 m
.18534 .38351 L
s
.18461 .38354 m
.18497 .38353 L
s
.18461 .38354 m
.18461 .38354 L
s
.18409 .38356 m
.18461 .38354 L
s
.44378 1.09691 m
.44382 1.09652 L
s
.27913 .35538 m
.27956 .35468 L
s
.18358 .38359 m
.18409 .38356 L
s
.29959 .74482 m
.2964 .79753 L
s
.29959 .74482 m
.26515 .71266 L
s
.18306 .38362 m
.18358 .38359 L
s
.44374 1.09729 m
.44378 1.09691 L
s
.41467 1.10643 m
.40803 1.11025 L
s
.27956 .35468 m
.27998 .354 L
s
.18255 .38365 m
.18306 .38362 L
s
.28495 .34711 m
.27965 .35437 L
s
.18203 .38368 m
.18255 .38365 L
s
.44369 1.09766 m
.44374 1.09729 L
s
.18152 .38372 m
.18203 .38368 L
s
.27998 .354 m
.28041 .35333 L
s
.181 .38376 m
.18152 .38372 L
s
.44369 1.09766 m
.44369 1.09766 L
s
.44378 1.09798 m
.44369 1.09766 L
s
.18049 .3838 m
.181 .38376 L
s
.28041 .35333 m
.28085 .35266 L
s
.17998 .38384 m
.18049 .3838 L
s
.44372 1.098 m
.44494 1.10124 L
s
.44387 1.09829 m
.44378 1.09798 L
s
.17947 .38389 m
.17998 .38384 L
s
.17895 .38394 m
.17947 .38389 L
s
.28085 .35266 m
.28128 .35201 L
s
.17844 .384 m
.17895 .38394 L
s
.44396 1.0986 m
.44387 1.09829 L
s
.17844 .384 m
.17844 .384 L
s
.17385 .38462 m
.17844 .384 L
s
.28128 .35201 m
.28172 .35136 L
s
.44405 1.09889 m
.44396 1.0986 L
s
.28172 .35136 m
.28216 .35072 L
s
.40893 1.10978 m
.38675 1.11792 L
s
.44413 1.09917 m
.44405 1.09889 L
s
.28216 .35072 m
.28261 .35009 L
s
.40803 1.11025 m
.40117 1.11344 L
s
.44421 1.09944 m
.44413 1.09917 L
s
.28261 .35009 m
.28306 .34947 L
s
.44429 1.09971 m
.44421 1.09944 L
s
.16928 .3855 m
.17385 .38462 L
s
.28306 .34947 m
.28351 .34886 L
s
.44436 1.09996 m
.44429 1.09971 L
s
.44443 1.1002 m
.44436 1.09996 L
s
.28351 .34886 m
.28396 .34825 L
s
.4445 1.10043 m
.44443 1.1002 L
s
.28396 .34825 m
.28455 .34761 L
s
.28396 .34825 m
.28396 .34825 L
s
.44457 1.10065 m
.4445 1.10043 L
s
.28455 .34761 m
.28515 .34697 L
s
.16474 .38663 m
.16928 .3855 L
s
.44464 1.10087 m
.44457 1.10065 L
s
.29184 .34065 m
.28495 .34711 L
s
.40117 1.11344 m
.39407 1.116 L
s
.28515 .34697 m
.28574 .34634 L
s
.14554 .39461 m
.16767 .38587 L
s
.44464 1.10087 m
.44464 1.10087 L
s
.44484 1.10103 m
.44464 1.10087 L
s
.28574 .34634 m
.28634 .34572 L
s
.44503 1.10119 m
.44484 1.10103 L
s
.28634 .34572 m
.28695 .34511 L
s
.44523 1.10133 m
.44503 1.10119 L
s
.44494 1.10124 m
.44758 1.10222 L
s
.2964 .79753 m
.29312 .85168 L
s
.16023 .38802 m
.16474 .38663 L
s
.28695 .34511 m
.28756 .34451 L
s
.44542 1.10147 m
.44523 1.10133 L
s
.28756 .34451 m
.28817 .34392 L
s
.44561 1.1016 m
.44542 1.10147 L
s
.28817 .34392 m
.28878 .34334 L
s
.4458 1.10171 m
.44561 1.1016 L
s
.26515 .71266 m
.22957 .67943 L
s
.39407 1.116 m
.38675 1.11792 L
s
.44599 1.10182 m
.4458 1.10171 L
s
.28878 .34334 m
.2894 .34277 L
s
.15575 .38968 m
.16023 .38802 L
s
.44617 1.10191 m
.44599 1.10182 L
s
.2894 .34277 m
.29002 .3422 L
s
.44635 1.102 m
.44617 1.10191 L
s
.29002 .3422 m
.29065 .34165 L
s
.44653 1.10207 m
.44635 1.102 L
s
.29065 .34165 m
.29128 .3411 L
s
.44671 1.10213 m
.44653 1.10207 L
s
.1513 .39162 m
.15575 .38968 L
s
.29128 .3411 m
.29205 .34051 L
s
.29128 .3411 m
.29128 .3411 L
s
.44689 1.10219 m
.44671 1.10213 L
s
.30028 .33495 m
.29184 .34065 L
s
.29205 .34051 m
.29282 .33993 L
s
.44689 1.10219 m
.44689 1.10219 L
s
.4472 1.1022 m
.44689 1.10219 L
s
.38675 1.11792 m
.38509 1.11826 L
s
.38675 1.11792 m
.38675 1.11792 L
s
.38675 1.11792 m
.36228 1.1197 L
s
.29282 .33993 m
.2936 .33936 L
s
.4475 1.1022 m
.4472 1.1022 L
s
.38509 1.11826 m
.38342 1.11857 L
s
.2936 .33936 m
.29438 .3388 L
s
.44781 1.10218 m
.4475 1.1022 L
s
.14689 .39386 m
.1513 .39162 L
s
.44758 1.10222 m
.4515 1.10118 L
s
.38342 1.11857 m
.38173 1.11884 L
s
.44811 1.10216 m
.44781 1.10218 L
s
.29438 .3388 m
.29517 .33825 L
s
.44841 1.10213 m
.44811 1.10216 L
s
.38173 1.11884 m
.38004 1.11908 L
s
.29517 .33825 m
.29596 .33771 L
s
.44871 1.10209 m
.44841 1.10213 L
s
.29596 .33771 m
.29676 .33717 L
s
.38004 1.11908 m
.37834 1.1193 L
s
.44901 1.10203 m
.44871 1.10209 L
s
.14251 .3964 m
.14689 .39386 L
s
.29676 .33717 m
.29756 .33665 L
s
.29312 .85168 m
.28975 .90734 L
s
.37834 1.1193 m
.37662 1.11947 L
s
.4493 1.10197 m
.44901 1.10203 L
s
.12542 .40991 m
.14554 .39461 L
s
.29756 .33665 m
.29836 .33614 L
s
.44959 1.10189 m
.4493 1.10197 L
s
.37662 1.11947 m
.37489 1.11962 L
s
.29836 .33614 m
.29917 .33563 L
s
.44988 1.10181 m
.44959 1.10189 L
s
.37489 1.11962 m
.37315 1.11973 L
s
.29917 .33563 m
.29998 .33514 L
s
.45017 1.10171 m
.44988 1.10181 L
s
.13817 .39926 m
.14251 .3964 L
s
.29998 .33514 m
.30079 .33466 L
s
.45046 1.1016 m
.45017 1.10171 L
s
.37315 1.11973 m
.37139 1.11981 L
s
.31024 .33 m
.30028 .33495 L
s
.45046 1.1016 m
.45046 1.1016 L
s
.45088 1.10145 m
.45046 1.1016 L
s
.30079 .33466 m
.30176 .33413 L
s
.30079 .33466 m
.30079 .33466 L
s
.37139 1.11981 m
.36963 1.11986 L
s
.4513 1.10129 m
.45088 1.10145 L
s
.22957 .67943 m
.19279 .64509 L
s
.30176 .33413 m
.30273 .33361 L
s
.36963 1.11986 m
.36785 1.11987 L
s
.45172 1.10112 m
.4513 1.10129 L
s
.13387 .40246 m
.13817 .39926 L
s
.30273 .33361 m
.3037 .3331 L
s
.4515 1.10118 m
.45661 1.09828 L
s
.45213 1.10093 m
.45172 1.10112 L
s
.36785 1.11987 m
.36607 1.11985 L
s
.3037 .3331 m
.30468 .3326 L
s
.45255 1.10074 m
.45213 1.10093 L
s
.36607 1.11985 m
.36584 1.11985 L
s
.36607 1.11985 m
.36607 1.11985 L
s
.36584 1.11985 m
.36562 1.11984 L
s
.30468 .3326 m
.30567 .33211 L
s
.36562 1.11984 m
.36539 1.11984 L
s
.36539 1.11984 m
.36517 1.11983 L
s
.45296 1.10053 m
.45255 1.10074 L
s
.36517 1.11983 m
.36494 1.11982 L
s
.36494 1.11982 m
.36472 1.11981 L
s
.36472 1.11981 m
.36449 1.11981 L
s
.36449 1.11981 m
.36427 1.1198 L
s
.36427 1.1198 m
.36404 1.11979 L
s
.30567 .33211 m
.30666 .33163 L
s
.36404 1.11979 m
.36381 1.11978 L
s
.45337 1.10032 m
.45296 1.10053 L
s
.36381 1.11978 m
.36359 1.11977 L
s
.36359 1.11977 m
.36336 1.11976 L
s
.12962 .406 m
.13387 .40246 L
s
.36336 1.11976 m
.36307 1.11974 L
s
.36336 1.11976 m
.36336 1.11976 L
s
.36307 1.11974 m
.36278 1.11973 L
s
.36278 1.11973 m
.36249 1.11971 L
s
.30666 .33163 m
.30765 .33116 L
s
.45377 1.10009 m
.45337 1.10032 L
s
.36249 1.11971 m
.36219 1.11969 L
s
.36228 1.1197 m
.33587 1.11477 L
s
.36219 1.11969 m
.3619 1.11968 L
s
.3619 1.11968 m
.36161 1.11966 L
s
.36161 1.11966 m
.36131 1.11964 L
s
.36131 1.11964 m
.36102 1.11962 L
s
.45418 1.09985 m
.45377 1.10009 L
s
.36102 1.11962 m
.36073 1.11959 L
s
.30765 .33116 m
.30865 .33071 L
s
.36073 1.11959 m
.36043 1.11957 L
s
.36043 1.11957 m
.36014 1.11955 L
s
.36014 1.11955 m
.35984 1.11952 L
s
.35984 1.11952 m
.35945 1.11949 L
s
.35984 1.11952 m
.35984 1.11952 L
s
.45459 1.0996 m
.45418 1.09985 L
s
.35945 1.11949 m
.35905 1.11945 L
s
.30865 .33071 m
.30965 .33026 L
s
.35905 1.11945 m
.35866 1.11942 L
s
.35866 1.11942 m
.35826 1.11938 L
s
.45499 1.09934 m
.45459 1.0996 L
s
.35826 1.11938 m
.35787 1.11934 L
s
.12542 .40991 m
.12962 .406 L
s
.35787 1.11934 m
.35747 1.11929 L
s
.30965 .33026 m
.31066 .32982 L
s
.28975 .90734 m
.28628 .96456 L
s
.35747 1.11929 m
.35707 1.11925 L
s
.35707 1.11925 m
.35668 1.11921 L
s
.45539 1.09907 m
.45499 1.09934 L
s
.35668 1.11921 m
.35628 1.11916 L
s
.32172 .32577 m
.31024 .33 L
s
.35628 1.11916 m
.35588 1.11911 L
s
.31066 .32982 m
.31167 .3294 L
s
.35588 1.11911 m
.35548 1.11906 L
s
.45539 1.09907 m
.45539 1.09907 L
s
.45593 1.09875 m
.45539 1.09907 L
s
.35548 1.11906 m
.35508 1.11901 L
s
.35508 1.11901 m
.35452 1.11893 L
s
.35508 1.11901 m
.35508 1.11901 L
s
.31167 .3294 m
.31269 .32898 L
s
.35452 1.11893 m
.35396 1.11886 L
s
.45646 1.09842 m
.45593 1.09875 L
s
.35396 1.11886 m
.35339 1.11877 L
s
.35339 1.11877 m
.35283 1.11869 L
s
.31269 .32898 m
.31387 .32852 L
s
.31269 .32898 m
.31269 .32898 L
s
.35283 1.11869 m
.35227 1.1186 L
s
.457 1.09808 m
.45646 1.09842 L
s
.12542 .40991 m
.14471 .40248 L
s
.12542 .40991 m
.12542 .40991 L
s
.12134 .41414 m
.12542 .40991 L
s
.10781 .43179 m
.12542 .40991 L
s
.35227 1.1186 m
.3517 1.11851 L
s
.45661 1.09828 m
.46283 1.09362 L
s
.3517 1.11851 m
.35113 1.11842 L
s
.45753 1.09773 m
.457 1.09808 L
s
.31387 .32852 m
.31506 .32806 L
s
.35113 1.11842 m
.35056 1.11832 L
s
.35056 1.11832 m
.34999 1.11822 L
s
.34999 1.11822 m
.34942 1.11811 L
s
.45806 1.09737 m
.45753 1.09773 L
s
.31506 .32806 m
.31625 .32762 L
s
.34942 1.11811 m
.34885 1.11801 L
s
.34885 1.11801 m
.34828 1.1179 L
s
.34828 1.1179 m
.34307 1.11675 L
s
.45859 1.09699 m
.45806 1.09737 L
s
.31625 .32762 m
.31744 .32719 L
s
.14471 .40248 m
.16412 .395 L
s
.45912 1.09661 m
.45859 1.09699 L
s
.11744 .41861 m
.12134 .41414 L
s
.31744 .32719 m
.31864 .32677 L
s
.45964 1.09621 m
.45912 1.09661 L
s
.31864 .32677 m
.31985 .32636 L
s
.19279 .64509 m
.15475 .60957 L
s
.46017 1.0958 m
.45964 1.09621 L
s
.34307 1.11675 m
.33776 1.11533 L
s
.31985 .32636 m
.32106 .32596 L
s
.46069 1.09538 m
.46017 1.0958 L
s
.16412 .395 m
.18366 .38747 L
s
.11372 .42331 m
.11744 .41861 L
s
.32106 .32596 m
.32228 .32558 L
s
.46121 1.09495 m
.46069 1.09538 L
s
.33472 .32226 m
.32172 .32577 L
s
.46173 1.0945 m
.46121 1.09495 L
s
.32228 .32558 m
.3235 .3252 L
s
.33776 1.11533 m
.33236 1.11364 L
s
.46173 1.0945 m
.46173 1.0945 L
s
.46239 1.09401 m
.46173 1.0945 L
s
.3235 .3252 m
.32473 .32484 L
s
.46305 1.09351 m
.46239 1.09401 L
s
.18366 .38747 m
.20332 .37989 L
s
.33587 1.11477 m
.30795 1.10289 L
s
.32473 .32484 m
.32597 .32449 L
s
.11017 .42824 m
.11372 .42331 L
s
.46283 1.09362 m
.47013 1.08728 L
s
.46371 1.09299 m
.46305 1.09351 L
s
.28628 .96456 m
.28272 1.02343 L
s
.32597 .32449 m
.32721 .32415 L
s
.46436 1.09246 m
.46371 1.09299 L
s
.33236 1.11364 m
.32686 1.11165 L
s
.32721 .32415 m
.32862 .32376 L
s
.32721 .32415 m
.32721 .32415 L
s
.46502 1.09192 m
.46436 1.09246 L
s
.20332 .37989 m
.22311 .37227 L
s
.32862 .32376 m
.33005 .32337 L
s
.46567 1.09137 m
.46502 1.09192 L
s
.10679 .4334 m
.11017 .42824 L
s
.46632 1.09081 m
.46567 1.09137 L
s
.33005 .32337 m
.33148 .32301 L
s
.32686 1.11165 m
.32127 1.10936 L
s
.46697 1.09023 m
.46632 1.09081 L
s
.33148 .32301 m
.33291 .32265 L
s
.09319 .46013 m
.10781 .43179 L
s
.46762 1.08964 m
.46697 1.09023 L
s
.22311 .37227 m
.24304 .36459 L
s
.33291 .32265 m
.33435 .32231 L
s
.10357 .43877 m
.10679 .4334 L
s
.46827 1.08904 m
.46762 1.08964 L
s
.33435 .32231 m
.3358 .32197 L
s
.46891 1.08843 m
.46827 1.08904 L
s
.32127 1.10936 m
.31557 1.10677 L
s
.34925 .31949 m
.33472 .32226 L
s
.3358 .32197 m
.33726 .32166 L
s
.46955 1.08781 m
.46891 1.08843 L
s
.24304 .36459 m
.26309 .35686 L
s
.46955 1.08781 m
.46955 1.08781 L
s
.47035 1.08713 m
.46955 1.08781 L
s
.10052 .44436 m
.10357 .43877 L
s
.33726 .32166 m
.33872 .32135 L
s
.47013 1.08728 m
.47847 1.07933 L
s
.47114 1.08644 m
.47035 1.08713 L
s
.33872 .32135 m
.34019 .32106 L
s
.31557 1.10677 m
.30976 1.10386 L
s
.47192 1.08574 m
.47114 1.08644 L
s
.34019 .32106 m
.34166 .32078 L
s
.15475 .60957 m
.11539 .57281 L
s
.47271 1.08502 m
.47192 1.08574 L
s
.26309 .35686 m
.28327 .34908 L
s
.09762 .45015 m
.10052 .44436 L
s
.34166 .32078 m
.34314 .32051 L
s
.4735 1.0843 m
.47271 1.08502 L
s
.30976 1.10386 m
.30385 1.10061 L
s
.34314 .32051 m
.34463 .32026 L
s
.47428 1.08356 m
.4735 1.0843 L
s
.28272 1.02343 m
.27905 1.08401 L
s
.30795 1.10289 m
.27905 1.08401 L
s
.34463 .32026 m
.34632 .31995 L
s
.34463 .32026 m
.34463 .32026 L
s
.47506 1.0828 m
.47428 1.08356 L
s
.09488 .45614 m
.09762 .45015 L
s
.28327 .34908 m
.30359 .34126 L
s
.47585 1.08203 m
.47506 1.0828 L
s
.34632 .31995 m
.34801 .31965 L
s
.30385 1.10061 m
.29782 1.09702 L
s
.47663 1.08125 m
.47585 1.08203 L
s
.34801 .31965 m
.34971 .31936 L
s
.47741 1.08046 m
.47663 1.08125 L
s
.36536 .31745 m
.34925 .31949 L
s
.34971 .31936 m
.35142 .31909 L
s
.09229 .46234 m
.09488 .45614 L
s
.47818 1.07965 m
.47741 1.08046 L
s
.30359 .34126 m
.32404 .33337 L
s
.35142 .31909 m
.35313 .31884 L
s
.47896 1.07883 m
.47818 1.07965 L
s
.29782 1.09702 m
.29168 1.09307 L
s
.47847 1.07933 m
.48782 1.06978 L
s
.082 .49461 m
.09319 .46013 L
s
.35313 .31884 m
.35486 .3186 L
s
.47896 1.07883 m
.47896 1.07883 L
s
.47989 1.07796 m
.47896 1.07883 L
s
.08985 .46873 m
.09229 .46234 L
s
.48082 1.07707 m
.47989 1.07796 L
s
.35486 .3186 m
.35659 .31837 L
s
.36536 .31745 m
.79001 .58781 L
s
.79001 .58781 m
.53542 1.0158 L
s
.53542 1.0158 m
.79001 .58781 L
s
.79001 .58781 m
.36536 .31745 L
s
.32404 .33337 m
.34463 .32544 L
s
.48175 1.07617 m
.48082 1.07707 L
s
.29168 1.09307 m
.28543 1.08874 L
s
.35659 .31837 m
.35833 .31815 L
s
.48268 1.07525 m
.48175 1.07617 L
s
.08757 .47531 m
.08985 .46873 L
s
.35833 .31815 m
.36007 .31796 L
s
.48361 1.07432 m
.48268 1.07525 L
s
.36007 .31796 m
.36183 .31777 L
s
.36536 .31746 m
.34463 .32544 L
s
.48454 1.07338 m
.48361 1.07432 L
s
.28543 1.08874 m
.27905 1.08401 L
s
.36183 .31777 m
.36359 .31761 L
s
.48546 1.07242 m
.48454 1.07338 L
s
.08732 .47606 m
.08757 .47531 L
s
.08708 .4768 m
.08732 .47606 L
s
.08684 .47755 m
.08708 .4768 L
s
.48639 1.07145 m
.48546 1.07242 L
s
.36359 .31761 m
.36536 .31746 L
s
.0866 .4783 m
.08684 .47755 L
s
.08636 .47905 m
.0866 .4783 L
s
.08613 .47981 m
.08636 .47905 L
s
.48731 1.07046 m
.48639 1.07145 L
s
.08589 .48057 m
.08613 .47981 L
s
.33601 .33428 m
.36536 .31745 L
s
.36536 .31746 m
.36215 .31924 L
s
.36536 .31746 m
.36536 .31746 L
s
.08566 .48133 m
.08589 .48057 L
s
.27905 1.08401 m
.29963 1.07853 L
s
.27905 1.08401 m
.27905 1.08401 L
s
.27905 1.08401 m
.27265 1.07895 L
s
.11539 .57281 m
.07463 .53475 L
s
.27905 1.08401 m
.27905 1.08401 L
s
.27905 1.08401 m
.24973 1.0582 L
s
.36215 .31924 m
.35894 .32104 L
s
.08543 .48209 m
.08566 .48133 L
s
.0852 .48285 m
.08543 .48209 L
s
.48823 1.06946 m
.48731 1.07046 L
s
.35894 .32104 m
.35574 .32285 L
s
.08498 .48362 m
.0852 .48285 L
s
.35574 .32285 m
.35255 .32466 L
s
.08475 .48439 m
.08498 .48362 L
s
.48782 1.06978 m
.4982 1.05866 L
s
.35255 .32466 m
.34936 .3265 L
s
.08475 .48439 m
.08475 .48439 L
s
.08459 .48494 m
.08475 .48439 L
s
.48915 1.06844 m
.48823 1.06946 L
s
.08443 .48549 m
.08459 .48494 L
s
.34936 .3265 m
.34618 .32834 L
s
.08428 .48605 m
.08443 .48549 L
s
.34618 .32834 m
.343 .33019 L
s
.08412 .4866 m
.08428 .48605 L
s
.08396 .48716 m
.08412 .4866 L
s
.343 .33019 m
.33984 .33206 L
s
.08381 .48771 m
.08396 .48716 L
s
.49007 1.06741 m
.48915 1.06844 L
s
.08366 .48827 m
.08381 .48771 L
s
.33984 .33206 m
.33667 .33393 L
s
.0835 .48883 m
.08366 .48827 L
s
.27265 1.07895 m
.26633 1.07364 L
s
.33667 .33393 m
.33352 .33582 L
s
.30774 .35202 m
.33601 .33428 L
s
.08335 .48939 m
.0835 .48883 L
s
.0832 .48995 m
.08335 .48939 L
s
.29963 1.07853 m
.32034 1.07302 L
s
.33352 .33582 m
.33037 .33771 L
s
.08305 .49052 m
.0832 .48995 L
s
.49007 1.06741 m
.49007 1.06741 L
s
.49116 1.06632 m
.49007 1.06741 L
s
.33037 .33771 m
.32723 .33962 L
s
.0829 .49108 m
.08305 .49052 L
s
.0829 .49108 m
.0829 .49108 L
s
.08279 .49151 m
.0829 .49108 L
s
.32723 .33962 m
.32428 .34147 L
s
.32723 .33962 m
.32723 .33962 L
s
.08268 .49193 m
.08279 .49151 L
s
.08257 .49235 m
.08268 .49193 L
s
.32428 .34147 m
.32135 .34332 L
s
.08246 .49278 m
.08257 .49235 L
s
.08235 .49321 m
.08246 .49278 L
s
.49224 1.06522 m
.49116 1.06632 L
s
.08224 .49363 m
.08235 .49321 L
s
.32135 .34332 m
.31841 .34518 L
s
.08213 .49406 m
.08224 .49363 L
s
.08203 .49449 m
.08213 .49406 L
s
.31841 .34518 m
.31549 .34706 L
s
.08192 .49492 m
.08203 .49449 L
s
.07463 .53475 m
.082 .49461 L
s
.08181 .49535 m
.08192 .49492 L
s
.31549 .34706 m
.31257 .34895 L
s
.08171 .49578 m
.08181 .49535 L
s
.49333 1.0641 m
.49224 1.06522 L
s
.0816 .49621 m
.08171 .49578 L
s
.31257 .34895 m
.30966 .35084 L
s
.0816 .49621 m
.0816 .49621 L
s
.08152 .49655 m
.0816 .49621 L
s
.26633 1.07364 m
.2601 1.0681 L
s
.08144 .49688 m
.08152 .49655 L
s
.08136 .49722 m
.08144 .49688 L
s
.30966 .35084 m
.30675 .35275 L
s
.08128 .49756 m
.08136 .49722 L
s
.0812 .49789 m
.08128 .49756 L
s
.28059 .37069 m
.30774 .35202 L
s
.08112 .49823 m
.0812 .49789 L
s
.30675 .35275 m
.30385 .35466 L
s
.08104 .49857 m
.08112 .49823 L
s
.49441 1.06296 m
.49333 1.0641 L
s
.08096 .49891 m
.08104 .49857 L
s
.08088 .49925 m
.08096 .49891 L
s
.32034 1.07302 m
.3412 1.06747 L
s
.30385 .35466 m
.30095 .35659 L
s
.0808 .49959 m
.08088 .49925 L
s
.08072 .49993 m
.0808 .49959 L
s
.08064 .50027 m
.08072 .49993 L
s
.30095 .35659 m
.29806 .35852 L
s
.08064 .50027 m
.08064 .50027 L
s
.08003 .503 m
.08064 .50027 L
s
.29806 .35852 m
.29518 .36047 L
s
.49549 1.06181 m
.49441 1.06296 L
s
.29518 .36047 m
.2923 .36242 L
s
.2923 .36242 m
.28961 .36432 L
s
.2923 .36242 m
.2923 .36242 L
s
.07944 .50576 m
.08003 .503 L
s
.28961 .36432 m
.28692 .36623 L
s
.49657 1.06064 m
.49549 1.06181 L
s
.2601 1.0681 m
.25394 1.06233 L
s
.28692 .36623 m
.28423 .36814 L
s
.07886 .50855 m
.07944 .50576 L
s
.28423 .36814 m
.28155 .37007 L
s
.28155 .37007 m
.27888 .37201 L
s
.25458 .39031 m
.28059 .37069 L
s
.49765 1.05946 m
.49657 1.06064 L
s
.27888 .37201 m
.27621 .37395 L
s
.07831 .51136 m
.07886 .50855 L
s
.27621 .37395 m
.27355 .3759 L
s
.3412 1.06747 m
.36219 1.06188 L
s
.27355 .3759 m
.2709 .37787 L
s
.2709 .37787 m
.26825 .37984 L
s
.49873 1.05826 m
.49765 1.05946 L
s
.07778 .5142 m
.07831 .51136 L
s
.26825 .37984 m
.2656 .38182 L
s
.2656 .38182 m
.26296 .38381 L
s
.25394 1.06233 m
.24787 1.05634 L
s
.4982 1.05866 m
.50958 1.04596 L
s
.26296 .38381 m
.26033 .38581 L
s
.49981 1.05705 m
.49873 1.05826 L
s
.07727 .51706 m
.07778 .5142 L
s
.26033 .38581 m
.25787 .38776 L
s
.26033 .38581 m
.26033 .38581 L
s
.25787 .38776 m
.25541 .38972 L
s
.25541 .38972 m
.25296 .39168 L
s
.22979 .41093 m
.25458 .39031 L
s
.07678 .51994 m
.07727 .51706 L
s
.50089 1.05582 m
.49981 1.05705 L
s
.25296 .39168 m
.25051 .39365 L
s
.24973 1.0582 m
.22064 1.02579 L
s
.25051 .39365 m
.24807 .39564 L
s
.24807 .39564 m
.24563 .39763 L
s
.07631 .52286 m
.07678 .51994 L
s
.36219 1.06188 m
.38333 1.05626 L
s
.50197 1.05457 m
.50089 1.05582 L
s
.24563 .39763 m
.2432 .39963 L
s
.24787 1.05634 m
.24187 1.05014 L
s
.2432 .39963 m
.24078 .40164 L
s
.24078 .40164 m
.23836 .40365 L
s
.07585 .52579 m
.07631 .52286 L
s
.23836 .40365 m
.23595 .40568 L
s
.50304 1.05331 m
.50197 1.05457 L
s
.23595 .40568 m
.23354 .40771 L
s
.07543 .52875 m
.07585 .52579 L
s
.23354 .40771 m
.23114 .40976 L
s
.23114 .40976 m
.2289 .41175 L
s
.23114 .40976 m
.23114 .40976 L
s
.20628 .43259 m
.22979 .41093 L
s
.50304 1.05331 m
.50304 1.05331 L
s
.5043 1.05198 m
.50304 1.05331 L
s
.2289 .41175 m
.22666 .41375 L
s
.07502 .53174 m
.07543 .52875 L
s
.22666 .41375 m
.22443 .41576 L
s
.24187 1.05014 m
.23595 1.04373 L
s
.22443 .41576 m
.2222 .41778 L
s
.2222 .41778 m
.21998 .41981 L
s
.50555 1.05064 m
.5043 1.05198 L
s
.07463 .53475 m
.07502 .53174 L
s
.38333 1.05626 m
.40462 1.0506 L
s
.21998 .41981 m
.21777 .42184 L
s
.21777 .42184 m
.21556 .42389 L
s
.21556 .42389 m
.21335 .42594 L
s
.07463 .53475 m
.07463 .53475 L
s
.07314 .54861 m
.07463 .53475 L
s
.07463 .53475 m
.07463 .53475 L
s
.07139 .57985 m
.07463 .53475 L
s
.50681 1.04928 m
.50555 1.05064 L
s
.21335 .42594 m
.21116 .428 L
s
.21116 .428 m
.20896 .43007 L
s
.20896 .43007 m
.20678 .43215 L
s
.23595 1.04373 m
.2301 1.03711 L
s
.20678 .43215 m
.20459 .43423 L
s
.18414 .45534 m
.20628 .43259 L
s
.50807 1.0479 m
.50681 1.04928 L
s
.20459 .43423 m
.20257 .43627 L
s
.20459 .43423 m
.20459 .43423 L
s
.20257 .43627 m
.20054 .43831 L
s
.20054 .43831 m
.19853 .44037 L
s
.50932 1.0465 m
.50807 1.0479 L
s
.19853 .44037 m
.19651 .44243 L
s
.19651 .44243 m
.19451 .4445 L
s
.40462 1.0506 m
.42605 1.0449 L
s
.19451 .4445 m
.19251 .44658 L
s
.19251 .44658 m
.19051 .44866 L
s
.51057 1.04509 m
.50932 1.0465 L
s
.2301 1.03711 m
.22433 1.0303 L
s
.19051 .44866 m
.18852 .45076 L
s
.50958 1.04596 m
.52198 1.03168 L
s
.18852 .45076 m
.18654 .45286 L
s
.07207 .56297 m
.07314 .54861 L
s
.18654 .45286 m
.18456 .45497 L
s
.18456 .45497 m
.18259 .45709 L
s
.16349 .47927 m
.18414 .45534 L
s
.51183 1.04366 m
.51057 1.04509 L
s
.18259 .45709 m
.18062 .45921 L
s
.18062 .45921 m
.1788 .46129 L
s
.18062 .45921 m
.18062 .45921 L
s
.1788 .46129 m
.17699 .46338 L
s
.17699 .46338 m
.17518 .46547 L
s
.51308 1.04221 m
.51183 1.04366 L
s
.22433 1.0303 m
.21864 1.0233 L
s
.17518 .46547 m
.17338 .46758 L
s
.17338 .46758 m
.17158 .46969 L
s
.17158 .46969 m
.16979 .47181 L
s
.42605 1.0449 m
.44762 1.03916 L
s
.51433 1.04074 m
.51308 1.04221 L
s
.16979 .47181 m
.16801 .47393 L
s
.16801 .47393 m
.16623 .47607 L
s
.22064 1.02579 m
.19245 .98729 L
s
.16623 .47607 m
.16446 .47821 L
s
.07144 .57784 m
.07207 .56297 L
s
.16446 .47821 m
.16269 .48036 L
s
.14448 .50445 m
.16349 .47927 L
s
.51558 1.03926 m
.51433 1.04074 L
s
.16269 .48036 m
.16093 .48252 L
s
.21864 1.0233 m
.21301 1.01611 L
s
.16093 .48252 m
.15917 .48468 L
s
.15917 .48468 m
.15756 .4868 L
s
.15917 .48468 m
.15917 .48468 L
s
.15756 .4868 m
.15595 .48893 L
s
.51682 1.03775 m
.51558 1.03926 L
s
.15595 .48893 m
.15436 .49107 L
s
.15436 .49107 m
.15276 .49321 L
s
.15276 .49321 m
.15118 .49536 L
s
.15118 .49536 m
.14959 .49752 L
s
.51807 1.03623 m
.51682 1.03775 L
s
.44762 1.03916 m
.46935 1.03338 L
s
.14959 .49752 m
.14802 .49969 L
s
.21301 1.01611 m
.20747 1.00873 L
s
.14802 .49969 m
.14645 .50186 L
s
.14645 .50186 m
.14488 .50405 L
s
.14488 .50405 m
.14333 .50623 L
s
.12731 .53102 m
.14448 .50445 L
s
.07126 .59321 m
.07144 .57784 L
s
.51807 1.03623 m
.51807 1.03623 L
s
.51952 1.03464 m
.51807 1.03623 L
s
.14333 .50623 m
.14177 .50843 L
s
.0725 .62902 m
.07139 .57985 L
s
.14177 .50843 m
.14023 .51064 L
s
.14023 .51064 m
.13883 .5128 L
s
.14023 .51064 m
.14023 .51064 L
s
.13883 .5128 m
.13743 .51496 L
s
.20747 1.00873 m
.20685 1.0079 L
s
.20747 1.00873 m
.20747 1.00873 L
s
.13743 .51496 m
.13604 .51714 L
s
.52097 1.03302 m
.51952 1.03464 L
s
.20685 1.0079 m
.20624 1.00707 L
s
.13604 .51714 m
.13466 .51932 L
s
.20624 1.00707 m
.20563 1.00623 L
s
.13466 .51932 m
.13328 .52151 L
s
.20563 1.00623 m
.20503 1.00539 L
s
.13328 .52151 m
.13191 .52371 L
s
.20503 1.00539 m
.20442 1.00455 L
s
.20442 1.00455 m
.20381 1.00371 L
s
.13191 .52371 m
.13055 .52592 L
s
.52242 1.03139 m
.52097 1.03302 L
s
.20381 1.00371 m
.2032 1.00287 L
s
.13055 .52592 m
.12919 .52813 L
s
.2032 1.00287 m
.2026 1.00202 L
s
.46935 1.03338 m
.49122 1.02756 L
s
.12919 .52813 m
.12783 .53035 L
s
.2026 1.00202 m
.20199 1.00117 L
s
.12783 .53035 m
.12649 .53258 L
s
.11223 .55914 m
.12731 .53102 L
s
.20199 1.00117 m
.20139 1.00032 L
s
.07153 .60909 m
.07126 .59321 L
s
.52198 1.03168 m
.53542 1.0158 L
s
.12649 .53258 m
.12515 .53482 L
s
.20139 1.00032 m
.20079 .99947 L
s
.52387 1.02974 m
.52242 1.03139 L
s
.20079 .99947 m
.20019 .99861 L
s
.12515 .53482 m
.12381 .53706 L
s
.20019 .99861 m
.19976 .998 L
s
.20019 .99861 m
.20019 .99861 L
s
.12381 .53706 m
.12381 .53706 L
s
.12381 .53706 m
.12262 .53926 L
s
.19976 .998 m
.19933 .99739 L
s
.19933 .99739 m
.1989 .99677 L
s
.12262 .53926 m
.12144 .54147 L
s
.1989 .99677 m
.19847 .99616 L
s
.12144 .54147 m
.12027 .54368 L
s
.19847 .99616 m
.19805 .99554 L
s
.19805 .99554 m
.19762 .99492 L
s
.12027 .54368 m
.1191 .5459 L
s
.52532 1.02807 m
.52387 1.02974 L
s
.19762 .99492 m
.19719 .9943 L
s
.19719 .9943 m
.19677 .99368 L
s
.1191 .5459 m
.11793 .54813 L
s
.19677 .99368 m
.19634 .99306 L
s
.19634 .99306 m
.19592 .99244 L
s
.11793 .54813 m
.11678 .55037 L
s
.19592 .99244 m
.19549 .99182 L
s
.11678 .55037 m
.11563 .55261 L
s
.19549 .99182 m
.19507 .99119 L
s
.19507 .99119 m
.19475 .99072 L
s
.19507 .99119 m
.19507 .99119 L
s
.11563 .55261 m
.11448 .55486 L
s
.19475 .99072 m
.19444 .99025 L
s
.19444 .99025 m
.19412 .98978 L
s
.52676 1.02637 m
.52532 1.02807 L
s
.19412 .98978 m
.1938 .98931 L
s
.11448 .55486 m
.11334 .55712 L
s
.1938 .98931 m
.19349 .98884 L
s
.19349 .98884 m
.19317 .98837 L
s
.11334 .55712 m
.11221 .55939 L
s
.19317 .98837 m
.19285 .9879 L
s
.19285 .9879 m
.19254 .98742 L
s
.07228 .62548 m
.07153 .60909 L
s
.09959 .58902 m
.11223 .55914 L
s
.11221 .55939 m
.11109 .56167 L
s
.19254 .98742 m
.19222 .98695 L
s
.49122 1.02756 m
.51325 1.0217 L
s
.19245 .98729 m
.16585 .94342 L
s
.19222 .98695 m
.19191 .98648 L
s
.19191 .98648 m
.19159 .986 L
s
.11109 .56167 m
.10997 .56395 L
s
.19159 .986 m
.19128 .98552 L
s
.19128 .98552 m
.19103 .98515 L
s
.19128 .98552 m
.19128 .98552 L
s
.10997 .56395 m
.109 .56619 L
s
.10997 .56395 m
.10997 .56395 L
s
.19103 .98515 m
.19079 .98478 L
s
.52821 1.02466 m
.52676 1.02637 L
s
.19079 .98478 m
.19055 .98441 L
s
.19055 .98441 m
.1903 .98404 L
s
.109 .56619 m
.10803 .56843 L
s
.1903 .98404 m
.19006 .98367 L
s
.19006 .98367 m
.18981 .9833 L
s
.18981 .9833 m
.18957 .98292 L
s
.10803 .56843 m
.10708 .57068 L
s
.18957 .98292 m
.18933 .98255 L
s
.18933 .98255 m
.18908 .98218 L
s
.18908 .98218 m
.18884 .9818 L
s
.18884 .9818 m
.1886 .98143 L
s
.10708 .57068 m
.10613 .57294 L
s
.1886 .98143 m
.18836 .98105 L
s
.18836 .98105 m
.18642 .97804 L
s
.18836 .98105 m
.18836 .98105 L
s
.10613 .57294 m
.10518 .57521 L
s
.52966 1.02293 m
.52821 1.02466 L
s
.10518 .57521 m
.10425 .57749 L
s
.10425 .57749 m
.10332 .57977 L
s
.18642 .97804 m
.1845 .97501 L
s
.10332 .57977 m
.10239 .58206 L
s
.10239 .58206 m
.10148 .58436 L
s
.1845 .97501 m
.18258 .97195 L
s
.10148 .58436 m
.10057 .58667 L
s
.07351 .64239 m
.07228 .62548 L
s
.5311 1.02118 m
.52966 1.02293 L
s
.10057 .58667 m
.09966 .58898 L
s
.08987 .62096 m
.09959 .58902 L
s
.09966 .58898 m
.09877 .5913 L
s
.18258 .97195 m
.18068 .96888 L
s
.09877 .5913 m
.09803 .59358 L
s
.09877 .5913 m
.09877 .5913 L
s
.07803 .6812 m
.0725 .62902 L
s
.09803 .59358 m
.09729 .59586 L
s
.51325 1.0217 m
.53542 1.0158 L
s
.18068 .96888 m
.17879 .96577 L
s
.09729 .59586 m
.09656 .59815 L
s
.53254 1.01941 m
.5311 1.02118 L
s
.09656 .59815 m
.09584 .60045 L
s
.09584 .60045 m
.09513 .60276 L
s
.17879 .96577 m
.17691 .96265 L
s
.09513 .60276 m
.09442 .60507 L
s
.09442 .60507 m
.09372 .60739 L
s
.17691 .96265 m
.17504 .9595 L
s
.09372 .60739 m
.09303 .60972 L
s
.53398 1.01761 m
.53254 1.01941 L
s
.09303 .60972 m
.09234 .61206 L
s
.09234 .61206 m
.09166 .6144 L
s
.17504 .9595 m
.17318 .95633 L
s
.07526 .65984 m
.07351 .64239 L
s
.09166 .6144 m
.09099 .61676 L
s
.09099 .61676 m
.09033 .61912 L
s
.17318 .95633 m
.17133 .95314 L
s
.09033 .61912 m
.08982 .62143 L
s
.09033 .61912 m
.09033 .61912 L
s
.08379 .65541 m
.08987 .62096 L
s
.53542 1.0158 m
.53398 1.01761 L
s
.08982 .62143 m
.08933 .62375 L
s
.08933 .62375 m
.08884 .62608 L
s
.17133 .95314 m
.16949 .94992 L
s
.08884 .62608 m
.08836 .62842 L
s
.08836 .62842 m
.08789 .63077 L
s
.16949 .94992 m
.16767 .94668 L
s
.08789 .63077 m
.08742 .63312 L
s
.08742 .63312 m
.08696 .63548 L
s
.53542 1.0158 m
.53542 1.0158 L
s
.53153 1.01539 m
.53542 1.0158 L
s
.53542 1.0158 m
.49964 1.01175 L
s
.16767 .94668 m
.16585 .94342 L
s
.08696 .63548 m
.08651 .63785 L
s
.52763 1.01497 m
.53153 1.01539 L
s
.08651 .63785 m
.08607 .64023 L
s
.07755 .67782 m
.07526 .65984 L
s
.52373 1.01454 m
.52763 1.01497 L
s
.08607 .64023 m
.08564 .64261 L
s
.16585 .94342 m
.15783 .92847 L
s
.16585 .94342 m
.16585 .94342 L
s
.16585 .94342 m
.14152 .89512 L
s
.51984 1.0141 m
.52373 1.01454 L
s
.08564 .64261 m
.08521 .645 L
s
.51595 1.01365 m
.51984 1.0141 L
s
.08521 .645 m
.08479 .64741 L
s
.08479 .64741 m
.08454 .64976 L
s
.08479 .64741 m
.08479 .64741 L
s
.51206 1.01319 m
.51595 1.01365 L
s
.08454 .64976 m
.0843 .65212 L
s
.50818 1.01272 m
.51206 1.01319 L
s
.0843 .65212 m
.08407 .65449 L
s
.5043 1.01224 m
.50818 1.01272 L
s
.08407 .65449 m
.08385 .65686 L
s
.50042 1.01176 m
.5043 1.01224 L
s
.08247 .69307 m
.08379 .65541 L
s
.08385 .65686 m
.08363 .65925 L
s
.49964 1.01175 m
.46451 1.00636 L
s
.49654 1.01126 m
.50042 1.01176 L
s
.08363 .65925 m
.08343 .66164 L
s
.49267 1.01076 m
.49654 1.01126 L
s
.08343 .66164 m
.08323 .66404 L
s
.4888 1.01024 m
.49267 1.01076 L
s
.08323 .66404 m
.08304 .66645 L
s
.4888 1.01024 m
.4888 1.01024 L
s
.48513 1.00966 m
.4888 1.01024 L
s
.15783 .92847 m
.15004 .91308 L
s
.0804 .69637 m
.07755 .67782 L
s
.08304 .66645 m
.08286 .66887 L
s
.48147 1.00908 m
.48513 1.00966 L
s
.08286 .66887 m
.08268 .67129 L
s
.47782 1.00848 m
.48147 1.00908 L
s
.08795 .73521 m
.07803 .6812 L
s
.08268 .67129 m
.08252 .67373 L
s
.47416 1.00787 m
.47782 1.00848 L
s
.08252 .67373 m
.08236 .67617 L
s
.47051 1.00726 m
.47416 1.00787 L
s
.08236 .67617 m
.08239 .67856 L
s
.08236 .67617 m
.08236 .67617 L
s
.46686 1.00664 m
.47051 1.00726 L
s
.08239 .67856 m
.08243 .68096 L
s
.46321 1.00601 m
.46686 1.00664 L
s
.46451 1.00636 m
.43008 .99961 L
s
.08243 .68096 m
.08247 .68337 L
s
.45957 1.00537 m
.46321 1.00601 L
s
.08247 .68337 m
.08253 .68579 L
s
.45593 1.00472 m
.45957 1.00537 L
s
.08253 .68579 m
.08259 .68821 L
s
.45229 1.00406 m
.45593 1.00472 L
s
.15004 .91308 m
.1425 .89725 L
s
.08259 .68821 m
.08267 .69064 L
s
.44865 1.0034 m
.45229 1.00406 L
s
.08385 .71549 m
.0804 .69637 L
s
.08267 .69064 m
.08275 .69309 L
s
.44502 1.00273 m
.44865 1.0034 L
s
.08795 .73521 m
.08247 .69307 L
s
.08275 .69309 m
.08284 .69554 L
s
.44502 1.00273 m
.44502 1.00273 L
s
.44158 1.002 m
.44502 1.00273 L
s
.08284 .69554 m
.08294 .698 L
s
.43814 1.00126 m
.44158 1.002 L
s
.08294 .698 m
.08305 .70047 L
s
.4347 1.00051 m
.43814 1.00126 L
s
.08305 .70047 m
.08317 .70294 L
s
.43127 .99975 m
.4347 1.00051 L
s
.08317 .70294 m
.0833 .70543 L
s
.42784 .99899 m
.43127 .99975 L
s
.43008 .99961 m
.39637 .99146 L
s
.0833 .70543 m
.08363 .70786 L
s
.0833 .70543 m
.0833 .70543 L
s
.42441 .99822 m
.42784 .99899 L
s
.08363 .70786 m
.08397 .7103 L
s
.42098 .99744 m
.42441 .99822 L
s
.1425 .89725 m
.13522 .88099 L
s
.08397 .7103 m
.08433 .71275 L
s
.41756 .99665 m
.42098 .99744 L
s
.14152 .89512 m
.12008 .84348 L
s
.08433 .71275 m
.08469 .71521 L
s
.41414 .99585 m
.41756 .99665 L
s
.08795 .73521 m
.08385 .71549 L
s
.41072 .99505 m
.41414 .99585 L
s
.08469 .71521 m
.08506 .71767 L
s
.4073 .99424 m
.41072 .99505 L
s
.08506 .71767 m
.08544 .72015 L
s
.40389 .99342 m
.4073 .99424 L
s
.08544 .72015 m
.08583 .72263 L
s
.40389 .99342 m
.40389 .99342 L
s
.40066 .99255 m
.40389 .99342 L
s
.08583 .72263 m
.08624 .72513 L
s
.39742 .99166 m
.40066 .99255 L
s
.08624 .72513 m
.08665 .72763 L
s
.39419 .99078 m
.39742 .99166 L
s
.39637 .99146 m
.36345 .98187 L
s
.08665 .72763 m
.08707 .73015 L
s
.13522 .88099 m
.1282 .86429 L
s
.39097 .98988 m
.39419 .99078 L
s
.08707 .73015 m
.08751 .73267 L
s
.38774 .98897 m
.39097 .98988 L
s
.08751 .73267 m
.08795 .73521 L
s
.38452 .98806 m
.38774 .98897 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.0926 .755 m
.08795 .73521 L
s
.10207 .78974 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08795 .73521 L
s
.08795 .73521 m
.08861 .73767 L
s
.10085 .77599 m
.08795 .73521 L
s
.3813 .98714 m
.38452 .98806 L
s
.08861 .73767 m
.08928 .74013 L
s
.37809 .98622 m
.3813 .98714 L
s
.08928 .74013 m
.08996 .74258 L
s
.37488 .98528 m
.37809 .98622 L
s
.37167 .98434 m
.37488 .98528 L
s
.08996 .74258 m
.09064 .74502 L
s
.36846 .9834 m
.37167 .98434 L
s
.09064 .74502 m
.09133 .74746 L
s
.1282 .86429 m
.12146 .84716 L
s
.36526 .98244 m
.36846 .9834 L
s
.09133 .74746 m
.09203 .74988 L
s
.36526 .98244 m
.36526 .98244 L
s
.36222 .98143 m
.36526 .98244 L
s
.36345 .98187 m
.33135 .97076 L
s
.09203 .74988 m
.09273 .75231 L
s
.35919 .98042 m
.36222 .98143 L
s
.09766 .77432 m
.0926 .755 L
s
.09273 .75231 m
.09344 .75472 L
s
.35616 .9794 m
.35919 .98042 L
s
.09344 .75472 m
.09415 .75713 L
s
.35313 .97837 m
.35616 .9794 L
s
.09415 .75713 m
.09488 .75953 L
s
.3501 .97733 m
.35313 .97837 L
s
.09488 .75953 m
.09561 .76192 L
s
.12146 .84716 m
.11503 .8296 L
s
.34708 .97629 m
.3501 .97733 L
s
.09561 .76192 m
.09634 .7643 L
s
.12008 .84348 m
.10207 .78974 L
s
.34406 .97524 m
.34708 .97629 L
s
.09634 .7643 m
.09728 .76662 L
s
.09634 .7643 m
.09634 .7643 L
s
.34105 .97418 m
.34406 .97524 L
s
.1031 .79319 m
.09766 .77432 L
s
.09728 .76662 m
.09822 .76892 L
s
.33803 .97312 m
.34105 .97418 L
s
.09822 .76892 m
.09917 .77122 L
s
.33502 .97205 m
.33803 .97312 L
s
.11503 .8296 m
.1089 .81161 L
s
.33202 .97097 m
.33502 .97205 L
s
.09917 .77122 m
.10012 .77352 L
s
.1089 .81161 m
.1031 .79319 L
s
.32902 .96988 m
.33202 .97097 L
s
.33135 .97076 m
.30015 .95807 L
s
.10012 .77352 m
.10108 .7758 L
s
.32902 .96988 m
.32902 .96988 L
s
.32617 .96875 m
.32902 .96988 L
s
.11819 .81026 m
.10085 .77599 L
s
.10108 .7758 m
.10205 .77808 L
s
.32333 .96761 m
.32617 .96875 L
s
.10205 .77808 m
.10302 .78036 L
s
.32049 .96646 m
.32333 .96761 L
s
.10302 .78036 m
.104 .78262 L
s
.31766 .9653 m
.32049 .96646 L
s
.104 .78262 m
.10498 .78488 L
s
.31482 .96414 m
.31766 .9653 L
s
.10498 .78488 m
.10597 .78713 L
s
.312 .96297 m
.31482 .96414 L
s
.10597 .78713 m
.10697 .78938 L
s
.30917 .96179 m
.312 .96297 L
s
.10697 .78938 m
.10797 .79162 L
s
.30635 .96061 m
.30917 .96179 L
s
.10797 .79162 m
.10916 .79379 L
s
.10797 .79162 m
.10797 .79162 L
s
.30353 .95942 m
.30635 .96061 L
s
.10916 .79379 m
.11035 .79596 L
s
.30071 .95823 m
.30353 .95942 L
s
.11035 .79596 m
.11154 .79812 L
s
.30015 .95807 m
.26994 .94369 L
s
.2979 .95703 m
.30071 .95823 L
s
.29509 .95582 m
.2979 .95703 L
s
.11154 .79812 m
.11275 .80028 L
s
.29509 .95582 m
.29509 .95582 L
s
.29244 .95456 m
.29509 .95582 L
s
.11275 .80028 m
.11396 .80243 L
s
.28979 .95329 m
.29244 .95456 L
s
.11396 .80243 m
.11517 .80457 L
s
.28714 .95202 m
.28979 .95329 L
s
.11517 .80457 m
.11639 .8067 L
s
.28449 .95074 m
.28714 .95202 L
s
.11639 .8067 m
.11761 .80883 L
s
.28185 .94946 m
.28449 .95074 L
s
.11761 .80883 m
.11884 .81096 L
s
.13868 .83986 m
.11819 .81026 L
s
.27921 .94817 m
.28185 .94946 L
s
.11884 .81096 m
.12008 .81307 L
s
.27658 .94687 m
.27921 .94817 L
s
.12008 .81307 m
.12132 .81518 L
s
.27395 .94557 m
.27658 .94687 L
s
.12132 .81518 m
.12256 .81729 L
s
.12256 .81729 m
.12398 .81933 L
s
.12256 .81729 m
.12256 .81729 L
s
.27132 .94426 m
.27395 .94557 L
s
.26869 .94294 m
.27132 .94426 L
s
.26994 .94369 m
.24083 .92748 L
s
.12398 .81933 m
.1254 .82137 L
s
.26607 .94162 m
.26869 .94294 L
s
.1254 .82137 m
.12683 .8234 L
s
.26345 .94029 m
.26607 .94162 L
s
.26345 .94029 m
.26345 .94029 L
s
.26099 .93891 m
.26345 .94029 L
s
.12683 .8234 m
.12826 .82542 L
s
.25852 .93753 m
.26099 .93891 L
s
.12826 .82542 m
.1297 .82744 L
s
.1297 .82744 m
.13114 .82946 L
s
.25606 .93614 m
.25852 .93753 L
s
.13114 .82946 m
.13259 .83146 L
s
.25361 .93474 m
.25606 .93614 L
s
.13259 .83146 m
.13404 .83346 L
s
.25115 .93334 m
.25361 .93474 L
s
.13404 .83346 m
.1355 .83546 L
s
.2487 .93193 m
.25115 .93334 L
s
.1355 .83546 m
.13696 .83744 L
s
.24626 .93051 m
.2487 .93193 L
s
.13696 .83744 m
.13843 .83942 L
s
.24382 .92909 m
.24626 .93051 L
s
.16159 .86583 m
.13868 .83986 L
s
.13843 .83942 m
.1399 .8414 L
s
.24138 .92766 m
.24382 .92909 L
s
.1399 .8414 m
.14154 .84332 L
s
.1399 .8414 m
.1399 .8414 L
s
.24083 .92748 m
.21294 .90926 L
s
.23894 .92622 m
.24138 .92766 L
s
.14154 .84332 m
.14318 .84523 L
s
.23651 .92478 m
.23894 .92622 L
s
.23408 .92334 m
.23651 .92478 L
s
.14318 .84523 m
.14482 .84714 L
s
.23408 .92334 m
.23408 .92334 L
s
.23181 .92184 m
.23408 .92334 L
s
.14482 .84714 m
.14647 .84904 L
s
.22953 .92034 m
.23181 .92184 L
s
.14647 .84904 m
.14812 .85093 L
s
.22726 .91883 m
.22953 .92034 L
s
.14812 .85093 m
.14978 .85282 L
s
.22499 .91731 m
.22726 .91883 L
s
.14978 .85282 m
.15145 .8547 L
s
.22273 .91579 m
.22499 .91731 L
s
.15145 .8547 m
.15311 .85658 L
s
.22047 .91427 m
.22273 .91579 L
s
.15311 .85658 m
.15479 .85845 L
s
.15479 .85845 m
.15646 .86032 L
s
.21822 .91273 m
.22047 .91427 L
s
.15646 .86032 m
.15814 .86217 L
s
.21596 .91119 m
.21822 .91273 L
s
.15814 .86217 m
.15983 .86402 L
s
.15983 .86402 m
.16167 .86582 L
s
.15983 .86402 m
.15983 .86402 L
s
.21294 .90926 m
.18645 .88882 L
s
.21372 .90965 m
.21596 .91119 L
s
.18645 .88882 m
.16159 .86583 L
s
.21147 .9081 m
.21372 .90965 L
s
.16167 .86582 m
.16352 .86762 L
s
.20923 .90654 m
.21147 .9081 L
s
.207 .90497 m
.20923 .90654 L
s
.207 .90497 m
.207 .90497 L
s
.20491 .90336 m
.207 .90497 L
s
.16352 .86762 m
.16537 .8694 L
s
.20283 .90174 m
.20491 .90336 L
s
.16537 .8694 m
.16723 .87118 L
s
.20075 .90012 m
.20283 .90174 L
s
.16723 .87118 m
.16909 .87296 L
s
.16909 .87296 m
.17095 .87473 L
s
.19867 .89848 m
.20075 .90012 L
s
.17095 .87473 m
.17282 .87649 L
s
.1966 .89684 m
.19867 .89848 L
s
.18222 .88521 m
.18427 .88689 L
s
.18222 .88521 m
.18222 .88521 L
s
.18033 .88348 m
.18222 .88521 L
s
.17282 .87649 m
.17469 .87824 L
s
.17845 .88174 m
.18033 .88348 L
s
.19454 .8952 m
.1966 .89684 L
s
.17469 .87824 m
.17657 .87999 L
s
.17657 .87999 m
.17845 .88174 L
s
.18427 .88689 m
.18631 .88856 L
s
.19247 .89355 m
.19454 .8952 L
s
.18631 .88856 m
.18836 .89023 L
s
.19042 .89189 m
.19247 .89355 L
s
.18836 .89023 m
.19042 .89189 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{141.5, 179.125},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 140.5}, {178.125, 0}} -> {0.100016, -0.000782992, \
0.00531701, 0.00531701}},
  CellTags->"SolidCornerCube"],

Cell[BoxData[
    TagBox[\(DrawSystem[{SolidRetroReflector[50, 0]}]\),
      HoldForm]], "Print",
  CellTags->"SolidCornerCube"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[SolidCornerCube[50,37.5],PlotType->FrontView, \
AspectRatio->1];\
\>", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .5 m
.10317 .5 L
.18254 .5 L
.2619 .5 L
.34127 .5 L
.42063 .5 L
.5 .5 L
.57937 .5 L
.65873 .5 L
.7381 .5 L
.81746 .5 L
.89683 .5 L
.97619 .5 L
.97619 .5 L
.89683 .5 L
.81746 .5 L
.7381 .5 L
.65873 .5 L
.57937 .5 L
.5 .5 L
.42063 .5 L
.34127 .5 L
.2619 .5 L
.18254 .5 L
.10317 .5 L
.02381 .5 L
.02381 .5 L
s
.5 .02381 m
.5 .10317 L
.5 .18254 L
.5 .2619 L
.5 .34127 L
.5 .42063 L
.5 .5 L
.5 .57936 L
.5 .65873 L
.5 .7381 L
.5 .81746 L
.5 .89683 L
.5 .97619 L
.5 .97619 L
.5 .89683 L
.5 .81746 L
.5 .7381 L
.5 .65873 L
.5 .57936 L
.5 .5 L
.5 .42063 L
.5 .34127 L
.5 .2619 L
.5 .18254 L
.5 .10317 L
.5 .02381 L
.5 .02381 L
s
.97619 .5 m
.97212 .56216 L
.95996 .62325 L
.93994 .68223 L
.91239 .7381 L
.87779 .78989 L
.83672 .83672 L
.78989 .87779 L
.7381 .91239 L
.68223 .93994 L
.62325 .95996 L
.56216 .97212 L
.5 .97619 L
.43784 .97212 L
.37675 .95996 L
.31777 .93994 L
.2619 .91239 L
.21011 .87779 L
.16328 .83672 L
.12221 .78989 L
.08761 .7381 L
.06006 .68223 L
.04004 .62325 L
.02788 .56216 L
.02381 .5 L
.02788 .43784 L
.04004 .37675 L
.06006 .31777 L
.08761 .2619 L
.12221 .21011 L
.16328 .16328 L
.21011 .12221 L
.2619 .08761 L
.31777 .06006 L
.37675 .04004 L
.43784 .02788 L
.5 .02381 L
.56216 .02788 L
.62325 .04004 L
.68223 .06006 L
.7381 .08761 L
.78989 .12221 L
.83672 .16328 L
.87779 .21011 L
.91239 .2619 L
.93994 .31777 L
.95996 .37675 L
.97212 .43784 L
.97619 .5 L
s
.5 .5 m
.08761 .2619 L
.1011 .23993 L
.1158 .21866 L
.13174 .1981 L
.14894 .17827 L
.16743 .15918 L
.18728 .14088 L
.20856 .12341 L
.23137 .10681 L
.25583 .09117 L
.28211 .07658 L
.31043 .06317 L
.34109 .05111 L
.37451 .04064 L
.41133 .03214 L
.45255 .02618 L
.5 .02381 L
.54745 .02618 L
.58867 .03214 L
.62549 .04064 L
.65891 .05111 L
.68957 .06317 L
.71789 .07658 L
.74417 .09117 L
.76863 .10681 L
.79144 .12341 L
.81272 .14088 L
.83257 .15918 L
.85106 .17827 L
.86826 .1981 L
.8842 .21866 L
.8989 .23993 L
.91239 .2619 L
.5 .5 L
s
.5 .5 m
.5 .97619 L
.47423 .97549 L
.44845 .97339 L
.42268 .96987 L
.3969 .9649 L
.37113 .95842 L
.34535 .95038 L
.31958 .94069 L
.2938 .92923 L
.26803 .91587 L
.24225 .90041 L
.21648 .88259 L
.19071 .86207 L
.16493 .83836 L
.13916 .81072 L
.11338 .778 L
.08761 .7381 L
.06594 .69582 L
.05048 .65714 L
.03944 .621 L
.03179 .58682 L
.02691 .55424 L
.02437 .52301 L
.02386 .49296 L
.02518 .46396 L
.02814 .43591 L
.03264 .40874 L
.03856 .3824 L
.04584 .35684 L
.05442 .33203 L
.06426 .30795 L
.07532 .28457 L
.08761 .2619 L
.5 .5 L
s
.5 .5 m
.91239 .2619 L
.92468 .28457 L
.93574 .30795 L
.94558 .33203 L
.95416 .35684 L
.96144 .3824 L
.96736 .40874 L
.97186 .43591 L
.97482 .46396 L
.97614 .49296 L
.97563 .52301 L
.97309 .55424 L
.96821 .58682 L
.96056 .621 L
.94952 .65714 L
.93406 .69582 L
.91239 .7381 L
.88662 .778 L
.86084 .81072 L
.83507 .83836 L
.80929 .86207 L
.78352 .88259 L
.75775 .90041 L
.73197 .91587 L
.7062 .92923 L
.68042 .94069 L
.65465 .95038 L
.62887 .95842 L
.6031 .9649 L
.57732 .96987 L
.55155 .97339 L
.52577 .97549 L
.5 .97619 L
.5 .5 L
s
.65081 .95168 m
.6392 .95539 L
.62744 .95882 L
.61551 .96197 L
.60341 .96483 L
.59114 .96739 L
.5787 .96964 L
.56607 .97158 L
.55326 .9732 L
.54026 .97449 L
.52705 .97542 L
.51363 .97599 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.50286 .97618 L
.50571 .97616 L
.50855 .97611 L
.51138 .97605 L
.5142 .97598 L
.51701 .97589 L
.51981 .97578 L
.5226 .97565 L
.52538 .97551 L
.52816 .97536 L
.53092 .97519 L
.53368 .975 L
.53368 .975 L
.53642 .97479 L
.53916 .97458 L
.54189 .97434 L
.54461 .9741 L
.54732 .97383 L
.55003 .97355 L
.55272 .97326 L
.55541 .97296 L
.55809 .97263 L
.56076 .9723 L
Mistroke
.56342 .97195 L
.56607 .97158 L
.56607 .97158 L
.56872 .97121 L
.57136 .97081 L
.57399 .97041 L
.57661 .96999 L
.57922 .96955 L
.58183 .96911 L
.58442 .96865 L
.58701 .96817 L
.5896 .96769 L
.59217 .96718 L
.59474 .96667 L
.5973 .96614 L
.5973 .96614 L
.59985 .9656 L
.60239 .96505 L
.60493 .96449 L
.60746 .96391 L
.60998 .96331 L
.6125 .96271 L
.61501 .96209 L
.61751 .96146 L
.62 .96082 L
.62249 .96017 L
.62496 .9595 L
.62744 .95882 L
.62744 .95882 L
.6299 .95813 L
.63236 .95743 L
.63481 .95671 L
.63725 .95598 L
.63969 .95524 L
.64212 .95449 L
.64454 .95372 L
.64696 .95295 L
.64936 .95216 L
.65177 .95136 L
.65416 .95055 L
.65655 .94972 L
.65655 .94972 L
.65893 .94889 L
.6613 .94804 L
.66367 .94718 L
.66603 .94631 L
.66839 .94542 L
.67073 .94453 L
.67308 .94362 L
.67541 .94271 L
Mistroke
.67774 .94178 L
.68006 .94084 L
.68237 .93988 L
.68468 .93892 L
.68468 .93892 L
.68698 .93794 L
.68927 .93696 L
.69156 .93596 L
.69384 .93495 L
.69612 .93393 L
.69838 .9329 L
.70065 .93185 L
.7029 .9308 L
.70515 .92973 L
.70739 .92866 L
.70963 .92757 L
.71186 .92647 L
.71186 .92647 L
.71408 .92536 L
.71629 .92423 L
.7185 .9231 L
.72071 .92196 L
.7229 .9208 L
.72509 .91963 L
.72728 .91845 L
.72945 .91726 L
.73162 .91606 L
.73379 .91485 L
.73594 .91363 L
.7381 .91239 L
.7381 .91239 L
.74024 .91115 L
.74238 .90989 L
.74451 .90862 L
.74664 .90734 L
.74875 .90605 L
.75087 .90475 L
.75297 .90344 L
.75507 .90211 L
.75716 .90078 L
.75925 .89943 L
.76133 .89807 L
.7634 .89671 L
.7634 .89671 L
.76547 .89533 L
.76753 .89393 L
.76959 .89253 L
.77163 .89112 L
.77367 .88969 L
.77571 .88826 L
Mistroke
.77774 .88681 L
.77976 .88535 L
.78177 .88388 L
.78378 .88239 L
.78578 .8809 L
.78778 .8794 L
.78778 .8794 L
.78977 .87788 L
.79175 .87635 L
.79372 .87481 L
.79569 .87326 L
.79765 .8717 L
.79961 .87013 L
.80156 .86854 L
.8035 .86694 L
.80543 .86533 L
.80736 .86371 L
.80928 .86208 L
.8112 .86044 L
.8112 .86044 L
.8131 .85878 L
.815 .85711 L
.8169 .85543 L
.81879 .85374 L
.82067 .85204 L
.82254 .85032 L
.82441 .84859 L
.82627 .84685 L
.82812 .8451 L
.82996 .84334 L
.8318 .84156 L
.83363 .83977 L
.83363 .83977 L
.83546 .83797 L
.83727 .83616 L
.83908 .83433 L
.84089 .8325 L
.84268 .83065 L
.84447 .82878 L
.84625 .82691 L
.84802 .82502 L
.84979 .82312 L
.85155 .8212 L
.8533 .81927 L
.85504 .81733 L
.85504 .81733 L
.85678 .81538 L
.85851 .81341 L
.86023 .81144 L
.86194 .80944 L
Mistroke
.86365 .80744 L
.86535 .80542 L
.86704 .80338 L
.86872 .80134 L
.87039 .79928 L
.87206 .7972 L
.87372 .79511 L
.87537 .79301 L
.87537 .79301 L
.87701 .7909 L
.87864 .78877 L
.88027 .78662 L
.88189 .78446 L
.8835 .78229 L
.8851 .7801 L
.88669 .7779 L
.88827 .77568 L
.88985 .77345 L
.89141 .7712 L
.89297 .76894 L
.89452 .76666 L
.89452 .76666 L
.89606 .76437 L
.89759 .76206 L
.89911 .75974 L
.90063 .7574 L
.90213 .75504 L
.90363 .75267 L
.90511 .75028 L
.90659 .74788 L
.90805 .74546 L
.90951 .74302 L
.91096 .74057 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.90063 .7574 L
.88827 .77568 L
Mistroke
.87537 .79301 L
.86194 .80944 L
.84802 .82502 L
.83363 .83977 L
.81879 .85374 L
.8035 .86694 L
.78778 .8794 L
.77163 .89112 L
.75507 .90211 L
.7381 .91239 L
.7381 .91239 L
.73427 .91458 L
.73042 .91673 L
.72655 .91885 L
.72266 .92093 L
.71875 .92297 L
.71482 .92498 L
.71087 .92696 L
.70689 .9289 L
.7029 .9308 L
.69889 .93267 L
.69485 .9345 L
.6908 .93629 L
.6908 .93629 L
.69029 .93652 L
.68978 .93674 L
.68927 .93696 L
.68876 .93718 L
.68825 .9374 L
.68774 .93762 L
.68723 .93784 L
.68672 .93805 L
.68621 .93827 L
.6857 .93849 L
.68519 .9387 L
.68468 .93892 L
.68468 .93892 L
.68402 .9392 L
.68336 .93947 L
.6827 .93975 L
.68204 .94002 L
.68138 .94029 L
.68072 .94057 L
.68006 .94084 L
.67939 .94111 L
.67873 .94138 L
.67807 .94164 L
.6774 .94191 L
.67674 .94218 L
.67674 .94218 L
Mistroke
.67585 .94253 L
.67497 .94288 L
.67408 .94323 L
.67319 .94358 L
.6723 .94393 L
.6714 .94427 L
.67051 .94462 L
.66962 .94496 L
.66872 .9453 L
.66783 .94564 L
.66693 .94597 L
.66603 .94631 L
.66603 .94631 L
.66477 .94677 L
.66351 .94724 L
.66225 .9477 L
.66099 .94815 L
.65972 .9486 L
.65845 .94905 L
.65718 .9495 L
.65591 .94994 L
.65464 .95038 L
.65336 .95082 L
.65209 .95125 L
.65081 .95168 L
Mfstroke
.5 .97619 m
.48637 .97599 L
.47295 .97542 L
.45974 .97449 L
.44674 .9732 L
.43393 .97158 L
.4213 .96964 L
.40886 .96739 L
.39659 .96483 L
.38449 .96197 L
.37256 .95882 L
.3608 .95539 L
.34919 .95168 L
.34919 .95168 L
.34791 .95125 L
.34664 .95082 L
.34536 .95038 L
.34409 .94994 L
.34282 .9495 L
.34155 .94905 L
.34028 .9486 L
.33901 .94815 L
.33775 .9477 L
.33649 .94724 L
.33523 .94677 L
.33397 .94631 L
.33397 .94631 L
.33307 .94597 L
.33217 .94564 L
.33128 .9453 L
.33038 .94496 L
.32949 .94462 L
.3286 .94427 L
.3277 .94393 L
.32681 .94358 L
.32592 .94323 L
.32503 .94288 L
.32415 .94253 L
.32326 .94218 L
.32326 .94218 L
.3226 .94191 L
.32193 .94164 L
.32127 .94138 L
.32061 .94111 L
.31994 .94084 L
.31928 .94057 L
.31862 .94029 L
.31796 .94002 L
.3173 .93975 L
.31664 .93947 L
Mistroke
.31598 .9392 L
.31532 .93892 L
.31532 .93892 L
.31481 .9387 L
.3143 .93849 L
.31379 .93827 L
.31328 .93805 L
.31277 .93784 L
.31226 .93762 L
.31175 .9374 L
.31124 .93718 L
.31073 .93696 L
.31022 .93674 L
.30971 .93652 L
.3092 .93629 L
.3092 .93629 L
.30515 .9345 L
.30111 .93267 L
.2971 .9308 L
.29311 .9289 L
.28913 .92696 L
.28518 .92498 L
.28125 .92297 L
.27734 .92093 L
.27345 .91885 L
.26958 .91673 L
.26573 .91458 L
.2619 .91239 L
.2619 .91239 L
.24493 .90211 L
.22837 .89112 L
.21222 .8794 L
.1965 .86694 L
.18121 .85374 L
.16637 .83977 L
.15198 .82502 L
.13806 .80944 L
.12463 .79301 L
.11173 .77568 L
.09937 .7574 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
Mistroke
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08904 .74057 L
.09049 .74302 L
.09195 .74546 L
.09341 .74788 L
.09489 .75028 L
.09637 .75267 L
.09787 .75504 L
.09937 .7574 L
.10089 .75974 L
.10241 .76206 L
.10394 .76437 L
.10548 .76666 L
.10548 .76666 L
.10703 .76894 L
.10859 .7712 L
.11015 .77345 L
.11173 .77568 L
.11331 .7779 L
.1149 .7801 L
.1165 .78229 L
.11811 .78446 L
.11973 .78662 L
.12136 .78877 L
.12299 .7909 L
.12463 .79301 L
.12463 .79301 L
.12628 .79511 L
.12794 .7972 L
.12961 .79928 L
.13128 .80134 L
.13296 .80338 L
.13465 .80542 L
.13635 .80744 L
.13806 .80944 L
.13977 .81144 L
.14149 .81341 L
.14322 .81538 L
.14496 .81733 L
.14496 .81733 L
.1467 .81927 L
.14845 .8212 L
.15021 .82312 L
.15198 .82502 L
.15375 .82691 L
.15553 .82878 L
Mistroke
.15732 .83065 L
.15911 .8325 L
.16092 .83433 L
.16273 .83616 L
.16454 .83797 L
.16637 .83977 L
.16637 .83977 L
.1682 .84156 L
.17004 .84334 L
.17188 .8451 L
.17373 .84685 L
.17559 .84859 L
.17746 .85032 L
.17933 .85204 L
.18121 .85374 L
.1831 .85543 L
.185 .85711 L
.1869 .85878 L
.1888 .86044 L
.1888 .86044 L
.19072 .86208 L
.19264 .86371 L
.19457 .86533 L
.1965 .86694 L
.19844 .86854 L
.20039 .87013 L
.20235 .8717 L
.20431 .87326 L
.20628 .87481 L
.20825 .87635 L
.21023 .87788 L
.21222 .8794 L
.21222 .8794 L
.21422 .8809 L
.21622 .88239 L
.21823 .88388 L
.22024 .88535 L
.22226 .88681 L
.22429 .88826 L
.22633 .88969 L
.22837 .89112 L
.23041 .89253 L
.23247 .89393 L
.23453 .89533 L
.2366 .89671 L
.2366 .89671 L
.23867 .89807 L
.24075 .89943 L
.24284 .90078 L
.24493 .90211 L
Mistroke
.24703 .90344 L
.24913 .90475 L
.25125 .90605 L
.25336 .90734 L
.25549 .90862 L
.25762 .90989 L
.25976 .91115 L
.2619 .91239 L
.2619 .91239 L
.26406 .91363 L
.26621 .91485 L
.26838 .91606 L
.27055 .91726 L
.27272 .91845 L
.27491 .91963 L
.2771 .9208 L
.27929 .92196 L
.2815 .9231 L
.28371 .92423 L
.28592 .92536 L
.28814 .92647 L
.28814 .92647 L
.29037 .92757 L
.29261 .92866 L
.29485 .92973 L
.2971 .9308 L
.29935 .93185 L
.30162 .9329 L
.30388 .93393 L
.30616 .93495 L
.30844 .93596 L
.31073 .93696 L
.31302 .93794 L
.31532 .93892 L
.31532 .93892 L
.31763 .93988 L
.31994 .94084 L
.32226 .94178 L
.32459 .94271 L
.32692 .94362 L
.32927 .94453 L
.33161 .94542 L
.33397 .94631 L
.33633 .94718 L
.3387 .94804 L
.34107 .94889 L
.34345 .94972 L
.34345 .94972 L
.34584 .95055 L
.34823 .95136 L
Mistroke
.35064 .95216 L
.35304 .95295 L
.35546 .95372 L
.35788 .95449 L
.36031 .95524 L
.36275 .95598 L
.36519 .95671 L
.36764 .95743 L
.3701 .95813 L
.37256 .95882 L
.37256 .95882 L
.37504 .9595 L
.37751 .96017 L
.38 .96082 L
.38249 .96146 L
.38499 .96209 L
.3875 .96271 L
.39002 .96331 L
.39254 .96391 L
.39507 .96449 L
.39761 .96505 L
.40015 .9656 L
.4027 .96614 L
.4027 .96614 L
.40526 .96667 L
.40783 .96718 L
.4104 .96769 L
.41299 .96817 L
.41558 .96865 L
.41817 .96911 L
.42078 .96955 L
.42339 .96999 L
.42601 .97041 L
.42864 .97081 L
.43128 .97121 L
.43393 .97158 L
.43393 .97158 L
.43658 .97195 L
.43924 .9723 L
.44191 .97263 L
.44459 .97296 L
.44728 .97326 L
.44997 .97355 L
.45268 .97383 L
.45539 .9741 L
.45811 .97434 L
.46084 .97458 L
.46358 .97479 L
.46632 .975 L
.46632 .975 L
Mistroke
.46908 .97519 L
.47184 .97536 L
.47462 .97551 L
.4774 .97565 L
.48019 .97578 L
.48299 .97589 L
.4858 .97598 L
.48862 .97605 L
.49145 .97611 L
.49429 .97616 L
.49714 .97618 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
.5 .97619 L
Mfstroke
.03343 .40476 m
.03602 .39286 L
.03893 .38095 L
.04217 .36905 L
.04574 .35714 L
.04966 .34524 L
.05393 .33333 L
.05856 .32143 L
.06356 .30952 L
.06896 .29762 L
.07475 .28571 L
.08096 .27381 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08618 .26439 L
.08478 .26687 L
.0834 .26935 L
.08204 .27183 L
.08069 .27431 L
.07937 .27679 L
.07806 .27927 L
.07677 .28175 L
.0755 .28423 L
.07425 .28671 L
.07302 .28919 L
.0718 .29167 L
.0718 .29167 L
.0706 .29415 L
.06942 .29663 L
.06826 .29911 L
.06711 .30159 L
.06599 .30407 L
.06488 .30655 L
.06378 .30903 L
.0627 .31151 L
.06164 .31399 L
.0606 .31647 L
Mistroke
.05957 .31895 L
.05856 .32143 L
.05856 .32143 L
.05756 .32391 L
.05659 .32639 L
.05562 .32887 L
.05468 .33135 L
.05374 .33383 L
.05283 .33631 L
.05193 .33879 L
.05104 .34127 L
.05017 .34375 L
.04932 .34623 L
.04848 .34871 L
.04766 .35119 L
.04766 .35119 L
.04685 .35367 L
.04606 .35615 L
.04528 .35863 L
.04451 .36111 L
.04377 .36359 L
.04303 .36607 L
.04231 .36855 L
.04161 .37103 L
.04092 .37351 L
.04024 .37599 L
.03958 .37847 L
.03893 .38095 L
.03893 .38095 L
.0383 .38343 L
.03768 .38591 L
.03707 .38839 L
.03648 .39087 L
.03591 .39335 L
.03534 .39583 L
.03479 .39831 L
.03426 .40079 L
.03374 .40327 L
.03323 .40575 L
.03274 .40823 L
.03225 .41071 L
.03225 .41071 L
.03179 .41319 L
.03134 .41567 L
.0309 .41815 L
.03047 .42063 L
.03006 .42312 L
.02966 .4256 L
.02927 .42808 L
.0289 .43056 L
Mistroke
.02854 .43304 L
.0282 .43552 L
.02786 .438 L
.02754 .44048 L
.02754 .44048 L
.02724 .44296 L
.02695 .44544 L
.02667 .44792 L
.0264 .4504 L
.02615 .45288 L
.02591 .45536 L
.02568 .45784 L
.02547 .46032 L
.02526 .4628 L
.02508 .46528 L
.0249 .46776 L
.02474 .47024 L
.02474 .47024 L
.02459 .47272 L
.02446 .4752 L
.02433 .47768 L
.02422 .48016 L
.02413 .48264 L
.02404 .48512 L
.02397 .4876 L
.02391 .49008 L
.02387 .49256 L
.02384 .49504 L
.02382 .49752 L
.02381 .5 L
.02381 .5 L
.02382 .50248 L
.02384 .50496 L
.02387 .50744 L
.02391 .50992 L
.02397 .5124 L
.02404 .51488 L
.02413 .51736 L
.02422 .51984 L
.02433 .52232 L
.02446 .5248 L
.02459 .52728 L
.02474 .52976 L
.02474 .52976 L
.0249 .53224 L
.02508 .53472 L
.02526 .5372 L
.02547 .53968 L
.02568 .54216 L
.02591 .54464 L
Mistroke
.02615 .54712 L
.0264 .5496 L
.02667 .55208 L
.02695 .55456 L
.02724 .55704 L
.02754 .55952 L
.02754 .55952 L
.02786 .562 L
.0282 .56448 L
.02854 .56696 L
.0289 .56944 L
.02927 .57192 L
.02966 .5744 L
.03006 .57688 L
.03047 .57936 L
.0309 .58185 L
.03134 .58433 L
.03179 .58681 L
.03225 .58929 L
.03225 .58929 L
.03274 .59177 L
.03323 .59425 L
.03374 .59673 L
.03426 .59921 L
.03479 .60169 L
.03534 .60417 L
.03591 .60665 L
.03648 .60913 L
.03707 .61161 L
.03768 .61409 L
.0383 .61657 L
.03893 .61905 L
.03893 .61905 L
.03958 .62153 L
.04024 .62401 L
.04092 .62649 L
.04161 .62897 L
.04231 .63145 L
.04303 .63393 L
.04377 .63641 L
.04451 .63889 L
.04528 .64137 L
.04606 .64385 L
.04685 .64633 L
.04766 .64881 L
.04766 .64881 L
.04848 .65129 L
.04932 .65377 L
.05017 .65625 L
.05104 .65873 L
Mistroke
.05193 .66121 L
.05283 .66369 L
.05374 .66617 L
.05468 .66865 L
.05562 .67113 L
.05659 .67361 L
.05756 .67609 L
.05856 .67857 L
.05856 .67857 L
.05957 .68105 L
.0606 .68353 L
.06164 .68601 L
.0627 .68849 L
.06378 .69097 L
.06488 .69345 L
.06599 .69593 L
.06711 .69841 L
.06826 .70089 L
.06942 .70337 L
.0706 .70585 L
.0718 .70833 L
.0718 .70833 L
.07302 .71081 L
.07425 .71329 L
.0755 .71577 L
.07677 .71825 L
.07806 .72073 L
.07937 .72321 L
.08069 .72569 L
.08204 .72817 L
.0834 .73065 L
.08478 .73313 L
.08618 .73561 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.08761 .7381 L
.07677 .71825 L
.06711 .69841 L
Mistroke
.05856 .67857 L
.05104 .65873 L
.04451 .63889 L
.03893 .61905 L
.03426 .59921 L
.03047 .57936 L
.02754 .55952 L
.02547 .53968 L
.02422 .51984 L
.02381 .5 L
.02381 .5 L
.02383 .49559 L
.02389 .49118 L
.02399 .48677 L
.02414 .48236 L
.02432 .47795 L
.02454 .47354 L
.02481 .46914 L
.02512 .46473 L
.02547 .46032 L
.02586 .45591 L
.02629 .4515 L
.02676 .44709 L
.02676 .44709 L
.02682 .44654 L
.02688 .44599 L
.02695 .44544 L
.02701 .44489 L
.02707 .44433 L
.02714 .44378 L
.02721 .44323 L
.02727 .44268 L
.02734 .44213 L
.02741 .44158 L
.02748 .44103 L
.02754 .44048 L
.02754 .44048 L
.02763 .43977 L
.02773 .43906 L
.02782 .43835 L
.02791 .43764 L
.028 .43693 L
.0281 .43622 L
.0282 .43552 L
.02829 .43481 L
.02839 .4341 L
.02849 .43339 L
.02859 .43268 L
.02869 .43197 L
.02869 .43197 L
Mistroke
.02883 .43103 L
.02897 .43008 L
.02911 .42914 L
.02925 .42819 L
.0294 .42725 L
.02955 .4263 L
.0297 .42536 L
.02985 .42441 L
.03 .42347 L
.03015 .42252 L
.03031 .42158 L
.03047 .42063 L
.03047 .42063 L
.0307 .41931 L
.03092 .41799 L
.03116 .41667 L
.03139 .41534 L
.03164 .41402 L
.03188 .4127 L
.03213 .41138 L
.03238 .41005 L
.03264 .40873 L
.0329 .40741 L
.03316 .40608 L
.03343 .40476 L
Mfstroke
.08761 .2619 m
.09459 .2502 L
.1018 .23886 L
.10921 .2279 L
.11682 .21727 L
.12463 .20699 L
.13263 .19702 L
.1408 .18738 L
.14915 .17803 L
.15768 .16898 L
.16637 .16023 L
.17522 .15175 L
.18424 .14356 L
.18424 .14356 L
.18525 .14266 L
.18626 .14177 L
.18728 .14089 L
.18829 .14 L
.18931 .13912 L
.19033 .13825 L
.19136 .13737 L
.19238 .1365 L
.19341 .13564 L
.19444 .13477 L
.19547 .13391 L
.1965 .13306 L
.1965 .13306 L
.19724 .13245 L
.19798 .13184 L
.19872 .13123 L
.19946 .13063 L
.20021 .13003 L
.20095 .12942 L
.2017 .12882 L
.20244 .12823 L
.20319 .12763 L
.20394 .12703 L
.20468 .12644 L
.20543 .12585 L
.20543 .12585 L
.206 .12541 L
.20656 .12497 L
.20712 .12453 L
.20769 .12409 L
.20825 .12365 L
.20882 .12321 L
.20938 .12277 L
.20995 .12234 L
.21052 .1219 L
.21109 .12147 L
Mistroke
.21165 .12104 L
.21222 .1206 L
.21222 .1206 L
.21267 .12027 L
.21311 .11993 L
.21355 .1196 L
.214 .11927 L
.21444 .11893 L
.21488 .1186 L
.21533 .11827 L
.21577 .11794 L
.21622 .11761 L
.21667 .11727 L
.21711 .11694 L
.21756 .11662 L
.21756 .11662 L
.22114 .114 L
.22474 .11142 L
.22837 .10888 L
.23201 .10638 L
.23568 .10391 L
.23936 .10147 L
.24307 .09907 L
.24679 .09671 L
.25054 .09438 L
.25431 .09209 L
.2581 .08983 L
.2619 .08761 L
.2619 .08761 L
.27929 .07804 L
.2971 .0692 L
.31532 .06108 L
.33397 .05369 L
.35304 .04705 L
.37256 .04118 L
.39254 .03609 L
.41299 .03183 L
.43393 .02842 L
.45539 .0259 L
.4774 .02435 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
Mistroke
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.49714 .02382 L
.49429 .02384 L
.49145 .02389 L
.48862 .02395 L
.4858 .02402 L
.48299 .02411 L
.48019 .02422 L
.4774 .02435 L
.47462 .02449 L
.47184 .02464 L
.46908 .02481 L
.46632 .025 L
.46632 .025 L
.46358 .0252 L
.46084 .02542 L
.45811 .02566 L
.45539 .0259 L
.45268 .02617 L
.44997 .02644 L
.44728 .02674 L
.44459 .02704 L
.44191 .02737 L
.43924 .0277 L
.43658 .02805 L
.43393 .02842 L
.43393 .02842 L
.43128 .02879 L
.42864 .02919 L
.42601 .02959 L
.42339 .03001 L
.42078 .03045 L
.41817 .03089 L
.41558 .03135 L
.41299 .03183 L
.4104 .03231 L
.40783 .03282 L
.40526 .03333 L
.4027 .03386 L
.4027 .03386 L
.40015 .0344 L
.39761 .03495 L
.39507 .03551 L
.39254 .03609 L
.39002 .03669 L
.3875 .03729 L
Mistroke
.38499 .03791 L
.38249 .03854 L
.38 .03918 L
.37751 .03983 L
.37504 .0405 L
.37256 .04118 L
.37256 .04118 L
.3701 .04187 L
.36764 .04257 L
.36519 .04329 L
.36275 .04402 L
.36031 .04476 L
.35788 .04551 L
.35546 .04628 L
.35304 .04705 L
.35064 .04784 L
.34823 .04864 L
.34584 .04945 L
.34345 .05028 L
.34345 .05028 L
.34107 .05111 L
.3387 .05196 L
.33633 .05282 L
.33397 .05369 L
.33161 .05458 L
.32927 .05547 L
.32692 .05638 L
.32459 .05729 L
.32226 .05822 L
.31994 .05916 L
.31763 .06012 L
.31532 .06108 L
.31532 .06108 L
.31302 .06205 L
.31073 .06304 L
.30844 .06404 L
.30616 .06505 L
.30388 .06607 L
.30162 .0671 L
.29935 .06815 L
.2971 .0692 L
.29485 .07027 L
.29261 .07134 L
.29037 .07243 L
.28814 .07353 L
.28814 .07353 L
.28592 .07464 L
.28371 .07577 L
.2815 .0769 L
.27929 .07804 L
Mistroke
.2771 .0792 L
.27491 .08037 L
.27272 .08155 L
.27055 .08274 L
.26838 .08394 L
.26621 .08515 L
.26406 .08637 L
.2619 .08761 L
.2619 .08761 L
.25976 .08885 L
.25762 .09011 L
.25549 .09138 L
.25336 .09266 L
.25125 .09395 L
.24913 .09525 L
.24703 .09656 L
.24493 .09789 L
.24284 .09922 L
.24075 .10057 L
.23867 .10193 L
.2366 .10329 L
.2366 .10329 L
.23453 .10467 L
.23247 .10607 L
.23041 .10747 L
.22837 .10888 L
.22633 .11031 L
.22429 .11174 L
.22226 .11319 L
.22024 .11465 L
.21823 .11612 L
.21622 .11761 L
.21422 .1191 L
.21222 .1206 L
.21222 .1206 L
.21023 .12212 L
.20825 .12365 L
.20628 .12519 L
.20431 .12674 L
.20235 .1283 L
.20039 .12987 L
.19844 .13146 L
.1965 .13306 L
.19457 .13467 L
.19264 .13629 L
.19072 .13792 L
.1888 .13956 L
.1888 .13956 L
.1869 .14122 L
.185 .14289 L
Mistroke
.1831 .14457 L
.18121 .14626 L
.17933 .14796 L
.17746 .14968 L
.17559 .15141 L
.17373 .15315 L
.17188 .1549 L
.17004 .15666 L
.1682 .15844 L
.16637 .16023 L
.16637 .16023 L
.16454 .16203 L
.16273 .16384 L
.16092 .16567 L
.15911 .1675 L
.15732 .16935 L
.15553 .17122 L
.15375 .17309 L
.15198 .17498 L
.15021 .17688 L
.14845 .1788 L
.1467 .18073 L
.14496 .18267 L
.14496 .18267 L
.14322 .18462 L
.14149 .18658 L
.13977 .18856 L
.13806 .19056 L
.13635 .19256 L
.13465 .19458 L
.13296 .19662 L
.13128 .19866 L
.12961 .20072 L
.12794 .2028 L
.12628 .20489 L
.12463 .20699 L
.12463 .20699 L
.12299 .2091 L
.12136 .21123 L
.11973 .21338 L
.11811 .21554 L
.1165 .21771 L
.1149 .2199 L
.11331 .2221 L
.11173 .22432 L
.11015 .22655 L
.10859 .2288 L
.10703 .23106 L
.10548 .23334 L
.10548 .23334 L
Mistroke
.10394 .23563 L
.10241 .23794 L
.10089 .24026 L
.09937 .2426 L
.09787 .24496 L
.09637 .24733 L
.09489 .24972 L
.09341 .25212 L
.09195 .25454 L
.09049 .25698 L
.08904 .25943 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
.08761 .2619 L
Mfstroke
.81576 .14356 m
.82478 .15175 L
.83363 .16023 L
.84232 .16898 L
.85085 .17803 L
.8592 .18738 L
.86737 .19702 L
.87537 .20699 L
.88318 .21727 L
.89079 .2279 L
.8982 .23886 L
.90541 .2502 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91096 .25943 L
.90951 .25698 L
.90805 .25454 L
.90659 .25212 L
.90511 .24972 L
.90363 .24733 L
.90213 .24496 L
.90063 .2426 L
.89911 .24026 L
.89759 .23794 L
.89606 .23563 L
.89452 .23334 L
.89452 .23334 L
.89297 .23106 L
.89141 .2288 L
.88985 .22655 L
.88827 .22432 L
.88669 .2221 L
.8851 .2199 L
.8835 .21771 L
.88189 .21554 L
.88027 .21338 L
.87864 .21123 L
Mistroke
.87701 .2091 L
.87537 .20699 L
.87537 .20699 L
.87372 .20489 L
.87206 .2028 L
.87039 .20072 L
.86872 .19866 L
.86704 .19662 L
.86535 .19458 L
.86365 .19256 L
.86194 .19056 L
.86023 .18856 L
.85851 .18658 L
.85678 .18462 L
.85504 .18267 L
.85504 .18267 L
.8533 .18073 L
.85155 .1788 L
.84979 .17688 L
.84802 .17498 L
.84625 .17309 L
.84447 .17122 L
.84268 .16935 L
.84089 .1675 L
.83908 .16567 L
.83727 .16384 L
.83546 .16203 L
.83363 .16023 L
.83363 .16023 L
.8318 .15844 L
.82996 .15666 L
.82812 .1549 L
.82627 .15315 L
.82441 .15141 L
.82254 .14968 L
.82067 .14796 L
.81879 .14626 L
.8169 .14457 L
.815 .14289 L
.8131 .14122 L
.8112 .13956 L
.8112 .13956 L
.80928 .13792 L
.80736 .13629 L
.80543 .13467 L
.8035 .13306 L
.80156 .13146 L
.79961 .12987 L
.79765 .1283 L
.79569 .12674 L
Mistroke
.79372 .12519 L
.79175 .12365 L
.78977 .12212 L
.78778 .1206 L
.78778 .1206 L
.78578 .1191 L
.78378 .11761 L
.78177 .11612 L
.77976 .11465 L
.77774 .11319 L
.77571 .11174 L
.77367 .11031 L
.77163 .10888 L
.76959 .10747 L
.76753 .10607 L
.76547 .10467 L
.7634 .10329 L
.7634 .10329 L
.76133 .10193 L
.75925 .10057 L
.75716 .09922 L
.75507 .09789 L
.75297 .09656 L
.75087 .09525 L
.74875 .09395 L
.74664 .09266 L
.74451 .09138 L
.74238 .09011 L
.74024 .08885 L
.7381 .08761 L
.7381 .08761 L
.73594 .08637 L
.73379 .08515 L
.73162 .08394 L
.72945 .08274 L
.72728 .08155 L
.72509 .08037 L
.7229 .0792 L
.72071 .07804 L
.7185 .0769 L
.71629 .07577 L
.71408 .07464 L
.71186 .07353 L
.71186 .07353 L
.70963 .07243 L
.70739 .07134 L
.70515 .07027 L
.7029 .0692 L
.70065 .06815 L
.69838 .0671 L
Mistroke
.69612 .06607 L
.69384 .06505 L
.69156 .06404 L
.68927 .06304 L
.68698 .06205 L
.68468 .06108 L
.68468 .06108 L
.68237 .06012 L
.68006 .05916 L
.67774 .05822 L
.67541 .05729 L
.67308 .05638 L
.67073 .05547 L
.66839 .05458 L
.66603 .05369 L
.66367 .05282 L
.6613 .05196 L
.65893 .05111 L
.65655 .05028 L
.65655 .05028 L
.65416 .04945 L
.65177 .04864 L
.64936 .04784 L
.64696 .04705 L
.64454 .04628 L
.64212 .04551 L
.63969 .04476 L
.63725 .04402 L
.63481 .04329 L
.63236 .04257 L
.6299 .04187 L
.62744 .04118 L
.62744 .04118 L
.62496 .0405 L
.62249 .03983 L
.62 .03918 L
.61751 .03854 L
.61501 .03791 L
.6125 .03729 L
.60998 .03669 L
.60746 .03609 L
.60493 .03551 L
.60239 .03495 L
.59985 .0344 L
.5973 .03386 L
.5973 .03386 L
.59474 .03333 L
.59217 .03282 L
.5896 .03231 L
.58701 .03183 L
Mistroke
.58442 .03135 L
.58183 .03089 L
.57922 .03045 L
.57661 .03001 L
.57399 .02959 L
.57136 .02919 L
.56872 .02879 L
.56607 .02842 L
.56607 .02842 L
.56342 .02805 L
.56076 .0277 L
.55809 .02737 L
.55541 .02704 L
.55272 .02674 L
.55003 .02644 L
.54732 .02617 L
.54461 .0259 L
.54189 .02566 L
.53916 .02542 L
.53642 .0252 L
.53368 .025 L
.53368 .025 L
.53092 .02481 L
.52816 .02464 L
.52538 .02449 L
.5226 .02435 L
.51981 .02422 L
.51701 .02411 L
.5142 .02402 L
.51138 .02395 L
.50855 .02389 L
.50571 .02384 L
.50286 .02382 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5 .02381 L
.5226 .02435 L
.54461 .0259 L
Mistroke
.56607 .02842 L
.58701 .03183 L
.60746 .03609 L
.62744 .04118 L
.64696 .04705 L
.66603 .05369 L
.68468 .06108 L
.7029 .0692 L
.72071 .07804 L
.7381 .08761 L
.7381 .08761 L
.7419 .08983 L
.74569 .09209 L
.74946 .09438 L
.75321 .09671 L
.75693 .09907 L
.76064 .10147 L
.76432 .10391 L
.76799 .10638 L
.77163 .10888 L
.77526 .11142 L
.77886 .114 L
.78244 .11662 L
.78244 .11662 L
.78289 .11694 L
.78333 .11727 L
.78378 .11761 L
.78423 .11794 L
.78467 .11827 L
.78512 .1186 L
.78556 .11893 L
.786 .11927 L
.78645 .1196 L
.78689 .11993 L
.78733 .12027 L
.78778 .1206 L
.78778 .1206 L
.78835 .12104 L
.78891 .12147 L
.78948 .1219 L
.79005 .12234 L
.79062 .12277 L
.79118 .12321 L
.79175 .12365 L
.79231 .12409 L
.79288 .12453 L
.79344 .12497 L
.794 .12541 L
.79457 .12585 L
.79457 .12585 L
Mistroke
.79532 .12644 L
.79606 .12703 L
.79681 .12763 L
.79756 .12823 L
.7983 .12882 L
.79905 .12942 L
.79979 .13003 L
.80054 .13063 L
.80128 .13123 L
.80202 .13184 L
.80276 .13245 L
.8035 .13306 L
.8035 .13306 L
.80453 .13391 L
.80556 .13477 L
.80659 .13564 L
.80762 .1365 L
.80864 .13737 L
.80967 .13825 L
.81069 .13912 L
.81171 .14 L
.81272 .14089 L
.81374 .14177 L
.81475 .14266 L
.81576 .14356 L
Mfstroke
.91239 .2619 m
.91904 .27381 L
.92525 .28571 L
.93104 .29762 L
.93644 .30952 L
.94144 .32143 L
.94607 .33333 L
.95034 .34524 L
.95426 .35714 L
.95783 .36905 L
.96107 .38095 L
.96398 .39286 L
.96657 .40476 L
.96657 .40476 L
.96684 .40608 L
.9671 .40741 L
.96736 .40873 L
.96762 .41005 L
.96787 .41138 L
.96812 .4127 L
.96836 .41402 L
.96861 .41534 L
.96884 .41667 L
.96908 .41799 L
.9693 .41931 L
.96953 .42063 L
.96953 .42063 L
.96969 .42158 L
.96985 .42252 L
.97 .42347 L
.97015 .42441 L
.9703 .42536 L
.97045 .4263 L
.9706 .42725 L
.97075 .42819 L
.97089 .42914 L
.97103 .43008 L
.97117 .43103 L
.97131 .43197 L
.97131 .43197 L
.97141 .43268 L
.97151 .43339 L
.97161 .4341 L
.97171 .43481 L
.9718 .43552 L
.9719 .43622 L
.972 .43693 L
.97209 .43764 L
.97218 .43835 L
.97227 .43906 L
Mistroke
.97237 .43977 L
.97246 .44048 L
.97246 .44048 L
.97252 .44103 L
.97259 .44158 L
.97266 .44213 L
.97273 .44268 L
.97279 .44323 L
.97286 .44378 L
.97293 .44433 L
.97299 .44489 L
.97305 .44544 L
.97312 .44599 L
.97318 .44654 L
.97324 .44709 L
.97324 .44709 L
.97371 .4515 L
.97414 .45591 L
.97453 .46032 L
.97488 .46473 L
.97519 .46914 L
.97546 .47354 L
.97568 .47795 L
.97586 .48236 L
.97601 .48677 L
.97611 .49118 L
.97617 .49559 L
.97619 .5 L
.97619 .5 L
.97578 .51984 L
.97453 .53968 L
.97246 .55952 L
.96953 .57936 L
.96574 .59921 L
.96107 .61905 L
.95549 .63889 L
.94896 .65873 L
.94144 .67857 L
.93289 .69841 L
.92323 .71825 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
Mistroke
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91239 .7381 L
.91382 .73561 L
.91522 .73313 L
.9166 .73065 L
.91796 .72817 L
.91931 .72569 L
.92063 .72321 L
.92194 .72073 L
.92323 .71825 L
.9245 .71577 L
.92575 .71329 L
.92698 .71081 L
.9282 .70833 L
.9282 .70833 L
.9294 .70585 L
.93058 .70337 L
.93174 .70089 L
.93289 .69841 L
.93401 .69593 L
.93512 .69345 L
.93622 .69097 L
.9373 .68849 L
.93836 .68601 L
.9394 .68353 L
.94043 .68105 L
.94144 .67857 L
.94144 .67857 L
.94244 .67609 L
.94341 .67361 L
.94438 .67113 L
.94532 .66865 L
.94626 .66617 L
.94717 .66369 L
.94807 .66121 L
.94896 .65873 L
.94983 .65625 L
.95068 .65377 L
.95152 .65129 L
.95234 .64881 L
.95234 .64881 L
.95315 .64633 L
.95394 .64385 L
.95472 .64137 L
.95549 .63889 L
.95623 .63641 L
.95697 .63393 L
Mistroke
.95769 .63145 L
.95839 .62897 L
.95908 .62649 L
.95976 .62401 L
.96042 .62153 L
.96107 .61905 L
.96107 .61905 L
.9617 .61657 L
.96232 .61409 L
.96293 .61161 L
.96352 .60913 L
.96409 .60665 L
.96466 .60417 L
.96521 .60169 L
.96574 .59921 L
.96626 .59673 L
.96677 .59425 L
.96726 .59177 L
.96775 .58929 L
.96775 .58929 L
.96821 .58681 L
.96866 .58433 L
.9691 .58185 L
.96953 .57936 L
.96994 .57688 L
.97034 .5744 L
.97073 .57192 L
.9711 .56944 L
.97146 .56696 L
.9718 .56448 L
.97214 .562 L
.97246 .55952 L
.97246 .55952 L
.97276 .55704 L
.97305 .55456 L
.97333 .55208 L
.9736 .5496 L
.97385 .54712 L
.97409 .54464 L
.97432 .54216 L
.97453 .53968 L
.97474 .5372 L
.97492 .53472 L
.9751 .53224 L
.97526 .52976 L
.97526 .52976 L
.97541 .52728 L
.97554 .5248 L
.97567 .52232 L
.97578 .51984 L
Mistroke
.97587 .51736 L
.97596 .51488 L
.97603 .5124 L
.97609 .50992 L
.97613 .50744 L
.97616 .50496 L
.97618 .50248 L
.97619 .5 L
.97619 .5 L
.97618 .49752 L
.97616 .49504 L
.97613 .49256 L
.97609 .49008 L
.97603 .4876 L
.97596 .48512 L
.97587 .48264 L
.97578 .48016 L
.97567 .47768 L
.97554 .4752 L
.97541 .47272 L
.97526 .47024 L
.97526 .47024 L
.9751 .46776 L
.97492 .46528 L
.97474 .4628 L
.97453 .46032 L
.97432 .45784 L
.97409 .45536 L
.97385 .45288 L
.9736 .4504 L
.97333 .44792 L
.97305 .44544 L
.97276 .44296 L
.97246 .44048 L
.97246 .44048 L
.97214 .438 L
.9718 .43552 L
.97146 .43304 L
.9711 .43056 L
.97073 .42808 L
.97034 .4256 L
.96994 .42312 L
.96953 .42063 L
.9691 .41815 L
.96866 .41567 L
.96821 .41319 L
.96775 .41071 L
.96775 .41071 L
.96726 .40823 L
.96677 .40575 L
Mistroke
.96626 .40327 L
.96574 .40079 L
.96521 .39831 L
.96466 .39583 L
.96409 .39335 L
.96352 .39087 L
.96293 .38839 L
.96232 .38591 L
.9617 .38343 L
.96107 .38095 L
.96107 .38095 L
.96042 .37847 L
.95976 .37599 L
.95908 .37351 L
.95839 .37103 L
.95769 .36855 L
.95697 .36607 L
.95623 .36359 L
.95549 .36111 L
.95472 .35863 L
.95394 .35615 L
.95315 .35367 L
.95234 .35119 L
.95234 .35119 L
.95152 .34871 L
.95068 .34623 L
.94983 .34375 L
.94896 .34127 L
.94807 .33879 L
.94717 .33631 L
.94626 .33383 L
.94532 .33135 L
.94438 .32887 L
.94341 .32639 L
.94244 .32391 L
.94144 .32143 L
.94144 .32143 L
.94043 .31895 L
.9394 .31647 L
.93836 .31399 L
.9373 .31151 L
.93622 .30903 L
.93512 .30655 L
.93401 .30407 L
.93289 .30159 L
.93174 .29911 L
.93058 .29663 L
.9294 .29415 L
.9282 .29167 L
.9282 .29167 L
Mistroke
.92698 .28919 L
.92575 .28671 L
.9245 .28423 L
.92323 .28175 L
.92194 .27927 L
.92063 .27679 L
.91931 .27431 L
.91796 .27183 L
.9166 .26935 L
.91522 .26687 L
.91382 .26439 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
.91239 .2619 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{133, 133},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 132}, {132, 0}} -> {-26.2503, -26.2503, 0.397732, \
0.397732}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->TopView,AspectRatio->1];", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0253968 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.02381 .10317 L
.02381 .18254 L
.02381 .2619 L
.02381 .34127 L
.02381 .42063 L
.02381 .5 L
.02381 .57937 L
.02381 .65873 L
.02381 .7381 L
.02381 .81746 L
.02381 .89683 L
.02381 .97619 L
.02381 .97619 L
.02381 .89683 L
.02381 .81746 L
.02381 .7381 L
.02381 .65873 L
.02381 .57937 L
.02381 .5 L
.02381 .42063 L
.02381 .34127 L
.02381 .2619 L
.02381 .18254 L
.02381 .10317 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .5 m
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5 L
s
.02381 .97619 m
.02381 .97212 L
.02381 .95996 L
.02381 .93994 L
.02381 .91239 L
.02381 .87779 L
.02381 .83672 L
.02381 .78989 L
.02381 .7381 L
.02381 .68223 L
.02381 .62325 L
.02381 .56216 L
.02381 .5 L
.02381 .43784 L
.02381 .37675 L
.02381 .31777 L
.02381 .2619 L
.02381 .21011 L
.02381 .16328 L
.02381 .12221 L
.02381 .08761 L
.02381 .06006 L
.02381 .04004 L
.02381 .02788 L
.02381 .02381 L
.02381 .02788 L
.02381 .04004 L
.02381 .06006 L
.02381 .08761 L
.02381 .12221 L
.02381 .16328 L
.02381 .21011 L
.02381 .2619 L
.02381 .31777 L
.02381 .37675 L
.02381 .43784 L
.02381 .5 L
.02381 .56216 L
.02381 .62325 L
.02381 .68223 L
.02381 .7381 L
.02381 .78989 L
.02381 .83672 L
.02381 .87779 L
.02381 .91239 L
.02381 .93994 L
.02381 .95996 L
.02381 .97212 L
.02381 .97619 L
s
.97619 .5 m
.52723 .08761 L
.4858 .1011 L
.44569 .1158 L
.40692 .13174 L
.36952 .14894 L
.33354 .16743 L
.29903 .18728 L
.26608 .20856 L
.23479 .23137 L
.2053 .25583 L
.17779 .28211 L
.1525 .31043 L
.12975 .34109 L
.11002 .37451 L
.09398 .41133 L
.08274 .45255 L
.07828 .5 L
.08274 .54745 L
.09398 .58867 L
.11002 .62549 L
.12975 .65891 L
.1525 .68957 L
.17779 .71789 L
.2053 .74417 L
.23479 .76863 L
.26608 .79144 L
.29903 .81272 L
.33354 .83257 L
.36952 .85106 L
.40692 .86826 L
.44569 .8842 L
.4858 .8989 L
.52723 .91239 L
.97619 .5 L
s
.97619 .5 m
.52723 .5 L
.4858 .47423 L
.44569 .44845 L
.40692 .42268 L
.36952 .3969 L
.33354 .37113 L
.29903 .34535 L
.26608 .31958 L
.23479 .2938 L
.2053 .26803 L
.17779 .24225 L
.1525 .21648 L
.12975 .19071 L
.11002 .16493 L
.09398 .13916 L
.08274 .11338 L
.07828 .08761 L
.08274 .06594 L
.09398 .05048 L
.11002 .03944 L
.12975 .03179 L
.1525 .02691 L
.17779 .02437 L
.2053 .02386 L
.23479 .02518 L
.26608 .02814 L
.29903 .03264 L
.33354 .03856 L
.36952 .04584 L
.40692 .05442 L
.44569 .06426 L
.4858 .07532 L
.52723 .08761 L
.97619 .5 L
s
.97619 .5 m
.52723 .91239 L
.4858 .92468 L
.44569 .93574 L
.40692 .94558 L
.36952 .95416 L
.33354 .96144 L
.29903 .96736 L
.26608 .97186 L
.23479 .97482 L
.2053 .97614 L
.17779 .97563 L
.1525 .97309 L
.12975 .96821 L
.11002 .96056 L
.09398 .94952 L
.08274 .93406 L
.07828 .91239 L
.08274 .88662 L
.09398 .86084 L
.11002 .83507 L
.12975 .80929 L
.1525 .78352 L
.17779 .75775 L
.2053 .73197 L
.23479 .7062 L
.26608 .68042 L
.29903 .65465 L
.33354 .62887 L
.36952 .6031 L
.40692 .57732 L
.44569 .55155 L
.4858 .52577 L
.52723 .5 L
.97619 .5 L
s
.02381 .65081 m
.02381 .6392 L
.02381 .62744 L
.02381 .61551 L
.02381 .60341 L
.02381 .59114 L
.02381 .5787 L
.02381 .56607 L
.02381 .55326 L
.02381 .54026 L
.02381 .52705 L
.02381 .51363 L
.02381 .5 L
.02381 .5 L
.06576 .5 L
.10771 .5 L
.14967 .5 L
.19162 .5 L
.23357 .5 L
.27552 .5 L
.31747 .5 L
.35943 .5 L
.40138 .5 L
.44333 .5 L
.48528 .5 L
.52723 .5 L
.52723 .5 L
.52274 .50286 L
.51826 .50571 L
.51377 .50855 L
.50928 .51138 L
.50479 .5142 L
.5003 .51701 L
.49581 .51981 L
.49132 .5226 L
.48683 .52538 L
.48234 .52816 L
.47785 .53092 L
.47336 .53368 L
.47336 .53368 L
.46922 .53642 L
.46508 .53916 L
.46094 .54189 L
.4568 .54461 L
.45266 .54732 L
.44852 .55003 L
.44438 .55272 L
.44024 .55541 L
.4361 .55809 L
.43196 .56076 L
Mistroke
.42782 .56342 L
.42368 .56607 L
.42368 .56607 L
.41986 .56872 L
.41604 .57136 L
.41221 .57399 L
.40839 .57661 L
.40457 .57922 L
.40075 .58183 L
.39693 .58442 L
.39311 .58701 L
.38928 .5896 L
.38546 .59217 L
.38164 .59474 L
.37782 .5973 L
.37782 .5973 L
.37429 .59985 L
.37077 .60239 L
.36724 .60493 L
.36371 .60746 L
.36019 .60998 L
.35666 .6125 L
.35314 .61501 L
.34961 .61751 L
.34608 .62 L
.34256 .62249 L
.33903 .62496 L
.33551 .62744 L
.33551 .62744 L
.33226 .6299 L
.32901 .63236 L
.32577 .63481 L
.32252 .63725 L
.31927 .63969 L
.31603 .64212 L
.31278 .64454 L
.30953 .64696 L
.30629 .64936 L
.30304 .65177 L
.29979 .65416 L
.29655 .65655 L
.29655 .65655 L
.29357 .65893 L
.29059 .6613 L
.28761 .66367 L
.28463 .66603 L
.28165 .66839 L
.27867 .67073 L
.27569 .67308 L
.27271 .67541 L
Mistroke
.26973 .67774 L
.26675 .68006 L
.26377 .68237 L
.26079 .68468 L
.26079 .68468 L
.25807 .68698 L
.25535 .68927 L
.25263 .69156 L
.24991 .69384 L
.24719 .69612 L
.24447 .69838 L
.24175 .70065 L
.23903 .7029 L
.23631 .70515 L
.23359 .70739 L
.23087 .70963 L
.22815 .71186 L
.22815 .71186 L
.22569 .71408 L
.22322 .71629 L
.22076 .7185 L
.21829 .72071 L
.21583 .7229 L
.21336 .72509 L
.2109 .72728 L
.20843 .72945 L
.20597 .73162 L
.2035 .73379 L
.20104 .73594 L
.19857 .7381 L
.19857 .7381 L
.19636 .74024 L
.19415 .74238 L
.19194 .74451 L
.18973 .74664 L
.18752 .74875 L
.1853 .75087 L
.18309 .75297 L
.18088 .75507 L
.17867 .75716 L
.17646 .75925 L
.17425 .76133 L
.17204 .7634 L
.17204 .7634 L
.17008 .76547 L
.16812 .76753 L
.16616 .76959 L
.16421 .77163 L
.16225 .77367 L
.16029 .77571 L
Mistroke
.15834 .77774 L
.15638 .77976 L
.15442 .78177 L
.15247 .78378 L
.15051 .78578 L
.14855 .78778 L
.14855 .78778 L
.14686 .78977 L
.14516 .79175 L
.14346 .79372 L
.14176 .79569 L
.14007 .79765 L
.13837 .79961 L
.13667 .80156 L
.13498 .8035 L
.13328 .80543 L
.13158 .80736 L
.12988 .80928 L
.12819 .8112 L
.12819 .8112 L
.12676 .8131 L
.12533 .815 L
.1239 .8169 L
.12247 .81879 L
.12104 .82067 L
.11961 .82254 L
.11818 .82441 L
.11675 .82627 L
.11532 .82812 L
.11389 .82996 L
.11246 .8318 L
.11103 .83363 L
.11103 .83363 L
.10988 .83546 L
.10873 .83727 L
.10758 .83908 L
.10643 .84089 L
.10527 .84268 L
.10412 .84447 L
.10297 .84625 L
.10182 .84802 L
.10067 .84979 L
.09952 .85155 L
.09837 .8533 L
.09722 .85504 L
.09722 .85504 L
.09637 .85678 L
.09551 .85851 L
.09466 .86023 L
.0938 .86194 L
Mistroke
.09295 .86365 L
.09209 .86535 L
.09124 .86704 L
.09038 .86872 L
.08953 .87039 L
.08867 .87206 L
.08782 .87372 L
.08696 .87537 L
.08696 .87537 L
.08643 .87701 L
.08589 .87864 L
.08535 .88027 L
.08482 .88189 L
.08428 .8835 L
.08374 .8851 L
.08321 .88669 L
.08267 .88827 L
.08213 .88985 L
.0816 .89141 L
.08106 .89297 L
.08053 .89452 L
.08053 .89452 L
.08034 .89606 L
.08015 .89759 L
.07996 .89911 L
.07978 .90063 L
.07959 .90213 L
.0794 .90363 L
.07921 .90511 L
.07903 .90659 L
.07884 .90805 L
.07865 .90951 L
.07846 .91096 L
.07828 .91239 L
.07828 .91239 L
.07374 .91239 L
.0692 .91239 L
.06466 .91239 L
.06012 .91239 L
.05558 .91239 L
.05104 .91239 L
.0465 .91239 L
.04197 .91239 L
.03743 .91239 L
.03289 .91239 L
.02835 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .90063 L
.02381 .88827 L
Mistroke
.02381 .87537 L
.02381 .86194 L
.02381 .84802 L
.02381 .83363 L
.02381 .81879 L
.02381 .8035 L
.02381 .78778 L
.02381 .77163 L
.02381 .75507 L
.02381 .7381 L
.02381 .7381 L
.02381 .73427 L
.02381 .73042 L
.02381 .72655 L
.02381 .72266 L
.02381 .71875 L
.02381 .71482 L
.02381 .71087 L
.02381 .70689 L
.02381 .7029 L
.02381 .69889 L
.02381 .69485 L
.02381 .6908 L
.02381 .6908 L
.02381 .69029 L
.02381 .68978 L
.02381 .68927 L
.02381 .68876 L
.02381 .68825 L
.02381 .68774 L
.02381 .68723 L
.02381 .68672 L
.02381 .68621 L
.02381 .6857 L
.02381 .68519 L
.02381 .68468 L
.02381 .68468 L
.02381 .68402 L
.02381 .68336 L
.02381 .6827 L
.02381 .68204 L
.02381 .68138 L
.02381 .68072 L
.02381 .68006 L
.02381 .67939 L
.02381 .67873 L
.02381 .67807 L
.02381 .6774 L
.02381 .67674 L
.02381 .67674 L
Mistroke
.02381 .67585 L
.02381 .67497 L
.02381 .67408 L
.02381 .67319 L
.02381 .6723 L
.02381 .6714 L
.02381 .67051 L
.02381 .66962 L
.02381 .66872 L
.02381 .66783 L
.02381 .66693 L
.02381 .66603 L
.02381 .66603 L
.02381 .66477 L
.02381 .66351 L
.02381 .66225 L
.02381 .66099 L
.02381 .65972 L
.02381 .65845 L
.02381 .65718 L
.02381 .65591 L
.02381 .65464 L
.02381 .65336 L
.02381 .65209 L
.02381 .65081 L
Mfstroke
.02381 .5 m
.02381 .48637 L
.02381 .47295 L
.02381 .45974 L
.02381 .44674 L
.02381 .43393 L
.02381 .4213 L
.02381 .40886 L
.02381 .39659 L
.02381 .38449 L
.02381 .37256 L
.02381 .3608 L
.02381 .34919 L
.02381 .34919 L
.02381 .34791 L
.02381 .34664 L
.02381 .34536 L
.02381 .34409 L
.02381 .34282 L
.02381 .34155 L
.02381 .34028 L
.02381 .33901 L
.02381 .33775 L
.02381 .33649 L
.02381 .33523 L
.02381 .33397 L
.02381 .33397 L
.02381 .33307 L
.02381 .33217 L
.02381 .33128 L
.02381 .33038 L
.02381 .32949 L
.02381 .3286 L
.02381 .3277 L
.02381 .32681 L
.02381 .32592 L
.02381 .32503 L
.02381 .32415 L
.02381 .32326 L
.02381 .32326 L
.02381 .3226 L
.02381 .32193 L
.02381 .32127 L
.02381 .32061 L
.02381 .31994 L
.02381 .31928 L
.02381 .31862 L
.02381 .31796 L
.02381 .3173 L
.02381 .31664 L
Mistroke
.02381 .31598 L
.02381 .31532 L
.02381 .31532 L
.02381 .31481 L
.02381 .3143 L
.02381 .31379 L
.02381 .31328 L
.02381 .31277 L
.02381 .31226 L
.02381 .31175 L
.02381 .31124 L
.02381 .31073 L
.02381 .31022 L
.02381 .30971 L
.02381 .3092 L
.02381 .3092 L
.02381 .30515 L
.02381 .30111 L
.02381 .2971 L
.02381 .29311 L
.02381 .28913 L
.02381 .28518 L
.02381 .28125 L
.02381 .27734 L
.02381 .27345 L
.02381 .26958 L
.02381 .26573 L
.02381 .2619 L
.02381 .2619 L
.02381 .24493 L
.02381 .22837 L
.02381 .21222 L
.02381 .1965 L
.02381 .18121 L
.02381 .16637 L
.02381 .15198 L
.02381 .13806 L
.02381 .12463 L
.02381 .11173 L
.02381 .09937 L
.02381 .08761 L
.02381 .08761 L
.02835 .08761 L
.03289 .08761 L
.03743 .08761 L
.04197 .08761 L
.0465 .08761 L
.05104 .08761 L
.05558 .08761 L
.06012 .08761 L
Mistroke
.06466 .08761 L
.0692 .08761 L
.07374 .08761 L
.07828 .08761 L
.07828 .08761 L
.07846 .08904 L
.07865 .09049 L
.07884 .09195 L
.07903 .09341 L
.07921 .09489 L
.0794 .09637 L
.07959 .09787 L
.07978 .09937 L
.07996 .10089 L
.08015 .10241 L
.08034 .10394 L
.08053 .10548 L
.08053 .10548 L
.08106 .10703 L
.0816 .10859 L
.08213 .11015 L
.08267 .11173 L
.08321 .11331 L
.08374 .1149 L
.08428 .1165 L
.08482 .11811 L
.08535 .11973 L
.08589 .12136 L
.08643 .12299 L
.08696 .12463 L
.08696 .12463 L
.08782 .12628 L
.08867 .12794 L
.08953 .12961 L
.09038 .13128 L
.09124 .13296 L
.09209 .13465 L
.09295 .13635 L
.0938 .13806 L
.09466 .13977 L
.09551 .14149 L
.09637 .14322 L
.09722 .14496 L
.09722 .14496 L
.09837 .1467 L
.09952 .14845 L
.10067 .15021 L
.10182 .15198 L
.10297 .15375 L
.10412 .15553 L
Mistroke
.10527 .15732 L
.10643 .15911 L
.10758 .16092 L
.10873 .16273 L
.10988 .16454 L
.11103 .16637 L
.11103 .16637 L
.11246 .1682 L
.11389 .17004 L
.11532 .17188 L
.11675 .17373 L
.11818 .17559 L
.11961 .17746 L
.12104 .17933 L
.12247 .18121 L
.1239 .1831 L
.12533 .185 L
.12676 .1869 L
.12819 .1888 L
.12819 .1888 L
.12988 .19072 L
.13158 .19264 L
.13328 .19457 L
.13498 .1965 L
.13667 .19844 L
.13837 .20039 L
.14007 .20235 L
.14176 .20431 L
.14346 .20628 L
.14516 .20825 L
.14686 .21023 L
.14855 .21222 L
.14855 .21222 L
.15051 .21422 L
.15247 .21622 L
.15442 .21823 L
.15638 .22024 L
.15834 .22226 L
.16029 .22429 L
.16225 .22633 L
.16421 .22837 L
.16616 .23041 L
.16812 .23247 L
.17008 .23453 L
.17204 .2366 L
.17204 .2366 L
.17425 .23867 L
.17646 .24075 L
.17867 .24284 L
.18088 .24493 L
Mistroke
.18309 .24703 L
.1853 .24913 L
.18752 .25125 L
.18973 .25336 L
.19194 .25549 L
.19415 .25762 L
.19636 .25976 L
.19857 .2619 L
.19857 .2619 L
.20104 .26406 L
.2035 .26621 L
.20597 .26838 L
.20843 .27055 L
.2109 .27272 L
.21336 .27491 L
.21583 .2771 L
.21829 .27929 L
.22076 .2815 L
.22322 .28371 L
.22569 .28592 L
.22815 .28814 L
.22815 .28814 L
.23087 .29037 L
.23359 .29261 L
.23631 .29485 L
.23903 .2971 L
.24175 .29935 L
.24447 .30162 L
.24719 .30388 L
.24991 .30616 L
.25263 .30844 L
.25535 .31073 L
.25807 .31302 L
.26079 .31532 L
.26079 .31532 L
.26377 .31763 L
.26675 .31994 L
.26973 .32226 L
.27271 .32459 L
.27569 .32692 L
.27867 .32927 L
.28165 .33161 L
.28463 .33397 L
.28761 .33633 L
.29059 .3387 L
.29357 .34107 L
.29655 .34345 L
.29655 .34345 L
.29979 .34584 L
.30304 .34823 L
Mistroke
.30629 .35064 L
.30953 .35304 L
.31278 .35546 L
.31603 .35788 L
.31927 .36031 L
.32252 .36275 L
.32577 .36519 L
.32901 .36764 L
.33226 .3701 L
.33551 .37256 L
.33551 .37256 L
.33903 .37504 L
.34256 .37751 L
.34608 .38 L
.34961 .38249 L
.35314 .38499 L
.35666 .3875 L
.36019 .39002 L
.36371 .39254 L
.36724 .39507 L
.37077 .39761 L
.37429 .40015 L
.37782 .4027 L
.37782 .4027 L
.38164 .40526 L
.38546 .40783 L
.38928 .4104 L
.39311 .41299 L
.39693 .41558 L
.40075 .41817 L
.40457 .42078 L
.40839 .42339 L
.41221 .42601 L
.41604 .42864 L
.41986 .43128 L
.42368 .43393 L
.42368 .43393 L
.42782 .43658 L
.43196 .43924 L
.4361 .44191 L
.44024 .44459 L
.44438 .44728 L
.44852 .44997 L
.45266 .45268 L
.4568 .45539 L
.46094 .45811 L
.46508 .46084 L
.46922 .46358 L
.47336 .46632 L
.47336 .46632 L
Mistroke
.47785 .46908 L
.48234 .47184 L
.48683 .47462 L
.49132 .4774 L
.49581 .48019 L
.5003 .48299 L
.50479 .4858 L
.50928 .48862 L
.51377 .49145 L
.51826 .49429 L
.52274 .49714 L
.52723 .5 L
.52723 .5 L
.48528 .5 L
.44333 .5 L
.40138 .5 L
.35943 .5 L
.31747 .5 L
.27552 .5 L
.23357 .5 L
.19162 .5 L
.14967 .5 L
.10771 .5 L
.06576 .5 L
.02381 .5 L
Mfstroke
.02381 .03343 m
.02381 .03602 L
.02381 .03893 L
.02381 .04217 L
.02381 .04574 L
.02381 .04966 L
.02381 .05393 L
.02381 .05856 L
.02381 .06356 L
.02381 .06896 L
.02381 .07475 L
.02381 .08096 L
.02381 .08761 L
.02381 .08761 L
.06576 .08761 L
.10771 .08761 L
.14967 .08761 L
.19162 .08761 L
.23357 .08761 L
.27552 .08761 L
.31747 .08761 L
.35943 .08761 L
.40138 .08761 L
.44333 .08761 L
.48528 .08761 L
.52723 .08761 L
.52723 .08761 L
.52274 .08618 L
.51826 .08478 L
.51377 .0834 L
.50928 .08204 L
.50479 .08069 L
.5003 .07937 L
.49581 .07806 L
.49132 .07677 L
.48683 .0755 L
.48234 .07425 L
.47785 .07302 L
.47336 .0718 L
.47336 .0718 L
.46922 .0706 L
.46508 .06942 L
.46094 .06826 L
.4568 .06711 L
.45266 .06599 L
.44852 .06488 L
.44438 .06378 L
.44024 .0627 L
.4361 .06164 L
.43196 .0606 L
Mistroke
.42782 .05957 L
.42368 .05856 L
.42368 .05856 L
.41986 .05756 L
.41604 .05659 L
.41221 .05562 L
.40839 .05468 L
.40457 .05374 L
.40075 .05283 L
.39693 .05193 L
.39311 .05104 L
.38928 .05017 L
.38546 .04932 L
.38164 .04848 L
.37782 .04766 L
.37782 .04766 L
.37429 .04685 L
.37077 .04606 L
.36724 .04528 L
.36371 .04451 L
.36019 .04377 L
.35666 .04303 L
.35314 .04231 L
.34961 .04161 L
.34608 .04092 L
.34256 .04024 L
.33903 .03958 L
.33551 .03893 L
.33551 .03893 L
.33226 .0383 L
.32901 .03768 L
.32577 .03707 L
.32252 .03648 L
.31927 .03591 L
.31603 .03534 L
.31278 .03479 L
.30953 .03426 L
.30629 .03374 L
.30304 .03323 L
.29979 .03274 L
.29655 .03225 L
.29655 .03225 L
.29357 .03179 L
.29059 .03134 L
.28761 .0309 L
.28463 .03047 L
.28165 .03006 L
.27867 .02966 L
.27569 .02927 L
.27271 .0289 L
Mistroke
.26973 .02854 L
.26675 .0282 L
.26377 .02786 L
.26079 .02754 L
.26079 .02754 L
.25807 .02724 L
.25535 .02695 L
.25263 .02667 L
.24991 .0264 L
.24719 .02615 L
.24447 .02591 L
.24175 .02568 L
.23903 .02547 L
.23631 .02526 L
.23359 .02508 L
.23087 .0249 L
.22815 .02474 L
.22815 .02474 L
.22569 .02459 L
.22322 .02446 L
.22076 .02433 L
.21829 .02422 L
.21583 .02413 L
.21336 .02404 L
.2109 .02397 L
.20843 .02391 L
.20597 .02387 L
.2035 .02384 L
.20104 .02382 L
.19857 .02381 L
.19857 .02381 L
.19636 .02382 L
.19415 .02384 L
.19194 .02387 L
.18973 .02391 L
.18752 .02397 L
.1853 .02404 L
.18309 .02413 L
.18088 .02422 L
.17867 .02433 L
.17646 .02446 L
.17425 .02459 L
.17204 .02474 L
.17204 .02474 L
.17008 .0249 L
.16812 .02508 L
.16616 .02526 L
.16421 .02547 L
.16225 .02568 L
.16029 .02591 L
Mistroke
.15834 .02615 L
.15638 .0264 L
.15442 .02667 L
.15247 .02695 L
.15051 .02724 L
.14855 .02754 L
.14855 .02754 L
.14686 .02786 L
.14516 .0282 L
.14346 .02854 L
.14176 .0289 L
.14007 .02927 L
.13837 .02966 L
.13667 .03006 L
.13498 .03047 L
.13328 .0309 L
.13158 .03134 L
.12988 .03179 L
.12819 .03225 L
.12819 .03225 L
.12676 .03274 L
.12533 .03323 L
.1239 .03374 L
.12247 .03426 L
.12104 .03479 L
.11961 .03534 L
.11818 .03591 L
.11675 .03648 L
.11532 .03707 L
.11389 .03768 L
.11246 .0383 L
.11103 .03893 L
.11103 .03893 L
.10988 .03958 L
.10873 .04024 L
.10758 .04092 L
.10643 .04161 L
.10527 .04231 L
.10412 .04303 L
.10297 .04377 L
.10182 .04451 L
.10067 .04528 L
.09952 .04606 L
.09837 .04685 L
.09722 .04766 L
.09722 .04766 L
.09637 .04848 L
.09551 .04932 L
.09466 .05017 L
.0938 .05104 L
Mistroke
.09295 .05193 L
.09209 .05283 L
.09124 .05374 L
.09038 .05468 L
.08953 .05562 L
.08867 .05659 L
.08782 .05756 L
.08696 .05856 L
.08696 .05856 L
.08643 .05957 L
.08589 .0606 L
.08535 .06164 L
.08482 .0627 L
.08428 .06378 L
.08374 .06488 L
.08321 .06599 L
.08267 .06711 L
.08213 .06826 L
.0816 .06942 L
.08106 .0706 L
.08053 .0718 L
.08053 .0718 L
.08034 .07302 L
.08015 .07425 L
.07996 .0755 L
.07978 .07677 L
.07959 .07806 L
.0794 .07937 L
.07921 .08069 L
.07903 .08204 L
.07884 .0834 L
.07865 .08478 L
.07846 .08618 L
.07828 .08761 L
.07828 .08761 L
.07374 .08761 L
.0692 .08761 L
.06466 .08761 L
.06012 .08761 L
.05558 .08761 L
.05104 .08761 L
.0465 .08761 L
.04197 .08761 L
.03743 .08761 L
.03289 .08761 L
.02835 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .07677 L
.02381 .06711 L
Mistroke
.02381 .05856 L
.02381 .05104 L
.02381 .04451 L
.02381 .03893 L
.02381 .03426 L
.02381 .03047 L
.02381 .02754 L
.02381 .02547 L
.02381 .02422 L
.02381 .02381 L
.02381 .02381 L
.02381 .02383 L
.02381 .02389 L
.02381 .02399 L
.02381 .02414 L
.02381 .02432 L
.02381 .02454 L
.02381 .02481 L
.02381 .02512 L
.02381 .02547 L
.02381 .02586 L
.02381 .02629 L
.02381 .02676 L
.02381 .02676 L
.02381 .02682 L
.02381 .02688 L
.02381 .02695 L
.02381 .02701 L
.02381 .02707 L
.02381 .02714 L
.02381 .02721 L
.02381 .02727 L
.02381 .02734 L
.02381 .02741 L
.02381 .02748 L
.02381 .02754 L
.02381 .02754 L
.02381 .02763 L
.02381 .02773 L
.02381 .02782 L
.02381 .02791 L
.02381 .028 L
.02381 .0281 L
.02381 .0282 L
.02381 .02829 L
.02381 .02839 L
.02381 .02849 L
.02381 .02859 L
.02381 .02869 L
.02381 .02869 L
Mistroke
.02381 .02883 L
.02381 .02897 L
.02381 .02911 L
.02381 .02925 L
.02381 .0294 L
.02381 .02955 L
.02381 .0297 L
.02381 .02985 L
.02381 .03 L
.02381 .03015 L
.02381 .03031 L
.02381 .03047 L
.02381 .03047 L
.02381 .0307 L
.02381 .03092 L
.02381 .03116 L
.02381 .03139 L
.02381 .03164 L
.02381 .03188 L
.02381 .03213 L
.02381 .03238 L
.02381 .03264 L
.02381 .0329 L
.02381 .03316 L
.02381 .03343 L
Mfstroke
.02381 .08761 m
.02381 .09459 L
.02381 .1018 L
.02381 .10921 L
.02381 .11682 L
.02381 .12463 L
.02381 .13263 L
.02381 .1408 L
.02381 .14915 L
.02381 .15768 L
.02381 .16637 L
.02381 .17522 L
.02381 .18424 L
.02381 .18424 L
.02381 .18525 L
.02381 .18626 L
.02381 .18728 L
.02381 .18829 L
.02381 .18931 L
.02381 .19033 L
.02381 .19136 L
.02381 .19238 L
.02381 .19341 L
.02381 .19444 L
.02381 .19547 L
.02381 .1965 L
.02381 .1965 L
.02381 .19724 L
.02381 .19798 L
.02381 .19872 L
.02381 .19946 L
.02381 .20021 L
.02381 .20095 L
.02381 .2017 L
.02381 .20244 L
.02381 .20319 L
.02381 .20394 L
.02381 .20468 L
.02381 .20543 L
.02381 .20543 L
.02381 .206 L
.02381 .20656 L
.02381 .20712 L
.02381 .20769 L
.02381 .20825 L
.02381 .20882 L
.02381 .20938 L
.02381 .20995 L
.02381 .21052 L
.02381 .21109 L
Mistroke
.02381 .21165 L
.02381 .21222 L
.02381 .21222 L
.02381 .21267 L
.02381 .21311 L
.02381 .21355 L
.02381 .214 L
.02381 .21444 L
.02381 .21488 L
.02381 .21533 L
.02381 .21577 L
.02381 .21622 L
.02381 .21667 L
.02381 .21711 L
.02381 .21756 L
.02381 .21756 L
.02381 .22114 L
.02381 .22474 L
.02381 .22837 L
.02381 .23201 L
.02381 .23568 L
.02381 .23936 L
.02381 .24307 L
.02381 .24679 L
.02381 .25054 L
.02381 .25431 L
.02381 .2581 L
.02381 .2619 L
.02381 .2619 L
.02381 .27929 L
.02381 .2971 L
.02381 .31532 L
.02381 .33397 L
.02381 .35304 L
.02381 .37256 L
.02381 .39254 L
.02381 .41299 L
.02381 .43393 L
.02381 .45539 L
.02381 .4774 L
.02381 .5 L
.02381 .5 L
.02835 .5 L
.03289 .5 L
.03743 .5 L
.04197 .5 L
.0465 .5 L
.05104 .5 L
.05558 .5 L
.06012 .5 L
Mistroke
.06466 .5 L
.0692 .5 L
.07374 .5 L
.07828 .5 L
.07828 .5 L
.07846 .49714 L
.07865 .49429 L
.07884 .49145 L
.07903 .48862 L
.07921 .4858 L
.0794 .48299 L
.07959 .48019 L
.07978 .4774 L
.07996 .47462 L
.08015 .47184 L
.08034 .46908 L
.08053 .46632 L
.08053 .46632 L
.08106 .46358 L
.0816 .46084 L
.08213 .45811 L
.08267 .45539 L
.08321 .45268 L
.08374 .44997 L
.08428 .44728 L
.08482 .44459 L
.08535 .44191 L
.08589 .43924 L
.08643 .43658 L
.08696 .43393 L
.08696 .43393 L
.08782 .43128 L
.08867 .42864 L
.08953 .42601 L
.09038 .42339 L
.09124 .42078 L
.09209 .41817 L
.09295 .41558 L
.0938 .41299 L
.09466 .4104 L
.09551 .40783 L
.09637 .40526 L
.09722 .4027 L
.09722 .4027 L
.09837 .40015 L
.09952 .39761 L
.10067 .39507 L
.10182 .39254 L
.10297 .39002 L
.10412 .3875 L
Mistroke
.10527 .38499 L
.10643 .38249 L
.10758 .38 L
.10873 .37751 L
.10988 .37504 L
.11103 .37256 L
.11103 .37256 L
.11246 .3701 L
.11389 .36764 L
.11532 .36519 L
.11675 .36275 L
.11818 .36031 L
.11961 .35788 L
.12104 .35546 L
.12247 .35304 L
.1239 .35064 L
.12533 .34823 L
.12676 .34584 L
.12819 .34345 L
.12819 .34345 L
.12988 .34107 L
.13158 .3387 L
.13328 .33633 L
.13498 .33397 L
.13667 .33161 L
.13837 .32927 L
.14007 .32692 L
.14176 .32459 L
.14346 .32226 L
.14516 .31994 L
.14686 .31763 L
.14855 .31532 L
.14855 .31532 L
.15051 .31302 L
.15247 .31073 L
.15442 .30844 L
.15638 .30616 L
.15834 .30388 L
.16029 .30162 L
.16225 .29935 L
.16421 .2971 L
.16616 .29485 L
.16812 .29261 L
.17008 .29037 L
.17204 .28814 L
.17204 .28814 L
.17425 .28592 L
.17646 .28371 L
.17867 .2815 L
.18088 .27929 L
Mistroke
.18309 .2771 L
.1853 .27491 L
.18752 .27272 L
.18973 .27055 L
.19194 .26838 L
.19415 .26621 L
.19636 .26406 L
.19857 .2619 L
.19857 .2619 L
.20104 .25976 L
.2035 .25762 L
.20597 .25549 L
.20843 .25336 L
.2109 .25125 L
.21336 .24913 L
.21583 .24703 L
.21829 .24493 L
.22076 .24284 L
.22322 .24075 L
.22569 .23867 L
.22815 .2366 L
.22815 .2366 L
.23087 .23453 L
.23359 .23247 L
.23631 .23041 L
.23903 .22837 L
.24175 .22633 L
.24447 .22429 L
.24719 .22226 L
.24991 .22024 L
.25263 .21823 L
.25535 .21622 L
.25807 .21422 L
.26079 .21222 L
.26079 .21222 L
.26377 .21023 L
.26675 .20825 L
.26973 .20628 L
.27271 .20431 L
.27569 .20235 L
.27867 .20039 L
.28165 .19844 L
.28463 .1965 L
.28761 .19457 L
.29059 .19264 L
.29357 .19072 L
.29655 .1888 L
.29655 .1888 L
.29979 .1869 L
.30304 .185 L
Mistroke
.30629 .1831 L
.30953 .18121 L
.31278 .17933 L
.31603 .17746 L
.31927 .17559 L
.32252 .17373 L
.32577 .17188 L
.32901 .17004 L
.33226 .1682 L
.33551 .16637 L
.33551 .16637 L
.33903 .16454 L
.34256 .16273 L
.34608 .16092 L
.34961 .15911 L
.35314 .15732 L
.35666 .15553 L
.36019 .15375 L
.36371 .15198 L
.36724 .15021 L
.37077 .14845 L
.37429 .1467 L
.37782 .14496 L
.37782 .14496 L
.38164 .14322 L
.38546 .14149 L
.38928 .13977 L
.39311 .13806 L
.39693 .13635 L
.40075 .13465 L
.40457 .13296 L
.40839 .13128 L
.41221 .12961 L
.41604 .12794 L
.41986 .12628 L
.42368 .12463 L
.42368 .12463 L
.42782 .12299 L
.43196 .12136 L
.4361 .11973 L
.44024 .11811 L
.44438 .1165 L
.44852 .1149 L
.45266 .11331 L
.4568 .11173 L
.46094 .11015 L
.46508 .10859 L
.46922 .10703 L
.47336 .10548 L
.47336 .10548 L
Mistroke
.47785 .10394 L
.48234 .10241 L
.48683 .10089 L
.49132 .09937 L
.49581 .09787 L
.5003 .09637 L
.50479 .09489 L
.50928 .09341 L
.51377 .09195 L
.51826 .09049 L
.52274 .08904 L
.52723 .08761 L
.52723 .08761 L
.48528 .08761 L
.44333 .08761 L
.40138 .08761 L
.35943 .08761 L
.31747 .08761 L
.27552 .08761 L
.23357 .08761 L
.19162 .08761 L
.14967 .08761 L
.10771 .08761 L
.06576 .08761 L
.02381 .08761 L
Mfstroke
.02381 .81576 m
.02381 .82478 L
.02381 .83363 L
.02381 .84232 L
.02381 .85085 L
.02381 .8592 L
.02381 .86737 L
.02381 .87537 L
.02381 .88318 L
.02381 .89079 L
.02381 .8982 L
.02381 .90541 L
.02381 .91239 L
.02381 .91239 L
.06576 .91239 L
.10771 .91239 L
.14967 .91239 L
.19162 .91239 L
.23357 .91239 L
.27552 .91239 L
.31747 .91239 L
.35943 .91239 L
.40138 .91239 L
.44333 .91239 L
.48528 .91239 L
.52723 .91239 L
.52723 .91239 L
.52274 .91096 L
.51826 .90951 L
.51377 .90805 L
.50928 .90659 L
.50479 .90511 L
.5003 .90363 L
.49581 .90213 L
.49132 .90063 L
.48683 .89911 L
.48234 .89759 L
.47785 .89606 L
.47336 .89452 L
.47336 .89452 L
.46922 .89297 L
.46508 .89141 L
.46094 .88985 L
.4568 .88827 L
.45266 .88669 L
.44852 .8851 L
.44438 .8835 L
.44024 .88189 L
.4361 .88027 L
.43196 .87864 L
Mistroke
.42782 .87701 L
.42368 .87537 L
.42368 .87537 L
.41986 .87372 L
.41604 .87206 L
.41221 .87039 L
.40839 .86872 L
.40457 .86704 L
.40075 .86535 L
.39693 .86365 L
.39311 .86194 L
.38928 .86023 L
.38546 .85851 L
.38164 .85678 L
.37782 .85504 L
.37782 .85504 L
.37429 .8533 L
.37077 .85155 L
.36724 .84979 L
.36371 .84802 L
.36019 .84625 L
.35666 .84447 L
.35314 .84268 L
.34961 .84089 L
.34608 .83908 L
.34256 .83727 L
.33903 .83546 L
.33551 .83363 L
.33551 .83363 L
.33226 .8318 L
.32901 .82996 L
.32577 .82812 L
.32252 .82627 L
.31927 .82441 L
.31603 .82254 L
.31278 .82067 L
.30953 .81879 L
.30629 .8169 L
.30304 .815 L
.29979 .8131 L
.29655 .8112 L
.29655 .8112 L
.29357 .80928 L
.29059 .80736 L
.28761 .80543 L
.28463 .8035 L
.28165 .80156 L
.27867 .79961 L
.27569 .79765 L
.27271 .79569 L
Mistroke
.26973 .79372 L
.26675 .79175 L
.26377 .78977 L
.26079 .78778 L
.26079 .78778 L
.25807 .78578 L
.25535 .78378 L
.25263 .78177 L
.24991 .77976 L
.24719 .77774 L
.24447 .77571 L
.24175 .77367 L
.23903 .77163 L
.23631 .76959 L
.23359 .76753 L
.23087 .76547 L
.22815 .7634 L
.22815 .7634 L
.22569 .76133 L
.22322 .75925 L
.22076 .75716 L
.21829 .75507 L
.21583 .75297 L
.21336 .75087 L
.2109 .74875 L
.20843 .74664 L
.20597 .74451 L
.2035 .74238 L
.20104 .74024 L
.19857 .7381 L
.19857 .7381 L
.19636 .73594 L
.19415 .73379 L
.19194 .73162 L
.18973 .72945 L
.18752 .72728 L
.1853 .72509 L
.18309 .7229 L
.18088 .72071 L
.17867 .7185 L
.17646 .71629 L
.17425 .71408 L
.17204 .71186 L
.17204 .71186 L
.17008 .70963 L
.16812 .70739 L
.16616 .70515 L
.16421 .7029 L
.16225 .70065 L
.16029 .69838 L
Mistroke
.15834 .69612 L
.15638 .69384 L
.15442 .69156 L
.15247 .68927 L
.15051 .68698 L
.14855 .68468 L
.14855 .68468 L
.14686 .68237 L
.14516 .68006 L
.14346 .67774 L
.14176 .67541 L
.14007 .67308 L
.13837 .67073 L
.13667 .66839 L
.13498 .66603 L
.13328 .66367 L
.13158 .6613 L
.12988 .65893 L
.12819 .65655 L
.12819 .65655 L
.12676 .65416 L
.12533 .65177 L
.1239 .64936 L
.12247 .64696 L
.12104 .64454 L
.11961 .64212 L
.11818 .63969 L
.11675 .63725 L
.11532 .63481 L
.11389 .63236 L
.11246 .6299 L
.11103 .62744 L
.11103 .62744 L
.10988 .62496 L
.10873 .62249 L
.10758 .62 L
.10643 .61751 L
.10527 .61501 L
.10412 .6125 L
.10297 .60998 L
.10182 .60746 L
.10067 .60493 L
.09952 .60239 L
.09837 .59985 L
.09722 .5973 L
.09722 .5973 L
.09637 .59474 L
.09551 .59217 L
.09466 .5896 L
.0938 .58701 L
Mistroke
.09295 .58442 L
.09209 .58183 L
.09124 .57922 L
.09038 .57661 L
.08953 .57399 L
.08867 .57136 L
.08782 .56872 L
.08696 .56607 L
.08696 .56607 L
.08643 .56342 L
.08589 .56076 L
.08535 .55809 L
.08482 .55541 L
.08428 .55272 L
.08374 .55003 L
.08321 .54732 L
.08267 .54461 L
.08213 .54189 L
.0816 .53916 L
.08106 .53642 L
.08053 .53368 L
.08053 .53368 L
.08034 .53092 L
.08015 .52816 L
.07996 .52538 L
.07978 .5226 L
.07959 .51981 L
.0794 .51701 L
.07921 .5142 L
.07903 .51138 L
.07884 .50855 L
.07865 .50571 L
.07846 .50286 L
.07828 .5 L
.07828 .5 L
.07374 .5 L
.0692 .5 L
.06466 .5 L
.06012 .5 L
.05558 .5 L
.05104 .5 L
.0465 .5 L
.04197 .5 L
.03743 .5 L
.03289 .5 L
.02835 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5226 L
.02381 .54461 L
Mistroke
.02381 .56607 L
.02381 .58701 L
.02381 .60746 L
.02381 .62744 L
.02381 .64696 L
.02381 .66603 L
.02381 .68468 L
.02381 .7029 L
.02381 .72071 L
.02381 .7381 L
.02381 .7381 L
.02381 .7419 L
.02381 .74569 L
.02381 .74946 L
.02381 .75321 L
.02381 .75693 L
.02381 .76064 L
.02381 .76432 L
.02381 .76799 L
.02381 .77163 L
.02381 .77526 L
.02381 .77886 L
.02381 .78244 L
.02381 .78244 L
.02381 .78289 L
.02381 .78333 L
.02381 .78378 L
.02381 .78423 L
.02381 .78467 L
.02381 .78512 L
.02381 .78556 L
.02381 .786 L
.02381 .78645 L
.02381 .78689 L
.02381 .78733 L
.02381 .78778 L
.02381 .78778 L
.02381 .78835 L
.02381 .78891 L
.02381 .78948 L
.02381 .79005 L
.02381 .79062 L
.02381 .79118 L
.02381 .79175 L
.02381 .79231 L
.02381 .79288 L
.02381 .79344 L
.02381 .794 L
.02381 .79457 L
.02381 .79457 L
Mistroke
.02381 .79532 L
.02381 .79606 L
.02381 .79681 L
.02381 .79756 L
.02381 .7983 L
.02381 .79905 L
.02381 .79979 L
.02381 .80054 L
.02381 .80128 L
.02381 .80202 L
.02381 .80276 L
.02381 .8035 L
.02381 .8035 L
.02381 .80453 L
.02381 .80556 L
.02381 .80659 L
.02381 .80762 L
.02381 .80864 L
.02381 .80967 L
.02381 .81069 L
.02381 .81171 L
.02381 .81272 L
.02381 .81374 L
.02381 .81475 L
.02381 .81576 L
Mfstroke
.02381 .91239 m
.02381 .91904 L
.02381 .92525 L
.02381 .93104 L
.02381 .93644 L
.02381 .94144 L
.02381 .94607 L
.02381 .95034 L
.02381 .95426 L
.02381 .95783 L
.02381 .96107 L
.02381 .96398 L
.02381 .96657 L
.02381 .96657 L
.02381 .96684 L
.02381 .9671 L
.02381 .96736 L
.02381 .96762 L
.02381 .96787 L
.02381 .96812 L
.02381 .96836 L
.02381 .96861 L
.02381 .96884 L
.02381 .96908 L
.02381 .9693 L
.02381 .96953 L
.02381 .96953 L
.02381 .96969 L
.02381 .96985 L
.02381 .97 L
.02381 .97015 L
.02381 .9703 L
.02381 .97045 L
.02381 .9706 L
.02381 .97075 L
.02381 .97089 L
.02381 .97103 L
.02381 .97117 L
.02381 .97131 L
.02381 .97131 L
.02381 .97141 L
.02381 .97151 L
.02381 .97161 L
.02381 .97171 L
.02381 .9718 L
.02381 .9719 L
.02381 .972 L
.02381 .97209 L
.02381 .97218 L
.02381 .97227 L
Mistroke
.02381 .97237 L
.02381 .97246 L
.02381 .97246 L
.02381 .97252 L
.02381 .97259 L
.02381 .97266 L
.02381 .97273 L
.02381 .97279 L
.02381 .97286 L
.02381 .97293 L
.02381 .97299 L
.02381 .97305 L
.02381 .97312 L
.02381 .97318 L
.02381 .97324 L
.02381 .97324 L
.02381 .97371 L
.02381 .97414 L
.02381 .97453 L
.02381 .97488 L
.02381 .97519 L
.02381 .97546 L
.02381 .97568 L
.02381 .97586 L
.02381 .97601 L
.02381 .97611 L
.02381 .97617 L
.02381 .97619 L
.02381 .97619 L
.02381 .97578 L
.02381 .97453 L
.02381 .97246 L
.02381 .96953 L
.02381 .96574 L
.02381 .96107 L
.02381 .95549 L
.02381 .94896 L
.02381 .94144 L
.02381 .93289 L
.02381 .92323 L
.02381 .91239 L
.02381 .91239 L
.02835 .91239 L
.03289 .91239 L
.03743 .91239 L
.04197 .91239 L
.0465 .91239 L
.05104 .91239 L
.05558 .91239 L
.06012 .91239 L
Mistroke
.06466 .91239 L
.0692 .91239 L
.07374 .91239 L
.07828 .91239 L
.07828 .91239 L
.07846 .91382 L
.07865 .91522 L
.07884 .9166 L
.07903 .91796 L
.07921 .91931 L
.0794 .92063 L
.07959 .92194 L
.07978 .92323 L
.07996 .9245 L
.08015 .92575 L
.08034 .92698 L
.08053 .9282 L
.08053 .9282 L
.08106 .9294 L
.0816 .93058 L
.08213 .93174 L
.08267 .93289 L
.08321 .93401 L
.08374 .93512 L
.08428 .93622 L
.08482 .9373 L
.08535 .93836 L
.08589 .9394 L
.08643 .94043 L
.08696 .94144 L
.08696 .94144 L
.08782 .94244 L
.08867 .94341 L
.08953 .94438 L
.09038 .94532 L
.09124 .94626 L
.09209 .94717 L
.09295 .94807 L
.0938 .94896 L
.09466 .94983 L
.09551 .95068 L
.09637 .95152 L
.09722 .95234 L
.09722 .95234 L
.09837 .95315 L
.09952 .95394 L
.10067 .95472 L
.10182 .95549 L
.10297 .95623 L
.10412 .95697 L
Mistroke
.10527 .95769 L
.10643 .95839 L
.10758 .95908 L
.10873 .95976 L
.10988 .96042 L
.11103 .96107 L
.11103 .96107 L
.11246 .9617 L
.11389 .96232 L
.11532 .96293 L
.11675 .96352 L
.11818 .96409 L
.11961 .96466 L
.12104 .96521 L
.12247 .96574 L
.1239 .96626 L
.12533 .96677 L
.12676 .96726 L
.12819 .96775 L
.12819 .96775 L
.12988 .96821 L
.13158 .96866 L
.13328 .9691 L
.13498 .96953 L
.13667 .96994 L
.13837 .97034 L
.14007 .97073 L
.14176 .9711 L
.14346 .97146 L
.14516 .9718 L
.14686 .97214 L
.14855 .97246 L
.14855 .97246 L
.15051 .97276 L
.15247 .97305 L
.15442 .97333 L
.15638 .9736 L
.15834 .97385 L
.16029 .97409 L
.16225 .97432 L
.16421 .97453 L
.16616 .97474 L
.16812 .97492 L
.17008 .9751 L
.17204 .97526 L
.17204 .97526 L
.17425 .97541 L
.17646 .97554 L
.17867 .97567 L
.18088 .97578 L
Mistroke
.18309 .97587 L
.1853 .97596 L
.18752 .97603 L
.18973 .97609 L
.19194 .97613 L
.19415 .97616 L
.19636 .97618 L
.19857 .97619 L
.19857 .97619 L
.20104 .97618 L
.2035 .97616 L
.20597 .97613 L
.20843 .97609 L
.2109 .97603 L
.21336 .97596 L
.21583 .97587 L
.21829 .97578 L
.22076 .97567 L
.22322 .97554 L
.22569 .97541 L
.22815 .97526 L
.22815 .97526 L
.23087 .9751 L
.23359 .97492 L
.23631 .97474 L
.23903 .97453 L
.24175 .97432 L
.24447 .97409 L
.24719 .97385 L
.24991 .9736 L
.25263 .97333 L
.25535 .97305 L
.25807 .97276 L
.26079 .97246 L
.26079 .97246 L
.26377 .97214 L
.26675 .9718 L
.26973 .97146 L
.27271 .9711 L
.27569 .97073 L
.27867 .97034 L
.28165 .96994 L
.28463 .96953 L
.28761 .9691 L
.29059 .96866 L
.29357 .96821 L
.29655 .96775 L
.29655 .96775 L
.29979 .96726 L
.30304 .96677 L
Mistroke
.30629 .96626 L
.30953 .96574 L
.31278 .96521 L
.31603 .96466 L
.31927 .96409 L
.32252 .96352 L
.32577 .96293 L
.32901 .96232 L
.33226 .9617 L
.33551 .96107 L
.33551 .96107 L
.33903 .96042 L
.34256 .95976 L
.34608 .95908 L
.34961 .95839 L
.35314 .95769 L
.35666 .95697 L
.36019 .95623 L
.36371 .95549 L
.36724 .95472 L
.37077 .95394 L
.37429 .95315 L
.37782 .95234 L
.37782 .95234 L
.38164 .95152 L
.38546 .95068 L
.38928 .94983 L
.39311 .94896 L
.39693 .94807 L
.40075 .94717 L
.40457 .94626 L
.40839 .94532 L
.41221 .94438 L
.41604 .94341 L
.41986 .94244 L
.42368 .94144 L
.42368 .94144 L
.42782 .94043 L
.43196 .9394 L
.4361 .93836 L
.44024 .9373 L
.44438 .93622 L
.44852 .93512 L
.45266 .93401 L
.4568 .93289 L
.46094 .93174 L
.46508 .93058 L
.46922 .9294 L
.47336 .9282 L
.47336 .9282 L
Mistroke
.47785 .92698 L
.48234 .92575 L
.48683 .9245 L
.49132 .92323 L
.49581 .92194 L
.5003 .92063 L
.50479 .91931 L
.50928 .91796 L
.51377 .9166 L
.51826 .91522 L
.52274 .91382 L
.52723 .91239 L
.52723 .91239 L
.48528 .91239 L
.44333 .91239 L
.40138 .91239 L
.35943 .91239 L
.31747 .91239 L
.27552 .91239 L
.23357 .91239 L
.19162 .91239 L
.14967 .91239 L
.10771 .91239 L
.06576 .91239 L
.02381 .91239 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{134, 134},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 133}, {133, 0}} -> {-0.937697, -26.2503, 0.296056, \
0.394741}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,AspectRatio->1];", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.120053 1.30829 -1.11022e-16 1.06004 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.43907 .55609 m
.44166 .56284 L
s
.4364 .54943 m
.43907 .55609 L
s
.43367 .54285 m
.4364 .54943 L
s
.44166 .56284 m
.44419 .56969 L
s
.44245 .56493 m
.45359 .59813 L
s
.42904 .5322 m
.44245 .56493 L
s
.43088 .53636 m
.43367 .54285 L
s
.44419 .56969 m
.44665 .57663 L
s
.42803 .52994 m
.43088 .53636 L
s
.44665 .57663 m
.44904 .58368 L
s
.41352 .5003 m
.42904 .5322 L
s
.42511 .52361 m
.42803 .52994 L
s
.44904 .58368 m
.45135 .59085 L
s
.42213 .51734 m
.42511 .52361 L
s
.45135 .59085 m
.45359 .59813 L
s
.42179 .51665 m
.42213 .51734 L
s
.42146 .51596 m
.42179 .51665 L
s
.42112 .51527 m
.42146 .51596 L
s
.42078 .51458 m
.42112 .51527 L
s
.42044 .51389 m
.42078 .51458 L
s
.4201 .5132 m
.42044 .51389 L
s
.41977 .51252 m
.4201 .5132 L
s
.41942 .51183 m
.41977 .51252 L
s
.47233 .59341 m
.45359 .59813 L
s
.45359 .59813 m
.45571 .60541 L
s
.45359 .59813 m
.45359 .59813 L
s
.45359 .59813 m
.46232 .63141 L
s
.41908 .51115 m
.41942 .51183 L
s
.41874 .51046 m
.41908 .51115 L
s
.4184 .50978 m
.41874 .51046 L
s
.41806 .5091 m
.4184 .50978 L
s
.41806 .5091 m
.41806 .5091 L
s
.41781 .50861 m
.41806 .5091 L
s
.41756 .50813 m
.41781 .50861 L
s
.41732 .50764 m
.41756 .50813 L
s
.41707 .50715 m
.41732 .50764 L
s
.41682 .50667 m
.41707 .50715 L
s
.41658 .50618 m
.41682 .50667 L
s
.41633 .5057 m
.41658 .50618 L
s
.41608 .50522 m
.41633 .5057 L
s
.45571 .60541 m
.45768 .61259 L
s
.41583 .50473 m
.41608 .50522 L
s
.41558 .50425 m
.41583 .50473 L
s
.41533 .50377 m
.41558 .50425 L
s
.41508 .50328 m
.41533 .50377 L
s
.41508 .50328 m
.41508 .50328 L
s
.41489 .50292 m
.41508 .50328 L
s
.41471 .50256 m
.41489 .50292 L
s
.41452 .5022 m
.41471 .50256 L
s
.41433 .50184 m
.41452 .5022 L
s
.41414 .50148 m
.41433 .50184 L
s
.41395 .50112 m
.41414 .50148 L
s
.41376 .50076 m
.41395 .50112 L
s
.41357 .5004 m
.41376 .50076 L
s
.41338 .50004 m
.41357 .5004 L
s
.39605 .46961 m
.41352 .5003 L
s
.41319 .49968 m
.41338 .50004 L
s
.413 .49932 m
.41319 .49968 L
s
.41281 .49896 m
.413 .49932 L
s
.41281 .49896 m
.41281 .49896 L
s
.41267 .49868 m
.41281 .49896 L
s
.45768 .61259 m
.45952 .61966 L
s
.41252 .49841 m
.41267 .49868 L
s
.41237 .49813 m
.41252 .49841 L
s
.41222 .49785 m
.41237 .49813 L
s
.41207 .49757 m
.41222 .49785 L
s
.41192 .49729 m
.41207 .49757 L
s
.41177 .49701 m
.41192 .49729 L
s
.41163 .49674 m
.41177 .49701 L
s
.41148 .49646 m
.41163 .49674 L
s
.41133 .49618 m
.41148 .49646 L
s
.41118 .4959 m
.41133 .49618 L
s
.41103 .49563 m
.41118 .4959 L
s
.41103 .49563 m
.41103 .49563 L
s
.40983 .49341 m
.41103 .49563 L
s
.40862 .49121 m
.40983 .49341 L
s
.45952 .61966 m
.46122 .62663 L
s
.4074 .48901 m
.40862 .49121 L
s
.40617 .48682 m
.4074 .48901 L
s
.40494 .48464 m
.40617 .48682 L
s
.46122 .62663 m
.46279 .63351 L
s
.40369 .48247 m
.40494 .48464 L
s
.4912 .58866 m
.47233 .59341 L
s
.40244 .4803 m
.40369 .48247 L
s
.46232 .63141 m
.46853 .66438 L
s
.40118 .47815 m
.40244 .4803 L
s
.46279 .63351 m
.46424 .6403 L
s
.39991 .476 m
.40118 .47815 L
s
.39863 .47386 m
.39991 .476 L
s
.39734 .47173 m
.39863 .47386 L
s
.46424 .6403 m
.46557 .64701 L
s
.39605 .46961 m
.39734 .47173 L
s
.39605 .46961 m
.39605 .46961 L
s
.3901 .46015 m
.39605 .46961 L
s
.37681 .4405 m
.39605 .46961 L
s
.46557 .64701 m
.46678 .65363 L
s
.51018 .58389 m
.4912 .58866 L
s
.46678 .65363 m
.46788 .66018 L
s
.38398 .45085 m
.3901 .46015 L
s
.46788 .66018 m
.46886 .66665 L
s
.46853 .66438 m
.47209 .69665 L
s
.37766 .4417 m
.38398 .45085 L
s
.46886 .66665 m
.46974 .67305 L
s
.52927 .57908 m
.51018 .58389 L
s
.46974 .67305 m
.47051 .67939 L
s
.37115 .43271 m
.37766 .4417 L
s
.356 .41336 m
.37681 .4405 L
s
.47051 .67939 m
.47059 .68009 L
s
.47051 .67939 m
.47051 .67939 L
s
.47059 .68009 m
.47066 .68079 L
s
.47066 .68079 m
.47074 .68148 L
s
.47074 .68148 m
.47082 .68218 L
s
.54849 .57424 m
.52927 .57908 L
s
.47082 .68218 m
.47089 .68288 L
s
.47089 .68288 m
.47096 .68357 L
s
.47096 .68357 m
.47103 .68427 L
s
.47103 .68427 m
.4711 .68496 L
s
.4711 .68496 m
.47117 .68566 L
s
.47117 .68566 m
.47124 .68635 L
s
.36443 .42387 m
.37115 .43271 L
s
.47124 .68635 m
.4713 .68704 L
s
.4713 .68704 m
.47137 .68773 L
s
.47137 .68773 m
.47141 .68822 L
s
.47137 .68773 m
.47137 .68773 L
s
.47141 .68822 m
.47146 .68872 L
s
.47146 .68872 m
.4715 .68921 L
s
.4715 .68921 m
.47155 .6897 L
s
.47155 .6897 m
.47159 .69019 L
s
.47159 .69019 m
.47163 .69068 L
s
.47163 .69068 m
.47167 .69117 L
s
.47167 .69117 m
.47171 .69166 L
s
.47171 .69166 m
.47175 .69215 L
s
.47175 .69215 m
.47179 .69264 L
s
.47179 .69264 m
.47183 .69313 L
s
.47183 .69313 m
.47187 .69362 L
s
.47187 .69362 m
.4719 .69398 L
s
.47187 .69362 m
.47187 .69362 L
s
.4719 .69398 m
.47192 .69435 L
s
.47192 .69435 m
.47195 .69472 L
s
.47195 .69472 m
.47198 .69508 L
s
.47198 .69508 m
.47201 .69545 L
s
.56782 .56938 m
.54849 .57424 L
s
.47201 .69545 m
.47203 .69581 L
s
.47203 .69581 m
.47206 .69618 L
s
.47206 .69618 m
.47208 .69654 L
s
.35749 .41518 m
.36443 .42387 L
s
.47208 .69654 m
.47211 .69691 L
s
.47209 .69665 m
.47291 .7278 L
s
.47211 .69691 m
.47213 .69727 L
s
.47213 .69727 m
.47216 .69763 L
s
.47216 .69763 m
.47218 .698 L
s
.47218 .698 m
.4722 .69828 L
s
.47218 .698 m
.47218 .698 L
s
.4722 .69828 m
.47222 .69856 L
s
.47222 .69856 m
.47224 .69884 L
s
.47224 .69884 m
.47225 .69913 L
s
.47225 .69913 m
.47227 .69941 L
s
.47227 .69941 m
.47229 .69969 L
s
.47229 .69969 m
.47231 .69997 L
s
.47231 .69997 m
.47232 .70026 L
s
.47232 .70026 m
.47234 .70054 L
s
.47234 .70054 m
.47236 .70082 L
s
.47236 .70082 m
.47237 .7011 L
s
.47237 .7011 m
.47239 .70138 L
s
.47239 .70138 m
.47251 .70363 L
s
.47239 .70138 m
.47239 .70138 L
s
.47251 .70363 m
.47262 .70587 L
s
.48746 .45438 m
.48562 .45346 L
s
.48929 .4553 m
.48746 .45438 L
s
.49111 .45623 m
.48929 .4553 L
s
.48562 .45346 m
.48379 .45254 L
s
.49294 .45716 m
.49111 .45623 L
s
.47969 .4506 m
.50136 .46138 L
s
.45829 .43947 m
.47969 .4506 L
s
.48379 .45254 m
.48195 .45162 L
s
.49476 .4581 m
.49294 .45716 L
s
.48195 .45162 m
.48012 .45071 L
s
.49658 .45904 m
.49476 .4581 L
s
.48012 .45071 m
.47827 .4498 L
s
.49658 .45904 m
.49658 .45904 L
s
.49852 .45994 m
.49658 .45904 L
s
.47827 .4498 m
.47643 .44889 L
s
.47262 .70587 m
.47271 .70809 L
s
.47643 .44889 m
.47458 .44799 L
s
.50045 .46086 m
.49852 .45994 L
s
.47458 .44799 m
.47285 .44705 L
s
.47458 .44799 m
.47458 .44799 L
s
.50238 .46177 m
.50045 .46086 L
s
.50136 .46138 m
.52331 .47186 L
s
.47285 .44705 m
.47112 .44612 L
s
.50431 .46269 m
.50238 .46177 L
s
.47112 .44612 m
.46938 .44519 L
s
.50624 .46361 m
.50431 .46269 L
s
.46938 .44519 m
.46764 .44427 L
s
.50816 .46453 m
.50624 .46361 L
s
.35033 .40664 m
.35749 .41518 L
s
.46764 .44427 m
.46589 .44335 L
s
.51008 .46546 m
.50816 .46453 L
s
.46589 .44335 m
.46415 .44243 L
s
.512 .46639 m
.51008 .46546 L
s
.46415 .44243 m
.4624 .44151 L
s
.51392 .46733 m
.512 .46639 L
s
.4624 .44151 m
.46065 .4406 L
s
.51584 .46826 m
.51392 .46733 L
s
.58728 .56448 m
.56782 .56938 L
s
.46065 .4406 m
.4589 .43969 L
s
.51775 .4692 m
.51584 .46826 L
s
.43713 .42793 m
.45829 .43947 L
s
.4589 .43969 m
.45714 .43878 L
s
.51967 .47015 m
.51775 .4692 L
s
.45714 .43878 m
.45538 .43788 L
s
.51967 .47015 m
.51967 .47015 L
s
.52169 .47106 m
.51967 .47015 L
s
.47271 .70809 m
.47279 .71032 L
s
.45538 .43788 m
.45362 .43697 L
s
.52372 .47198 m
.52169 .47106 L
s
.45362 .43697 m
.45362 .43697 L
s
.45362 .43697 m
.45197 .43604 L
s
.52331 .47186 m
.54555 .48208 L
s
.52575 .4729 m
.52372 .47198 L
s
.33384 .38856 m
.356 .41336 L
s
.45197 .43604 m
.45032 .43511 L
s
.52777 .47382 m
.52575 .4729 L
s
.45032 .43511 m
.44867 .43419 L
s
.52979 .47475 m
.52777 .47382 L
s
.44867 .43419 m
.44701 .43327 L
s
.53181 .47568 m
.52979 .47475 L
s
.44701 .43327 m
.44535 .43235 L
s
.53383 .47662 m
.53181 .47568 L
s
.44535 .43235 m
.44369 .43143 L
s
.47279 .71032 m
.47285 .71253 L
s
.53585 .47755 m
.53383 .47662 L
s
.44369 .43143 m
.44203 .43051 L
s
.53786 .47849 m
.53585 .47755 L
s
.44203 .43051 m
.44036 .4296 L
s
.53988 .47944 m
.53786 .47849 L
s
.44036 .4296 m
.43869 .42869 L
s
.54189 .48039 m
.53988 .47944 L
s
.43869 .42869 m
.43702 .42779 L
s
.5439 .48134 m
.54189 .48039 L
s
.41622 .41589 m
.43713 .42793 L
s
.43702 .42779 m
.43534 .42688 L
s
.47285 .71253 m
.4729 .71473 L
s
.5439 .48134 m
.5439 .48134 L
s
.54603 .48226 m
.5439 .48134 L
s
.43534 .42688 m
.43366 .42598 L
s
.54555 .48208 m
.5681 .49209 L
s
.54816 .48319 m
.54603 .48226 L
s
.43366 .42598 m
.4321 .42505 L
s
.43366 .42598 m
.43366 .42598 L
s
.55029 .48411 m
.54816 .48319 L
s
.4321 .42505 m
.43053 .42412 L
s
.55241 .48505 m
.55029 .48411 L
s
.43053 .42412 m
.42896 .42319 L
s
.4729 .71473 m
.47294 .71693 L
s
.55454 .48598 m
.55241 .48505 L
s
.42896 .42319 m
.42738 .42227 L
s
.55666 .48692 m
.55454 .48598 L
s
.42738 .42227 m
.42581 .42135 L
s
.55878 .48787 m
.55666 .48692 L
s
.42581 .42135 m
.42423 .42043 L
s
.5609 .48881 m
.55878 .48787 L
s
.42423 .42043 m
.42265 .41952 L
s
.47294 .71693 m
.47296 .71912 L
s
.34293 .39827 m
.35033 .40664 L
s
.56302 .48976 m
.5609 .48881 L
s
.42265 .41952 m
.42106 .41861 L
s
.56514 .49072 m
.56302 .48976 L
s
.42106 .41861 m
.41947 .4177 L
s
.56725 .49168 m
.56514 .49072 L
s
.41947 .4177 m
.41788 .41679 L
s
.60686 .55955 m
.58728 .56448 L
s
.56937 .49264 m
.56725 .49168 L
s
.41788 .41679 m
.41628 .41588 L
s
.5681 .49209 m
.59099 .50189 L
s
.47296 .71912 m
.47297 .7213 L
s
.56937 .49264 m
.56937 .49264 L
s
.57161 .49357 m
.56937 .49264 L
s
.39555 .40324 m
.41622 .41589 L
s
.41628 .41588 m
.41469 .41498 L
s
.57385 .4945 m
.57161 .49357 L
s
.41469 .41498 m
.41321 .41405 L
s
.41469 .41498 m
.41469 .41498 L
s
.57609 .49544 m
.57385 .4945 L
s
.41321 .41405 m
.41172 .41312 L
s
.47297 .7213 m
.47296 .72348 L
s
.57833 .49639 m
.57609 .49544 L
s
.41172 .41312 m
.41023 .41219 L
s
.58057 .49733 m
.57833 .49639 L
s
.41023 .41219 m
.40874 .41127 L
s
.5828 .49828 m
.58057 .49733 L
s
.40874 .41127 m
.40725 .41034 L
s
.47296 .72348 m
.47294 .72564 L
s
.58504 .49924 m
.5828 .49828 L
s
.40725 .41034 m
.40575 .40942 L
s
.58727 .5002 m
.58504 .49924 L
s
.40575 .40942 m
.40425 .40851 L
s
.5895 .50116 m
.58727 .5002 L
s
.40425 .40851 m
.40275 .40759 L
s
.47294 .72564 m
.47291 .7278 L
s
.59173 .50213 m
.5895 .50116 L
s
.40275 .40759 m
.40124 .40668 L
s
.59099 .50189 m
.61424 .51152 L
s
.59396 .5031 m
.59173 .50213 L
s
.40124 .40668 m
.39973 .40577 L
s
.33528 .39005 m
.34293 .39827 L
s
.59619 .50407 m
.59396 .5031 L
s
.39973 .40577 m
.39822 .40486 L
s
.47291 .7278 m
.47258 .73742 L
s
.47291 .7278 m
.47291 .7278 L
s
.47291 .7278 m
.4709 .75743 L
s
.47291 .7278 m
.4451 .70694 L
s
.47291 .7278 m
.47291 .7278 L
s
.59619 .50407 m
.59619 .50407 L
s
.59855 .50502 m
.59619 .50407 L
s
.39822 .40486 m
.3967 .40396 L
s
.62656 .5546 m
.60686 .55955 L
s
.3967 .40396 m
.3953 .40302 L
s
.3967 .40396 m
.3967 .40396 L
s
.60092 .50596 m
.59855 .50502 L
s
.37515 .38978 m
.39555 .40324 L
s
.3953 .40302 m
.3939 .40209 L
s
.60328 .50691 m
.60092 .50596 L
s
.3939 .40209 m
.3925 .40116 L
s
.60564 .50787 m
.60328 .50691 L
s
.3925 .40116 m
.3911 .40023 L
s
.608 .50883 m
.60564 .50787 L
s
.3911 .40023 m
.38969 .3993 L
s
.61036 .50979 m
.608 .50883 L
s
.38969 .3993 m
.38827 .39838 L
s
.61272 .51076 m
.61036 .50979 L
s
.38827 .39838 m
.38686 .39746 L
s
.61508 .51174 m
.61272 .51076 L
s
.61424 .51152 m
.63787 .52099 L
s
.38686 .39746 m
.38544 .39654 L
s
.61744 .51271 m
.61508 .51174 L
s
.38544 .39654 m
.38401 .39562 L
s
.61979 .5137 m
.61744 .51271 L
s
.38401 .39562 m
.38258 .39471 L
s
.62215 .51468 m
.61979 .5137 L
s
.47258 .73742 m
.47196 .74689 L
s
.38258 .39471 m
.38115 .3938 L
s
.32735 .38201 m
.33528 .39005 L
s
.6245 .51567 m
.62215 .51468 L
s
.38115 .3938 m
.37972 .39289 L
s
.62656 .5546 m
.64638 .54961 L
s
.6245 .51567 m
.6245 .51567 L
s
.62701 .51663 m
.6245 .51567 L
s
.37972 .39289 m
.37841 .39195 L
s
.37972 .39289 m
.37972 .39289 L
s
.31057 .36648 m
.33384 .38856 L
s
.62951 .51759 m
.62701 .51663 L
s
.37841 .39195 m
.3771 .39101 L
s
.63201 .51856 m
.62951 .51759 L
s
.3771 .39101 m
.37579 .39007 L
s
.63451 .51953 m
.63201 .51856 L
s
.37579 .39007 m
.37447 .38913 L
s
.35504 .37525 m
.37515 .38978 L
s
.63701 .52051 m
.63451 .51953 L
s
.37447 .38913 m
.37315 .3882 L
s
.63951 .52149 m
.63701 .52051 L
s
.63787 .52099 m
.66191 .53033 L
s
.37315 .3882 m
.37182 .38727 L
s
.64201 .52247 m
.63951 .52149 L
s
.37182 .38727 m
.37049 .38634 L
s
.64451 .52346 m
.64201 .52247 L
s
.37049 .38634 m
.36915 .38542 L
s
.64701 .52446 m
.64451 .52346 L
s
.47196 .74689 m
.47104 .7562 L
s
.36915 .38542 m
.36782 .3845 L
s
.64638 .54961 m
.66633 .54458 L
s
.6495 .52546 m
.64701 .52446 L
s
.31912 .37415 m
.32735 .38201 L
s
.36782 .3845 m
.36647 .38358 L
s
.652 .52647 m
.6495 .52546 L
s
.36647 .38358 m
.36513 .38266 L
s
.6545 .52748 m
.652 .52647 L
s
.36513 .38266 m
.36377 .38175 L
s
.6545 .52748 m
.6545 .52748 L
s
.65716 .52845 m
.6545 .52748 L
s
.61264 .63216 m
.61407 .6304 L
s
.61264 .63216 m
.61264 .63216 L
s
.61135 .63389 m
.61264 .63216 L
s
.61407 .6304 m
.61549 .62863 L
s
.61185 .63318 m
.59778 .65133 L
s
.62619 .61486 m
.61185 .63318 L
s
.61549 .62863 m
.61691 .62686 L
s
.61691 .62686 m
.61832 .62508 L
s
.61004 .63562 m
.61135 .63389 L
s
.61832 .62508 m
.61973 .6233 L
s
.61973 .6233 m
.62113 .62151 L
s
.60873 .63734 m
.61004 .63562 L
s
.36377 .38175 m
.36256 .3808 L
s
.36377 .38175 m
.36377 .38175 L
s
.62113 .62151 m
.62253 .61972 L
s
.60742 .63906 m
.60873 .63734 L
s
.62253 .61972 m
.62392 .61793 L
s
.62392 .61793 m
.62531 .61613 L
s
.6061 .64077 m
.60742 .63906 L
s
.6408 .59636 m
.62619 .61486 L
s
.62531 .61613 m
.6267 .61433 L
s
.60478 .64248 m
.6061 .64077 L
s
.6267 .61433 m
.62808 .61252 L
s
.60346 .64419 m
.60478 .64248 L
s
.62808 .61252 m
.62945 .61071 L
s
.60213 .64589 m
.60346 .64419 L
s
.62945 .61071 m
.63096 .60886 L
s
.62945 .61071 m
.62945 .61071 L
s
.60079 .64759 m
.60213 .64589 L
s
.63096 .60886 m
.63247 .60701 L
s
.59945 .64928 m
.60079 .64759 L
s
.65982 .52943 m
.65716 .52845 L
s
.63247 .60701 m
.63397 .60515 L
s
.5981 .65098 m
.59945 .64928 L
s
.59676 .65266 m
.5981 .65098 L
s
.59778 .65133 m
.58397 .66934 L
s
.63397 .60515 m
.63546 .60329 L
s
.59676 .65266 m
.59676 .65266 L
s
.59553 .65432 m
.59676 .65266 L
s
.36256 .3808 m
.36135 .37985 L
s
.63546 .60329 m
.63696 .60142 L
s
.5943 .65597 m
.59553 .65432 L
s
.63696 .60142 m
.63844 .59955 L
s
.59306 .65762 m
.5943 .65597 L
s
.63844 .59955 m
.63993 .59767 L
s
.59182 .65926 m
.59306 .65762 L
s
.63993 .59767 m
.6414 .59579 L
s
.65569 .57765 m
.6408 .59636 L
s
.59057 .6609 m
.59182 .65926 L
s
.66248 .53042 m
.65982 .52943 L
s
.6414 .59579 m
.64288 .59391 L
s
.58932 .66254 m
.59057 .6609 L
s
.64288 .59391 m
.64434 .59202 L
s
.36135 .37985 m
.36013 .3789 L
s
.58806 .66418 m
.58932 .66254 L
s
.64434 .59202 m
.64581 .59012 L
s
.5868 .66581 m
.58806 .66418 L
s
.64581 .59012 m
.64726 .58822 L
s
.66191 .53033 m
.68641 .53953 L
s
.58554 .66743 m
.5868 .66581 L
s
.64726 .58822 m
.64887 .58627 L
s
.64726 .58822 m
.64726 .58822 L
s
.66514 .53141 m
.66248 .53042 L
s
.58427 .66906 m
.58554 .66743 L
s
.64887 .58627 m
.65047 .58433 L
s
.36013 .3789 m
.3589 .37796 L
s
.58397 .66934 m
.57042 .68721 L
s
.583 .67068 m
.58427 .66906 L
s
.65047 .58433 m
.65206 .58237 L
s
.58172 .6723 m
.583 .67068 L
s
.65206 .58237 m
.65365 .58041 L
s
.58172 .6723 m
.58172 .6723 L
s
.58056 .67388 m
.58172 .6723 L
s
.6678 .5324 m
.66514 .53141 L
s
.65365 .58041 m
.65524 .57845 L
s
.57939 .67546 m
.58056 .67388 L
s
.3589 .37796 m
.35767 .37702 L
s
.65524 .57845 m
.65682 .57648 L
s
.57822 .67704 m
.57939 .67546 L
s
.67089 .55872 m
.65569 .57765 L
s
.65682 .57648 m
.6584 .57451 L
s
.57705 .67862 m
.57822 .67704 L
s
.66633 .54458 m
.68641 .53953 L
s
.57587 .68019 m
.57705 .67862 L
s
.6584 .57451 m
.65997 .57253 L
s
.67046 .5334 m
.6678 .5324 L
s
.47104 .7562 m
.46982 .76537 L
s
.35767 .37702 m
.35644 .37608 L
s
.57468 .68176 m
.57587 .68019 L
s
.65997 .57253 m
.66153 .57054 L
s
.57349 .68333 m
.57468 .68176 L
s
.66153 .57054 m
.66309 .56855 L
s
.5723 .68489 m
.57349 .68333 L
s
.66309 .56855 m
.66465 .56655 L
s
.67312 .53441 m
.67046 .5334 L
s
.4709 .75743 m
.466 .78508 L
s
.35644 .37608 m
.3552 .37514 L
s
.5711 .68645 m
.5723 .68489 L
s
.66465 .56655 m
.6662 .56455 L
s
.5699 .68801 m
.5711 .68645 L
s
.6662 .56455 m
.66791 .5625 L
s
.6662 .56455 m
.6662 .56455 L
s
.57042 .68721 m
.55712 .70497 L
s
.31057 .36648 m
.31912 .37415 L
s
.56869 .68957 m
.5699 .68801 L
s
.33532 .35914 m
.35504 .37525 L
s
.67578 .53542 m
.67312 .53441 L
s
.66791 .5625 m
.66962 .56044 L
s
.3552 .37514 m
.35396 .37421 L
s
.56748 .69112 m
.56869 .68957 L
s
.66962 .56044 m
.67132 .55838 L
s
.56748 .69112 m
.56748 .69112 L
s
.56638 .69264 m
.56748 .69112 L
s
.68641 .53953 m
.67089 .55872 L
s
.67132 .55838 m
.67302 .55631 L
s
.56528 .69416 m
.56638 .69264 L
s
.67843 .53644 m
.67578 .53542 L
s
.35396 .37421 m
.35271 .37328 L
s
.56417 .69567 m
.56528 .69416 L
s
.67302 .55631 m
.67471 .55423 L
s
.56306 .69718 m
.56417 .69567 L
s
.67471 .55423 m
.6764 .55215 L
s
.68109 .53747 m
.67843 .53644 L
s
.35271 .37328 m
.35146 .37235 L
s
.56195 .69869 m
.56306 .69718 L
s
.6764 .55215 m
.67808 .55007 L
s
.56083 .7002 m
.56195 .69869 L
s
.67808 .55007 m
.67976 .54797 L
s
.5597 .7017 m
.56083 .7002 L
s
.35146 .37235 m
.3502 .37143 L
s
.68375 .5385 m
.68109 .53747 L
s
.67976 .54797 m
.68143 .54587 L
s
.55857 .7032 m
.5597 .7017 L
s
.68143 .54587 m
.68309 .54377 L
s
.55744 .7047 m
.55857 .7032 L
s
.3502 .37143 m
.34894 .37051 L
s
.68641 .53953 m
.68375 .5385 L
s
.68309 .54377 m
.68475 .54165 L
s
.5563 .70619 m
.55744 .7047 L
s
.55712 .70497 m
.54409 .72263 L
s
.68475 .54165 m
.68641 .53953 L
s
.55515 .70768 m
.5563 .70619 L
s
.34894 .37051 m
.34783 .36955 L
s
.34894 .37051 m
.34894 .37051 L
s
.79588 .46211 m
.68641 .53953 L
s
.68641 .53953 m
.79588 .46211 L
s
.68641 .53953 m
.68641 .53953 L
s
.554 .70917 m
.55515 .70768 L
s
.554 .70917 m
.554 .70917 L
s
.55297 .71063 m
.554 .70917 L
s
.55193 .71209 m
.55297 .71063 L
s
.34783 .36955 m
.34672 .36859 L
s
.46982 .76537 m
.46829 .77438 L
s
.55089 .71354 m
.55193 .71209 L
s
.54984 .71499 m
.55089 .71354 L
s
.34672 .36859 m
.3456 .36763 L
s
.54878 .71644 m
.54984 .71499 L
s
.54772 .71788 m
.54878 .71644 L
s
.3456 .36763 m
.34448 .36667 L
s
.54666 .71932 m
.54772 .71788 L
s
.31057 .36648 m
.31262 .36587 L
s
.31057 .36648 m
.31057 .36648 L
s
.30191 .35922 m
.31057 .36648 L
s
.4451 .70694 m
.41645 .68546 L
s
.28647 .34752 m
.31057 .36648 L
s
.31057 .36648 m
.31057 .36648 L
s
.31057 .36648 m
.30778 .40182 L
s
.54559 .72076 m
.54666 .71932 L
s
.34448 .36667 m
.34335 .36572 L
s
.54452 .7222 m
.54559 .72076 L
s
.31262 .36587 m
.31468 .36526 L
s
.54344 .72363 m
.54452 .7222 L
s
.54409 .72263 m
.53134 .7402 L
s
.34335 .36572 m
.34222 .36477 L
s
.31468 .36526 m
.31674 .36465 L
s
.54236 .72506 m
.54344 .72363 L
s
.54127 .72649 m
.54236 .72506 L
s
.31674 .36465 m
.3188 .36404 L
s
.34222 .36477 m
.34108 .36383 L
s
.54127 .72649 m
.54127 .72649 L
s
.5403 .72789 m
.54127 .72649 L
s
.3188 .36404 m
.32086 .36343 L
s
.53932 .72928 m
.5403 .72789 L
s
.34108 .36383 m
.33994 .36288 L
s
.32086 .36343 m
.32292 .36282 L
s
.53834 .73068 m
.53932 .72928 L
s
.53735 .73207 m
.53834 .73068 L
s
.32292 .36282 m
.32498 .36221 L
s
.33994 .36288 m
.33879 .36194 L
s
.53636 .73345 m
.53735 .73207 L
s
.32498 .36221 m
.32704 .3616 L
s
.46829 .77438 m
.46643 .78323 L
s
.33879 .36194 m
.33764 .36101 L
s
.53536 .73484 m
.53636 .73345 L
s
.32704 .3616 m
.32911 .36098 L
s
.53436 .73622 m
.53536 .73484 L
s
.33118 .36037 m
.32911 .36098 L
s
.33764 .36101 m
.33648 .36007 L
s
.53335 .7376 m
.53436 .73622 L
s
.53234 .73898 m
.53335 .7376 L
s
.33118 .36037 m
.33325 .35976 L
s
.33648 .36007 m
.33532 .35914 L
s
.53132 .74035 m
.53234 .73898 L
s
.33325 .35976 m
.33532 .35914 L
s
.53134 .7402 m
.5189 .7577 L
s
.5303 .74172 m
.53132 .74035 L
s
.31921 .34364 m
.33532 .35914 L
s
.33532 .35914 m
.33432 .35817 L
s
.33532 .35914 m
.33532 .35914 L
s
.29336 .35255 m
.30191 .35922 L
s
.52927 .74309 m
.5303 .74172 L
s
.52927 .74309 m
.52927 .74309 L
s
.52836 .74443 m
.52927 .74309 L
s
.33432 .35817 m
.33333 .35721 L
s
.52744 .74577 m
.52836 .74443 L
s
.33333 .35721 m
.33234 .35625 L
s
.52652 .7471 m
.52744 .74577 L
s
.52559 .74843 m
.52652 .7471 L
s
.33234 .35625 m
.33135 .35531 L
s
.52466 .74976 m
.52559 .74843 L
s
.52373 .75109 m
.52466 .74976 L
s
.33135 .35531 m
.33036 .35437 L
s
.46643 .78323 m
.46424 .79192 L
s
.52278 .75241 m
.52373 .75109 L
s
.52184 .75373 m
.52278 .75241 L
s
.33036 .35437 m
.32938 .35344 L
s
.52088 .75505 m
.52184 .75373 L
s
.466 .78508 m
.45817 .81033 L
s
.32938 .35344 m
.32839 .35253 L
s
.51993 .75636 m
.52088 .75505 L
s
.51896 .75768 m
.51993 .75636 L
s
.32839 .35253 m
.32741 .35162 L
s
.5189 .7577 m
.5068 .77514 L
s
.51799 .75899 m
.51896 .75768 L
s
.32741 .35162 m
.32643 .35072 L
s
.51799 .75899 m
.51799 .75899 L
s
.51715 .76026 m
.51799 .75899 L
s
.28492 .34643 m
.29336 .35255 L
s
.51629 .76154 m
.51715 .76026 L
s
.32643 .35072 m
.32546 .34983 L
s
.51544 .76282 m
.51629 .76154 L
s
.32546 .34983 m
.32448 .34895 L
s
.51457 .76409 m
.51544 .76282 L
s
.5137 .76536 m
.51457 .76409 L
s
.32448 .34895 m
.32351 .34808 L
s
.51283 .76662 m
.5137 .76536 L
s
.46424 .79192 m
.46169 .80045 L
s
.32351 .34808 m
.3227 .34717 L
s
.32351 .34808 m
.32351 .34808 L
s
.51195 .76789 m
.51283 .76662 L
s
.51106 .76915 m
.51195 .76789 L
s
.3227 .34717 m
.32189 .34626 L
s
.51017 .77041 m
.51106 .76915 L
s
.32189 .34626 m
.32108 .34537 L
s
.50928 .77166 m
.51017 .77041 L
s
.26184 .33204 m
.28647 .34752 L
s
.30492 .43805 m
.30778 .40182 L
s
.50837 .77291 m
.50928 .77166 L
s
.32108 .34537 m
.32027 .34448 L
s
.50747 .77417 m
.50837 .77291 L
s
.27657 .34082 m
.28492 .34643 L
s
.32027 .34448 m
.31947 .34361 L
s
.50747 .77417 m
.50747 .77417 L
s
.50668 .77538 m
.50747 .77417 L
s
.5068 .77514 m
.49512 .79252 L
s
.5059 .7766 m
.50668 .77538 L
s
.30822 .33062 m
.31921 .34364 L
s
.31947 .34361 m
.31867 .34274 L
s
.5051 .77781 m
.5059 .7766 L
s
.31867 .34274 m
.31787 .34188 L
s
.50431 .77902 m
.5051 .77781 L
s
.41645 .68546 m
.38693 .66331 L
s
.5035 .78023 m
.50431 .77902 L
s
.31787 .34188 m
.31707 .34103 L
s
.46169 .80045 m
.45876 .8088 L
s
.50269 .78144 m
.5035 .78023 L
s
.31707 .34103 m
.31627 .34018 L
s
.50188 .78264 m
.50269 .78144 L
s
.31627 .34018 m
.31547 .33935 L
s
.50105 .78384 m
.50188 .78264 L
s
.50023 .78504 m
.50105 .78384 L
s
.31547 .33935 m
.31468 .33852 L
s
.49939 .78623 m
.50023 .78504 L
s
.31468 .33852 m
.31389 .3377 L
s
.49855 .78742 m
.49939 .78623 L
s
.2683 .33572 m
.27657 .34082 L
s
.31389 .3377 m
.31325 .33685 L
s
.31389 .3377 m
.31389 .3377 L
s
.49771 .78861 m
.49855 .78742 L
s
.49771 .78861 m
.49771 .78861 L
s
.497 .78977 m
.49771 .78861 L
s
.31325 .33685 m
.3126 .336 L
s
.49628 .79092 m
.497 .78977 L
s
.3126 .336 m
.31196 .33516 L
s
.49556 .79207 m
.49628 .79092 L
s
.45876 .8088 m
.45542 .81697 L
s
.31196 .33516 m
.31133 .33433 L
s
.49483 .79322 m
.49556 .79207 L
s
.49512 .79252 m
.48398 .80985 L
s
.49409 .79436 m
.49483 .79322 L
s
.45817 .81033 m
.44742 .83269 L
s
.31133 .33433 m
.31069 .3335 L
s
.49335 .7955 m
.49409 .79436 L
s
.31069 .3335 m
.31006 .33269 L
s
.4926 .79664 m
.49335 .7955 L
s
.31006 .33269 m
.30942 .33188 L
s
.49185 .79778 m
.4926 .79664 L
s
.26012 .3311 m
.2683 .33572 L
s
.30942 .33188 m
.30879 .33108 L
s
.49109 .79891 m
.49185 .79778 L
s
.49032 .80004 m
.49109 .79891 L
s
.30879 .33108 m
.30816 .33028 L
s
.3009 .31934 m
.30822 .33062 L
s
.48955 .80117 m
.49032 .80004 L
s
.30816 .33028 m
.30754 .3295 L
s
.48877 .80229 m
.48955 .80117 L
s
.30754 .3295 m
.30691 .32872 L
s
.45542 .81697 m
.45166 .82494 L
s
.48877 .80229 m
.48877 .80229 L
s
.48813 .80338 m
.48877 .80229 L
s
.30691 .32872 m
.30629 .32795 L
s
.30492 .43805 m
.30198 .47521 L
s
.48749 .80446 m
.48813 .80338 L
s
.30629 .32795 m
.3058 .32714 L
s
.30629 .32795 m
.30629 .32795 L
s
.48684 .80555 m
.48749 .80446 L
s
.23702 .32042 m
.26184 .33204 L
s
.48619 .80663 m
.48684 .80555 L
s
.3058 .32714 m
.30532 .32634 L
s
.48553 .8077 m
.48619 .80663 L
s
.252 .32695 m
.26012 .3311 L
s
.30532 .32634 m
.30484 .32555 L
s
.48486 .80878 m
.48553 .8077 L
s
.30484 .32555 m
.30436 .32477 L
s
.48419 .80985 m
.48486 .80878 L
s
.30436 .32477 m
.30388 .32399 L
s
.48398 .80985 m
.47363 .8271 L
s
.4835 .81091 m
.48419 .80985 L
s
.30388 .32399 m
.3034 .32322 L
s
.48282 .81198 m
.4835 .81091 L
s
.45166 .82494 m
.44742 .83269 L
s
.48212 .81304 m
.48282 .81198 L
s
.3034 .32322 m
.30293 .32246 L
s
.38693 .66331 m
.35649 .64049 L
s
.48142 .81409 m
.48212 .81304 L
s
.30293 .32246 m
.30246 .32171 L
s
.48071 .81515 m
.48142 .81409 L
s
.30246 .32171 m
.30199 .32096 L
s
.48071 .81515 m
.48071 .81515 L
s
.48016 .81616 m
.48071 .81515 L
s
.24395 .32325 m
.252 .32695 L
s
.30199 .32096 m
.30152 .32022 L
s
.4796 .81717 m
.48016 .81616 L
s
.30152 .32022 m
.30105 .31948 L
s
.47904 .81818 m
.4796 .81717 L
s
.30105 .31948 m
.30058 .31876 L
s
.29647 .3094 m
.3009 .31934 L
s
.47847 .81919 m
.47904 .81818 L
s
.30058 .31876 m
.30025 .318 L
s
.30058 .31876 m
.30058 .31876 L
s
.47789 .82019 m
.47847 .81919 L
s
.30025 .318 m
.29992 .31724 L
s
.4773 .82118 m
.47789 .82019 L
s
.44742 .83269 m
.44742 .83269 L
s
.44742 .83269 m
.4428 .84001 L
s
.44959 .83223 m
.44742 .83269 L
s
.44742 .83269 m
.43377 .85173 L
s
.29992 .31724 m
.29959 .3165 L
s
.45177 .83176 m
.44959 .83223 L
s
.47671 .82218 m
.4773 .82118 L
s
.45395 .8313 m
.45177 .83176 L
s
.47611 .82317 m
.47671 .82218 L
s
.29959 .3165 m
.29926 .31576 L
s
.45395 .8313 m
.45613 .83083 L
s
.45831 .83037 m
.45613 .83083 L
s
.23597 .32002 m
.24395 .32325 L
s
.4755 .82416 m
.47611 .82317 L
s
.29926 .31576 m
.29894 .31503 L
s
.4605 .8299 m
.45831 .83037 L
s
.46268 .82943 m
.4605 .8299 L
s
.47489 .82514 m
.4755 .82416 L
s
.29894 .31503 m
.29861 .3143 L
s
.46268 .82943 m
.46487 .82897 L
s
.46706 .8285 m
.46487 .82897 L
s
.47426 .82612 m
.47489 .82514 L
s
.30198 .47521 m
.29897 .51334 L
s
.29861 .3143 m
.29829 .31359 L
s
.46924 .82803 m
.46706 .8285 L
s
.47144 .82756 m
.46924 .82803 L
s
.47363 .8271 m
.47426 .82612 L
s
.29829 .31359 m
.29797 .31287 L
s
.47363 .8271 m
.47144 .82756 L
s
.47363 .8271 m
.46592 .84148 L
s
.47363 .8271 m
.47363 .8271 L
s
.47317 .82803 m
.47363 .8271 L
s
.29797 .31287 m
.29765 .31217 L
s
.47271 .82895 m
.47317 .82803 L
s
.29765 .31217 m
.29733 .31147 L
s
.4428 .84001 m
.43792 .8467 L
s
.47225 .82986 m
.47271 .82895 L
s
.21238 .31301 m
.23702 .32042 L
s
.29733 .31147 m
.29702 .31078 L
s
.47178 .83076 m
.47225 .82986 L
s
.22804 .31723 m
.23597 .32002 L
s
.29702 .31078 m
.29671 .3101 L
s
.4713 .83165 m
.47178 .83076 L
s
.29671 .3101 m
.29652 .30938 L
s
.29671 .3101 m
.29671 .3101 L
s
.47083 .83253 m
.4713 .83165 L
s
.29443 .30055 m
.29647 .3094 L
s
.29652 .30938 m
.29634 .30867 L
s
.47034 .8334 m
.47083 .83253 L
s
.29634 .30867 m
.29616 .30797 L
s
.46986 .83426 m
.47034 .8334 L
s
.29616 .30797 m
.29598 .30727 L
s
.46937 .83511 m
.46986 .83426 L
s
.29598 .30727 m
.2958 .30658 L
s
.46888 .83595 m
.46937 .83511 L
s
.35649 .64049 m
.3251 .61694 L
s
.43792 .8467 m
.4328 .85281 L
s
.2958 .30658 m
.29563 .3059 L
s
.46838 .83678 m
.46888 .83595 L
s
.22018 .31489 m
.22804 .31723 L
s
.29563 .3059 m
.29545 .30522 L
s
.46788 .8376 m
.46838 .83678 L
s
.29545 .30522 m
.29528 .30455 L
s
.46788 .8376 m
.46788 .8376 L
s
.46755 .83838 m
.46788 .8376 L
s
.46721 .83915 m
.46755 .83838 L
s
.29528 .30455 m
.29511 .30389 L
s
.46687 .8399 m
.46721 .83915 L
s
.29511 .30389 m
.29495 .30324 L
s
.46652 .84065 m
.46687 .8399 L
s
.29495 .30324 m
.29478 .30259 L
s
.43377 .85173 m
.4173 .86698 L
s
.46617 .84139 m
.46652 .84065 L
s
.29478 .30259 m
.29462 .30194 L
s
.29588 .55247 m
.29897 .51334 L
s
.4328 .85281 m
.42745 .85837 L
s
.46592 .84148 m
.46145 .85156 L
s
.46582 .84212 m
.46617 .84139 L
s
.21238 .31301 m
.22018 .31489 L
s
.29462 .30194 m
.29458 .30127 L
s
.29462 .30194 m
.29462 .30194 L
s
.46547 .84284 m
.46582 .84212 L
s
.29458 .30127 m
.29454 .3006 L
s
.46511 .84356 m
.46547 .84284 L
s
.29454 .3006 m
.29451 .29994 L
s
.29448 .29261 m
.29443 .30055 L
s
.46475 .84426 m
.46511 .84356 L
s
.29451 .29994 m
.29448 .29928 L
s
.46438 .84495 m
.46475 .84426 L
s
.29448 .29928 m
.29445 .29864 L
s
.46401 .84564 m
.46438 .84495 L
s
.29445 .29864 m
.29442 .29799 L
s
.46364 .84632 m
.46401 .84564 L
s
.29442 .29799 m
.2944 .29736 L
s
.21238 .31301 m
.21238 .31301 L
s
.21065 .31265 m
.21238 .31301 L
s
.18831 .31012 m
.21238 .31301 L
s
.46364 .84632 m
.46364 .84632 L
s
.46342 .84695 m
.46364 .84632 L
s
.42745 .85837 m
.42186 .86339 L
s
.2944 .29736 m
.29437 .29673 L
s
.4632 .84758 m
.46342 .84695 L
s
.20893 .31232 m
.21065 .31265 L
s
.29437 .29673 m
.29435 .29611 L
s
.46297 .8482 m
.4632 .84758 L
s
.29435 .29611 m
.29433 .29549 L
s
.46274 .84881 m
.46297 .8482 L
s
.20721 .31201 m
.20893 .31232 L
s
.29433 .29549 m
.29432 .29488 L
s
.46251 .84941 m
.46274 .84881 L
s
.20549 .31172 m
.20721 .31201 L
s
.29432 .29488 m
.2943 .29428 L
s
.46227 .85 m
.46251 .84941 L
s
.2943 .29428 m
.29441 .29365 L
s
.2943 .29428 m
.2943 .29428 L
s
.46203 .85058 m
.46227 .85 L
s
.20377 .31145 m
.20549 .31172 L
s
.3251 .61694 m
.2927 .59264 L
s
.46179 .85116 m
.46203 .85058 L
s
.29441 .29365 m
.29453 .29302 L
s
.42186 .86339 m
.41605 .86789 L
s
.20206 .31121 m
.20377 .31145 L
s
.46155 .85172 m
.46179 .85116 L
s
.29453 .29302 m
.29464 .2924 L
s
.46145 .85156 m
.45935 .85855 L
s
.2964 .28547 m
.29448 .29261 L
s
.4613 .85228 m
.46155 .85172 L
s
.20035 .31099 m
.20206 .31121 L
s
.29464 .2924 m
.29476 .29178 L
s
.46105 .85283 m
.4613 .85228 L
s
.29476 .29178 m
.29488 .29117 L
s
.29588 .55247 m
.2927 .59264 L
s
.19865 .3108 m
.20035 .31099 L
s
.4608 .85337 m
.46105 .85283 L
s
.29488 .29117 m
.295 .29057 L
s
.4608 .85337 m
.4608 .85337 L
s
.46069 .85388 m
.4608 .85337 L
s
.19694 .31062 m
.19865 .3108 L
s
.295 .29057 m
.29513 .28998 L
s
.46057 .85437 m
.46069 .85388 L
s
.4173 .86698 m
.39815 .87801 L
s
.29513 .28998 m
.29525 .28939 L
s
.19524 .31048 m
.19694 .31062 L
s
.46046 .85486 m
.46057 .85437 L
s
.29525 .28939 m
.29538 .28881 L
s
.41605 .86789 m
.41001 .87189 L
s
.46034 .85533 m
.46046 .85486 L
s
.19355 .31035 m
.19524 .31048 L
s
.29538 .28881 m
.29551 .28823 L
s
.46022 .8558 m
.46034 .85533 L
s
.19185 .31025 m
.19355 .31035 L
s
.29551 .28823 m
.29565 .28766 L
s
.46009 .85627 m
.46022 .8558 L
s
.29565 .28766 m
.29579 .2871 L
s
.45996 .85672 m
.46009 .85627 L
s
.19185 .31025 m
.19185 .31025 L
s
.19164 .31024 m
.19185 .31025 L
s
.19143 .31023 m
.19164 .31024 L
s
.19122 .31022 m
.19143 .31023 L
s
.19101 .31021 m
.19122 .31022 L
s
.29579 .2871 m
.29605 .28651 L
s
.29579 .2871 m
.29579 .2871 L
s
.1908 .3102 m
.19101 .31021 L
s
.45983 .85716 m
.45996 .85672 L
s
.19058 .31019 m
.1908 .3102 L
s
.19037 .31018 m
.19058 .31019 L
s
.19016 .31017 m
.19037 .31018 L
s
.18995 .31017 m
.19016 .31017 L
s
.18974 .31016 m
.18995 .31017 L
s
.29605 .28651 m
.29631 .28592 L
s
.4597 .8576 m
.45983 .85716 L
s
.18953 .31015 m
.18974 .31016 L
s
.18932 .31014 m
.18953 .31015 L
s
.18932 .31014 m
.18932 .31014 L
s
.18905 .31014 m
.18932 .31014 L
s
.18877 .31013 m
.18905 .31014 L
s
.1885 .31012 m
.18877 .31013 L
s
.45957 .85803 m
.4597 .8576 L
s
.29631 .28592 m
.29658 .28534 L
s
.18823 .31012 m
.1885 .31012 L
s
.16526 .31202 m
.18831 .31012 L
s
.18796 .31011 m
.18823 .31012 L
s
.41001 .87189 m
.40375 .87538 L
s
.18769 .31011 m
.18796 .31011 L
s
.18742 .3101 m
.18769 .31011 L
s
.30005 .27907 m
.2964 .28547 L
s
.45943 .85845 m
.45957 .85803 L
s
.29658 .28534 m
.29685 .28477 L
s
.18715 .3101 m
.18742 .3101 L
s
.18688 .31009 m
.18715 .3101 L
s
.18661 .31009 m
.18688 .31009 L
s
.18634 .31009 m
.18661 .31009 L
s
.45929 .85886 m
.45943 .85845 L
s
.18607 .31009 m
.18634 .31009 L
s
.45935 .85855 m
.45911 .8631 L
s
.29685 .28477 m
.29712 .2842 L
s
.18607 .31009 m
.18607 .31009 L
s
.18571 .31009 m
.18607 .31009 L
s
.18535 .31009 m
.18571 .31009 L
s
.45929 .85886 m
.45929 .85886 L
s
.45928 .85924 m
.45929 .85886 L
s
.18499 .31009 m
.18535 .31009 L
s
.29712 .2842 m
.2974 .28364 L
s
.18463 .31009 m
.18499 .31009 L
s
.18427 .3101 m
.18463 .31009 L
s
.45928 .8596 m
.45928 .85924 L
s
.18391 .3101 m
.18427 .3101 L
s
.18355 .31011 m
.18391 .3101 L
s
.2974 .28364 m
.29767 .28308 L
s
.18319 .31012 m
.18355 .31011 L
s
.18283 .31012 m
.18319 .31012 L
s
.45927 .85996 m
.45928 .8596 L
s
.18247 .31013 m
.18283 .31012 L
s
.29767 .28308 m
.29796 .28254 L
s
.18211 .31014 m
.18247 .31013 L
s
.18175 .31016 m
.18211 .31014 L
s
.45925 .86032 m
.45927 .85996 L
s
.18175 .31016 m
.18175 .31016 L
s
.18125 .31018 m
.18175 .31016 L
s
.29796 .28254 m
.29824 .282 L
s
.18075 .3102 m
.18125 .31018 L
s
.2927 .59264 m
.28944 .63389 L
s
.2927 .59264 m
.25925 .56755 L
s
.45924 .86066 m
.45925 .86032 L
s
.18025 .31022 m
.18075 .3102 L
s
.40375 .87538 m
.39728 .87838 L
s
.17975 .31025 m
.18025 .31022 L
s
.29824 .282 m
.29852 .28146 L
s
.45922 .86099 m
.45924 .86066 L
s
.17925 .31027 m
.17975 .31025 L
s
.17875 .3103 m
.17925 .31027 L
s
.29852 .28146 m
.29881 .28093 L
s
.17824 .31034 m
.17875 .3103 L
s
.4592 .86132 m
.45922 .86099 L
s
.17774 .31037 m
.17824 .31034 L
s
.29881 .28093 m
.29911 .28041 L
s
.17725 .31041 m
.17774 .31037 L
s
.45918 .86164 m
.4592 .86132 L
s
.17675 .31045 m
.17725 .31041 L
s
.17625 .31049 m
.17675 .31045 L
s
.29911 .28041 m
.29952 .27986 L
s
.29911 .28041 m
.29911 .28041 L
s
.45916 .86195 m
.45918 .86164 L
s
.17575 .31053 m
.17625 .31049 L
s
.17575 .31053 m
.17575 .31053 L
s
.17127 .31103 m
.17575 .31053 L
s
.45913 .86225 m
.45916 .86195 L
s
.29952 .27986 m
.29995 .27931 L
s
.4591 .86255 m
.45913 .86225 L
s
.29995 .27931 m
.30037 .27878 L
s
.39815 .87801 m
.37652 .88442 L
s
.30531 .27332 m
.30005 .27907 L
s
.45907 .86284 m
.4591 .86255 L
s
.39728 .87838 m
.39058 .88089 L
s
.30037 .27878 m
.3008 .27824 L
s
.45907 .86284 m
.45907 .86284 L
s
.45917 .86309 m
.45907 .86284 L
s
.3008 .27824 m
.30123 .27772 L
s
.16682 .31173 m
.17127 .31103 L
s
.45911 .8631 m
.46043 .86562 L
s
.45926 .86333 m
.45917 .86309 L
s
.30123 .27772 m
.30166 .2772 L
s
.45936 .86357 m
.45926 .86333 L
s
.30166 .2772 m
.3021 .27668 L
s
.45945 .8638 m
.45936 .86357 L
s
.3021 .27668 m
.30254 .27618 L
s
.45954 .86401 m
.45945 .8638 L
s
.1624 .31263 m
.16682 .31173 L
s
.30254 .27618 m
.30299 .27568 L
s
.45963 .86423 m
.45954 .86401 L
s
.39058 .88089 m
.38366 .88291 L
s
.30299 .27568 m
.30343 .27519 L
s
.45972 .86443 m
.45963 .86423 L
s
.14368 .31893 m
.16526 .31202 L
s
.30343 .27519 m
.30388 .2747 L
s
.4598 .86463 m
.45972 .86443 L
s
.45988 .86481 m
.4598 .86463 L
s
.30388 .2747 m
.30433 .27423 L
s
.28944 .63389 m
.28609 .67628 L
s
.158 .31373 m
.1624 .31263 L
s
.45996 .86499 m
.45988 .86481 L
s
.30433 .27423 m
.30492 .27372 L
s
.30433 .27423 m
.30433 .27423 L
s
.46004 .86516 m
.45996 .86499 L
s
.30492 .27372 m
.30551 .27321 L
s
.46012 .86533 m
.46004 .86516 L
s
.31213 .26821 m
.30531 .27332 L
s
.30551 .27321 m
.3061 .27271 L
s
.46012 .86533 m
.46012 .86533 L
s
.46032 .86546 m
.46012 .86533 L
s
.25925 .56755 m
.2247 .54163 L
s
.38366 .88291 m
.37652 .88442 L
s
.3061 .27271 m
.30669 .27222 L
s
.15364 .31504 m
.158 .31373 L
s
.46052 .86558 m
.46032 .86546 L
s
.30669 .27222 m
.30729 .27174 L
s
.46072 .86569 m
.46052 .86558 L
s
.46043 .86562 m
.46314 .86636 L
s
.30729 .27174 m
.30789 .27127 L
s
.46092 .86579 m
.46072 .86569 L
s
.30789 .27127 m
.3085 .2708 L
s
.46112 .86589 m
.46092 .86579 L
s
.1493 .31658 m
.15364 .31504 L
s
.3085 .2708 m
.30911 .27034 L
s
.46131 .86598 m
.46112 .86589 L
s
.46151 .86606 m
.46131 .86598 L
s
.30911 .27034 m
.30972 .26988 L
s
.37652 .88442 m
.37652 .88442 L
s
.37652 .88442 m
.3749 .88469 L
s
.37652 .88442 m
.35268 .88586 L
s
.4617 .86613 m
.46151 .86606 L
s
.30972 .26988 m
.31033 .26943 L
s
.3749 .88469 m
.37327 .88494 L
s
.46188 .86619 m
.4617 .86613 L
s
.31033 .26943 m
.31095 .26899 L
s
.145 .31834 m
.1493 .31658 L
s
.46207 .86625 m
.46188 .86619 L
s
.37327 .88494 m
.37163 .88515 L
s
.31095 .26899 m
.31157 .26856 L
s
.46225 .8663 m
.46207 .86625 L
s
.31157 .26856 m
.31233 .2681 L
s
.31157 .26856 m
.31157 .26856 L
s
.37163 .88515 m
.36998 .88535 L
s
.46244 .86634 m
.46225 .8663 L
s
.32045 .26369 m
.31213 .26821 L
s
.31233 .2681 m
.3131 .26764 L
s
.46244 .86634 m
.46244 .86634 L
s
.46275 .86634 m
.46244 .86634 L
s
.36998 .88535 m
.36832 .88552 L
s
.3131 .26764 m
.31387 .26718 L
s
.14073 .32034 m
.145 .31834 L
s
.46306 .86634 m
.46275 .86634 L
s
.28609 .67628 m
.28265 .71984 L
s
.36832 .88552 m
.36665 .88566 L
s
.31387 .26718 m
.31464 .26674 L
s
.46336 .86633 m
.46306 .86634 L
s
.12405 .33096 m
.14368 .31893 L
s
.46314 .86636 m
.46709 .86551 L
s
.36665 .88566 m
.36496 .88578 L
s
.46367 .86631 m
.46336 .86633 L
s
.31464 .26674 m
.31541 .2663 L
s
.46397 .86628 m
.46367 .86631 L
s
.31541 .2663 m
.31619 .26587 L
s
.36496 .88578 m
.36327 .88587 L
s
.13649 .32259 m
.14073 .32034 L
s
.46427 .86624 m
.46397 .86628 L
s
.31619 .26587 m
.31698 .26545 L
s
.36327 .88587 m
.36156 .88593 L
s
.46457 .8662 m
.46427 .86624 L
s
.31698 .26545 m
.31777 .26503 L
s
.36156 .88593 m
.35984 .88597 L
s
.46487 .86614 m
.46457 .8662 L
s
.31777 .26503 m
.31856 .26463 L
s
.2247 .54163 m
.18898 .51484 L
s
.46517 .86608 m
.46487 .86614 L
s
.35984 .88597 m
.35811 .88599 L
s
.31856 .26463 m
.31935 .26423 L
s
.1323 .3251 m
.13649 .32259 L
s
.46546 .86601 m
.46517 .86608 L
s
.35811 .88599 m
.35637 .88597 L
s
.31935 .26423 m
.32015 .26384 L
s
.46575 .86594 m
.46546 .86601 L
s
.32015 .26384 m
.32096 .26345 L
s
.46604 .86585 m
.46575 .86594 L
s
.35637 .88597 m
.35615 .88597 L
s
.35637 .88597 m
.35637 .88597 L
s
.35615 .88597 m
.35593 .88597 L
s
.35593 .88597 m
.35571 .88596 L
s
.33025 .25975 m
.32045 .26369 L
s
.35571 .88596 m
.35549 .88596 L
s
.35549 .88596 m
.35528 .88595 L
s
.35528 .88595 m
.35506 .88595 L
s
.46604 .86585 m
.46604 .86585 L
s
.46646 .86573 m
.46604 .86585 L
s
.35506 .88595 m
.35484 .88594 L
s
.32096 .26345 m
.32191 .26303 L
s
.32096 .26345 m
.32096 .26345 L
s
.35484 .88594 m
.35462 .88594 L
s
.35462 .88594 m
.3544 .88593 L
s
.3544 .88593 m
.35418 .88592 L
s
.35418 .88592 m
.35396 .88591 L
s
.35396 .88591 m
.35374 .88591 L
s
.12815 .32789 m
.1323 .3251 L
s
.46688 .8656 m
.46646 .86573 L
s
.35374 .88591 m
.35345 .8859 L
s
.35374 .88591 m
.35374 .88591 L
s
.32191 .26303 m
.32286 .26262 L
s
.35345 .8859 m
.35317 .88588 L
s
.35317 .88588 m
.35288 .88587 L
s
.35288 .88587 m
.3526 .88586 L
s
.35268 .88586 m
.32697 .88205 L
s
.3526 .88586 m
.35231 .88584 L
s
.4673 .86546 m
.46688 .8656 L
s
.35231 .88584 m
.35203 .88583 L
s
.35203 .88583 m
.35174 .88581 L
s
.32286 .26262 m
.32382 .26222 L
s
.35174 .88581 m
.35146 .8858 L
s
.35146 .8858 m
.35117 .88578 L
s
.46709 .86551 m
.47218 .8632 L
s
.35117 .88578 m
.35088 .88577 L
s
.46771 .86531 m
.4673 .86546 L
s
.35088 .88577 m
.3506 .88575 L
s
.3506 .88575 m
.35031 .88573 L
s
.32382 .26222 m
.32478 .26182 L
s
.35031 .88573 m
.34993 .8857 L
s
.35031 .88573 m
.35031 .88573 L
s
.34993 .8857 m
.34954 .88568 L
s
.46812 .86516 m
.46771 .86531 L
s
.34954 .88568 m
.34916 .88565 L
s
.34916 .88565 m
.34877 .88562 L
s
.32478 .26182 m
.32575 .26143 L
s
.34877 .88562 m
.34839 .88559 L
s
.12405 .33096 m
.12815 .32789 L
s
.46854 .86499 m
.46812 .86516 L
s
.34839 .88559 m
.348 .88556 L
s
.28265 .71984 m
.27911 .76463 L
s
.348 .88556 m
.34761 .88552 L
s
.34761 .88552 m
.34723 .88549 L
s
.32575 .26143 m
.32673 .26105 L
s
.34723 .88549 m
.34684 .88545 L
s
.46895 .86482 m
.46854 .86499 L
s
.34684 .88545 m
.34645 .88541 L
s
.34645 .88541 m
.34606 .88538 L
s
.34606 .88538 m
.34567 .88534 L
s
.32673 .26105 m
.3277 .26068 L
s
.46935 .86464 m
.46895 .86482 L
s
.34567 .88534 m
.34513 .88528 L
s
.34567 .88534 m
.34567 .88534 L
s
.34513 .88528 m
.34458 .88522 L
s
.34458 .88522 m
.34403 .88516 L
s
.46976 .86445 m
.46935 .86464 L
s
.3277 .26068 m
.32869 .26031 L
s
.34403 .88516 m
.34348 .88509 L
s
.34348 .88509 m
.34293 .88502 L
s
.12405 .33096 m
.14488 .32446 L
s
.12405 .33096 m
.12405 .33096 L
s
.12006 .33428 m
.12405 .33096 L
s
.10684 .34813 m
.12405 .33096 L
s
.47016 .86425 m
.46976 .86445 L
s
.34293 .88502 m
.34238 .88495 L
s
.32869 .26031 m
.32967 .25996 L
s
.34238 .88495 m
.34183 .88488 L
s
.34183 .88488 m
.34128 .8848 L
s
.47057 .86404 m
.47016 .86425 L
s
.34128 .8848 m
.34072 .88473 L
s
.32967 .25996 m
.33066 .25961 L
s
.34072 .88473 m
.34017 .88465 L
s
.34017 .88465 m
.33961 .88456 L
s
.47097 .86383 m
.47057 .86404 L
s
.34152 .25638 m
.33025 .25975 L
s
.33961 .88456 m
.33905 .88448 L
s
.33066 .25961 m
.33166 .25927 L
s
.33905 .88448 m
.33398 .88359 L
s
.47097 .86383 m
.47097 .86383 L
s
.4715 .86357 m
.47097 .86383 L
s
.33166 .25927 m
.33266 .25894 L
s
.11625 .33779 m
.12006 .33428 L
s
.47203 .86331 m
.4715 .86357 L
s
.14488 .32446 m
.16585 .31791 L
s
.33266 .25894 m
.33382 .25857 L
s
.33266 .25894 m
.33266 .25894 L
s
.47257 .86304 m
.47203 .86331 L
s
.47218 .8632 m
.47836 .85951 L
s
.18898 .51484 m
.15205 .48714 L
s
.47309 .86276 m
.47257 .86304 L
s
.33382 .25857 m
.33498 .25821 L
s
.33398 .88359 m
.32882 .88249 L
s
.47362 .86248 m
.47309 .86276 L
s
.33498 .25821 m
.33615 .25786 L
s
.11262 .34148 m
.11625 .33779 L
s
.47415 .86218 m
.47362 .86248 L
s
.16585 .31791 m
.18698 .31131 L
s
.33615 .25786 m
.33732 .25752 L
s
.47467 .86187 m
.47415 .86218 L
s
.33732 .25752 m
.3385 .25718 L
s
.32882 .88249 m
.32356 .88117 L
s
.47519 .86156 m
.47467 .86187 L
s
.3385 .25718 m
.33969 .25685 L
s
.32697 .88205 m
.29983 .87282 L
s
.47572 .86124 m
.47519 .86156 L
s
.10915 .34535 m
.11262 .34148 L
s
.33969 .25685 m
.34088 .25654 L
s
.27911 .76463 m
.27548 .81069 L
s
.47624 .8609 m
.47572 .86124 L
s
.18698 .31131 m
.20827 .30466 L
s
.34088 .25654 m
.34207 .25623 L
s
.47675 .86056 m
.47624 .8609 L
s
.32356 .88117 m
.31821 .87963 L
s
.35427 .25358 m
.34152 .25638 L
s
.47727 .86021 m
.47675 .86056 L
s
.34207 .25623 m
.34327 .25593 L
s
.47727 .86021 m
.47727 .86021 L
s
.47792 .85982 m
.47727 .86021 L
s
.10584 .34939 m
.10915 .34535 L
s
.34327 .25593 m
.34448 .25564 L
s
.47858 .85942 m
.47792 .85982 L
s
.20827 .30466 m
.22971 .29797 L
s
.34448 .25564 m
.34569 .25536 L
s
.31821 .87963 m
.31277 .87785 L
s
.47836 .85951 m
.48558 .8545 L
s
.47923 .85901 m
.47858 .85942 L
s
.09253 .37035 m
.10684 .34813 L
s
.34569 .25536 m
.34691 .25509 L
s
.47987 .8586 m
.47923 .85901 L
s
.1027 .35361 m
.10584 .34939 L
s
.34691 .25509 m
.3483 .25478 L
s
.34691 .25509 m
.34691 .25509 L
s
.48052 .85817 m
.47987 .8586 L
s
.31277 .87785 m
.30723 .87583 L
s
.3483 .25478 m
.34969 .25447 L
s
.48117 .85773 m
.48052 .85817 L
s
.22971 .29797 m
.25131 .29123 L
s
.48181 .85729 m
.48117 .85773 L
s
.34969 .25447 m
.35109 .25418 L
s
.09971 .35798 m
.1027 .35361 L
s
.48246 .85683 m
.48181 .85729 L
s
.35109 .25418 m
.3525 .25389 L
s
.4831 .85637 m
.48246 .85683 L
s
.30723 .87583 m
.30158 .87357 L
s
.3525 .25389 m
.35391 .25362 L
s
.48374 .85589 m
.4831 .85637 L
s
.25131 .29123 m
.27306 .28444 L
s
.15205 .48714 m
.11383 .45847 L
s
.35391 .25362 m
.35533 .25335 L
s
.48438 .85541 m
.48374 .85589 L
s
.36852 .25135 m
.35427 .25358 L
s
.09687 .36252 m
.09971 .35798 L
s
.35533 .25335 m
.35676 .2531 L
s
.48502 .85491 m
.48438 .85541 L
s
.30158 .87357 m
.29583 .87104 L
s
.48502 .85491 m
.48502 .85491 L
s
.4858 .85438 m
.48502 .85491 L
s
.35676 .2531 m
.35819 .25285 L
s
.27548 .81069 m
.27173 .8581 L
s
.29983 .87282 m
.27173 .8581 L
s
.48558 .8545 m
.49382 .84822 L
s
.27306 .28444 m
.29498 .27759 L
s
.48658 .85384 m
.4858 .85438 L
s
.35819 .25285 m
.35963 .25262 L
s
.09419 .36722 m
.09687 .36252 L
s
.48736 .85328 m
.48658 .85384 L
s
.35963 .25262 m
.36108 .25239 L
s
.29583 .87104 m
.28998 .86824 L
s
.48813 .85272 m
.48736 .85328 L
s
.36108 .25239 m
.36253 .25218 L
s
.48891 .85214 m
.48813 .85272 L
s
.09165 .37208 m
.09419 .36722 L
s
.36253 .25218 m
.36399 .25198 L
s
.29498 .27759 m
.31706 .2707 L
s
.48968 .85156 m
.48891 .85214 L
s
.36399 .25198 m
.36564 .25173 L
s
.36399 .25198 m
.36399 .25198 L
s
.28998 .86824 m
.28401 .86516 L
s
.49046 .85096 m
.48968 .85156 L
s
.08154 .39736 m
.09253 .37035 L
s
.49123 .85036 m
.49046 .85096 L
s
.36564 .25173 m
.3673 .25149 L
s
.08926 .37709 m
.09165 .37208 L
s
.492 .84974 m
.49123 .85036 L
s
.3673 .25149 m
.36896 .25126 L
s
.31706 .2707 m
.3393 .26375 L
s
.49277 .84912 m
.492 .84974 L
s
.28401 .86516 m
.27793 .86178 L
s
.38429 .24971 m
.36852 .25135 L
s
.36896 .25126 m
.37064 .25104 L
s
.49354 .84848 m
.49277 .84912 L
s
.08702 .38225 m
.08926 .37709 L
s
.37064 .25104 m
.37232 .25083 L
s
.4943 .84783 m
.49354 .84848 L
s
.49382 .84822 m
.50304 .84069 L
s
.37232 .25083 m
.374 .25064 L
s
.4943 .84783 m
.4943 .84783 L
s
.49522 .84714 m
.4943 .84783 L
s
.27793 .86178 m
.27173 .8581 L
s
.36171 .25676 m
.3393 .26375 L
s
.49614 .84644 m
.49522 .84714 L
s
.374 .25064 m
.3757 .25045 L
s
.38429 .24971 m
.79588 .46211 L
s
.79588 .46211 m
.5498 .79815 L
s
.5498 .79815 m
.79588 .46211 L
s
.79588 .46211 m
.38429 .24971 L
s
.08678 .38283 m
.08702 .38225 L
s
.08654 .38341 m
.08678 .38283 L
s
.0863 .384 m
.08654 .38341 L
s
.49705 .84573 m
.49614 .84644 L
s
.08607 .38459 m
.0863 .384 L
s
.3757 .25045 m
.3774 .25028 L
s
.08583 .38518 m
.08607 .38459 L
s
.0856 .38577 m
.08583 .38518 L
s
.49797 .84501 m
.49705 .84573 L
s
.08537 .38636 m
.0856 .38577 L
s
.08515 .38696 m
.08537 .38636 L
s
.27173 .8581 m
.29395 .85331 L
s
.27173 .8581 m
.27173 .8581 L
s
.27173 .8581 m
.26551 .85415 L
s
.27173 .8581 m
.27173 .8581 L
s
.27173 .8581 m
.24326 .83797 L
s
.11383 .45847 m
.07426 .42879 L
s
.3774 .25028 m
.37911 .25012 L
s
.08492 .38756 m
.08515 .38696 L
s
.08469 .38815 m
.08492 .38756 L
s
.49888 .84427 m
.49797 .84501 L
s
.08447 .38876 m
.08469 .38815 L
s
.38429 .24971 m
.36171 .25676 L
s
.08425 .38936 m
.08447 .38876 L
s
.37911 .25012 m
.38083 .24997 L
s
.08425 .38936 m
.08425 .38936 L
s
.08409 .38979 m
.08425 .38936 L
s
.4998 .84353 m
.49888 .84427 L
s
.08394 .39022 m
.08409 .38979 L
s
.08378 .39066 m
.08394 .39022 L
s
.08363 .39109 m
.08378 .39066 L
s
.08348 .39153 m
.08363 .39109 L
s
.38083 .24997 m
.38255 .24983 L
s
.08333 .39196 m
.08348 .39153 L
s
.50071 .84277 m
.4998 .84353 L
s
.08317 .3924 m
.08333 .39196 L
s
.08302 .39284 m
.08317 .3924 L
s
.26551 .85415 m
.25938 .85001 L
s
.08287 .39328 m
.08302 .39284 L
s
.08273 .39372 m
.08287 .39328 L
s
.08258 .39416 m
.08273 .39372 L
s
.50162 .84201 m
.50071 .84277 L
s
.38255 .24983 m
.38429 .24971 L
s
.08243 .3946 m
.08258 .39416 L
s
.29395 .85331 m
.31633 .84848 L
s
.08243 .3946 m
.08243 .3946 L
s
.08232 .39493 m
.08243 .3946 L
s
.08221 .39526 m
.08232 .39493 L
s
.08211 .3956 m
.08221 .39526 L
s
.082 .39593 m
.08211 .3956 L
s
.50253 .84123 m
.50162 .84201 L
s
.08189 .39626 m
.082 .39593 L
s
.08178 .3966 m
.08189 .39626 L
s
.35588 .26291 m
.38429 .24971 L
s
.38429 .24971 m
.38118 .25111 L
s
.38429 .24971 m
.38429 .24971 L
s
.08168 .39693 m
.08178 .3966 L
s
.08157 .39727 m
.08168 .39693 L
s
.08147 .3976 m
.08157 .39727 L
s
.38118 .25111 m
.37807 .25252 L
s
.07426 .42879 m
.08154 .39736 L
s
.08136 .39794 m
.08147 .3976 L
s
.08126 .39828 m
.08136 .39794 L
s
.50344 .84044 m
.50253 .84123 L
s
.37807 .25252 m
.37498 .25394 L
s
.08115 .39862 m
.08126 .39828 L
s
.08115 .39862 m
.08115 .39862 L
s
.08107 .39888 m
.08115 .39862 L
s
.25938 .85001 m
.25333 .84569 L
s
.08099 .39914 m
.08107 .39888 L
s
.37498 .25394 m
.37189 .25537 L
s
.08091 .39941 m
.08099 .39914 L
s
.08083 .39967 m
.08091 .39941 L
s
.50304 .84069 m
.51324 .83192 L
s
.08075 .39993 m
.08083 .39967 L
s
.37189 .25537 m
.3688 .2568 L
s
.08068 .4002 m
.08075 .39993 L
s
.0806 .40046 m
.08068 .4002 L
s
.50434 .83964 m
.50344 .84044 L
s
.08052 .40073 m
.0806 .40046 L
s
.3688 .2568 m
.36572 .25825 L
s
.08044 .40099 m
.08052 .40073 L
s
.08036 .40126 m
.08044 .40099 L
s
.08029 .40153 m
.08036 .40126 L
s
.36572 .25825 m
.36265 .2597 L
s
.08021 .40179 m
.08029 .40153 L
s
.08021 .40179 m
.08021 .40179 L
s
.0796 .40393 m
.08021 .40179 L
s
.36265 .2597 m
.35958 .26117 L
s
.50525 .83882 m
.50434 .83964 L
s
.31633 .84848 m
.33889 .84362 L
s
.35958 .26117 m
.35652 .26264 L
s
.35652 .26264 m
.35347 .26412 L
s
.32852 .27683 m
.35588 .26291 L
s
.07902 .4061 m
.0796 .40393 L
s
.35347 .26412 m
.35042 .26561 L
s
.50525 .83882 m
.50525 .83882 L
s
.50632 .83796 m
.50525 .83882 L
s
.25333 .84569 m
.24735 .84118 L
s
.35042 .26561 m
.34738 .2671 L
s
.34738 .2671 m
.34453 .26855 L
s
.34738 .2671 m
.34738 .2671 L
s
.07845 .40828 m
.07902 .4061 L
s
.34453 .26855 m
.34169 .27001 L
s
.50739 .83709 m
.50632 .83796 L
s
.34169 .27001 m
.33885 .27147 L
s
.07791 .41048 m
.07845 .40828 L
s
.33885 .27147 m
.33602 .27294 L
s
.33602 .27294 m
.33319 .27442 L
s
.50845 .83621 m
.50739 .83709 L
s
.33319 .27442 m
.33037 .27591 L
s
.07738 .4127 m
.07791 .41048 L
s
.33037 .27591 m
.32756 .2774 L
s
.30224 .29148 m
.32852 .27683 L
s
.24735 .84118 m
.24145 .83651 L
s
.32756 .2774 m
.32475 .27891 L
s
.33889 .84362 m
.36161 .83872 L
s
.50952 .83531 m
.50845 .83621 L
s
.32475 .27891 m
.32195 .28042 L
s
.07688 .41494 m
.07738 .4127 L
s
.32195 .28042 m
.31915 .28194 L
s
.31915 .28194 m
.31636 .28346 L
s
.51058 .83441 m
.50952 .83531 L
s
.07639 .4172 m
.07688 .41494 L
s
.31636 .28346 m
.31357 .285 L
s
.31357 .285 m
.31097 .28649 L
s
.31357 .285 m
.31357 .285 L
s
.24326 .83797 m
.21502 .81267 L
s
.31097 .28649 m
.30836 .28798 L
s
.07592 .41948 m
.07639 .4172 L
s
.51165 .83349 m
.51058 .83441 L
s
.30836 .28798 m
.30577 .28949 L
s
.24145 .83651 m
.23563 .83167 L
s
.30577 .28949 m
.30317 .291 L
s
.30317 .291 m
.30059 .29252 L
s
.07548 .42178 m
.07592 .41948 L
s
.27707 .30689 m
.30224 .29148 L
s
.51271 .83256 m
.51165 .83349 L
s
.30059 .29252 m
.29801 .29404 L
s
.29801 .29404 m
.29543 .29558 L
s
.07505 .4241 m
.07548 .42178 L
s
.36161 .83872 m
.38451 .83378 L
s
.29543 .29558 m
.29286 .29712 L
s
.29286 .29712 m
.2903 .29867 L
s
.51377 .83161 m
.51271 .83256 L
s
.2903 .29867 m
.28774 .30022 L
s
.07464 .42644 m
.07505 .4241 L
s
.28774 .30022 m
.28518 .30178 L
s
.51324 .83192 m
.52443 .82192 L
s
.23563 .83167 m
.22988 .82667 L
s
.28518 .30178 m
.28263 .30335 L
s
.51483 .83065 m
.51377 .83161 L
s
.28263 .30335 m
.28025 .30488 L
s
.28263 .30335 m
.28263 .30335 L
s
.07426 .42879 m
.07464 .42644 L
s
.28025 .30488 m
.27787 .30642 L
s
.27787 .30642 m
.2755 .30796 L
s
.25308 .32307 m
.27707 .30689 L
s
.51589 .82968 m
.51483 .83065 L
s
.07426 .42879 m
.07426 .42879 L
s
.07277 .43964 m
.07426 .42879 L
s
.07098 .46409 m
.07426 .42879 L
s
.07426 .42879 m
.07426 .42879 L
s
.2755 .30796 m
.27313 .30951 L
s
.27313 .30951 m
.27077 .31106 L
s
.27077 .31106 m
.26841 .31263 L
s
.51695 .8287 m
.51589 .82968 L
s
.26841 .31263 m
.26606 .3142 L
s
.22988 .82667 m
.22421 .8215 L
s
.26606 .3142 m
.26371 .31577 L
s
.38451 .83378 m
.40758 .82881 L
s
.26371 .31577 m
.26137 .31736 L
s
.26137 .31736 m
.25904 .31895 L
s
.51801 .82771 m
.51695 .8287 L
s
.25904 .31895 m
.25671 .32054 L
s
.25671 .32054 m
.25438 .32215 L
s
.25438 .32215 m
.25221 .32371 L
s
.25438 .32215 m
.25438 .32215 L
s
.23033 .34007 m
.25308 .32307 L
s
.51801 .82771 m
.51801 .82771 L
s
.51924 .82666 m
.51801 .82771 L
s
.25221 .32371 m
.25005 .32528 L
s
.22421 .8215 m
.21861 .81619 L
s
.25005 .32528 m
.24789 .32686 L
s
.07169 .45088 m
.07277 .43964 L
s
.24789 .32686 m
.24574 .32845 L
s
.24574 .32845 m
.24359 .33004 L
s
.52048 .8256 m
.51924 .82666 L
s
.24359 .33004 m
.24145 .33164 L
s
.24145 .33164 m
.23931 .33324 L
s
.23931 .33324 m
.23718 .33485 L
s
.52171 .82453 m
.52048 .8256 L
s
.40758 .82881 m
.43083 .8238 L
s
.23718 .33485 m
.23505 .33647 L
s
.23505 .33647 m
.23293 .33809 L
s
.21861 .81619 m
.21308 .81072 L
s
.23293 .33809 m
.23081 .33972 L
s
.23081 .33972 m
.2287 .34136 L
s
.20891 .35793 m
.23033 .34007 L
s
.52294 .82344 m
.52171 .82453 L
s
.2287 .34136 m
.22674 .34296 L
s
.2287 .34136 m
.2287 .34136 L
s
.22674 .34296 m
.22478 .34456 L
s
.21502 .81267 m
.18769 .7826 L
s
.22478 .34456 m
.22283 .34618 L
s
.07104 .46252 m
.07169 .45088 L
s
.52418 .82234 m
.52294 .82344 L
s
.22283 .34618 m
.22088 .34779 L
s
.22088 .34779 m
.21894 .34942 L
s
.21308 .81072 m
.20763 .80511 L
s
.21894 .34942 m
.21701 .35105 L
s
.21701 .35105 m
.21507 .35269 L
s
.52541 .82123 m
.52418 .82234 L
s
.21507 .35269 m
.21315 .35433 L
s
.52443 .82192 m
.53661 .81067 L
s
.21315 .35433 m
.21123 .35598 L
s
.21123 .35598 m
.20932 .35764 L
s
.45426 .81875 m
.43083 .8238 L
s
.20932 .35764 m
.20741 .3593 L
s
.18893 .37671 m
.20891 .35793 L
s
.52664 .8201 m
.52541 .82123 L
s
.20741 .3593 m
.2055 .36097 L
s
.20763 .80511 m
.20225 .79935 L
s
.2055 .36097 m
.20374 .3626 L
s
.2055 .36097 m
.2055 .36097 L
s
.20374 .3626 m
.20199 .36424 L
s
.20199 .36424 m
.20024 .36588 L
s
.52787 .81896 m
.52664 .8201 L
s
.07082 .47455 m
.07104 .46252 L
s
.20024 .36588 m
.1985 .36754 L
s
.07192 .50256 m
.07098 .46409 L
s
.1985 .36754 m
.19676 .36919 L
s
.19676 .36919 m
.19503 .37086 L
s
.52909 .8178 m
.52787 .81896 L
s
.19503 .37086 m
.1933 .37253 L
s
.20225 .79935 m
.20166 .7987 L
s
.20225 .79935 m
.20225 .79935 L
s
.1933 .37253 m
.19158 .3742 L
s
.20166 .7987 m
.20106 .79805 L
s
.19158 .3742 m
.18987 .37588 L
s
.20106 .79805 m
.20047 .79739 L
s
.20047 .79739 m
.19988 .79674 L
s
.18987 .37588 m
.18816 .37757 L
s
.17055 .39648 m
.18893 .37671 L
s
.19988 .79674 m
.19929 .79608 L
s
.53032 .81663 m
.52909 .8178 L
s
.18816 .37757 m
.18645 .37926 L
s
.19929 .79608 m
.1987 .79543 L
s
.18645 .37926 m
.18475 .38096 L
s
.1987 .79543 m
.19812 .79477 L
s
.45426 .81875 m
.47787 .81366 L
s
.18475 .38096 m
.1832 .38263 L
s
.18475 .38096 m
.18475 .38096 L
s
.19812 .79477 m
.19753 .79411 L
s
.19753 .79411 m
.19694 .79344 L
s
.1832 .38263 m
.18164 .3843 L
s
.19694 .79344 m
.19636 .79278 L
s
.53155 .81545 m
.53032 .81663 L
s
.07104 .48697 m
.07082 .47455 L
s
.18164 .3843 m
.1801 .38598 L
s
.19636 .79278 m
.19578 .79211 L
s
.1801 .38598 m
.17856 .38766 L
s
.19578 .79211 m
.19519 .79144 L
s
.19519 .79144 m
.19478 .79097 L
s
.19519 .79144 m
.19519 .79144 L
s
.17856 .38766 m
.17702 .38935 L
s
.19478 .79097 m
.19436 .79049 L
s
.19436 .79049 m
.19395 .79001 L
s
.17702 .38935 m
.17549 .39104 L
s
.19395 .79001 m
.19353 .78953 L
s
.53277 .81425 m
.53155 .81545 L
s
.19353 .78953 m
.19312 .78905 L
s
.17549 .39104 m
.17397 .39274 L
s
.19312 .78905 m
.1927 .78856 L
s
.1927 .78856 m
.19229 .78808 L
s
.17397 .39274 m
.17245 .39445 L
s
.19229 .78808 m
.19188 .7876 L
s
.17245 .39445 m
.17094 .39616 L
s
.19188 .7876 m
.19147 .78711 L
s
.19147 .78711 m
.19105 .78662 L
s
.17094 .39616 m
.16943 .39788 L
s
.15394 .41735 m
.17055 .39648 L
s
.19105 .78662 m
.19064 .78614 L
s
.19064 .78614 m
.19023 .78565 L
s
.53277 .81425 m
.53277 .81425 L
s
.5342 .81299 m
.53277 .81425 L
s
.16943 .39788 m
.16793 .39961 L
s
.19023 .78565 m
.18992 .78528 L
s
.19023 .78565 m
.19023 .78565 L
s
.18992 .78528 m
.18962 .78492 L
s
.18962 .78492 m
.18931 .78455 L
s
.16793 .39961 m
.16643 .40134 L
s
.18931 .78455 m
.189 .78418 L
s
.189 .78418 m
.1887 .78381 L
s
.16643 .40134 m
.16508 .40303 L
s
.16643 .40134 m
.16643 .40134 L
s
.1887 .78381 m
.18839 .78344 L
s
.18839 .78344 m
.18808 .78308 L
s
.18808 .78308 m
.18778 .78271 L
s
.16508 .40303 m
.16373 .40474 L
s
.07172 .49979 m
.07104 .48697 L
s
.18778 .78271 m
.18747 .78234 L
s
.18769 .7826 m
.16192 .74834 L
s
.18747 .78234 m
.18717 .78196 L
s
.16373 .40474 m
.16239 .40645 L
s
.53562 .81172 m
.5342 .81299 L
s
.18717 .78196 m
.18686 .78159 L
s
.18686 .78159 m
.18656 .78122 L
s
.47787 .81366 m
.50166 .80853 L
s
.18656 .78122 m
.18632 .78093 L
s
.18656 .78122 m
.18656 .78122 L
s
.16239 .40645 m
.16105 .40816 L
s
.18632 .78093 m
.18608 .78064 L
s
.18608 .78064 m
.18585 .78035 L
s
.18585 .78035 m
.18561 .78006 L
s
.16105 .40816 m
.15972 .40988 L
s
.18561 .78006 m
.18537 .77977 L
s
.18537 .77977 m
.18514 .77948 L
s
.18514 .77948 m
.1849 .77919 L
s
.1849 .77919 m
.18466 .7789 L
s
.15972 .40988 m
.15839 .4116 L
s
.18466 .7789 m
.18443 .77861 L
s
.18443 .77861 m
.18419 .77832 L
s
.18419 .77832 m
.18396 .77802 L
s
.15839 .4116 m
.15707 .41334 L
s
.18396 .77802 m
.18372 .77773 L
s
.53704 .81044 m
.53562 .81172 L
s
.18372 .77773 m
.18185 .77538 L
s
.18372 .77773 m
.18372 .77773 L
s
.15707 .41334 m
.15576 .41507 L
s
.15576 .41507 m
.15445 .41682 L
s
.18185 .77538 m
.17998 .77301 L
s
.15445 .41682 m
.15315 .41857 L
s
.13937 .43942 m
.15394 .41735 L
s
.53661 .81067 m
.5498 .79815 L
s
.15315 .41857 m
.15185 .42032 L
s
.53846 .80913 m
.53704 .81044 L
s
.15185 .42032 m
.15056 .42208 L
s
.17998 .77301 m
.17813 .77062 L
s
.07288 .51303 m
.07172 .49979 L
s
.15056 .42208 m
.14941 .42381 L
s
.15056 .42208 m
.15056 .42208 L
s
.14941 .42381 m
.14827 .42554 L
s
.17813 .77062 m
.17628 .76822 L
s
.14827 .42554 m
.14713 .42728 L
s
.07717 .54338 m
.07192 .50256 L
s
.14713 .42728 m
.146 .42903 L
s
.53988 .80782 m
.53846 .80913 L
s
.17628 .76822 m
.17445 .7658 L
s
.146 .42903 m
.14488 .43078 L
s
.14488 .43078 m
.14376 .43253 L
s
.17445 .7658 m
.17263 .76335 L
s
.14376 .43253 m
.14265 .4343 L
s
.50166 .80853 m
.52563 .80336 L
s
.14265 .4343 m
.14154 .43606 L
s
.5413 .80648 m
.53988 .80782 L
s
.14154 .43606 m
.14044 .43784 L
s
.17263 .76335 m
.17082 .7609 L
s
.14044 .43784 m
.13935 .43962 L
s
.12715 .46288 m
.13937 .43942 L
s
.13935 .43962 m
.13826 .4414 L
s
.17082 .7609 m
.16902 .75842 L
s
.07453 .52667 m
.07288 .51303 L
s
.13826 .4414 m
.13718 .4432 L
s
.13718 .4432 m
.13624 .44495 L
s
.13718 .4432 m
.13718 .4432 L
s
.54272 .80514 m
.5413 .80648 L
s
.16902 .75842 m
.16723 .75592 L
s
.13624 .44495 m
.13531 .44672 L
s
.13531 .44672 m
.13439 .44848 L
s
.16723 .75592 m
.16545 .75341 L
s
.13439 .44848 m
.13347 .45026 L
s
.13347 .45026 m
.13256 .45204 L
s
.16545 .75341 m
.16368 .75088 L
s
.54414 .80377 m
.54272 .80514 L
s
.13256 .45204 m
.13165 .45383 L
s
.13165 .45383 m
.13075 .45562 L
s
.16368 .75088 m
.16192 .74834 L
s
.13075 .45562 m
.12986 .45742 L
s
.12986 .45742 m
.12898 .45922 L
s
.07671 .54074 m
.07453 .52667 L
s
.16192 .74834 m
.15415 .73666 L
s
.16192 .74834 m
.16192 .74834 L
s
.16192 .74834 m
.13837 .7106 L
s
.12898 .45922 m
.1281 .46103 L
s
.54555 .80239 m
.54414 .80377 L
s
.1281 .46103 m
.12722 .46285 L
s
.11777 .48796 m
.12715 .46288 L
s
.12722 .46285 m
.12636 .46467 L
s
.52563 .80336 m
.5498 .79815 L
s
.12636 .46467 m
.12564 .46646 L
s
.12636 .46467 m
.12636 .46467 L
s
.12564 .46646 m
.12493 .46825 L
s
.12493 .46825 m
.12423 .47005 L
s
.54697 .80099 m
.54555 .80239 L
s
.12423 .47005 m
.12353 .47186 L
s
.12353 .47186 m
.12284 .47367 L
s
.12284 .47367 m
.12216 .47549 L
s
.15415 .73666 m
.14661 .72463 L
s
.07943 .55524 m
.07671 .54074 L
s
.12216 .47549 m
.12149 .47731 L
s
.12149 .47731 m
.12082 .47914 L
s
.08667 .58561 m
.07717 .54338 L
s
.54838 .79958 m
.54697 .80099 L
s
.12082 .47914 m
.12015 .48097 L
s
.12015 .48097 m
.1195 .48282 L
s
.1195 .48282 m
.11885 .48466 L
s
.11885 .48466 m
.11821 .48652 L
s
.11821 .48652 m
.11773 .48833 L
s
.11821 .48652 m
.11821 .48652 L
s
.11191 .51501 m
.11777 .48796 L
s
.5498 .79815 m
.54838 .79958 L
s
.11773 .48833 m
.11725 .49016 L
s
.14661 .72463 m
.13932 .71226 L
s
.11725 .49016 m
.11678 .49199 L
s
.08274 .57019 m
.07943 .55524 L
s
.11678 .49199 m
.11632 .49382 L
s
.11632 .49382 m
.11586 .49566 L
s
.11586 .49566 m
.11541 .49751 L
s
.11541 .49751 m
.11497 .49937 L
s
.5498 .79815 m
.5498 .79815 L
s
.54602 .79783 m
.5498 .79815 L
s
.5498 .79815 m
.51513 .79497 L
s
.11497 .49937 m
.11454 .50123 L
s
.54225 .7975 m
.54602 .79783 L
s
.11454 .50123 m
.11411 .50309 L
s
.53847 .79716 m
.54225 .7975 L
s
.11411 .50309 m
.11369 .50497 L
s
.13932 .71226 m
.13227 .69956 L
s
.5347 .79681 m
.53847 .79716 L
s
.11369 .50497 m
.11328 .50684 L
s
.13837 .7106 m
.11764 .67025 L
s
.08667 .58561 m
.08274 .57019 L
s
.53093 .79646 m
.5347 .79681 L
s
.11328 .50684 m
.11288 .50873 L
s
.11288 .50873 m
.11264 .51058 L
s
.11288 .50873 m
.11288 .50873 L
s
.52717 .7961 m
.53093 .79646 L
s
.11264 .51058 m
.11241 .51243 L
s
.52341 .79573 m
.52717 .7961 L
s
.11241 .51243 m
.11219 .51429 L
s
.51964 .79535 m
.52341 .79573 L
s
.11219 .51429 m
.11198 .51616 L
s
.51589 .79497 m
.51964 .79535 L
s
.11068 .54459 m
.11191 .51501 L
s
.13227 .69956 m
.12549 .68651 L
s
.11198 .51616 m
.11177 .51803 L
s
.51513 .79497 m
.4811 .79073 L
s
.51213 .79458 m
.51589 .79497 L
s
.11177 .51803 m
.11157 .51991 L
s
.50838 .79418 m
.51213 .79458 L
s
.08667 .58561 m
.08667 .58561 L
s
.08911 .58495 m
.08667 .58561 L
s
.09114 .60108 m
.08667 .58561 L
s
.10027 .62824 m
.08667 .58561 L
s
.11157 .51991 m
.11138 .52179 L
s
.50462 .79378 m
.50838 .79418 L
s
.11138 .52179 m
.1112 .52369 L
s
.50462 .79378 m
.50462 .79378 L
s
.50108 .79332 m
.50462 .79378 L
s
.09155 .58429 m
.08911 .58495 L
s
.1112 .52369 m
.11103 .52558 L
s
.49753 .79286 m
.50108 .79332 L
s
.12549 .68651 m
.11898 .67312 L
s
.11103 .52558 m
.11086 .52749 L
s
.49399 .79239 m
.49753 .79286 L
s
.11086 .52749 m
.1107 .5294 L
s
.09398 .58364 m
.09155 .58429 L
s
.49045 .79192 m
.49399 .79239 L
s
.09602 .61619 m
.09114 .60108 L
s
.1107 .5294 m
.11056 .53132 L
s
.48691 .79143 m
.49045 .79192 L
s
.11056 .53132 m
.11059 .5332 L
s
.11056 .53132 m
.11056 .53132 L
s
.09643 .58298 m
.09398 .58364 L
s
.48337 .79094 m
.48691 .79143 L
s
.11059 .5332 m
.11063 .53508 L
s
.11898 .67312 m
.11276 .6594 L
s
.47984 .79045 m
.48337 .79094 L
s
.11764 .67025 m
.10027 .62824 L
s
.4811 .79073 m
.44774 .78542 L
s
.11063 .53508 m
.11067 .53697 L
s
.47631 .78995 m
.47984 .79045 L
s
.10126 .63094 m
.09602 .61619 L
s
.09887 .58232 m
.09643 .58298 L
s
.11067 .53697 m
.11073 .53887 L
s
.47278 .78944 m
.47631 .78995 L
s
.11276 .6594 m
.10685 .64534 L
s
.11073 .53887 m
.11079 .54077 L
s
.46926 .78892 m
.47278 .78944 L
s
.10685 .64534 m
.10126 .63094 L
s
.11079 .54077 m
.11087 .54269 L
s
.10132 .58166 m
.09887 .58232 L
s
.46574 .7884 m
.46926 .78892 L
s
.11087 .54269 m
.11095 .5446 L
s
.46221 .78787 m
.46574 .7884 L
s
.11603 .57768 m
.11068 .54459 L
s
.11095 .5446 m
.11104 .54653 L
s
.46221 .78787 m
.46221 .78787 L
s
.45888 .78729 m
.46221 .78787 L
s
.10376 .581 m
.10132 .58166 L
s
.11104 .54653 m
.11114 .54846 L
s
.45555 .78671 m
.45888 .78729 L
s
.11114 .54846 m
.11125 .5504 L
s
.45222 .78612 m
.45555 .78671 L
s
.11125 .5504 m
.11137 .55235 L
s
.10621 .58033 m
.10376 .581 L
s
.44889 .78553 m
.45222 .78612 L
s
.11137 .55235 m
.11149 .5543 L
s
.44556 .78493 m
.44889 .78553 L
s
.44774 .78542 m
.41508 .77901 L
s
.11149 .5543 m
.11182 .55621 L
s
.11149 .5543 m
.11149 .5543 L
s
.44224 .78432 m
.44556 .78493 L
s
.10866 .57967 m
.10621 .58033 L
s
.11182 .55621 m
.11215 .55812 L
s
.43892 .78371 m
.44224 .78432 L
s
.11215 .55812 m
.1125 .56005 L
s
.43561 .78309 m
.43892 .78371 L
s
.1125 .56005 m
.11285 .56198 L
s
.43229 .78246 m
.43561 .78309 L
s
.11112 .57901 m
.10866 .57967 L
s
.42898 .78183 m
.43229 .78246 L
s
.11285 .56198 m
.11321 .56391 L
s
.42567 .78119 m
.42898 .78183 L
s
.11321 .56391 m
.11359 .56586 L
s
.42236 .78055 m
.42567 .78119 L
s
.11359 .56586 m
.11397 .56781 L
s
.11357 .57835 m
.11112 .57901 L
s
.42236 .78055 m
.42236 .78055 L
s
.41923 .77986 m
.42236 .78055 L
s
.11397 .56781 m
.11436 .56977 L
s
.4161 .77917 m
.41923 .77986 L
s
.11436 .56977 m
.11476 .57174 L
s
.41297 .77847 m
.4161 .77917 L
s
.41508 .77901 m
.38317 .77147 L
s
.11603 .57768 m
.11357 .57835 L
s
.11476 .57174 m
.11518 .57371 L
s
.40984 .77777 m
.41297 .77847 L
s
.11518 .57371 m
.1156 .57569 L
s
.40672 .77706 m
.40984 .77777 L
s
.1156 .57569 m
.11603 .57768 L
s
.4036 .77634 m
.40672 .77706 L
s
.11603 .57768 m
.11603 .57768 L
s
.11603 .57768 m
.11668 .57962 L
s
.12857 .60972 m
.11603 .57768 L
s
.40048 .77562 m
.4036 .77634 L
s
.11668 .57962 m
.11733 .58155 L
s
.39736 .77489 m
.40048 .77562 L
s
.11733 .58155 m
.11799 .58347 L
s
.39425 .77415 m
.39736 .77489 L
s
.39114 .77341 m
.39425 .77415 L
s
.11799 .58347 m
.11865 .58539 L
s
.38803 .77267 m
.39114 .77341 L
s
.11865 .58539 m
.11932 .58731 L
s
.38493 .77192 m
.38803 .77267 L
s
.11932 .58731 m
.12 .58921 L
s
.38493 .77192 m
.38493 .77192 L
s
.38199 .77113 m
.38493 .77192 L
s
.38317 .77147 m
.35207 .76274 L
s
.12 .58921 m
.12068 .59111 L
s
.37905 .77033 m
.38199 .77113 L
s
.12068 .59111 m
.12137 .59301 L
s
.37611 .76953 m
.37905 .77033 L
s
.12137 .59301 m
.12207 .5949 L
s
.37317 .76872 m
.37611 .76953 L
s
.12207 .5949 m
.12277 .59678 L
s
.37024 .7679 m
.37317 .76872 L
s
.12277 .59678 m
.12348 .59866 L
s
.36731 .76708 m
.37024 .7679 L
s
.12348 .59866 m
.12419 .60054 L
s
.36439 .76626 m
.36731 .76708 L
s
.12419 .60054 m
.1251 .60235 L
s
.12419 .60054 m
.12419 .60054 L
s
.36147 .76543 m
.36439 .76626 L
s
.1251 .60235 m
.12601 .60417 L
s
.35855 .76459 m
.36147 .76543 L
s
.12601 .60417 m
.12694 .60597 L
s
.35563 .76375 m
.35855 .76459 L
s
.35272 .7629 m
.35563 .76375 L
s
.12694 .60597 m
.12786 .60777 L
s
.34981 .76205 m
.35272 .7629 L
s
.35207 .76274 m
.32183 .75277 L
s
.12786 .60777 m
.1288 .60957 L
s
.34981 .76205 m
.34981 .76205 L
s
.34705 .76116 m
.34981 .76205 L
s
.14541 .63664 m
.12857 .60972 L
s
.1288 .60957 m
.12973 .61136 L
s
.3443 .76026 m
.34705 .76116 L
s
.12973 .61136 m
.13068 .61315 L
s
.34155 .75936 m
.3443 .76026 L
s
.13068 .61315 m
.13163 .61493 L
s
.3388 .75845 m
.34155 .75936 L
s
.13163 .61493 m
.13259 .6167 L
s
.33605 .75753 m
.3388 .75845 L
s
.13259 .6167 m
.13355 .61847 L
s
.33331 .75662 m
.33605 .75753 L
s
.13355 .61847 m
.13451 .62023 L
s
.33057 .75569 m
.33331 .75662 L
s
.13451 .62023 m
.13549 .62199 L
s
.32784 .75476 m
.33057 .75569 L
s
.13549 .62199 m
.13664 .6237 L
s
.13549 .62199 m
.13549 .62199 L
s
.32511 .75383 m
.32784 .75476 L
s
.13664 .6237 m
.13779 .6254 L
s
.32238 .75289 m
.32511 .75383 L
s
.13779 .6254 m
.13896 .6271 L
s
.32183 .75277 m
.29256 .74146 L
s
.31965 .75194 m
.32238 .75289 L
s
.31693 .75099 m
.31965 .75194 L
s
.13896 .6271 m
.14012 .6288 L
s
.31693 .75099 m
.31693 .75099 L
s
.31436 .75 m
.31693 .75099 L
s
.14012 .6288 m
.1413 .63048 L
s
.31179 .74901 m
.31436 .75 L
s
.1413 .63048 m
.14247 .63217 L
s
.30922 .74801 m
.31179 .74901 L
s
.14247 .63217 m
.14366 .63384 L
s
.30666 .74701 m
.30922 .74801 L
s
.14366 .63384 m
.14484 .63552 L
s
.3041 .746 m
.30666 .74701 L
s
.14484 .63552 m
.14604 .63718 L
s
.16529 .65989 m
.14541 .63664 L
s
.30154 .74498 m
.3041 .746 L
s
.14604 .63718 m
.14724 .63885 L
s
.29899 .74396 m
.30154 .74498 L
s
.14724 .63885 m
.14844 .6405 L
s
.29643 .74294 m
.29899 .74396 L
s
.14844 .6405 m
.14965 .64215 L
s
.14965 .64215 m
.15102 .64376 L
s
.14965 .64215 m
.14965 .64215 L
s
.29389 .74191 m
.29643 .74294 L
s
.29134 .74088 m
.29389 .74191 L
s
.29256 .74146 m
.26433 .72872 L
s
.15102 .64376 m
.1524 .64536 L
s
.2888 .73984 m
.29134 .74088 L
s
.1524 .64536 m
.15379 .64696 L
s
.28626 .73879 m
.2888 .73984 L
s
.28626 .73879 m
.28626 .73879 L
s
.28387 .73771 m
.28626 .73879 L
s
.15379 .64696 m
.15518 .64855 L
s
.28149 .73662 m
.28387 .73771 L
s
.15518 .64855 m
.15657 .65013 L
s
.15657 .65013 m
.15797 .65171 L
s
.2791 .73553 m
.28149 .73662 L
s
.15797 .65171 m
.15938 .65329 L
s
.27672 .73443 m
.2791 .73553 L
s
.15938 .65329 m
.16079 .65486 L
s
.27434 .73333 m
.27672 .73443 L
s
.16079 .65486 m
.1622 .65643 L
s
.27197 .73222 m
.27434 .73333 L
s
.1622 .65643 m
.16362 .65799 L
s
.2696 .73111 m
.27197 .73222 L
s
.16362 .65799 m
.16504 .65955 L
s
.26723 .72999 m
.2696 .73111 L
s
.18751 .68029 m
.16529 .65989 L
s
.16504 .65955 m
.16647 .6611 L
s
.26487 .72887 m
.26723 .72999 L
s
.16647 .6611 m
.16806 .6626 L
s
.16647 .6611 m
.16647 .6611 L
s
.26433 .72872 m
.2373 .71441 L
s
.26251 .72774 m
.26487 .72887 L
s
.16806 .6626 m
.16965 .66411 L
s
.26015 .72661 m
.26251 .72774 L
s
.2578 .72547 m
.26015 .72661 L
s
.16965 .66411 m
.17124 .66561 L
s
.2578 .72547 m
.2578 .72547 L
s
.25559 .72429 m
.2578 .72547 L
s
.17124 .66561 m
.17284 .6671 L
s
.25338 .72311 m
.25559 .72429 L
s
.17284 .6671 m
.17445 .66859 L
s
.25118 .72193 m
.25338 .72311 L
s
.17445 .66859 m
.17606 .67007 L
s
.24898 .72074 m
.25118 .72193 L
s
.17606 .67007 m
.17767 .67155 L
s
.24679 .71954 m
.24898 .72074 L
s
.17767 .67155 m
.17929 .67302 L
s
.2446 .71834 m
.24679 .71954 L
s
.17929 .67302 m
.18091 .67449 L
s
.18091 .67449 m
.18254 .67596 L
s
.24241 .71714 m
.2446 .71834 L
s
.18254 .67596 m
.18417 .67742 L
s
.24023 .71593 m
.24241 .71714 L
s
.18417 .67742 m
.1858 .67887 L
s
.1858 .67887 m
.18759 .68028 L
s
.1858 .67887 m
.1858 .67887 L
s
.2373 .71441 m
.21161 .69835 L
s
.23805 .71471 m
.24023 .71593 L
s
.21161 .69835 m
.18751 .68029 L
s
.23587 .7135 m
.23805 .71471 L
s
.18759 .68028 m
.18938 .68169 L
s
.2337 .71227 m
.23587 .7135 L
s
.23153 .71104 m
.2337 .71227 L
s
.23153 .71104 m
.23153 .71104 L
s
.22951 .70978 m
.23153 .71104 L
s
.18938 .68169 m
.19117 .6831 L
s
.22749 .7085 m
.22951 .70978 L
s
.19117 .6831 m
.19297 .68449 L
s
.22548 .70722 m
.22749 .7085 L
s
.19297 .68449 m
.19478 .68589 L
s
.19478 .68589 m
.19658 .68728 L
s
.22347 .70594 m
.22548 .70722 L
s
.19658 .68728 m
.1984 .68866 L
s
.22146 .70466 m
.22347 .70594 L
s
.20752 .69551 m
.2095 .69683 L
s
.20752 .69551 m
.20752 .69551 L
s
.20568 .69415 m
.20752 .69551 L
s
.1984 .68866 m
.20021 .69004 L
s
.20386 .69279 m
.20568 .69415 L
s
.21946 .70336 m
.22146 .70466 L
s
.20021 .69004 m
.20203 .69142 L
s
.20203 .69142 m
.20386 .69279 L
s
.2095 .69683 m
.21148 .69815 L
s
.21746 .70207 m
.21946 .70336 L
s
.21148 .69815 m
.21347 .69946 L
s
.21546 .70077 m
.21746 .70207 L
s
.21347 .69946 m
.21546 .70077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{149, 149},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 148}, {148, 0}} -> {0.0917595, -4.71685*^-6, \
0.00516462, 0.00637412}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[SolidCornerCube[50,37.5,Mirrored->True],PlotType->\
TopView, AspectRatio->1];\
\>", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0253968 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .97619 m
.02381 .97212 L
.02381 .95996 L
.02381 .93994 L
.02381 .91239 L
.02381 .87779 L
.02381 .83672 L
.02381 .78989 L
.02381 .7381 L
.02381 .68223 L
.02381 .62325 L
.02381 .56216 L
.02381 .5 L
.02381 .43784 L
.02381 .37675 L
.02381 .31777 L
.02381 .2619 L
.02381 .21011 L
.02381 .16328 L
.02381 .12221 L
.02381 .08761 L
.02381 .06006 L
.02381 .04004 L
.02381 .02788 L
.02381 .02381 L
.02381 .02788 L
.02381 .04004 L
.02381 .06006 L
.02381 .08761 L
.02381 .12221 L
.02381 .16328 L
.02381 .21011 L
.02381 .2619 L
.02381 .31777 L
.02381 .37675 L
.02381 .43784 L
.02381 .5 L
.02381 .56216 L
.02381 .62325 L
.02381 .68223 L
.02381 .7381 L
.02381 .78989 L
.02381 .83672 L
.02381 .87779 L
.02381 .91239 L
.02381 .93994 L
.02381 .95996 L
.02381 .97212 L
.02381 .97619 L
s
.02381 .65081 m
.02381 .6392 L
.02381 .62744 L
.02381 .61551 L
.02381 .60341 L
.02381 .59114 L
.02381 .5787 L
.02381 .56607 L
.02381 .55326 L
.02381 .54026 L
.02381 .52705 L
.02381 .51363 L
.02381 .5 L
.02381 .5 L
.06576 .5 L
.10771 .5 L
.14967 .5 L
.19162 .5 L
.23357 .5 L
.27552 .5 L
.31747 .5 L
.35943 .5 L
.40138 .5 L
.44333 .5 L
.48528 .5 L
.52723 .5 L
.52723 .5 L
.52274 .50286 L
.51826 .50571 L
.51377 .50855 L
.50928 .51138 L
.50479 .5142 L
.5003 .51701 L
.49581 .51981 L
.49132 .5226 L
.48683 .52538 L
.48234 .52816 L
.47785 .53092 L
.47336 .53368 L
.47336 .53368 L
.46922 .53642 L
.46508 .53916 L
.46094 .54189 L
.4568 .54461 L
.45266 .54732 L
.44852 .55003 L
.44438 .55272 L
.44024 .55541 L
.4361 .55809 L
.43196 .56076 L
Mistroke
.42782 .56342 L
.42368 .56607 L
.42368 .56607 L
.41986 .56872 L
.41604 .57136 L
.41221 .57399 L
.40839 .57661 L
.40457 .57922 L
.40075 .58183 L
.39693 .58442 L
.39311 .58701 L
.38928 .5896 L
.38546 .59217 L
.38164 .59474 L
.37782 .5973 L
.37782 .5973 L
.37429 .59985 L
.37077 .60239 L
.36724 .60493 L
.36371 .60746 L
.36019 .60998 L
.35666 .6125 L
.35314 .61501 L
.34961 .61751 L
.34608 .62 L
.34256 .62249 L
.33903 .62496 L
.33551 .62744 L
.33551 .62744 L
.33226 .6299 L
.32901 .63236 L
.32577 .63481 L
.32252 .63725 L
.31927 .63969 L
.31603 .64212 L
.31278 .64454 L
.30953 .64696 L
.30629 .64936 L
.30304 .65177 L
.29979 .65416 L
.29655 .65655 L
.29655 .65655 L
.29357 .65893 L
.29059 .6613 L
.28761 .66367 L
.28463 .66603 L
.28165 .66839 L
.27867 .67073 L
.27569 .67308 L
.27271 .67541 L
Mistroke
.26973 .67774 L
.26675 .68006 L
.26377 .68237 L
.26079 .68468 L
.26079 .68468 L
.25807 .68698 L
.25535 .68927 L
.25263 .69156 L
.24991 .69384 L
.24719 .69612 L
.24447 .69838 L
.24175 .70065 L
.23903 .7029 L
.23631 .70515 L
.23359 .70739 L
.23087 .70963 L
.22815 .71186 L
.22815 .71186 L
.22569 .71408 L
.22322 .71629 L
.22076 .7185 L
.21829 .72071 L
.21583 .7229 L
.21336 .72509 L
.2109 .72728 L
.20843 .72945 L
.20597 .73162 L
.2035 .73379 L
.20104 .73594 L
.19857 .7381 L
.19857 .7381 L
.19636 .74024 L
.19415 .74238 L
.19194 .74451 L
.18973 .74664 L
.18752 .74875 L
.1853 .75087 L
.18309 .75297 L
.18088 .75507 L
.17867 .75716 L
.17646 .75925 L
.17425 .76133 L
.17204 .7634 L
.17204 .7634 L
.17008 .76547 L
.16812 .76753 L
.16616 .76959 L
.16421 .77163 L
.16225 .77367 L
.16029 .77571 L
Mistroke
.15834 .77774 L
.15638 .77976 L
.15442 .78177 L
.15247 .78378 L
.15051 .78578 L
.14855 .78778 L
.14855 .78778 L
.14686 .78977 L
.14516 .79175 L
.14346 .79372 L
.14176 .79569 L
.14007 .79765 L
.13837 .79961 L
.13667 .80156 L
.13498 .8035 L
.13328 .80543 L
.13158 .80736 L
.12988 .80928 L
.12819 .8112 L
.12819 .8112 L
.12676 .8131 L
.12533 .815 L
.1239 .8169 L
.12247 .81879 L
.12104 .82067 L
.11961 .82254 L
.11818 .82441 L
.11675 .82627 L
.11532 .82812 L
.11389 .82996 L
.11246 .8318 L
.11103 .83363 L
.11103 .83363 L
.10988 .83546 L
.10873 .83727 L
.10758 .83908 L
.10643 .84089 L
.10527 .84268 L
.10412 .84447 L
.10297 .84625 L
.10182 .84802 L
.10067 .84979 L
.09952 .85155 L
.09837 .8533 L
.09722 .85504 L
.09722 .85504 L
.09637 .85678 L
.09551 .85851 L
.09466 .86023 L
.0938 .86194 L
Mistroke
.09295 .86365 L
.09209 .86535 L
.09124 .86704 L
.09038 .86872 L
.08953 .87039 L
.08867 .87206 L
.08782 .87372 L
.08696 .87537 L
.08696 .87537 L
.08643 .87701 L
.08589 .87864 L
.08535 .88027 L
.08482 .88189 L
.08428 .8835 L
.08374 .8851 L
.08321 .88669 L
.08267 .88827 L
.08213 .88985 L
.0816 .89141 L
.08106 .89297 L
.08053 .89452 L
.08053 .89452 L
.08034 .89606 L
.08015 .89759 L
.07996 .89911 L
.07978 .90063 L
.07959 .90213 L
.0794 .90363 L
.07921 .90511 L
.07903 .90659 L
.07884 .90805 L
.07865 .90951 L
.07846 .91096 L
.07828 .91239 L
.07828 .91239 L
.07374 .91239 L
.0692 .91239 L
.06466 .91239 L
.06012 .91239 L
.05558 .91239 L
.05104 .91239 L
.0465 .91239 L
.04197 .91239 L
.03743 .91239 L
.03289 .91239 L
.02835 .91239 L
.02381 .91239 L
.02381 .91239 L
.02381 .90063 L
.02381 .88827 L
Mistroke
.02381 .87537 L
.02381 .86194 L
.02381 .84802 L
.02381 .83363 L
.02381 .81879 L
.02381 .8035 L
.02381 .78778 L
.02381 .77163 L
.02381 .75507 L
.02381 .7381 L
.02381 .7381 L
.02381 .73427 L
.02381 .73042 L
.02381 .72655 L
.02381 .72266 L
.02381 .71875 L
.02381 .71482 L
.02381 .71087 L
.02381 .70689 L
.02381 .7029 L
.02381 .69889 L
.02381 .69485 L
.02381 .6908 L
.02381 .6908 L
.02381 .69029 L
.02381 .68978 L
.02381 .68927 L
.02381 .68876 L
.02381 .68825 L
.02381 .68774 L
.02381 .68723 L
.02381 .68672 L
.02381 .68621 L
.02381 .6857 L
.02381 .68519 L
.02381 .68468 L
.02381 .68468 L
.02381 .68402 L
.02381 .68336 L
.02381 .6827 L
.02381 .68204 L
.02381 .68138 L
.02381 .68072 L
.02381 .68006 L
.02381 .67939 L
.02381 .67873 L
.02381 .67807 L
.02381 .6774 L
.02381 .67674 L
.02381 .67674 L
Mistroke
.02381 .67585 L
.02381 .67497 L
.02381 .67408 L
.02381 .67319 L
.02381 .6723 L
.02381 .6714 L
.02381 .67051 L
.02381 .66962 L
.02381 .66872 L
.02381 .66783 L
.02381 .66693 L
.02381 .66603 L
.02381 .66603 L
.02381 .66477 L
.02381 .66351 L
.02381 .66225 L
.02381 .66099 L
.02381 .65972 L
.02381 .65845 L
.02381 .65718 L
.02381 .65591 L
.02381 .65464 L
.02381 .65336 L
.02381 .65209 L
.02381 .65081 L
Mfstroke
.02381 .5 m
.02381 .48637 L
.02381 .47295 L
.02381 .45974 L
.02381 .44674 L
.02381 .43393 L
.02381 .4213 L
.02381 .40886 L
.02381 .39659 L
.02381 .38449 L
.02381 .37256 L
.02381 .3608 L
.02381 .34919 L
.02381 .34919 L
.02381 .34791 L
.02381 .34664 L
.02381 .34536 L
.02381 .34409 L
.02381 .34282 L
.02381 .34155 L
.02381 .34028 L
.02381 .33901 L
.02381 .33775 L
.02381 .33649 L
.02381 .33523 L
.02381 .33397 L
.02381 .33397 L
.02381 .33307 L
.02381 .33217 L
.02381 .33128 L
.02381 .33038 L
.02381 .32949 L
.02381 .3286 L
.02381 .3277 L
.02381 .32681 L
.02381 .32592 L
.02381 .32503 L
.02381 .32415 L
.02381 .32326 L
.02381 .32326 L
.02381 .3226 L
.02381 .32193 L
.02381 .32127 L
.02381 .32061 L
.02381 .31994 L
.02381 .31928 L
.02381 .31862 L
.02381 .31796 L
.02381 .3173 L
.02381 .31664 L
Mistroke
.02381 .31598 L
.02381 .31532 L
.02381 .31532 L
.02381 .31481 L
.02381 .3143 L
.02381 .31379 L
.02381 .31328 L
.02381 .31277 L
.02381 .31226 L
.02381 .31175 L
.02381 .31124 L
.02381 .31073 L
.02381 .31022 L
.02381 .30971 L
.02381 .3092 L
.02381 .3092 L
.02381 .30515 L
.02381 .30111 L
.02381 .2971 L
.02381 .29311 L
.02381 .28913 L
.02381 .28518 L
.02381 .28125 L
.02381 .27734 L
.02381 .27345 L
.02381 .26958 L
.02381 .26573 L
.02381 .2619 L
.02381 .2619 L
.02381 .24493 L
.02381 .22837 L
.02381 .21222 L
.02381 .1965 L
.02381 .18121 L
.02381 .16637 L
.02381 .15198 L
.02381 .13806 L
.02381 .12463 L
.02381 .11173 L
.02381 .09937 L
.02381 .08761 L
.02381 .08761 L
.02835 .08761 L
.03289 .08761 L
.03743 .08761 L
.04197 .08761 L
.0465 .08761 L
.05104 .08761 L
.05558 .08761 L
.06012 .08761 L
Mistroke
.06466 .08761 L
.0692 .08761 L
.07374 .08761 L
.07828 .08761 L
.07828 .08761 L
.07846 .08904 L
.07865 .09049 L
.07884 .09195 L
.07903 .09341 L
.07921 .09489 L
.0794 .09637 L
.07959 .09787 L
.07978 .09937 L
.07996 .10089 L
.08015 .10241 L
.08034 .10394 L
.08053 .10548 L
.08053 .10548 L
.08106 .10703 L
.0816 .10859 L
.08213 .11015 L
.08267 .11173 L
.08321 .11331 L
.08374 .1149 L
.08428 .1165 L
.08482 .11811 L
.08535 .11973 L
.08589 .12136 L
.08643 .12299 L
.08696 .12463 L
.08696 .12463 L
.08782 .12628 L
.08867 .12794 L
.08953 .12961 L
.09038 .13128 L
.09124 .13296 L
.09209 .13465 L
.09295 .13635 L
.0938 .13806 L
.09466 .13977 L
.09551 .14149 L
.09637 .14322 L
.09722 .14496 L
.09722 .14496 L
.09837 .1467 L
.09952 .14845 L
.10067 .15021 L
.10182 .15198 L
.10297 .15375 L
.10412 .15553 L
Mistroke
.10527 .15732 L
.10643 .15911 L
.10758 .16092 L
.10873 .16273 L
.10988 .16454 L
.11103 .16637 L
.11103 .16637 L
.11246 .1682 L
.11389 .17004 L
.11532 .17188 L
.11675 .17373 L
.11818 .17559 L
.11961 .17746 L
.12104 .17933 L
.12247 .18121 L
.1239 .1831 L
.12533 .185 L
.12676 .1869 L
.12819 .1888 L
.12819 .1888 L
.12988 .19072 L
.13158 .19264 L
.13328 .19457 L
.13498 .1965 L
.13667 .19844 L
.13837 .20039 L
.14007 .20235 L
.14176 .20431 L
.14346 .20628 L
.14516 .20825 L
.14686 .21023 L
.14855 .21222 L
.14855 .21222 L
.15051 .21422 L
.15247 .21622 L
.15442 .21823 L
.15638 .22024 L
.15834 .22226 L
.16029 .22429 L
.16225 .22633 L
.16421 .22837 L
.16616 .23041 L
.16812 .23247 L
.17008 .23453 L
.17204 .2366 L
.17204 .2366 L
.17425 .23867 L
.17646 .24075 L
.17867 .24284 L
.18088 .24493 L
Mistroke
.18309 .24703 L
.1853 .24913 L
.18752 .25125 L
.18973 .25336 L
.19194 .25549 L
.19415 .25762 L
.19636 .25976 L
.19857 .2619 L
.19857 .2619 L
.20104 .26406 L
.2035 .26621 L
.20597 .26838 L
.20843 .27055 L
.2109 .27272 L
.21336 .27491 L
.21583 .2771 L
.21829 .27929 L
.22076 .2815 L
.22322 .28371 L
.22569 .28592 L
.22815 .28814 L
.22815 .28814 L
.23087 .29037 L
.23359 .29261 L
.23631 .29485 L
.23903 .2971 L
.24175 .29935 L
.24447 .30162 L
.24719 .30388 L
.24991 .30616 L
.25263 .30844 L
.25535 .31073 L
.25807 .31302 L
.26079 .31532 L
.26079 .31532 L
.26377 .31763 L
.26675 .31994 L
.26973 .32226 L
.27271 .32459 L
.27569 .32692 L
.27867 .32927 L
.28165 .33161 L
.28463 .33397 L
.28761 .33633 L
.29059 .3387 L
.29357 .34107 L
.29655 .34345 L
.29655 .34345 L
.29979 .34584 L
.30304 .34823 L
Mistroke
.30629 .35064 L
.30953 .35304 L
.31278 .35546 L
.31603 .35788 L
.31927 .36031 L
.32252 .36275 L
.32577 .36519 L
.32901 .36764 L
.33226 .3701 L
.33551 .37256 L
.33551 .37256 L
.33903 .37504 L
.34256 .37751 L
.34608 .38 L
.34961 .38249 L
.35314 .38499 L
.35666 .3875 L
.36019 .39002 L
.36371 .39254 L
.36724 .39507 L
.37077 .39761 L
.37429 .40015 L
.37782 .4027 L
.37782 .4027 L
.38164 .40526 L
.38546 .40783 L
.38928 .4104 L
.39311 .41299 L
.39693 .41558 L
.40075 .41817 L
.40457 .42078 L
.40839 .42339 L
.41221 .42601 L
.41604 .42864 L
.41986 .43128 L
.42368 .43393 L
.42368 .43393 L
.42782 .43658 L
.43196 .43924 L
.4361 .44191 L
.44024 .44459 L
.44438 .44728 L
.44852 .44997 L
.45266 .45268 L
.4568 .45539 L
.46094 .45811 L
.46508 .46084 L
.46922 .46358 L
.47336 .46632 L
.47336 .46632 L
Mistroke
.47785 .46908 L
.48234 .47184 L
.48683 .47462 L
.49132 .4774 L
.49581 .48019 L
.5003 .48299 L
.50479 .4858 L
.50928 .48862 L
.51377 .49145 L
.51826 .49429 L
.52274 .49714 L
.52723 .5 L
.52723 .5 L
.48528 .5 L
.44333 .5 L
.40138 .5 L
.35943 .5 L
.31747 .5 L
.27552 .5 L
.23357 .5 L
.19162 .5 L
.14967 .5 L
.10771 .5 L
.06576 .5 L
.02381 .5 L
Mfstroke
.02381 .03343 m
.02381 .03602 L
.02381 .03893 L
.02381 .04217 L
.02381 .04574 L
.02381 .04966 L
.02381 .05393 L
.02381 .05856 L
.02381 .06356 L
.02381 .06896 L
.02381 .07475 L
.02381 .08096 L
.02381 .08761 L
.02381 .08761 L
.06576 .08761 L
.10771 .08761 L
.14967 .08761 L
.19162 .08761 L
.23357 .08761 L
.27552 .08761 L
.31747 .08761 L
.35943 .08761 L
.40138 .08761 L
.44333 .08761 L
.48528 .08761 L
.52723 .08761 L
.52723 .08761 L
.52274 .08618 L
.51826 .08478 L
.51377 .0834 L
.50928 .08204 L
.50479 .08069 L
.5003 .07937 L
.49581 .07806 L
.49132 .07677 L
.48683 .0755 L
.48234 .07425 L
.47785 .07302 L
.47336 .0718 L
.47336 .0718 L
.46922 .0706 L
.46508 .06942 L
.46094 .06826 L
.4568 .06711 L
.45266 .06599 L
.44852 .06488 L
.44438 .06378 L
.44024 .0627 L
.4361 .06164 L
.43196 .0606 L
Mistroke
.42782 .05957 L
.42368 .05856 L
.42368 .05856 L
.41986 .05756 L
.41604 .05659 L
.41221 .05562 L
.40839 .05468 L
.40457 .05374 L
.40075 .05283 L
.39693 .05193 L
.39311 .05104 L
.38928 .05017 L
.38546 .04932 L
.38164 .04848 L
.37782 .04766 L
.37782 .04766 L
.37429 .04685 L
.37077 .04606 L
.36724 .04528 L
.36371 .04451 L
.36019 .04377 L
.35666 .04303 L
.35314 .04231 L
.34961 .04161 L
.34608 .04092 L
.34256 .04024 L
.33903 .03958 L
.33551 .03893 L
.33551 .03893 L
.33226 .0383 L
.32901 .03768 L
.32577 .03707 L
.32252 .03648 L
.31927 .03591 L
.31603 .03534 L
.31278 .03479 L
.30953 .03426 L
.30629 .03374 L
.30304 .03323 L
.29979 .03274 L
.29655 .03225 L
.29655 .03225 L
.29357 .03179 L
.29059 .03134 L
.28761 .0309 L
.28463 .03047 L
.28165 .03006 L
.27867 .02966 L
.27569 .02927 L
.27271 .0289 L
Mistroke
.26973 .02854 L
.26675 .0282 L
.26377 .02786 L
.26079 .02754 L
.26079 .02754 L
.25807 .02724 L
.25535 .02695 L
.25263 .02667 L
.24991 .0264 L
.24719 .02615 L
.24447 .02591 L
.24175 .02568 L
.23903 .02547 L
.23631 .02526 L
.23359 .02508 L
.23087 .0249 L
.22815 .02474 L
.22815 .02474 L
.22569 .02459 L
.22322 .02446 L
.22076 .02433 L
.21829 .02422 L
.21583 .02413 L
.21336 .02404 L
.2109 .02397 L
.20843 .02391 L
.20597 .02387 L
.2035 .02384 L
.20104 .02382 L
.19857 .02381 L
.19857 .02381 L
.19636 .02382 L
.19415 .02384 L
.19194 .02387 L
.18973 .02391 L
.18752 .02397 L
.1853 .02404 L
.18309 .02413 L
.18088 .02422 L
.17867 .02433 L
.17646 .02446 L
.17425 .02459 L
.17204 .02474 L
.17204 .02474 L
.17008 .0249 L
.16812 .02508 L
.16616 .02526 L
.16421 .02547 L
.16225 .02568 L
.16029 .02591 L
Mistroke
.15834 .02615 L
.15638 .0264 L
.15442 .02667 L
.15247 .02695 L
.15051 .02724 L
.14855 .02754 L
.14855 .02754 L
.14686 .02786 L
.14516 .0282 L
.14346 .02854 L
.14176 .0289 L
.14007 .02927 L
.13837 .02966 L
.13667 .03006 L
.13498 .03047 L
.13328 .0309 L
.13158 .03134 L
.12988 .03179 L
.12819 .03225 L
.12819 .03225 L
.12676 .03274 L
.12533 .03323 L
.1239 .03374 L
.12247 .03426 L
.12104 .03479 L
.11961 .03534 L
.11818 .03591 L
.11675 .03648 L
.11532 .03707 L
.11389 .03768 L
.11246 .0383 L
.11103 .03893 L
.11103 .03893 L
.10988 .03958 L
.10873 .04024 L
.10758 .04092 L
.10643 .04161 L
.10527 .04231 L
.10412 .04303 L
.10297 .04377 L
.10182 .04451 L
.10067 .04528 L
.09952 .04606 L
.09837 .04685 L
.09722 .04766 L
.09722 .04766 L
.09637 .04848 L
.09551 .04932 L
.09466 .05017 L
.0938 .05104 L
Mistroke
.09295 .05193 L
.09209 .05283 L
.09124 .05374 L
.09038 .05468 L
.08953 .05562 L
.08867 .05659 L
.08782 .05756 L
.08696 .05856 L
.08696 .05856 L
.08643 .05957 L
.08589 .0606 L
.08535 .06164 L
.08482 .0627 L
.08428 .06378 L
.08374 .06488 L
.08321 .06599 L
.08267 .06711 L
.08213 .06826 L
.0816 .06942 L
.08106 .0706 L
.08053 .0718 L
.08053 .0718 L
.08034 .07302 L
.08015 .07425 L
.07996 .0755 L
.07978 .07677 L
.07959 .07806 L
.0794 .07937 L
.07921 .08069 L
.07903 .08204 L
.07884 .0834 L
.07865 .08478 L
.07846 .08618 L
.07828 .08761 L
.07828 .08761 L
.07374 .08761 L
.0692 .08761 L
.06466 .08761 L
.06012 .08761 L
.05558 .08761 L
.05104 .08761 L
.0465 .08761 L
.04197 .08761 L
.03743 .08761 L
.03289 .08761 L
.02835 .08761 L
.02381 .08761 L
.02381 .08761 L
.02381 .07677 L
.02381 .06711 L
Mistroke
.02381 .05856 L
.02381 .05104 L
.02381 .04451 L
.02381 .03893 L
.02381 .03426 L
.02381 .03047 L
.02381 .02754 L
.02381 .02547 L
.02381 .02422 L
.02381 .02381 L
.02381 .02381 L
.02381 .02383 L
.02381 .02389 L
.02381 .02399 L
.02381 .02414 L
.02381 .02432 L
.02381 .02454 L
.02381 .02481 L
.02381 .02512 L
.02381 .02547 L
.02381 .02586 L
.02381 .02629 L
.02381 .02676 L
.02381 .02676 L
.02381 .02682 L
.02381 .02688 L
.02381 .02695 L
.02381 .02701 L
.02381 .02707 L
.02381 .02714 L
.02381 .02721 L
.02381 .02727 L
.02381 .02734 L
.02381 .02741 L
.02381 .02748 L
.02381 .02754 L
.02381 .02754 L
.02381 .02763 L
.02381 .02773 L
.02381 .02782 L
.02381 .02791 L
.02381 .028 L
.02381 .0281 L
.02381 .0282 L
.02381 .02829 L
.02381 .02839 L
.02381 .02849 L
.02381 .02859 L
.02381 .02869 L
.02381 .02869 L
Mistroke
.02381 .02883 L
.02381 .02897 L
.02381 .02911 L
.02381 .02925 L
.02381 .0294 L
.02381 .02955 L
.02381 .0297 L
.02381 .02985 L
.02381 .03 L
.02381 .03015 L
.02381 .03031 L
.02381 .03047 L
.02381 .03047 L
.02381 .0307 L
.02381 .03092 L
.02381 .03116 L
.02381 .03139 L
.02381 .03164 L
.02381 .03188 L
.02381 .03213 L
.02381 .03238 L
.02381 .03264 L
.02381 .0329 L
.02381 .03316 L
.02381 .03343 L
Mfstroke
.02381 .08761 m
.02381 .09459 L
.02381 .1018 L
.02381 .10921 L
.02381 .11682 L
.02381 .12463 L
.02381 .13263 L
.02381 .1408 L
.02381 .14915 L
.02381 .15768 L
.02381 .16637 L
.02381 .17522 L
.02381 .18424 L
.02381 .18424 L
.02381 .18525 L
.02381 .18626 L
.02381 .18728 L
.02381 .18829 L
.02381 .18931 L
.02381 .19033 L
.02381 .19136 L
.02381 .19238 L
.02381 .19341 L
.02381 .19444 L
.02381 .19547 L
.02381 .1965 L
.02381 .1965 L
.02381 .19724 L
.02381 .19798 L
.02381 .19872 L
.02381 .19946 L
.02381 .20021 L
.02381 .20095 L
.02381 .2017 L
.02381 .20244 L
.02381 .20319 L
.02381 .20394 L
.02381 .20468 L
.02381 .20543 L
.02381 .20543 L
.02381 .206 L
.02381 .20656 L
.02381 .20712 L
.02381 .20769 L
.02381 .20825 L
.02381 .20882 L
.02381 .20938 L
.02381 .20995 L
.02381 .21052 L
.02381 .21109 L
Mistroke
.02381 .21165 L
.02381 .21222 L
.02381 .21222 L
.02381 .21267 L
.02381 .21311 L
.02381 .21355 L
.02381 .214 L
.02381 .21444 L
.02381 .21488 L
.02381 .21533 L
.02381 .21577 L
.02381 .21622 L
.02381 .21667 L
.02381 .21711 L
.02381 .21756 L
.02381 .21756 L
.02381 .22114 L
.02381 .22474 L
.02381 .22837 L
.02381 .23201 L
.02381 .23568 L
.02381 .23936 L
.02381 .24307 L
.02381 .24679 L
.02381 .25054 L
.02381 .25431 L
.02381 .2581 L
.02381 .2619 L
.02381 .2619 L
.02381 .27929 L
.02381 .2971 L
.02381 .31532 L
.02381 .33397 L
.02381 .35304 L
.02381 .37256 L
.02381 .39254 L
.02381 .41299 L
.02381 .43393 L
.02381 .45539 L
.02381 .4774 L
.02381 .5 L
.02381 .5 L
.02835 .5 L
.03289 .5 L
.03743 .5 L
.04197 .5 L
.0465 .5 L
.05104 .5 L
.05558 .5 L
.06012 .5 L
Mistroke
.06466 .5 L
.0692 .5 L
.07374 .5 L
.07828 .5 L
.07828 .5 L
.07846 .49714 L
.07865 .49429 L
.07884 .49145 L
.07903 .48862 L
.07921 .4858 L
.0794 .48299 L
.07959 .48019 L
.07978 .4774 L
.07996 .47462 L
.08015 .47184 L
.08034 .46908 L
.08053 .46632 L
.08053 .46632 L
.08106 .46358 L
.0816 .46084 L
.08213 .45811 L
.08267 .45539 L
.08321 .45268 L
.08374 .44997 L
.08428 .44728 L
.08482 .44459 L
.08535 .44191 L
.08589 .43924 L
.08643 .43658 L
.08696 .43393 L
.08696 .43393 L
.08782 .43128 L
.08867 .42864 L
.08953 .42601 L
.09038 .42339 L
.09124 .42078 L
.09209 .41817 L
.09295 .41558 L
.0938 .41299 L
.09466 .4104 L
.09551 .40783 L
.09637 .40526 L
.09722 .4027 L
.09722 .4027 L
.09837 .40015 L
.09952 .39761 L
.10067 .39507 L
.10182 .39254 L
.10297 .39002 L
.10412 .3875 L
Mistroke
.10527 .38499 L
.10643 .38249 L
.10758 .38 L
.10873 .37751 L
.10988 .37504 L
.11103 .37256 L
.11103 .37256 L
.11246 .3701 L
.11389 .36764 L
.11532 .36519 L
.11675 .36275 L
.11818 .36031 L
.11961 .35788 L
.12104 .35546 L
.12247 .35304 L
.1239 .35064 L
.12533 .34823 L
.12676 .34584 L
.12819 .34345 L
.12819 .34345 L
.12988 .34107 L
.13158 .3387 L
.13328 .33633 L
.13498 .33397 L
.13667 .33161 L
.13837 .32927 L
.14007 .32692 L
.14176 .32459 L
.14346 .32226 L
.14516 .31994 L
.14686 .31763 L
.14855 .31532 L
.14855 .31532 L
.15051 .31302 L
.15247 .31073 L
.15442 .30844 L
.15638 .30616 L
.15834 .30388 L
.16029 .30162 L
.16225 .29935 L
.16421 .2971 L
.16616 .29485 L
.16812 .29261 L
.17008 .29037 L
.17204 .28814 L
.17204 .28814 L
.17425 .28592 L
.17646 .28371 L
.17867 .2815 L
.18088 .27929 L
Mistroke
.18309 .2771 L
.1853 .27491 L
.18752 .27272 L
.18973 .27055 L
.19194 .26838 L
.19415 .26621 L
.19636 .26406 L
.19857 .2619 L
.19857 .2619 L
.20104 .25976 L
.2035 .25762 L
.20597 .25549 L
.20843 .25336 L
.2109 .25125 L
.21336 .24913 L
.21583 .24703 L
.21829 .24493 L
.22076 .24284 L
.22322 .24075 L
.22569 .23867 L
.22815 .2366 L
.22815 .2366 L
.23087 .23453 L
.23359 .23247 L
.23631 .23041 L
.23903 .22837 L
.24175 .22633 L
.24447 .22429 L
.24719 .22226 L
.24991 .22024 L
.25263 .21823 L
.25535 .21622 L
.25807 .21422 L
.26079 .21222 L
.26079 .21222 L
.26377 .21023 L
.26675 .20825 L
.26973 .20628 L
.27271 .20431 L
.27569 .20235 L
.27867 .20039 L
.28165 .19844 L
.28463 .1965 L
.28761 .19457 L
.29059 .19264 L
.29357 .19072 L
.29655 .1888 L
.29655 .1888 L
.29979 .1869 L
.30304 .185 L
Mistroke
.30629 .1831 L
.30953 .18121 L
.31278 .17933 L
.31603 .17746 L
.31927 .17559 L
.32252 .17373 L
.32577 .17188 L
.32901 .17004 L
.33226 .1682 L
.33551 .16637 L
.33551 .16637 L
.33903 .16454 L
.34256 .16273 L
.34608 .16092 L
.34961 .15911 L
.35314 .15732 L
.35666 .15553 L
.36019 .15375 L
.36371 .15198 L
.36724 .15021 L
.37077 .14845 L
.37429 .1467 L
.37782 .14496 L
.37782 .14496 L
.38164 .14322 L
.38546 .14149 L
.38928 .13977 L
.39311 .13806 L
.39693 .13635 L
.40075 .13465 L
.40457 .13296 L
.40839 .13128 L
.41221 .12961 L
.41604 .12794 L
.41986 .12628 L
.42368 .12463 L
.42368 .12463 L
.42782 .12299 L
.43196 .12136 L
.4361 .11973 L
.44024 .11811 L
.44438 .1165 L
.44852 .1149 L
.45266 .11331 L
.4568 .11173 L
.46094 .11015 L
.46508 .10859 L
.46922 .10703 L
.47336 .10548 L
.47336 .10548 L
Mistroke
.47785 .10394 L
.48234 .10241 L
.48683 .10089 L
.49132 .09937 L
.49581 .09787 L
.5003 .09637 L
.50479 .09489 L
.50928 .09341 L
.51377 .09195 L
.51826 .09049 L
.52274 .08904 L
.52723 .08761 L
.52723 .08761 L
.48528 .08761 L
.44333 .08761 L
.40138 .08761 L
.35943 .08761 L
.31747 .08761 L
.27552 .08761 L
.23357 .08761 L
.19162 .08761 L
.14967 .08761 L
.10771 .08761 L
.06576 .08761 L
.02381 .08761 L
Mfstroke
.02381 .81576 m
.02381 .82478 L
.02381 .83363 L
.02381 .84232 L
.02381 .85085 L
.02381 .8592 L
.02381 .86737 L
.02381 .87537 L
.02381 .88318 L
.02381 .89079 L
.02381 .8982 L
.02381 .90541 L
.02381 .91239 L
.02381 .91239 L
.06576 .91239 L
.10771 .91239 L
.14967 .91239 L
.19162 .91239 L
.23357 .91239 L
.27552 .91239 L
.31747 .91239 L
.35943 .91239 L
.40138 .91239 L
.44333 .91239 L
.48528 .91239 L
.52723 .91239 L
.52723 .91239 L
.52274 .91096 L
.51826 .90951 L
.51377 .90805 L
.50928 .90659 L
.50479 .90511 L
.5003 .90363 L
.49581 .90213 L
.49132 .90063 L
.48683 .89911 L
.48234 .89759 L
.47785 .89606 L
.47336 .89452 L
.47336 .89452 L
.46922 .89297 L
.46508 .89141 L
.46094 .88985 L
.4568 .88827 L
.45266 .88669 L
.44852 .8851 L
.44438 .8835 L
.44024 .88189 L
.4361 .88027 L
.43196 .87864 L
Mistroke
.42782 .87701 L
.42368 .87537 L
.42368 .87537 L
.41986 .87372 L
.41604 .87206 L
.41221 .87039 L
.40839 .86872 L
.40457 .86704 L
.40075 .86535 L
.39693 .86365 L
.39311 .86194 L
.38928 .86023 L
.38546 .85851 L
.38164 .85678 L
.37782 .85504 L
.37782 .85504 L
.37429 .8533 L
.37077 .85155 L
.36724 .84979 L
.36371 .84802 L
.36019 .84625 L
.35666 .84447 L
.35314 .84268 L
.34961 .84089 L
.34608 .83908 L
.34256 .83727 L
.33903 .83546 L
.33551 .83363 L
.33551 .83363 L
.33226 .8318 L
.32901 .82996 L
.32577 .82812 L
.32252 .82627 L
.31927 .82441 L
.31603 .82254 L
.31278 .82067 L
.30953 .81879 L
.30629 .8169 L
.30304 .815 L
.29979 .8131 L
.29655 .8112 L
.29655 .8112 L
.29357 .80928 L
.29059 .80736 L
.28761 .80543 L
.28463 .8035 L
.28165 .80156 L
.27867 .79961 L
.27569 .79765 L
.27271 .79569 L
Mistroke
.26973 .79372 L
.26675 .79175 L
.26377 .78977 L
.26079 .78778 L
.26079 .78778 L
.25807 .78578 L
.25535 .78378 L
.25263 .78177 L
.24991 .77976 L
.24719 .77774 L
.24447 .77571 L
.24175 .77367 L
.23903 .77163 L
.23631 .76959 L
.23359 .76753 L
.23087 .76547 L
.22815 .7634 L
.22815 .7634 L
.22569 .76133 L
.22322 .75925 L
.22076 .75716 L
.21829 .75507 L
.21583 .75297 L
.21336 .75087 L
.2109 .74875 L
.20843 .74664 L
.20597 .74451 L
.2035 .74238 L
.20104 .74024 L
.19857 .7381 L
.19857 .7381 L
.19636 .73594 L
.19415 .73379 L
.19194 .73162 L
.18973 .72945 L
.18752 .72728 L
.1853 .72509 L
.18309 .7229 L
.18088 .72071 L
.17867 .7185 L
.17646 .71629 L
.17425 .71408 L
.17204 .71186 L
.17204 .71186 L
.17008 .70963 L
.16812 .70739 L
.16616 .70515 L
.16421 .7029 L
.16225 .70065 L
.16029 .69838 L
Mistroke
.15834 .69612 L
.15638 .69384 L
.15442 .69156 L
.15247 .68927 L
.15051 .68698 L
.14855 .68468 L
.14855 .68468 L
.14686 .68237 L
.14516 .68006 L
.14346 .67774 L
.14176 .67541 L
.14007 .67308 L
.13837 .67073 L
.13667 .66839 L
.13498 .66603 L
.13328 .66367 L
.13158 .6613 L
.12988 .65893 L
.12819 .65655 L
.12819 .65655 L
.12676 .65416 L
.12533 .65177 L
.1239 .64936 L
.12247 .64696 L
.12104 .64454 L
.11961 .64212 L
.11818 .63969 L
.11675 .63725 L
.11532 .63481 L
.11389 .63236 L
.11246 .6299 L
.11103 .62744 L
.11103 .62744 L
.10988 .62496 L
.10873 .62249 L
.10758 .62 L
.10643 .61751 L
.10527 .61501 L
.10412 .6125 L
.10297 .60998 L
.10182 .60746 L
.10067 .60493 L
.09952 .60239 L
.09837 .59985 L
.09722 .5973 L
.09722 .5973 L
.09637 .59474 L
.09551 .59217 L
.09466 .5896 L
.0938 .58701 L
Mistroke
.09295 .58442 L
.09209 .58183 L
.09124 .57922 L
.09038 .57661 L
.08953 .57399 L
.08867 .57136 L
.08782 .56872 L
.08696 .56607 L
.08696 .56607 L
.08643 .56342 L
.08589 .56076 L
.08535 .55809 L
.08482 .55541 L
.08428 .55272 L
.08374 .55003 L
.08321 .54732 L
.08267 .54461 L
.08213 .54189 L
.0816 .53916 L
.08106 .53642 L
.08053 .53368 L
.08053 .53368 L
.08034 .53092 L
.08015 .52816 L
.07996 .52538 L
.07978 .5226 L
.07959 .51981 L
.0794 .51701 L
.07921 .5142 L
.07903 .51138 L
.07884 .50855 L
.07865 .50571 L
.07846 .50286 L
.07828 .5 L
.07828 .5 L
.07374 .5 L
.0692 .5 L
.06466 .5 L
.06012 .5 L
.05558 .5 L
.05104 .5 L
.0465 .5 L
.04197 .5 L
.03743 .5 L
.03289 .5 L
.02835 .5 L
.02381 .5 L
.02381 .5 L
.02381 .5226 L
.02381 .54461 L
Mistroke
.02381 .56607 L
.02381 .58701 L
.02381 .60746 L
.02381 .62744 L
.02381 .64696 L
.02381 .66603 L
.02381 .68468 L
.02381 .7029 L
.02381 .72071 L
.02381 .7381 L
.02381 .7381 L
.02381 .7419 L
.02381 .74569 L
.02381 .74946 L
.02381 .75321 L
.02381 .75693 L
.02381 .76064 L
.02381 .76432 L
.02381 .76799 L
.02381 .77163 L
.02381 .77526 L
.02381 .77886 L
.02381 .78244 L
.02381 .78244 L
.02381 .78289 L
.02381 .78333 L
.02381 .78378 L
.02381 .78423 L
.02381 .78467 L
.02381 .78512 L
.02381 .78556 L
.02381 .786 L
.02381 .78645 L
.02381 .78689 L
.02381 .78733 L
.02381 .78778 L
.02381 .78778 L
.02381 .78835 L
.02381 .78891 L
.02381 .78948 L
.02381 .79005 L
.02381 .79062 L
.02381 .79118 L
.02381 .79175 L
.02381 .79231 L
.02381 .79288 L
.02381 .79344 L
.02381 .794 L
.02381 .79457 L
.02381 .79457 L
Mistroke
.02381 .79532 L
.02381 .79606 L
.02381 .79681 L
.02381 .79756 L
.02381 .7983 L
.02381 .79905 L
.02381 .79979 L
.02381 .80054 L
.02381 .80128 L
.02381 .80202 L
.02381 .80276 L
.02381 .8035 L
.02381 .8035 L
.02381 .80453 L
.02381 .80556 L
.02381 .80659 L
.02381 .80762 L
.02381 .80864 L
.02381 .80967 L
.02381 .81069 L
.02381 .81171 L
.02381 .81272 L
.02381 .81374 L
.02381 .81475 L
.02381 .81576 L
Mfstroke
.02381 .91239 m
.02381 .91904 L
.02381 .92525 L
.02381 .93104 L
.02381 .93644 L
.02381 .94144 L
.02381 .94607 L
.02381 .95034 L
.02381 .95426 L
.02381 .95783 L
.02381 .96107 L
.02381 .96398 L
.02381 .96657 L
.02381 .96657 L
.02381 .96684 L
.02381 .9671 L
.02381 .96736 L
.02381 .96762 L
.02381 .96787 L
.02381 .96812 L
.02381 .96836 L
.02381 .96861 L
.02381 .96884 L
.02381 .96908 L
.02381 .9693 L
.02381 .96953 L
.02381 .96953 L
.02381 .96969 L
.02381 .96985 L
.02381 .97 L
.02381 .97015 L
.02381 .9703 L
.02381 .97045 L
.02381 .9706 L
.02381 .97075 L
.02381 .97089 L
.02381 .97103 L
.02381 .97117 L
.02381 .97131 L
.02381 .97131 L
.02381 .97141 L
.02381 .97151 L
.02381 .97161 L
.02381 .97171 L
.02381 .9718 L
.02381 .9719 L
.02381 .972 L
.02381 .97209 L
.02381 .97218 L
.02381 .97227 L
Mistroke
.02381 .97237 L
.02381 .97246 L
.02381 .97246 L
.02381 .97252 L
.02381 .97259 L
.02381 .97266 L
.02381 .97273 L
.02381 .97279 L
.02381 .97286 L
.02381 .97293 L
.02381 .97299 L
.02381 .97305 L
.02381 .97312 L
.02381 .97318 L
.02381 .97324 L
.02381 .97324 L
.02381 .97371 L
.02381 .97414 L
.02381 .97453 L
.02381 .97488 L
.02381 .97519 L
.02381 .97546 L
.02381 .97568 L
.02381 .97586 L
.02381 .97601 L
.02381 .97611 L
.02381 .97617 L
.02381 .97619 L
.02381 .97619 L
.02381 .97578 L
.02381 .97453 L
.02381 .97246 L
.02381 .96953 L
.02381 .96574 L
.02381 .96107 L
.02381 .95549 L
.02381 .94896 L
.02381 .94144 L
.02381 .93289 L
.02381 .92323 L
.02381 .91239 L
.02381 .91239 L
.02835 .91239 L
.03289 .91239 L
.03743 .91239 L
.04197 .91239 L
.0465 .91239 L
.05104 .91239 L
.05558 .91239 L
.06012 .91239 L
Mistroke
.06466 .91239 L
.0692 .91239 L
.07374 .91239 L
.07828 .91239 L
.07828 .91239 L
.07846 .91382 L
.07865 .91522 L
.07884 .9166 L
.07903 .91796 L
.07921 .91931 L
.0794 .92063 L
.07959 .92194 L
.07978 .92323 L
.07996 .9245 L
.08015 .92575 L
.08034 .92698 L
.08053 .9282 L
.08053 .9282 L
.08106 .9294 L
.0816 .93058 L
.08213 .93174 L
.08267 .93289 L
.08321 .93401 L
.08374 .93512 L
.08428 .93622 L
.08482 .9373 L
.08535 .93836 L
.08589 .9394 L
.08643 .94043 L
.08696 .94144 L
.08696 .94144 L
.08782 .94244 L
.08867 .94341 L
.08953 .94438 L
.09038 .94532 L
.09124 .94626 L
.09209 .94717 L
.09295 .94807 L
.0938 .94896 L
.09466 .94983 L
.09551 .95068 L
.09637 .95152 L
.09722 .95234 L
.09722 .95234 L
.09837 .95315 L
.09952 .95394 L
.10067 .95472 L
.10182 .95549 L
.10297 .95623 L
.10412 .95697 L
Mistroke
.10527 .95769 L
.10643 .95839 L
.10758 .95908 L
.10873 .95976 L
.10988 .96042 L
.11103 .96107 L
.11103 .96107 L
.11246 .9617 L
.11389 .96232 L
.11532 .96293 L
.11675 .96352 L
.11818 .96409 L
.11961 .96466 L
.12104 .96521 L
.12247 .96574 L
.1239 .96626 L
.12533 .96677 L
.12676 .96726 L
.12819 .96775 L
.12819 .96775 L
.12988 .96821 L
.13158 .96866 L
.13328 .9691 L
.13498 .96953 L
.13667 .96994 L
.13837 .97034 L
.14007 .97073 L
.14176 .9711 L
.14346 .97146 L
.14516 .9718 L
.14686 .97214 L
.14855 .97246 L
.14855 .97246 L
.15051 .97276 L
.15247 .97305 L
.15442 .97333 L
.15638 .9736 L
.15834 .97385 L
.16029 .97409 L
.16225 .97432 L
.16421 .97453 L
.16616 .97474 L
.16812 .97492 L
.17008 .9751 L
.17204 .97526 L
.17204 .97526 L
.17425 .97541 L
.17646 .97554 L
.17867 .97567 L
.18088 .97578 L
Mistroke
.18309 .97587 L
.1853 .97596 L
.18752 .97603 L
.18973 .97609 L
.19194 .97613 L
.19415 .97616 L
.19636 .97618 L
.19857 .97619 L
.19857 .97619 L
.20104 .97618 L
.2035 .97616 L
.20597 .97613 L
.20843 .97609 L
.2109 .97603 L
.21336 .97596 L
.21583 .97587 L
.21829 .97578 L
.22076 .97567 L
.22322 .97554 L
.22569 .97541 L
.22815 .97526 L
.22815 .97526 L
.23087 .9751 L
.23359 .97492 L
.23631 .97474 L
.23903 .97453 L
.24175 .97432 L
.24447 .97409 L
.24719 .97385 L
.24991 .9736 L
.25263 .97333 L
.25535 .97305 L
.25807 .97276 L
.26079 .97246 L
.26079 .97246 L
.26377 .97214 L
.26675 .9718 L
.26973 .97146 L
.27271 .9711 L
.27569 .97073 L
.27867 .97034 L
.28165 .96994 L
.28463 .96953 L
.28761 .9691 L
.29059 .96866 L
.29357 .96821 L
.29655 .96775 L
.29655 .96775 L
.29979 .96726 L
.30304 .96677 L
Mistroke
.30629 .96626 L
.30953 .96574 L
.31278 .96521 L
.31603 .96466 L
.31927 .96409 L
.32252 .96352 L
.32577 .96293 L
.32901 .96232 L
.33226 .9617 L
.33551 .96107 L
.33551 .96107 L
.33903 .96042 L
.34256 .95976 L
.34608 .95908 L
.34961 .95839 L
.35314 .95769 L
.35666 .95697 L
.36019 .95623 L
.36371 .95549 L
.36724 .95472 L
.37077 .95394 L
.37429 .95315 L
.37782 .95234 L
.37782 .95234 L
.38164 .95152 L
.38546 .95068 L
.38928 .94983 L
.39311 .94896 L
.39693 .94807 L
.40075 .94717 L
.40457 .94626 L
.40839 .94532 L
.41221 .94438 L
.41604 .94341 L
.41986 .94244 L
.42368 .94144 L
.42368 .94144 L
.42782 .94043 L
.43196 .9394 L
.4361 .93836 L
.44024 .9373 L
.44438 .93622 L
.44852 .93512 L
.45266 .93401 L
.4568 .93289 L
.46094 .93174 L
.46508 .93058 L
.46922 .9294 L
.47336 .9282 L
.47336 .9282 L
Mistroke
.47785 .92698 L
.48234 .92575 L
.48683 .9245 L
.49132 .92323 L
.49581 .92194 L
.5003 .92063 L
.50479 .91931 L
.50928 .91796 L
.51377 .9166 L
.51826 .91522 L
.52274 .91382 L
.52723 .91239 L
.52723 .91239 L
.48528 .91239 L
.44333 .91239 L
.40138 .91239 L
.35943 .91239 L
.31747 .91239 L
.27552 .91239 L
.23357 .91239 L
.19162 .91239 L
.14967 .91239 L
.10771 .91239 L
.06576 .91239 L
.02381 .91239 L
Mfstroke
.5 g
.48825 .5 m
.52723 .91239 L
.97619 .5 L
.48825 .5 L
F
.48825 .5 m
.97619 .5 L
.52723 .08761 L
.48825 .5 L
F
.48825 .5 m
.52723 .08761 L
.4858 .1011 L
.48825 .5 L
F
.48825 .5 m
.4858 .1011 L
.44569 .1158 L
.48825 .5 L
F
.48825 .5 m
.44569 .1158 L
.40692 .13174 L
.48825 .5 L
F
.48825 .5 m
.40692 .13174 L
.36952 .14894 L
.48825 .5 L
F
.48825 .5 m
.36952 .14894 L
.33354 .16743 L
.48825 .5 L
F
.48825 .5 m
.33354 .16743 L
.29903 .18728 L
.48825 .5 L
F
.48825 .5 m
.29903 .18728 L
.26608 .20856 L
.48825 .5 L
F
.48825 .5 m
.26608 .20856 L
.23479 .23137 L
.48825 .5 L
F
.48825 .5 m
.23479 .23137 L
.2053 .25583 L
.48825 .5 L
F
.48825 .5 m
.2053 .25583 L
.17779 .28211 L
.48825 .5 L
F
.48825 .5 m
.17779 .28211 L
.1525 .31043 L
.48825 .5 L
F
.48825 .5 m
.1525 .31043 L
.12975 .34109 L
.48825 .5 L
F
.48825 .5 m
.12975 .34109 L
.11002 .37451 L
.48825 .5 L
F
.48825 .5 m
.11002 .37451 L
.09398 .41133 L
.48825 .5 L
F
.48825 .5 m
.09398 .41133 L
.08274 .45255 L
.48825 .5 L
F
.48825 .5 m
.08274 .45255 L
.07828 .5 L
.48825 .5 L
F
.48825 .5 m
.07828 .5 L
.08274 .54745 L
.48825 .5 L
F
.48825 .5 m
.08274 .54745 L
.09398 .58867 L
.48825 .5 L
F
.48825 .5 m
.09398 .58867 L
.11002 .62549 L
.48825 .5 L
F
.48825 .5 m
.11002 .62549 L
.12975 .65891 L
.48825 .5 L
F
.48825 .5 m
.12975 .65891 L
.1525 .68957 L
.48825 .5 L
F
.48825 .5 m
.1525 .68957 L
.17779 .71789 L
.48825 .5 L
F
.48825 .5 m
.17779 .71789 L
.2053 .74417 L
.48825 .5 L
F
.48825 .5 m
.2053 .74417 L
.23479 .76863 L
.48825 .5 L
F
.48825 .5 m
.23479 .76863 L
.26608 .79144 L
.48825 .5 L
F
.48825 .5 m
.26608 .79144 L
.29903 .81272 L
.48825 .5 L
F
.48825 .5 m
.29903 .81272 L
.33354 .83257 L
.48825 .5 L
F
.48825 .5 m
.33354 .83257 L
.36952 .85106 L
.48825 .5 L
F
.48825 .5 m
.36952 .85106 L
.40692 .86826 L
.48825 .5 L
F
.48825 .5 m
.40692 .86826 L
.44569 .8842 L
.48825 .5 L
F
.48825 .5 m
.44569 .8842 L
.4858 .8989 L
.48825 .5 L
F
.48825 .5 m
.4858 .8989 L
.52723 .91239 L
.48825 .5 L
F
0 g
.97619 .5 m
.52723 .08761 L
.4858 .1011 L
.44569 .1158 L
.40692 .13174 L
.36952 .14894 L
.33354 .16743 L
.29903 .18728 L
.26608 .20856 L
.23479 .23137 L
.2053 .25583 L
.17779 .28211 L
.1525 .31043 L
.12975 .34109 L
.11002 .37451 L
.09398 .41133 L
.08274 .45255 L
.07828 .5 L
.08274 .54745 L
.09398 .58867 L
.11002 .62549 L
.12975 .65891 L
.1525 .68957 L
.17779 .71789 L
.2053 .74417 L
.23479 .76863 L
.26608 .79144 L
.29903 .81272 L
.33354 .83257 L
.36952 .85106 L
.40692 .86826 L
.44569 .8842 L
.4858 .8989 L
.52723 .91239 L
.97619 .5 L
s
.5 g
.48825 .2759 m
.52723 .08761 L
.97619 .5 L
.48825 .2759 L
F
.48825 .2759 m
.97619 .5 L
.52723 .5 L
.48825 .2759 L
F
.48825 .2759 m
.52723 .5 L
.4858 .47423 L
.48825 .2759 L
F
.48825 .2759 m
.4858 .47423 L
.44569 .44845 L
.48825 .2759 L
F
.48825 .2759 m
.44569 .44845 L
.40692 .42268 L
.48825 .2759 L
F
.48825 .2759 m
.40692 .42268 L
.36952 .3969 L
.48825 .2759 L
F
.48825 .2759 m
.36952 .3969 L
.33354 .37113 L
.48825 .2759 L
F
.48825 .2759 m
.33354 .37113 L
.29903 .34535 L
.48825 .2759 L
F
.48825 .2759 m
.29903 .34535 L
.26608 .31958 L
.48825 .2759 L
F
.48825 .2759 m
.26608 .31958 L
.23479 .2938 L
.48825 .2759 L
F
.48825 .2759 m
.23479 .2938 L
.2053 .26803 L
.48825 .2759 L
F
.48825 .2759 m
.2053 .26803 L
.17779 .24225 L
.48825 .2759 L
F
.48825 .2759 m
.17779 .24225 L
.1525 .21648 L
.48825 .2759 L
F
.48825 .2759 m
.1525 .21648 L
.12975 .19071 L
.48825 .2759 L
F
.48825 .2759 m
.12975 .19071 L
.11002 .16493 L
.48825 .2759 L
F
.48825 .2759 m
.11002 .16493 L
.09398 .13916 L
.48825 .2759 L
F
.48825 .2759 m
.09398 .13916 L
.08274 .11338 L
.48825 .2759 L
F
.48825 .2759 m
.08274 .11338 L
.07828 .08761 L
.48825 .2759 L
F
.48825 .2759 m
.07828 .08761 L
.08274 .06594 L
.48825 .2759 L
F
.48825 .2759 m
.08274 .06594 L
.09398 .05048 L
.48825 .2759 L
F
.48825 .2759 m
.09398 .05048 L
.11002 .03944 L
.48825 .2759 L
F
.48825 .2759 m
.11002 .03944 L
.12975 .03179 L
.48825 .2759 L
F
.48825 .2759 m
.12975 .03179 L
.1525 .02691 L
.48825 .2759 L
F
.48825 .2759 m
.1525 .02691 L
.17779 .02437 L
.48825 .2759 L
F
.48825 .2759 m
.17779 .02437 L
.2053 .02386 L
.48825 .2759 L
F
.48825 .2759 m
.2053 .02386 L
.23479 .02518 L
.48825 .2759 L
F
.48825 .2759 m
.23479 .02518 L
.26608 .02814 L
.48825 .2759 L
F
.48825 .2759 m
.26608 .02814 L
.29903 .03264 L
.48825 .2759 L
F
.48825 .2759 m
.29903 .03264 L
.33354 .03856 L
.48825 .2759 L
F
.48825 .2759 m
.33354 .03856 L
.36952 .04584 L
.48825 .2759 L
F
.48825 .2759 m
.36952 .04584 L
.40692 .05442 L
.48825 .2759 L
F
.48825 .2759 m
.40692 .05442 L
.44569 .06426 L
.48825 .2759 L
F
.48825 .2759 m
.44569 .06426 L
.4858 .07532 L
.48825 .2759 L
F
.48825 .2759 m
.4858 .07532 L
.52723 .08761 L
.48825 .2759 L
F
0 g
.97619 .5 m
.52723 .5 L
.4858 .47423 L
.44569 .44845 L
.40692 .42268 L
.36952 .3969 L
.33354 .37113 L
.29903 .34535 L
.26608 .31958 L
.23479 .2938 L
.2053 .26803 L
.17779 .24225 L
.1525 .21648 L
.12975 .19071 L
.11002 .16493 L
.09398 .13916 L
.08274 .11338 L
.07828 .08761 L
.08274 .06594 L
.09398 .05048 L
.11002 .03944 L
.12975 .03179 L
.1525 .02691 L
.17779 .02437 L
.2053 .02386 L
.23479 .02518 L
.26608 .02814 L
.29903 .03264 L
.33354 .03856 L
.36952 .04584 L
.40692 .05442 L
.44569 .06426 L
.4858 .07532 L
.52723 .08761 L
.97619 .5 L
s
.5 g
.48825 .7241 m
.52723 .5 L
.97619 .5 L
.48825 .7241 L
F
.48825 .7241 m
.97619 .5 L
.52723 .91239 L
.48825 .7241 L
F
.48825 .7241 m
.52723 .91239 L
.4858 .92468 L
.48825 .7241 L
F
.48825 .7241 m
.4858 .92468 L
.44569 .93574 L
.48825 .7241 L
F
.48825 .7241 m
.44569 .93574 L
.40692 .94558 L
.48825 .7241 L
F
.48825 .7241 m
.40692 .94558 L
.36952 .95416 L
.48825 .7241 L
F
.48825 .7241 m
.36952 .95416 L
.33354 .96144 L
.48825 .7241 L
F
.48825 .7241 m
.33354 .96144 L
.29903 .96736 L
.48825 .7241 L
F
.48825 .7241 m
.29903 .96736 L
.26608 .97186 L
.48825 .7241 L
F
.48825 .7241 m
.26608 .97186 L
.23479 .97482 L
.48825 .7241 L
F
.48825 .7241 m
.23479 .97482 L
.2053 .97614 L
.48825 .7241 L
F
.48825 .7241 m
.2053 .97614 L
.17779 .97563 L
.48825 .7241 L
F
.48825 .7241 m
.17779 .97563 L
.1525 .97309 L
.48825 .7241 L
F
.48825 .7241 m
.1525 .97309 L
.12975 .96821 L
.48825 .7241 L
F
.48825 .7241 m
.12975 .96821 L
.11002 .96056 L
.48825 .7241 L
F
.48825 .7241 m
.11002 .96056 L
.09398 .94952 L
.48825 .7241 L
F
.48825 .7241 m
.09398 .94952 L
.08274 .93406 L
.48825 .7241 L
F
.48825 .7241 m
.08274 .93406 L
.07828 .91239 L
.48825 .7241 L
F
.48825 .7241 m
.07828 .91239 L
.08274 .88662 L
.48825 .7241 L
F
.48825 .7241 m
.08274 .88662 L
.09398 .86084 L
.48825 .7241 L
F
.48825 .7241 m
.09398 .86084 L
.11002 .83507 L
.48825 .7241 L
F
.48825 .7241 m
.11002 .83507 L
.12975 .80929 L
.48825 .7241 L
F
.48825 .7241 m
.12975 .80929 L
.1525 .78352 L
.48825 .7241 L
F
.48825 .7241 m
.1525 .78352 L
.17779 .75775 L
.48825 .7241 L
F
.48825 .7241 m
.17779 .75775 L
.2053 .73197 L
.48825 .7241 L
F
.48825 .7241 m
.2053 .73197 L
.23479 .7062 L
.48825 .7241 L
F
.48825 .7241 m
.23479 .7062 L
.26608 .68042 L
.48825 .7241 L
F
.48825 .7241 m
.26608 .68042 L
.29903 .65465 L
.48825 .7241 L
F
.48825 .7241 m
.29903 .65465 L
.33354 .62887 L
.48825 .7241 L
F
.48825 .7241 m
.33354 .62887 L
.36952 .6031 L
.48825 .7241 L
F
.48825 .7241 m
.36952 .6031 L
.40692 .57732 L
.48825 .7241 L
F
.48825 .7241 m
.40692 .57732 L
.44569 .55155 L
.48825 .7241 L
F
.48825 .7241 m
.44569 .55155 L
.4858 .52577 L
.48825 .7241 L
F
.48825 .7241 m
.4858 .52577 L
.52723 .5 L
.48825 .7241 L
F
0 g
.97619 .5 m
.52723 .91239 L
.4858 .92468 L
.44569 .93574 L
.40692 .94558 L
.36952 .95416 L
.33354 .96144 L
.29903 .96736 L
.26608 .97186 L
.23479 .97482 L
.2053 .97614 L
.17779 .97563 L
.1525 .97309 L
.12975 .96821 L
.11002 .96056 L
.09398 .94952 L
.08274 .93406 L
.07828 .91239 L
.08274 .88662 L
.09398 .86084 L
.11002 .83507 L
.12975 .80929 L
.1525 .78352 L
.17779 .75775 L
.2053 .73197 L
.23479 .7062 L
.26608 .68042 L
.29903 .65465 L
.33354 .62887 L
.36952 .6031 L
.40692 .57732 L
.44569 .55155 L
.4858 .52577 L
.52723 .5 L
.97619 .5 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{161, 161},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 160}, {160, 0}} -> {-0.937697, -26.2503, 0.246096, \
0.328129}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[SolidCornerCube[38,34,FullForm->True],AspectRatio->1];\
\
\>", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.118604 1.28846 5.55112e-17 1.04741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.43455 .59665 m
.28564 .3552 L
s
.692 .53164 m
.43455 .59665 L
s
.43455 .59665 m
.42758 .84135 L
s
.43455 .59665 m
.42758 .84135 L
s
.28564 .3552 m
.43455 .59665 L
s
.09088 .31845 m
.28564 .3552 L
s
.28564 .3552 m
.32631 .3431 L
s
.09088 .31845 m
.28564 .3552 L
s
.692 .53164 m
.80743 .45036 L
s
.47067 .83212 m
.692 .53164 L
s
.692 .53164 m
.32631 .3431 L
s
.80743 .45036 m
.692 .53164 L
s
.47067 .83212 m
.692 .53164 L
s
.32631 .3431 m
.692 .53164 L
s
.32631 .3431 m
.37865 .22831 L
s
.32631 .3431 m
.37865 .22831 L
s
.244 .86805 m
.42758 .84135 L
s
.42758 .84135 m
.47067 .83212 L
s
.42758 .84135 m
.244 .86805 L
s
.55148 .80155 m
.47067 .83212 L
s
.47067 .83212 m
.55148 .80155 L
s
.09088 .31845 m
.05131 .58412 L
s
.37865 .22831 m
.09088 .31845 L
s
.05131 .58412 m
.09088 .31845 L
s
.244 .86805 m
.05131 .58412 L
s
.55148 .80155 m
.244 .86805 L
s
.244 .86805 m
.05131 .58412 L
s
.80743 .45036 m
.37865 .22831 L
s
.55148 .80155 m
.80743 .45036 L
s
.80743 .45036 m
.55148 .80155 L
s
.37865 .22831 m
.80743 .45036 L
s
.37865 .22831 m
.09956 .57105 L
s
.09957 .57105 m
.37865 .22831 L
s
.05131 .58412 m
.09957 .57105 L
s
.09957 .57105 m
.55148 .80155 L
s
.09956 .57105 m
.55148 .80155 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{129, 129},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 128}, {128, 0}} -> {0.0920471, -4.77373*^-6, \
0.0060635, 0.00745895}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
LineOfRays[40,NumberOfRays->7],
Move[SolidCornerCube[50,37.5],50],
Boundary[100,GraphicDesign->Off]},PlotType->TopView,AspectRatio->1];\
\>", \
"Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0108844 0.524825 0.0180546 [
[.5381 .02381 -30 -4.5 ]
[.5381 .02381 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.56803 .97619 m
.56803 .96081 L
.56803 .91572 L
.56803 .84399 L
.56803 .75051 L
.56803 .64165 L
.56803 .52483 L
.56803 .408 L
.56803 .29914 L
.56803 .20566 L
.56803 .13393 L
.56803 .08884 L
.56803 .07346 L
.56803 .08884 L
.56803 .13393 L
.56803 .20566 L
.56803 .29914 L
.56803 .408 L
.56803 .52483 L
.56803 .64165 L
.56803 .75051 L
.56803 .84399 L
.56803 .91572 L
.56803 .96081 L
.56803 .97619 L
s
.56803 .66777 m
.56803 .64562 L
.56803 .62284 L
.56803 .59942 L
.56803 .57531 L
.56803 .55046 L
.56803 .52483 L
s
.56803 .52483 m
.60399 .52483 L
.63994 .52483 L
.6759 .52483 L
.71186 .52483 L
.74782 .52483 L
.78378 .52483 L
s
.78378 .52483 m
.77993 .53024 L
.77608 .53561 L
.77224 .54095 L
.76839 .54625 L
.76454 .55151 L
.76069 .55675 L
s
.76069 .55675 m
.75714 .56195 L
.7536 .56711 L
.75005 .57224 L
.7465 .57735 L
.74295 .58242 L
.7394 .58745 L
s
.7394 .58745 m
.73612 .59246 L
.73285 .59744 L
.72957 .60239 L
.7263 .6073 L
.72302 .61219 L
.71975 .61705 L
s
.71975 .61705 m
.71672 .62188 L
.7137 .62668 L
.71068 .63146 L
.70766 .63621 L
.70463 .64093 L
.70161 .64562 L
s
.70161 .64562 m
.69883 .65028 L
.69605 .65492 L
.69326 .65953 L
.69048 .66412 L
.6877 .66868 L
.68491 .67321 L
s
.68491 .67321 m
.68236 .67772 L
.67981 .6822 L
.67725 .68666 L
.6747 .69109 L
.67215 .6955 L
.66959 .69988 L
s
.66959 .69988 m
.66726 .70423 L
.66493 .70856 L
.6626 .71287 L
.66027 .71715 L
.65793 .7214 L
.6556 .72564 L
s
.6556 .72564 m
.65349 .72984 L
.65138 .73402 L
.64927 .73818 L
.64715 .74232 L
.64504 .74642 L
.64293 .75051 L
s
.64293 .75051 m
.64103 .75457 L
.63914 .7586 L
.63724 .76261 L
.63534 .7666 L
.63345 .77056 L
.63155 .7745 L
s
.63155 .7745 m
.62988 .77841 L
.6282 .7823 L
.62652 .78616 L
.62484 .79 L
.62317 .79381 L
.62149 .7976 L
s
.62149 .7976 m
.62003 .80136 L
.61858 .8051 L
.61712 .80881 L
.61567 .8125 L
.61421 .81616 L
.61276 .8198 L
s
.61276 .8198 m
.61153 .82341 L
.61031 .82699 L
.60908 .83055 L
.60786 .83408 L
.60663 .83759 L
.60541 .84106 L
s
.60541 .84106 m
.60442 .84452 L
.60343 .84794 L
.60245 .85134 L
.60146 .85471 L
.60048 .85805 L
.59949 .86136 L
s
.59949 .86136 m
.59876 .86464 L
.59802 .8679 L
.59729 .87112 L
.59656 .87432 L
.59583 .87749 L
.59509 .88062 L
s
.59509 .88062 m
.59463 .88373 L
.59417 .8868 L
.59371 .88985 L
.59325 .89286 L
.59279 .89583 L
.59233 .89878 L
s
.59233 .89878 m
.59217 .90169 L
.59201 .90457 L
.59185 .90741 L
.59169 .91022 L
.59153 .91299 L
.59137 .91572 L
s
.59137 .91572 m
.58748 .91572 L
.58359 .91572 L
.5797 .91572 L
.57581 .91572 L
.57192 .91572 L
.56803 .91572 L
s
.56803 .91572 m
.56803 .89286 L
.56803 .8679 L
.56803 .84106 L
.56803 .8125 L
.56803 .7823 L
.56803 .75051 L
s
.56803 .75051 m
.56803 .74323 L
.56803 .73588 L
.56803 .72844 L
.56803 .72093 L
.56803 .71334 L
.56803 .70568 L
s
.56803 .70568 m
.56803 .70471 L
.56803 .70375 L
.56803 .70278 L
.56803 .70181 L
.56803 .70085 L
.56803 .69988 L
s
.56803 .69988 m
.56803 .69863 L
.56803 .69738 L
.56803 .69612 L
.56803 .69487 L
.56803 .69361 L
.56803 .69235 L
s
.56803 .69235 m
.56803 .69067 L
.56803 .68898 L
.56803 .68729 L
.56803 .6856 L
.56803 .6839 L
.56803 .6822 L
s
.56803 .6822 m
.56803 .67982 L
.56803 .67742 L
.56803 .67502 L
.56803 .67261 L
.56803 .67019 L
.56803 .66777 L
s
.56803 .52483 m
.56803 .49919 L
.56803 .47434 L
.56803 .45023 L
.56803 .42681 L
.56803 .40403 L
.56803 .38188 L
s
.56803 .38188 m
.56803 .37946 L
.56803 .37704 L
.56803 .37463 L
.56803 .37223 L
.56803 .36984 L
.56803 .36745 L
s
.56803 .36745 m
.56803 .36575 L
.56803 .36405 L
.56803 .36236 L
.56803 .36067 L
.56803 .35898 L
.56803 .3573 L
s
.56803 .3573 m
.56803 .35604 L
.56803 .35478 L
.56803 .35353 L
.56803 .35227 L
.56803 .35102 L
.56803 .34977 L
s
.56803 .34977 m
.56803 .3488 L
.56803 .34784 L
.56803 .34687 L
.56803 .3459 L
.56803 .34494 L
.56803 .34397 L
s
.56803 .34397 m
.56803 .33631 L
.56803 .32872 L
.56803 .32121 L
.56803 .31377 L
.56803 .30642 L
.56803 .29914 L
s
.56803 .29914 m
.56803 .26735 L
.56803 .23715 L
.56803 .20859 L
.56803 .18175 L
.56803 .15679 L
.56803 .13393 L
s
.56803 .13393 m
.57192 .13393 L
.57581 .13393 L
.5797 .13393 L
.58359 .13393 L
.58748 .13393 L
.59137 .13393 L
s
.59137 .13393 m
.59153 .13666 L
.59169 .13943 L
.59185 .14224 L
.59201 .14508 L
.59217 .14796 L
.59233 .15087 L
s
.59233 .15087 m
.59279 .15382 L
.59325 .15679 L
.59371 .1598 L
.59417 .16285 L
.59463 .16592 L
.59509 .16903 L
s
.59509 .16903 m
.59583 .17216 L
.59656 .17533 L
.59729 .17853 L
.59802 .18175 L
.59876 .18501 L
.59949 .18829 L
s
.59949 .18829 m
.60048 .1916 L
.60146 .19494 L
.60245 .19831 L
.60343 .20171 L
.60442 .20513 L
.60541 .20859 L
s
.60541 .20859 m
.60663 .21206 L
.60786 .21557 L
.60908 .2191 L
.61031 .22266 L
.61153 .22624 L
.61276 .22985 L
s
.61276 .22985 m
.61421 .23349 L
.61567 .23715 L
.61712 .24084 L
.61858 .24455 L
.62003 .24829 L
.62149 .25205 L
s
.62149 .25205 m
.62317 .25584 L
.62484 .25965 L
.62652 .26349 L
.6282 .26735 L
.62988 .27124 L
.63155 .27515 L
s
.63155 .27515 m
.63345 .27909 L
.63534 .28305 L
.63724 .28704 L
.63914 .29105 L
.64103 .29508 L
.64293 .29914 L
s
.64293 .29914 m
.64504 .30323 L
.64715 .30734 L
.64927 .31147 L
.65138 .31563 L
.65349 .31981 L
.6556 .32401 L
s
.6556 .32401 m
.65793 .32825 L
.66027 .3325 L
.6626 .33678 L
.66493 .34109 L
.66726 .34542 L
.66959 .34977 L
s
.66959 .34977 m
.67215 .35415 L
.6747 .35856 L
.67725 .36299 L
.67981 .36745 L
.68236 .37193 L
.68491 .37644 L
s
.68491 .37644 m
.6877 .38097 L
.69048 .38553 L
.69326 .39012 L
.69605 .39473 L
.69883 .39937 L
.70161 .40403 L
s
.70161 .40403 m
.70463 .40872 L
.70766 .41344 L
.71068 .41819 L
.7137 .42297 L
.71672 .42777 L
.71975 .4326 L
s
.71975 .4326 m
.72302 .43746 L
.7263 .44235 L
.72957 .44727 L
.73285 .45221 L
.73612 .45719 L
.7394 .4622 L
s
.7394 .4622 m
.74295 .46724 L
.7465 .4723 L
.75005 .47741 L
.7536 .48254 L
.75714 .4877 L
.76069 .4929 L
s
.76069 .4929 m
.76454 .49814 L
.76839 .5034 L
.77224 .5087 L
.77608 .51404 L
.77993 .51941 L
.78378 .52483 L
s
.78378 .52483 m
.74782 .52483 L
.71186 .52483 L
.6759 .52483 L
.63994 .52483 L
.60399 .52483 L
.56803 .52483 L
s
.56803 .08258 m
.56803 .08779 L
.56803 .09425 L
.56803 .10201 L
.56803 .11114 L
.56803 .12174 L
.56803 .13393 L
s
.56803 .13393 m
.60399 .13393 L
.63994 .13393 L
.6759 .13393 L
.71186 .13393 L
.74782 .13393 L
.78378 .13393 L
s
.78378 .13393 m
.77993 .13125 L
.77608 .12865 L
.77224 .12612 L
.76839 .12366 L
.76454 .12127 L
.76069 .11895 L
s
.76069 .11895 m
.75714 .1167 L
.7536 .11451 L
.75005 .11238 L
.7465 .11033 L
.74295 .10833 L
.7394 .1064 L
s
.7394 .1064 m
.73612 .10453 L
.73285 .10272 L
.72957 .10097 L
.7263 .09927 L
.72302 .09764 L
.71975 .09607 L
s
.71975 .09607 m
.71672 .09455 L
.7137 .09309 L
.71068 .09168 L
.70766 .09033 L
.70463 .08903 L
.70161 .08779 L
s
.70161 .08779 m
.69883 .08661 L
.69605 .08547 L
.69326 .08439 L
.69048 .08336 L
.6877 .08239 L
.68491 .08146 L
s
.68491 .08146 m
.68236 .08059 L
.67981 .07977 L
.67725 .079 L
.6747 .07829 L
.67215 .07762 L
.66959 .077 L
s
.66959 .077 m
.66726 .07643 L
.66493 .07592 L
.6626 .07545 L
.66027 .07503 L
.65793 .07466 L
.6556 .07434 L
s
.6556 .07434 m
.65349 .07407 L
.65138 .07385 L
.64927 .07368 L
.64715 .07356 L
.64504 .07348 L
.64293 .07346 L
s
.64293 .07346 m
.64103 .07348 L
.63914 .07356 L
.63724 .07368 L
.63534 .07385 L
.63345 .07407 L
.63155 .07434 L
s
.63155 .07434 m
.62988 .07466 L
.6282 .07503 L
.62652 .07545 L
.62484 .07592 L
.62317 .07643 L
.62149 .077 L
s
.62149 .077 m
.62003 .07762 L
.61858 .07829 L
.61712 .079 L
.61567 .07977 L
.61421 .08059 L
.61276 .08146 L
s
.61276 .08146 m
.61153 .08239 L
.61031 .08336 L
.60908 .08439 L
.60786 .08547 L
.60663 .08661 L
.60541 .08779 L
s
.60541 .08779 m
.60442 .08903 L
.60343 .09033 L
.60245 .09168 L
.60146 .09309 L
.60048 .09455 L
.59949 .09607 L
s
.59949 .09607 m
.59876 .09764 L
.59802 .09927 L
.59729 .10097 L
.59656 .10272 L
.59583 .10453 L
.59509 .1064 L
s
.59509 .1064 m
.59463 .10833 L
.59417 .11033 L
.59371 .11238 L
.59325 .11451 L
.59279 .1167 L
.59233 .11895 L
s
.59233 .11895 m
.59217 .12127 L
.59201 .12366 L
.59185 .12612 L
.59169 .12865 L
.59153 .13125 L
.59137 .13393 L
s
.59137 .13393 m
.58748 .13393 L
.58359 .13393 L
.5797 .13393 L
.57581 .13393 L
.57192 .13393 L
.56803 .13393 L
s
.56803 .13393 m
.56803 .11451 L
.56803 .09927 L
.56803 .08779 L
.56803 .07977 L
.56803 .07503 L
.56803 .07346 L
s
.56803 .07346 m
.56803 .07354 L
.56803 .07377 L
.56803 .07416 L
.56803 .0747 L
.56803 .0754 L
.56803 .07625 L
s
.56803 .07625 m
.56803 .07637 L
.56803 .07649 L
.56803 .07662 L
.56803 .07674 L
.56803 .07687 L
.56803 .077 L
s
.56803 .077 m
.56803 .07717 L
.56803 .07735 L
.56803 .07753 L
.56803 .07771 L
.56803 .0779 L
.56803 .07809 L
s
.56803 .07809 m
.56803 .07835 L
.56803 .07862 L
.56803 .0789 L
.56803 .07918 L
.56803 .07947 L
.56803 .07977 L
s
.56803 .07977 m
.56803 .0802 L
.56803 .08065 L
.56803 .08111 L
.56803 .08159 L
.56803 .08207 L
.56803 .08258 L
s
.56803 .13393 m
.56803 .14738 L
.56803 .16163 L
.56803 .1766 L
.56803 .19227 L
.56803 .20859 L
.56803 .22552 L
s
.56803 .22552 m
.56803 .22744 L
.56803 .22937 L
.56803 .2313 L
.56803 .23325 L
.56803 .23519 L
.56803 .23715 L
s
.56803 .23715 m
.56803 .23855 L
.56803 .23996 L
.56803 .24137 L
.56803 .24278 L
.56803 .2442 L
.56803 .24562 L
s
.56803 .24562 m
.56803 .24668 L
.56803 .24775 L
.56803 .24882 L
.56803 .2499 L
.56803 .25097 L
.56803 .25205 L
s
.56803 .25205 m
.56803 .25289 L
.56803 .25373 L
.56803 .25457 L
.56803 .25542 L
.56803 .25626 L
.56803 .25711 L
s
.56803 .25711 m
.56803 .26392 L
.56803 .27081 L
.56803 .27777 L
.56803 .28482 L
.56803 .29194 L
.56803 .29914 L
s
.56803 .29914 m
.56803 .3325 L
.56803 .36745 L
.56803 .40403 L
.56803 .44235 L
.56803 .48254 L
.56803 .52483 L
s
.56803 .52483 m
.57192 .52483 L
.57581 .52483 L
.5797 .52483 L
.58359 .52483 L
.58748 .52483 L
.59137 .52483 L
s
.59137 .52483 m
.59153 .51941 L
.59169 .51404 L
.59185 .5087 L
.59201 .5034 L
.59217 .49814 L
.59233 .4929 L
s
.59233 .4929 m
.59279 .4877 L
.59325 .48254 L
.59371 .47741 L
.59417 .4723 L
.59463 .46724 L
.59509 .4622 L
s
.59509 .4622 m
.59583 .45719 L
.59656 .45221 L
.59729 .44727 L
.59802 .44235 L
.59876 .43746 L
.59949 .4326 L
s
.59949 .4326 m
.60048 .42777 L
.60146 .42297 L
.60245 .41819 L
.60343 .41344 L
.60442 .40872 L
.60541 .40403 L
s
.60541 .40403 m
.60663 .39937 L
.60786 .39473 L
.60908 .39012 L
.61031 .38553 L
.61153 .38097 L
.61276 .37644 L
s
.61276 .37644 m
.61421 .37193 L
.61567 .36745 L
.61712 .36299 L
.61858 .35856 L
.62003 .35415 L
.62149 .34977 L
s
.62149 .34977 m
.62317 .34542 L
.62484 .34109 L
.62652 .33678 L
.6282 .3325 L
.62988 .32825 L
.63155 .32401 L
s
.63155 .32401 m
.63345 .31981 L
.63534 .31563 L
.63724 .31147 L
.63914 .30734 L
.64103 .30323 L
.64293 .29914 L
s
.64293 .29914 m
.64504 .29508 L
.64715 .29105 L
.64927 .28704 L
.65138 .28305 L
.65349 .27909 L
.6556 .27515 L
s
.6556 .27515 m
.65793 .27124 L
.66027 .26735 L
.6626 .26349 L
.66493 .25965 L
.66726 .25584 L
.66959 .25205 L
s
.66959 .25205 m
.67215 .24829 L
.6747 .24455 L
.67725 .24084 L
.67981 .23715 L
.68236 .23349 L
.68491 .22985 L
s
.68491 .22985 m
.6877 .22624 L
.69048 .22266 L
.69326 .2191 L
.69605 .21557 L
.69883 .21206 L
.70161 .20859 L
s
.70161 .20859 m
.70463 .20513 L
.70766 .20171 L
.71068 .19831 L
.7137 .19494 L
.71672 .1916 L
.71975 .18829 L
s
.71975 .18829 m
.72302 .18501 L
.7263 .18175 L
.72957 .17853 L
.73285 .17533 L
.73612 .17216 L
.7394 .16903 L
s
.7394 .16903 m
.74295 .16592 L
.7465 .16285 L
.75005 .1598 L
.7536 .15679 L
.75714 .15382 L
.76069 .15087 L
s
.76069 .15087 m
.76454 .14796 L
.76839 .14508 L
.77224 .14224 L
.77608 .13943 L
.77993 .13666 L
.78378 .13393 L
s
.78378 .13393 m
.74782 .13393 L
.71186 .13393 L
.6759 .13393 L
.63994 .13393 L
.60399 .13393 L
.56803 .13393 L
s
.56803 .82413 m
.56803 .84106 L
.56803 .85738 L
.56803 .87305 L
.56803 .88802 L
.56803 .90227 L
.56803 .91572 L
s
.56803 .91572 m
.60399 .91572 L
.63994 .91572 L
.6759 .91572 L
.71186 .91572 L
.74782 .91572 L
.78378 .91572 L
s
.78378 .91572 m
.77993 .91299 L
.77608 .91022 L
.77224 .90741 L
.76839 .90457 L
.76454 .90169 L
.76069 .89878 L
s
.76069 .89878 m
.75714 .89583 L
.7536 .89286 L
.75005 .88985 L
.7465 .8868 L
.74295 .88373 L
.7394 .88062 L
s
.7394 .88062 m
.73612 .87749 L
.73285 .87432 L
.72957 .87112 L
.7263 .8679 L
.72302 .86464 L
.71975 .86136 L
s
.71975 .86136 m
.71672 .85805 L
.7137 .85471 L
.71068 .85134 L
.70766 .84794 L
.70463 .84452 L
.70161 .84106 L
s
.70161 .84106 m
.69883 .83759 L
.69605 .83408 L
.69326 .83055 L
.69048 .82699 L
.6877 .82341 L
.68491 .8198 L
s
.68491 .8198 m
.68236 .81616 L
.67981 .8125 L
.67725 .80881 L
.6747 .8051 L
.67215 .80136 L
.66959 .7976 L
s
.66959 .7976 m
.66726 .79381 L
.66493 .79 L
.6626 .78616 L
.66027 .7823 L
.65793 .77841 L
.6556 .7745 L
s
.6556 .7745 m
.65349 .77056 L
.65138 .7666 L
.64927 .76261 L
.64715 .7586 L
.64504 .75457 L
.64293 .75051 L
s
.64293 .75051 m
.64103 .74642 L
.63914 .74232 L
.63724 .73818 L
.63534 .73402 L
.63345 .72984 L
.63155 .72564 L
s
.63155 .72564 m
.62988 .7214 L
.6282 .71715 L
.62652 .71287 L
.62484 .70856 L
.62317 .70423 L
.62149 .69988 L
s
.62149 .69988 m
.62003 .6955 L
.61858 .69109 L
.61712 .68666 L
.61567 .6822 L
.61421 .67772 L
.61276 .67321 L
s
.61276 .67321 m
.61153 .66868 L
.61031 .66412 L
.60908 .65953 L
.60786 .65492 L
.60663 .65028 L
.60541 .64562 L
s
.60541 .64562 m
.60442 .64093 L
.60343 .63621 L
.60245 .63146 L
.60146 .62668 L
.60048 .62188 L
.59949 .61705 L
s
.59949 .61705 m
.59876 .61219 L
.59802 .6073 L
.59729 .60239 L
.59656 .59744 L
.59583 .59246 L
.59509 .58745 L
s
.59509 .58745 m
.59463 .58242 L
.59417 .57735 L
.59371 .57224 L
.59325 .56711 L
.59279 .56195 L
.59233 .55675 L
s
.59233 .55675 m
.59217 .55151 L
.59201 .54625 L
.59185 .54095 L
.59169 .53561 L
.59153 .53024 L
.59137 .52483 L
s
.59137 .52483 m
.58748 .52483 L
.58359 .52483 L
.5797 .52483 L
.57581 .52483 L
.57192 .52483 L
.56803 .52483 L
s
.56803 .52483 m
.56803 .56711 L
.56803 .6073 L
.56803 .64562 L
.56803 .6822 L
.56803 .71715 L
.56803 .75051 L
s
.56803 .75051 m
.56803 .75771 L
.56803 .76483 L
.56803 .77188 L
.56803 .77884 L
.56803 .78573 L
.56803 .79254 L
s
.56803 .79254 m
.56803 .79339 L
.56803 .79423 L
.56803 .79508 L
.56803 .79592 L
.56803 .79676 L
.56803 .7976 L
s
.56803 .7976 m
.56803 .79868 L
.56803 .79975 L
.56803 .80083 L
.56803 .8019 L
.56803 .80297 L
.56803 .80404 L
s
.56803 .80404 m
.56803 .80546 L
.56803 .80687 L
.56803 .80828 L
.56803 .80969 L
.56803 .8111 L
.56803 .8125 L
s
.56803 .8125 m
.56803 .81446 L
.56803 .81641 L
.56803 .81835 L
.56803 .82028 L
.56803 .82221 L
.56803 .82413 L
s
.56803 .91572 m
.56803 .92791 L
.56803 .93851 L
.56803 .94764 L
.56803 .9554 L
.56803 .96186 L
.56803 .96707 L
s
.56803 .96707 m
.56803 .96758 L
.56803 .96807 L
.56803 .96854 L
.56803 .969 L
.56803 .96945 L
.56803 .96988 L
s
.56803 .96988 m
.56803 .97018 L
.56803 .97047 L
.56803 .97075 L
.56803 .97103 L
.56803 .9713 L
.56803 .97156 L
s
.56803 .97156 m
.56803 .97175 L
.56803 .97194 L
.56803 .97212 L
.56803 .9723 L
.56803 .97248 L
.56803 .97265 L
s
.56803 .97265 m
.56803 .97278 L
.56803 .97291 L
.56803 .97303 L
.56803 .97316 L
.56803 .97328 L
.56803 .9734 L
s
.56803 .9734 m
.56803 .97425 L
.56803 .97495 L
.56803 .97549 L
.56803 .97588 L
.56803 .97611 L
.56803 .97619 L
s
.56803 .97619 m
.56803 .97462 L
.56803 .96988 L
.56803 .96186 L
.56803 .95038 L
.56803 .93514 L
.56803 .91572 L
s
.56803 .91572 m
.57192 .91572 L
.57581 .91572 L
.5797 .91572 L
.58359 .91572 L
.58748 .91572 L
.59137 .91572 L
s
.59137 .91572 m
.59153 .9184 L
.59169 .921 L
.59185 .92353 L
.59201 .92599 L
.59217 .92838 L
.59233 .9307 L
s
.59233 .9307 m
.59279 .93296 L
.59325 .93514 L
.59371 .93727 L
.59417 .93932 L
.59463 .94132 L
.59509 .94325 L
s
.59509 .94325 m
.59583 .94512 L
.59656 .94693 L
.59729 .94868 L
.59802 .95038 L
.59876 .95201 L
.59949 .95359 L
s
.59949 .95359 m
.60048 .9551 L
.60146 .95657 L
.60245 .95797 L
.60343 .95932 L
.60442 .96062 L
.60541 .96186 L
s
.60541 .96186 m
.60663 .96304 L
.60786 .96418 L
.60908 .96526 L
.61031 .96629 L
.61153 .96726 L
.61276 .96819 L
s
.61276 .96819 m
.61421 .96906 L
.61567 .96988 L
.61712 .97065 L
.61858 .97137 L
.62003 .97203 L
.62149 .97265 L
s
.62149 .97265 m
.62317 .97322 L
.62484 .97373 L
.62652 .9742 L
.6282 .97462 L
.62988 .97499 L
.63155 .97531 L
s
.63155 .97531 m
.63345 .97558 L
.63534 .9758 L
.63724 .97597 L
.63914 .97609 L
.64103 .97617 L
.64293 .97619 L
s
.64293 .97619 m
.64504 .97617 L
.64715 .97609 L
.64927 .97597 L
.65138 .9758 L
.65349 .97558 L
.6556 .97531 L
s
.6556 .97531 m
.65793 .97499 L
.66027 .97462 L
.6626 .9742 L
.66493 .97373 L
.66726 .97322 L
.66959 .97265 L
s
.66959 .97265 m
.67215 .97203 L
.6747 .97137 L
.67725 .97065 L
.67981 .96988 L
.68236 .96906 L
.68491 .96819 L
s
.68491 .96819 m
.6877 .96726 L
.69048 .96629 L
.69326 .96526 L
.69605 .96418 L
.69883 .96304 L
.70161 .96186 L
s
.70161 .96186 m
.70463 .96062 L
.70766 .95932 L
.71068 .95797 L
.7137 .95657 L
.71672 .9551 L
.71975 .95359 L
s
.71975 .95359 m
.72302 .95201 L
.7263 .95038 L
.72957 .94868 L
.73285 .94693 L
.73612 .94512 L
.7394 .94325 L
s
.7394 .94325 m
.74295 .94132 L
.7465 .93932 L
.75005 .93727 L
.7536 .93514 L
.75714 .93296 L
.76069 .9307 L
s
.76069 .9307 m
.76454 .92838 L
.76839 .92599 L
.77224 .92353 L
.77608 .921 L
.77993 .9184 L
.78378 .91572 L
s
.78378 .91572 m
.74782 .91572 L
.71186 .91572 L
.6759 .91572 L
.63994 .91572 L
.60399 .91572 L
.56803 .91572 L
s
.97619 .52483 m
.78378 .13393 L
.76602 .14672 L
.74883 .16066 L
.73222 .17576 L
.71619 .19206 L
.70077 .2096 L
.68598 .22841 L
.67186 .24858 L
.65845 .2702 L
.64581 .29339 L
.63402 .3183 L
.62318 .34514 L
.61343 .3742 L
.60497 .40588 L
.5981 .44078 L
.59328 .47985 L
.59137 .52483 L
.59328 .5698 L
.5981 .60887 L
.60497 .64377 L
.61343 .67545 L
.62318 .70451 L
.63402 .73135 L
.64581 .75626 L
.65845 .77945 L
.67186 .80107 L
.68598 .82124 L
.70077 .84005 L
.71619 .85759 L
.73222 .87389 L
.74883 .88899 L
.76602 .90293 L
.78378 .91572 L
.97619 .52483 L
s
.97619 .52483 m
.78378 .52483 L
.76602 .50039 L
.74883 .47596 L
.73222 .45153 L
.71619 .4271 L
.70077 .40267 L
.68598 .37824 L
.67186 .35381 L
.65845 .32938 L
.64581 .30495 L
.63402 .28052 L
.62318 .25609 L
.61343 .23165 L
.60497 .20722 L
.5981 .18279 L
.59328 .15836 L
.59137 .13393 L
.59328 .11339 L
.5981 .09874 L
.60497 .08827 L
.61343 .08103 L
.62318 .0764 L
.63402 .07399 L
.64581 .07351 L
.65845 .07475 L
.67186 .07757 L
.68598 .08183 L
.70077 .08744 L
.71619 .09434 L
.73222 .10247 L
.74883 .1118 L
.76602 .12229 L
.78378 .13393 L
.97619 .52483 L
s
.97619 .52482 m
.78378 .91572 L
.76602 .92736 L
.74883 .93785 L
.73222 .94718 L
.71619 .95531 L
.70077 .96221 L
.68598 .96782 L
.67186 .97208 L
.65845 .9749 L
.64581 .97614 L
.63402 .97566 L
.62318 .97325 L
.61343 .96862 L
.60497 .96138 L
.5981 .95091 L
.59328 .93626 L
.59137 .91572 L
.59328 .89129 L
.5981 .86686 L
.60497 .84243 L
.61343 .818 L
.62318 .79356 L
.63402 .76913 L
.64581 .7447 L
.65845 .72027 L
.67186 .69584 L
.68598 .67141 L
.70077 .64698 L
.71619 .62255 L
.73222 .59812 L
.74883 .57369 L
.76602 .54926 L
.78378 .52482 L
.97619 .52482 L
s
.039 .916 .04 r
.02381 .16373 m
.56803 .16373 L
s
0 0 0 r
2 Mabswid
.56803 .16373 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2841 m
.56803 .2841 L
s
0 0 0 r
2 Mabswid
.56803 .2841 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .40446 m
.56803 .40446 L
s
0 0 0 r
2 Mabswid
.56803 .40446 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52483 m
.56803 .52483 L
s
0 0 0 r
2 Mabswid
.56803 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64519 m
.56803 .64519 L
s
0 0 0 r
2 Mabswid
.56803 .64519 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .76555 m
.56803 .76555 L
s
0 0 0 r
2 Mabswid
.56803 .76555 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .88592 m
.56803 .88592 L
s
0 0 0 r
2 Mabswid
.56803 .88592 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .16373 m
.70958 .16373 L
s
0 0 0 r
2 Mabswid
.70958 .16373 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .2841 m
.79845 .2841 L
s
0 0 0 r
2 Mabswid
.79845 .2841 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .40446 m
.88732 .40446 L
s
0 0 0 r
2 Mabswid
.88732 .40446 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .52483 m
.97619 .52483 L
s
0 0 0 r
2 Mabswid
.97619 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .64519 m
.88732 .64519 L
s
0 0 0 r
2 Mabswid
.88732 .64519 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .76555 m
.79845 .76555 L
s
0 0 0 r
2 Mabswid
.79845 .76555 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .88592 m
.70958 .88592 L
s
0 0 0 r
2 Mabswid
.70958 .88592 Mdot
.039 .916 .04 r
.5 Mabswid
.70958 .16373 m
.79845 .52483 L
s
0 0 0 r
2 Mabswid
.79845 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .2841 m
.8577 .52483 L
s
0 0 0 r
2 Mabswid
.8577 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.88732 .40446 m
.91694 .52483 L
s
0 0 0 r
2 Mabswid
.91694 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52483 m
.97619 .52483 L
s
0 0 0 r
2 Mabswid
.97619 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.88732 .64519 m
.91694 .52483 L
s
0 0 0 r
2 Mabswid
.91694 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .76555 m
.8577 .52483 L
s
0 0 0 r
2 Mabswid
.8577 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.70958 .88592 m
.79845 .52483 L
s
0 0 0 r
2 Mabswid
.79845 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .52483 m
.70958 .88592 L
s
0 0 0 r
2 Mabswid
.70958 .88592 Mdot
.039 .916 .04 r
.5 Mabswid
.8577 .52483 m
.79845 .76555 L
s
0 0 0 r
2 Mabswid
.79845 .76555 Mdot
.039 .916 .04 r
.5 Mabswid
.91694 .52483 m
.88732 .64519 L
s
0 0 0 r
2 Mabswid
.88732 .64519 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52483 m
.97619 .52483 L
s
0 0 0 r
2 Mabswid
.97619 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.91694 .52483 m
.88732 .40446 L
s
0 0 0 r
2 Mabswid
.88732 .40446 Mdot
.039 .916 .04 r
.5 Mabswid
.8577 .52483 m
.79845 .2841 L
s
0 0 0 r
2 Mabswid
.79845 .2841 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .52483 m
.70958 .16373 L
s
0 0 0 r
2 Mabswid
.70958 .16373 Mdot
.039 .916 .04 r
.5 Mabswid
.70958 .88592 m
.56803 .88592 L
s
0 0 0 r
2 Mabswid
.56803 .88592 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .76555 m
.56803 .76555 L
s
0 0 0 r
2 Mabswid
.56803 .76555 Mdot
.039 .916 .04 r
.5 Mabswid
.88732 .64519 m
.56803 .64519 L
s
0 0 0 r
2 Mabswid
.56803 .64519 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .52483 m
.56803 .52483 L
s
0 0 0 r
2 Mabswid
.56803 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.88732 .40446 m
.56803 .40446 L
s
0 0 0 r
2 Mabswid
.56803 .40446 Mdot
.039 .916 .04 r
.5 Mabswid
.79845 .2841 m
.56803 .2841 L
s
0 0 0 r
2 Mabswid
.56803 .2841 Mdot
.039 .916 .04 r
.5 Mabswid
.70958 .16373 m
.56803 .16373 L
s
0 0 0 r
2 Mabswid
.56803 .16373 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .88592 m
.02381 .88592 L
s
0 0 0 r
2 Mabswid
.02381 .88592 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .76555 m
.02381 .76555 L
s
0 0 0 r
2 Mabswid
.02381 .76555 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .64519 m
.02381 .64519 L
s
0 0 0 r
2 Mabswid
.02381 .64519 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .52483 m
.02381 .52483 L
s
0 0 0 r
2 Mabswid
.02381 .52483 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .40446 m
.02381 .40446 L
s
0 0 0 r
2 Mabswid
.02381 .40446 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .2841 m
.02381 .2841 L
s
0 0 0 r
2 Mabswid
.02381 .2841 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .16373 m
.02381 .16373 L
s
0 0 0 r
2 Mabswid
.02381 .16373 Mdot
[(CornerCube)] .5381 .02381 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{171, 171},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 170}, {170, 0}} -> {-2.31349, -29.2204, 0.541921, \
0.326703}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
CircleOfRays[35,NumberOfRays->7],
Move[SolidCornerCube[50,37.5],{50,0,5}],
Boundary[150,GraphicDesign->Off]},PlotType->TopView,AspectRatio->1];\
\>", \
"Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0109021 0.493832 0.0188727 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.59267 .02381 m
.58871 .10215 L
.58475 .18048 L
.58079 .25882 L
.57683 .33716 L
.57288 .41549 L
.56892 .49383 L
.56496 .57217 L
.561 .65051 L
.55704 .72884 L
.55308 .80718 L
.54912 .88552 L
.54516 .96385 L
.54516 .96385 L
.54912 .88552 L
.55308 .80718 L
.55704 .72884 L
.561 .65051 L
.56496 .57217 L
.56892 .49383 L
.57288 .41549 L
.57683 .33716 L
.58079 .25882 L
.58475 .18048 L
.58871 .10215 L
.59267 .02381 L
.59267 .02381 L
s
.56892 .49383 m
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
.56892 .49383 L
s
.54516 .96385 m
.54536 .95983 L
.54597 .94784 L
.54697 .92808 L
.54834 .90088 L
.55007 .86673 L
.55212 .82619 L
.55446 .77996 L
.55704 .72884 L
.55983 .6737 L
.56277 .61548 L
.56582 .55518 L
.56892 .49383 L
.57202 .43248 L
.57506 .37218 L
.57801 .31396 L
.58079 .25882 L
.58338 .2077 L
.58571 .16148 L
.58776 .12094 L
.58949 .08678 L
.59086 .05959 L
.59186 .03983 L
.59247 .02783 L
.59267 .02381 L
.59247 .02783 L
.59186 .03983 L
.59086 .05959 L
.58949 .08678 L
.58776 .12094 L
.58571 .16148 L
.58338 .2077 L
.58079 .25882 L
.57801 .31396 L
.57506 .37218 L
.57202 .43248 L
.56892 .49383 L
.56582 .55518 L
.56277 .61548 L
.55983 .6737 L
.55704 .72884 L
.55446 .77996 L
.55212 .82619 L
.55007 .86673 L
.54834 .90088 L
.54697 .92808 L
.54597 .94784 L
.54536 .95983 L
.54516 .96385 L
s
.97619 .55551 m
.80477 .11939 L
.78638 .13002 L
.76849 .14194 L
.75112 .15516 L
.73427 .16971 L
.71796 .18563 L
.70221 .20299 L
.68706 .22186 L
.67254 .24235 L
.65871 .26458 L
.64563 .28874 L
.6334 .31505 L
.62215 .34384 L
.61204 .37555 L
.60335 .41085 L
.59649 .45082 L
.59221 .49736 L
.59175 .54448 L
.5945 .5859 L
.59952 .62328 L
.60629 .65755 L
.61449 .68928 L
.62389 .71887 L
.63435 .74659 L
.64574 .77265 L
.65798 .79718 L
.67101 .82032 L
.68478 .84215 L
.69924 .86274 L
.71438 .88213 L
.73016 .90038 L
.74658 .91749 L
.76363 .93349 L
.97619 .55551 L
s
.97619 .55551 m
.7842 .52644 L
.76777 .49831 L
.7519 .47027 L
.73661 .44232 L
.7219 .41446 L
.7078 .38669 L
.69433 .35901 L
.68152 .33144 L
.66942 .30397 L
.6581 .27662 L
.64762 .2494 L
.63809 .22232 L
.62965 .1954 L
.6225 .16869 L
.61692 .14221 L
.61341 .11604 L
.61278 .09031 L
.61577 .06921 L
.62135 .05468 L
.62876 .04482 L
.63758 .03855 L
.64755 .0352 L
.65849 .03433 L
.67028 .03562 L
.68283 .03882 L
.69606 .04378 L
.70993 .05035 L
.72439 .05843 L
.73941 .06794 L
.75498 .07883 L
.77107 .09106 L
.78767 .10458 L
.80477 .11939 L
.97619 .55551 L
s
.97619 .55551 m
.76363 .93349 L
.7453 .94293 L
.72759 .95126 L
.71052 .95846 L
.6941 .9645 L
.67835 .96936 L
.6633 .97297 L
.64898 .97527 L
.63545 .97617 L
.62278 .97556 L
.61104 .97328 L
.60035 .96913 L
.59086 .96284 L
.58281 .95401 L
.5765 .94207 L
.57247 .92609 L
.57164 .90441 L
.57483 .87926 L
.58092 .85455 L
.58907 .83014 L
.59879 .80598 L
.6098 .78201 L
.62191 .75821 L
.63496 .73455 L
.64885 .71102 L
.66352 .68761 L
.6789 .6643 L
.69494 .6411 L
.71161 .61799 L
.72889 .59497 L
.74676 .57204 L
.7652 .54919 L
.7842 .52644 L
.97619 .55551 L
s
.56139 .64268 m
.56197 .63123 L
.56256 .61962 L
.56315 .60784 L
.56376 .5959 L
.56437 .58379 L
.56499 .57151 L
.56562 .55905 L
.56626 .5464 L
.56691 .53357 L
.56757 .52053 L
.56824 .50729 L
.56892 .49383 L
.56892 .49383 L
.58686 .49655 L
.6048 .49927 L
.62274 .50198 L
.64068 .5047 L
.65862 .50742 L
.67656 .51013 L
.6945 .51285 L
.71244 .51557 L
.73038 .51829 L
.74832 .521 L
.76626 .52372 L
.7842 .52644 L
.7842 .52644 L
.78214 .52897 L
.78008 .53149 L
.77801 .534 L
.77595 .5365 L
.77389 .539 L
.77183 .54148 L
.76977 .54395 L
.76771 .54642 L
.76566 .54888 L
.7636 .55132 L
.76154 .55376 L
.75948 .55619 L
.75948 .55619 L
.75757 .55863 L
.75567 .56107 L
.75376 .56349 L
.75185 .56591 L
.74995 .56832 L
.74804 .57072 L
.74614 .57311 L
.74423 .57549 L
.74233 .57787 L
.74043 .58024 L
Mistroke
.73852 .5826 L
.73662 .58495 L
.73662 .58495 L
.73485 .58731 L
.73309 .58967 L
.73132 .59201 L
.72956 .59435 L
.72779 .59669 L
.72603 .59901 L
.72426 .60133 L
.7225 .60364 L
.72074 .60594 L
.71897 .60823 L
.71721 .61052 L
.71545 .6128 L
.71545 .6128 L
.71381 .61509 L
.71218 .61737 L
.71055 .61965 L
.70891 .62192 L
.70728 .62418 L
.70564 .62643 L
.70401 .62868 L
.70238 .63092 L
.70075 .63315 L
.69912 .63538 L
.69748 .63759 L
.69585 .63981 L
.69585 .63981 L
.69434 .64203 L
.69283 .64424 L
.69132 .64645 L
.68981 .64865 L
.6883 .65085 L
.68679 .65303 L
.68528 .65522 L
.68377 .65739 L
.68226 .65956 L
.68075 .66172 L
.67925 .66387 L
.67774 .66602 L
.67774 .66602 L
.67635 .66817 L
.67495 .67033 L
.67356 .67247 L
.67217 .67461 L
.67078 .67674 L
.66939 .67886 L
.668 .68098 L
.66661 .68309 L
Mistroke
.66522 .68519 L
.66383 .68729 L
.66244 .68938 L
.66105 .69147 L
.66105 .69147 L
.65977 .69356 L
.65849 .69565 L
.65721 .69773 L
.65594 .69981 L
.65466 .70188 L
.65338 .70394 L
.65211 .70599 L
.65083 .70804 L
.64956 .71009 L
.64828 .71212 L
.64701 .71415 L
.64573 .71618 L
.64573 .71618 L
.64457 .71821 L
.6434 .72024 L
.64224 .72226 L
.64108 .72427 L
.63991 .72628 L
.63875 .72829 L
.63759 .73028 L
.63642 .73227 L
.63526 .73425 L
.6341 .73623 L
.63294 .7382 L
.63177 .74016 L
.63177 .74016 L
.63072 .74214 L
.62967 .7441 L
.62862 .74606 L
.62757 .74802 L
.62651 .74997 L
.62546 .75191 L
.62441 .75384 L
.62336 .75577 L
.62231 .7577 L
.62126 .75961 L
.62021 .76152 L
.61916 .76342 L
.61916 .76342 L
.61822 .76534 L
.61728 .76725 L
.61634 .76915 L
.61541 .77104 L
.61447 .77293 L
.61353 .77481 L
Mistroke
.61259 .77668 L
.61165 .77855 L
.61072 .78041 L
.60978 .78227 L
.60884 .78412 L
.60791 .78596 L
.60791 .78596 L
.60708 .78781 L
.60626 .78966 L
.60543 .7915 L
.60461 .79333 L
.60378 .79516 L
.60296 .79698 L
.60214 .79879 L
.60132 .8006 L
.60049 .8024 L
.59967 .80419 L
.59885 .80598 L
.59803 .80776 L
.59803 .80776 L
.59732 .80955 L
.59661 .81133 L
.59591 .81311 L
.5952 .81488 L
.5945 .81664 L
.59379 .8184 L
.59309 .82015 L
.59238 .82189 L
.59168 .82363 L
.59098 .82536 L
.59027 .82708 L
.58957 .82879 L
.58957 .82879 L
.58899 .83052 L
.58841 .83224 L
.58782 .83395 L
.58724 .83565 L
.58666 .83735 L
.58608 .83904 L
.5855 .84073 L
.58492 .8424 L
.58434 .84407 L
.58376 .84573 L
.58318 .84739 L
.5826 .84903 L
.5826 .84903 L
.58215 .85069 L
.58169 .85234 L
.58124 .85398 L
.58079 .85562 L
Mistroke
.58034 .85725 L
.57989 .85887 L
.57944 .86048 L
.57899 .86209 L
.57854 .86368 L
.57809 .86527 L
.57765 .86685 L
.5772 .86843 L
.5772 .86843 L
.57689 .87001 L
.57658 .87159 L
.57626 .87316 L
.57595 .87472 L
.57565 .87628 L
.57534 .87782 L
.57503 .87936 L
.57472 .88089 L
.57441 .88241 L
.5741 .88392 L
.5738 .88542 L
.57349 .88692 L
.57349 .88692 L
.57333 .88842 L
.57318 .88992 L
.57302 .89141 L
.57286 .8929 L
.57271 .89437 L
.57255 .89583 L
.5724 .89728 L
.57225 .89873 L
.57209 .90016 L
.57194 .90159 L
.57179 .90301 L
.57164 .90441 L
.57164 .90441 L
.5697 .90412 L
.56775 .90382 L
.56581 .90353 L
.56387 .90324 L
.56193 .90294 L
.55999 .90265 L
.55805 .90235 L
.55611 .90206 L
.55417 .90177 L
.55223 .90147 L
.55029 .90118 L
.54834 .90088 L
.54834 .90088 L
.54893 .88927 L
.54955 .87708 L
Mistroke
.55019 .86434 L
.55086 .85109 L
.55156 .83735 L
.55227 .82314 L
.55301 .80849 L
.55378 .7934 L
.55456 .77788 L
.55537 .76195 L
.55619 .7456 L
.55704 .72884 L
.55704 .72884 L
.55723 .72506 L
.55742 .72127 L
.55761 .71745 L
.55781 .71361 L
.558 .70975 L
.5582 .70587 L
.5584 .70197 L
.5586 .69805 L
.55879 .6941 L
.55899 .69014 L
.5592 .68616 L
.5594 .68216 L
.5594 .68216 L
.55942 .68166 L
.55945 .68116 L
.55947 .68065 L
.5595 .68015 L
.55953 .67965 L
.55955 .67915 L
.55958 .67864 L
.5596 .67814 L
.55963 .67763 L
.55965 .67713 L
.55968 .67662 L
.5597 .67612 L
.5597 .67612 L
.55974 .67547 L
.55977 .67482 L
.5598 .67417 L
.55984 .67352 L
.55987 .67286 L
.5599 .67221 L
.55993 .67156 L
.55997 .6709 L
.56 .67025 L
.56003 .66959 L
.56007 .66894 L
.5601 .66828 L
.5601 .66828 L
Mistroke
.56014 .66741 L
.56019 .66653 L
.56023 .66565 L
.56028 .66478 L
.56032 .6639 L
.56037 .66302 L
.56041 .66213 L
.56045 .66125 L
.5605 .66037 L
.56054 .65949 L
.56059 .6586 L
.56063 .65771 L
.56063 .65771 L
.5607 .65647 L
.56076 .65523 L
.56082 .65398 L
.56089 .65274 L
.56095 .65149 L
.56101 .65023 L
.56107 .64898 L
.56114 .64773 L
.5612 .64647 L
.56127 .64521 L
.56133 .64395 L
.56139 .64268 L
Mfstroke
.56892 .49383 m
.5696 .48037 L
.57027 .46713 L
.57092 .4541 L
.57157 .44126 L
.57221 .42862 L
.57284 .41615 L
.57346 .40387 L
.57407 .39176 L
.57468 .37982 L
.57527 .36805 L
.57586 .35643 L
.57644 .34498 L
.57644 .34498 L
.5765 .34372 L
.57657 .34246 L
.57663 .3412 L
.57669 .33994 L
.57676 .33868 L
.57682 .33743 L
.57688 .33618 L
.57695 .33493 L
.57701 .33368 L
.57707 .33244 L
.57714 .33119 L
.5772 .32995 L
.5772 .32995 L
.57724 .32906 L
.57729 .32818 L
.57733 .32729 L
.57738 .32641 L
.57742 .32553 L
.57747 .32465 L
.57751 .32377 L
.57756 .32289 L
.5776 .32201 L
.57764 .32113 L
.57769 .32026 L
.57773 .31938 L
.57773 .31938 L
.57777 .31873 L
.5778 .31807 L
.57783 .31742 L
.57787 .31676 L
.5779 .31611 L
.57793 .31545 L
.57796 .3148 L
.578 .31415 L
.57803 .3135 L
.57806 .31285 L
Mistroke
.5781 .3122 L
.57813 .31155 L
.57813 .31155 L
.57815 .31104 L
.57818 .31054 L
.57821 .31003 L
.57823 .30953 L
.57826 .30902 L
.57828 .30852 L
.57831 .30802 L
.57833 .30751 L
.57836 .30701 L
.57838 .30651 L
.57841 .30601 L
.57843 .3055 L
.57843 .3055 L
.57864 .3015 L
.57884 .29752 L
.57904 .29356 L
.57924 .28962 L
.57944 .2857 L
.57963 .2818 L
.57983 .27792 L
.58002 .27406 L
.58022 .27022 L
.58041 .2664 L
.5806 .2626 L
.58079 .25882 L
.58079 .25882 L
.58164 .24206 L
.58247 .22572 L
.58327 .20978 L
.58406 .19427 L
.58482 .17918 L
.58556 .16452 L
.58628 .15032 L
.58697 .13658 L
.58764 .12333 L
.58828 .11059 L
.5889 .09839 L
.58949 .08678 L
.58949 .08678 L
.59143 .08707 L
.59337 .08737 L
.59531 .08766 L
.59725 .08796 L
.59919 .08825 L
.60113 .08854 L
.60308 .08884 L
.60502 .08913 L
Mistroke
.60696 .08943 L
.6089 .08972 L
.61084 .09001 L
.61278 .09031 L
.61278 .09031 L
.61279 .09174 L
.6128 .09318 L
.6128 .09463 L
.61281 .09609 L
.61282 .09756 L
.61282 .09903 L
.61283 .10052 L
.61283 .10202 L
.61284 .10352 L
.61284 .10504 L
.61285 .10656 L
.61285 .10809 L
.61285 .10809 L
.613 .10966 L
.61315 .11123 L
.61331 .11281 L
.61346 .1144 L
.61361 .116 L
.61376 .1176 L
.61391 .11922 L
.61406 .12084 L
.6142 .12247 L
.61435 .12411 L
.6145 .12576 L
.61465 .12742 L
.61465 .12742 L
.61493 .1291 L
.61521 .13079 L
.6155 .13249 L
.61578 .1342 L
.61606 .13592 L
.61634 .13764 L
.61662 .13937 L
.6169 .14111 L
.61718 .14286 L
.61746 .14461 L
.61774 .14637 L
.61802 .14814 L
.61802 .14814 L
.61843 .14994 L
.61883 .15174 L
.61923 .15355 L
.61964 .15537 L
.62004 .15719 L
.62045 .15903 L
Mistroke
.62085 .16087 L
.62125 .16271 L
.62165 .16457 L
.62205 .16643 L
.62246 .16829 L
.62286 .17017 L
.62286 .17017 L
.62338 .17207 L
.6239 .17398 L
.62442 .17589 L
.62494 .17781 L
.62545 .17974 L
.62597 .18167 L
.62649 .18362 L
.62701 .18556 L
.62753 .18752 L
.62804 .18948 L
.62856 .19145 L
.62908 .19343 L
.62908 .19343 L
.62971 .19543 L
.63034 .19743 L
.63097 .19945 L
.63159 .20147 L
.63222 .20349 L
.63285 .20553 L
.63348 .20756 L
.63411 .20961 L
.63474 .21166 L
.63536 .21372 L
.63599 .21579 L
.63662 .21786 L
.63662 .21786 L
.63735 .21996 L
.63809 .22206 L
.63883 .22417 L
.63956 .22628 L
.6403 .22841 L
.64104 .23053 L
.64177 .23267 L
.64251 .23481 L
.64324 .23696 L
.64398 .23911 L
.64471 .24127 L
.64544 .24344 L
.64544 .24344 L
.64629 .24563 L
.64713 .24783 L
.64797 .25003 L
.64881 .25224 L
Mistroke
.64965 .25445 L
.65049 .25667 L
.65133 .2589 L
.65217 .26114 L
.65301 .26338 L
.65385 .26563 L
.65469 .26788 L
.65553 .27014 L
.65553 .27014 L
.65648 .27242 L
.65742 .27471 L
.65837 .27701 L
.65931 .27931 L
.66026 .28162 L
.66121 .28393 L
.66215 .28625 L
.6631 .28858 L
.66404 .29092 L
.66498 .29326 L
.66593 .2956 L
.66687 .29796 L
.66687 .29796 L
.66792 .30033 L
.66897 .30271 L
.67003 .3051 L
.67108 .3075 L
.67213 .3099 L
.67318 .31231 L
.67423 .31472 L
.67528 .31714 L
.67633 .31957 L
.67737 .32201 L
.67842 .32445 L
.67947 .32689 L
.67947 .32689 L
.68063 .32936 L
.68179 .33184 L
.68295 .33433 L
.68411 .33682 L
.68526 .33931 L
.68642 .34182 L
.68758 .34433 L
.68873 .34684 L
.68989 .34937 L
.69105 .3519 L
.6922 .35443 L
.69336 .35698 L
.69336 .35698 L
.69463 .35954 L
.6959 .36212 L
Mistroke
.69716 .3647 L
.69843 .36729 L
.6997 .36988 L
.70097 .37248 L
.70224 .37509 L
.7035 .3777 L
.70477 .38033 L
.70604 .38296 L
.7073 .38559 L
.70857 .38823 L
.70857 .38823 L
.70995 .3909 L
.71134 .39358 L
.71272 .39626 L
.7141 .39895 L
.71549 .40164 L
.71687 .40435 L
.71825 .40706 L
.71963 .40978 L
.72101 .4125 L
.7224 .41523 L
.72378 .41797 L
.72516 .42072 L
.72516 .42072 L
.72666 .4235 L
.72817 .42628 L
.72968 .42907 L
.73118 .43186 L
.73269 .43467 L
.73419 .43748 L
.7357 .4403 L
.7372 .44313 L
.7387 .44596 L
.74021 .4488 L
.74171 .45165 L
.74321 .45451 L
.74321 .45451 L
.74485 .4574 L
.74649 .4603 L
.74813 .4632 L
.74976 .46611 L
.7514 .46903 L
.75303 .47196 L
.75467 .4749 L
.75631 .47784 L
.75794 .48079 L
.75957 .48376 L
.76121 .48673 L
.76284 .48971 L
.76284 .48971 L
Mistroke
.76462 .49272 L
.76641 .49574 L
.76819 .49877 L
.76997 .5018 L
.77175 .50485 L
.77353 .50791 L
.77531 .51097 L
.77709 .51404 L
.77887 .51713 L
.78064 .52022 L
.78242 .52332 L
.7842 .52644 L
.7842 .52644 L
.76626 .52372 L
.74832 .521 L
.73038 .51829 L
.71244 .51557 L
.6945 .51285 L
.67656 .51013 L
.65862 .50742 L
.64068 .5047 L
.62274 .50198 L
.6048 .49927 L
.58686 .49655 L
.56892 .49383 L
Mfstroke
.59219 .03331 m
.59206 .03586 L
.59192 .03873 L
.59175 .04193 L
.59158 .04546 L
.59138 .04933 L
.59117 .05354 L
.59094 .05811 L
.59069 .06305 L
.59042 .06837 L
.59013 .07409 L
.58982 .08022 L
.58949 .08678 L
.58949 .08678 L
.60743 .0895 L
.62537 .09221 L
.64331 .09493 L
.66125 .09765 L
.67919 .10037 L
.69713 .10308 L
.71507 .1058 L
.73301 .10852 L
.75095 .11123 L
.76889 .11395 L
.78683 .11667 L
.80477 .11939 L
.80477 .11939 L
.80292 .11769 L
.80107 .11602 L
.79922 .11436 L
.79737 .11272 L
.79552 .11111 L
.79366 .10951 L
.79181 .10793 L
.78995 .10636 L
.7881 .10482 L
.78624 .10329 L
.78438 .10179 L
.78252 .1003 L
.78252 .1003 L
.78081 .09884 L
.7791 .09741 L
.77739 .096 L
.77567 .0946 L
.77396 .09322 L
.77224 .09185 L
.77053 .0905 L
.76881 .08917 L
.76709 .08786 L
.76538 .08656 L
Mistroke
.76366 .08527 L
.76194 .08401 L
.76194 .08401 L
.76035 .08278 L
.75877 .08156 L
.75718 .08037 L
.75559 .07918 L
.75401 .07802 L
.75242 .07687 L
.75083 .07573 L
.74924 .07461 L
.74765 .0735 L
.74605 .07241 L
.74446 .07134 L
.74287 .07028 L
.74287 .07028 L
.7414 .06925 L
.73993 .06824 L
.73846 .06724 L
.73699 .06626 L
.73552 .06529 L
.73405 .06434 L
.73258 .0634 L
.73111 .06248 L
.72963 .06157 L
.72816 .06067 L
.72669 .05979 L
.72521 .05892 L
.72521 .05892 L
.72385 .05809 L
.7225 .05727 L
.72114 .05646 L
.71978 .05566 L
.71842 .05488 L
.71706 .05412 L
.7157 .05337 L
.71434 .05263 L
.71297 .0519 L
.71161 .05119 L
.71025 .05049 L
.70888 .04981 L
.70888 .04981 L
.70763 .04916 L
.70638 .04852 L
.70513 .04789 L
.70387 .04728 L
.70262 .04668 L
.70137 .04609 L
.70011 .04552 L
.69886 .04495 L
Mistroke
.6976 .04441 L
.69634 .04387 L
.69509 .04335 L
.69383 .04284 L
.69383 .04284 L
.69268 .04237 L
.69153 .0419 L
.69038 .04145 L
.68923 .04101 L
.68808 .04058 L
.68693 .04017 L
.68578 .03977 L
.68463 .03938 L
.68347 .03901 L
.68232 .03865 L
.68117 .0383 L
.68001 .03796 L
.68001 .03796 L
.67896 .03766 L
.67792 .03736 L
.67687 .03708 L
.67582 .03681 L
.67477 .03656 L
.67372 .03632 L
.67267 .03609 L
.67162 .03587 L
.67057 .03566 L
.66951 .03547 L
.66846 .03529 L
.66741 .03513 L
.66741 .03513 L
.66646 .03499 L
.66551 .03487 L
.66457 .03476 L
.66362 .03466 L
.66267 .03457 L
.66172 .0345 L
.66077 .03444 L
.65982 .03439 L
.65887 .03436 L
.65792 .03433 L
.65696 .03432 L
.65601 .03433 L
.65601 .03433 L
.65517 .03436 L
.65432 .03441 L
.65347 .03447 L
.65263 .03454 L
.65178 .03462 L
.65093 .03472 L
Mistroke
.65008 .03483 L
.64923 .03495 L
.64838 .03509 L
.64753 .03524 L
.64668 .0354 L
.64583 .03558 L
.64583 .03558 L
.64509 .03578 L
.64435 .036 L
.6436 .03623 L
.64286 .03647 L
.64211 .03673 L
.64137 .037 L
.64062 .03729 L
.63988 .03758 L
.63913 .03789 L
.63838 .03822 L
.63763 .03856 L
.63688 .03891 L
.63688 .03891 L
.63625 .03929 L
.63561 .03968 L
.63498 .04009 L
.63434 .04051 L
.6337 .04095 L
.63306 .0414 L
.63242 .04186 L
.63178 .04234 L
.63114 .04283 L
.6305 .04333 L
.62986 .04385 L
.62921 .04438 L
.62921 .04438 L
.62869 .04495 L
.62816 .04553 L
.62764 .04612 L
.62711 .04673 L
.62659 .04735 L
.62606 .04798 L
.62553 .04863 L
.625 .0493 L
.62447 .04998 L
.62394 .05067 L
.62341 .05138 L
.62287 .0521 L
.62287 .0521 L
.62247 .05286 L
.62206 .05363 L
.62165 .05442 L
.62124 .05522 L
Mistroke
.62083 .05604 L
.62042 .05687 L
.62001 .05772 L
.6196 .05859 L
.61919 .05947 L
.61877 .06036 L
.61836 .06127 L
.61794 .0622 L
.61794 .0622 L
.61766 .06316 L
.61738 .06414 L
.6171 .06514 L
.61682 .06615 L
.61654 .06718 L
.61625 .06823 L
.61597 .06929 L
.61568 .07037 L
.6154 .07146 L
.61511 .07257 L
.61482 .0737 L
.61453 .07485 L
.61453 .07485 L
.61439 .07604 L
.61425 .07725 L
.61411 .07847 L
.61396 .07971 L
.61382 .08097 L
.61367 .08225 L
.61353 .08354 L
.61338 .08486 L
.61323 .08619 L
.61308 .08754 L
.61293 .08892 L
.61278 .09031 L
.61278 .09031 L
.61084 .09001 L
.6089 .08972 L
.60696 .08943 L
.60502 .08913 L
.60308 .08884 L
.60113 .08854 L
.59919 .08825 L
.59725 .08796 L
.59531 .08766 L
.59337 .08737 L
.59143 .08707 L
.58949 .08678 L
.58949 .08678 L
.59003 .07609 L
.59051 .06655 L
Mistroke
.59094 .05811 L
.59131 .05069 L
.59164 .04425 L
.59192 .03873 L
.59215 .03412 L
.59234 .03038 L
.59248 .0275 L
.59259 .02544 L
.59265 .02422 L
.59267 .02381 L
.59267 .02381 L
.59267 .02383 L
.59267 .02389 L
.59266 .02399 L
.59265 .02413 L
.59265 .02431 L
.59263 .02454 L
.59262 .0248 L
.59261 .0251 L
.59259 .02544 L
.59257 .02583 L
.59255 .02625 L
.59252 .02672 L
.59252 .02672 L
.59252 .02678 L
.59252 .02684 L
.59251 .02691 L
.59251 .02697 L
.59251 .02703 L
.5925 .0271 L
.5925 .02716 L
.5925 .02723 L
.59249 .02729 L
.59249 .02736 L
.59249 .02743 L
.59248 .0275 L
.59248 .0275 L
.59248 .02758 L
.59248 .02767 L
.59247 .02777 L
.59247 .02786 L
.59246 .02795 L
.59246 .02804 L
.59245 .02814 L
.59245 .02824 L
.59244 .02833 L
.59244 .02843 L
.59243 .02853 L
.59243 .02863 L
.59243 .02863 L
Mistroke
.59242 .02877 L
.59241 .0289 L
.59241 .02904 L
.5924 .02918 L
.59239 .02933 L
.59238 .02947 L
.59238 .02962 L
.59237 .02977 L
.59236 .02992 L
.59235 .03007 L
.59235 .03023 L
.59234 .03038 L
.59234 .03038 L
.59233 .03061 L
.59232 .03083 L
.5923 .03106 L
.59229 .0313 L
.59228 .03153 L
.59227 .03178 L
.59226 .03202 L
.59224 .03227 L
.59223 .03252 L
.59222 .03278 L
.5922 .03304 L
.59219 .03331 L
Mfstroke
.58949 .08678 m
.58914 .09368 L
.58878 .10079 L
.58841 .1081 L
.58803 .11562 L
.58764 .12333 L
.58724 .13122 L
.58683 .13929 L
.58642 .14753 L
.58599 .15594 L
.58556 .16452 L
.58512 .17326 L
.58467 .18216 L
.58467 .18216 L
.58462 .18316 L
.58457 .18416 L
.58452 .18516 L
.58447 .18616 L
.58441 .18717 L
.58436 .18818 L
.58431 .18919 L
.58426 .1902 L
.58421 .19121 L
.58416 .19223 L
.58411 .19325 L
.58406 .19427 L
.58406 .19427 L
.58402 .195 L
.58398 .19573 L
.58395 .19646 L
.58391 .19719 L
.58387 .19792 L
.58383 .19866 L
.5838 .19939 L
.58376 .20013 L
.58372 .20086 L
.58369 .2016 L
.58365 .20234 L
.58361 .20308 L
.58361 .20308 L
.58358 .20364 L
.58355 .20419 L
.58353 .20475 L
.5835 .20531 L
.58347 .20586 L
.58344 .20642 L
.58341 .20698 L
.58339 .20754 L
.58336 .2081 L
.58333 .20866 L
Mistroke
.5833 .20922 L
.58327 .20978 L
.58327 .20978 L
.58325 .21022 L
.58323 .21066 L
.58321 .21109 L
.58318 .21153 L
.58316 .21197 L
.58314 .21241 L
.58312 .21285 L
.58309 .21329 L
.58307 .21373 L
.58305 .21417 L
.58303 .21461 L
.58301 .21505 L
.58301 .21505 L
.58283 .21858 L
.58265 .22214 L
.58247 .22572 L
.58228 .22931 L
.5821 .23293 L
.58192 .23657 L
.58173 .24023 L
.58155 .24391 L
.58136 .2476 L
.58117 .25132 L
.58098 .25506 L
.58079 .25882 L
.58079 .25882 L
.57993 .27599 L
.57904 .29356 L
.57813 .31155 L
.5772 .32995 L
.57625 .34878 L
.57527 .36805 L
.57428 .38776 L
.57326 .40795 L
.57221 .42862 L
.57114 .4498 L
.57004 .47152 L
.56892 .49383 L
.56892 .49383 L
.57086 .49413 L
.5728 .49442 L
.57474 .49471 L
.57668 .49501 L
.57862 .4953 L
.58056 .4956 L
.5825 .49589 L
.58444 .49618 L
Mistroke
.58639 .49648 L
.58833 .49677 L
.59027 .49707 L
.59221 .49736 L
.59221 .49736 L
.59243 .49455 L
.59265 .49175 L
.59288 .48896 L
.5931 .48618 L
.59332 .48341 L
.59354 .48065 L
.59376 .47789 L
.59398 .47515 L
.5942 .47241 L
.59441 .46969 L
.59463 .46697 L
.59485 .46426 L
.59485 .46426 L
.59522 .46159 L
.59558 .45892 L
.59595 .45626 L
.59631 .45361 L
.59668 .45097 L
.59704 .44833 L
.59741 .44571 L
.59777 .44309 L
.59813 .44048 L
.59849 .43788 L
.59886 .43529 L
.59922 .43271 L
.59922 .43271 L
.59972 .43015 L
.60021 .4276 L
.60071 .42506 L
.60121 .42253 L
.6017 .42001 L
.6022 .41749 L
.60269 .41498 L
.60319 .41248 L
.60368 .40998 L
.60418 .4075 L
.60467 .40502 L
.60516 .40255 L
.60516 .40255 L
.60578 .4001 L
.6064 .39767 L
.60702 .39524 L
.60764 .39282 L
.60826 .3904 L
.60887 .38799 L
Mistroke
.60949 .38559 L
.61011 .3832 L
.61072 .38081 L
.61134 .37843 L
.61196 .37606 L
.61257 .3737 L
.61257 .3737 L
.61331 .37136 L
.61404 .36902 L
.61477 .3667 L
.61551 .36438 L
.61624 .36206 L
.61697 .35976 L
.6177 .35746 L
.61844 .35517 L
.61917 .35288 L
.6199 .35061 L
.62063 .34834 L
.62136 .34607 L
.62136 .34607 L
.62221 .34383 L
.62305 .3416 L
.62389 .33937 L
.62474 .33715 L
.62558 .33494 L
.62642 .33273 L
.62727 .33053 L
.62811 .32833 L
.62895 .32615 L
.62979 .32397 L
.63063 .32179 L
.63147 .31962 L
.63147 .31962 L
.63243 .31748 L
.63338 .31534 L
.63433 .31321 L
.63528 .31109 L
.63623 .30897 L
.63718 .30686 L
.63813 .30475 L
.63908 .30265 L
.64003 .30056 L
.64098 .29847 L
.64192 .29639 L
.64287 .29432 L
.64287 .29432 L
.64393 .29227 L
.64498 .29023 L
.64604 .28819 L
.6471 .28616 L
Mistroke
.64815 .28413 L
.64921 .28212 L
.65026 .2801 L
.65132 .2781 L
.65237 .2761 L
.65342 .27411 L
.65448 .27212 L
.65553 .27014 L
.65553 .27014 L
.65669 .26818 L
.65785 .26623 L
.65901 .26429 L
.66017 .26235 L
.66133 .26042 L
.66249 .25849 L
.66365 .25657 L
.66481 .25466 L
.66597 .25275 L
.66713 .25085 L
.66828 .24896 L
.66944 .24707 L
.66944 .24707 L
.67071 .24521 L
.67197 .24335 L
.67324 .2415 L
.6745 .23966 L
.67577 .23782 L
.67703 .23599 L
.6783 .23416 L
.67956 .23234 L
.68083 .23053 L
.68209 .22872 L
.68335 .22692 L
.68461 .22513 L
.68461 .22513 L
.68599 .22336 L
.68736 .2216 L
.68873 .21984 L
.69011 .21809 L
.69148 .21635 L
.69285 .21461 L
.69422 .21288 L
.69559 .21116 L
.69696 .20944 L
.69833 .20773 L
.6997 .20603 L
.70107 .20433 L
.70107 .20433 L
.70256 .20266 L
.70404 .20099 L
Mistroke
.70552 .19933 L
.707 .19768 L
.70849 .19603 L
.70997 .1944 L
.71145 .19276 L
.71293 .19114 L
.71441 .18952 L
.71589 .18791 L
.71737 .18631 L
.71885 .18471 L
.71885 .18471 L
.72045 .18314 L
.72205 .18157 L
.72365 .18001 L
.72525 .17846 L
.72684 .17692 L
.72844 .17538 L
.73004 .17385 L
.73163 .17233 L
.73323 .17082 L
.73482 .16931 L
.73642 .16781 L
.73801 .16632 L
.73801 .16632 L
.73974 .16485 L
.74146 .16339 L
.74318 .16194 L
.7449 .1605 L
.74662 .15906 L
.74833 .15763 L
.75005 .15621 L
.75177 .1548 L
.75349 .15339 L
.75521 .152 L
.75692 .15061 L
.75864 .14922 L
.75864 .14922 L
.76049 .14787 L
.76235 .14653 L
.7642 .14519 L
.76605 .14386 L
.7679 .14254 L
.76975 .14123 L
.7716 .13993 L
.77345 .13863 L
.7753 .13734 L
.77715 .13607 L
.77899 .1348 L
.78084 .13354 L
.78084 .13354 L
Mistroke
.78284 .13231 L
.78484 .13109 L
.78683 .12988 L
.78883 .12867 L
.79082 .12748 L
.79282 .12629 L
.79481 .12512 L
.7968 .12395 L
.7988 .1228 L
.80079 .12165 L
.80278 .12051 L
.80477 .11939 L
.80477 .11939 L
.78683 .11667 L
.76889 .11395 L
.75095 .11123 L
.73301 .10852 L
.71507 .1058 L
.69713 .10308 L
.67919 .10037 L
.66125 .09765 L
.64331 .09493 L
.62537 .09221 L
.60743 .0895 L
.58949 .08678 L
Mfstroke
.55316 .80551 m
.55271 .8144 L
.55227 .82314 L
.55184 .83172 L
.55141 .84013 L
.551 .84838 L
.55059 .85645 L
.55019 .86434 L
.5498 .87204 L
.54942 .87956 L
.54905 .88688 L
.54869 .89399 L
.54834 .90088 L
.54834 .90088 L
.56628 .9036 L
.58422 .90632 L
.60216 .90903 L
.62011 .91175 L
.63805 .91447 L
.65599 .91719 L
.67393 .9199 L
.69187 .92262 L
.70981 .92534 L
.72775 .92805 L
.74569 .93077 L
.76363 .93349 L
.76363 .93349 L
.76178 .93178 L
.75993 .93006 L
.75808 .92833 L
.75624 .92659 L
.75439 .92485 L
.75255 .92309 L
.7507 .92132 L
.74886 .91955 L
.74701 .91777 L
.74517 .91597 L
.74332 .91417 L
.74148 .91236 L
.74148 .91236 L
.73979 .91056 L
.7381 .90876 L
.7364 .90694 L
.73471 .90512 L
.73302 .90329 L
.73133 .90145 L
.72964 .8996 L
.72795 .89774 L
.72626 .89588 L
.72457 .89401 L
Mistroke
.72288 .89212 L
.72119 .89024 L
.72119 .89024 L
.71964 .88836 L
.71809 .88648 L
.71654 .88458 L
.71499 .88268 L
.71343 .88077 L
.71188 .87886 L
.71033 .87694 L
.70879 .875 L
.70724 .87307 L
.70569 .87112 L
.70414 .86917 L
.70259 .8672 L
.70259 .8672 L
.70117 .86526 L
.69975 .8633 L
.69833 .86133 L
.69691 .85936 L
.69549 .85738 L
.69407 .8554 L
.69265 .8534 L
.69124 .8514 L
.68982 .8494 L
.6884 .84738 L
.68698 .84536 L
.68557 .84333 L
.68557 .84333 L
.68427 .84131 L
.68297 .83929 L
.68168 .83726 L
.68038 .83522 L
.67908 .83317 L
.67779 .83112 L
.67649 .82906 L
.6752 .82699 L
.67391 .82492 L
.67261 .82284 L
.67132 .82075 L
.67002 .81866 L
.67002 .81866 L
.66885 .81658 L
.66767 .81449 L
.66649 .81239 L
.66531 .81029 L
.66413 .80818 L
.66296 .80607 L
.66178 .80394 L
.66061 .80181 L
Mistroke
.65943 .79968 L
.65825 .79753 L
.65708 .79539 L
.6559 .79323 L
.6559 .79323 L
.65484 .79108 L
.65378 .78893 L
.65271 .78677 L
.65165 .78461 L
.65059 .78244 L
.64953 .78026 L
.64847 .77808 L
.6474 .77589 L
.64634 .77369 L
.64528 .77149 L
.64422 .76928 L
.64316 .76706 L
.64316 .76706 L
.64221 .76485 L
.64126 .76264 L
.64031 .76042 L
.63936 .7582 L
.63841 .75596 L
.63746 .75373 L
.63651 .75148 L
.63557 .74923 L
.63462 .74697 L
.63367 .74471 L
.63272 .74244 L
.63177 .74016 L
.63177 .74016 L
.63094 .7379 L
.6301 .73562 L
.62926 .73334 L
.62842 .73106 L
.62759 .72877 L
.62675 .72647 L
.62591 .72416 L
.62508 .72185 L
.62424 .71953 L
.6234 .71721 L
.62257 .71488 L
.62173 .71254 L
.62173 .71254 L
.62101 .71022 L
.62028 .70788 L
.61956 .70554 L
.61883 .7032 L
.61811 .70085 L
.61739 .69849 L
Mistroke
.61666 .69612 L
.61594 .69375 L
.61522 .69137 L
.61449 .68899 L
.61377 .6866 L
.61305 .6842 L
.61305 .6842 L
.61244 .68181 L
.61183 .67942 L
.61122 .67702 L
.61061 .67461 L
.61 .6722 L
.60939 .66977 L
.60878 .66735 L
.60817 .66491 L
.60756 .66247 L
.60696 .66003 L
.60635 .65757 L
.60574 .65511 L
.60574 .65511 L
.60525 .65266 L
.60476 .65021 L
.60427 .64774 L
.60377 .64527 L
.60328 .6428 L
.60279 .64031 L
.6023 .63782 L
.60181 .63533 L
.60132 .63282 L
.60083 .63031 L
.60035 .62779 L
.59986 .62527 L
.59986 .62527 L
.59949 .62275 L
.59912 .62023 L
.59875 .6177 L
.59838 .61517 L
.59802 .61263 L
.59765 .61008 L
.59728 .60752 L
.59692 .60495 L
.59655 .60238 L
.59619 .5998 L
.59582 .59722 L
.59546 .59462 L
.59546 .59462 L
.59522 .59204 L
.59498 .58945 L
.59474 .58686 L
.59451 .58425 L
Mistroke
.59427 .58164 L
.59403 .57902 L
.5938 .57639 L
.59356 .57376 L
.59333 .57112 L
.59309 .56846 L
.59286 .56581 L
.59263 .56314 L
.59263 .56314 L
.59253 .56049 L
.59243 .55782 L
.59234 .55515 L
.59224 .55247 L
.59215 .54979 L
.59205 .54709 L
.59196 .54439 L
.59186 .54168 L
.59177 .53896 L
.59168 .53623 L
.59158 .53349 L
.59149 .53075 L
.59149 .53075 L
.59155 .52801 L
.59161 .52527 L
.59166 .52252 L
.59172 .51976 L
.59178 .517 L
.59184 .51422 L
.5919 .51143 L
.59196 .50864 L
.59202 .50583 L
.59208 .50302 L
.59215 .50019 L
.59221 .49736 L
.59221 .49736 L
.59027 .49707 L
.58833 .49677 L
.58639 .49648 L
.58444 .49618 L
.5825 .49589 L
.58056 .4956 L
.57862 .4953 L
.57668 .49501 L
.57474 .49471 L
.5728 .49442 L
.57086 .49413 L
.56892 .49383 L
.56892 .49383 L
.56779 .51614 L
.56669 .53787 L
Mistroke
.56562 .55905 L
.56458 .57972 L
.56356 .5999 L
.56256 .61962 L
.56159 .63888 L
.56063 .65771 L
.5597 .67612 L
.55879 .6941 L
.55791 .71168 L
.55704 .72884 L
.55704 .72884 L
.55685 .7326 L
.55666 .73634 L
.55647 .74006 L
.55629 .74376 L
.5561 .74744 L
.55591 .75109 L
.55573 .75473 L
.55555 .75835 L
.55537 .76195 L
.55518 .76552 L
.55501 .76908 L
.55483 .77262 L
.55483 .77262 L
.5548 .77306 L
.55478 .7735 L
.55476 .77394 L
.55474 .77438 L
.55472 .77482 L
.55469 .77525 L
.55467 .77569 L
.55465 .77613 L
.55463 .77657 L
.5546 .77701 L
.55458 .77744 L
.55456 .77788 L
.55456 .77788 L
.55453 .77844 L
.5545 .779 L
.55448 .77956 L
.55445 .78012 L
.55442 .78068 L
.55439 .78124 L
.55436 .7818 L
.55433 .78236 L
.55431 .78291 L
.55428 .78347 L
.55425 .78403 L
.55422 .78458 L
.55422 .78458 L
Mistroke
.55418 .78532 L
.55415 .78606 L
.55411 .7868 L
.55407 .78754 L
.55404 .78827 L
.554 .78901 L
.55396 .78974 L
.55392 .79048 L
.55389 .79121 L
.55385 .79194 L
.55381 .79267 L
.55378 .7934 L
.55378 .7934 L
.55372 .79442 L
.55367 .79544 L
.55362 .79645 L
.55357 .79746 L
.55352 .79848 L
.55347 .79949 L
.55342 .80049 L
.55337 .8015 L
.55332 .8025 L
.55327 .80351 L
.55321 .80451 L
.55316 .80551 L
Mfstroke
.54834 .90088 m
.54801 .90745 L
.5477 .91358 L
.54741 .91929 L
.54714 .92461 L
.54689 .92955 L
.54666 .93413 L
.54645 .93834 L
.54626 .9422 L
.54608 .94573 L
.54592 .94893 L
.54577 .9518 L
.54564 .95436 L
.54564 .95436 L
.54563 .95462 L
.54561 .95488 L
.5456 .95514 L
.54559 .95539 L
.54558 .95564 L
.54556 .95589 L
.54555 .95613 L
.54554 .95637 L
.54553 .9566 L
.54552 .95683 L
.5455 .95706 L
.54549 .95728 L
.54549 .95728 L
.54549 .95744 L
.54548 .95759 L
.54547 .95774 L
.54546 .9579 L
.54546 .95804 L
.54545 .95819 L
.54544 .95834 L
.54543 .95848 L
.54543 .95862 L
.54542 .95876 L
.54541 .9589 L
.54541 .95903 L
.54541 .95903 L
.5454 .95913 L
.5454 .95923 L
.54539 .95933 L
.54539 .95943 L
.54538 .95953 L
.54538 .95962 L
.54537 .95971 L
.54537 .95981 L
.54536 .9599 L
.54536 .95999 L
Mistroke
.54535 .96008 L
.54535 .96017 L
.54535 .96017 L
.54534 .96024 L
.54534 .9603 L
.54534 .96037 L
.54533 .96044 L
.54533 .9605 L
.54533 .96057 L
.54532 .96063 L
.54532 .9607 L
.54532 .96076 L
.54531 .96082 L
.54531 .96088 L
.54531 .96094 L
.54531 .96094 L
.54529 .96141 L
.54526 .96184 L
.54524 .96222 L
.54523 .96256 L
.54521 .96287 L
.5452 .96313 L
.54519 .96335 L
.54518 .96353 L
.54517 .96367 L
.54517 .96377 L
.54516 .96383 L
.54516 .96385 L
.54516 .96385 L
.54518 .96345 L
.54524 .96222 L
.54535 .96017 L
.54549 .95728 L
.54568 .95354 L
.54592 .94893 L
.54619 .94342 L
.54652 .93697 L
.54689 .92955 L
.54732 .92111 L
.5478 .91158 L
.54834 .90088 L
.54834 .90088 L
.55029 .90118 L
.55223 .90147 L
.55417 .90177 L
.55611 .90206 L
.55805 .90235 L
.55999 .90265 L
.56193 .90294 L
.56387 .90324 L
Mistroke
.56581 .90353 L
.56775 .90382 L
.5697 .90412 L
.57164 .90441 L
.57164 .90441 L
.57165 .90583 L
.57166 .90722 L
.57167 .9086 L
.57168 .90996 L
.57169 .9113 L
.57171 .91262 L
.57172 .91392 L
.57174 .9152 L
.57175 .91647 L
.57177 .91772 L
.57179 .91895 L
.57181 .92016 L
.57181 .92016 L
.57198 .92138 L
.57215 .92257 L
.57232 .92376 L
.57249 .92492 L
.57267 .92607 L
.57284 .9272 L
.57302 .92832 L
.57319 .92942 L
.57337 .9305 L
.57354 .93156 L
.57372 .93261 L
.5739 .93364 L
.5739 .93364 L
.57422 .93468 L
.57453 .9357 L
.57485 .93671 L
.57517 .9377 L
.57549 .93868 L
.57581 .93963 L
.57613 .94058 L
.57645 .94151 L
.57677 .94242 L
.5771 .94332 L
.57742 .9442 L
.57774 .94507 L
.57774 .94507 L
.5782 .94594 L
.57865 .9468 L
.5791 .94764 L
.57956 .94847 L
.58001 .94928 L
.58047 .95008 L
Mistroke
.58092 .95087 L
.58138 .95164 L
.58184 .95239 L
.58229 .95314 L
.58275 .95386 L
.58321 .95458 L
.58321 .95458 L
.58379 .9553 L
.58437 .956 L
.58496 .95669 L
.58554 .95737 L
.58612 .95803 L
.5867 .95868 L
.58729 .95931 L
.58787 .95993 L
.58846 .96054 L
.58904 .96113 L
.58963 .96171 L
.59022 .96228 L
.59022 .96228 L
.59092 .96285 L
.59162 .96341 L
.59233 .96395 L
.59303 .96448 L
.59374 .965 L
.59444 .9655 L
.59515 .96599 L
.59586 .96647 L
.59657 .96693 L
.59727 .96738 L
.59798 .96782 L
.59869 .96825 L
.59869 .96825 L
.59951 .96868 L
.60034 .96909 L
.60116 .96949 L
.60198 .96988 L
.60281 .97026 L
.60363 .97062 L
.60446 .97097 L
.60528 .97131 L
.60611 .97164 L
.60694 .97195 L
.60777 .97225 L
.60859 .97254 L
.60859 .97254 L
.60953 .97283 L
.61047 .9731 L
.61141 .97337 L
.61235 .97362 L
Mistroke
.61329 .97386 L
.61423 .97408 L
.61518 .9743 L
.61612 .9745 L
.61706 .97469 L
.61801 .97486 L
.61895 .97502 L
.6199 .97517 L
.6199 .97517 L
.62095 .97533 L
.62201 .97547 L
.62306 .9756 L
.62412 .97571 L
.62518 .97581 L
.62623 .9759 L
.62729 .97598 L
.62835 .97604 L
.62941 .97609 L
.63047 .97613 L
.63153 .97616 L
.63259 .97617 L
.63259 .97617 L
.63376 .97619 L
.63494 .97619 L
.63611 .97618 L
.63728 .97616 L
.63846 .97612 L
.63963 .97608 L
.64081 .97602 L
.64198 .97594 L
.64316 .97585 L
.64433 .97576 L
.64551 .97564 L
.64669 .97552 L
.64669 .97552 L
.64798 .97539 L
.64927 .97526 L
.65056 .97511 L
.65186 .97495 L
.65315 .97478 L
.65444 .97459 L
.65573 .97439 L
.65703 .97417 L
.65832 .97395 L
.65962 .9737 L
.66092 .97345 L
.66221 .97318 L
.66221 .97318 L
.66363 .97292 L
.66504 .97264 L
Mistroke
.66645 .97235 L
.66787 .97205 L
.66928 .97173 L
.6707 .9714 L
.67212 .97105 L
.67353 .97069 L
.67495 .97032 L
.67637 .96993 L
.67779 .96953 L
.67921 .96912 L
.67921 .96912 L
.68075 .96871 L
.68229 .96828 L
.68383 .96784 L
.68537 .96739 L
.68692 .96692 L
.68846 .96644 L
.69001 .96594 L
.69155 .96543 L
.6931 .96491 L
.69464 .96437 L
.69619 .96381 L
.69774 .96324 L
.69774 .96324 L
.69941 .96268 L
.70109 .9621 L
.70277 .9615 L
.70445 .96089 L
.70612 .96027 L
.7078 .95963 L
.70948 .95897 L
.71116 .9583 L
.71285 .95761 L
.71453 .95691 L
.71621 .95619 L
.71789 .95545 L
.71789 .95545 L
.71972 .95472 L
.72154 .95398 L
.72336 .95321 L
.72518 .95244 L
.72701 .95164 L
.72883 .95083 L
.73066 .95 L
.73249 .94915 L
.73431 .94829 L
.73614 .94741 L
.73797 .94652 L
.7398 .9456 L
.7398 .9456 L
Mistroke
.74178 .94469 L
.74376 .94377 L
.74575 .94282 L
.74773 .94186 L
.74971 .94088 L
.7517 .93988 L
.75368 .93886 L
.75567 .93782 L
.75766 .93677 L
.75965 .93569 L
.76164 .9346 L
.76363 .93349 L
.76363 .93349 L
.74569 .93077 L
.72775 .92805 L
.70981 .92534 L
.69187 .92262 L
.67393 .9199 L
.65599 .91719 L
.63805 .91447 L
.62011 .91175 L
.60216 .90903 L
.58422 .90632 L
.56628 .9036 L
.54834 .90088 L
Mfstroke
.039 .916 .04 r
.02381 .8241 m
.55222 .8241 L
s
0 0 0 r
2 Mabswid
.55222 .8241 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .69975 m
.55851 .69975 L
s
0 0 0 r
2 Mabswid
.55851 .69975 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42034 m
.57263 .42034 L
s
0 0 0 r
2 Mabswid
.57263 .42034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19627 m
.58395 .19627 L
s
0 0 0 r
2 Mabswid
.58395 .19627 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19627 m
.58395 .19627 L
s
0 0 0 r
2 Mabswid
.58395 .19627 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42034 m
.57263 .42034 L
s
0 0 0 r
2 Mabswid
.57263 .42034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .69975 m
.55851 .69975 L
s
0 0 0 r
2 Mabswid
.55851 .69975 Mdot
.039 .916 .04 r
.5 Mabswid
.55222 .8241 m
.73991 .83381 L
s
0 0 0 r
2 Mabswid
.73991 .83381 Mdot
.039 .916 .04 r
.5 Mabswid
.55851 .69975 m
.72771 .70851 L
s
0 0 0 r
2 Mabswid
.72771 .70851 Mdot
.039 .916 .04 r
.5 Mabswid
.57263 .42034 m
.7832 .43123 L
s
0 0 0 r
2 Mabswid
.7832 .43123 Mdot
.039 .916 .04 r
.5 Mabswid
.58395 .19627 m
.71394 .20299 L
s
0 0 0 r
2 Mabswid
.71394 .20299 Mdot
.039 .916 .04 r
.5 Mabswid
.58395 .19627 m
.82344 .20866 L
s
0 0 0 r
2 Mabswid
.82344 .20866 Mdot
.039 .916 .04 r
.5 Mabswid
.57263 .42034 m
.71859 .42789 L
s
0 0 0 r
2 Mabswid
.71859 .42789 Mdot
.039 .916 .04 r
.5 Mabswid
.55851 .69975 m
.75663 .71 L
s
0 0 0 r
2 Mabswid
.75663 .71 Mdot
.039 .916 .04 r
.5 Mabswid
.73991 .83381 m
.83952 .53482 L
s
0 0 0 r
2 Mabswid
.83952 .53482 Mdot
.039 .916 .04 r
.5 Mabswid
.72771 .70851 m
.84067 .36943 L
s
0 0 0 r
2 Mabswid
.84067 .36943 Mdot
.039 .916 .04 r
.5 Mabswid
.7832 .43123 m
.81406 .6404 L
s
0 0 0 r
2 Mabswid
.81406 .6404 Mdot
.039 .916 .04 r
.5 Mabswid
.71394 .20299 m
.79877 .77779 L
s
0 0 0 r
2 Mabswid
.79877 .77779 Mdot
.039 .916 .04 r
.5 Mabswid
.82344 .20866 m
.8347 .28493 L
s
0 0 0 r
2 Mabswid
.8347 .28493 Mdot
.039 .916 .04 r
.5 Mabswid
.71859 .42789 m
.82318 .41275 L
s
0 0 0 r
2 Mabswid
.82318 .41275 Mdot
.039 .916 .04 r
.5 Mabswid
.75663 .71 m
.82338 .70034 L
s
0 0 0 r
2 Mabswid
.82338 .70034 Mdot
.039 .916 .04 r
.5 Mabswid
.83952 .53482 m
.79834 .25579 L
s
0 0 0 r
2 Mabswid
.79834 .25579 Mdot
.039 .916 .04 r
.5 Mabswid
.84067 .36943 m
.77335 .37917 L
s
0 0 0 r
2 Mabswid
.77335 .37917 Mdot
.039 .916 .04 r
.5 Mabswid
.81406 .6404 m
.70706 .65589 L
s
0 0 0 r
2 Mabswid
.70706 .65589 Mdot
.039 .916 .04 r
.5 Mabswid
.79877 .77779 m
.76356 .88347 L
s
0 0 0 r
2 Mabswid
.76356 .88347 Mdot
.039 .916 .04 r
.5 Mabswid
.8347 .28493 m
.63748 .87695 L
s
0 0 0 r
2 Mabswid
.63748 .87695 Mdot
.039 .916 .04 r
.5 Mabswid
.82318 .41275 m
.74158 .65768 L
s
0 0 0 r
2 Mabswid
.74158 .65768 Mdot
.039 .916 .04 r
.5 Mabswid
.82338 .70034 m
.77601 .37931 L
s
0 0 0 r
2 Mabswid
.77601 .37931 Mdot
.039 .916 .04 r
.5 Mabswid
.79834 .25579 m
.58151 .24457 L
s
0 0 0 r
2 Mabswid
.58151 .24457 Mdot
.039 .916 .04 r
.5 Mabswid
.77335 .37917 m
.57523 .36892 L
s
0 0 0 r
2 Mabswid
.57523 .36892 Mdot
.039 .916 .04 r
.5 Mabswid
.70706 .65589 m
.56111 .64834 L
s
0 0 0 r
2 Mabswid
.56111 .64834 Mdot
.039 .916 .04 r
.5 Mabswid
.76356 .88347 m
.54978 .87241 L
s
0 0 0 r
2 Mabswid
.54978 .87241 Mdot
.039 .916 .04 r
.5 Mabswid
.63748 .87695 m
.54978 .87241 L
s
0 0 0 r
2 Mabswid
.54978 .87241 Mdot
.039 .916 .04 r
.5 Mabswid
.74158 .65768 m
.56111 .64834 L
s
0 0 0 r
2 Mabswid
.56111 .64834 Mdot
.039 .916 .04 r
.5 Mabswid
.77601 .37931 m
.57523 .36892 L
s
0 0 0 r
2 Mabswid
.57523 .36892 Mdot
.039 .916 .04 r
.5 Mabswid
.58151 .24457 m
.02381 .24457 L
s
0 0 0 r
2 Mabswid
.02381 .24457 Mdot
.039 .916 .04 r
.5 Mabswid
.57523 .36892 m
.02381 .36892 L
s
0 0 0 r
2 Mabswid
.02381 .36892 Mdot
.039 .916 .04 r
.5 Mabswid
.56111 .64834 m
.02381 .64834 L
s
0 0 0 r
2 Mabswid
.02381 .64834 Mdot
.039 .916 .04 r
.5 Mabswid
.54978 .87241 m
.02381 .87241 L
s
0 0 0 r
2 Mabswid
.02381 .87241 Mdot
.039 .916 .04 r
.5 Mabswid
.54978 .87241 m
.02381 .87241 L
s
0 0 0 r
2 Mabswid
.02381 .87241 Mdot
.039 .916 .04 r
.5 Mabswid
.56111 .64834 m
.02381 .64834 L
s
0 0 0 r
2 Mabswid
.02381 .64834 Mdot
.039 .916 .04 r
.5 Mabswid
.57523 .36892 m
.02381 .36892 L
s
0 0 0 r
2 Mabswid
.02381 .36892 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{179, 179},
  ImageMargins->{{42, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 178}, {178, 0}} -> {-2.1844, -26.1667, 0.515317, \
0.29768}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->FrontView];", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99082 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.493832 0.0188727 0.495409 0.0188727 [
[ 0 0 0 0 ]
[ 1 .99082 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .49541 m
.10215 .49541 L
.18048 .49541 L
.25882 .49541 L
.33716 .49541 L
.41549 .49541 L
.49383 .49541 L
.57217 .49541 L
.65051 .49541 L
.72884 .49541 L
.80718 .49541 L
.88552 .49541 L
.96385 .49541 L
.96385 .49541 L
.88552 .49541 L
.80718 .49541 L
.72884 .49541 L
.65051 .49541 L
.57217 .49541 L
.49383 .49541 L
.41549 .49541 L
.33716 .49541 L
.25882 .49541 L
.18048 .49541 L
.10215 .49541 L
.02381 .49541 L
.02381 .49541 L
s
.49383 .02359 m
.49383 .10223 L
.49383 .18086 L
.49383 .2595 L
.49383 .33814 L
.49383 .41677 L
.49383 .49541 L
.49383 .57405 L
.49383 .65268 L
.49383 .73132 L
.49383 .80995 L
.49383 .88859 L
.49383 .96723 L
.49383 .96723 L
.49383 .88859 L
.49383 .80995 L
.49383 .73132 L
.49383 .65268 L
.49383 .57405 L
.49383 .49541 L
.49383 .41677 L
.49383 .33814 L
.49383 .2595 L
.49383 .18086 L
.49383 .10223 L
.49383 .02359 L
.49383 .02359 L
s
.96385 .49541 m
.95983 .55699 L
.94784 .61752 L
.92808 .67597 L
.90088 .73132 L
.86673 .78263 L
.82619 .82903 L
.77996 .86973 L
.72884 .90402 L
.6737 .93131 L
.61548 .95115 L
.55518 .96319 L
.49383 .96723 L
.43248 .96319 L
.37218 .95115 L
.31396 .93131 L
.25882 .90402 L
.2077 .86973 L
.16148 .82903 L
.12094 .78263 L
.08678 .73132 L
.05959 .67597 L
.03983 .61752 L
.02783 .55699 L
.02381 .49541 L
.02783 .43382 L
.03983 .37329 L
.05959 .31485 L
.08678 .2595 L
.12094 .20818 L
.16148 .16178 L
.2077 .12109 L
.25882 .0868 L
.31396 .05951 L
.37218 .03967 L
.43248 .02763 L
.49383 .02359 L
.55518 .02763 L
.61548 .03967 L
.6737 .05951 L
.72884 .0868 L
.77996 .12109 L
.82619 .16178 L
.86673 .20818 L
.90088 .2595 L
.92808 .31485 L
.94784 .37329 L
.95983 .43382 L
.96385 .49541 L
s
.55551 .49541 m
.11939 .2595 L
.13002 .23773 L
.14194 .21665 L
.15516 .19628 L
.16971 .17663 L
.18563 .15772 L
.20299 .13959 L
.22186 .12227 L
.24235 .10583 L
.26458 .09034 L
.28874 .07588 L
.31505 .06259 L
.34384 .05064 L
.37555 .04027 L
.41085 .03184 L
.45082 .02594 L
.49736 .02359 L
.54448 .02594 L
.5859 .03184 L
.62328 .04027 L
.65755 .05064 L
.68928 .06259 L
.71887 .07588 L
.74659 .09034 L
.77265 .10583 L
.79718 .12227 L
.82032 .13959 L
.84215 .15772 L
.86274 .17663 L
.88213 .19628 L
.90038 .21665 L
.91749 .23773 L
.93349 .2595 L
.55551 .49541 L
s
.55551 .49541 m
.52644 .96723 L
.49831 .96654 L
.47027 .96445 L
.44232 .96097 L
.41446 .95604 L
.38669 .94962 L
.35901 .94165 L
.33144 .93205 L
.30397 .9207 L
.27662 .90746 L
.2494 .89214 L
.22232 .87448 L
.1954 .85415 L
.16869 .83066 L
.14221 .80328 L
.11604 .77086 L
.09031 .73132 L
.06921 .68943 L
.05468 .6511 L
.04482 .6153 L
.03855 .58143 L
.0352 .54915 L
.03433 .51821 L
.03562 .48843 L
.03882 .4597 L
.04378 .4319 L
.05035 .40499 L
.05843 .37889 L
.06794 .35356 L
.07883 .32898 L
.09106 .30512 L
.10458 .28196 L
.11939 .2595 L
.55551 .49541 L
s
.55551 .49541 m
.93349 .2595 L
.94293 .28196 L
.95126 .30512 L
.95846 .32898 L
.9645 .35356 L
.96936 .37889 L
.97297 .40499 L
.97527 .4319 L
.97617 .4597 L
.97556 .48843 L
.97328 .51821 L
.96913 .54915 L
.96284 .58143 L
.95401 .6153 L
.94207 .6511 L
.92609 .68943 L
.90441 .73132 L
.87926 .77086 L
.85455 .80328 L
.83014 .83066 L
.80598 .85415 L
.78201 .87448 L
.75821 .89214 L
.73455 .90746 L
.71102 .9207 L
.68761 .93205 L
.6643 .94165 L
.6411 .94962 L
.61799 .95604 L
.59497 .96097 L
.57204 .96445 L
.54919 .96654 L
.52644 .96723 L
.55551 .49541 L
s
.64268 .94294 m
.63123 .94662 L
.61962 .95002 L
.60784 .95314 L
.5959 .95597 L
.58379 .9585 L
.57151 .96074 L
.55905 .96266 L
.5464 .96427 L
.53357 .96554 L
.52053 .96647 L
.50729 .96703 L
.49383 .96723 L
.49383 .96723 L
.49655 .96723 L
.49927 .96723 L
.50198 .96723 L
.5047 .96723 L
.50742 .96723 L
.51013 .96723 L
.51285 .96723 L
.51557 .96723 L
.51829 .96723 L
.521 .96723 L
.52372 .96723 L
.52644 .96723 L
.52644 .96723 L
.52897 .96722 L
.53149 .96719 L
.534 .96715 L
.5365 .96709 L
.539 .96702 L
.54148 .96693 L
.54395 .96682 L
.54642 .9667 L
.54888 .96656 L
.55132 .9664 L
.55376 .96623 L
.55619 .96605 L
.55619 .96605 L
.55863 .96584 L
.56107 .96563 L
.56349 .9654 L
.56591 .96515 L
.56832 .96489 L
.57072 .96462 L
.57311 .96433 L
.57549 .96402 L
.57787 .9637 L
.58024 .96337 L
Mistroke
.5826 .96302 L
.58495 .96266 L
.58495 .96266 L
.58731 .96229 L
.58967 .9619 L
.59201 .9615 L
.59435 .96108 L
.59669 .96065 L
.59901 .96021 L
.60133 .95975 L
.60364 .95928 L
.60594 .9588 L
.60823 .9583 L
.61052 .9578 L
.6128 .95727 L
.6128 .95727 L
.61509 .95674 L
.61737 .95619 L
.61965 .95563 L
.62192 .95506 L
.62418 .95447 L
.62643 .95387 L
.62868 .95326 L
.63092 .95264 L
.63315 .952 L
.63538 .95135 L
.63759 .95069 L
.63981 .95002 L
.63981 .95002 L
.64203 .94933 L
.64424 .94863 L
.64645 .94793 L
.64865 .9472 L
.65085 .94647 L
.65303 .94572 L
.65522 .94497 L
.65739 .9442 L
.65956 .94342 L
.66172 .94262 L
.66387 .94182 L
.66602 .941 L
.66602 .941 L
.66817 .94017 L
.67033 .93933 L
.67247 .93848 L
.67461 .93762 L
.67674 .93674 L
.67886 .93586 L
.68098 .93496 L
.68309 .93405 L
Mistroke
.68519 .93313 L
.68729 .9322 L
.68938 .93125 L
.69147 .9303 L
.69147 .9303 L
.69356 .92933 L
.69565 .92836 L
.69773 .92737 L
.69981 .92637 L
.70188 .92535 L
.70394 .92433 L
.70599 .9233 L
.70804 .92225 L
.71009 .9212 L
.71212 .92013 L
.71415 .91905 L
.71618 .91796 L
.71618 .91796 L
.71821 .91686 L
.72024 .91575 L
.72226 .91462 L
.72427 .91349 L
.72628 .91234 L
.72829 .91119 L
.73028 .91002 L
.73227 .90884 L
.73425 .90765 L
.73623 .90645 L
.7382 .90524 L
.74016 .90402 L
.74016 .90402 L
.74214 .90278 L
.7441 .90154 L
.74606 .90028 L
.74802 .89901 L
.74997 .89773 L
.75191 .89644 L
.75384 .89514 L
.75577 .89383 L
.7577 .89251 L
.75961 .89117 L
.76152 .88983 L
.76342 .88847 L
.76342 .88847 L
.76534 .8871 L
.76725 .88573 L
.76915 .88434 L
.77104 .88294 L
.77293 .88152 L
.77481 .8801 L
Mistroke
.77668 .87866 L
.77855 .87722 L
.78041 .87576 L
.78227 .87429 L
.78412 .87281 L
.78596 .87132 L
.78596 .87132 L
.78781 .86982 L
.78966 .86831 L
.7915 .86678 L
.79333 .86524 L
.79516 .8637 L
.79698 .86214 L
.79879 .86056 L
.8006 .85898 L
.8024 .85739 L
.80419 .85578 L
.80598 .85416 L
.80776 .85254 L
.80776 .85254 L
.80955 .85089 L
.81133 .84924 L
.81311 .84758 L
.81488 .8459 L
.81664 .84421 L
.8184 .84251 L
.82015 .8408 L
.82189 .83908 L
.82363 .83734 L
.82536 .8356 L
.82708 .83384 L
.82879 .83206 L
.82879 .83206 L
.83052 .83028 L
.83224 .82848 L
.83395 .82667 L
.83565 .82485 L
.83735 .82302 L
.83904 .82117 L
.84073 .81931 L
.8424 .81744 L
.84407 .81556 L
.84573 .81366 L
.84739 .81175 L
.84903 .80983 L
.84903 .80983 L
.85069 .80789 L
.85234 .80595 L
.85398 .80399 L
.85562 .80201 L
Mistroke
.85725 .80002 L
.85887 .79802 L
.86048 .79601 L
.86209 .79398 L
.86368 .79194 L
.86527 .78988 L
.86685 .78781 L
.86843 .78573 L
.86843 .78573 L
.87001 .78363 L
.87159 .78152 L
.87316 .7794 L
.87472 .77726 L
.87628 .77511 L
.87782 .77294 L
.87936 .77076 L
.88089 .76856 L
.88241 .76635 L
.88392 .76412 L
.88542 .76188 L
.88692 .75963 L
.88692 .75963 L
.88842 .75735 L
.88992 .75507 L
.89141 .75276 L
.8929 .75045 L
.89437 .74811 L
.89583 .74576 L
.89728 .7434 L
.89873 .74101 L
.90016 .73861 L
.90159 .7362 L
.90301 .73377 L
.90441 .73132 L
.90441 .73132 L
.90412 .73132 L
.90382 .73132 L
.90353 .73132 L
.90324 .73132 L
.90294 .73132 L
.90265 .73132 L
.90235 .73132 L
.90206 .73132 L
.90177 .73132 L
.90147 .73132 L
.90118 .73132 L
.90088 .73132 L
.90088 .73132 L
.88927 .75045 L
.87708 .76856 L
Mistroke
.86434 .78573 L
.85109 .80201 L
.83735 .81744 L
.82314 .83206 L
.80849 .8459 L
.7934 .85898 L
.77788 .87132 L
.76195 .88294 L
.7456 .89383 L
.72884 .90402 L
.72884 .90402 L
.72506 .90618 L
.72127 .90831 L
.71745 .91041 L
.71361 .91247 L
.70975 .9145 L
.70587 .91649 L
.70197 .91845 L
.69805 .92037 L
.6941 .92225 L
.69014 .9241 L
.68616 .92592 L
.68216 .9277 L
.68216 .9277 L
.68166 .92792 L
.68116 .92814 L
.68065 .92836 L
.68015 .92857 L
.67965 .92879 L
.67915 .92901 L
.67864 .92922 L
.67814 .92944 L
.67763 .92966 L
.67713 .92987 L
.67662 .93009 L
.67612 .9303 L
.67612 .9303 L
.67547 .93057 L
.67482 .93085 L
.67417 .93112 L
.67352 .93139 L
.67286 .93166 L
.67221 .93193 L
.67156 .9322 L
.6709 .93247 L
.67025 .93273 L
.66959 .933 L
.66894 .93326 L
.66828 .93353 L
.66828 .93353 L
Mistroke
.66741 .93388 L
.66653 .93422 L
.66565 .93457 L
.66478 .93492 L
.6639 .93526 L
.66302 .9356 L
.66213 .93594 L
.66125 .93628 L
.66037 .93662 L
.65949 .93695 L
.6586 .93729 L
.65771 .93762 L
.65771 .93762 L
.65647 .93808 L
.65523 .93854 L
.65398 .93899 L
.65274 .93945 L
.65149 .93989 L
.65023 .94034 L
.64898 .94078 L
.64773 .94122 L
.64647 .94166 L
.64521 .94209 L
.64395 .94252 L
.64268 .94294 L
Mfstroke
.49383 .96723 m
.48037 .96703 L
.46713 .96647 L
.4541 .96554 L
.44126 .96427 L
.42862 .96266 L
.41615 .96074 L
.40387 .9585 L
.39176 .95597 L
.37982 .95314 L
.36805 .95002 L
.35643 .94662 L
.34498 .94294 L
.34498 .94294 L
.34372 .94252 L
.34246 .94209 L
.3412 .94166 L
.33994 .94122 L
.33868 .94078 L
.33743 .94034 L
.33618 .93989 L
.33493 .93945 L
.33368 .93899 L
.33244 .93854 L
.33119 .93808 L
.32995 .93762 L
.32995 .93762 L
.32906 .93729 L
.32818 .93695 L
.32729 .93662 L
.32641 .93628 L
.32553 .93594 L
.32465 .9356 L
.32377 .93526 L
.32289 .93492 L
.32201 .93457 L
.32113 .93422 L
.32026 .93388 L
.31938 .93353 L
.31938 .93353 L
.31873 .93326 L
.31807 .933 L
.31742 .93273 L
.31676 .93247 L
.31611 .9322 L
.31545 .93193 L
.3148 .93166 L
.31415 .93139 L
.3135 .93112 L
.31285 .93085 L
Mistroke
.3122 .93057 L
.31155 .9303 L
.31155 .9303 L
.31104 .93009 L
.31054 .92987 L
.31003 .92966 L
.30953 .92944 L
.30902 .92922 L
.30852 .92901 L
.30802 .92879 L
.30751 .92857 L
.30701 .92836 L
.30651 .92814 L
.30601 .92792 L
.3055 .9277 L
.3055 .9277 L
.3015 .92592 L
.29752 .9241 L
.29356 .92225 L
.28962 .92037 L
.2857 .91845 L
.2818 .91649 L
.27792 .9145 L
.27406 .91247 L
.27022 .91041 L
.2664 .90831 L
.2626 .90618 L
.25882 .90402 L
.25882 .90402 L
.24206 .89383 L
.22572 .88294 L
.20978 .87132 L
.19427 .85898 L
.17918 .8459 L
.16452 .83206 L
.15032 .81744 L
.13658 .80201 L
.12333 .78573 L
.11059 .76856 L
.09839 .75045 L
.08678 .73132 L
.08678 .73132 L
.08707 .73132 L
.08737 .73132 L
.08766 .73132 L
.08796 .73132 L
.08825 .73132 L
.08854 .73132 L
.08884 .73132 L
.08913 .73132 L
Mistroke
.08943 .73132 L
.08972 .73132 L
.09001 .73132 L
.09031 .73132 L
.09031 .73132 L
.09174 .73377 L
.09318 .7362 L
.09463 .73861 L
.09609 .74101 L
.09756 .7434 L
.09903 .74576 L
.10052 .74811 L
.10202 .75045 L
.10352 .75276 L
.10504 .75507 L
.10656 .75735 L
.10809 .75963 L
.10809 .75963 L
.10966 .76188 L
.11123 .76412 L
.11281 .76635 L
.1144 .76856 L
.116 .77076 L
.1176 .77294 L
.11922 .77511 L
.12084 .77726 L
.12247 .7794 L
.12411 .78152 L
.12576 .78363 L
.12742 .78573 L
.12742 .78573 L
.1291 .78781 L
.13079 .78988 L
.13249 .79194 L
.1342 .79398 L
.13592 .79601 L
.13764 .79802 L
.13937 .80002 L
.14111 .80201 L
.14286 .80399 L
.14461 .80595 L
.14637 .80789 L
.14814 .80983 L
.14814 .80983 L
.14994 .81175 L
.15174 .81366 L
.15355 .81556 L
.15537 .81744 L
.15719 .81931 L
.15903 .82117 L
Mistroke
.16087 .82302 L
.16271 .82485 L
.16457 .82667 L
.16643 .82848 L
.16829 .83028 L
.17017 .83206 L
.17017 .83206 L
.17207 .83384 L
.17398 .8356 L
.17589 .83734 L
.17781 .83908 L
.17974 .8408 L
.18167 .84251 L
.18362 .84421 L
.18556 .8459 L
.18752 .84758 L
.18948 .84924 L
.19145 .85089 L
.19343 .85254 L
.19343 .85254 L
.19543 .85416 L
.19743 .85578 L
.19945 .85739 L
.20147 .85898 L
.20349 .86056 L
.20553 .86214 L
.20756 .8637 L
.20961 .86524 L
.21166 .86678 L
.21372 .86831 L
.21579 .86982 L
.21786 .87132 L
.21786 .87132 L
.21996 .87281 L
.22206 .87429 L
.22417 .87576 L
.22628 .87722 L
.22841 .87866 L
.23053 .8801 L
.23267 .88152 L
.23481 .88294 L
.23696 .88434 L
.23911 .88573 L
.24127 .8871 L
.24344 .88847 L
.24344 .88847 L
.24563 .88983 L
.24783 .89117 L
.25003 .89251 L
.25224 .89383 L
Mistroke
.25445 .89514 L
.25667 .89644 L
.2589 .89773 L
.26114 .89901 L
.26338 .90028 L
.26563 .90154 L
.26788 .90278 L
.27014 .90402 L
.27014 .90402 L
.27242 .90524 L
.27471 .90645 L
.27701 .90765 L
.27931 .90884 L
.28162 .91002 L
.28393 .91119 L
.28625 .91234 L
.28858 .91349 L
.29092 .91462 L
.29326 .91575 L
.2956 .91686 L
.29796 .91796 L
.29796 .91796 L
.30033 .91905 L
.30271 .92013 L
.3051 .9212 L
.3075 .92225 L
.3099 .9233 L
.31231 .92433 L
.31472 .92535 L
.31714 .92637 L
.31957 .92737 L
.32201 .92836 L
.32445 .92933 L
.32689 .9303 L
.32689 .9303 L
.32936 .93125 L
.33184 .9322 L
.33433 .93313 L
.33682 .93405 L
.33931 .93496 L
.34182 .93586 L
.34433 .93674 L
.34684 .93762 L
.34937 .93848 L
.3519 .93933 L
.35443 .94017 L
.35698 .941 L
.35698 .941 L
.35954 .94182 L
.36212 .94262 L
Mistroke
.3647 .94342 L
.36729 .9442 L
.36988 .94497 L
.37248 .94572 L
.37509 .94647 L
.3777 .9472 L
.38033 .94793 L
.38296 .94863 L
.38559 .94933 L
.38823 .95002 L
.38823 .95002 L
.3909 .95069 L
.39358 .95135 L
.39626 .952 L
.39895 .95264 L
.40164 .95326 L
.40435 .95387 L
.40706 .95447 L
.40978 .95506 L
.4125 .95563 L
.41523 .95619 L
.41797 .95674 L
.42072 .95727 L
.42072 .95727 L
.4235 .9578 L
.42628 .9583 L
.42907 .9588 L
.43186 .95928 L
.43467 .95975 L
.43748 .96021 L
.4403 .96065 L
.44313 .96108 L
.44596 .9615 L
.4488 .9619 L
.45165 .96229 L
.45451 .96266 L
.45451 .96266 L
.4574 .96302 L
.4603 .96337 L
.4632 .9637 L
.46611 .96402 L
.46903 .96433 L
.47196 .96462 L
.4749 .96489 L
.47784 .96515 L
.48079 .9654 L
.48376 .96563 L
.48673 .96584 L
.48971 .96605 L
.48971 .96605 L
Mistroke
.49272 .96623 L
.49574 .9664 L
.49877 .96656 L
.5018 .9667 L
.50485 .96682 L
.50791 .96693 L
.51097 .96702 L
.51404 .96709 L
.51713 .96715 L
.52022 .96719 L
.52332 .96722 L
.52644 .96723 L
.52644 .96723 L
.52372 .96723 L
.521 .96723 L
.51829 .96723 L
.51557 .96723 L
.51285 .96723 L
.51013 .96723 L
.50742 .96723 L
.5047 .96723 L
.50198 .96723 L
.49927 .96723 L
.49655 .96723 L
.49383 .96723 L
Mfstroke
.03331 .40105 m
.03586 .38925 L
.03873 .37745 L
.04193 .36566 L
.04546 .35386 L
.04933 .34207 L
.05354 .33027 L
.05811 .31848 L
.06305 .30668 L
.06837 .29489 L
.07409 .28309 L
.08022 .2713 L
.08678 .2595 L
.08678 .2595 L
.0895 .2595 L
.09221 .2595 L
.09493 .2595 L
.09765 .2595 L
.10037 .2595 L
.10308 .2595 L
.1058 .2595 L
.10852 .2595 L
.11123 .2595 L
.11395 .2595 L
.11667 .2595 L
.11939 .2595 L
.11939 .2595 L
.11769 .26196 L
.11602 .26441 L
.11436 .26687 L
.11272 .26933 L
.11111 .27179 L
.10951 .27424 L
.10793 .2767 L
.10636 .27916 L
.10482 .28162 L
.10329 .28407 L
.10179 .28653 L
.1003 .28899 L
.1003 .28899 L
.09884 .29145 L
.09741 .2939 L
.096 .29636 L
.0946 .29882 L
.09322 .30128 L
.09185 .30373 L
.0905 .30619 L
.08917 .30865 L
.08786 .31111 L
.08656 .31356 L
Mistroke
.08527 .31602 L
.08401 .31848 L
.08401 .31848 L
.08278 .32093 L
.08156 .32339 L
.08037 .32585 L
.07918 .32831 L
.07802 .33076 L
.07687 .33322 L
.07573 .33568 L
.07461 .33814 L
.0735 .34059 L
.07241 .34305 L
.07134 .34551 L
.07028 .34797 L
.07028 .34797 L
.06925 .35042 L
.06824 .35288 L
.06724 .35534 L
.06626 .3578 L
.06529 .36025 L
.06434 .36271 L
.0634 .36517 L
.06248 .36763 L
.06157 .37008 L
.06067 .37254 L
.05979 .375 L
.05892 .37745 L
.05892 .37745 L
.05809 .37991 L
.05727 .38237 L
.05646 .38483 L
.05566 .38728 L
.05488 .38974 L
.05412 .3922 L
.05337 .39466 L
.05263 .39711 L
.0519 .39957 L
.05119 .40203 L
.05049 .40449 L
.04981 .40694 L
.04981 .40694 L
.04916 .4094 L
.04852 .41186 L
.04789 .41432 L
.04728 .41677 L
.04668 .41923 L
.04609 .42169 L
.04552 .42414 L
.04495 .4266 L
Mistroke
.04441 .42906 L
.04387 .43152 L
.04335 .43397 L
.04284 .43643 L
.04284 .43643 L
.04237 .43889 L
.0419 .44135 L
.04145 .4438 L
.04101 .44626 L
.04058 .44872 L
.04017 .45118 L
.03977 .45363 L
.03938 .45609 L
.03901 .45855 L
.03865 .46101 L
.0383 .46346 L
.03796 .46592 L
.03796 .46592 L
.03766 .46838 L
.03736 .47084 L
.03708 .47329 L
.03681 .47575 L
.03656 .47821 L
.03632 .48066 L
.03609 .48312 L
.03587 .48558 L
.03566 .48804 L
.03547 .49049 L
.03529 .49295 L
.03513 .49541 L
.03513 .49541 L
.03499 .49787 L
.03487 .50032 L
.03476 .50278 L
.03466 .50524 L
.03457 .5077 L
.0345 .51015 L
.03444 .51261 L
.03439 .51507 L
.03436 .51753 L
.03433 .51998 L
.03432 .52244 L
.03433 .5249 L
.03433 .5249 L
.03436 .52736 L
.03441 .52981 L
.03447 .53227 L
.03454 .53473 L
.03462 .53718 L
.03472 .53964 L
Mistroke
.03483 .5421 L
.03495 .54456 L
.03509 .54701 L
.03524 .54947 L
.0354 .55193 L
.03558 .55439 L
.03558 .55439 L
.03578 .55684 L
.036 .5593 L
.03623 .56176 L
.03647 .56422 L
.03673 .56667 L
.037 .56913 L
.03729 .57159 L
.03758 .57405 L
.03789 .5765 L
.03822 .57896 L
.03856 .58142 L
.03891 .58387 L
.03891 .58387 L
.03929 .58633 L
.03968 .58879 L
.04009 .59125 L
.04051 .5937 L
.04095 .59616 L
.0414 .59862 L
.04186 .60108 L
.04234 .60353 L
.04283 .60599 L
.04333 .60845 L
.04385 .61091 L
.04438 .61336 L
.04438 .61336 L
.04495 .61582 L
.04553 .61828 L
.04612 .62074 L
.04673 .62319 L
.04735 .62565 L
.04798 .62811 L
.04863 .63057 L
.0493 .63302 L
.04998 .63548 L
.05067 .63794 L
.05138 .64039 L
.0521 .64285 L
.0521 .64285 L
.05286 .64531 L
.05363 .64777 L
.05442 .65022 L
.05522 .65268 L
Mistroke
.05604 .65514 L
.05687 .6576 L
.05772 .66005 L
.05859 .66251 L
.05947 .66497 L
.06036 .66743 L
.06127 .66988 L
.0622 .67234 L
.0622 .67234 L
.06316 .6748 L
.06414 .67726 L
.06514 .67971 L
.06615 .68217 L
.06718 .68463 L
.06823 .68709 L
.06929 .68954 L
.07037 .692 L
.07146 .69446 L
.07257 .69691 L
.0737 .69937 L
.07485 .70183 L
.07485 .70183 L
.07604 .70429 L
.07725 .70674 L
.07847 .7092 L
.07971 .71166 L
.08097 .71412 L
.08225 .71657 L
.08354 .71903 L
.08486 .72149 L
.08619 .72395 L
.08754 .7264 L
.08892 .72886 L
.09031 .73132 L
.09031 .73132 L
.09001 .73132 L
.08972 .73132 L
.08943 .73132 L
.08913 .73132 L
.08884 .73132 L
.08854 .73132 L
.08825 .73132 L
.08796 .73132 L
.08766 .73132 L
.08737 .73132 L
.08707 .73132 L
.08678 .73132 L
.08678 .73132 L
.07609 .71166 L
.06655 .692 L
Mistroke
.05811 .67234 L
.05069 .65268 L
.04425 .63302 L
.03873 .61336 L
.03412 .5937 L
.03038 .57405 L
.0275 .55439 L
.02544 .53473 L
.02422 .51507 L
.02381 .49541 L
.02381 .49541 L
.02383 .49104 L
.02389 .48667 L
.02399 .4823 L
.02413 .47793 L
.02431 .47357 L
.02454 .4692 L
.0248 .46483 L
.0251 .46046 L
.02544 .45609 L
.02583 .45172 L
.02625 .44735 L
.02672 .44298 L
.02672 .44298 L
.02678 .44244 L
.02684 .44189 L
.02691 .44135 L
.02697 .4408 L
.02703 .44025 L
.0271 .43971 L
.02716 .43916 L
.02723 .43862 L
.02729 .43807 L
.02736 .43752 L
.02743 .43698 L
.0275 .43643 L
.0275 .43643 L
.02758 .43573 L
.02767 .43503 L
.02777 .43433 L
.02786 .43362 L
.02795 .43292 L
.02804 .43222 L
.02814 .43152 L
.02824 .43081 L
.02833 .43011 L
.02843 .42941 L
.02853 .42871 L
.02863 .42801 L
.02863 .42801 L
Mistroke
.02877 .42707 L
.0289 .42613 L
.02904 .4252 L
.02918 .42426 L
.02933 .42333 L
.02947 .42239 L
.02962 .42145 L
.02977 .42052 L
.02992 .41958 L
.03007 .41865 L
.03023 .41771 L
.03038 .41677 L
.03038 .41677 L
.03061 .41546 L
.03083 .41415 L
.03106 .41284 L
.0313 .41153 L
.03153 .41022 L
.03178 .40891 L
.03202 .4076 L
.03227 .40629 L
.03252 .40498 L
.03278 .40367 L
.03304 .40236 L
.03331 .40105 L
Mfstroke
.08678 .2595 m
.09368 .2479 L
.10079 .23667 L
.1081 .2258 L
.11562 .21528 L
.12333 .20509 L
.13122 .19522 L
.13929 .18565 L
.14753 .1764 L
.15594 .16743 L
.16452 .15875 L
.17326 .15036 L
.18216 .14224 L
.18216 .14224 L
.18316 .14135 L
.18416 .14047 L
.18516 .13959 L
.18616 .13872 L
.18717 .13785 L
.18818 .13698 L
.18919 .13611 L
.1902 .13525 L
.19121 .13439 L
.19223 .13354 L
.19325 .13268 L
.19427 .13184 L
.19427 .13184 L
.195 .13123 L
.19573 .13063 L
.19646 .13003 L
.19719 .12943 L
.19792 .12883 L
.19866 .12824 L
.19939 .12764 L
.20013 .12705 L
.20086 .12646 L
.2016 .12587 L
.20234 .12528 L
.20308 .12469 L
.20308 .12469 L
.20364 .12426 L
.20419 .12382 L
.20475 .12338 L
.20531 .12295 L
.20586 .12251 L
.20642 .12208 L
.20698 .12165 L
.20754 .12121 L
.2081 .12078 L
.20866 .12035 L
Mistroke
.20922 .11992 L
.20978 .1195 L
.20978 .1195 L
.21022 .11916 L
.21066 .11883 L
.21109 .1185 L
.21153 .11817 L
.21197 .11784 L
.21241 .11751 L
.21285 .11718 L
.21329 .11685 L
.21373 .11653 L
.21417 .1162 L
.21461 .11587 L
.21505 .11554 L
.21505 .11554 L
.21858 .11296 L
.22214 .1104 L
.22572 .10788 L
.22931 .1054 L
.23293 .10295 L
.23657 .10054 L
.24023 .09816 L
.24391 .09582 L
.2476 .09351 L
.25132 .09124 L
.25506 .089 L
.25882 .0868 L
.25882 .0868 L
.27599 .07733 L
.29356 .06856 L
.31155 .06052 L
.32995 .0532 L
.34878 .04662 L
.36805 .0408 L
.38776 .03576 L
.40795 .03154 L
.42862 .02816 L
.4498 .02567 L
.47152 .02412 L
.49383 .02359 L
.49383 .02359 L
.49413 .02359 L
.49442 .02359 L
.49471 .02359 L
.49501 .02359 L
.4953 .02359 L
.4956 .02359 L
.49589 .02359 L
.49618 .02359 L
Mistroke
.49648 .02359 L
.49677 .02359 L
.49707 .02359 L
.49736 .02359 L
.49736 .02359 L
.49455 .0236 L
.49175 .02363 L
.48896 .02367 L
.48618 .02373 L
.48341 .0238 L
.48065 .02389 L
.47789 .024 L
.47515 .02412 L
.47241 .02426 L
.46969 .02442 L
.46697 .02459 L
.46426 .02477 L
.46426 .02477 L
.46159 .02497 L
.45892 .02519 L
.45626 .02542 L
.45361 .02567 L
.45097 .02593 L
.44833 .0262 L
.44571 .02649 L
.44309 .0268 L
.44048 .02711 L
.43788 .02745 L
.43529 .02779 L
.43271 .02816 L
.43271 .02816 L
.43015 .02853 L
.4276 .02892 L
.42506 .02932 L
.42253 .02974 L
.42001 .03017 L
.41749 .03061 L
.41498 .03107 L
.41248 .03154 L
.40998 .03202 L
.4075 .03251 L
.40502 .03302 L
.40255 .03355 L
.40255 .03355 L
.4001 .03408 L
.39767 .03463 L
.39524 .03519 L
.39282 .03576 L
.3904 .03635 L
.38799 .03695 L
Mistroke
.38559 .03756 L
.3832 .03818 L
.38081 .03882 L
.37843 .03947 L
.37606 .04013 L
.3737 .0408 L
.3737 .0408 L
.37136 .04149 L
.36902 .04218 L
.3667 .04289 L
.36438 .04361 L
.36206 .04435 L
.35976 .04509 L
.35746 .04585 L
.35517 .04662 L
.35288 .0474 L
.35061 .0482 L
.34834 .049 L
.34607 .04982 L
.34607 .04982 L
.34383 .05064 L
.3416 .05148 L
.33937 .05234 L
.33715 .0532 L
.33494 .05407 L
.33273 .05496 L
.33053 .05586 L
.32833 .05677 L
.32615 .05769 L
.32397 .05862 L
.32179 .05956 L
.31962 .06052 L
.31962 .06052 L
.31748 .06149 L
.31534 .06246 L
.31321 .06345 L
.31109 .06445 L
.30897 .06546 L
.30686 .06649 L
.30475 .06752 L
.30265 .06856 L
.30056 .06962 L
.29847 .07069 L
.29639 .07177 L
.29432 .07286 L
.29432 .07286 L
.29227 .07396 L
.29023 .07507 L
.28819 .07619 L
.28616 .07733 L
Mistroke
.28413 .07847 L
.28212 .07963 L
.2801 .0808 L
.2781 .08198 L
.2761 .08317 L
.27411 .08437 L
.27212 .08558 L
.27014 .0868 L
.27014 .0868 L
.26818 .08804 L
.26623 .08928 L
.26429 .09054 L
.26235 .09181 L
.26042 .09308 L
.25849 .09437 L
.25657 .09568 L
.25466 .09699 L
.25275 .09831 L
.25085 .09964 L
.24896 .10099 L
.24707 .10235 L
.24707 .10235 L
.24521 .10371 L
.24335 .10509 L
.2415 .10648 L
.23966 .10788 L
.23782 .1093 L
.23599 .11072 L
.23416 .11215 L
.23234 .1136 L
.23053 .11506 L
.22872 .11653 L
.22692 .11801 L
.22513 .1195 L
.22513 .1195 L
.22336 .121 L
.2216 .12251 L
.21984 .12404 L
.21809 .12557 L
.21635 .12712 L
.21461 .12868 L
.21288 .13025 L
.21116 .13184 L
.20944 .13343 L
.20773 .13504 L
.20603 .13665 L
.20433 .13828 L
.20433 .13828 L
.20266 .13992 L
.20099 .14158 L
Mistroke
.19933 .14324 L
.19768 .14492 L
.19603 .1466 L
.1944 .1483 L
.19276 .15002 L
.19114 .15174 L
.18952 .15348 L
.18791 .15522 L
.18631 .15698 L
.18471 .15875 L
.18471 .15875 L
.18314 .16054 L
.18157 .16234 L
.18001 .16414 L
.17846 .16597 L
.17692 .1678 L
.17538 .16965 L
.17385 .1715 L
.17233 .17338 L
.17082 .17526 L
.16931 .17716 L
.16781 .17907 L
.16632 .18099 L
.16632 .18099 L
.16485 .18292 L
.16339 .18487 L
.16194 .18683 L
.1605 .18881 L
.15906 .1908 L
.15763 .1928 L
.15621 .19481 L
.1548 .19684 L
.15339 .19888 L
.152 .20094 L
.15061 .203 L
.14922 .20509 L
.14922 .20509 L
.14787 .20718 L
.14653 .20929 L
.14519 .21142 L
.14386 .21356 L
.14254 .21571 L
.14123 .21788 L
.13993 .22006 L
.13863 .22226 L
.13734 .22447 L
.13607 .2267 L
.1348 .22894 L
.13354 .23119 L
.13354 .23119 L
Mistroke
.13231 .23346 L
.13109 .23575 L
.12988 .23805 L
.12867 .24037 L
.12748 .24271 L
.12629 .24506 L
.12512 .24742 L
.12395 .24981 L
.1228 .2522 L
.12165 .25462 L
.12051 .25705 L
.11939 .2595 L
.11939 .2595 L
.11667 .2595 L
.11395 .2595 L
.11123 .2595 L
.10852 .2595 L
.1058 .2595 L
.10308 .2595 L
.10037 .2595 L
.09765 .2595 L
.09493 .2595 L
.09221 .2595 L
.0895 .2595 L
.08678 .2595 L
Mfstroke
.80551 .14224 m
.8144 .15036 L
.82314 .15875 L
.83172 .16743 L
.84013 .1764 L
.84838 .18565 L
.85645 .19522 L
.86434 .20509 L
.87204 .21528 L
.87956 .2258 L
.88688 .23667 L
.89399 .2479 L
.90088 .2595 L
.90088 .2595 L
.9036 .2595 L
.90632 .2595 L
.90903 .2595 L
.91175 .2595 L
.91447 .2595 L
.91719 .2595 L
.9199 .2595 L
.92262 .2595 L
.92534 .2595 L
.92805 .2595 L
.93077 .2595 L
.93349 .2595 L
.93349 .2595 L
.93178 .25705 L
.93006 .25462 L
.92833 .2522 L
.92659 .24981 L
.92485 .24742 L
.92309 .24506 L
.92132 .24271 L
.91955 .24037 L
.91777 .23805 L
.91597 .23575 L
.91417 .23346 L
.91236 .23119 L
.91236 .23119 L
.91056 .22894 L
.90876 .2267 L
.90694 .22447 L
.90512 .22226 L
.90329 .22006 L
.90145 .21788 L
.8996 .21571 L
.89774 .21356 L
.89588 .21142 L
.89401 .20929 L
Mistroke
.89212 .20718 L
.89024 .20509 L
.89024 .20509 L
.88836 .203 L
.88648 .20094 L
.88458 .19888 L
.88268 .19684 L
.88077 .19481 L
.87886 .1928 L
.87694 .1908 L
.875 .18881 L
.87307 .18683 L
.87112 .18487 L
.86917 .18292 L
.8672 .18099 L
.8672 .18099 L
.86526 .17907 L
.8633 .17716 L
.86133 .17526 L
.85936 .17338 L
.85738 .1715 L
.8554 .16965 L
.8534 .1678 L
.8514 .16597 L
.8494 .16414 L
.84738 .16234 L
.84536 .16054 L
.84333 .15875 L
.84333 .15875 L
.84131 .15698 L
.83929 .15522 L
.83726 .15348 L
.83522 .15174 L
.83317 .15002 L
.83112 .1483 L
.82906 .1466 L
.82699 .14492 L
.82492 .14324 L
.82284 .14158 L
.82075 .13992 L
.81866 .13828 L
.81866 .13828 L
.81658 .13665 L
.81449 .13504 L
.81239 .13343 L
.81029 .13184 L
.80818 .13025 L
.80607 .12868 L
.80394 .12712 L
.80181 .12557 L
Mistroke
.79968 .12404 L
.79753 .12251 L
.79539 .121 L
.79323 .1195 L
.79323 .1195 L
.79108 .11801 L
.78893 .11653 L
.78677 .11506 L
.78461 .1136 L
.78244 .11215 L
.78026 .11072 L
.77808 .1093 L
.77589 .10788 L
.77369 .10648 L
.77149 .10509 L
.76928 .10371 L
.76706 .10235 L
.76706 .10235 L
.76485 .10099 L
.76264 .09964 L
.76042 .09831 L
.7582 .09699 L
.75596 .09568 L
.75373 .09437 L
.75148 .09308 L
.74923 .09181 L
.74697 .09054 L
.74471 .08928 L
.74244 .08804 L
.74016 .0868 L
.74016 .0868 L
.7379 .08558 L
.73562 .08437 L
.73334 .08317 L
.73106 .08198 L
.72877 .0808 L
.72647 .07963 L
.72416 .07847 L
.72185 .07733 L
.71953 .07619 L
.71721 .07507 L
.71488 .07396 L
.71254 .07286 L
.71254 .07286 L
.71022 .07177 L
.70788 .07069 L
.70554 .06962 L
.7032 .06856 L
.70085 .06752 L
.69849 .06649 L
Mistroke
.69612 .06546 L
.69375 .06445 L
.69137 .06345 L
.68899 .06246 L
.6866 .06149 L
.6842 .06052 L
.6842 .06052 L
.68181 .05956 L
.67942 .05862 L
.67702 .05769 L
.67461 .05677 L
.6722 .05586 L
.66977 .05496 L
.66735 .05407 L
.66491 .0532 L
.66247 .05234 L
.66003 .05148 L
.65757 .05064 L
.65511 .04982 L
.65511 .04982 L
.65266 .049 L
.65021 .0482 L
.64774 .0474 L
.64527 .04662 L
.6428 .04585 L
.64031 .04509 L
.63782 .04435 L
.63533 .04361 L
.63282 .04289 L
.63031 .04218 L
.62779 .04149 L
.62527 .0408 L
.62527 .0408 L
.62275 .04013 L
.62023 .03947 L
.6177 .03882 L
.61517 .03818 L
.61263 .03756 L
.61008 .03695 L
.60752 .03635 L
.60495 .03576 L
.60238 .03519 L
.5998 .03463 L
.59722 .03408 L
.59462 .03355 L
.59462 .03355 L
.59204 .03302 L
.58945 .03251 L
.58686 .03202 L
.58425 .03154 L
Mistroke
.58164 .03107 L
.57902 .03061 L
.57639 .03017 L
.57376 .02974 L
.57112 .02932 L
.56846 .02892 L
.56581 .02853 L
.56314 .02816 L
.56314 .02816 L
.56049 .02779 L
.55782 .02745 L
.55515 .02711 L
.55247 .0268 L
.54979 .02649 L
.54709 .0262 L
.54439 .02593 L
.54168 .02567 L
.53896 .02542 L
.53623 .02519 L
.53349 .02497 L
.53075 .02477 L
.53075 .02477 L
.52801 .02459 L
.52527 .02442 L
.52252 .02426 L
.51976 .02412 L
.517 .024 L
.51422 .02389 L
.51143 .0238 L
.50864 .02373 L
.50583 .02367 L
.50302 .02363 L
.50019 .0236 L
.49736 .02359 L
.49736 .02359 L
.49707 .02359 L
.49677 .02359 L
.49648 .02359 L
.49618 .02359 L
.49589 .02359 L
.4956 .02359 L
.4953 .02359 L
.49501 .02359 L
.49471 .02359 L
.49442 .02359 L
.49413 .02359 L
.49383 .02359 L
.49383 .02359 L
.51614 .02412 L
.53787 .02567 L
Mistroke
.55905 .02816 L
.57972 .03154 L
.5999 .03576 L
.61962 .0408 L
.63888 .04662 L
.65771 .0532 L
.67612 .06052 L
.6941 .06856 L
.71168 .07733 L
.72884 .0868 L
.72884 .0868 L
.7326 .089 L
.73634 .09124 L
.74006 .09351 L
.74376 .09582 L
.74744 .09816 L
.75109 .10054 L
.75473 .10295 L
.75835 .1054 L
.76195 .10788 L
.76552 .1104 L
.76908 .11296 L
.77262 .11554 L
.77262 .11554 L
.77306 .11587 L
.7735 .1162 L
.77394 .11653 L
.77438 .11685 L
.77482 .11718 L
.77525 .11751 L
.77569 .11784 L
.77613 .11817 L
.77657 .1185 L
.77701 .11883 L
.77744 .11916 L
.77788 .1195 L
.77788 .1195 L
.77844 .11992 L
.779 .12035 L
.77956 .12078 L
.78012 .12121 L
.78068 .12165 L
.78124 .12208 L
.7818 .12251 L
.78236 .12295 L
.78291 .12338 L
.78347 .12382 L
.78403 .12426 L
.78458 .12469 L
.78458 .12469 L
Mistroke
.78532 .12528 L
.78606 .12587 L
.7868 .12646 L
.78754 .12705 L
.78827 .12764 L
.78901 .12824 L
.78974 .12883 L
.79048 .12943 L
.79121 .13003 L
.79194 .13063 L
.79267 .13123 L
.7934 .13184 L
.7934 .13184 L
.79442 .13268 L
.79544 .13354 L
.79645 .13439 L
.79746 .13525 L
.79848 .13611 L
.79949 .13698 L
.80049 .13785 L
.8015 .13872 L
.8025 .13959 L
.80351 .14047 L
.80451 .14135 L
.80551 .14224 L
Mfstroke
.90088 .2595 m
.90745 .2713 L
.91358 .28309 L
.91929 .29489 L
.92461 .30668 L
.92955 .31848 L
.93413 .33027 L
.93834 .34207 L
.9422 .35386 L
.94573 .36566 L
.94893 .37745 L
.9518 .38925 L
.95436 .40105 L
.95436 .40105 L
.95462 .40236 L
.95488 .40367 L
.95514 .40498 L
.95539 .40629 L
.95564 .4076 L
.95589 .40891 L
.95613 .41022 L
.95637 .41153 L
.9566 .41284 L
.95683 .41415 L
.95706 .41546 L
.95728 .41677 L
.95728 .41677 L
.95744 .41771 L
.95759 .41865 L
.95774 .41958 L
.9579 .42052 L
.95804 .42145 L
.95819 .42239 L
.95834 .42333 L
.95848 .42426 L
.95862 .4252 L
.95876 .42613 L
.9589 .42707 L
.95903 .42801 L
.95903 .42801 L
.95913 .42871 L
.95923 .42941 L
.95933 .43011 L
.95943 .43081 L
.95953 .43152 L
.95962 .43222 L
.95971 .43292 L
.95981 .43362 L
.9599 .43433 L
.95999 .43503 L
Mistroke
.96008 .43573 L
.96017 .43643 L
.96017 .43643 L
.96024 .43698 L
.9603 .43752 L
.96037 .43807 L
.96044 .43862 L
.9605 .43916 L
.96057 .43971 L
.96063 .44025 L
.9607 .4408 L
.96076 .44135 L
.96082 .44189 L
.96088 .44244 L
.96094 .44298 L
.96094 .44298 L
.96141 .44735 L
.96184 .45172 L
.96222 .45609 L
.96256 .46046 L
.96287 .46483 L
.96313 .4692 L
.96335 .47357 L
.96353 .47793 L
.96367 .4823 L
.96377 .48667 L
.96383 .49104 L
.96385 .49541 L
.96385 .49541 L
.96345 .51507 L
.96222 .53473 L
.96017 .55439 L
.95728 .57405 L
.95354 .5937 L
.94893 .61336 L
.94342 .63302 L
.93697 .65268 L
.92955 .67234 L
.92111 .692 L
.91158 .71166 L
.90088 .73132 L
.90088 .73132 L
.90118 .73132 L
.90147 .73132 L
.90177 .73132 L
.90206 .73132 L
.90235 .73132 L
.90265 .73132 L
.90294 .73132 L
.90324 .73132 L
Mistroke
.90353 .73132 L
.90382 .73132 L
.90412 .73132 L
.90441 .73132 L
.90441 .73132 L
.90583 .72886 L
.90722 .7264 L
.9086 .72395 L
.90996 .72149 L
.9113 .71903 L
.91262 .71657 L
.91392 .71412 L
.9152 .71166 L
.91647 .7092 L
.91772 .70674 L
.91895 .70429 L
.92016 .70183 L
.92016 .70183 L
.92138 .69937 L
.92257 .69691 L
.92376 .69446 L
.92492 .692 L
.92607 .68954 L
.9272 .68709 L
.92832 .68463 L
.92942 .68217 L
.9305 .67971 L
.93156 .67726 L
.93261 .6748 L
.93364 .67234 L
.93364 .67234 L
.93468 .66988 L
.9357 .66743 L
.93671 .66497 L
.9377 .66251 L
.93868 .66005 L
.93963 .6576 L
.94058 .65514 L
.94151 .65268 L
.94242 .65022 L
.94332 .64777 L
.9442 .64531 L
.94507 .64285 L
.94507 .64285 L
.94594 .64039 L
.9468 .63794 L
.94764 .63548 L
.94847 .63302 L
.94928 .63057 L
.95008 .62811 L
Mistroke
.95087 .62565 L
.95164 .62319 L
.95239 .62074 L
.95314 .61828 L
.95386 .61582 L
.95458 .61336 L
.95458 .61336 L
.9553 .61091 L
.956 .60845 L
.95669 .60599 L
.95737 .60353 L
.95803 .60108 L
.95868 .59862 L
.95931 .59616 L
.95993 .5937 L
.96054 .59125 L
.96113 .58879 L
.96171 .58633 L
.96228 .58387 L
.96228 .58387 L
.96285 .58142 L
.96341 .57896 L
.96395 .5765 L
.96448 .57405 L
.965 .57159 L
.9655 .56913 L
.96599 .56667 L
.96647 .56422 L
.96693 .56176 L
.96738 .5593 L
.96782 .55684 L
.96825 .55439 L
.96825 .55439 L
.96868 .55193 L
.96909 .54947 L
.96949 .54701 L
.96988 .54456 L
.97026 .5421 L
.97062 .53964 L
.97097 .53718 L
.97131 .53473 L
.97164 .53227 L
.97195 .52981 L
.97225 .52736 L
.97254 .5249 L
.97254 .5249 L
.97283 .52244 L
.9731 .51998 L
.97337 .51753 L
.97362 .51507 L
Mistroke
.97386 .51261 L
.97408 .51015 L
.9743 .5077 L
.9745 .50524 L
.97469 .50278 L
.97486 .50032 L
.97502 .49787 L
.97517 .49541 L
.97517 .49541 L
.97533 .49295 L
.97547 .49049 L
.9756 .48804 L
.97571 .48558 L
.97581 .48312 L
.9759 .48066 L
.97598 .47821 L
.97604 .47575 L
.97609 .47329 L
.97613 .47084 L
.97616 .46838 L
.97617 .46592 L
.97617 .46592 L
.97619 .46346 L
.97619 .46101 L
.97618 .45855 L
.97616 .45609 L
.97612 .45363 L
.97608 .45118 L
.97602 .44872 L
.97594 .44626 L
.97585 .4438 L
.97576 .44135 L
.97564 .43889 L
.97552 .43643 L
.97552 .43643 L
.97539 .43397 L
.97526 .43152 L
.97511 .42906 L
.97495 .4266 L
.97478 .42414 L
.97459 .42169 L
.97439 .41923 L
.97417 .41677 L
.97395 .41432 L
.9737 .41186 L
.97345 .4094 L
.97318 .40694 L
.97318 .40694 L
.97292 .40449 L
.97264 .40203 L
Mistroke
.97235 .39957 L
.97205 .39711 L
.97173 .39466 L
.9714 .3922 L
.97105 .38974 L
.97069 .38728 L
.97032 .38483 L
.96993 .38237 L
.96953 .37991 L
.96912 .37745 L
.96912 .37745 L
.96871 .375 L
.96828 .37254 L
.96784 .37008 L
.96739 .36763 L
.96692 .36517 L
.96644 .36271 L
.96594 .36025 L
.96543 .3578 L
.96491 .35534 L
.96437 .35288 L
.96381 .35042 L
.96324 .34797 L
.96324 .34797 L
.96268 .34551 L
.9621 .34305 L
.9615 .34059 L
.96089 .33814 L
.96027 .33568 L
.95963 .33322 L
.95897 .33076 L
.9583 .32831 L
.95761 .32585 L
.95691 .32339 L
.95619 .32093 L
.95545 .31848 L
.95545 .31848 L
.95472 .31602 L
.95398 .31356 L
.95321 .31111 L
.95244 .30865 L
.95164 .30619 L
.95083 .30373 L
.95 .30128 L
.94915 .29882 L
.94829 .29636 L
.94741 .2939 L
.94652 .29145 L
.9456 .28899 L
.9456 .28899 L
Mistroke
.94469 .28653 L
.94377 .28407 L
.94282 .28162 L
.94186 .27916 L
.94088 .2767 L
.93988 .27424 L
.93886 .27179 L
.93782 .26933 L
.93677 .26687 L
.93569 .26441 L
.9346 .26196 L
.93349 .2595 L
.93349 .2595 L
.93077 .2595 L
.92805 .2595 L
.92534 .2595 L
.92262 .2595 L
.9199 .2595 L
.91719 .2595 L
.91447 .2595 L
.91175 .2595 L
.90903 .2595 L
.90632 .2595 L
.9036 .2595 L
.90088 .2595 L
Mfstroke
.039 .916 .04 r
.8241 .49541 m
.8241 .49541 L
s
0 0 0 r
2 Mabswid
.8241 .49541 Mdot
.039 .916 .04 r
.5 Mabswid
.69975 .75363 m
.69975 .75363 L
s
0 0 0 r
2 Mabswid
.69975 .75363 Mdot
.039 .916 .04 r
.5 Mabswid
.42034 .8174 m
.42034 .8174 L
s
0 0 0 r
2 Mabswid
.42034 .8174 Mdot
.039 .916 .04 r
.5 Mabswid
.19627 .63871 m
.19627 .63871 L
s
0 0 0 r
2 Mabswid
.19627 .63871 Mdot
.039 .916 .04 r
.5 Mabswid
.19627 .35211 m
.19627 .35211 L
s
0 0 0 r
2 Mabswid
.19627 .35211 Mdot
.039 .916 .04 r
.5 Mabswid
.42034 .17342 m
.42034 .17342 L
s
0 0 0 r
2 Mabswid
.42034 .17342 Mdot
.039 .916 .04 r
.5 Mabswid
.69975 .23719 m
.69975 .23719 L
s
0 0 0 r
2 Mabswid
.69975 .23719 Mdot
.039 .916 .04 r
.5 Mabswid
.8241 .49541 m
.83381 .49541 L
s
0 0 0 r
2 Mabswid
.83381 .49541 Mdot
.039 .916 .04 r
.5 Mabswid
.69975 .75363 m
.70851 .75363 L
s
0 0 0 r
2 Mabswid
.70851 .75363 Mdot
.039 .916 .04 r
.5 Mabswid
.42034 .8174 m
.43123 .8174 L
s
0 0 0 r
2 Mabswid
.43123 .8174 Mdot
.039 .916 .04 r
.5 Mabswid
.19627 .63871 m
.20299 .63871 L
s
0 0 0 r
2 Mabswid
.20299 .63871 Mdot
.039 .916 .04 r
.5 Mabswid
.19627 .35211 m
.20866 .35211 L
s
0 0 0 r
2 Mabswid
.20866 .35211 Mdot
.039 .916 .04 r
.5 Mabswid
.42034 .17342 m
.42789 .17342 L
s
0 0 0 r
2 Mabswid
.42789 .17342 Mdot
.039 .916 .04 r
.5 Mabswid
.69975 .23719 m
.71 .23719 L
s
0 0 0 r
2 Mabswid
.71 .23719 Mdot
.039 .916 .04 r
.5 Mabswid
.83381 .49541 m
.53482 .32747 L
s
0 0 0 r
2 Mabswid
.53482 .32747 Mdot
.039 .916 .04 r
.5 Mabswid
.70851 .75363 m
.36943 .56318 L
s
0 0 0 r
2 Mabswid
.36943 .56318 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .8174 m
.6404 .69151 L
s
0 0 0 r
2 Mabswid
.6404 .69151 Mdot
.039 .916 .04 r
.5 Mabswid
.20299 .63871 m
.77779 .29276 L
s
0 0 0 r
2 Mabswid
.77779 .29276 Mdot
.039 .916 .04 r
.5 Mabswid
.20866 .35211 m
.28493 .3062 L
s
0 0 0 r
2 Mabswid
.28493 .3062 Mdot
.039 .916 .04 r
.5 Mabswid
.42789 .17342 m
.41275 .67984 L
s
0 0 0 r
2 Mabswid
.41275 .67984 Mdot
.039 .916 .04 r
.5 Mabswid
.71 .23719 m
.70034 .56041 L
s
0 0 0 r
2 Mabswid
.70034 .56041 Mdot
.039 .916 .04 r
.5 Mabswid
.53482 .32747 m
.25579 .49541 L
s
0 0 0 r
2 Mabswid
.25579 .49541 Mdot
.039 .916 .04 r
.5 Mabswid
.36943 .56318 m
.37917 .23719 L
s
0 0 0 r
2 Mabswid
.37917 .23719 Mdot
.039 .916 .04 r
.5 Mabswid
.6404 .69151 m
.65589 .17342 L
s
0 0 0 r
2 Mabswid
.65589 .17342 Mdot
.039 .916 .04 r
.5 Mabswid
.77779 .29276 m
.88347 .35211 L
s
0 0 0 r
2 Mabswid
.88347 .35211 Mdot
.039 .916 .04 r
.5 Mabswid
.28493 .3062 m
.87695 .63871 L
s
0 0 0 r
2 Mabswid
.87695 .63871 Mdot
.039 .916 .04 r
.5 Mabswid
.41275 .67984 m
.65768 .8174 L
s
0 0 0 r
2 Mabswid
.65768 .8174 Mdot
.039 .916 .04 r
.5 Mabswid
.70034 .56041 m
.37931 .75363 L
s
0 0 0 r
2 Mabswid
.37931 .75363 Mdot
.039 .916 .04 r
.5 Mabswid
.25579 .49541 m
.24457 .49541 L
s
0 0 0 r
2 Mabswid
.24457 .49541 Mdot
.039 .916 .04 r
.5 Mabswid
.37917 .23719 m
.36892 .23719 L
s
0 0 0 r
2 Mabswid
.36892 .23719 Mdot
.039 .916 .04 r
.5 Mabswid
.65589 .17342 m
.64834 .17342 L
s
0 0 0 r
2 Mabswid
.64834 .17342 Mdot
.039 .916 .04 r
.5 Mabswid
.88347 .35211 m
.87241 .35211 L
s
0 0 0 r
2 Mabswid
.87241 .35211 Mdot
.039 .916 .04 r
.5 Mabswid
.87695 .63871 m
.87241 .63871 L
s
0 0 0 r
2 Mabswid
.87241 .63871 Mdot
.039 .916 .04 r
.5 Mabswid
.65768 .8174 m
.64834 .8174 L
s
0 0 0 r
2 Mabswid
.64834 .8174 Mdot
.039 .916 .04 r
.5 Mabswid
.37931 .75363 m
.36892 .75363 L
s
0 0 0 r
2 Mabswid
.36892 .75363 Mdot
.039 .916 .04 r
.5 Mabswid
.24457 .49541 m
.24457 .49541 L
s
0 0 0 r
2 Mabswid
.24457 .49541 Mdot
.039 .916 .04 r
.5 Mabswid
.36892 .23719 m
.36892 .23719 L
s
0 0 0 r
2 Mabswid
.36892 .23719 Mdot
.039 .916 .04 r
.5 Mabswid
.64834 .17342 m
.64834 .17342 L
s
0 0 0 r
2 Mabswid
.64834 .17342 Mdot
.039 .916 .04 r
.5 Mabswid
.87241 .35211 m
.87241 .35211 L
s
0 0 0 r
2 Mabswid
.87241 .35211 Mdot
.039 .916 .04 r
.5 Mabswid
.87241 .63871 m
.87241 .63871 L
s
0 0 0 r
2 Mabswid
.87241 .63871 Mdot
.039 .916 .04 r
.5 Mabswid
.64834 .8174 m
.64834 .8174 L
s
0 0 0 r
2 Mabswid
.64834 .8174 Mdot
.039 .916 .04 r
.5 Mabswid
.36892 .75363 m
.36892 .75363 L
s
0 0 0 r
2 Mabswid
.36892 .75363 Mdot
0 0 m
1 0 L
1 .99082 L
0 .99082 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{165.938, 164.375},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 164.938}, {163.375, 0}} -> {-26.1746, -26.2503, \
0.321351, 0.321351}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86255 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0 1.00397 -0.0416748 1.00397 [
[ 0 0 0 0 ]
[ 1 .86255 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86255 L
0 .86255 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.26829 .59265 Mdot
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.61617 .48453 m
.26829 .59265 L
s
0 0 0 r
2 Mabswid
.22043 .48158 Mdot
.039 .916 .04 r
.5 Mabswid
.57654 .36355 m
.22043 .48158 L
s
.23092 .51523 m
.58589 .39973 L
s
.25395 .63445 m
.60957 .52609 L
s
0 0 0 r
2 Mabswid
.26206 .69749 Mdot
.039 .916 .04 r
.5 Mabswid
.61939 .59243 m
.26206 .69749 L
s
.16528 .42982 m
.53601 .30264 L
s
0 g
.61326 .42946 m
.61463 .43499 L
s
.61186 .424 m
.61326 .42946 L
s
.61043 .41861 m
.61186 .424 L
s
.61368 .43115 m
.61985 .45786 L
s
.60652 .40464 m
.61368 .43115 L
s
.61463 .43499 m
.61598 .44059 L
s
.60897 .41328 m
.61043 .41861 L
s
.61598 .44059 m
.6173 .44626 L
s
.60749 .40802 m
.60897 .41328 L
s
.6173 .44626 m
.61859 .45202 L
s
.60599 .40281 m
.60749 .40802 L
s
.59846 .37868 m
.60652 .40464 L
s
.60446 .39766 m
.60599 .40281 L
s
.61859 .45202 m
.61985 .45786 L
s
.6029 .39256 m
.60446 .39766 L
s
.63281 .45458 m
.61985 .45786 L
s
.61985 .45786 m
.62106 .46369 L
s
.61985 .45786 m
.61985 .45786 L
s
.61985 .45786 m
.62494 .4844 L
s
.60273 .392 m
.6029 .39256 L
s
.60256 .39144 m
.60273 .392 L
s
.60238 .39087 m
.60256 .39144 L
s
.62106 .46369 m
.6222 .46942 L
s
.60221 .39031 m
.60238 .39087 L
s
.60203 .38975 m
.60221 .39031 L
s
.60185 .38919 m
.60203 .38975 L
s
.60168 .38863 m
.60185 .38919 L
s
.6015 .38808 m
.60168 .38863 L
s
.60133 .38752 m
.6015 .38808 L
s
.60115 .38696 m
.60133 .38752 L
s
.60097 .3864 m
.60115 .38696 L
s
.60079 .38585 m
.60097 .3864 L
s
.60079 .38585 m
.60079 .38585 L
s
.60067 .38545 m
.60079 .38585 L
s
.6222 .46942 m
.62327 .47506 L
s
.60054 .38506 m
.60067 .38545 L
s
.60041 .38466 m
.60054 .38506 L
s
.60029 .38426 m
.60041 .38466 L
s
.60016 .38387 m
.60029 .38426 L
s
.60003 .38347 m
.60016 .38387 L
s
.5999 .38308 m
.60003 .38347 L
s
.59977 .38269 m
.5999 .38308 L
s
.59965 .38229 m
.59977 .38269 L
s
.59952 .3819 m
.59965 .38229 L
s
.59939 .3815 m
.59952 .3819 L
s
.59926 .38111 m
.59939 .3815 L
s
.59926 .38111 m
.59926 .38111 L
s
.59916 .38082 m
.59926 .38111 L
s
.59907 .38052 m
.59916 .38082 L
s
.59897 .38023 m
.59907 .38052 L
s
.59887 .37993 m
.59897 .38023 L
s
.62327 .47506 m
.62428 .4806 L
s
.59878 .37964 m
.59887 .37993 L
s
.59868 .37935 m
.59878 .37964 L
s
.59858 .37905 m
.59868 .37935 L
s
.59849 .37876 m
.59858 .37905 L
s
.59839 .37847 m
.59849 .37876 L
s
.5896 .35362 m
.59846 .37868 L
s
.59829 .37817 m
.59839 .37847 L
s
.59819 .37788 m
.59829 .37817 L
s
.5981 .37759 m
.59819 .37788 L
s
.5981 .37759 m
.5981 .37759 L
s
.59802 .37736 m
.5981 .37759 L
s
.59794 .37713 m
.59802 .37736 L
s
.59787 .37691 m
.59794 .37713 L
s
.59779 .37668 m
.59787 .37691 L
s
.59772 .37645 m
.59779 .37668 L
s
.59764 .37623 m
.59772 .37645 L
s
.59756 .376 m
.59764 .37623 L
s
.59749 .37577 m
.59756 .376 L
s
.59741 .37554 m
.59749 .37577 L
s
.59734 .37532 m
.59741 .37554 L
s
.59726 .37509 m
.59734 .37532 L
s
.6458 .4513 m
.63281 .45458 L
s
.59718 .37487 m
.59726 .37509 L
s
.59718 .37487 m
.59718 .37487 L
s
.59657 .37306 m
.59718 .37487 L
s
.62428 .4806 m
.62522 .48606 L
s
.59595 .37126 m
.59657 .37306 L
s
.59533 .36947 m
.59595 .37126 L
s
.62494 .4844 m
.62886 .5104 L
s
.62522 .48606 m
.62611 .49144 L
s
.59471 .36768 m
.59533 .36947 L
s
.59408 .3659 m
.59471 .36768 L
s
0 0 0 r
2 Mabswid
.15034 .4405 Mdot
.039 .916 .04 r
.5 Mabswid
.5267 .31173 m
.15034 .4405 L
s
0 g
.59345 .36413 m
.59408 .3659 L
s
.62611 .49144 m
.62694 .49674 L
s
.59282 .36236 m
.59345 .36413 L
s
.59218 .3606 m
.59282 .36236 L
s
.59154 .35884 m
.59218 .3606 L
s
.65884 .448 m
.6458 .4513 L
s
.62694 .49674 m
.62771 .50196 L
s
.5909 .3571 m
.59154 .35884 L
s
.59025 .35535 m
.5909 .3571 L
s
.5896 .35362 m
.59025 .35535 L
s
.62771 .50196 m
.62843 .50711 L
s
.5896 .35362 m
.5896 .35362 L
s
.58663 .34589 m
.5896 .35362 L
s
.58006 .32982 m
.5896 .35362 L
s
.62843 .50711 m
.62909 .51219 L
s
.67192 .44469 m
.65884 .448 L
s
.62886 .5104 m
.63157 .53552 L
s
.58359 .33828 m
.58663 .34589 L
s
.62909 .51219 m
.62971 .5172 L
s
.62971 .5172 m
.63027 .52214 L
s
.67192 .44469 m
.68504 .44137 L
s
.58048 .3308 m
.58359 .33828 L
s
.63027 .52214 m
.63033 .52268 L
s
.63027 .52214 m
.63027 .52214 L
s
.63033 .52268 m
.63039 .52322 L
s
.63039 .52322 m
.63045 .52377 L
s
.63045 .52377 m
.6305 .52431 L
s
.6305 .52431 m
.63056 .52485 L
s
.63056 .52485 m
.63062 .52539 L
s
.63062 .52539 m
.63067 .52593 L
s
.63067 .52593 m
.63073 .52647 L
s
.63073 .52647 m
.63078 .52701 L
s
.63078 .52701 m
.63083 .52755 L
s
.57729 .32344 m
.58048 .3308 L
s
.63083 .52755 m
.63089 .52808 L
s
.6982 .43804 m
.68504 .44137 L
s
.63089 .52808 m
.63094 .52862 L
s
.56996 .30762 m
.58006 .32982 L
s
.63094 .52862 m
.63098 .529 L
s
.63094 .52862 m
.63094 .52862 L
s
.63098 .529 m
.63101 .52939 L
s
.63101 .52939 m
.63105 .52977 L
s
.63105 .52977 m
.63109 .53015 L
s
.63109 .53015 m
.63112 .53053 L
s
.63112 .53053 m
.63116 .53091 L
s
.63116 .53091 m
.63119 .53129 L
s
.63119 .53129 m
.63123 .53167 L
s
.63123 .53167 m
.63126 .53205 L
s
.63126 .53205 m
.6313 .53243 L
s
.6313 .53243 m
.63133 .53281 L
s
.63133 .53281 m
.63137 .53318 L
s
.63137 .53318 m
.63139 .53347 L
s
.63137 .53318 m
.63137 .53318 L
s
.63139 .53347 m
.63142 .53375 L
s
.63142 .53375 m
.63144 .53403 L
s
.63144 .53403 m
.63147 .53431 L
s
.63147 .53431 m
.63149 .5346 L
s
.63149 .5346 m
.63151 .53488 L
s
.63151 .53488 m
.63154 .53516 L
s
.57402 .31621 m
.57729 .32344 L
s
.63154 .53516 m
.63156 .53544 L
s
.63156 .53544 m
.63159 .53572 L
s
.63157 .53552 m
.633 .55939 L
s
.63159 .53572 m
.63161 .53601 L
s
.63161 .53601 m
.63163 .53629 L
s
.71141 .43471 m
.6982 .43804 L
s
.63163 .53629 m
.63166 .53657 L
s
.63166 .53657 m
.63167 .53679 L
s
.63166 .53657 m
.63166 .53657 L
s
.63167 .53679 m
.63169 .537 L
s
.63169 .537 m
.63171 .53722 L
s
.63171 .53722 m
.63173 .53744 L
s
.63173 .53744 m
.63175 .53766 L
s
.63175 .53766 m
.63176 .53788 L
s
.63176 .53788 m
.63178 .53809 L
s
.63178 .53809 m
.6318 .53831 L
s
.6318 .53831 m
.63181 .53853 L
s
.63181 .53853 m
.63183 .53874 L
s
.63183 .53874 m
.63185 .53896 L
s
.63185 .53896 m
.63187 .53918 L
s
.63187 .53918 m
.632 .54091 L
s
.63187 .53918 m
.63187 .53918 L
s
.66034 .35064 m
.674 .35966 L
s
.64698 .34138 m
.66034 .35064 L
s
.66457 .35337 m
.66337 .35257 L
s
.66576 .35416 m
.66457 .35337 L
s
.66337 .35257 m
.66217 .35178 L
s
.66696 .35496 m
.66576 .35416 L
s
.66217 .35178 m
.66098 .35099 L
s
.66815 .35577 m
.66696 .35496 L
s
.66098 .35099 m
.65978 .3502 L
s
.66934 .35657 m
.66815 .35577 L
s
.65978 .3502 m
.65858 .34941 L
s
.67053 .35738 m
.66934 .35657 L
s
.65858 .34941 m
.65738 .34863 L
s
.67173 .35819 m
.67053 .35738 L
s
.65738 .34863 m
.65626 .34783 L
s
.65738 .34863 m
.65738 .34863 L
s
.67173 .35819 m
.67173 .35819 L
s
.673 .35898 m
.67173 .35819 L
s
.65626 .34783 m
.65514 .34703 L
s
.67427 .35977 m
.673 .35898 L
s
.674 .35966 m
.68797 .36847 L
s
.65514 .34703 m
.65401 .34623 L
s
.67554 .36056 m
.67427 .35977 L
s
.65401 .34623 m
.65289 .34543 L
s
.67681 .36136 m
.67554 .36056 L
s
.65289 .34543 m
.65176 .34464 L
s
.67807 .36216 m
.67681 .36136 L
s
.65176 .34464 m
.65064 .34385 L
s
.67934 .36296 m
.67807 .36216 L
s
.65064 .34385 m
.64951 .34306 L
s
.632 .54091 m
.63212 .54263 L
s
.68061 .36377 m
.67934 .36296 L
s
.64951 .34306 m
.64838 .34227 L
s
.68187 .36457 m
.68061 .36377 L
s
.64838 .34227 m
.64725 .34149 L
s
.68314 .36538 m
.68187 .36457 L
s
.63396 .33185 m
.64698 .34138 L
s
.64725 .34149 m
.64612 .3407 L
s
.6844 .36619 m
.68314 .36538 L
s
.64612 .3407 m
.64499 .33992 L
s
.68567 .36701 m
.6844 .36619 L
s
.64499 .33992 m
.64386 .33914 L
s
.68693 .36783 m
.68567 .36701 L
s
.64386 .33914 m
.64281 .33835 L
s
.64386 .33914 m
.64386 .33914 L
s
.68693 .36783 m
.68693 .36783 L
s
.68828 .36862 m
.68693 .36783 L
s
.64281 .33835 m
.64175 .33755 L
s
.68797 .36847 m
.70224 .37709 L
s
.68962 .36942 m
.68828 .36862 L
s
.64175 .33755 m
.6407 .33676 L
s
.69097 .37023 m
.68962 .36942 L
s
.63212 .54263 m
.63224 .54434 L
s
.6407 .33676 m
.63964 .33597 L
s
.69231 .37103 m
.69097 .37023 L
s
.63964 .33597 m
.63858 .33518 L
s
.57068 .3091 m
.57402 .31621 L
s
.69366 .37184 m
.69231 .37103 L
s
.63858 .33518 m
.63752 .33439 L
s
.695 .37265 m
.69366 .37184 L
s
.63752 .33439 m
.63646 .33361 L
s
.69634 .37346 m
.695 .37265 L
s
.63646 .33361 m
.6354 .33282 L
s
.72466 .43135 m
.71141 .43471 L
s
.69768 .37427 m
.69634 .37346 L
s
.6354 .33282 m
.63434 .33204 L
s
.63224 .54434 m
.63235 .54605 L
s
.69902 .37509 m
.69768 .37427 L
s
.63434 .33204 m
.63328 .33127 L
s
.62129 .322 m
.63396 .33185 L
s
.70036 .37591 m
.69902 .37509 L
s
.63328 .33127 m
.63221 .33049 L
s
.7017 .37674 m
.70036 .37591 L
s
.63221 .33049 m
.63115 .32972 L
s
.70304 .37756 m
.7017 .37674 L
s
.63115 .32972 m
.63016 .32892 L
s
.63115 .32972 m
.63115 .32972 L
s
.70224 .37709 m
.7168 .38553 L
s
.70304 .37756 m
.70304 .37756 L
s
.70447 .37837 m
.70304 .37756 L
s
.63016 .32892 m
.62917 .32813 L
s
.63235 .54605 m
.63245 .54774 L
s
.70589 .37918 m
.70447 .37837 L
s
.62917 .32813 m
.62818 .32734 L
s
.70732 .37999 m
.70589 .37918 L
s
.62818 .32734 m
.62719 .32656 L
s
.62719 .32656 m
.6262 .32577 L
s
.70874 .3808 m
.70732 .37999 L
s
.6262 .32577 m
.62521 .32499 L
s
.71017 .38162 m
.70874 .3808 L
s
.63245 .54774 m
.63255 .54943 L
s
.62521 .32499 m
.62422 .32421 L
s
.71159 .38244 m
.71017 .38162 L
s
0 0 0 r
2 Mabswid
.61617 .48453 Mdot
.039 .916 .04 r
.5 Mabswid
.77118 .43968 m
.61617 .48453 L
s
0 g
.62422 .32421 m
.62322 .32343 L
s
.71301 .38326 m
.71159 .38244 L
s
.62322 .32343 m
.62223 .32265 L
s
.71443 .38408 m
.71301 .38326 L
s
.62223 .32265 m
.62123 .32188 L
s
.71586 .38491 m
.71443 .38408 L
s
.60902 .31177 m
.62129 .322 L
s
.63255 .54943 m
.63264 .55111 L
s
.62123 .32188 m
.62023 .32111 L
s
.71728 .38574 m
.71586 .38491 L
s
.7168 .38553 m
.73166 .39382 L
s
.62023 .32111 m
.61924 .32034 L
s
.7187 .38657 m
.71728 .38574 L
s
.61924 .32034 m
.61832 .31955 L
s
.61924 .32034 m
.61924 .32034 L
s
.72012 .38741 m
.7187 .38657 L
s
.56725 .30213 m
.57068 .3091 L
s
.61832 .31955 m
.6174 .31876 L
s
.73795 .42799 m
.72466 .43135 L
s
.72012 .38741 m
.72012 .38741 L
s
.72163 .38823 m
.72012 .38741 L
s
.63264 .55111 m
.63273 .55278 L
s
.6174 .31876 m
.61647 .31797 L
s
.72314 .38904 m
.72163 .38823 L
s
.61647 .31797 m
.61555 .31719 L
s
.72465 .38987 m
.72314 .38904 L
s
.61555 .31719 m
.61463 .31641 L
s
.55944 .28735 m
.56996 .30762 L
s
.72616 .39069 m
.72465 .38987 L
s
.63273 .55278 m
.6328 .55445 L
s
.61463 .31641 m
.6137 .31563 L
s
.72768 .39152 m
.72616 .39069 L
s
.6137 .31563 m
.61278 .31485 L
s
.72919 .39235 m
.72768 .39152 L
s
.61278 .31485 m
.61185 .31408 L
s
.7307 .39318 m
.72919 .39235 L
s
.6328 .55445 m
.63288 .5561 L
s
.61185 .31408 m
.61092 .31331 L
s
.73221 .39402 m
.7307 .39318 L
s
.039 .916 .04 r
.2175 .70616 m
.5903 .59628 L
s
0 g
.61092 .31331 m
.60999 .31253 L
s
.73166 .39382 m
.74682 .40196 L
s
.73371 .39485 m
.73221 .39402 L
s
.60999 .31253 m
.60906 .31177 L
s
.63288 .5561 m
.63294 .55775 L
s
.73522 .3957 m
.73371 .39485 L
s
.59719 .30108 m
.60902 .31177 L
s
.60906 .31177 m
.60813 .311 L
s
.73673 .39654 m
.73522 .3957 L
s
.60813 .311 m
.60728 .31021 L
s
.60813 .311 m
.60813 .311 L
s
.73824 .39739 m
.73673 .39654 L
s
.60728 .31021 m
.60643 .30943 L
s
.75129 .42462 m
.73795 .42799 L
s
.63294 .55775 m
.633 .55939 L
s
.73824 .39739 m
.73824 .39739 L
s
.73985 .39822 m
.73824 .39739 L
s
.60643 .30943 m
.60557 .30864 L
s
.56373 .29528 m
.56725 .30213 L
s
.74146 .39905 m
.73985 .39822 L
s
.60557 .30864 m
.60472 .30786 L
s
.60472 .30786 m
.60386 .30708 L
s
.74306 .39988 m
.74146 .39905 L
s
.633 .55939 m
.63318 .56667 L
s
.633 .55939 m
.633 .55939 L
s
.633 .55939 m
.63311 .58164 L
s
.633 .55939 m
.61997 .54086 L
s
.633 .55939 m
.633 .55939 L
s
.60386 .30708 m
.60301 .30631 L
s
.74467 .40072 m
.74306 .39988 L
s
.60301 .30631 m
.60215 .30553 L
s
.74628 .40156 m
.74467 .40072 L
s
.60215 .30553 m
.60129 .30476 L
s
.74788 .4024 m
.74628 .40156 L
s
.74682 .40196 m
.76229 .40997 L
s
.60129 .30476 m
.60043 .30399 L
s
.74949 .40324 m
.74788 .4024 L
s
.60043 .30399 m
.59957 .30322 L
s
.7511 .40409 m
.74949 .40324 L
s
.59957 .30322 m
.5987 .30245 L
s
.7527 .40495 m
.7511 .40409 L
s
.5987 .30245 m
.59784 .30169 L
s
.75129 .42462 m
.76467 .42124 L
s
.75431 .4058 m
.7527 .40495 L
s
.59784 .30169 m
.59706 .3009 L
s
.59784 .30169 m
.59784 .30169 L
s
.75591 .40666 m
.75431 .4058 L
s
.58592 .28981 m
.59719 .30108 L
s
.59706 .3009 m
.59628 .30012 L
s
.75752 .40753 m
.75591 .40666 L
s
.59628 .30012 m
.5955 .29934 L
s
.75752 .40753 m
.75752 .40753 L
s
.75923 .40837 m
.75752 .40753 L
s
.56011 .28857 m
.56373 .29528 L
s
.5955 .29934 m
.59471 .29856 L
s
.63318 .56667 m
.63323 .57378 L
s
.76095 .40921 m
.75923 .40837 L
s
.59471 .29856 m
.59393 .29778 L
s
.76266 .41005 m
.76095 .40921 L
s
.59393 .29778 m
.59314 .29701 L
s
.76229 .40997 m
.77809 .41784 L
s
.73624 .475 m
.72645 .48889 L
s
.74629 .46096 m
.73624 .475 L
s
.73848 .47185 m
.73951 .47045 L
s
.73848 .47185 m
.73848 .47185 L
s
.73753 .47323 m
.73848 .47185 L
s
.73658 .4746 m
.73753 .47323 L
s
.73564 .47597 m
.73658 .4746 L
s
.76438 .4109 m
.76266 .41005 L
s
.73951 .47045 m
.74055 .46904 L
s
.73468 .47733 m
.73564 .47597 L
s
.59314 .29701 m
.59236 .29623 L
s
.74055 .46904 m
.74158 .46764 L
s
.73373 .47869 m
.73468 .47733 L
s
.73277 .48005 m
.73373 .47869 L
s
.74158 .46764 m
.74261 .46622 L
s
.73182 .4814 m
.73277 .48005 L
s
.74261 .46622 m
.74364 .46481 L
s
.73086 .48275 m
.73182 .4814 L
s
.74364 .46481 m
.74466 .46338 L
s
.72989 .4841 m
.73086 .48275 L
s
.74466 .46338 m
.74568 .46196 L
s
.72893 .48544 m
.72989 .4841 L
s
.74568 .46196 m
.74671 .46053 L
s
.75662 .44676 m
.74629 .46096 L
s
.72796 .48678 m
.72893 .48544 L
s
.72699 .48812 m
.72796 .48678 L
s
.74671 .46053 m
.74772 .4591 L
s
.72699 .48812 m
.72699 .48812 L
s
.72611 .48943 m
.72699 .48812 L
s
.74772 .4591 m
.74874 .45766 L
s
.72645 .48889 m
.71694 .50263 L
s
.74874 .45766 m
.74975 .45622 L
s
.72522 .49074 m
.72611 .48943 L
s
.59236 .29623 m
.59157 .29546 L
s
.74975 .45622 m
.75076 .45478 L
s
.72434 .49204 m
.72522 .49074 L
s
.76609 .41176 m
.76438 .4109 L
s
.75076 .45478 m
.75188 .4533 L
s
.75076 .45478 m
.75076 .45478 L
s
.72345 .49334 m
.72434 .49204 L
s
.75188 .4533 m
.75298 .45183 L
s
.72256 .49464 m
.72345 .49334 L
s
.75298 .45183 m
.75409 .45034 L
s
.72166 .49594 m
.72256 .49464 L
s
.75409 .45034 m
.75519 .44886 L
s
.72077 .49723 m
.72166 .49594 L
s
.59157 .29546 m
.59078 .29469 L
s
.76467 .42124 m
.77809 .41784 L
s
.71987 .49852 m
.72077 .49723 L
s
.75519 .44886 m
.75629 .44737 L
s
.76781 .41262 m
.76609 .41176 L
s
.71897 .4998 m
.71987 .49852 L
s
.75629 .44737 m
.75739 .44587 L
s
.76721 .43239 m
.75662 .44676 L
s
.71807 .50109 m
.71897 .4998 L
s
.75739 .44587 m
.75849 .44437 L
s
.71716 .50237 m
.71807 .50109 L
s
.75849 .44437 m
.75958 .44287 L
s
.59078 .29469 m
.58999 .29393 L
s
.71625 .50364 m
.71716 .50237 L
s
.71694 .50263 m
.70772 .51623 L
s
.75958 .44287 m
.76067 .44136 L
s
.76952 .41348 m
.76781 .41262 L
s
.71625 .50364 m
.71625 .50364 L
s
.71543 .50489 m
.71625 .50364 L
s
.76067 .44136 m
.76176 .43985 L
s
.7146 .50614 m
.71543 .50489 L
s
.76176 .43985 m
.76285 .43833 L
s
.71377 .50739 m
.7146 .50614 L
s
.58999 .29393 m
.58919 .29316 L
s
.76285 .43833 m
.76393 .43681 L
s
.71294 .50863 m
.71377 .50739 L
s
.77123 .41434 m
.76952 .41348 L
s
.76393 .43681 m
.76513 .43526 L
s
.76393 .43681 m
.76393 .43681 L
s
.71211 .50987 m
.71294 .50863 L
s
.76513 .43526 m
.76632 .4337 L
s
.71128 .51111 m
.71211 .50987 L
s
.58919 .29316 m
.5884 .2924 L
s
.76632 .4337 m
.76751 .43214 L
s
.71044 .51234 m
.71128 .51111 L
s
.77295 .41521 m
.77123 .41434 L
s
.77809 .41784 m
.76721 .43239 L
s
.7096 .51357 m
.71044 .51234 L
s
.76751 .43214 m
.76869 .43057 L
s
.5884 .2924 m
.5877 .29162 L
s
.5884 .2924 m
.5884 .2924 L
s
.70876 .5148 m
.7096 .51357 L
s
.76869 .43057 m
.76988 .429 L
s
.70791 .51603 m
.70876 .5148 L
s
.77466 .41609 m
.77295 .41521 L
s
.76988 .429 m
.77106 .42742 L
s
.70707 .51725 m
.70791 .51603 L
s
.70772 .51623 m
.69878 .52969 L
s
.77106 .42742 m
.77224 .42583 L
s
.5877 .29162 m
.58699 .29083 L
s
.70622 .51847 m
.70707 .51725 L
s
.77224 .42583 m
.77341 .42425 L
s
.70622 .51847 m
.70622 .51847 L
s
.70545 .51966 m
.70622 .51847 L
s
.63323 .57378 m
.63313 .58073 L
s
.77638 .41696 m
.77466 .41609 L
s
.5564 .28201 m
.56011 .28857 L
s
.77341 .42425 m
.77458 .42265 L
s
.70468 .52086 m
.70545 .51966 L
s
.58699 .29083 m
.58628 .29005 L
s
.77458 .42265 m
.77576 .42106 L
s
.70391 .52205 m
.70468 .52086 L
s
.77809 .41784 m
.77638 .41696 L
s
.77576 .42106 m
.77692 .41945 L
s
.70313 .52323 m
.70391 .52205 L
s
.58628 .29005 m
.58558 .28928 L
s
.77692 .41945 m
.77809 .41784 L
s
.70236 .52442 m
.70313 .52323 L
s
.57534 .27776 m
.58592 .28981 L
s
.54863 .26936 m
.55944 .28735 L
s
.70158 .5256 m
.70236 .52442 L
s
.87687 .35891 m
.77809 .41784 L
s
.77809 .41784 m
.87687 .35891 L
s
.77809 .41784 m
.77809 .41784 L
s
.58558 .28928 m
.58487 .2885 L
s
.7008 .52678 m
.70158 .5256 L
s
.70001 .52796 m
.7008 .52678 L
s
.58487 .2885 m
.58416 .28772 L
s
.69923 .52913 m
.70001 .52796 L
s
.69844 .5303 m
.69923 .52913 L
s
.69878 .52969 m
.69015 .54301 L
s
.69765 .53147 m
.69844 .5303 L
s
.58416 .28772 m
.58344 .28695 L
s
.69686 .53263 m
.69765 .53147 L
s
.69686 .53263 m
.69686 .53263 L
s
.69614 .53377 m
.69686 .53263 L
s
.58344 .28695 m
.58273 .28618 L
s
.69543 .53491 m
.69614 .53377 L
s
.69471 .53605 m
.69543 .53491 L
s
.58273 .28618 m
.58201 .28542 L
s
.69399 .53718 m
.69471 .53605 L
s
.69327 .53832 m
.69399 .53718 L
s
.58201 .28542 m
.5813 .28465 L
s
.69254 .53944 m
.69327 .53832 L
s
.5813 .28465 m
.58058 .28389 L
s
.69182 .54057 m
.69254 .53944 L
s
.69109 .54169 m
.69182 .54057 L
s
.63313 .58073 m
.6329 .58752 L
s
.58058 .28389 m
.57986 .28313 L
s
.69036 .54281 m
.69109 .54169 L
s
.55258 .2756 m
.5564 .28201 L
s
.68962 .54393 m
.69036 .54281 L
s
.69015 .54301 m
.68186 .55619 L
s
.63311 .58164 m
.63188 .60193 L
s
.57986 .28313 m
.57923 .28234 L
s
.57986 .28313 m
.57986 .28313 L
s
.68889 .54505 m
.68962 .54393 L
s
.68815 .54616 m
.68889 .54505 L
s
.57923 .28234 m
.57861 .28156 L
s
.68815 .54616 m
.68815 .54616 L
s
.68749 .54725 m
.68815 .54616 L
s
.68683 .54834 m
.68749 .54725 L
s
.57861 .28156 m
.57798 .28078 L
s
.68616 .54942 m
.68683 .54834 L
s
.039 .916 .04 r
.58589 .39973 m
.73013 .35606 L
s
0 0 0 r
2 Mabswid
.58589 .39973 Mdot
.57654 .36355 Mdot
.039 .916 .04 r
.5 Mabswid
.68209 .33099 m
.57654 .36355 L
s
0 g
.57798 .28078 m
.57736 .28 L
s
.6855 .5505 m
.68616 .54942 L
s
.68483 .55158 m
.6855 .5505 L
s
.57736 .28 m
.57673 .27922 L
s
.68416 .55266 m
.68483 .55158 L
s
.68349 .55373 m
.68416 .55266 L
s
.57673 .27922 m
.5761 .27845 L
s
.68281 .55481 m
.68349 .55373 L
s
.68213 .55587 m
.68281 .55481 L
s
.5761 .27845 m
.57547 .27768 L
s
.68145 .55694 m
.68213 .55587 L
s
.68186 .55619 m
.67394 .56922 L
s
.56576 .26459 m
.57534 .27776 L
s
.57547 .27768 m
.57483 .27691 L
s
.6329 .58752 m
.63253 .59414 L
s
.68077 .558 m
.68145 .55694 L
s
.68009 .55906 m
.68077 .558 L
s
.57483 .27691 m
.5742 .27614 L
s
.68009 .55906 m
.68009 .55906 L
s
.67948 .5601 m
.68009 .55906 L
s
.54863 .26936 m
.55258 .2756 L
s
.67887 .56114 m
.67948 .5601 L
s
.5742 .27614 m
.57356 .27538 L
s
.67826 .56217 m
.67887 .56114 L
s
.57356 .27538 m
.57292 .27462 L
s
.67765 .5632 m
.67826 .56217 L
s
.67704 .56423 m
.67765 .5632 L
s
.57292 .27462 m
.57228 .27386 L
s
.61997 .54086 m
.60668 .52198 L
s
.67642 .56526 m
.67704 .56423 L
s
.57228 .27386 m
.57175 .27307 L
s
.57228 .27386 m
.57228 .27386 L
s
.6758 .56628 m
.67642 .56526 L
s
.67518 .5673 m
.6758 .56628 L
s
.57175 .27307 m
.57121 .27229 L
s
.67455 .56832 m
.67518 .5673 L
s
.57121 .27229 m
.57067 .27151 L
s
.67393 .56933 m
.67455 .56832 L
s
.67394 .56922 m
.66643 .58208 L
s
.6733 .57035 m
.67393 .56933 L
s
.57067 .27151 m
.57014 .27073 L
s
.63253 .59414 m
.63201 .60059 L
s
.67267 .57135 m
.6733 .57035 L
s
.67267 .57135 m
.67267 .57135 L
s
.67212 .57234 m
.67267 .57135 L
s
0 0 0 r
2 Mabswid
.20283 .72046 Mdot
.039 .916 .04 r
.5 Mabswid
.58149 .60947 m
.20283 .72046 L
s
0 g
.57014 .27073 m
.5696 .26995 L
s
.67156 .57333 m
.67212 .57234 L
s
.5696 .26995 m
.56905 .26917 L
s
.67101 .57431 m
.67156 .57333 L
s
.54863 .26936 m
.55006 .26896 L
s
.54863 .26936 m
.54863 .26936 L
s
.54468 .26345 m
.54863 .26936 L
s
.53771 .25394 m
.54863 .26936 L
s
.54863 .26936 m
.54863 .26936 L
s
.54863 .26936 m
.54899 .29713 L
s
.67045 .57529 m
.67101 .57431 L
s
.56905 .26917 m
.56851 .2684 L
s
.55006 .26896 m
.55148 .26856 L
s
.55148 .26856 m
.55291 .26817 L
s
.66989 .57626 m
.67045 .57529 L
s
.56851 .2684 m
.56796 .26763 L
s
.55291 .26817 m
.55434 .26777 L
s
.66933 .57724 m
.66989 .57626 L
s
.55434 .26777 m
.55576 .26737 L
s
.66876 .57821 m
.66933 .57724 L
s
.56796 .26763 m
.56742 .26687 L
s
.55576 .26737 m
.55719 .26697 L
s
.66819 .57918 m
.66876 .57821 L
s
.55719 .26697 m
.55862 .26658 L
s
.56742 .26687 m
.56687 .2661 L
s
.66762 .58014 m
.66819 .57918 L
s
.55862 .26658 m
.56004 .26618 L
s
.56004 .26618 m
.56147 .26578 L
s
.56687 .2661 m
.56631 .26534 L
s
.66705 .58111 m
.66762 .58014 L
s
.56147 .26578 m
.5629 .26538 L
s
.66648 .58207 m
.66705 .58111 L
s
.63201 .60059 m
.63134 .60686 L
s
.5629 .26538 m
.56433 .26498 L
s
.56631 .26534 m
.56576 .26459 L
s
.66643 .58208 m
.65943 .59476 L
s
.6659 .58303 m
.66648 .58207 L
s
.56433 .26498 m
.56576 .26459 L
s
.55893 .25213 m
.56576 .26459 L
s
.56576 .26459 m
.56532 .2638 L
s
.56576 .26459 m
.56576 .26459 L
s
.6659 .58303 m
.6659 .58303 L
s
.6654 .58396 m
.6659 .58303 L
s
.63188 .60193 m
.62929 .61991 L
s
.66491 .58489 m
.6654 .58396 L
s
.56532 .2638 m
.56489 .26302 L
s
.66441 .58582 m
.66491 .58489 L
s
.54081 .25803 m
.54468 .26345 L
s
.56489 .26302 m
.56446 .26225 L
s
.66391 .58675 m
.66441 .58582 L
s
.6634 .58767 m
.66391 .58675 L
s
.56446 .26225 m
.56403 .26149 L
s
.6629 .58859 m
.6634 .58767 L
s
.56403 .26149 m
.5636 .26074 L
s
.66239 .58951 m
.6629 .58859 L
s
.66187 .59043 m
.66239 .58951 L
s
.5636 .26074 m
.56317 .25999 L
s
.66136 .59134 m
.66187 .59043 L
s
.56317 .25999 m
.56274 .25925 L
s
.63134 .60686 m
.6305 .61295 L
s
.66084 .59225 m
.66136 .59134 L
s
.56274 .25925 m
.56232 .25852 L
s
.66032 .59316 m
.66084 .59225 L
s
.6598 .59406 m
.66032 .59316 L
s
.56232 .25852 m
.56189 .2578 L
s
.6598 .59406 m
.6598 .59406 L
s
.65937 .59494 m
.6598 .59406 L
s
.56189 .2578 m
.56147 .25708 L
s
.65943 .59476 m
.65303 .60723 L
s
.65893 .59582 m
.65937 .59494 L
s
.039 .916 .04 r
.60957 .52609 m
.74792 .48685 L
s
0 0 0 r
2 Mabswid
.60957 .52609 Mdot
0 g
.5 Mabswid
.53701 .25306 m
.54081 .25803 L
s
.56147 .25708 m
.56105 .25637 L
s
.65849 .5967 m
.65893 .59582 L
s
.65805 .59757 m
.65849 .5967 L
s
.56105 .25637 m
.56063 .25567 L
s
.6576 .59844 m
.65805 .59757 L
s
.56063 .25567 m
.56032 .25495 L
s
.56063 .25567 m
.56063 .25567 L
s
.65715 .59931 m
.6576 .59844 L
s
.56032 .25495 m
.56001 .25423 L
s
.6567 .60017 m
.65715 .59931 L
s
.6305 .61295 m
.6295 .61884 L
s
.039 .916 .04 r
.10137 .44124 m
.4937 .30596 L
s
0 g
.65625 .60103 m
.6567 .60017 L
s
.56001 .25423 m
.55971 .25352 L
s
.65579 .60189 m
.65625 .60103 L
s
.55971 .25352 m
.5594 .25282 L
s
.60668 .52198 m
.59314 .50273 L
s
.54899 .29713 m
.54936 .32534 L
s
.65533 .60274 m
.65579 .60189 L
s
0 0 0 r
2 Mabswid
.77118 .43968 Mdot
.039 .916 .04 r
.5 Mabswid
.77555 .38357 m
.77118 .43968 L
s
0 g
.52682 .2414 m
.53771 .25394 L
s
.5594 .25282 m
.5591 .25212 L
s
.65487 .60359 m
.65533 .60274 L
s
.65441 .60444 m
.65487 .60359 L
s
.55529 .24189 m
.55893 .25213 L
s
.5591 .25212 m
.5588 .25143 L
s
.53329 .24852 m
.53701 .25306 L
s
.65441 .60444 m
.65441 .60444 L
s
.65404 .60527 m
.65441 .60444 L
s
.5588 .25143 m
.5585 .25075 L
s
.65366 .60609 m
.65404 .60527 L
s
.5585 .25075 m
.5582 .25007 L
s
.65328 .60691 m
.65366 .60609 L
s
.5582 .25007 m
.5579 .2494 L
s
.6529 .60772 m
.65328 .60691 L
s
.65303 .60723 m
.64743 .61941 L
s
.65252 .60853 m
.6529 .60772 L
s
.5579 .2494 m
.5576 .24874 L
s
.6295 .61884 m
.62831 .62453 L
s
.65214 .60934 m
.65252 .60853 L
s
.5576 .24874 m
.55731 .24808 L
s
.62929 .61991 m
.62536 .63524 L
s
.65175 .61015 m
.65214 .60934 L
s
.55731 .24808 m
.55702 .24744 L
s
.65136 .61095 m
.65175 .61015 L
s
0 0 0 r
2 Mabswid
.68209 .33099 Mdot
.039 .916 .04 r
.5 Mabswid
.77138 .49892 m
.68209 .33099 L
s
0 g
.55702 .24744 m
.55683 .24677 L
s
.55702 .24744 m
.55702 .24744 L
s
.65096 .61175 m
.65136 .61095 L
s
.52965 .24438 m
.53329 .24852 L
s
.55683 .24677 m
.55664 .2461 L
s
.65056 .61255 m
.65096 .61175 L
s
.65016 .61334 m
.65056 .61255 L
s
.55664 .2461 m
.55645 .24544 L
s
.64976 .61413 m
.65016 .61334 L
s
.55645 .24544 m
.55626 .24479 L
s
.64976 .61413 m
.64976 .61413 L
s
.64946 .61489 m
.64976 .61413 L
s
.55626 .24479 m
.55607 .24415 L
s
.64915 .61565 m
.64946 .61489 L
s
.62831 .62453 m
.62694 .63001 L
s
.55607 .24415 m
.55589 .24351 L
s
.64884 .61641 m
.64915 .61565 L
s
.55589 .24351 m
.55571 .24288 L
s
.64853 .61716 m
.64884 .61641 L
s
0 0 0 r
2 Mabswid
.61939 .59243 Mdot
.039 .916 .04 r
.5 Mabswid
.68398 .57475 m
.61939 .59243 L
s
0 g
.55571 .24288 m
.55552 .24225 L
s
.64821 .61791 m
.64853 .61716 L
s
.55552 .24225 m
.55534 .24163 L
s
.6479 .61866 m
.64821 .61791 L
s
.52606 .24064 m
.52965 .24438 L
s
.55394 .2332 m
.55529 .24189 L
s
.64758 .6194 m
.6479 .61866 L
s
.55534 .24163 m
.55516 .24102 L
s
.64743 .61941 m
.64298 .63118 L
s
.64725 .62014 m
.64758 .6194 L
s
.55516 .24102 m
.55499 .24041 L
s
.64692 .62088 m
.64725 .62014 L
s
.55499 .24041 m
.55481 .23981 L
s
.54936 .32534 m
.54973 .35398 L
s
0 0 0 r
2 Mabswid
.10869 .50645 Mdot
.039 .916 .04 r
.5 Mabswid
.50318 .37489 m
.10869 .50645 L
s
0 g
.64659 .62161 m
.64692 .62088 L
s
.55481 .23981 m
.55473 .23919 L
s
.55481 .23981 m
.55481 .23981 L
s
.64626 .62234 m
.64659 .62161 L
s
.62694 .63001 m
.62536 .63524 L
s
.55473 .23919 m
.55465 .23858 L
s
.039 .916 .04 r
.73013 .35606 m
.78675 .45981 L
s
0 0 0 r
2 Mabswid
.73013 .35606 Mdot
0 g
.5 Mabswid
.64592 .62307 m
.64626 .62234 L
s
.55465 .23858 m
.55457 .23797 L
s
.51613 .23201 m
.52682 .2414 L
s
.64592 .62307 m
.64592 .62307 L
s
.6457 .62376 m
.64592 .62307 L
s
.55457 .23797 m
.55449 .23737 L
s
.64547 .62446 m
.6457 .62376 L
s
.52254 .23728 m
.52606 .24064 L
s
.59314 .50273 m
.57933 .48311 L
s
.55449 .23737 m
.55442 .23677 L
s
.64523 .62514 m
.64547 .62446 L
s
.55442 .23677 m
.55434 .23618 L
s
.645 .62583 m
.64523 .62514 L
s
.55434 .23618 m
.55427 .23559 L
s
.64476 .62651 m
.645 .62583 L
s
0 0 0 r
2 Mabswid
.77555 .38357 Mdot
.039 .916 .04 r
.5 Mabswid
.59661 .38683 m
.77555 .38357 L
s
0 g
.55427 .23559 m
.55419 .23501 L
s
.64451 .62719 m
.64476 .62651 L
s
.64427 .62786 m
.64451 .62719 L
s
.55419 .23501 m
.55412 .23444 L
s
.62536 .63524 m
.62536 .63524 L
s
.62536 .63524 m
.6236 .64009 L
s
.62682 .63491 m
.62536 .63524 L
s
.62536 .63524 m
.6201 .64763 L
s
.64402 .62853 m
.64427 .62786 L
s
.55412 .23444 m
.55405 .23387 L
s
.62829 .63457 m
.62682 .63491 L
s
.62976 .63423 m
.62829 .63457 L
s
.63122 .63389 m
.62976 .63423 L
s
.64376 .6292 m
.64402 .62853 L
s
.55405 .23387 m
.55399 .23331 L
s
.63269 .63355 m
.63122 .63389 L
s
.63416 .63321 m
.63269 .63355 L
s
.51908 .2343 m
.52254 .23728 L
s
.64351 .62986 m
.64376 .6292 L
s
.55399 .23331 m
.55392 .23276 L
s
.63563 .63287 m
.63416 .63321 L
s
.55438 .22573 m
.55394 .2332 L
s
.63563 .63287 m
.6371 .63253 L
s
.64325 .63052 m
.64351 .62986 L
s
.55392 .23276 m
.55394 .23218 L
s
.55392 .23276 m
.55392 .23276 L
s
.63857 .6322 m
.6371 .63253 L
s
.64004 .63186 m
.63857 .6322 L
s
.64298 .63118 m
.64325 .63052 L
s
.64151 .63152 m
.64004 .63186 L
s
.55394 .23218 m
.55397 .23161 L
s
.64298 .63118 m
.64151 .63152 L
s
.64298 .63118 m
.64067 .64056 L
s
.64298 .63118 m
.64298 .63118 L
s
.64284 .6318 m
.64298 .63118 L
s
.55397 .23161 m
.55399 .23105 L
s
.64269 .63241 m
.64284 .6318 L
s
.55399 .23105 m
.55402 .23049 L
s
.64254 .63301 m
.64269 .63241 L
s
.55402 .23049 m
.55405 .22994 L
s
.6236 .64009 m
.62172 .64444 L
s
.64239 .63361 m
.64254 .63301 L
s
.55405 .22994 m
.55408 .2294 L
s
0 0 0 r
2 Mabswid
.68398 .57475 Mdot
.039 .916 .04 r
.5 Mabswid
.70458 .24752 m
.68398 .57475 L
s
0 g
.64224 .6342 m
.64239 .63361 L
s
.51568 .23168 m
.51908 .2343 L
s
.54973 .35398 m
.5501 .38308 L
s
.55408 .2294 m
.55411 .22886 L
s
.64208 .63478 m
.64224 .6342 L
s
.55411 .22886 m
.55415 .22832 L
s
.039 .916 .04 r
.53601 .30264 m
.64398 .26819 L
s
0 0 0 r
2 Mabswid
.53601 .30264 Mdot
0 g
.5 Mabswid
.64193 .63535 m
.64208 .63478 L
s
.55415 .22832 m
.55418 .22779 L
s
.64177 .63591 m
.64193 .63535 L
s
.55418 .22779 m
.55422 .22727 L
s
.64161 .63646 m
.64177 .63591 L
s
.55422 .22727 m
.55425 .22675 L
s
.039 .916 .04 r
.74792 .48685 m
.76003 .32349 L
s
0 0 0 r
2 Mabswid
.74792 .48685 Mdot
0 g
.5 Mabswid
.64145 .63701 m
.64161 .63646 L
s
.55425 .22675 m
.55429 .22624 L
s
.64128 .63755 m
.64145 .63701 L
s
.50583 .226 m
.51613 .23201 L
s
.55429 .22624 m
.55442 .22571 L
s
.55429 .22624 m
.55429 .22624 L
s
.62172 .64444 m
.61972 .6483 L
s
.64112 .63808 m
.64128 .63755 L
s
.51234 .22943 m
.51568 .23168 L
s
0 0 0 r
2 Mabswid
.13223 .63513 Mdot
.039 .916 .04 r
.5 Mabswid
.52806 .51213 m
.13223 .63513 L
s
0 g
.55631 .21923 m
.55438 .22573 L
s
.55442 .22571 m
.55455 .22519 L
s
.039 .916 .04 r
.14366 .67189 m
.53834 .55189 L
s
0 g
.64112 .63808 m
.64112 .63808 L
s
.64106 .63858 m
.64112 .63808 L
s
.55455 .22519 m
.55468 .22467 L
s
.64101 .63907 m
.64106 .63858 L
s
.57933 .48311 m
.56524 .46309 L
s
.55468 .22467 m
.55481 .22415 L
s
.64095 .63956 m
.64101 .63907 L
s
.55481 .22415 m
.55494 .22364 L
s
.64089 .64003 m
.64095 .63956 L
s
.55494 .22364 m
.55507 .22314 L
s
.64083 .6405 m
.64089 .64003 L
s
.55507 .22314 m
.5552 .22264 L
s
.6201 .64763 m
.61356 .65677 L
s
.64067 .64056 m
.64044 .64671 L
s
.64077 .64096 m
.64083 .6405 L
s
.5552 .22264 m
.55534 .22215 L
s
.6407 .64141 m
.64077 .64096 L
s
.61972 .6483 m
.61761 .65172 L
s
.50906 .22753 m
.51234 .22943 L
s
.55534 .22215 m
.55548 .22167 L
s
.64064 .64186 m
.6407 .64141 L
s
.55548 .22167 m
.55562 .22119 L
s
.64057 .6423 m
.64064 .64186 L
s
.55562 .22119 m
.55575 .22071 L
s
.6405 .64273 m
.64057 .6423 L
s
.55575 .22071 m
.5559 .22024 L
s
.64043 .64316 m
.6405 .64273 L
s
.5501 .38308 m
.55049 .41264 L
s
.5559 .22024 m
.55612 .21975 L
s
.5559 .22024 m
.5559 .22024 L
s
.64035 .64357 m
.64043 .64316 L
s
.55612 .21975 m
.55635 .21927 L
s
.64035 .64357 m
.64035 .64357 L
s
.64038 .64396 m
.64035 .64357 L
s
.55635 .21927 m
.55658 .21879 L
s
.55952 .21357 m
.55631 .21923 L
s
.64041 .64434 m
.64038 .64396 L
s
.50583 .226 m
.50906 .22753 L
s
.61761 .65172 m
.61539 .65471 L
s
.55658 .21879 m
.55681 .21832 L
s
.64044 .64471 m
.64041 .64434 L
s
.55681 .21832 m
.55704 .21785 L
s
.64047 .64508 m
.64044 .64471 L
s
.55704 .21785 m
.55728 .21739 L
s
.64049 .64544 m
.64047 .64508 L
s
.55728 .21739 m
.55751 .21694 L
s
.64051 .64579 m
.64049 .64544 L
s
.55751 .21694 m
.55775 .21649 L
s
.64053 .64613 m
.64051 .64579 L
s
.64055 .64647 m
.64053 .64613 L
s
.55775 .21649 m
.55799 .21604 L
s
.64057 .6468 m
.64055 .64647 L
s
.55799 .21604 m
.55823 .2156 L
s
.50583 .226 m
.50583 .226 L
s
.50512 .22571 m
.50583 .226 L
s
.49609 .22357 m
.50583 .226 L
s
.039 .916 .04 r
.08982 .55028 m
.49345 .41821 L
s
0 g
.64044 .64671 m
.64174 .65055 L
s
.64059 .64713 m
.64057 .6468 L
s
.61539 .65471 m
.61306 .65728 L
s
.55823 .2156 m
.55847 .21517 L
s
.50441 .22543 m
.50512 .22571 L
s
.6406 .64744 m
.64059 .64713 L
s
.55847 .21517 m
.55871 .21474 L
s
0 0 0 r
2 Mabswid
.5267 .31173 Mdot
.039 .916 .04 r
.5 Mabswid
.67583 .26428 m
.5267 .31173 L
s
0 g
.64062 .64775 m
.6406 .64744 L
s
.55871 .21474 m
.55904 .2143 L
s
.55871 .21474 m
.55871 .21474 L
s
.50371 .22518 m
.50441 .22543 L
s
.56524 .46309 m
.55087 .44267 L
s
.64062 .64775 m
.64062 .64775 L
s
.64073 .64804 m
.64062 .64775 L
s
.55904 .2143 m
.55937 .21386 L
s
.50301 .22494 m
.50371 .22518 L
s
.64083 .64831 m
.64073 .64804 L
s
.55937 .21386 m
.5597 .21342 L
s
.64094 .64858 m
.64083 .64831 L
s
.56387 .20864 m
.55952 .21357 L
s
.5597 .21342 m
.56003 .21299 L
s
.50231 .22472 m
.50301 .22494 L
s
.61356 .65677 m
.60582 .66243 L
s
.64105 .64884 m
.64094 .64858 L
s
.56003 .21299 m
.56036 .21257 L
s
.55049 .41264 m
.55087 .44267 L
s
.50162 .22452 m
.50231 .22472 L
s
.64115 .6491 m
.64105 .64884 L
s
.61306 .65728 m
.61063 .65944 L
s
.56036 .21257 m
.5607 .21215 L
s
.039 .916 .04 r
.64398 .26819 m
.73117 .4328 L
s
0 0 0 r
2 Mabswid
.64398 .26819 Mdot
0 g
.5 Mabswid
.64126 .64935 m
.64115 .6491 L
s
.50092 .22434 m
.50162 .22452 L
s
.5607 .21215 m
.56103 .21173 L
s
.64136 .64959 m
.64126 .64935 L
s
.56103 .21173 m
.56137 .21132 L
s
.64146 .64983 m
.64136 .64959 L
s
.50023 .22417 m
.50092 .22434 L
s
.56137 .21132 m
.56171 .21092 L
s
.64156 .65006 m
.64146 .64983 L
s
.49955 .22403 m
.50023 .22417 L
s
.56171 .21092 m
.56205 .21052 L
s
.64165 .65028 m
.64156 .65006 L
s
.56205 .21052 m
.5624 .21013 L
s
.64175 .65049 m
.64165 .65028 L
s
.49886 .2239 m
.49955 .22403 L
s
.5624 .21013 m
.56274 .20974 L
s
.64185 .6507 m
.64175 .65049 L
s
.64174 .65055 m
.64422 .65257 L
s
.61063 .65944 m
.6081 .66121 L
s
.49818 .22379 m
.49886 .2239 L
s
.56274 .20974 m
.56317 .20934 L
s
.56274 .20974 m
.56274 .20974 L
s
.64185 .6507 m
.64185 .6507 L
s
.64203 .65089 m
.64185 .6507 L
s
.56317 .20934 m
.5636 .20894 L
s
.64222 .65106 m
.64203 .65089 L
s
.49751 .2237 m
.49818 .22379 L
s
.5636 .20894 m
.56403 .20855 L
s
.6424 .65123 m
.64222 .65106 L
s
.49751 .2237 m
.49751 .2237 L
s
.49742 .22369 m
.49751 .2237 L
s
.56927 .20437 m
.56387 .20864 L
s
.49734 .22368 m
.49742 .22369 L
s
.64258 .6514 m
.6424 .65123 L
s
.56403 .20855 m
.56447 .20816 L
s
.49725 .22367 m
.49734 .22368 L
s
.49717 .22366 m
.49725 .22367 L
s
.49708 .22365 m
.49717 .22366 L
s
.497 .22364 m
.49708 .22365 L
s
.49692 .22364 m
.497 .22364 L
s
.64277 .65155 m
.64258 .6514 L
s
.49683 .22363 m
.49692 .22364 L
s
.56447 .20816 m
.5649 .20778 L
s
.49675 .22362 m
.49683 .22363 L
s
.49666 .22361 m
.49675 .22362 L
s
.49658 .22361 m
.49666 .22361 L
s
.49649 .2236 m
.49658 .22361 L
s
.64295 .65171 m
.64277 .65155 L
s
.49649 .2236 m
.49649 .2236 L
s
.49639 .22359 m
.49649 .2236 L
s
.5649 .20778 m
.56534 .2074 L
s
.49628 .22358 m
.49639 .22359 L
s
.49617 .22358 m
.49628 .22358 L
s
.49606 .22357 m
.49617 .22358 L
s
.48711 .22488 m
.49609 .22357 L
s
.64312 .65185 m
.64295 .65171 L
s
.49596 .22356 m
.49606 .22357 L
s
.56534 .2074 m
.56578 .20703 L
s
.49585 .22356 m
.49596 .22356 L
s
.6081 .66121 m
.60546 .66259 L
s
.49574 .22355 m
.49585 .22356 L
s
.49563 .22355 m
.49574 .22355 L
s
.49553 .22354 m
.49563 .22355 L
s
.6433 .65199 m
.64312 .65185 L
s
.49542 .22354 m
.49553 .22354 L
s
.56578 .20703 m
.56622 .20666 L
s
.49531 .22354 m
.49542 .22354 L
s
.4952 .22353 m
.49531 .22354 L
s
.4952 .22353 m
.4952 .22353 L
s
.49506 .22353 m
.4952 .22353 L
s
.64348 .65212 m
.6433 .65199 L
s
.49492 .22353 m
.49506 .22353 L
s
.56622 .20666 m
.56666 .2063 L
s
.49478 .22353 m
.49492 .22353 L
s
.49463 .22353 m
.49478 .22353 L
s
.039 .916 .04 r
.5903 .59628 m
.71977 .56076 L
s
0 0 0 r
2 Mabswid
.5903 .59628 Mdot
0 g
.5 Mabswid
.64366 .65225 m
.64348 .65212 L
s
.55087 .44267 m
.55127 .47319 L
s
.55087 .44267 m
.53622 .42184 L
s
.49449 .22353 m
.49463 .22353 L
s
.56666 .2063 m
.56711 .20594 L
s
.49435 .22353 m
.49449 .22353 L
s
.49421 .22353 m
.49435 .22353 L
s
.64383 .65236 m
.64366 .65225 L
s
.49407 .22353 m
.49421 .22353 L
s
.56711 .20594 m
.56755 .20559 L
s
.49393 .22354 m
.49407 .22353 L
s
.49378 .22354 m
.49393 .22354 L
s
.644 .65248 m
.64383 .65236 L
s
.49364 .22355 m
.49378 .22354 L
s
.56755 .20559 m
.568 .20525 L
s
.4935 .22355 m
.49364 .22355 L
s
.4935 .22355 m
.4935 .22355 L
s
.4933 .22357 m
.4935 .22355 L
s
.644 .65248 m
.644 .65248 L
s
.64426 .65256 m
.644 .65248 L
s
.60582 .66243 m
.59697 .6644 L
s
.49311 .22358 m
.4933 .22357 L
s
.568 .20525 m
.56853 .20489 L
s
.568 .20525 m
.568 .20525 L
s
.49291 .22359 m
.49311 .22358 L
s
.64422 .65257 m
.6477 .6531 L
s
.64452 .65264 m
.64426 .65256 L
s
.60546 .66259 m
.60273 .66358 L
s
.49271 .22361 m
.49291 .22359 L
s
.56853 .20489 m
.56907 .20453 L
s
.49252 .22363 m
.49271 .22361 L
s
.64478 .65272 m
.64452 .65264 L
s
.49232 .22365 m
.49252 .22363 L
s
.49213 .22367 m
.49232 .22365 L
s
.56907 .20453 m
.5696 .20418 L
s
.64504 .65279 m
.64478 .65272 L
s
.49193 .22369 m
.49213 .22367 L
s
.57564 .2007 m
.56927 .20437 L
s
.49174 .22372 m
.49193 .22369 L
s
.5696 .20418 m
.57014 .20383 L
s
.6453 .65285 m
.64504 .65279 L
s
.49154 .22374 m
.49174 .22372 L
s
.49135 .22377 m
.49154 .22374 L
s
.57014 .20383 m
.57068 .20349 L
s
.49115 .2238 m
.49135 .22377 L
s
.64555 .6529 m
.6453 .65285 L
s
.49115 .2238 m
.49115 .2238 L
s
.48942 .22416 m
.49115 .2238 L
s
.64581 .65295 m
.64555 .6529 L
s
.57068 .20349 m
.57123 .20316 L
s
.64606 .653 m
.64581 .65295 L
s
.57123 .20316 m
.57177 .20283 L
s
.60273 .66358 m
.5999 .66418 L
s
.64632 .65303 m
.64606 .653 L
s
.57177 .20283 m
.57232 .2025 L
s
.64657 .65306 m
.64632 .65303 L
s
.57232 .2025 m
.57287 .20219 L
s
.4877 .22466 m
.48942 .22416 L
s
.64682 .65309 m
.64657 .65306 L
s
.57287 .20219 m
.57341 .20187 L
s
.64707 .6531 m
.64682 .65309 L
s
.57341 .20187 m
.57397 .20157 L
s
.64707 .6531 m
.64707 .6531 L
s
.6474 .6531 m
.64707 .6531 L
s
.57397 .20157 m
.57452 .20127 L
s
.64774 .65308 m
.6474 .6531 L
s
.57452 .20127 m
.57516 .20095 L
s
.57452 .20127 m
.57452 .20127 L
s
.48602 .22532 m
.4877 .22466 L
s
.55127 .47319 m
.55167 .5042 L
s
.64807 .65306 m
.64774 .65308 L
s
.6477 .6531 m
.65205 .65233 L
s
.57516 .20095 m
.57581 .20063 L
s
.5999 .66418 m
.59697 .6644 L
s
.6484 .65304 m
.64807 .65306 L
s
.47905 .23 m
.48711 .22488 L
s
.58292 .1976 m
.57564 .2007 L
s
.57581 .20063 m
.57645 .20032 L
s
.039 .916 .04 r
.76003 .32349 m
.67345 .3221 L
s
0 0 0 r
2 Mabswid
.76003 .32349 Mdot
0 g
.5 Mabswid
.64873 .653 m
.6484 .65304 L
s
.57645 .20032 m
.5771 .20002 L
s
.64906 .65296 m
.64873 .653 L
s
.48436 .22613 m
.48602 .22532 L
s
.5771 .20002 m
.57775 .19972 L
s
.64939 .65292 m
.64906 .65296 L
s
.53622 .42184 m
.52126 .40058 L
s
.64972 .65287 m
.64939 .65292 L
s
.57775 .19972 m
.5784 .19943 L
s
.039 .916 .04 r
.78675 .45981 m
.68775 .46598 L
s
0 0 0 r
2 Mabswid
.78675 .45981 Mdot
0 g
.5 Mabswid
.65005 .65281 m
.64972 .65287 L
s
.5784 .19943 m
.57905 .19915 L
s
0 0 0 r
2 Mabswid
.67583 .26428 Mdot
.039 .916 .04 r
.5 Mabswid
.7331 .36955 m
.67583 .26428 L
s
0 g
.65038 .65275 m
.65005 .65281 L
s
.57905 .19915 m
.57971 .19887 L
s
.59697 .6644 m
.59631 .66439 L
s
.59697 .6644 m
.59697 .6644 L
s
.59697 .6644 m
.58714 .66253 L
s
.48272 .22711 m
.48436 .22613 L
s
.6507 .65268 m
.65038 .65275 L
s
.57971 .19887 m
.58037 .1986 L
s
.59631 .66439 m
.59564 .66437 L
s
.65103 .6526 m
.6507 .65268 L
s
.58037 .1986 m
.58103 .19833 L
s
.65103 .6526 m
.65103 .6526 L
s
.65144 .6525 m
.65103 .6526 L
s
.59564 .66437 m
.59496 .66432 L
s
0 0 0 r
2 Mabswid
.58149 .60947 Mdot
.039 .916 .04 r
.5 Mabswid
.72145 .5713 m
.58149 .60947 L
s
0 g
.58103 .19833 m
.58169 .19807 L
s
.65185 .65239 m
.65144 .6525 L
s
.58169 .19807 m
.58235 .19781 L
s
.59496 .66432 m
.59428 .66426 L
s
.65225 .65228 m
.65185 .65239 L
s
.48111 .22825 m
.48272 .22711 L
s
.58235 .19781 m
.58311 .19754 L
s
.58235 .19781 m
.58235 .19781 L
s
.65205 .65233 m
.65717 .65041 L
s
.65266 .65216 m
.65225 .65228 L
s
.59428 .66426 m
.5936 .66418 L
s
.59108 .19504 m
.58292 .1976 L
s
.58311 .19754 m
.58386 .19727 L
s
.65307 .65203 m
.65266 .65216 L
s
.5936 .66418 m
.59291 .66408 L
s
.58386 .19727 m
.58462 .19701 L
s
.65347 .6519 m
.65307 .65203 L
s
.59291 .66408 m
.59221 .66396 L
s
.58462 .19701 m
.58539 .19675 L
s
.65388 .65176 m
.65347 .6519 L
s
.47953 .22956 m
.48111 .22825 L
s
.55167 .5042 m
.55208 .53572 L
s
.65428 .65161 m
.65388 .65176 L
s
.58539 .19675 m
.58615 .1965 L
s
.59221 .66396 m
.59151 .66382 L
s
.65468 .65146 m
.65428 .65161 L
s
.58615 .1965 m
.58692 .19625 L
s
.59151 .66382 m
.59081 .66365 L
s
.65508 .6513 m
.65468 .65146 L
s
.58692 .19625 m
.58768 .19601 L
s
.65548 .65114 m
.65508 .6513 L
s
.59081 .66365 m
.5901 .66347 L
s
.47798 .23106 m
.47953 .22956 L
s
.58768 .19601 m
.58846 .19578 L
s
.65588 .65097 m
.65548 .65114 L
s
.039 .916 .04 r
.71977 .56076 m
.7331 .36955 L
s
0 0 0 r
2 Mabswid
.71977 .56076 Mdot
0 g
.5 Mabswid
.47209 .23898 m
.47905 .23 L
s
.58846 .19578 m
.58923 .19556 L
s
.5901 .66347 m
.58938 .66327 L
s
.65588 .65097 m
.65588 .65097 L
s
.65637 .65077 m
.65588 .65097 L
s
.58923 .19556 m
.59 .19534 L
s
.65685 .65057 m
.65637 .65077 L
s
.58938 .66327 m
.58866 .66305 L
s
.59 .19534 m
.59078 .19512 L
s
.65734 .65036 m
.65685 .65057 L
s
.47646 .23274 m
.47798 .23106 L
s
.58866 .66305 m
.58857 .66303 L
s
.58866 .66305 m
.58866 .66305 L
s
.58857 .66303 m
.58848 .663 L
s
.52126 .40058 m
.50599 .37889 L
s
.58848 .663 m
.58839 .66297 L
s
.65717 .65041 m
.66299 .64745 L
s
.59078 .19512 m
.59156 .19492 L
s
.58839 .66297 m
.5883 .66294 L
s
.65782 .65014 m
.65734 .65036 L
s
.5883 .66294 m
.58821 .66291 L
s
.58821 .66291 m
.58812 .66288 L
s
.60009 .193 m
.59108 .19504 L
s
.58812 .66288 m
.58803 .66285 L
s
.58803 .66285 m
.58794 .66281 L
s
.58794 .66281 m
.58785 .66278 L
s
.59156 .19492 m
.59244 .19469 L
s
.59156 .19492 m
.59156 .19492 L
s
.58785 .66278 m
.58775 .66275 L
s
.6583 .64992 m
.65782 .65014 L
s
.58775 .66275 m
.58766 .66272 L
s
.58766 .66272 m
.58757 .66269 L
s
.58757 .66269 m
.58745 .66264 L
s
.58757 .66269 m
.58757 .66269 L
s
.58745 .66264 m
.58734 .6626 L
s
.58734 .6626 m
.58722 .66256 L
s
.65878 .64969 m
.6583 .64992 L
s
.59244 .19469 m
.59332 .19447 L
s
.58722 .66256 m
.5871 .66251 L
s
.58714 .66253 m
.57646 .65674 L
s
.5871 .66251 m
.58698 .66247 L
s
.58698 .66247 m
.58687 .66243 L
s
.58687 .66243 m
.58675 .66238 L
s
.65926 .64946 m
.65878 .64969 L
s
.58675 .66238 m
.58663 .66233 L
s
.59332 .19447 m
.5942 .19425 L
s
.58663 .66233 m
.58651 .66229 L
s
.47497 .23461 m
.47646 .23274 L
s
.58651 .66229 m
.58639 .66224 L
s
.58639 .66224 m
.58627 .66219 L
s
.58627 .66219 m
.58615 .66215 L
s
.65974 .64922 m
.65926 .64946 L
s
.58615 .66215 m
.586 .66208 L
s
.58615 .66215 m
.58615 .66215 L
s
.5942 .19425 m
.59508 .19404 L
s
.586 .66208 m
.58584 .66202 L
s
.58584 .66202 m
.58568 .66195 L
s
.66022 .64897 m
.65974 .64922 L
s
.58568 .66195 m
.58552 .66188 L
s
.58552 .66188 m
.58536 .66181 L
s
.59508 .19404 m
.59597 .19384 L
s
.58536 .66181 m
.5852 .66174 L
s
.5852 .66174 m
.58504 .66167 L
s
.6607 .64871 m
.66022 .64897 L
s
.58504 .66167 m
.58488 .6616 L
s
.59597 .19384 m
.59686 .19365 L
s
.58488 .6616 m
.58472 .66153 L
s
.039 .916 .04 r
.4937 .30596 m
.68032 .24613 L
s
0 0 0 r
2 Mabswid
.4937 .30596 Mdot
0 g
.5 Mabswid
.58472 .66153 m
.58456 .66146 L
s
.66118 .64845 m
.6607 .64871 L
s
.58456 .66146 m
.58439 .66138 L
s
.58439 .66138 m
.58423 .66131 L
s
.47351 .23669 m
.47497 .23461 L
s
.59686 .19365 m
.59775 .19346 L
s
.55208 .53572 m
.55249 .56777 L
s
.58423 .66131 m
.58401 .6612 L
s
.58423 .66131 m
.58423 .66131 L
s
.66165 .64819 m
.66118 .64845 L
s
.58401 .6612 m
.58378 .66109 L
s
.58378 .66109 m
.58355 .66098 L
s
.59775 .19346 m
.59864 .19327 L
s
.66165 .64819 m
.66165 .64819 L
s
.66221 .64789 m
.66165 .64819 L
s
.58355 .66098 m
.58332 .66087 L
s
.58332 .66087 m
.5831 .66076 L
s
.5831 .66076 m
.58287 .66064 L
s
.59864 .19327 m
.59954 .1931 L
s
.66278 .64759 m
.66221 .64789 L
s
.58287 .66064 m
.58264 .66052 L
s
.58264 .66052 m
.58241 .6604 L
s
.66334 .64729 m
.66278 .64759 L
s
.59954 .1931 m
.60043 .19293 L
s
.58241 .6604 m
.58218 .66028 L
s
.58218 .66028 m
.58195 .66016 L
s
.66299 .64745 m
.66947 .64352 L
s
.47209 .23898 m
.47351 .23669 L
s
.60994 .19146 m
.60009 .193 L
s
.58195 .66016 m
.58172 .66003 L
s
.6639 .64698 m
.66334 .64729 L
s
.60043 .19293 m
.60134 .19277 L
s
.58172 .66003 m
.58149 .6599 L
s
.58149 .6599 m
.57938 .65867 L
s
.66446 .64666 m
.6639 .64698 L
s
.60134 .19277 m
.60224 .19261 L
s
.66502 .64633 m
.66446 .64666 L
s
.60224 .19261 m
.60325 .19243 L
s
.60224 .19261 m
.60224 .19261 L
s
.66557 .646 m
.66502 .64633 L
s
.60325 .19243 m
.60426 .19226 L
s
.47209 .23898 m
.48617 .23496 L
s
.47209 .23898 m
.47209 .23898 L
s
.47073 .24145 m
.47209 .23898 L
s
.4664 .25175 m
.47209 .23898 L
s
.66613 .64566 m
.66557 .646 L
s
.57938 .65867 m
.57723 .65727 L
s
.60426 .19226 m
.60527 .1921 L
s
.66669 .64531 m
.66613 .64566 L
s
.60527 .1921 m
.60628 .19194 L
s
.66724 .64496 m
.66669 .64531 L
s
.60628 .19194 m
.6073 .19179 L
s
.6678 .6446 m
.66724 .64496 L
s
.48617 .23496 m
.50031 .23093 L
s
.50599 .37889 m
.49041 .35674 L
s
.46946 .24406 m
.47073 .24145 L
s
0 0 0 r
2 Mabswid
.77138 .49892 Mdot
.039 .916 .04 r
.5 Mabswid
.70624 .5044 m
.77138 .49892 L
s
0 g
.66835 .64423 m
.6678 .6446 L
s
.57723 .65727 m
.57504 .65571 L
s
.6073 .19179 m
.60832 .19165 L
s
.66835 .64423 m
.66835 .64423 L
s
.669 .64384 m
.66835 .64423 L
s
.60832 .19165 m
.60934 .19152 L
s
.57646 .65674 m
.56513 .64703 L
s
.66964 .64344 m
.669 .64384 L
s
.60934 .19152 m
.61037 .19139 L
s
.50031 .23093 m
.51449 .22689 L
s
.66947 .64352 m
.67657 .63868 L
s
.67028 .64304 m
.66964 .64344 L
s
.62062 .19042 m
.60994 .19146 L
s
0 0 0 r
2 Mabswid
.50318 .37489 Mdot
.039 .916 .04 r
.5 Mabswid
.67345 .3221 m
.50318 .37489 L
s
0 g
.61037 .19139 m
.6114 .19127 L
s
.57504 .65571 m
.57282 .65399 L
s
.55249 .56777 m
.55291 .60034 L
s
.46826 .24681 m
.46946 .24406 L
s
.67092 .64262 m
.67028 .64304 L
s
0 0 0 r
2 Mabswid
.72145 .5713 Mdot
.039 .916 .04 r
.5 Mabswid
.73117 .4328 m
.72145 .5713 L
s
0 g
.6114 .19127 m
.61243 .19115 L
s
.67156 .6422 m
.67092 .64262 L
s
.61243 .19115 m
.61346 .19105 L
s
.6722 .64177 m
.67156 .6422 L
s
.51449 .22689 m
.52872 .22283 L
s
.61346 .19105 m
.6145 .19095 L
s
.67284 .64134 m
.6722 .64177 L
s
.57282 .65399 m
.57054 .65209 L
s
.46714 .24968 m
.46826 .24681 L
s
.67348 .6409 m
.67284 .64134 L
s
.6145 .19095 m
.61565 .19083 L
s
.6145 .19095 m
.6145 .19095 L
s
.67411 .64045 m
.67348 .6409 L
s
.61565 .19083 m
.6168 .19071 L
s
.52872 .22283 m
.54301 .21876 L
s
.67475 .64 m
.67411 .64045 L
s
.6168 .19071 m
.61796 .1906 L
s
.57054 .65209 m
.56823 .65002 L
s
.67539 .63953 m
.67475 .64 L
s
.46609 .25268 m
.46714 .24968 L
s
.61796 .1906 m
.61912 .19051 L
s
.67602 .63907 m
.67539 .63953 L
s
.61912 .19051 m
.62028 .19041 L
s
.54301 .21876 m
.55734 .21467 L
s
0 0 0 r
2 Mabswid
.70458 .24752 Mdot
.039 .916 .04 r
.5 Mabswid
.68032 .24613 m
.70458 .24752 L
s
0 g
.67602 .63907 m
.67602 .63907 L
s
.67675 .63857 m
.67602 .63907 L
s
.46212 .26817 m
.4664 .25175 L
s
.67657 .63868 m
.68426 .63296 L
s
.62028 .19041 m
.62145 .19033 L
s
.67748 .63806 m
.67675 .63857 L
s
.56823 .65002 m
.56587 .64776 L
s
.63212 .18988 m
.62062 .19042 L
s
.46511 .2558 m
.46609 .25268 L
s
.62145 .19033 m
.62261 .19025 L
s
.6782 .63755 m
.67748 .63806 L
s
.67893 .63703 m
.6782 .63755 L
s
.57173 .21057 m
.55734 .21467 L
s
.62261 .19025 m
.62379 .19018 L
s
.67965 .63651 m
.67893 .63703 L
s
.62379 .19018 m
.62496 .19012 L
s
.64444 .18983 m
.87687 .35891 L
s
.87687 .35891 m
.73119 .59202 L
s
.73119 .59202 m
.87687 .35891 L
s
.87687 .35891 m
.64444 .18983 L
s
.56587 .64776 m
.56346 .64531 L
s
.68038 .63597 m
.67965 .63651 L
s
.4642 .25904 m
.46511 .2558 L
s
.62496 .19012 m
.62614 .19007 L
s
.56513 .64703 m
.55334 .63347 L
s
.6811 .63543 m
.68038 .63597 L
s
.55291 .60034 m
.55334 .63347 L
s
.49041 .35674 m
.4745 .33412 L
s
.58617 .20645 m
.57173 .21057 L
s
.62614 .19007 m
.62732 .19003 L
s
.68182 .63488 m
.6811 .63543 L
s
.62732 .19003 m
.6285 .18999 L
s
.68254 .63433 m
.68182 .63488 L
s
.56346 .64531 m
.56101 .64267 L
s
.46336 .2624 m
.4642 .25904 L
s
.6285 .18999 m
.62981 .18993 L
s
.6285 .18999 m
.6285 .18999 L
s
.68327 .63377 m
.68254 .63433 L
s
.58617 .20645 m
.60066 .20232 L
s
.68399 .6332 m
.68327 .63377 L
s
.62981 .18993 m
.63112 .18988 L
s
.039 .916 .04 r
.53834 .55189 m
.70624 .5044 L
s
0 0 0 r
2 Mabswid
.53834 .55189 Mdot
.52806 .51213 Mdot
.039 .916 .04 r
.5 Mabswid
.68775 .46598 m
.52806 .51213 L
s
0 g
.68471 .63262 m
.68399 .6332 L
s
.63112 .18988 m
.63244 .18983 L
s
.68426 .63296 m
.69253 .6264 L
s
.56101 .64267 m
.5585 .63982 L
s
.46259 .26587 m
.46336 .2624 L
s
.68471 .63262 m
.68471 .63262 L
s
.68552 .63201 m
.68471 .63262 L
s
.64444 .18983 m
.63212 .18988 L
s
.63244 .18983 m
.63376 .1898 L
s
.68634 .63139 m
.68552 .63201 L
s
.60066 .20232 m
.6152 .19817 L
s
.63376 .1898 m
.63508 .18977 L
s
.68716 .63077 m
.68634 .63139 L
s
.63508 .18977 m
.63641 .18975 L
s
.5585 .63982 m
.55595 .63676 L
s
.68797 .63014 m
.68716 .63077 L
s
.46188 .26945 m
.46259 .26587 L
s
.63641 .18975 m
.63774 .18974 L
s
.68879 .6295 m
.68797 .63014 L
s
.62979 .19401 m
.6152 .19817 L
s
.6896 .62886 m
.68879 .6295 L
s
.45937 .28804 m
.46212 .26817 L
s
.63774 .18974 m
.63907 .18974 L
s
.69041 .6282 m
.6896 .62886 L
s
.46123 .27314 m
.46188 .26945 L
s
.63907 .18974 m
.64041 .18975 L
s
.55595 .63676 m
.55334 .63347 L
s
.69123 .62754 m
.69041 .6282 L
s
.64041 .18975 m
.64175 .18977 L
s
.64444 .18983 m
.62979 .19401 L
s
.69204 .62687 m
.69123 .62754 L
s
.64175 .18977 m
.64309 .18979 L
s
.69285 .62619 m
.69204 .62687 L
s
.46065 .27694 m
.46123 .27314 L
s
.56787 .63008 m
.55334 .63347 L
s
.55334 .63347 m
.55334 .63347 L
s
.55334 .63347 m
.55072 .63 L
s
.55334 .63347 m
.55334 .63347 L
s
.55334 .63347 m
.54131 .61623 L
s
.69253 .6264 m
.70137 .61902 L
s
.64309 .18979 m
.64444 .18983 L
s
.69366 .62551 m
.69285 .62619 L
s
.62805 .1987 m
.64444 .18983 L
s
.64444 .18983 m
.64444 .18983 L
s
.64444 .18983 m
.64265 .19077 L
s
.69447 .62481 m
.69366 .62551 L
s
.64265 .19077 m
.64087 .19172 L
s
.64087 .19172 m
.63908 .19267 L
s
.69447 .62481 m
.69447 .62481 L
s
.69538 .62409 m
.69447 .62481 L
s
.46059 .27736 m
.46065 .27694 L
s
0 0 0 r
2 Mabswid
.68032 .24613 Mdot
0 g
.5 Mabswid
.63908 .19267 m
.6373 .19363 L
s
.46053 .27779 m
.46059 .27736 L
s
.46047 .27822 m
.46053 .27779 L
s
.6373 .19363 m
.63552 .19459 L
s
.55072 .63 m
.54813 .62642 L
s
.58244 .62669 m
.56787 .63008 L
s
.6963 .62335 m
.69538 .62409 L
s
.46042 .27866 m
.46047 .27822 L
s
.63552 .19459 m
.63375 .19557 L
s
.46036 .27909 m
.46042 .27866 L
s
.4745 .33412 m
.45824 .31102 L
s
.4603 .27953 m
.46036 .27909 L
s
.63375 .19557 m
.63197 .19654 L
s
.46025 .27996 m
.4603 .27953 L
s
.69721 .62261 m
.6963 .62335 L
s
.63197 .19654 m
.6302 .19753 L
s
.46019 .2804 m
.46025 .27996 L
s
.6302 .19753 m
.62843 .19852 L
s
.46014 .28084 m
.46019 .2804 L
s
.46008 .28128 m
.46014 .28084 L
s
.62843 .19852 m
.62667 .19951 L
s
.69812 .62186 m
.69721 .62261 L
s
.61227 .20811 m
.62805 .1987 L
s
.46003 .28172 m
.46008 .28128 L
s
.62667 .19951 m
.6249 .20052 L
s
.45998 .28216 m
.46003 .28172 L
s
.45998 .28216 m
.45998 .28216 L
s
.45994 .28248 m
.45998 .28216 L
s
.6249 .20052 m
.62314 .20153 L
s
.54813 .62642 m
.54557 .62273 L
s
.69903 .6211 m
.69812 .62186 L
s
.4599 .2828 m
.45994 .28248 L
s
.59707 .62328 m
.58244 .62669 L
s
.45987 .28311 m
.4599 .2828 L
s
.62314 .20153 m
.62151 .2025 L
s
.62314 .20153 m
.62314 .20153 L
s
.45983 .28343 m
.45987 .28311 L
s
.4598 .28375 m
.45983 .28343 L
s
.62151 .2025 m
.61987 .20349 L
s
.45976 .28407 m
.4598 .28375 L
s
.69994 .62033 m
.69903 .6211 L
s
.45973 .28439 m
.45976 .28407 L
s
.61987 .20349 m
.61824 .20448 L
s
.4597 .28472 m
.45973 .28439 L
s
.45966 .28504 m
.4597 .28472 L
s
.61824 .20448 m
.61661 .20548 L
s
.45963 .28536 m
.45966 .28504 L
s
.4596 .28568 m
.45963 .28536 L
s
.61661 .20548 m
.61499 .20648 L
s
.70085 .61956 m
.69994 .62033 L
s
.45956 .28601 m
.4596 .28568 L
s
.45956 .28601 m
.45956 .28601 L
s
.45954 .28625 m
.45956 .28601 L
s
.039 .916 .04 r
.49345 .41821 m
.59661 .38683 L
s
0 0 0 r
2 Mabswid
.49345 .41821 Mdot
0 g
.5 Mabswid
.61499 .20648 m
.61336 .20749 L
s
.45952 .28649 m
.45954 .28625 L
s
.45949 .28674 m
.45952 .28649 L
s
.61336 .20749 m
.61174 .2085 L
s
.45947 .28698 m
.45949 .28674 L
s
.54557 .62273 m
.54304 .61892 L
s
.59714 .21808 m
.61227 .20811 L
s
.70176 .61877 m
.70085 .61956 L
s
.45944 .28723 m
.45947 .28698 L
s
.45942 .28747 m
.45944 .28723 L
s
.61174 .2085 m
.61012 .20952 L
s
.4594 .28772 m
.45942 .28747 L
s
.61176 .61985 m
.59707 .62328 L
s
0 0 0 r
2 Mabswid
.7331 .36955 Mdot
0 g
.5 Mabswid
.45938 .28797 m
.4594 .28772 L
s
.61012 .20952 m
.6085 .21055 L
s
.45935 .28821 m
.45938 .28797 L
s
.45824 .31102 m
.45937 .28804 L
s
.70137 .61902 m
.71075 .61083 L
s
.45933 .28846 m
.45935 .28821 L
s
.45931 .28871 m
.45933 .28846 L
s
.70267 .61798 m
.70176 .61877 L
s
.6085 .21055 m
.60689 .21158 L
s
.45929 .28895 m
.45931 .28871 L
s
.45929 .28895 m
.45929 .28895 L
s
.45927 .28915 m
.45929 .28895 L
s
.45926 .28934 m
.45927 .28915 L
s
.60689 .21158 m
.60527 .21262 L
s
.45924 .28953 m
.45926 .28934 L
s
.45922 .28973 m
.45924 .28953 L
s
.45921 .28992 m
.45922 .28973 L
s
.60527 .21262 m
.60366 .21366 L
s
.45919 .29011 m
.45921 .28992 L
s
.45917 .29031 m
.45919 .29011 L
s
.70358 .61717 m
.70267 .61798 L
s
.45916 .2905 m
.45917 .29031 L
s
.60366 .21366 m
.60217 .21467 L
s
.60366 .21366 m
.60366 .21366 L
s
.45914 .2907 m
.45916 .2905 L
s
.45913 .29089 m
.45914 .2907 L
s
.45911 .29109 m
.45913 .29089 L
s
.4591 .29128 m
.45911 .29109 L
s
.60217 .21467 m
.60067 .21569 L
s
.4591 .29128 m
.4591 .29128 L
s
.45898 .29285 m
.4591 .29128 L
s
.54304 .61892 m
.54054 .61501 L
s
.70449 .61636 m
.70358 .61717 L
s
.60067 .21569 m
.59918 .21672 L
s
.59918 .21672 m
.59769 .21775 L
s
.6265 .61642 m
.61176 .61985 L
s
.45887 .29443 m
.45898 .29285 L
s
.59769 .21775 m
.5962 .21879 L
s
.58266 .22861 m
.59714 .21808 L
s
.7054 .61554 m
.70449 .61636 L
s
.5962 .21879 m
.59472 .21983 L
s
0 0 0 r
2 Mabswid
.67345 .3221 Mdot
0 g
.5 Mabswid
.45877 .29603 m
.45887 .29443 L
s
.59472 .21983 m
.59324 .22088 L
s
.54131 .61623 m
.52927 .59556 L
s
.7054 .61554 m
.7054 .61554 L
s
.70642 .61469 m
.7054 .61554 L
s
.59324 .22088 m
.59176 .22193 L
s
.59176 .22193 m
.59028 .22299 L
s
.54054 .61501 m
.53807 .611 L
s
.45868 .29764 m
.45877 .29603 L
s
.59028 .22299 m
.5888 .22405 L
s
.70743 .61382 m
.70642 .61469 L
s
.5888 .22405 m
.58733 .22512 L
s
.45859 .29926 m
.45868 .29764 L
s
.58733 .22512 m
.58586 .22619 L
s
.64129 .61297 m
.6265 .61642 L
s
.58586 .22619 m
.58449 .22724 L
s
.58586 .22619 m
.58586 .22619 L
s
.70845 .61295 m
.70743 .61382 L
s
.58449 .22724 m
.58313 .22829 L
s
.45852 .3009 m
.45859 .29926 L
s
.58313 .22829 m
.58177 .22935 L
s
.56887 .23974 m
.58266 .22861 L
s
.70947 .61207 m
.70845 .61295 L
s
.58177 .22935 m
.58041 .23042 L
s
.53807 .611 m
.53562 .6069 L
s
.45845 .30255 m
.45852 .3009 L
s
.58041 .23042 m
.57905 .23148 L
s
.57905 .23148 m
.5777 .23256 L
s
0 0 0 r
2 Mabswid
.73117 .4328 Mdot
0 g
.5 Mabswid
.71049 .61118 m
.70947 .61207 L
s
.45839 .30422 m
.45845 .30255 L
s
.5777 .23256 m
.57634 .23364 L
s
.57634 .23364 m
.57499 .23472 L
s
.57499 .23472 m
.57365 .23581 L
s
.45834 .3059 m
.45839 .30422 L
s
.7115 .61028 m
.71049 .61118 L
s
.64129 .61297 m
.65613 .60951 L
s
.57365 .23581 m
.5723 .2369 L
s
.71075 .61083 m
.7207 .60183 L
s
.5723 .2369 m
.57096 .238 L
s
.53562 .6069 m
.5332 .60269 L
s
.4583 .30759 m
.45834 .3059 L
s
.57096 .238 m
.56962 .2391 L
s
.71252 .60937 m
.7115 .61028 L
s
.56962 .2391 m
.56837 .24018 L
s
.56962 .2391 m
.56962 .2391 L
s
.5558 .25148 m
.56887 .23974 L
s
.56837 .24018 m
.56714 .24127 L
s
.45827 .3093 m
.4583 .30759 L
s
.56714 .24127 m
.5659 .24235 L
s
.71353 .60845 m
.71252 .60937 L
s
.5659 .24235 m
.56466 .24345 L
s
.45824 .31102 m
.45827 .3093 L
s
.56466 .24345 m
.56343 .24455 L
s
.5332 .60269 m
.53081 .59839 L
s
.71455 .60752 m
.71353 .60845 L
s
.56343 .24455 m
.5622 .24565 L
s
.67103 .60604 m
.65613 .60951 L
s
.45824 .31102 m
.45824 .31102 L
s
.45824 .31893 m
.45824 .31102 L
s
.45824 .31102 m
.45824 .31102 L
s
.4588 .33672 m
.45824 .31102 L
s
.5622 .24565 m
.56097 .24676 L
s
.56097 .24676 m
.55975 .24787 L
s
.71556 .60658 m
.71455 .60752 L
s
.55975 .24787 m
.55852 .24899 L
s
.55852 .24899 m
.5573 .25011 L
s
.5573 .25011 m
.55608 .25124 L
s
.71658 .60563 m
.71556 .60658 L
s
.55608 .25124 m
.55487 .25237 L
s
.54351 .26386 m
.5558 .25148 L
s
.53081 .59839 m
.52844 .594 L
s
.55487 .25237 m
.55374 .25348 L
s
.55487 .25237 m
.55487 .25237 L
s
.55374 .25348 m
.55263 .25459 L
s
.71759 .60467 m
.71658 .60563 L
s
.55263 .25459 m
.55151 .25571 L
s
.68599 .60256 m
.67103 .60604 L
s
.55151 .25571 m
.55039 .25683 L
s
.52927 .59556 m
.51748 .57183 L
s
.55039 .25683 m
.54928 .25796 L
s
.4584 .32712 m
.45824 .31893 L
s
.71759 .60467 m
.71759 .60467 L
s
.71873 .60368 m
.71759 .60467 L
s
.54928 .25796 m
.54817 .25909 L
s
.54817 .25909 m
.54706 .26023 L
s
.52844 .594 m
.5261 .58953 L
s
.54706 .26023 m
.54596 .26137 L
s
.71986 .60267 m
.71873 .60368 L
s
.54596 .26137 m
.54485 .26251 L
s
.54485 .26251 m
.54375 .26366 L
s
.54375 .26366 m
.54265 .26482 L
s
.53205 .27694 m
.54351 .26386 L
s
.721 .60165 m
.71986 .60267 L
s
.54265 .26482 m
.54156 .26597 L
s
.54156 .26597 m
.54055 .26711 L
s
.54156 .26597 m
.54156 .26597 L
s
.5261 .58953 m
.52378 .58496 L
s
.701 .59906 m
.68599 .60256 L
s
.54055 .26711 m
.53955 .26825 L
s
.7207 .60183 m
.73119 .59202 L
s
.53955 .26825 m
.53855 .2694 L
s
.72213 .60062 m
.721 .60165 L
s
.53855 .2694 m
.53756 .27055 L
s
.45874 .33558 m
.4584 .32712 L
s
0 0 0 r
2 Mabswid
.68775 .46598 Mdot
0 g
.5 Mabswid
.53756 .27055 m
.53656 .27171 L
s
.53656 .27171 m
.53557 .27286 L
s
.72327 .59959 m
.72213 .60062 L
s
.53557 .27286 m
.53458 .27403 L
s
.53458 .27403 m
.53359 .2752 L
s
.52378 .58496 m
.52378 .58496 L
s
.52378 .58496 m
.52352 .58445 L
s
.52352 .58445 m
.52327 .58394 L
s
.53359 .2752 m
.5326 .27637 L
s
.52327 .58394 m
.52301 .58342 L
s
.7244 .59854 m
.72327 .59959 L
s
.5326 .27637 m
.53162 .27755 L
s
.52301 .58342 m
.52276 .5829 L
s
0 0 0 r
2 Mabswid
.70624 .5044 Mdot
0 g
.5 Mabswid
.52152 .29077 m
.53205 .27694 L
s
.52276 .5829 m
.5225 .58239 L
s
.53162 .27755 m
.53064 .27873 L
s
.5225 .58239 m
.52225 .58187 L
s
.53064 .27873 m
.52966 .27991 L
s
.71607 .59555 m
.701 .59906 L
s
.52225 .58187 m
.522 .58135 L
s
.52966 .27991 m
.52877 .28108 L
s
.52966 .27991 m
.52966 .27991 L
s
.522 .58135 m
.52174 .58083 L
s
.72553 .59748 m
.7244 .59854 L
s
.52174 .58083 m
.52149 .58031 L
s
.52877 .28108 m
.52789 .28225 L
s
.52149 .58031 m
.52124 .57979 L
s
.45926 .34432 m
.45874 .33558 L
s
.52789 .28225 m
.527 .28342 L
s
.52124 .57979 m
.52098 .57927 L
s
.52098 .57927 m
.52073 .57874 L
s
.46105 .36466 m
.4588 .33672 L
s
.527 .28342 m
.52612 .2846 L
s
.72667 .59641 m
.72553 .59748 L
s
.52073 .57874 m
.52055 .57837 L
s
.52073 .57874 m
.52073 .57874 L
s
.52055 .57837 m
.52037 .57799 L
s
.52612 .2846 m
.52524 .28578 L
s
.52037 .57799 m
.52019 .57762 L
s
.52019 .57762 m
.52001 .57724 L
s
.52524 .28578 m
.52437 .28696 L
s
.52001 .57724 m
.51983 .57686 L
s
.51983 .57686 m
.51965 .57648 L
s
.52437 .28696 m
.52349 .28815 L
s
.51965 .57648 m
.51947 .57611 L
s
.7278 .59533 m
.72667 .59641 L
s
.51947 .57611 m
.51929 .57573 L
s
.52349 .28815 m
.52262 .28935 L
s
.51929 .57573 m
.51912 .57535 L
s
.51912 .57535 m
.51894 .57497 L
s
.52262 .28935 m
.52175 .29055 L
s
0 0 0 r
2 Mabswid
.59661 .38683 Mdot
0 g
.5 Mabswid
.51894 .57497 m
.51876 .57459 L
s
.51876 .57459 m
.51858 .57421 L
s
.52175 .29055 m
.52089 .29175 L
s
.512 .30541 m
.52152 .29077 L
s
.51858 .57421 m
.51845 .57392 L
s
.51858 .57421 m
.51858 .57421 L
s
.51845 .57392 m
.51831 .57364 L
s
.71607 .59555 m
.73119 .59202 L
s
.52089 .29175 m
.52002 .29296 L
s
.51831 .57364 m
.51818 .57335 L
s
.72893 .59424 m
.7278 .59533 L
s
.51818 .57335 m
.51805 .57306 L
s
.51805 .57306 m
.51791 .57278 L
s
.52002 .29296 m
.51916 .29417 L
s
.51791 .57278 m
.51778 .57249 L
s
.51778 .57249 m
.51765 .5722 L
s
.45996 .35334 m
.45926 .34432 L
s
.51916 .29417 m
.51839 .29536 L
s
.51916 .29417 m
.51916 .29417 L
s
.51765 .5722 m
.51751 .57191 L
s
.51751 .57191 m
.51738 .57162 L
s
.51748 .57183 m
.50617 .54547 L
s
.51738 .57162 m
.51725 .57134 L
s
.51839 .29536 m
.51762 .29656 L
s
.51725 .57134 m
.51712 .57105 L
s
.51712 .57105 m
.51698 .57076 L
s
.51698 .57076 m
.51688 .57053 L
s
.51698 .57076 m
.51698 .57076 L
s
.73006 .59314 m
.72893 .59424 L
s
.51762 .29656 m
.51685 .29776 L
s
.51688 .57053 m
.51678 .57031 L
s
.51678 .57031 m
.51667 .57008 L
s
.51667 .57008 m
.51657 .56986 L
s
.51657 .56986 m
.51647 .56963 L
s
.51685 .29776 m
.51609 .29896 L
s
.51647 .56963 m
.51637 .56941 L
s
.51637 .56941 m
.51626 .56918 L
s
.51626 .56918 m
.51616 .56895 L
s
.51616 .56895 m
.51606 .56873 L
s
.51609 .29896 m
.51533 .30017 L
s
.51606 .56873 m
.51596 .5685 L
s
.51596 .5685 m
.51585 .56827 L
s
.51585 .56827 m
.51575 .56805 L
s
.51533 .30017 m
.51457 .30138 L
s
.51575 .56805 m
.51493 .56623 L
s
.51575 .56805 m
.51575 .56805 L
s
.73119 .59202 m
.73006 .59314 L
s
.51457 .30138 m
.51381 .3026 L
s
.51381 .3026 m
.51306 .30382 L
s
.51493 .56623 m
.51412 .56439 L
s
.51306 .30382 m
.5123 .30505 L
s
.5123 .30505 m
.51155 .30628 L
s
.73119 .59202 m
.73119 .59202 L
s
.72907 .59166 m
.73119 .59202 L
s
.73119 .59202 m
.71175 .58854 L
s
.50364 .32098 m
.512 .30541 L
s
.51412 .56439 m
.51331 .56255 L
s
.46084 .36265 m
.45996 .35334 L
s
.51155 .30628 m
.51081 .30751 L
s
.72696 .59129 m
.72907 .59166 L
s
.51081 .30751 m
.51006 .30875 L
s
.72485 .59091 m
.72696 .59129 L
s
.51331 .56255 m
.5125 .56069 L
s
.51006 .30875 m
.50941 .30997 L
s
.51006 .30875 m
.51006 .30875 L
s
.72274 .59053 m
.72485 .59091 L
s
.50941 .30997 m
.50876 .31119 L
s
.5125 .56069 m
.5117 .55883 L
s
.72063 .59015 m
.72274 .59053 L
s
.50876 .31119 m
.50811 .31241 L
s
.50811 .31241 m
.50746 .31365 L
s
.71852 .58976 m
.72063 .59015 L
s
.5117 .55883 m
.5109 .55695 L
s
.50746 .31365 m
.50682 .31488 L
s
.71641 .58936 m
.71852 .58976 L
s
.50682 .31488 m
.50618 .31612 L
s
.7143 .58896 m
.71641 .58936 L
s
.50618 .31612 m
.50554 .31736 L
s
.5109 .55695 m
.5101 .55507 L
s
.71219 .58856 m
.7143 .58896 L
s
.50554 .31736 m
.50491 .31861 L
s
.71008 .58815 m
.71219 .58856 L
s
.71175 .58854 m
.69269 .58433 L
s
.46192 .37226 m
.46084 .36265 L
s
.50491 .31861 m
.50427 .31986 L
s
.5101 .55507 m
.50931 .55317 L
s
.70797 .58774 m
.71008 .58815 L
s
.50427 .31986 m
.50364 .32112 L
s
.70586 .58732 m
.70797 .58774 L
s
.49663 .33758 m
.50364 .32098 L
s
.46499 .39429 m
.46105 .36466 L
s
.50364 .32112 m
.50301 .32238 L
s
.50931 .55317 m
.50852 .55126 L
s
.70586 .58732 m
.70586 .58732 L
s
.70388 .58687 m
.70586 .58732 L
s
.50301 .32238 m
.50239 .32364 L
s
.7019 .58642 m
.70388 .58687 L
s
.50239 .32364 m
.50185 .32489 L
s
.50239 .32364 m
.50239 .32364 L
s
.50852 .55126 m
.50773 .54934 L
s
.50185 .32489 m
.50132 .32613 L
s
.69992 .58596 m
.7019 .58642 L
s
.50132 .32613 m
.5008 .32739 L
s
.69794 .5855 m
.69992 .58596 L
s
.50773 .54934 m
.50695 .54741 L
s
.5008 .32739 m
.50027 .32864 L
s
.69597 .58503 m
.69794 .5855 L
s
.50027 .32864 m
.49975 .32991 L
s
.69399 .58456 m
.69597 .58503 L
s
.50695 .54741 m
.50617 .54547 L
s
.49975 .32991 m
.49923 .33117 L
s
.69201 .58408 m
.69399 .58456 L
s
.4632 .38216 m
.46192 .37226 L
s
.69269 .58433 m
.67404 .57939 L
s
.49923 .33117 m
.49871 .33244 L
s
.50617 .54547 m
.50272 .53661 L
s
.50617 .54547 m
.50617 .54547 L
s
.50617 .54547 m
.49561 .517 L
s
.69003 .5836 m
.69201 .58408 L
s
.49871 .33244 m
.4982 .33371 L
s
.68806 .58312 m
.69003 .5836 L
s
.4982 .33371 m
.49769 .33499 L
s
.68608 .58263 m
.68806 .58312 L
s
.49769 .33499 m
.49718 .33628 L
s
.68411 .58213 m
.68608 .58263 L
s
.49718 .33628 m
.49667 .33756 L
s
.68213 .58164 m
.68411 .58213 L
s
.49121 .35542 m
.49663 .33758 L
s
.49667 .33756 m
.49617 .33885 L
s
.68213 .58164 m
.68213 .58164 L
s
.68027 .58111 m
.68213 .58164 L
s
.49617 .33885 m
.49576 .34012 L
s
.49617 .33885 m
.49617 .33885 L
s
.67841 .58058 m
.68027 .58111 L
s
.49576 .34012 m
.49536 .3414 L
s
.67656 .58004 m
.67841 .58058 L
s
.49536 .3414 m
.49496 .34268 L
s
.46469 .39237 m
.4632 .38216 L
s
.6747 .5795 m
.67656 .58004 L
s
.49496 .34268 m
.49456 .34396 L
s
.50272 .53661 m
.49934 .52753 L
s
.67284 .57896 m
.6747 .5795 L
s
.49456 .34396 m
.49416 .34525 L
s
.67404 .57939 m
.6558 .5737 L
s
.49416 .34525 m
.49377 .34654 L
s
.67099 .57841 m
.67284 .57896 L
s
.49377 .34654 m
.49338 .34784 L
s
.66913 .57786 m
.67099 .57841 L
s
.49338 .34784 m
.49299 .34914 L
s
.66728 .57731 m
.66913 .57786 L
s
.49299 .34914 m
.4926 .35044 L
s
.66542 .57675 m
.66728 .57731 L
s
.4926 .35044 m
.49222 .35175 L
s
.66357 .57619 m
.66542 .57675 L
s
.49222 .35175 m
.49184 .35307 L
s
.66172 .57562 m
.66357 .57619 L
s
.49184 .35307 m
.49147 .35439 L
s
.65987 .57505 m
.66172 .57562 L
s
.49934 .52753 m
.49604 .51825 L
s
.4664 .4029 m
.46469 .39237 L
s
.49147 .35439 m
.49119 .35568 L
s
.49147 .35439 m
.49147 .35439 L
s
.65987 .57505 m
.65987 .57505 L
s
.65812 .57445 m
.65987 .57505 L
s
.48778 .37475 m
.49121 .35542 L
s
.49119 .35568 m
.49092 .35698 L
s
.47054 .42498 m
.46499 .39429 L
s
.65638 .57385 m
.65812 .57445 L
s
.49092 .35698 m
.49065 .35829 L
s
.65463 .57324 m
.65638 .57385 L
s
.6558 .5737 m
.638 .56724 L
s
.49065 .35829 m
.49038 .3596 L
s
.65289 .57263 m
.65463 .57324 L
s
.49038 .3596 m
.49012 .36091 L
s
.65115 .57202 m
.65289 .57263 L
s
.49012 .36091 m
.48986 .36223 L
s
.64941 .5714 m
.65115 .57202 L
s
.48986 .36223 m
.4896 .36356 L
s
.64767 .57078 m
.64941 .5714 L
s
.49604 .51825 m
.49282 .50875 L
s
.4896 .36356 m
.48934 .36489 L
s
.64593 .57015 m
.64767 .57078 L
s
.46835 .41377 m
.4664 .4029 L
s
.49561 .517 m
.48601 .487 L
s
.48934 .36489 m
.48909 .36622 L
s
.64419 .56952 m
.64593 .57015 L
s
.48909 .36622 m
.48884 .36756 L
s
.64245 .56889 m
.64419 .56952 L
s
.48884 .36756 m
.4886 .3689 L
s
.64071 .56826 m
.64245 .56889 L
s
.4886 .3689 m
.48835 .37025 L
s
.63898 .56762 m
.64071 .56826 L
s
.48835 .37025 m
.48822 .37157 L
s
.48835 .37025 m
.48835 .37025 L
s
.63898 .56762 m
.63898 .56762 L
s
.63734 .56695 m
.63898 .56762 L
s
.638 .56724 m
.62066 .55996 L
s
.48822 .37157 m
.48809 .3729 L
s
.63571 .56628 m
.63734 .56695 L
s
.49282 .50875 m
.48969 .49904 L
s
.48809 .3729 m
.48796 .37423 L
s
.63407 .56561 m
.63571 .56628 L
s
.47054 .42498 m
.46835 .41377 L
s
.48796 .37423 m
.48783 .37557 L
s
.63244 .56493 m
.63407 .56561 L
s
.48694 .396 m
.48778 .37475 L
s
.48783 .37557 m
.48771 .37691 L
s
.63081 .56425 m
.63244 .56493 L
s
.48771 .37691 m
.48759 .37826 L
s
.62918 .56357 m
.63081 .56425 L
s
.48759 .37826 m
.48747 .37961 L
s
.62755 .56288 m
.62918 .56357 L
s
.62592 .56219 m
.62755 .56288 L
s
.48747 .37961 m
.48736 .38097 L
s
.48969 .49904 m
.48665 .48913 L
s
.62429 .56149 m
.62592 .56219 L
s
.48736 .38097 m
.48725 .38233 L
s
.62266 .5608 m
.62429 .56149 L
s
.48725 .38233 m
.48714 .3837 L
s
.47054 .42498 m
.47054 .42498 L
s
.47214 .42457 m
.47054 .42498 L
s
.47293 .43626 m
.47054 .42498 L
s
.4776 .45611 m
.47054 .42498 L
s
.62103 .5601 m
.62266 .5608 L
s
.48714 .3837 m
.48704 .38507 L
s
.6194 .55939 m
.62103 .5601 L
s
.62066 .55996 m
.60383 .55183 L
s
.48704 .38507 m
.48694 .38645 L
s
.47374 .42415 m
.47214 .42457 L
s
.6194 .55939 m
.6194 .55939 L
s
.61787 .55866 m
.6194 .55939 L
s
.48694 .38645 m
.48695 .3878 L
s
.48694 .38645 m
.48694 .38645 L
s
.48665 .48913 m
.48369 .479 L
s
.61635 .55793 m
.61787 .55866 L
s
.48695 .3878 m
.48697 .38916 L
s
.47534 .42373 m
.47374 .42415 L
s
.48601 .487 m
.4776 .45611 L
s
.61482 .55719 m
.61635 .55793 L
s
.48697 .38916 m
.48699 .39052 L
s
.47545 .44729 m
.47293 .43626 L
s
.61329 .55645 m
.61482 .55719 L
s
.48699 .39052 m
.48702 .39189 L
s
.47694 .42331 m
.47534 .42373 L
s
.61176 .5557 m
.61329 .55645 L
s
.48369 .479 m
.48084 .46865 L
s
.48702 .39189 m
.48705 .39326 L
s
.61024 .55496 m
.61176 .5557 L
s
.48705 .39326 m
.48708 .39464 L
s
.47809 .45808 m
.47545 .44729 L
s
.47855 .42289 m
.47694 .42331 L
s
.60871 .55421 m
.61024 .55496 L
s
.48084 .46865 m
.47809 .45808 L
s
.48708 .39464 m
.48712 .39602 L
s
.60719 .55345 m
.60871 .55421 L
s
.48978 .41995 m
.48694 .396 L
s
.48712 .39602 m
.48716 .39741 L
s
.60567 .5527 m
.60719 .55345 L
s
.48015 .42247 m
.47855 .42289 L
s
.48716 .39741 m
.4872 .3988 L
s
.60414 .55193 m
.60567 .5527 L
s
.60262 .55117 m
.60414 .55193 L
s
.4872 .3988 m
.48725 .4002 L
s
.60383 .55183 m
.58754 .54279 L
s
.48175 .42205 m
.48015 .42247 L
s
.6011 .5504 m
.60262 .55117 L
s
.48725 .4002 m
.4873 .4016 L
s
.6011 .5504 m
.6011 .5504 L
s
.59968 .54961 m
.6011 .5504 L
s
.4873 .4016 m
.48735 .40301 L
s
.48336 .42163 m
.48175 .42205 L
s
.59825 .54882 m
.59968 .54961 L
s
.48735 .40301 m
.48753 .40439 L
s
.48735 .40301 m
.48735 .40301 L
s
.59683 .54802 m
.59825 .54882 L
s
.48753 .40439 m
.48772 .40578 L
s
.5954 .54721 m
.59683 .54802 L
s
.48496 .42121 m
.48336 .42163 L
s
.48772 .40578 m
.48791 .40717 L
s
.59398 .54641 m
.5954 .54721 L
s
.48791 .40717 m
.4881 .40856 L
s
.59256 .5456 m
.59398 .54641 L
s
.4881 .40856 m
.4883 .40997 L
s
.48657 .42079 m
.48496 .42121 L
s
.59114 .54479 m
.59256 .5456 L
s
.4883 .40997 m
.4885 .41138 L
s
.58972 .54397 m
.59114 .54479 L
s
.5883 .54315 m
.58972 .54397 L
s
.4885 .41138 m
.4887 .41279 L
s
.48817 .42037 m
.48657 .42079 L
s
.58688 .54233 m
.5883 .54315 L
s
.4887 .41279 m
.48891 .41421 L
s
.58754 .54279 m
.57186 .53277 L
s
.58546 .54151 m
.58688 .54233 L
s
.48891 .41421 m
.48912 .41564 L
s
.58405 .54068 m
.58546 .54151 L
s
.48912 .41564 m
.48934 .41707 L
s
.48978 .41995 m
.48817 .42037 L
s
.58405 .54068 m
.58405 .54068 L
s
.58272 .53983 m
.58405 .54068 L
s
.48934 .41707 m
.48956 .4185 L
s
.5814 .53897 m
.58272 .53983 L
s
.48956 .4185 m
.48978 .41995 L
s
.58008 .53811 m
.5814 .53897 L
s
.48978 .41995 m
.48978 .41995 L
s
.48978 .41995 m
.49014 .42136 L
s
.49665 .44332 m
.48978 .41995 L
s
.57876 .53725 m
.58008 .53811 L
s
.49014 .42136 m
.4905 .42276 L
s
.57744 .53638 m
.57876 .53725 L
s
.57612 .53552 m
.57744 .53638 L
s
.4905 .42276 m
.49087 .42416 L
s
.5748 .53464 m
.57612 .53552 L
s
.49087 .42416 m
.49123 .42556 L
s
.57348 .53377 m
.5748 .53464 L
s
.49123 .42556 m
.4916 .42695 L
s
.57217 .53289 m
.57348 .53377 L
s
.4916 .42695 m
.49197 .42834 L
s
.57186 .53277 m
.55684 .52167 L
s
.57085 .53201 m
.57217 .53289 L
s
.49197 .42834 m
.49235 .42973 L
s
.56954 .53112 m
.57085 .53201 L
s
.56823 .53024 m
.56954 .53112 L
s
.49235 .42973 m
.49272 .43111 L
s
.56823 .53024 m
.56823 .53024 L
s
.567 .52932 m
.56823 .53024 L
s
.49272 .43111 m
.4931 .43249 L
s
.56578 .52841 m
.567 .52932 L
s
.4931 .43249 m
.49347 .43386 L
s
.56457 .52749 m
.56578 .52841 L
s
.49347 .43386 m
.49385 .43523 L
s
.56335 .52657 m
.56457 .52749 L
s
.49385 .43523 m
.49424 .4366 L
s
.56213 .52564 m
.56335 .52657 L
s
.49424 .4366 m
.49474 .43793 L
s
.49424 .4366 m
.49424 .4366 L
s
.56092 .52471 m
.56213 .52564 L
s
.49474 .43793 m
.49525 .43926 L
s
.5597 .52378 m
.56092 .52471 L
s
.49525 .43926 m
.49577 .44058 L
s
.55849 .52285 m
.5597 .52378 L
s
.49577 .44058 m
.49628 .4419 L
s
.55727 .52191 m
.55849 .52285 L
s
.49628 .4419 m
.49679 .44322 L
s
.55684 .52167 m
.54259 .50937 L
s
.55606 .52097 m
.55727 .52191 L
s
.50593 .46313 m
.49665 .44332 L
s
.55485 .52003 m
.55606 .52097 L
s
.49679 .44322 m
.49731 .44453 L
s
.55364 .51908 m
.55485 .52003 L
s
.49731 .44453 m
.49783 .44584 L
s
.55364 .51908 m
.55364 .51908 L
s
.55253 .51811 m
.55364 .51908 L
s
.49783 .44584 m
.49835 .44714 L
s
.55141 .51713 m
.55253 .51811 L
s
.49835 .44714 m
.49887 .44844 L
s
.5503 .51615 m
.55141 .51713 L
s
.49887 .44844 m
.4994 .44974 L
s
.54918 .51517 m
.5503 .51615 L
s
.4994 .44974 m
.49992 .45104 L
s
.54807 .51419 m
.54918 .51517 L
s
.49992 .45104 m
.50045 .45233 L
s
.50045 .45233 m
.50109 .45359 L
s
.50045 .45233 m
.50045 .45233 L
s
.54696 .5132 m
.54807 .51419 L
s
.54585 .51221 m
.54696 .5132 L
s
.50109 .45359 m
.50174 .45484 L
s
.54474 .51122 m
.54585 .51221 L
s
.50174 .45484 m
.50238 .4561 L
s
.54363 .51022 m
.54474 .51122 L
s
.50238 .4561 m
.50303 .45734 L
s
.54253 .50922 m
.54363 .51022 L
s
.54259 .50937 m
.52923 .49569 L
s
.54142 .50822 m
.54253 .50922 L
s
.50303 .45734 m
.50368 .45859 L
s
.54032 .50721 m
.54142 .50822 L
s
.50368 .45859 m
.50433 .45983 L
s
.54032 .50721 m
.54032 .50721 L
s
.53931 .50618 m
.54032 .50721 L
s
.50433 .45983 m
.50498 .46107 L
s
.5383 .50514 m
.53931 .50618 L
s
.50498 .46107 m
.50564 .46231 L
s
.53729 .50411 m
.5383 .50514 L
s
.51692 .4804 m
.50593 .46313 L
s
.50564 .46231 m
.50629 .46354 L
s
.53629 .50306 m
.53729 .50411 L
s
.50629 .46354 m
.50695 .46477 L
s
.50695 .46477 m
.50761 .46599 L
s
.53528 .50202 m
.53629 .50306 L
s
.50761 .46599 m
.50827 .46721 L
s
.53428 .50097 m
.53528 .50202 L
s
.50827 .46721 m
.50904 .4684 L
s
.50827 .46721 m
.50827 .46721 L
s
.53327 .49992 m
.53428 .50097 L
s
.50904 .4684 m
.50981 .46959 L
s
.53227 .49887 m
.53327 .49992 L
s
.50981 .46959 m
.51058 .47078 L
s
.53127 .49781 m
.53227 .49887 L
s
.53027 .49675 m
.53127 .49781 L
s
.51058 .47078 m
.51135 .47196 L
s
.52928 .49569 m
.53027 .49675 L
s
.52923 .49569 m
.51692 .4804 L
s
.52828 .49462 m
.52928 .49569 L
s
.51135 .47196 m
.51212 .47314 L
s
.52828 .49462 m
.52828 .49462 L
s
.52738 .49353 m
.52828 .49462 L
s
.51212 .47314 m
.5129 .47431 L
s
.52648 .49243 m
.52738 .49353 L
s
.5129 .47431 m
.51367 .47549 L
s
.52559 .49133 m
.52648 .49243 L
s
.51367 .47549 m
.51445 .47665 L
s
.51445 .47665 m
.51523 .47782 L
s
.52469 .49023 m
.52559 .49133 L
s
.51523 .47782 m
.51601 .47898 L
s
.51758 .4813 m
.51846 .48243 L
s
.51758 .4813 m
.51758 .4813 L
s
.51679 .48014 m
.51758 .4813 L
s
.51601 .47898 m
.51679 .48014 L
s
.5238 .48913 m
.52469 .49023 L
s
.51846 .48243 m
.51935 .48355 L
s
.5229 .48802 m
.5238 .48913 L
s
.51935 .48355 m
.52023 .48467 L
s
.52201 .4869 m
.5229 .48802 L
s
.52023 .48467 m
.52112 .48579 L
s
.52112 .48579 m
.52201 .4869 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{176, 151.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 175}, {150.75, 0}} -> {-0.000653325, 0.0415057, \
0.00569916, 0.00569916}},
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
CircleOfRays[35,NumberOfRays->7],
Move[SolidCornerCube[50,37.5],{50,0,0}],
Boundary[150,GraphicDesign->Off]},PlotType->TopView,AspectRatio->1];\
\>", \
"Input",
  CellTags->"SolidCornerCube"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0108844 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.56803 .02381 m
.56803 .10317 L
.56803 .18254 L
.56803 .2619 L
.56803 .34127 L
.56803 .42063 L
.56803 .5 L
.56803 .57937 L
.56803 .65873 L
.56803 .7381 L
.56803 .81746 L
.56803 .89683 L
.56803 .97619 L
.56803 .97619 L
.56803 .89683 L
.56803 .81746 L
.56803 .7381 L
.56803 .65873 L
.56803 .57937 L
.56803 .5 L
.56803 .42063 L
.56803 .34127 L
.56803 .2619 L
.56803 .18254 L
.56803 .10317 L
.56803 .02381 L
.56803 .02381 L
s
.56803 .5 m
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
.56803 .5 L
s
.97619 .5 m
.78378 .08761 L
.76602 .1011 L
.74883 .1158 L
.73222 .13174 L
.71619 .14894 L
.70077 .16743 L
.68598 .18728 L
.67186 .20856 L
.65845 .23137 L
.64581 .25583 L
.63402 .28211 L
.62318 .31043 L
.61343 .34109 L
.60497 .37451 L
.5981 .41133 L
.59328 .45255 L
.59137 .5 L
.59137 .5 L
.59328 .54745 L
.5981 .58867 L
.60497 .62549 L
.61343 .65891 L
.62318 .68957 L
.63402 .71789 L
.64581 .74417 L
.65845 .76863 L
.67186 .79144 L
.68598 .81272 L
.70077 .83257 L
.71619 .85106 L
.73222 .86826 L
.74883 .8842 L
.76602 .8989 L
.78378 .91239 L
.97619 .5 L
.97619 .5 L
s
.97619 .5 m
.78378 .5 L
.76602 .47423 L
.74883 .44845 L
.73222 .42268 L
.71619 .3969 L
.70077 .37113 L
.68598 .34535 L
.67186 .31958 L
.65845 .2938 L
.64581 .26803 L
.63402 .24225 L
.62318 .21648 L
.61343 .19071 L
.60497 .16493 L
.5981 .13916 L
.59328 .11338 L
.59137 .08761 L
.59137 .08761 L
.59328 .06594 L
.5981 .05048 L
.60497 .03944 L
.61343 .03179 L
.62318 .02691 L
.63402 .02437 L
.64581 .02386 L
.65845 .02518 L
.67186 .02814 L
.68598 .03264 L
.70077 .03856 L
.71619 .04584 L
.73222 .05442 L
.74883 .06426 L
.76602 .07532 L
.78378 .08761 L
.97619 .5 L
.97619 .5 L
s
.97619 .5 m
.78378 .91239 L
.76602 .92468 L
.74883 .93574 L
.73222 .94558 L
.71619 .95416 L
.70077 .96144 L
.68598 .96736 L
.67186 .97186 L
.65845 .97482 L
.64581 .97614 L
.63402 .97563 L
.62318 .97309 L
.61343 .96821 L
.60497 .96056 L
.5981 .94952 L
.59328 .93406 L
.59137 .91239 L
.59137 .91239 L
.59328 .88662 L
.5981 .86084 L
.60497 .83507 L
.61343 .80929 L
.62318 .78352 L
.63402 .75775 L
.64581 .73197 L
.65845 .7062 L
.67186 .68042 L
.68598 .65465 L
.70077 .62887 L
.71619 .6031 L
.73222 .57732 L
.74883 .55155 L
.76602 .52577 L
.78378 .5 L
.97619 .5 L
.97619 .5 L
s
.56803 .97619 m
.56803 .97212 L
.56803 .95996 L
.56803 .93994 L
.56803 .91239 L
.56803 .87779 L
.56803 .83672 L
.56803 .78989 L
.56803 .7381 L
.56803 .68223 L
.56803 .62325 L
.56803 .56216 L
.56803 .5 L
.56803 .43784 L
.56803 .37675 L
.56803 .31777 L
.56803 .2619 L
.56803 .21011 L
.56803 .16328 L
.56803 .12221 L
.56803 .08761 L
.56803 .06006 L
.56803 .04004 L
.56803 .02788 L
.56803 .02381 L
.56803 .02788 L
.56803 .04004 L
.56803 .06006 L
.56803 .08761 L
.56803 .12221 L
.56803 .16328 L
.56803 .21011 L
.56803 .2619 L
.56803 .31777 L
.56803 .37675 L
.56803 .43784 L
.56803 .5 L
.56803 .56216 L
.56803 .62325 L
.56803 .68223 L
.56803 .7381 L
.56803 .78989 L
.56803 .83672 L
.56803 .87779 L
.56803 .91239 L
.56803 .93994 L
.56803 .95996 L
.56803 .97212 L
.56803 .97619 L
s
.039 .916 .04 r
.02381 .83333 m
.56803 .83333 L
s
0 0 0 r
2 Mabswid
.56803 .83333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .70783 m
.56803 .70783 L
s
0 0 0 r
2 Mabswid
.56803 .70783 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42583 m
.56803 .42583 L
s
0 0 0 r
2 Mabswid
.56803 .42583 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19968 m
.56803 .19968 L
s
0 0 0 r
2 Mabswid
.56803 .19968 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19968 m
.56803 .19968 L
s
0 0 0 r
2 Mabswid
.56803 .19968 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42583 m
.56803 .42583 L
s
0 0 0 r
2 Mabswid
.56803 .42583 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .70783 m
.56803 .70783 L
s
0 0 0 r
2 Mabswid
.56803 .70783 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .83333 m
.74291 .83333 L
s
0 0 0 r
2 Mabswid
.74291 .83333 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .70783 m
.72544 .70783 L
s
0 0 0 r
2 Mabswid
.72544 .70783 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .42583 m
.79297 .42583 L
s
0 0 0 r
2 Mabswid
.79297 .42583 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .19968 m
.70757 .19968 L
s
0 0 0 r
2 Mabswid
.70757 .19968 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .19968 m
.82445 .19968 L
s
0 0 0 r
2 Mabswid
.82445 .19968 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .42583 m
.71357 .42583 L
s
0 0 0 r
2 Mabswid
.71357 .42583 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .70783 m
.76559 .70783 L
s
0 0 0 r
2 Mabswid
.76559 .70783 Mdot
.039 .916 .04 r
.5 Mabswid
.74291 .83333 m
.82067 .5 L
s
0 0 0 r
2 Mabswid
.82067 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.72544 .70783 m
.8224 .29217 L
s
0 0 0 r
2 Mabswid
.8224 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.79297 .42583 m
.82758 .57417 L
s
0 0 0 r
2 Mabswid
.82758 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.70757 .19968 m
.83607 .7505 L
s
0 0 0 r
2 Mabswid
.83607 .7505 Mdot
.039 .916 .04 r
.5 Mabswid
.82445 .19968 m
.83607 .2495 L
s
0 0 0 r
2 Mabswid
.83607 .2495 Mdot
.039 .916 .04 r
.5 Mabswid
.71357 .42583 m
.82758 .42583 L
s
0 0 0 r
2 Mabswid
.82758 .42583 Mdot
.039 .916 .04 r
.5 Mabswid
.76559 .70783 m
.8224 .70783 L
s
0 0 0 r
2 Mabswid
.8224 .70783 Mdot
.039 .916 .04 r
.5 Mabswid
.82067 .5 m
.74291 .16667 L
s
0 0 0 r
2 Mabswid
.74291 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.8224 .29217 m
.76559 .29217 L
s
0 0 0 r
2 Mabswid
.76559 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.82758 .57417 m
.71357 .57417 L
s
0 0 0 r
2 Mabswid
.71357 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.83607 .7505 m
.82445 .80032 L
s
0 0 0 r
2 Mabswid
.82445 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.83607 .2495 m
.70757 .80032 L
s
0 0 0 r
2 Mabswid
.70757 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.82758 .42583 m
.79297 .57417 L
s
0 0 0 r
2 Mabswid
.79297 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.8224 .70783 m
.72544 .29217 L
s
0 0 0 r
2 Mabswid
.72544 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.74291 .16667 m
.56803 .16667 L
s
0 0 0 r
2 Mabswid
.56803 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.76559 .29217 m
.56803 .29217 L
s
0 0 0 r
2 Mabswid
.56803 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.71357 .57417 m
.56803 .57417 L
s
0 0 0 r
2 Mabswid
.56803 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.82445 .80032 m
.56803 .80032 L
s
0 0 0 r
2 Mabswid
.56803 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.70757 .80032 m
.56803 .80032 L
s
0 0 0 r
2 Mabswid
.56803 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.79297 .57417 m
.56803 .57417 L
s
0 0 0 r
2 Mabswid
.56803 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.72544 .29217 m
.56803 .29217 L
s
0 0 0 r
2 Mabswid
.56803 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .16667 m
.02381 .16667 L
s
0 0 0 r
2 Mabswid
.02381 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .29217 m
.02381 .29217 L
s
0 0 0 r
2 Mabswid
.02381 .29217 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .57417 m
.02381 .57417 L
s
0 0 0 r
2 Mabswid
.02381 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .80032 m
.02381 .80032 L
s
0 0 0 r
2 Mabswid
.02381 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .80032 m
.02381 .80032 L
s
0 0 0 r
2 Mabswid
.02381 .80032 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .57417 m
.02381 .57417 L
s
0 0 0 r
2 Mabswid
.02381 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.56803 .29217 m
.02381 .29217 L
s
0 0 0 r
2 Mabswid
.02381 .29217 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{163, 163},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 162}, {162, 0}} -> {-2.18795, -26.2503, 0.567133, \
0.324078}},
  CellTags->"SolidCornerCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AnamorphicPrisms[aperture, bigedgethickness, firstangle, \
prismspacing, secondangle, exitoffset, options]\
\>", "Subsection",
  CellTags->"AnamorphicPrisms"],

Cell[CellGroupData[{

Cell["?AnamorphicPrisms", "Input",
  CellTags->"AnamorphicPrisms"],

Cell[BoxData[
    \("AnamorphicPrisms[aperture, bigedgethickness, firstangle, prismspacing, \
secondangle, exitoffset, options] specifies a pair of wedge-shaped prism \
elements that are commonly used to correct the asymmetric beam shape of a \
laser diode- from elliptical to near circular in shape. \n\nAnamorphicPrisms \
is created with the first prism surface positioned at the origin with a tilt \
given by firstangle and the second prism located offset along the postive \
x-axis with a lateral offset given by exitoffset and a tilt given by \
secondangle. The aperture argument may denote a circle, rectangle, or polygon \
depending on the number and type of elements listed by it. The \
bigedgethickness specifies the thickness of the larger prism edge. The \
firstangle and secondangle parameters denote the amount of tilt in the x-y \
plane given to the first and second prism elements. The prismspacing argument \
gives the gap between the two prism elements. Finally, the exitoffset \
parameter indicates the distance between the last prism's exit surface center \
and the x-axis (incoming optical axis). See also: Prism, WedgePrism, \
DovePrism, PentaPrism, and RhomboidalPrism."\)], "Print",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[AnamorphicPrisms[{12,12}, 8.5, 21.2, 1.5, 6.0, \
5.3],PlotType->TopView]\
\>", "Input",
  CellTags->"AnamorphicPrisms"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72802 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.260082 0.0443437 0.51696 0.0443437 [
[ 0 0 0 0 ]
[ 1 .72802 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.37522 .18692 m
.02381 .32323 L
.06319 .35552 L
.39126 .22827 L
.37522 .18692 L
F
.39126 .22827 m
.06319 .35552 L
.10257 .38781 L
.40729 .26961 L
.39126 .22827 L
F
.40729 .26961 m
.10257 .38781 L
.14195 .42009 L
.42333 .31095 L
.40729 .26961 L
F
.42333 .31095 m
.14195 .42009 L
.18132 .45238 L
.43937 .3523 L
.42333 .31095 L
F
.43937 .3523 m
.18132 .45238 L
.2207 .48467 L
.4554 .39364 L
.43937 .3523 L
F
.4554 .39364 m
.2207 .48467 L
.26008 .51696 L
.47144 .43498 L
.4554 .39364 L
F
.47144 .43498 m
.26008 .51696 L
.29946 .54925 L
.48747 .47632 L
.47144 .43498 L
F
.48747 .47632 m
.29946 .54925 L
.33884 .58154 L
.50351 .51767 L
.48747 .47632 L
F
.50351 .51767 m
.33884 .58154 L
.37822 .61383 L
.51954 .55901 L
.50351 .51767 L
F
.51954 .55901 m
.37822 .61383 L
.4176 .64611 L
.53558 .60035 L
.51954 .55901 L
F
.53558 .60035 m
.4176 .64611 L
.45698 .6784 L
.55162 .64169 L
.53558 .60035 L
F
.55162 .64169 m
.45698 .6784 L
.49635 .71069 L
.56765 .68304 L
.55162 .64169 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37522 .18692 m
.39126 .22827 L
.40729 .26961 L
.42333 .31095 L
.43937 .3523 L
.4554 .39364 L
.47144 .43498 L
.48747 .47632 L
.50351 .51767 L
.51954 .55901 L
.53558 .60035 L
.55162 .64169 L
.56765 .68304 L
.49635 .71069 L
.45698 .6784 L
.4176 .64611 L
.37822 .61383 L
.33884 .58154 L
.29946 .54925 L
.26008 .51696 L
.2207 .48467 L
.18132 .45238 L
.14195 .42009 L
.10257 .38781 L
.06319 .35552 L
.02381 .32323 L
.37522 .18692 L
s
.5 g
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
.47144 .43498 m
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
.47144 .43498 L
F
0 g
.47144 .43498 m
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.47144 .43498 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.26008 .51696 L
.47144 .43498 L
s
.5 g
.97619 .54654 m
.60133 .58594 L
.6216 .53922 L
.97156 .50244 L
.97619 .54654 L
F
.97156 .50244 m
.6216 .53922 L
.64186 .49251 L
.96692 .45834 L
.97156 .50244 L
F
.96692 .45834 m
.64186 .49251 L
.66213 .44579 L
.96228 .41424 L
.96692 .45834 L
F
.96228 .41424 m
.66213 .44579 L
.68239 .39907 L
.95765 .37014 L
.96228 .41424 L
F
.95765 .37014 m
.68239 .39907 L
.70266 .35235 L
.95301 .32604 L
.95765 .37014 L
F
.95301 .32604 m
.70266 .35235 L
.72292 .30563 L
.94838 .28194 L
.95301 .32604 L
F
.94838 .28194 m
.72292 .30563 L
.74319 .25892 L
.94374 .23784 L
.94838 .28194 L
F
.94374 .23784 m
.74319 .25892 L
.76345 .2122 L
.93911 .19374 L
.94374 .23784 L
F
.93911 .19374 m
.76345 .2122 L
.78372 .16548 L
.93447 .14964 L
.93911 .19374 L
F
.93447 .14964 m
.78372 .16548 L
.80398 .11876 L
.92984 .10554 L
.93447 .14964 L
F
.92984 .10554 m
.80398 .11876 L
.82425 .07205 L
.9252 .06143 L
.92984 .10554 L
F
.9252 .06143 m
.82425 .07205 L
.84451 .02533 L
.92057 .01733 L
.9252 .06143 L
F
0 g
.97619 .54654 m
.97156 .50244 L
.96692 .45834 L
.96228 .41424 L
.95765 .37014 L
.95301 .32604 L
.94838 .28194 L
.94374 .23784 L
.93911 .19374 L
.93447 .14964 L
.92984 .10554 L
.9252 .06143 L
.92057 .01733 L
.84451 .02533 L
.82425 .07205 L
.80398 .11876 L
.78372 .16548 L
.76345 .2122 L
.74319 .25892 L
.72292 .30563 L
.70266 .35235 L
.68239 .39907 L
.66213 .44579 L
.64186 .49251 L
.6216 .53922 L
.60133 .58594 L
.97619 .54654 L
s
.5 g
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
.94838 .28194 m
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
.94838 .28194 L
F
0 g
.94838 .28194 m
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.94838 .28194 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.72292 .30563 L
.94838 .28194 L
s
.37522 .18692 m
.02381 .32323 L
.06319 .35552 L
.39126 .22827 L
.37522 .18692 L
s
.39126 .22827 m
.06319 .35552 L
.10257 .38781 L
.40729 .26961 L
.39126 .22827 L
s
.40729 .26961 m
.10257 .38781 L
.14195 .42009 L
.42333 .31095 L
.40729 .26961 L
s
.42333 .31095 m
.14195 .42009 L
.18132 .45238 L
.43937 .3523 L
.42333 .31095 L
s
.43937 .3523 m
.18132 .45238 L
.2207 .48467 L
.4554 .39364 L
.43937 .3523 L
s
.4554 .39364 m
.2207 .48467 L
.26008 .51696 L
.47144 .43498 L
.4554 .39364 L
s
.47144 .43498 m
.26008 .51696 L
.29946 .54925 L
.48747 .47632 L
.47144 .43498 L
s
.48747 .47632 m
.29946 .54925 L
.33884 .58154 L
.50351 .51767 L
.48747 .47632 L
s
.50351 .51767 m
.33884 .58154 L
.37822 .61383 L
.51954 .55901 L
.50351 .51767 L
s
.51954 .55901 m
.37822 .61383 L
.4176 .64611 L
.53558 .60035 L
.51954 .55901 L
s
.53558 .60035 m
.4176 .64611 L
.45698 .6784 L
.55162 .64169 L
.53558 .60035 L
s
.55162 .64169 m
.45698 .6784 L
.49635 .71069 L
.56765 .68304 L
.55162 .64169 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.49635 .71069 L
.56765 .68304 L
.56765 .68304 L
s
.56765 .68304 m
.49635 .71069 L
.45698 .6784 L
.55162 .64169 L
.56765 .68304 L
s
.55162 .64169 m
.45698 .6784 L
.4176 .64611 L
.53558 .60035 L
.55162 .64169 L
s
.53558 .60035 m
.4176 .64611 L
.37822 .61383 L
.51954 .55901 L
.53558 .60035 L
s
.51954 .55901 m
.37822 .61383 L
.33884 .58154 L
.50351 .51767 L
.51954 .55901 L
s
.50351 .51767 m
.33884 .58154 L
.29946 .54925 L
.48747 .47632 L
.50351 .51767 L
s
.48747 .47632 m
.29946 .54925 L
.26008 .51696 L
.47144 .43498 L
.48747 .47632 L
s
.47144 .43498 m
.26008 .51696 L
.2207 .48467 L
.4554 .39364 L
.47144 .43498 L
s
.4554 .39364 m
.2207 .48467 L
.18132 .45238 L
.43937 .3523 L
.4554 .39364 L
s
.43937 .3523 m
.18132 .45238 L
.14195 .42009 L
.42333 .31095 L
.43937 .3523 L
s
.42333 .31095 m
.14195 .42009 L
.10257 .38781 L
.40729 .26961 L
.42333 .31095 L
s
.40729 .26961 m
.10257 .38781 L
.06319 .35552 L
.39126 .22827 L
.40729 .26961 L
s
.39126 .22827 m
.06319 .35552 L
.02381 .32323 L
.37522 .18692 L
.39126 .22827 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.37522 .18692 m
.02381 .32323 L
.02381 .32323 L
.37522 .18692 L
.37522 .18692 L
s
.97619 .54654 m
.60133 .58594 L
.6216 .53922 L
.97156 .50244 L
.97619 .54654 L
s
.97156 .50244 m
.6216 .53922 L
.64186 .49251 L
.96692 .45834 L
.97156 .50244 L
s
.96692 .45834 m
.64186 .49251 L
.66213 .44579 L
.96228 .41424 L
.96692 .45834 L
s
.96228 .41424 m
.66213 .44579 L
.68239 .39907 L
.95765 .37014 L
.96228 .41424 L
s
.95765 .37014 m
.68239 .39907 L
.70266 .35235 L
.95301 .32604 L
.95765 .37014 L
s
.95301 .32604 m
.70266 .35235 L
.72292 .30563 L
.94838 .28194 L
.95301 .32604 L
s
.94838 .28194 m
.72292 .30563 L
.74319 .25892 L
.94374 .23784 L
.94838 .28194 L
s
.94374 .23784 m
.74319 .25892 L
.76345 .2122 L
.93911 .19374 L
.94374 .23784 L
s
.93911 .19374 m
.76345 .2122 L
.78372 .16548 L
.93447 .14964 L
.93911 .19374 L
s
.93447 .14964 m
.78372 .16548 L
.80398 .11876 L
.92984 .10554 L
.93447 .14964 L
s
.92984 .10554 m
.80398 .11876 L
.82425 .07205 L
.9252 .06143 L
.92984 .10554 L
s
.9252 .06143 m
.82425 .07205 L
.84451 .02533 L
.92057 .01733 L
.9252 .06143 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.84451 .02533 L
.92057 .01733 L
.92057 .01733 L
s
.92057 .01733 m
.84451 .02533 L
.82425 .07205 L
.9252 .06143 L
.92057 .01733 L
s
.9252 .06143 m
.82425 .07205 L
.80398 .11876 L
.92984 .10554 L
.9252 .06143 L
s
.92984 .10554 m
.80398 .11876 L
.78372 .16548 L
.93447 .14964 L
.92984 .10554 L
s
.93447 .14964 m
.78372 .16548 L
.76345 .2122 L
.93911 .19374 L
.93447 .14964 L
s
.93911 .19374 m
.76345 .2122 L
.74319 .25892 L
.94374 .23784 L
.93911 .19374 L
s
.94374 .23784 m
.74319 .25892 L
.72292 .30563 L
.94838 .28194 L
.94374 .23784 L
s
.94838 .28194 m
.72292 .30563 L
.70266 .35235 L
.95301 .32604 L
.94838 .28194 L
s
.95301 .32604 m
.70266 .35235 L
.68239 .39907 L
.95765 .37014 L
.95301 .32604 L
s
.95765 .37014 m
.68239 .39907 L
.66213 .44579 L
.96228 .41424 L
.95765 .37014 L
s
.96228 .41424 m
.66213 .44579 L
.64186 .49251 L
.96692 .45834 L
.96228 .41424 L
s
.96692 .45834 m
.64186 .49251 L
.6216 .53922 L
.97156 .50244 L
.96692 .45834 L
s
.97156 .50244 m
.6216 .53922 L
.60133 .58594 L
.97619 .54654 L
.97156 .50244 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
.97619 .54654 m
.60133 .58594 L
.60133 .58594 L
.97619 .54654 L
.97619 .54654 L
s
0 0 m
1 0 L
1 .72802 L
0 .72802 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{213, 155},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 212}, {154, 0}} -> {-5.89016, -11.6581, 0.106609, \
0.106609}},
  CellTags->"AnamorphicPrisms"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"AnamorphicPrisms", "[", 
              RowBox[{\({12, 12}\), ",", 
                StyleBox["8.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], ",", 
                StyleBox["21.200000000000001`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3], ",", 
                StyleBox["1.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], ",", 
                StyleBox["6.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], ",", 
                StyleBox["5.29999999999999982`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2]}], "]"}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"AnamorphicPrisms"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"AnamorphicPrisms"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86741 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0 1.02053 -0.0400143 1.02053 [
[ 0 0 0 0 ]
[ 1 .86741 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86741 L
0 .86741 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.62242 .44711 m
.6232 .47189 L
s
.65856 .42266 m
.62242 .44711 L
s
.58794 .4431 m
.62242 .44711 L
s
.63564 .41038 m
.58794 .4431 L
s
.55332 .43909 m
.58794 .4431 L
s
.61243 .39795 m
.55332 .43909 L
s
.51856 .43505 m
.55332 .43909 L
s
.58892 .38537 m
.51856 .43505 L
s
.48365 .431 m
.51856 .43505 L
s
.6232 .47189 m
.62399 .49703 L
s
.65961 .44759 m
.6232 .47189 L
s
.4486 .42694 m
.48365 .431 L
s
.51664 .37198 m .4134 .42285 L .51659 .34664 L .373 .195 .506 r
F
.51664 .37198 m .41272 .44778 L .4134 .42285 L F
0 g
.4423 .4262 m
.4486 .42694 L
s
.37806 .41875 m
.4134 .42285 L
s
.65961 .44759 m
.65856 .42266 L
s
.65856 .42266 m
.63564 .41038 L
s
.62399 .49703 m
.6248 .52252 L
s
.66067 .47287 m
.62399 .49703 L
s
.34257 .41463 m
.37806 .41875 L
s
.30693 .4105 m
.34257 .41463 L
s
.27114 .40634 m
.30693 .4105 L
s
.63564 .41038 m
.61243 .39795 L
s
.51669 .3977 m .41272 .44778 L .51664 .37198 L .373 .195 .506 r
F
0 g
.51665 .37744 m
.54101 .35971 L
s
.51669 .3977 m .41203 .47306 L .41272 .44778 L .373 .195 .506 r
F
0 g
.41272 .44778 m
.4134 .42285 L
s
.66067 .47287 m
.65961 .44759 L
s
.2352 .40217 m
.27114 .40634 L
s
.6248 .52252 m
.66175 .49852 L
s
.6248 .52252 m
.62561 .54838 L
s
.38964 .27866 m
.2352 .40217 L
s
.19911 .39799 m
.2352 .40217 L
s
.36323 .26452 m
.19911 .39799 L
s
.19689 .42305 m
.19911 .39799 L
s
.61243 .39795 m
.58892 .38537 L
s
.51673 .42379 m .41203 .47306 L .51669 .3977 L .373 .195 .506 r
F
0 g
.27114 .40634 m
.4157 .29262 L
s
.30693 .4105 m
.44142 .30639 L
s
.34257 .41463 m
.4668 .31998 L
s
.37806 .41875 m
.49186 .3334 L
s
.4134 .42285 m
.51659 .34664 L
s
.5167 .40732 m
.56512 .37262 L
s
.51673 .42379 m .41133 .49871 L .41203 .47306 L .373 .195 .506 r
F
0 g
.41203 .47306 m
.41272 .44778 L
s
.66175 .49852 m
.66067 .47287 L
s
.62561 .54838 m
.62644 .5746 L
s
.66284 .52453 m
.62561 .54838 L
s
.58892 .38537 m
.56512 .37262 L
s
.36211 .29026 m
.19689 .42305 L
s
.19463 .44848 m
.19689 .42305 L
s
.51678 .45028 m .41133 .49871 L .51673 .42379 L .373 .195 .506 r
F
.51678 .45028 m .41061 .52472 L .41133 .49871 L F
0 g
.41133 .49871 m
.41203 .47306 L
s
.66284 .52453 m
.66175 .49852 L
s
.64996 .37861 m
.65096 .40378 L
s
.89073 .27928 m
.64996 .37861 L
s
.64832 .35583 m
.64996 .37861 L
s
.56512 .37262 m
.54101 .35971 L
s
.19235 .47428 m
.19463 .44848 L
s
.51683 .47717 m .41061 .52472 L .51678 .45028 L .373 .195 .506 r
F
.51683 .47717 m .40989 .55111 L .41061 .52472 L F
0 g
.41061 .52472 m
.41133 .49871 L
s
.66395 .55092 m
.66284 .52453 L
s
.65096 .40378 m
.65199 .42932 L
s
.89361 .30495 m
.65096 .40378 L
s
.64118 .56589 m .62728 .6012 L .66507 .5777 L .656 .751 .92 r
F
.64118 .56589 m .59131 .59736 L .62728 .6012 L F
0 g
.62644 .5746 m
.62646 .57518 L
s
.62728 .6012 m
.62813 .62819 L
s
.51659 .34664 m
.54101 .35971 L
s
.61697 .55393 m .59131 .59736 L .64118 .56589 L .656 .751 .92 r
F
0 g
.62728 .6012 m
.66507 .5777 L
s
.64065 .56563 m
.66395 .55092 L
s
.61697 .55393 m .5552 .5935 L .59131 .59736 L .656 .751 .92 r
F
0 g
.59131 .59736 m
.62728 .6012 L
s
.87494 .26125 m
.64832 .35583 L
s
.64665 .33253 m
.64832 .35583 L
s
.19003 .50045 m
.19235 .47428 L
s
.59244 .54181 m .5552 .5935 L .61697 .55393 L .656 .751 .92 r
F
.59244 .54181 m .51892 .58962 L .5552 .5935 L F
0 g
.5552 .5935 m
.59131 .59736 L
s
.51688 .50447 m .40989 .55111 L .51683 .47717 L .373 .195 .506 r
F
.51688 .50447 m .40916 .57789 L .40989 .55111 L F
0 g
.40989 .55111 m
.41061 .52472 L
s
.66395 .55092 m
.66507 .5777 L
s
.56759 .52953 m .51892 .58962 L .59244 .54181 L .656 .751 .92 r
F
.56759 .52953 m .48249 .58573 L .51892 .58962 L F
0 g
.51892 .58962 m
.5552 .5935 L
s
.65199 .42932 m
.65302 .45523 L
s
.62813 .62819 m
.62899 .65558 L
s
.66621 .60488 m
.62813 .62819 L
s
.51659 .34664 m
.51664 .37198 L
s
.49186 .3334 m
.51659 .34664 L
s
.5424 .51708 m .48249 .58573 L .56759 .52953 L .656 .751 .92 r
F
.5424 .51708 m .4459 .58182 L .48249 .58573 L F
0 g
.48249 .58573 m
.51892 .58962 L
s
.51688 .50447 m .4459 .58182 L .5424 .51708 L .656 .751 .92 r
F
.51688 .50447 m .40916 .57789 L .4459 .58182 L F
0 g
.4459 .58182 m
.48249 .58573 L
s
.18767 .52701 m
.19003 .50045 L
s
.51693 .53219 m .40916 .57789 L .51688 .50447 L .373 .195 .506 r
F
.51693 .53219 m .40841 .60506 L .40916 .57789 L F
0 g
.44342 .58155 m
.4459 .58182 L
s
.49101 .49169 m .40916 .57789 L .51688 .50447 L .656 .751 .92 r
F
.49101 .49169 m .37225 .57395 L .40916 .57789 L F
0 g
.66507 .5777 m
.66621 .60488 L
s
.64118 .56589 m
.66507 .5777 L
s
.65302 .45523 m
.65408 .48153 L
s
.49186 .3334 m
.4668 .31998 L
s
.62899 .65558 m
.66737 .63245 L
s
.62899 .65558 m
.62987 .68337 L
s
.64665 .33253 m
.85889 .24291 L
s
.64494 .30869 m
.64665 .33253 L
s
.46479 .47873 m .37225 .57395 L .49101 .49169 L .656 .751 .92 r
F
.46479 .47873 m .33518 .56998 L .37225 .57395 L F
0 g
.37225 .57395 m
.40916 .57789 L
s
.51664 .37198 m
.51669 .3977 L
s
.43821 .46559 m .33518 .56998 L .46479 .47873 L .656 .751 .92 r
F
.43821 .46559 m .29795 .566 L .33518 .56998 L F
0 g
.33518 .56998 m
.37225 .57395 L
s
.41126 .45228 m .29795 .566 L .43821 .46559 L .656 .751 .92 r
F
.41126 .45228 m .26056 .56201 L .29795 .566 L F
0 g
.29795 .566 m
.33518 .56998 L
s
.61697 .55393 m
.64118 .56589 L
s
.51698 .56033 m .40841 .60506 L .51693 .53219 L .373 .195 .506 r
F
.51698 .56033 m .40765 .63264 L .40841 .60506 L F
0 g
.40841 .60506 m
.40916 .57789 L
s
.66737 .63245 m
.66621 .60488 L
s
.4668 .31998 m
.44142 .30639 L
s
.65408 .48153 m
.65514 .50821 L
s
.38394 .43877 m .26056 .56201 L .41126 .45228 L .656 .751 .92 r
F
.38394 .43877 m .223 .55799 L .26056 .56201 L F
0 g
.26056 .56201 m
.29795 .566 L
s
.62987 .68337 m
.63076 .71157 L
s
.66854 .66044 m
.62987 .68337 L
s
.51669 .3977 m
.51673 .42379 L
s
.35624 .42508 m .223 .55799 L .38394 .43877 L .656 .751 .92 r
F
.35624 .42508 m .18528 .55396 L .223 .55799 L F
0 g
.19463 .44848 m
.36097 .3164 L
s
.19235 .47428 m
.35981 .34294 L
s
.19003 .50045 m
.35864 .36989 L
s
.18767 .52701 m
.35745 .39727 L
s
.223 .55799 m
.26056 .56201 L
s
.18528 .55396 m
.223 .55799 L
s
.18528 .55396 m
.18767 .52701 L
s
.18528 .55396 m
.35624 .42508 L
s
.18286 .58132 m
.18528 .55396 L
s
.59244 .54181 m
.61697 .55393 L
s
.64319 .28429 m
.64494 .30869 L
s
.44142 .30639 m
.4157 .29262 L
s
.51704 .58892 m .40765 .63264 L .51698 .56033 L .373 .195 .506 r
F
.51704 .58892 m .40689 .66063 L .40765 .63264 L F
0 g
.40765 .63264 m
.40841 .60506 L
s
.66854 .66044 m
.66737 .63245 L
s
.63076 .71157 m
.63166 .7402 L
s
.66973 .68885 m
.63076 .71157 L
s
.51673 .42379 m
.51678 .45028 L
s
.56759 .52953 m
.59244 .54181 L
s
.18286 .58132 m
.35501 .45334 L
s
.18039 .60908 m
.18286 .58132 L
s
.4157 .29262 m
.38964 .27866 L
s
.51709 .61795 m .40689 .66063 L .51704 .58892 L .373 .195 .506 r
F
.51709 .61795 m .40611 .68903 L .40689 .66063 L F
0 g
.40689 .66063 m
.40765 .63264 L
s
.66973 .68885 m
.66854 .66044 L
s
.9087 .43937 m .65623 .5353 L .65459 .51334 L .656 .751 .92 r
F
0 g
.65623 .5353 m
.65733 .56279 L
s
.65514 .50821 m
.65534 .51312 L
s
.63166 .7402 m
.67095 .71769 L
s
.63166 .7402 m
.63258 .76925 L
s
.51678 .45028 m
.51683 .47717 L
s
.6414 .25931 m
.64319 .28429 L
s
.5424 .51708 m
.56759 .52953 L
s
.89361 .30495 m
.89073 .27928 L
s
.89073 .27928 m
.87494 .26125 L
s
.38964 .27866 m
.36323 .26452 L
s
.18039 .60908 m
.35375 .48205 L
s
.17789 .63727 m
.18039 .60908 L
s
.51714 .64744 m .40611 .68903 L .51709 .61795 L .373 .195 .506 r
F
.51714 .64744 m .40532 .71787 L .40611 .68903 L F
0 g
.40611 .68903 m
.40689 .66063 L
s
.67095 .71769 m
.66973 .68885 L
s
.65733 .56279 m
.65845 .5907 L
s
.63258 .76925 m
.67217 .74698 L
s
.63258 .76925 m
.59499 .76561 L
s
.51683 .47717 m
.51688 .50447 L
s
.51688 .50447 m
.5424 .51708 L
s
.59499 .76561 m
.55724 .76195 L
s
.64722 .73578 m
.59499 .76561 L
s
.36323 .26452 m
.36211 .29026 L
s
.89654 .33102 m
.89361 .30495 L
s
.89232 .42191 m .65459 .51334 L .65292 .49085 L .656 .751 .92 r
F
.9087 .43937 m .65459 .51334 L .89232 .42191 L F
0 g
.65199 .42932 m
.89654 .33102 L
s
.65459 .51334 m
.65623 .5353 L
s
.17789 .63727 m
.35248 .51123 L
s
.17536 .66589 m
.17789 .63727 L
s
.55724 .76195 m
.51932 .75828 L
s
.62193 .72442 m
.55724 .76195 L
s
.87494 .26125 m
.85889 .24291 L
s
.5172 .6774 m .40532 .71787 L .51714 .64744 L .373 .195 .506 r
F
.5172 .6774 m .40452 .74716 L .40532 .71787 L F
0 g
.40532 .71787 m
.40611 .68903 L
s
.40452 .74716 m
.40532 .71787 L
s
.67217 .74698 m
.67095 .71769 L
s
.51932 .75828 m
.48122 .75459 L
s
.59629 .71291 m
.51932 .75828 L
s
.65845 .5907 m
.91507 .49615 L
s
.65845 .5907 m
.65958 .61904 L
s
.51688 .50447 m
.51693 .53219 L
s
.49101 .49169 m
.51688 .50447 L
s
.48122 .75459 m
.44296 .75088 L
s
.48122 .75459 m
.57029 .70124 L
s
.36211 .29026 m
.36097 .3164 L
s
.89951 .35748 m
.89654 .33102 L
s
.40452 .74716 m
.44296 .75088 L
s
.44296 .75088 m
.54393 .6894 L
s
.17536 .66589 m
.35119 .54089 L
s
.17278 .69494 m
.17536 .66589 L
s
.85889 .24291 m
.84255 .22425 L
s
.40452 .74716 m
.5172 .6774 L
s
.3659 .74342 m
.40452 .74716 L
s
.64722 .73578 m
.67217 .74698 L
s
.65958 .61904 m
.91833 .52522 L
s
.65958 .61904 m
.66073 .64782 L
s
.46479 .47873 m
.49101 .49169 L
s
.87565 .40414 m .65292 .49085 L .65121 .46781 L .656 .751 .92 r
F
.89232 .42191 m .65292 .49085 L .87565 .40414 L F
0 g
.88877 .41813 m
.90559 .41165 L
s
.78934 .42862 m
.90252 .38436 L
s
.65302 .45523 m
.89951 .35748 L
s
.65292 .49085 m
.65459 .51334 L
s
.3659 .74342 m
.32711 .73966 L
s
.3659 .74342 m
.49009 .66523 L
s
.51693 .53219 m
.51698 .56033 L
s
.79179 .16627 m .63956 .23373 L .64056 .25961 L .499 .287 .523 r
F
0 g
.63768 .20754 m
.63956 .23373 L
s
.64138 .2591 m
.6414 .25931 L
s
.64494 .30869 m
.84255 .22425 L
s
.32711 .73966 m
.46259 .65288 L
s
.32711 .73966 m
.28814 .73588 L
s
.36097 .3164 m
.35981 .34294 L
s
.90252 .38436 m
.89951 .35748 L
s
.17278 .69494 m
.34988 .57103 L
s
.17016 .72445 m
.17278 .69494 L
s
.28814 .73588 m
.249 .73209 L
s
.28814 .73588 m
.43469 .64036 L
s
.62193 .72442 m
.64722 .73578 L
s
.84255 .22425 m
.82593 .20526 L
s
.43821 .46559 m
.46479 .47873 L
s
.66073 .64782 m
.6619 .67704 L
s
.92165 .55477 m
.66073 .64782 L
s
.249 .73209 m
.20967 .72828 L
s
.249 .73209 m
.40639 .62765 L
s
.51698 .56033 m
.51704 .58892 L
s
.20967 .72828 m
.17016 .72445 L
s
.37768 .61476 m
.20967 .72828 L
s
.79404 .19243 m .64056 .25961 L .64158 .28589 L .499 .287 .523 r
F
.79179 .16627 m .64056 .25961 L .79404 .19243 L F
0 g
.63956 .23373 m
.64056 .25961 L
s
.6466 .28281 m
.82593 .20526 L
s
.35981 .34294 m
.35864 .36989 L
s
.90559 .41165 m
.90252 .38436 L
s
.17016 .72445 m
.34854 .60168 L
s
.59629 .71291 m
.62193 .72442 L
s
.85867 .38604 m .65121 .46781 L .64945 .44422 L .656 .751 .92 r
F
.87565 .40414 m .65121 .46781 L .85867 .38604 L F
0 g
.65121 .46781 m
.65292 .49085 L
s
.65733 .56279 m
.91186 .46754 L
s
.41126 .45228 m
.43821 .46559 L
s
.63576 .1807 m
.63768 .20754 L
s
.6619 .67704 m
.92502 .5848 L
s
.6619 .67704 m
.66309 .70672 L
s
.82593 .20526 m
.80901 .18594 L
s
.51704 .58892 m
.51709 .61795 L
s
.79632 .219 m .64158 .28589 L .64261 .31258 L .499 .287 .523 r
F
.79404 .19243 m .64158 .28589 L .79632 .219 L F
0 g
.64056 .25961 m
.64158 .28589 L
s
.63768 .20754 m
.77426 .14625 L
s
.79404 .19249 m
.80901 .18594 L
s
.35864 .36989 m
.35745 .39727 L
s
.57029 .70124 m
.59629 .71291 L
s
.90559 .41165 m
.9087 .43937 L
s
.38394 .43877 m
.41126 .45228 L
s
.66309 .70672 m
.92844 .61533 L
s
.66309 .70672 m
.66146 .68584 L
s
.51709 .61795 m
.51714 .64744 L
s
.79179 .16627 m
.80901 .18594 L
s
.84138 .36761 m .64945 .44422 L .64765 .42003 L .656 .751 .92 r
F
.85867 .38604 m .64945 .44422 L .84138 .36761 L F
0 g
.65623 .5353 m
.9087 .43937 L
s
.64945 .44422 m
.65121 .46781 L
s
.79864 .24601 m .64261 .31258 L .64366 .3397 L .499 .287 .523 r
F
.79632 .219 m .64261 .31258 L .79864 .24601 L F
0 g
.64158 .28589 m
.64261 .31258 L
s
.63956 .23373 m
.79179 .16627 L
s
.54393 .6894 m
.57029 .70124 L
s
.35624 .42508 m
.35745 .39727 L
s
.63576 .1807 m
.75642 .12587 L
s
.63378 .15319 m
.63576 .1807 L
s
.9087 .43937 m
.91186 .46754 L
s
.89232 .42191 m
.9087 .43937 L
s
.35624 .42508 m
.38394 .43877 L
s
.51714 .64744 m
.5172 .6774 L
s
.5172 .6774 m
.54393 .6894 L
s
.79179 .16627 m
.79404 .19243 L
s
.77426 .14625 m
.79179 .16627 L
s
.801 .27345 m .64366 .3397 L .64472 .36725 L .499 .287 .523 r
F
.79864 .24601 m .64366 .3397 L .801 .27345 L F
0 g
.64261 .31258 m
.64366 .3397 L
s
.35501 .45334 m
.35624 .42508 L
s
.91507 .49615 m
.91186 .46754 L
s
.66146 .68584 m
.65979 .66443 L
s
.91143 .59865 m
.66146 .68584 L
s
.87565 .40414 m
.89232 .42191 L
s
.82377 .34884 m .64765 .42003 L .6458 .39524 L .656 .751 .92 r
F
.84138 .36761 m .64765 .42003 L .82377 .34884 L F
0 g
.64765 .42003 m
.64945 .44422 L
s
.73825 .10511 m
.63378 .15319 L
s
.63176 .12499 m
.63378 .15319 L
s
.49009 .66523 m
.5172 .6774 L
s
.79404 .19243 m
.79632 .219 L
s
.8034 .30135 m .64472 .36725 L .6458 .39524 L .499 .287 .523 r
F
.801 .27345 m .64472 .36725 L .8034 .30135 L F
0 g
.64366 .3397 m
.64472 .36725 L
s
.77426 .14625 m
.75642 .12587 L
s
.35501 .45334 m
.35375 .48205 L
s
.91833 .52522 m
.91507 .49615 L
s
.85867 .38604 m
.87565 .40414 L
s
.46259 .65288 m
.49009 .66523 L
s
.65979 .66443 m
.65808 .64247 L
s
.8941 .58165 m
.65979 .66443 L
s
.79632 .219 m
.79864 .24601 L
s
.82377 .34884 m .6458 .39524 L .80583 .32971 L .656 .751 .92 r
F
.80583 .32971 m .6458 .39524 L .6469 .42369 L .499 .287 .523 r
F
.8034 .30135 m .6458 .39524 L .80583 .32971 L F
.80583 .32971 m .6458 .39524 L .64391 .36982 L .656 .751 .92 r
F
0 g
.64472 .36725 m
.64481 .36959 L
s
.35375 .48205 m
.35248 .51123 L
s
.92165 .55477 m
.91833 .52522 L
s
.75642 .12587 m
.73825 .10511 L
s
.71974 .08397 m
.63176 .12499 L
s
.62968 .09607 m
.63176 .12499 L
s
.84138 .36761 m
.85867 .38604 L
s
.43469 .64036 m
.46259 .65288 L
s
.79864 .24601 m
.801 .27345 L
s
.80831 .35855 m .6469 .42369 L .64802 .4526 L .499 .287 .523 r
F
.80583 .32971 m .6469 .42369 L .80831 .35855 L F
0 g
.6458 .39524 m
.6469 .42369 L
s
.35248 .51123 m
.35119 .54089 L
s
.92502 .5848 m
.92165 .55477 L
s
.65808 .64247 m
.65633 .61995 L
s
.73825 .10511 m
.71974 .08397 L
s
.40639 .62765 m
.43469 .64036 L
s
.78755 .31023 m .64391 .36982 L .64197 .34374 L .656 .751 .92 r
F
.80583 .32971 m .64391 .36982 L .78755 .31023 L F
0 g
.64391 .36982 m
.6458 .39524 L
s
.82377 .34884 m
.84138 .36761 L
s
.70088 .06244 m
.62968 .09607 L
s
.62756 .0664 m
.62968 .09607 L
s
.801 .27345 m
.8034 .30135 L
s
.80831 .35855 m .64802 .4526 L .81083 .38788 L .499 .287 .523 r
F
.81083 .38788 m .64802 .4526 L .64916 .48199 L F
0 g
.6469 .42369 m
.64802 .4526 L
s
.35119 .54089 m
.34988 .57103 L
s
.92844 .61533 m
.92502 .5848 L
s
.37768 .61476 m
.40639 .62765 L
s
.71974 .08397 m
.70088 .06244 L
s
.80583 .32971 m
.82377 .34884 L
s
.65633 .61995 m
.65453 .59685 L
s
.8034 .30135 m
.80583 .32971 L
s
.81339 .4177 m .64916 .48199 L .65031 .51186 L .499 .287 .523 r
F
.81083 .38788 m .64916 .48199 L .81339 .4177 L F
0 g
.64802 .4526 m
.64916 .48199 L
s
.34988 .57103 m
.34854 .60168 L
s
.76893 .29037 m .64197 .34374 L .63998 .31698 L .656 .751 .92 r
F
.78755 .31023 m .64197 .34374 L .76893 .29037 L F
0 g
.64197 .34374 m
.64391 .36982 L
s
.91143 .59865 m
.92844 .61533 L
s
.34854 .60168 m
.37768 .61476 L
s
.68168 .0405 m
.62756 .0664 L
s
.62853 .09291 m
.62756 .0664 L
s
.70088 .06244 m
.68168 .0405 L
s
.80583 .32971 m
.80831 .35855 L
s
.78755 .31023 m
.80583 .32971 L
s
.816 .44804 m .65031 .51186 L .65149 .54224 L .499 .287 .523 r
F
.81339 .4177 m .65031 .51186 L .816 .44804 L F
0 g
.64916 .48199 m
.65031 .51186 L
s
.8941 .58165 m
.91143 .59865 L
s
.68312 .06708 m
.62853 .09291 L
s
.62953 .11986 m
.62853 .09291 L
s
.76893 .29037 m .63998 .31698 L .74994 .27014 L .656 .751 .92 r
F
.74994 .27014 m .63998 .31698 L .63794 .28951 L F
0 g
.63998 .31698 m
.64197 .34374 L
s
.68168 .0405 m
.68312 .06708 L
s
.80831 .35855 m
.81083 .38788 L
s
.81865 .47891 m .65149 .54224 L .65268 .57314 L .499 .287 .523 r
F
.816 .44804 m .65149 .54224 L .81865 .47891 L F
0 g
.65031 .51186 m
.65149 .54224 L
s
.76893 .29037 m
.78755 .31023 L
s
.68459 .09412 m
.62953 .11986 L
s
.63054 .14726 m
.62953 .11986 L
s
.87643 .56433 m
.8941 .58165 L
s
.68312 .06708 m
.68459 .09412 L
s
.81083 .38788 m
.81339 .4177 L
s
.81865 .47891 m .65268 .57314 L .82135 .51031 L .499 .287 .523 r
F
0 g
.65268 .57314 m
.82135 .51031 L
s
.65149 .54224 m
.65268 .57314 L
s
.65453 .59685 m
.84006 .52867 L
s
.65808 .64247 m
.87643 .56433 L
s
.65633 .61995 m
.85842 .54667 L
s
.65268 .57314 m
.65453 .59685 L
s
.65078 .54879 m
.65268 .57314 L
s
.73059 .2495 m .63794 .28951 L .63584 .26131 L .656 .751 .92 r
F
.74994 .27014 m .63794 .28951 L .73059 .2495 L F
0 g
.63794 .28951 m
.63998 .31698 L
s
.74994 .27014 m
.76893 .29037 L
s
.68609 .12161 m
.63054 .14726 L
s
.63157 .17514 m
.63054 .14726 L
s
.85842 .54667 m
.87643 .56433 L
s
.68459 .09412 m
.68609 .12161 L
s
.81339 .4177 m
.816 .44804 L
s
.68761 .14959 m
.63157 .17514 L
s
.63262 .20349 m
.63157 .17514 L
s
.64884 .52378 m
.65078 .54879 L
s
.65078 .54879 m
.80225 .49159 L
s
.84006 .52867 m
.85842 .54667 L
s
.68609 .12161 m
.68761 .14959 L
s
.71086 .22847 m .63584 .26131 L .63368 .23234 L .656 .751 .92 r
F
.73059 .2495 m .63584 .26131 L .71086 .22847 L F
0 g
.63584 .26131 m
.63794 .28951 L
s
.73059 .2495 m
.74994 .27014 L
s
.816 .44804 m
.81865 .47891 L
s
.63262 .20349 m
.68916 .17805 L
s
.68761 .14959 m
.68916 .17805 L
s
.82135 .51031 m
.84006 .52867 L
s
.81865 .47891 m
.82135 .51031 L
s
.64884 .52378 m
.78278 .47249 L
s
.64884 .52378 m
.64683 .49808 L
s
.71086 .22847 m .63368 .23234 L .69073 .20701 L .656 .751 .92 r
F
0 g
.63368 .23234 m
.63477 .2617 L
s
.63368 .23234 m
.69073 .20701 L
s
.71086 .22847 m
.73059 .2495 L
s
.63262 .20349 m
.63368 .23234 L
s
.63368 .23234 m
.63584 .26131 L
s
.69073 .20701 m
.71086 .22847 L
s
.68916 .17805 m
.69073 .20701 L
s
.80225 .49159 m
.82135 .51031 L
s
.69234 .23649 m
.63477 .2617 L
s
.63587 .29157 m
.63477 .2617 L
s
.64683 .49808 m
.64478 .47167 L
s
.76291 .45301 m
.64683 .49808 L
s
.69073 .20701 m
.69234 .23649 L
s
.78278 .47249 m
.80225 .49159 L
s
.69397 .2665 m
.63587 .29157 L
s
.63699 .32198 m
.63587 .29157 L
s
.69234 .23649 m
.69397 .2665 L
s
.76291 .45301 m
.78278 .47249 L
s
.64478 .47167 m
.64266 .44451 L
s
.74263 .43312 m
.64478 .47167 L
s
.69563 .29705 m
.63699 .32198 L
s
.63813 .35294 m
.63699 .32198 L
s
.69397 .2665 m
.69563 .29705 L
s
.74263 .43312 m
.76291 .45301 L
s
.69732 .32816 m
.63813 .35294 L
s
.6393 .38446 m
.63813 .35294 L
s
.69563 .29705 m
.69732 .32816 L
s
.64266 .44451 m
.64048 .41657 L
s
.72193 .41283 m
.64266 .44451 L
s
.69904 .35984 m
.6393 .38446 L
s
.64048 .41657 m
.6393 .38446 L
s
.72193 .41283 m
.74263 .43312 L
s
.69732 .32816 m
.69904 .35984 L
s
.64048 .41657 m
.7008 .3921 L
s
.7008 .3921 m
.72193 .41283 L
s
.69904 .35984 m
.7008 .3921 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{196, 170},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 195}, {169, 0}} -> {-0.000425123, 0.0392051, \
0.0050294, 0.0050294}},
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
{CircleOfRays[5,WaveLength->.650,NumberOfRays->10],
Move[AnamorphicPrisms[{12,12}, 8.5, 21.2, 1.5, 6.0, 5.3],30],
Move[Screen[25],60]},
PlotType->TopView]\
\>", "Input",
  CellTags->"AnamorphicPrisms"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .445 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.015873 0.235992 0.015873 [
[.62319 .01853 -51 -4.5 ]
[.62319 .01853 51 4.5 ]
[.97619 .0106 -3 -4.5 ]
[.97619 .0106 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .445 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.54122 .11785 m
.41543 .16665 L
.44362 .18976 L
.5527 .14745 L
.54122 .11785 L
F
.5527 .14745 m
.44362 .18976 L
.47181 .21288 L
.56418 .17705 L
.5527 .14745 L
F
.56418 .17705 m
.47181 .21288 L
.5 .23599 L
.57566 .20665 L
.56418 .17705 L
F
.57566 .20665 m
.5 .23599 L
.52819 .25911 L
.58714 .23624 L
.57566 .20665 L
F
.58714 .23624 m
.52819 .25911 L
.55638 .28222 L
.59862 .26584 L
.58714 .23624 L
F
.59862 .26584 m
.55638 .28222 L
.58457 .30534 L
.6101 .29544 L
.59862 .26584 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.54122 .11785 m
.5527 .14745 L
.56418 .17705 L
.57566 .20665 L
.58714 .23624 L
.59862 .26584 L
.6101 .29544 L
.58457 .30534 L
.55638 .28222 L
.52819 .25911 L
.5 .23599 L
.47181 .21288 L
.44362 .18976 L
.41543 .16665 L
.54122 .11785 L
s
.5 g
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
.57566 .20665 m
.5 .23599 L
.5 .23599 L
.57566 .20665 L
.57566 .20665 L
F
0 g
.57566 .20665 m
.57566 .20665 L
.57566 .20665 L
.57566 .20665 L
.57566 .20665 L
.57566 .20665 L
.57566 .20665 L
.5 .23599 L
.5 .23599 L
.5 .23599 L
.5 .23599 L
.5 .23599 L
.5 .23599 L
.5 .23599 L
.57566 .20665 L
s
.5 g
.75633 .24658 m
.62215 .26068 L
.63666 .22724 L
.75302 .21501 L
.75633 .24658 L
F
.75302 .21501 m
.63666 .22724 L
.65117 .19379 L
.7497 .18344 L
.75302 .21501 L
F
.7497 .18344 m
.65117 .19379 L
.66568 .16035 L
.74638 .15187 L
.7497 .18344 L
F
.74638 .15187 m
.66568 .16035 L
.68018 .1269 L
.74306 .12029 L
.74638 .15187 L
F
.74306 .12029 m
.68018 .1269 L
.69469 .09346 L
.73974 .08872 L
.74306 .12029 L
F
.73974 .08872 m
.69469 .09346 L
.7092 .06001 L
.73642 .05715 L
.73974 .08872 L
F
0 g
.75633 .24658 m
.75302 .21501 L
.7497 .18344 L
.74638 .15187 L
.74306 .12029 L
.73974 .08872 L
.73642 .05715 L
.7092 .06001 L
.69469 .09346 L
.68018 .1269 L
.66568 .16035 L
.65117 .19379 L
.63666 .22724 L
.62215 .26068 L
.75633 .24658 L
s
.5 g
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
.74638 .15187 m
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
.74638 .15187 L
F
0 g
.74638 .15187 m
.74638 .15187 L
.74638 .15187 L
.74638 .15187 L
.74638 .15187 L
.74638 .15187 L
.74638 .15187 L
.66568 .16035 L
.66568 .16035 L
.66568 .16035 L
.66568 .16035 L
.66568 .16035 L
.66568 .16035 L
.66568 .16035 L
.74638 .15187 L
s
.54122 .11785 m
.41543 .16665 L
.44362 .18976 L
.5527 .14745 L
.54122 .11785 L
s
.5527 .14745 m
.44362 .18976 L
.47181 .21288 L
.56418 .17705 L
.5527 .14745 L
s
.56418 .17705 m
.47181 .21288 L
.5 .23599 L
.57566 .20665 L
.56418 .17705 L
s
.57566 .20665 m
.5 .23599 L
.52819 .25911 L
.58714 .23624 L
.57566 .20665 L
s
.58714 .23624 m
.52819 .25911 L
.55638 .28222 L
.59862 .26584 L
.58714 .23624 L
s
.59862 .26584 m
.55638 .28222 L
.58457 .30534 L
.6101 .29544 L
.59862 .26584 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.58457 .30534 L
.6101 .29544 L
.6101 .29544 L
s
.6101 .29544 m
.58457 .30534 L
.55638 .28222 L
.59862 .26584 L
.6101 .29544 L
s
.59862 .26584 m
.55638 .28222 L
.52819 .25911 L
.58714 .23624 L
.59862 .26584 L
s
.58714 .23624 m
.52819 .25911 L
.5 .23599 L
.57566 .20665 L
.58714 .23624 L
s
.57566 .20665 m
.5 .23599 L
.47181 .21288 L
.56418 .17705 L
.57566 .20665 L
s
.56418 .17705 m
.47181 .21288 L
.44362 .18976 L
.5527 .14745 L
.56418 .17705 L
s
.5527 .14745 m
.44362 .18976 L
.41543 .16665 L
.54122 .11785 L
.5527 .14745 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.54122 .11785 m
.41543 .16665 L
.41543 .16665 L
.54122 .11785 L
.54122 .11785 L
s
.75633 .24658 m
.62215 .26068 L
.63666 .22724 L
.75302 .21501 L
.75633 .24658 L
s
.75302 .21501 m
.63666 .22724 L
.65117 .19379 L
.7497 .18344 L
.75302 .21501 L
s
.7497 .18344 m
.65117 .19379 L
.66568 .16035 L
.74638 .15187 L
.7497 .18344 L
s
.74638 .15187 m
.66568 .16035 L
.68018 .1269 L
.74306 .12029 L
.74638 .15187 L
s
.74306 .12029 m
.68018 .1269 L
.69469 .09346 L
.73974 .08872 L
.74306 .12029 L
s
.73974 .08872 m
.69469 .09346 L
.7092 .06001 L
.73642 .05715 L
.73974 .08872 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.7092 .06001 L
.73642 .05715 L
.73642 .05715 L
s
.73642 .05715 m
.7092 .06001 L
.69469 .09346 L
.73974 .08872 L
.73642 .05715 L
s
.73974 .08872 m
.69469 .09346 L
.68018 .1269 L
.74306 .12029 L
.73974 .08872 L
s
.74306 .12029 m
.68018 .1269 L
.66568 .16035 L
.74638 .15187 L
.74306 .12029 L
s
.74638 .15187 m
.66568 .16035 L
.65117 .19379 L
.7497 .18344 L
.74638 .15187 L
s
.7497 .18344 m
.65117 .19379 L
.63666 .22724 L
.75302 .21501 L
.7497 .18344 L
s
.75302 .21501 m
.63666 .22724 L
.62215 .26068 L
.75633 .24658 L
.75302 .21501 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.75633 .24658 m
.62215 .26068 L
.62215 .26068 L
.75633 .24658 L
.75633 .24658 L
s
.97619 .03758 m
.97619 .10372 L
.97619 .16985 L
.97619 .23599 L
.97619 .30213 L
.97619 .36827 L
.97619 .4344 L
.97619 .4344 L
.97619 .36827 L
.97619 .30213 L
.97619 .23599 L
.97619 .16985 L
.97619 .10372 L
.97619 .03758 L
.97619 .03758 L
s
.97619 .23599 m
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
.97619 .23599 L
s
.97619 .4344 m
.97619 .42764 L
.97619 .40782 L
.97619 .37629 L
.97619 .3352 L
.97619 .28735 L
.97619 .23599 L
.97619 .18464 L
.97619 .13679 L
.97619 .09569 L
.97619 .06416 L
.97619 .04434 L
.97619 .03758 L
.97619 .04434 L
.97619 .06416 L
.97619 .09569 L
.97619 .13679 L
.97619 .18464 L
.97619 .23599 L
.97619 .28735 L
.97619 .3352 L
.97619 .37629 L
.97619 .40782 L
.97619 .42764 L
.97619 .4344 L
s
.947 .013 .01 r
.02381 .27567 m
.5484 .27567 L
s
0 0 0 r
2 Mabswid
.5484 .27567 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .2681 m
.53915 .2681 L
s
0 0 0 r
2 Mabswid
.53915 .2681 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .24825 m
.51496 .24825 L
s
0 0 0 r
2 Mabswid
.51496 .24825 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .22373 m
.48504 .22373 L
s
0 0 0 r
2 Mabswid
.48504 .22373 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .20389 m
.46085 .20389 L
s
0 0 0 r
2 Mabswid
.46085 .20389 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .19631 m
.4516 .19631 L
s
0 0 0 r
2 Mabswid
.4516 .19631 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .20389 m
.46085 .20389 L
s
0 0 0 r
2 Mabswid
.46085 .20389 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .22373 m
.48504 .22373 L
s
0 0 0 r
2 Mabswid
.48504 .22373 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .24825 m
.51496 .24825 L
s
0 0 0 r
2 Mabswid
.51496 .24825 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .2681 m
.53915 .2681 L
s
0 0 0 r
2 Mabswid
.53915 .2681 Mdot
.947 .013 .01 r
.5 Mabswid
.5484 .27567 m
.5942 .25446 L
s
0 0 0 r
2 Mabswid
.5942 .25446 Mdot
.947 .013 .01 r
.5 Mabswid
.53915 .2681 m
.5903 .24441 L
s
0 0 0 r
2 Mabswid
.5903 .24441 Mdot
.947 .013 .01 r
.5 Mabswid
.51496 .24825 m
.58009 .21809 L
s
0 0 0 r
2 Mabswid
.58009 .21809 Mdot
.947 .013 .01 r
.5 Mabswid
.48504 .22373 m
.56747 .18556 L
s
0 0 0 r
2 Mabswid
.56747 .18556 Mdot
.947 .013 .01 r
.5 Mabswid
.46085 .20389 m
.55727 .15924 L
s
0 0 0 r
2 Mabswid
.55727 .15924 Mdot
.947 .013 .01 r
.5 Mabswid
.4516 .19631 m
.55337 .14918 L
s
0 0 0 r
2 Mabswid
.55337 .14918 Mdot
.947 .013 .01 r
.5 Mabswid
.46085 .20389 m
.55727 .15924 L
s
0 0 0 r
2 Mabswid
.55727 .15924 Mdot
.947 .013 .01 r
.5 Mabswid
.48504 .22373 m
.56747 .18556 L
s
0 0 0 r
2 Mabswid
.56747 .18556 Mdot
.947 .013 .01 r
.5 Mabswid
.51496 .24825 m
.58009 .21809 L
s
0 0 0 r
2 Mabswid
.58009 .21809 Mdot
.947 .013 .01 r
.5 Mabswid
.53915 .2681 m
.5903 .24441 L
s
0 0 0 r
2 Mabswid
.5903 .24441 Mdot
.947 .013 .01 r
.5 Mabswid
.5942 .25446 m
.63389 .23363 L
s
0 0 0 r
2 Mabswid
.63389 .23363 Mdot
.947 .013 .01 r
.5 Mabswid
.5903 .24441 m
.64068 .21797 L
s
0 0 0 r
2 Mabswid
.64068 .21797 Mdot
.947 .013 .01 r
.5 Mabswid
.58009 .21809 m
.65847 .17695 L
s
0 0 0 r
2 Mabswid
.65847 .17695 Mdot
.947 .013 .01 r
.5 Mabswid
.56747 .18556 m
.68047 .12625 L
s
0 0 0 r
2 Mabswid
.68047 .12625 Mdot
.947 .013 .01 r
.5 Mabswid
.55727 .15924 m
.69826 .08524 L
s
0 0 0 r
2 Mabswid
.69826 .08524 Mdot
.947 .013 .01 r
.5 Mabswid
.55337 .14918 m
.70505 .06957 L
s
0 0 0 r
2 Mabswid
.70505 .06957 Mdot
.947 .013 .01 r
.5 Mabswid
.55727 .15924 m
.69826 .08524 L
s
0 0 0 r
2 Mabswid
.69826 .08524 Mdot
.947 .013 .01 r
.5 Mabswid
.56747 .18556 m
.68047 .12625 L
s
0 0 0 r
2 Mabswid
.68047 .12625 Mdot
.947 .013 .01 r
.5 Mabswid
.58009 .21809 m
.65847 .17695 L
s
0 0 0 r
2 Mabswid
.65847 .17695 Mdot
.947 .013 .01 r
.5 Mabswid
.5903 .24441 m
.64068 .21797 L
s
0 0 0 r
2 Mabswid
.64068 .21797 Mdot
.947 .013 .01 r
.5 Mabswid
.63389 .23363 m
.75441 .22828 L
s
0 0 0 r
2 Mabswid
.75441 .22828 Mdot
.947 .013 .01 r
.5 Mabswid
.64068 .21797 m
.7528 .21298 L
s
0 0 0 r
2 Mabswid
.7528 .21298 Mdot
.947 .013 .01 r
.5 Mabswid
.65847 .17695 m
.74859 .17295 L
s
0 0 0 r
2 Mabswid
.74859 .17295 Mdot
.947 .013 .01 r
.5 Mabswid
.68047 .12625 m
.74339 .12346 L
s
0 0 0 r
2 Mabswid
.74339 .12346 Mdot
.947 .013 .01 r
.5 Mabswid
.69826 .08524 m
.73919 .08342 L
s
0 0 0 r
2 Mabswid
.73919 .08342 Mdot
.947 .013 .01 r
.5 Mabswid
.70505 .06957 m
.73758 .06813 L
s
0 0 0 r
2 Mabswid
.73758 .06813 Mdot
.947 .013 .01 r
.5 Mabswid
.69826 .08524 m
.73919 .08342 L
s
0 0 0 r
2 Mabswid
.73919 .08342 Mdot
.947 .013 .01 r
.5 Mabswid
.68047 .12625 m
.74339 .12346 L
s
0 0 0 r
2 Mabswid
.74339 .12346 Mdot
.947 .013 .01 r
.5 Mabswid
.65847 .17695 m
.74859 .17295 L
s
0 0 0 r
2 Mabswid
.74859 .17295 Mdot
.947 .013 .01 r
.5 Mabswid
.64068 .21797 m
.7528 .21298 L
s
0 0 0 r
2 Mabswid
.7528 .21298 Mdot
.947 .013 .01 r
.5 Mabswid
.75441 .22828 m
.97619 .22884 L
s
0 0 0 r
2 Mabswid
.97619 .22884 Mdot
.947 .013 .01 r
.5 Mabswid
.7528 .21298 m
.97619 .21355 L
s
0 0 0 r
2 Mabswid
.97619 .21355 Mdot
.947 .013 .01 r
.5 Mabswid
.74859 .17295 m
.97619 .17352 L
s
0 0 0 r
2 Mabswid
.97619 .17352 Mdot
.947 .013 .01 r
.5 Mabswid
.74339 .12346 m
.97619 .12405 L
s
0 0 0 r
2 Mabswid
.97619 .12405 Mdot
.947 .013 .01 r
.5 Mabswid
.73919 .08342 m
.97619 .08402 L
s
0 0 0 r
2 Mabswid
.97619 .08402 Mdot
.947 .013 .01 r
.5 Mabswid
.73758 .06813 m
.97619 .06873 L
s
0 0 0 r
2 Mabswid
.97619 .06873 Mdot
.947 .013 .01 r
.5 Mabswid
.73919 .08342 m
.97619 .08402 L
s
0 0 0 r
2 Mabswid
.97619 .08402 Mdot
.947 .013 .01 r
.5 Mabswid
.74339 .12346 m
.97619 .12405 L
s
0 0 0 r
2 Mabswid
.97619 .12405 Mdot
.947 .013 .01 r
.5 Mabswid
.74859 .17295 m
.97619 .17352 L
s
0 0 0 r
2 Mabswid
.97619 .17352 Mdot
.947 .013 .01 r
.5 Mabswid
.7528 .21298 m
.97619 .21355 L
s
0 0 0 r
2 Mabswid
.97619 .21355 Mdot
[(Anamorphic Prisms)] .62319 .01853 0 0 Mshowa
[(S)] .97619 .0106 0 0 Mshowa
0 0 m
1 0 L
1 .445 L
0 .445 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{307.438, 136.75},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 306.438}, {135.75, 0}} -> {-1.94827, -15.1382, \
0.208514, 0.208514}},
  CellTags->"AnamorphicPrisms"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"CircleOfRays", "[", 
                RowBox[{"5", ",", \(NumberOfRays \[Rule] 10\), ",", 
                  RowBox[{"WaveLength", "\[Rule]", 
                    StyleBox["0.65`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->3]}]}], "]"}], ",", 
              RowBox[{"Move", "[", 
                RowBox[{
                  RowBox[{"AnamorphicPrisms", "[", 
                    RowBox[{\({12, 12}\), ",", 
                      StyleBox["8.5`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2], ",", 
                      StyleBox["21.200000000000001`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->3], ",", 
                      StyleBox["1.5`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2], ",", 
                      StyleBox["6.`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2], ",", 
                      StyleBox["5.29999999999999982`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->2]}], "]"}], ",", 
                  StyleBox["30.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], ",", 
              RowBox[{"Move", "[", 
                RowBox[{\(Screen[25]\), ",", 
                  StyleBox["60.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}]}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"AnamorphicPrisms"],

Cell[BoxData[
    \("-50 ray/surface intersections-"\)], "Output",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell["\<\
ShowSystem[sys,PlotType->Surface,RayChoice->ComponentNumber->3];\
\>\
", "Input",
  CellTags->"AnamorphicPrisms"]
}, Closed]],

Cell[CellGroupData[{

Cell["DirectVisionPrism[length, thickness, options]", "Subsection",
  CellTags->"DirectVisionPrism"],

Cell[CellGroupData[{

Cell["?DirectVisionPrism", "Input",
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    \("DirectVisionPrism[length, thickness, options] is constructed from \
three prisms cemented together that act as a dispersing element where \
spectral separation is required without any additional deviation of the beam. \
\n\nThe outer elements of DirectVisionPrism are commonly made from crown \
glass while the center element is made from flint glass. The length parameter \
gives the overall length of the component's base. DirectVisionPrism is \
normally aligned with its entrance face at x=0 and the exit face positioned \
along the x-axis. \n\nSee also: Prism, RhomboidalPrism, WedgePrism, and \
PellinBrocaPrism."\)], "Print",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DirectVisionPrism[71,20]", "Input",
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    TagBox[\(DirectVisionPrism[71, 20]\),
      HoldForm]], "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DrawSystem[\ DirectVisionPrism[71, 20], 
        PlotType -> TopView];\)\)], "Input",
  CellTags->"DirectVisionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .28169 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0912414 0.0134138 0.18919 0.0134138 [
[ 0 0 0 0 ]
[ 1 .28169 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00671 m
.02381 .1034 L
.02381 .1034 L
.02381 .00671 L
.02381 .00671 L
s
.02381 .1034 m
.15867 .27498 L
.15867 .27498 L
.02381 .1034 L
.02381 .1034 L
s
.84133 .27498 m
.15867 .27498 L
.15867 .27498 L
.84133 .27498 L
.84133 .27498 L
s
.97619 .1034 m
.84133 .27498 L
.84133 .27498 L
.97619 .1034 L
.97619 .1034 L
s
.97619 .00671 m
.97619 .1034 L
.97619 .1034 L
.97619 .00671 L
.97619 .00671 L
s
.97619 .00671 m
.5 .00671 L
.5 .00671 L
.97619 .00671 L
.97619 .00671 L
s
.5 .00671 m
.15867 .27498 L
.15867 .27498 L
.5 .00671 L
.5 .00671 L
s
.5 .00671 m
.84133 .27498 L
.84133 .27498 L
.5 .00671 L
.5 .00671 L
s
.02381 .00671 m
.02381 .1034 L
.15867 .27498 L
.84133 .27498 L
.97619 .1034 L
.97619 .00671 L
.02381 .00671 L
s
.02381 .00671 m
.02381 .1034 L
.15867 .27498 L
.84133 .27498 L
.97619 .1034 L
.97619 .00671 L
.02381 .00671 L
s
0 0 m
1 0 L
1 .28169 L
0 .28169 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{190.875, 53.6875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002n0000=B000`400?l00000o`00003o__ooool0
00Gooooo]?l00005ooooo`001Oooool00ol0003oooooooooo`1Dooooo`05o`000?oooooooooooooo
ool00000Eoooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`03ooooo`00
1Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`1@ooooo`;o00002Ooo
ool2o`0005?ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00oooool0
00Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0?ooooo`;o0000Coooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003ooooo
ooooo`1;ooooo`;o00005?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00?ooooo
0005ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool06Oooool2o`0004[ooooo00?o0000oooo
ooooool00oooool000Gooooo00?o0000ooooooooool0A_ooool2o`0001kooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`03ooooo`001Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`03ooooo`001Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo027ooooo0_l00016ooooo`03o`000?oo
oooooooo00?ooooo0005ooooo`03o`000?oooooooooo04;ooooo0_l0000Vooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00oooool000Go
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool00oooool000Gooooo0_l00010ooooo`03o`000?oooooooooo02_ooooo
0_l00011ooooo`03o`000?oooooooooo00?ooooo0005ooooo`03o`000?oooooooooo03gooooo0_l0
000`ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00oooool000Kooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01?ooool000Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0coooo
o`;o0000>oooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`00
2Oooool00ol0003oooooooooo`0dooooo`;o0000>_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Oooooo0009ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo000:ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0?Oooool2o`0003?ooooo00?o0000ooooooooool02?ooool0
00_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02Oooool000cooooo00?o0000ooooooooool0;?ooool2o`0004Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`003Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0;ooooo`003_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Oooooo0_l0
000Zooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo000?oooo
o`03o`000?oooooooooo02Cooooo0_l0001>ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03Oooool0013ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1?ooooo`;o
00009?ooool00ol0003oooooooooo`0>ooooo`004Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0?ooooo`004_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0@ooooo`004_ooool00ol0003oooooooooo`0Looooo`;o0000F?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo000Cooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0FOooool2o`0001cooooo00?o0000ooooooooool04Oooool001Co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04_ooool001Gooooo00?o0000ooooooooool05Oooool2o`00063ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`005_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo067ooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo000F
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo000Hooooo`03
o`000?oooooooooo00gooooo0_l0001Zooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05_ooool001Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[ooooo`;o0000
3Oooool00ol0003oooooooooo`0Gooooo`006_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`006oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Iooooo`006oooool00ol0003oooooooooo`05ooooo`;o0000M?ooool2o`00
00Oooooo00?o0000ooooooooool06Oooool001cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool001gooooo
00Go0000ooooooooooooooooo`00001jooooo`05o`000?ooooooooooooooool000007Oooool001ko
oooo00?o0000ooooool00000O?ooool00ol0003oooooo`00000Nooooo`007ooooon1o`0001kooooo
002nooooo`00\
\>"],
  ImageRangeCache->{{{0, 189.875}, {52.6875, 0}} -> {-7.36727, -14.1042, \
0.398581, 0.398581}},
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"DirectVisionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63244 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0279337 1.02793 -0.17824 1.02793 [
[ 0 0 0 0 ]
[ 1 .63244 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .63244 L
0 .63244 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.27766 .38653 m
.83168 .20794 L
s
.09354 .34147 m
.27766 .38653 L
s
.27766 .38653 m
.2683 .58826 L
s
.4243 .16382 m
.27766 .38653 L
s
.04376 .29553 m
.09354 .34147 L
s
.07556 .54521 m
.09354 .34147 L
s
.84856 .01698 m
.04376 .29553 L
s
.02309 .50124 m
.04376 .29553 L
s
.2683 .58826 m
.84845 .41719 L
s
.07556 .54521 m
.2683 .58826 L
s
.2683 .58826 m
.42125 .37475 L
s
.02309 .50124 m
.07556 .54521 L
s
.83168 .20794 m
.88698 .07396 L
s
.83168 .20794 m
.84845 .41719 L
s
.4243 .16382 m
.83168 .20794 L
s
.86756 .23297 m
.02309 .50124 L
s
.42125 .37475 m
.4243 .16382 L
s
.84856 .01698 m
.4243 .16382 L
s
.84845 .41719 m
.90752 .28808 L
s
.84845 .41719 m
.42125 .37475 L
s
.88698 .07396 m
.84856 .01698 L
s
.88698 .07396 m
.90752 .28808 L
s
.42125 .37475 m
.86756 .23297 L
s
.86756 .23297 m
.84856 .01698 L
s
.90752 .28808 m
.86756 .23297 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{167.438, 105.875},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002W0000JB000`400?l00000o`00003oYoooool0
0:Oooooo002<ooooo`;o00006Oooool008Wooooo0ol000000ooooooo0000ooooo`0Hooooo`00Q_oo
ool3o`0000Cooooo0_l0000Hooooo`00Poooool3o`0000Oooooo00?o0000ooooool000005oooool0
083ooooo0ol0000:ooooo`03o`000?oooooo000001Oooooo001mooooo`?o00003Oooool01?l0003o
ooooooooool0000Fooooo`00N_ooool3o`00013ooooo00Co0000oooooooooooo00005_ooool007So
oooo0ol0000Cooooo`04o`000?ooooooooooo`0001Gooooo001eooooo`?o00005_ooool01Ol0003o
oooooooooooooooo000001Cooooo001booooo`?o00006Oooool01Ol0003ooooooooooooooooo0000
01Cooooo001_ooooo`?o00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo001/ooooo`?o00007oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo
001Yooooo`?o00008_ooool01?l0003oooooooooooooool2o`0001?ooooo001Wooooo`;o00009Ooo
ool01?l0003oooooooooooooool2o`0001?ooooo001Tooooo`?o00009oooool01?l0003ooooooooo
ooooool2o`0001?ooooo001Qooooo`?o0000:_ooool01_l0003oooooooooool0003oooooo`0001?o
oooo001Nooooo`?o0000;Oooool01_l0003oooooooooool0003oooooo`0001?ooooo001Kooooo`?o
0000<?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo013ooooo001Hooooo`?o0000
<oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo013ooooo001Eooooo`?o0000=ooo
ool2o`0000?ooooo00?o0000ooooooooool04?ooool005?ooooo0ol0000iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04?ooool0053ooooo0ol0000looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool004gooooo0ol0000nooooo`;o00001?ooool00ol0003o
ooooooooo`0@ooooo`00B_ooool3o`00047ooooo0_l00004ooooo`03o`000?oooooooooo013ooooo
0017ooooo`?o0000@oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo013ooooo0014
ooooo`So0000@Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo013ooooo0011oooo
o`?o00000_ooool00ol0003oooooooooo`03ooooo`[o0000=oooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo013ooooo000oooooo`;o00001?ooool2o`0000oooooo2Ol0000]ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool003cooooo0ol00005ooooo`03
o`000?oooooo000001Sooooo2_l0000Sooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool03oooool003Wooooo0ol00008ooooo`03o`000?oooooo000002;ooooo2_l0000Hooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0?ooooo`00=_ooool3o`0000[o
oooo00Co0000oooooooooooo0000;?ooool9o`0000oooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00oooooo000cooooo`?o00003?ooool01Ol0003ooooooooooooooooo
000003Gooooo2_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0?ooooo`00<?ooool3o`0000oooooo00Go0000ooooooooooooooooo`00000o
ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000]oooo
o`?o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo0ol00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`00:oooool2o`0001?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool002Sooooo0ol0000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=_ooool3o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo000Uooooo`?o00005oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03?ooooo0ol0000;ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003ooooo
ooooo`0?ooooo`008_ooool3o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0`ooooo`?o00003_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`007oooool3o`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]
ooooo`?o00003oooool3o`0000Kooooo00Go0000ooooooooooooooooo`00000Aooooo`007?ooool3
o`0001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`?o00003oooool3
o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Aooooo`006_ooool2
o`00027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`?o00003oooool3
o`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000013ooooo000G
ooooo`?o00008_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo0ol0000?
ooooo`?o00002Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00013ooooo000D
ooooo`?o00009?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo0ol0000?
ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000013ooooo000Aoooo
o`?o00009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0ol0000?oooo
o`?o00003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000013ooooo000>ooooo`?o
0000:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo0ol0000?ooooo`?o
00004_ooool00ol0003oooooooooo`07ooooo`;o00004?ooool000_ooooo0ol0000[ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06?ooool3o`0000kooooo1?l0000Eooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03_ooool000Sooooo0ol0000^ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05Oooool3o`0000kooooo1?l0000Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03_ooool000Oooooo0_l0000_ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04Oooool4o`0000kooooo1?l0000Kooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool000Oooooo00?o0000ooooool00000;Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo0ol0000?ooooo`Co00007_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0007ooooo`04o`000?ooooooooooo`00
02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003oooool3o`00
02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003o
oooooooooooooooo000002[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`?o00003oooool3o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@oooo
o`001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`05ooooo`?o00003oooool3o`0002Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`001oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`?o0000
3oooool3o`0002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`001ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooo`000002o`0000oooooo0ol0000_ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04Oooool000Kooooo00?o0000ooooooooool01_ooool3o`0002;ooooo00?o0000
ooooooooool03_ooool3o`0000kooooo1?l0000booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04Oooool000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04o`00
01gooooo00?o0000ooooooooool03?ooool3o`000003ooooool0003ooooo00_ooooo1?l0000eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool000Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`Co00006?ooool00ol0003oooooooooo`0:ooooo`?o
00001?ooool00ol0003oooooooooo`07ooooo`Co0000>?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01;ooooo0006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool4o`0001Cooooo00?o0000ooooooooool01oooool3o`0000Oooooo00?o0000ooooooooool0
1?ooool4o`0003_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`001_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo0ol0000@ooooo`03o`000?oo
oooooooo00Gooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co0000?_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01?ooooo0006ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03oooool4o`0000_ooooo00?o0000ooooooooool00oooool3o`0000gooooo1Ol0
0011ooooo`05o`000?ooooooooooooooool000005_ooool000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Cooooo`Co00001oooool00ol0003oooooooooo`03o`0000kooooo2?l0
0010ooooo`05o`000?ooooooooooooooool000005_ooool000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`Co00000_ooool4o`0000kooooo0ol00002ooooo`03o`000?oo
oooooooo00?ooooo2_l0000fooooo`05o`000?ooooooooooooooool000005_ooool000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`?o00003_ooool3o`0000Cooooo00?o
0000ooooooooool03_ooool:o`0002gooooo00?o0000ooooool000005oooool000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo1?l00006
ooooo`03o`000?oooooooooo01Wooooo2ol0000Rooooo`03o`000?oooooo000001Oooooo0006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`?o00002Oooool00ol0003oooooooooo`0Uooooo`[o00006?ooool2o`0001Sooooo0005ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`?o
00003?ooool00ol0003oooooooooo`0_ooooo`[o00003_ooool2o`0001Sooooo0005ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03o`0000kooooo
00?o0000ooooooooool0>_ooool:o`0000Cooooo0_l0000Hooooo`001Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo0ol0000@ooooo`03o`000?oooooooooo04Gooooo1Ol0
000Iooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo1?l0000A
ooooo`03o`000?oooooooooo04Gooooo0ol0000Looooo`001Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Oooooo0ol00003ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0@Oooool4o`0001oooooo0005ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool3o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`?o
00008oooool000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`?o0000
2?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03cooooo1?l0000Vooooo`001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo1?l0000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0>_ooool3o`0002[ooooo0005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool3o`0000oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0fooooo`Co0000;Oooool000Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`?o00004_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Cooooo0ol0000aooooo`001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0ol0000Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool3o`0003Co
oooo0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool3o`0001Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`Co0000=oooool000Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`000002o`0001_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0/ooooo`?o0000>oooool000Cooooo00?o0000ooooooooool01Oooool3
o`0001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`Co0000?_ooool0
00Cooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo01kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Wooooo`?o0000@_ooool000Cooooo00?o0000ooooool0
00000_l00004ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Sooooo`Co0000AOooool000Cooooo0_l00007ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`?o0000BOooool000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07_ooool4o`0004cooooo0007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo0ol0001@
ooooo`002?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Hooooo`Co0000Doooool000Wooooo00Co0000oooooooooooo00008?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo0ol0001Gooooo`002_ooool00ol0
003oooooo`00000Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool4o`00
05[ooooo000;ooooo`;o00008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo0ol0001Nooooo`003?ooool3o`0001gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`?o0000HOooool000oooooo1Ol0000Hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool4o`0006Cooooo000Dooooo`Co00005?ooool01Ol0003ooooooooooooo
oooo000000_ooooo0ol0001Xooooo`006?ooool5o`0000oooooo00Co0000oooooooooooo00002?oo
ool4o`0006_ooooo000Mooooo`Go00002_ooool01?l0003oooooooooool00005ooooo`?o0000Kooo
ool002;ooooo1?l00006ooooo`03o`000?oooooo000000;ooooo1?l0001booooo`009_ooool5o`00
0003ooooool0003o000000?o0000M_ooool002_ooooo0ol0001iooooo`00Yoooool00:Oooooo002W
ooooo`00Yoooool00:Oooooo002Wooooo`00Yoooool00001\
\>"],
  ImageRangeCache->{{{0, 166.438}, {104.875, 0}} -> {0.0253761, 0.173394, \
0.00586662, 0.00586662}},
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DrawSystem[\ {\n\t\tRainbowOfRays[{ .4,  .65}], \n\t\tMove[\ 
          DirectVisionPrism[71, 20], 10], \n\t\tBoundary[100, 
          GraphicDesign -> Off]}, PlotType -> TopView]\)], "Input",
  CellTags->"DirectVisionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31294 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.161532 0.00952381 [
[.40927 .00745 -57 -4.5 ]
[.40927 .00745 57 4.5 ]
[ 0 0 0 0 ]
[ 1 .31294 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.07117 .03197 m
.07117 .10062 L
.07117 .10062 L
.07117 .03197 L
.07117 .03197 L
s
.07117 .10062 m
.16692 .22245 L
.16692 .22245 L
.07117 .10062 L
.07117 .10062 L
s
.65161 .22245 m
.16692 .22245 L
.16692 .22245 L
.65161 .22245 L
.65161 .22245 L
s
.74736 .10062 m
.65161 .22245 L
.65161 .22245 L
.74736 .10062 L
.74736 .10062 L
s
.74736 .03197 m
.74736 .10062 L
.74736 .10062 L
.74736 .03197 L
.74736 .03197 L
s
.74736 .03197 m
.40927 .03197 L
.40927 .03197 L
.74736 .03197 L
.74736 .03197 L
s
.40927 .03197 m
.16692 .22245 L
.16692 .22245 L
.40927 .03197 L
.40927 .03197 L
s
.40927 .03197 m
.65161 .22245 L
.65161 .22245 L
.40927 .03197 L
.40927 .03197 L
s
.07117 .03197 m
.07117 .10062 L
.16692 .22245 L
.65161 .22245 L
.74736 .10062 L
.74736 .03197 L
.07117 .03197 L
s
.07117 .03197 m
.07117 .10062 L
.16692 .22245 L
.65161 .22245 L
.74736 .10062 L
.74736 .03197 L
.07117 .03197 L
s
.001 .032 .937 r
.02381 .16153 m
.11905 .16153 L
s
0 0 0 r
2 Mabswid
.11905 .16153 Mdot
.027 .909 .047 r
.5 Mabswid
.02381 .16153 m
.11905 .16153 L
s
0 0 0 r
2 Mabswid
.11905 .16153 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .16153 m
.11905 .16153 L
s
0 0 0 r
2 Mabswid
.11905 .16153 Mdot
.001 .032 .937 r
.5 Mabswid
.11905 .16153 m
.30498 .11393 L
s
0 0 0 r
2 Mabswid
.30498 .11393 Mdot
.027 .909 .047 r
.5 Mabswid
.11905 .16153 m
.3038 .11486 L
s
0 0 0 r
2 Mabswid
.3038 .11486 Mdot
.947 .013 .01 r
.5 Mabswid
.11905 .16153 m
.30322 .11532 L
s
0 0 0 r
2 Mabswid
.30322 .11532 Mdot
.001 .032 .937 r
.5 Mabswid
.30498 .11393 m
.52557 .12338 L
s
0 0 0 r
2 Mabswid
.52557 .12338 Mdot
.027 .909 .047 r
.5 Mabswid
.3038 .11486 m
.52055 .11944 L
s
0 0 0 r
2 Mabswid
.52055 .11944 Mdot
.947 .013 .01 r
.5 Mabswid
.30322 .11532 m
.51881 .11807 L
s
0 0 0 r
2 Mabswid
.51881 .11807 Mdot
.001 .032 .937 r
.5 Mabswid
.52557 .12338 m
.67242 .19597 L
s
0 0 0 r
2 Mabswid
.67242 .19597 Mdot
.027 .909 .047 r
.5 Mabswid
.52055 .11944 m
.68746 .17683 L
s
0 0 0 r
2 Mabswid
.68746 .17683 Mdot
.947 .013 .01 r
.5 Mabswid
.51881 .11807 m
.69238 .17058 L
s
0 0 0 r
2 Mabswid
.69238 .17058 Mdot
.001 .032 .937 r
.5 Mabswid
.67242 .19597 m
.97619 .30549 L
s
0 0 0 r
2 Mabswid
.97619 .30549 Mdot
.027 .909 .047 r
.5 Mabswid
.68746 .17683 m
.97619 .21842 L
s
0 0 0 r
2 Mabswid
.97619 .21842 Mdot
.947 .013 .01 r
.5 Mabswid
.69238 .17058 m
.97619 .19406 L
s
0 0 0 r
2 Mabswid
.97619 .19406 Mdot
[(Direct Vision Prism)] .40927 .00745 0 0 Mshowa
0 0 m
1 0 L
1 .31294 L
0 .31294 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.375, 83},
  ImageMargins->{{50, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490000Db000`400?l00000o`00003oooooool:
ooooo`00ooooool:ooooo`00AOooool4o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_l000001Ooo
oooo0000o`000?l0003ooooo00?o00000_ooool01?l0003oooooo`000?l00003ooooo`?o00001?oo
ool8o`0000;ooooo00Co0000ooooool0003ooooo0_l0001eooooo`00A_ooool01?l0003ooooooooo
ool00003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003o
ooooo`0000Kooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`000003ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo000007Kooooo0016
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooooooool0003ooooo00Go0000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0_l00002ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000005ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool01Ol0003oooooo`000?oooooo
000007Kooooo0016ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0004ooooo`05o`000?oooooo0000ooooool00000M_ooool004Kooooo00Ko0000oooooooooooooooo
o`000?ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Ko00001?ooool01Ol0
003oooooooooool0003ooooo00;o00000_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?l0
0006ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`So0000Moooool004Kooooo00Co
0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00006?ooool01?l0003oooooooooool00027ooooo`00AOooool4o`0000Cooooo00?o0000oooooooo
ool04?ooool3o`000003ooooool0003o000000;o00001_ooool00ol0003oooooooooo`0<ooooo`Co
00001_ooool00ol0003oooooooooo`1oooooo`00ooooool:ooooo`00ooooool:ooooo`005ooooon]
o`0004Gooooo000Gooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`00001B
ooooo`03o`000?oooooooooo04Cooooo000Gooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Cooooo000Gooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo04Cooooo000Gooooo`03o`000?oooooooooo04gooooo0_l00009ooooo`;o0000
C_ooool00ol0003oooooooooo`14ooooo`005oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`14ooooo`005oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`14ooooo`005oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`14ooooo`005oooool00ol0003o
ooooooooo`18ooooo`;o00004oooool2o`0004Wooooo00?o0000ooooooooool0A?ooool001Oooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0A?ooool001Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A?ooool001Oooooo00?o0000
ooooooooool0A?ooool2o`0001_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`14
ooooo`005oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01cooooo0_l00014oooo
o`03o`000?oooooooooo04Cooooo000Gooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04Cooooo000Gooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo04Cooooo000Gooooo`03o`000?oooooooooo03oooooo0_l0000Uooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0A?ooool001Oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Vooooo`;o0000?oooool00ol0003oooooooooo`14ooooo`005oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0??ooool2o`00
04Gooooo000Gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo04Cooooo000Gooooo`03o`000?oooooooooo03[ooooo
0_l0000_ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0A?ooool001Sooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0`ooooo`;o0000>Oooool00ol0003ooooooooo
o`15ooooo`006Oooool00ol0003oooooooooo`0dooooo`03oo830_l0003olP<201_olP<200?o1^P<
ooooooooool05oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04Kooooo000Joooo
o`03o`000?oooooooooo02oooooo1?ob0`801?oooooo0000o`000?l0000=ooooo`go00S_7Oob0`8d
ooooo`03o`000?oooooooooo04Oooooo000Jooooo`03o`000?oooooooooo02_ooooo1?ob0`83oooo
o`;o0000;?ooool;o`08k`;o000000Co00S_oo830_ob0`;olP<2<Oooool00ol0003oooooooooo`17
ooooo`006oooool00ol0003oooooooooo`0Vooooo`ColP<21_ooool00ol0003oooooooooo`0ioooo
o`;o00000_l02>l3oo830Rgooooo00?o0000ooooooooool0B?ooool001cooooo00?o0000oooooooo
ool08Oooool4oo830PWooooo00?o0000ooooooooool0?Oooool01?l0003o00S_o`08koooool4oo83
0RSooooo00?o0000ooooooooool0BOooool001gooooo00?o0000ooooooooool07?ooool4oo830P_o
oooo0_l00011ooooo`04o`000?oooooo00S_o`08k`;ooooo00Co1^P<oo830_ob0`;olP<29?ooool0
0ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`0Hooooo`?olP<23_ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo00;o00S_0oooool00ol6j0colP<2oo830P02oo83
0Qoooooo00?o0000ooooooooool0Boooool001kooooo00?o0000ooooooooool05?ooool4oo830Q3o
oooo00?o0000ooooooooool0A?ooool01?l0003oooooooooooooool2o`08k`?ooooo0ol6j0`3oo83
0Qcooooo00?o0000ooooooooool0Boooool001oooooo00?o0000ooooooooool03oooool4oo830Q?o
oooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l02>l4ooooo`?o1^P<0oob0`8Hooooo`03
o`000?oooooooooo04cooooo000Pooooo`03o`000?oooooooooo00[ooooo1?ob0`8Eooooo`;o0000
Boooool00ol0003oooooooooo`02ooooo`;o00S_1Oooool3o`KX30ColP<24oooool00ol0003ooooo
ooooo`1=ooooo`008Oooool00ol0003oooooooooo`05ooooo`ColP<26?ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00?ooooo0_l02>l6ooooo`?o1^P<00Cooooooo830_ob0`;olP<2
3oooool00ol0003oooooooooo`1>ooooo`008Oooool01?l0003oooooooooooooool4oo830Q_ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`;o00S_1oooool2o`KX30;ooooo
1?ob0`8;ooooo`03o`000?oooooooooo04kooooo000;oooooa[olP<27_ooool00ol0003ooooooooo
o`1@ooooo`;o00001_ooool00ol02>ooooooooooo`06ooooo`?o1^P<0oooool3oo830POooooo00?o
0000ooooooooool0Coooool002?ooooo0_l0000Looooo`;o0000EOooool00ol0003oooooooooo`04
ooooo`;o00S_2Oooool3o`KX30?ooooo0oob0`83ooooo`03o`000?oooooooooo053ooooo000Toooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05oooo
o`;o00S_2_ooool3o`KX30?ooooo2?ob0`9>ooooo`009Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool01_ooool2o`08k`_ooooo0ol6j0`3o`0000Go
oooo3?ob0`92ooooo`009Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05[ooooo
0_l00008ooooo`;o00S_3?ooool4o`KX313ooooo3?ob0`8fooooo`009_ooool00ol0003ooooooooo
o`0Cooooo`;o0000Goooool00ol0003oooooooooo`07ooooo`;o00S_2_ooool01?l0003ooooooooo
ooooool7o`KX31Gooooo3?ob0`8Zooooo`009oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool02?ooool2o`08k`Oooooo00?o0000ooooooooool02Ooo
ool7o`KX31[ooooo3?ob0`8Nooooo`00:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool02Oooool2o`08k`Cooooo00?o0000ooooooooool04Oooool6
o`KX323ooooo3?ob0`8Booooo`00:?ooool00ol0003oooooooooo`0=ooooo`;o0000I_ooool2o`00
00_ooooo0_l02>l3o`0001Wooooo1ol6j0`Uooooo`GolP<20_l0000;ooooo`00:Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02_ooool2o`08kb7o
oooo1ol6j0`Sooooo`;o00002oooool002[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool02>l00_l02>lUooooo`Ko1^P<
:_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool3o`08kbSooooo1ol6j0`Sooooo`00;?ooool0
0ol0003oooooooooo`04ooooo`;o0000L?ooool2o`0000Kooooo00?o0000ooooooooool01oooool3
o`08kbcooooo1_l6j0`Mooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`;o00S_<?ooool7o`KX
31Kooooo000]ooooo`05o`000?ooooooooooooooool00000M_ooool01Ol0003ooooooooooooooooo
000000oooooo0ol02>ldooooo`Oo1^P<0_ooool2o`0000_ooooo000^ooooo`?o0000N?ooool3o`00
01?ooooo0ol02>lhooooo`;o1^P<0_l0000;ooooo`00;ooooomlo`0001Oooooo0ol02>m4ooooo`00
aOooool2o`08kd;ooooo0037ooooo`?o00S_?oooool00<[ooooo0ol02>llooooo`00cOooool3o`08
kcWooooo003@ooooo`;o00S_=oooool00=;ooooo0ol02>ldooooo`00eOooool3o`08kc7ooooo003H
ooooo`?o00S_;_ooool00=_ooooo0_l02>l/ooooo`00gOooool3o`08kbWooooo003Pooooo`?o00S_
9_ooool00>?ooooo0ol02>lSooooo`00i_ooool2o`08kb7ooooo003Xooooo`?o00S_7_ooool00>_o
oooo0ol02>lKooooo`00k_ooool3o`08kaSooooo003aooooo`;o00S_5_ooool00??ooooo0ol02>lC
ooooo`00m_ooool3o`08ka3ooooo003iooooo`?o00S_0_l0000;ooooo`00o?ooool2o`0000_ooooo
003oooooo`[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 264.375}, {82, 0}} -> {-4.71159, -18.0413, 0.413894, \
0.413894}},
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"RainbowOfRays", "[", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["0.4`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], ",", 
                    StyleBox["0.65`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]}], "}"}], "]"}], ",", 
              RowBox[{"Move", "[", 
                RowBox[{\(DirectVisionPrism[71, 20]\), ",", 
                  StyleBox["10.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], 
              ",", \(Boundary[{0, \(-50\), \(-50\)}, {100, 50, 
                  50}, {GraphicDesign \[Rule] Off}]\)}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    \("-15 ray/surface intersections-"\)], "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToRayica[OpticalMedium->SF14]", "Input",
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    \({"SF14 is an optical material from Schott with a refractive index of \
1.76181 at the 0.5876 micron wavelength and a corresponding V-number of \
26.5158. The model for this glass is valid from 0.37 to 2.325 microns of \
wavelength."}\)], "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DrawSystem[\ {\n\t\tRainbowOfRays[{ .4,  .65}], \n\t\tMove[\ 
          DirectVisionPrism[71, 20, ComponentMedium -> {BK7, SF14}], 
          10], \n\t\tBoundary[100, GraphicDesign -> Off]}, 
      PlotType -> TopView]\)], "Input",
  CellTags->"DirectVisionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.152377 0.00952381 [
[.40927 .00548 -57 -4.5 ]
[.40927 .00548 57 4.5 ]
[ 0 0 0 0 ]
[ 1 .2302 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.07117 .02281 m
.07117 .09146 L
.07117 .09146 L
.07117 .02281 L
.07117 .02281 L
s
.07117 .09146 m
.16692 .21329 L
.16692 .21329 L
.07117 .09146 L
.07117 .09146 L
s
.65161 .21329 m
.16692 .21329 L
.16692 .21329 L
.65161 .21329 L
.65161 .21329 L
s
.74736 .09146 m
.65161 .21329 L
.65161 .21329 L
.74736 .09146 L
.74736 .09146 L
s
.74736 .02281 m
.74736 .09146 L
.74736 .09146 L
.74736 .02281 L
.74736 .02281 L
s
.74736 .02281 m
.40927 .02281 L
.40927 .02281 L
.74736 .02281 L
.74736 .02281 L
s
.40927 .02281 m
.16692 .21329 L
.16692 .21329 L
.40927 .02281 L
.40927 .02281 L
s
.40927 .02281 m
.65161 .21329 L
.65161 .21329 L
.40927 .02281 L
.40927 .02281 L
s
.07117 .02281 m
.07117 .09146 L
.16692 .21329 L
.65161 .21329 L
.74736 .09146 L
.74736 .02281 L
.07117 .02281 L
s
.07117 .02281 m
.07117 .09146 L
.16692 .21329 L
.65161 .21329 L
.74736 .09146 L
.74736 .02281 L
.07117 .02281 L
s
.001 .032 .937 r
.02381 .15238 m
.11905 .15238 L
s
0 0 0 r
2 Mabswid
.11905 .15238 Mdot
.027 .909 .047 r
.5 Mabswid
.02381 .15238 m
.11905 .15238 L
s
0 0 0 r
2 Mabswid
.11905 .15238 Mdot
.947 .013 .01 r
.5 Mabswid
.02381 .15238 m
.11905 .15238 L
s
0 0 0 r
2 Mabswid
.11905 .15238 Mdot
.001 .032 .937 r
.5 Mabswid
.11905 .15238 m
.30498 .10478 L
s
0 0 0 r
2 Mabswid
.30498 .10478 Mdot
.027 .909 .047 r
.5 Mabswid
.11905 .15238 m
.3038 .10571 L
s
0 0 0 r
2 Mabswid
.3038 .10571 Mdot
.947 .013 .01 r
.5 Mabswid
.11905 .15238 m
.30322 .10616 L
s
0 0 0 r
2 Mabswid
.30322 .10616 Mdot
.001 .032 .937 r
.5 Mabswid
.30498 .10478 m
.52057 .11029 L
s
0 0 0 r
2 Mabswid
.52057 .11029 Mdot
.027 .909 .047 r
.5 Mabswid
.3038 .10571 m
.51601 .10671 L
s
0 0 0 r
2 Mabswid
.51601 .10671 Mdot
.947 .013 .01 r
.5 Mabswid
.30322 .10616 m
.51443 .10547 L
s
0 0 0 r
2 Mabswid
.51443 .10547 Mdot
.001 .032 .937 r
.5 Mabswid
.52057 .11029 m
.68456 .17137 L
s
0 0 0 r
2 Mabswid
.68456 .17137 Mdot
.027 .909 .047 r
.5 Mabswid
.51601 .10671 m
.69687 .15571 L
s
0 0 0 r
2 Mabswid
.69687 .15571 Mdot
.947 .013 .01 r
.5 Mabswid
.51443 .10547 m
.70126 .15012 L
s
0 0 0 r
2 Mabswid
.70126 .15012 Mdot
.001 .032 .937 r
.5 Mabswid
.68456 .17137 m
.97619 .22471 L
s
0 0 0 r
2 Mabswid
.97619 .22471 Mdot
.027 .909 .047 r
.5 Mabswid
.69687 .15571 m
.97619 .1641 L
s
0 0 0 r
2 Mabswid
.97619 .1641 Mdot
.947 .013 .01 r
.5 Mabswid
.70126 .15012 m
.97619 .14462 L
s
0 0 0 r
2 Mabswid
.97619 .14462 Mdot
[(Direct Vision Prism)] .40927 .00548 0 0 Mshowa
0 0 m
1 0 L
1 .2302 L
0 .2302 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{391, 89.875},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000670000FB000`400?l00000o`00003ooooooon8
ooooo`00oooooon8ooooo`00NOooool4o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_l000001Ooo
oooo0000o`000?l0003ooooo00?o00000_ooool01?l0003oooooo`000?l00003ooooo`?o00001?oo
ool8o`0000;ooooo00Co0000ooooool0003ooooo0_l0002oooooo`00N_ooool01?l0003ooooooooo
ool00003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003o
ooooo`0000Kooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`000003ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo00000<3ooooo001j
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooooooool0003ooooo00Go0000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0_l00002ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000005ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool01Ol0003oooooo`000?oooooo
00000<3ooooo001jooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0004ooooo`05o`000?oooooo0000ooooool00000`?ooool007[ooooo00Ko0000oooooooooooooooo
o`000?ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Ko00001?ooool01Ol0
003oooooooooool0003ooooo00;o00000_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?l0
0006ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`So0000`Oooool007[ooooo00Co
0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00006?ooool01?l0003oooooooooool0003Aooooo`00NOooool4o`0000Cooooo00?o0000oooooooo
ool04?ooool3o`000003ooooool0003o000000;o00001_ooool00ol0003oooooooooo`0<ooooo`Co
00001_ooool00ol0003oooooooooo`39ooooo`00oooooon8ooooo`008_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0I?ooool0027oooooool0001W
ooooo`008Oooool00ol0003oooooooooo`1jooooo`05o`000?ooooooooooooooool00000O?ooool0
0ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1fooooo`;o00002Oooool2o`0007Sooooo
00?o0000ooooooooool0IOooool0027ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0IOooool0027ooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0IOooool0027ooooo00?o0000ooooooooool0L_ooool2o`00017ooooo0_l0001doooo
o`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo06Gooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oooooo
oooo06gooooo0_l0000Kooooo`;o0000Koooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003ooooo
ooooo`1Yooooo`;o00008oooool2o`0006_ooooo00?o0000ooooooooool0IOooool0027ooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool0IOooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0IOooool0027ooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0IOooool0027ooooo00?o0000ooooooooool0I?ooool2o`0002gooooo0_l0001Vooooo`03
o`000?oooooooooo06Gooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06Gooooo000Qooooo`03o`000?oooooooooo063ooooo0_l0000eooooo`;o0000H_ooool0
0ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Uooooo`008Oooool2o`0005cooooo0_l0
000oooooo`;o0000GOooool2o`0006Kooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo06Gooooo000Roooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo06Kooooo000Sooooo`03o`000?oooooooooo05Gooooo0_l00017ooooo`;o
0000Eoooool00ol0003oooooooooo`1Wooooo`009?ooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Xooooo`009Ooo
ool00ol0003oooooooooo`1?ooooo`03o`08kol0003o00S_01Co00S_>Oooool2o`0005;ooooo00?o
0000ooooooooool0JOooool002Gooooo00?o0000ooooooooool0Boooool4o`08k`03oo830_l0003o
lP<204golP<200Go0000oo830_ob0`;olP<2o`KX301?ooooo`03o`000?oooooooooo06Wooooo000V
ooooo`03o`000?oooooooooo04Kooooo1?l02>l4oo830P03o`000?oooooooooo03gooooo4Ol02>l2
o`000003o`08koob0`;olP<200?olP<2B_ooool00ol0003oooooooooo`1Zooooo`009oooool00ol0
003oooooooooo`11ooooo`Co00S_1?ob0`82ooooo`03o`000?oooooooooo05;ooooo0_l00003o`08
k`03o`KX3?ob0`;olP<200;olP<2AOooool00ol0003oooooooooo`1[ooooo`00:?ooool00ol0003o
ooooooooo`0looooo`Co00S_1?ob0`85ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool00ol02>l00ooooooo1^P<oo830P03oo830T3ooooo00?o0000ooooooooool0K?ooool002Sooooo
00?o0000ooooooooool0>Oooool2o`08k`GolP<21oooool2o`0005Wooooo0_l00003ooooo`;o00S_
0_ooool2o`KX30GolP<2>oooool00ol0003oooooooooo`1/ooooo`00:Oooool00ol0003ooooooooo
o`0dooooo`;o00S_1?ob0`8;ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_oo
ool3o`08k`?ooooo0ol6j0`4oo830SKooooo00?o0000ooooooooool0KOooool002[ooooo00?o0000
ooooooooool0;oooool2o`08k`ColP<23_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo00Cooooo0ol02>l3ooooo`Co1^P<1?ob0`8aooooo`03o`000?oooooooooo06kooooo000[oooo
o`03o`000?oooooooooo02[ooooo0_l02>l4oo830Q7ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`06ooooo`?o00S_1?ooool3o`KX3003ooooooob0`;olP<200?olP<2:oooool00ol0
003oooooooooo`1_ooooo`00;?ooool00ol0003oooooooooo`0Uooooo`;o00S_1?ob0`8Cooooo`;o
0000Hoooool2o`0000Wooooo0_l02>l5ooooo`Co1^P<0_ooool4oo830RKooooo00?o0000oooooooo
ool0L?ooool002cooooo00?o0000ooooooooool08Oooool2o`08k`ColP<25_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo00Sooooo0ol02>l6ooooo`Co1^P<0_ooool5oo830R7ooooo
00?o0000ooooooooool0L?ooool002gooooo00?o0000ooooooooool07?ooool2o`08k`ColP<26Ooo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00[ooooo0ol02>l7ooooo`?o1^P<1?oo
ool4oo830Qcooooo00?o0000ooooooooool0LOooool002kooooo00?o0000ooooooooool05oooool2
o`08k`ColP<27?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00cooooo0_l02>l8
ooooo`Co1^P<1?ooool4oo830QOooooo00?o0000ooooooooool0L_ooool002oooooo00?o0000oooo
ooooool04_ooool2o`08k`ColP<27_ooool2o`0006gooooo0_l0000>ooooo`?o00S_2Oooool3o`KX
30Gooooo1Oob0`8Aooooo`03o`000?oooooooooo07?ooooo000_ooooo`03o`000?oooooooooo00oo
oooo1Oob0`8Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool03_ooool3o`08k`Wo
oooo1?l6j0`6ooooo`ColP<23Oooool00ol0003oooooooooo`1cooooo`00<?ooool00ol0003ooooo
ooooo`0:ooooo`ColP<29Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo013ooooo
0_l02>l;ooooo`?o1^P<1oooool4oo830PSooooo00?o0000ooooooooool0B?oooolJoo830P;o0000
4?ooool0037ooooo00?o0000ooooooooool01Oooool4oo830ROooooo0_l0001eooooo`;o00004_oo
ool3o`08k`_ooooo1?l6j0`7ooooo`GolP<20_ooool00ol0003oooooooooo`0Foooooc?olP<26_oo
ool2o`00013ooooo000booooo`03o`000?oooooooooo00ColP<2:_ooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo01;ooooo0ol02>l<ooooo`?o1^P<2OoooolKoo830Uoooooo000@oooo
obGolP<2;Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01Cooooo0_l02>l=oooo
o`Co1^P<1Oooool3o`0007Oooooo000cooooo`;o0000;?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo01Gooooo0ol02>l>ooooo`?o1^P<00?oooooo`000?l00000NOooool003Cooooo
00?o0000ooooooooool0:?ooool2o`0007oooooo0_l0000Hooooo`?o00S_3_oooolDo`KX36Sooooo
000eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0POooool00ol0003ooooooooo
o`0Hooooo`?o00S_2oooool00ol0003oooooooooo`0Aooooob?o1^P<AOooool003Kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01[ooooo0_l02>l8
ooooo`03o`000?oooooooooo03Gooooo8ol6j0`@ooooo`;o00004?ooool003Oooooo00?o0000oooo
ooooool08Oooool2o`0008Oooooo0_l0000Looooo`?o00S_1?ooool00ol0003oooooooooo`1Ioooo
oa3o1^P<0_l0000@ooooo`00=oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool07?ooool3o`08k`03ooooool0003ooooo07cooooo000hooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Mooooo`03o`00
0?l02>oo00S_00;o00S_Noooool003Wooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo01cooooo0_l00003ooooo`Go00S_M_ooool003[ooooo00?o0000
ooooooooool06Oooool2o`00097ooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo1_l02>m`
ooooo`00>_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09?ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0>ooooo`Go00S_Joooool003_ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05?ooool6o`08kfGooooo000looooo`03o`000?oooooooooo01?ooooo0_l0002Iooooo`;o0000
5Oooool00ol0003oooooooooo`0Kooooo`Go00S_H?ooool003gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Ooo
ool5o`08ke_ooooo000nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo1_l02>mEooooo`00?_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0]ooooo`Go00S_D?ooool003oooooo00?o0000ooooooooool02oooool2o`000:?o
oooo0_l0000=ooooo`03o`000?oooooooooo03?ooooo1_l02>m:ooooo`00@?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0jooooo`Go00S_AOooool0047ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool6o`08kcoooooo0011
ooooo`03o`000?oooooooooo00Gooooo0_l0002[ooooo`;o00001oooool00ol0003oooooooooo`16
ooooo`Go00S_>_ooool004;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2]oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool6o`08kcCooooo0013ooooo`05
o`000?ooooooooooooooool00000/Oooool01Ol0003ooooooooooooooooo000005Gooooo1Ol02>l_
ooooo`00A?ooool00ol0003oooooo`00002cooooo`03o`000?oooooo000005_ooooo1Ol02>lZoooo
o`00AOoooonho`00063ooooo1_l02>lTooooo`00oooooomTooooo`Go00S_7oooool00?ooooooJOoo
ool6o`08kaWooooo003oooooofoooooo1Ol02>lDooooo`00oooooomdooooo`;o00S_0_l0000@oooo
o`00oooooomfooooo`;o00004?ooool00?ooooooR?ooool00001\
\>"],
  ImageRangeCache->{{{0, 390}, {88.875, 0}} -> {-4.5326, -16.6827, 0.279654, \
0.279654}},
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"RainbowOfRays", "[", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["0.4`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], ",", 
                    StyleBox["0.65`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]}], "}"}], "]"}], ",", 
              RowBox[{"Move", "[", 
                
                RowBox[{\(DirectVisionPrism[71, 
                    20, {ComponentMedium \[Rule] {BK7, SF14}}]\), ",", 
                  StyleBox["10.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], 
              ",", \(Boundary[{0, \(-50\), \(-50\)}, {100, 50, 
                  50}, {GraphicDesign \[Rule] Off}]\)}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"DirectVisionPrism"],

Cell[BoxData[
    \("-15 ray/surface intersections-"\)], "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["DovePrism[width,length,options]", "Subsection",
  CellTags->"DovePrism"],

Cell[CellGroupData[{

Cell["?DovePrism", "Input",
  CellTags->"DovePrism"],

Cell[BoxData[
    \("DovePrism[width, length, options] refers to a six-sided prism having \
trapezoidal dimensions on two sides and rectangular dimensions on the \
remaining sides. \n\nDovePrism[width, slantlength, length, options] is \
another pattern for DovePrism. DovePrism is commonly used as an image \
rotator. As the prism is rotated, the image that passes through it will \
rotate at twice the angular rate of the prism. DovePrism uses internal \
reflection off the hypotenuse face to rotate the image. The hypotenuse face \
of a dove prism is the face of the largest area.  If the Mirrored->True \
option is given, a reflectorized surface is placed on the hypotenuse of the \
prism. See also: PechanPrism, ReversionPrism, and Prism."\)], "Print",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?DovePrismMirrored", "Input",
  CellTags->"DovePrism"],

Cell[BoxData[
    \("DovePrismMirrored[width, length, options] is an obsolete function that \
has been replaced by DovePrism[width, length, Mirrored->True, options]. \n\n\
DovePrismMirrored[width, slantlength, length, options] is another pattern for \
DovePrismMirrored. See DovePrism."\)], "Print",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DovePrism[10,30]", "Input",
  CellTags->"DovePrism"],

Cell[BoxData[
    TagBox[\(DovePrism[10, 30]\),
      HoldForm]], "Output",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[DovePrism[10,30]];", "Input",
  CellTags->"DovePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.43033 .5939 m
.20111 .43502 L
s
.20111 .43502 m
.94767 .19408 L
s
.20111 .43502 m
.04805 .29263 L
s
.27858 .44895 m
.04805 .29263 L
s
.04805 .29263 m
.82983 .01827 L
s
.43033 .5939 m
.27858 .44895 L
s
.69244 .51781 m
.43033 .5939 L
s
.94767 .19408 m
.69244 .51781 L
s
.82983 .01827 m
.94767 .19408 L
s
.55369 .36169 m
.69244 .51781 L
s
.27858 .44895 m
.55369 .36169 L
s
.82983 .01827 m
.55369 .36169 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{181, 122.875},
  ImageMargins->{{97, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 180}, {121.875, 0}} -> {0.0205183, 0.147119, \
0.00544976, 0.00544976}},
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DovePrism[10,30,Mirrored->True]", "Input",
  CellTags->"DovePrism"],

Cell[BoxData[
    TagBox[\(DovePrism[10, 30, {Mirrored \[Rule] True}]\),
      HoldForm]], "Output",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[DovePrism[10,30,Mirrored->True]];", "Input",
  CellTags->"DovePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
.82983 .01827 m .20111 .43502 L .04805 .29263 L .662 .743 .91 r
F
.82983 .01827 m .94767 .19408 L .20111 .43502 L F
0 g
.5 Mabswid
[ ] 0 setdash
.04805 .29263 m
.20111 .43502 L
s
.20111 .43502 m
.94767 .19408 L
s
.20111 .43502 m
.43033 .5939 L
s
.04805 .29263 m
.82983 .01827 L
s
.04805 .29263 m
.27858 .44895 L
s
.43033 .5939 m
.27858 .44895 L
s
.69244 .51781 m
.43033 .5939 L
s
.82983 .01827 m
.94767 .19408 L
s
.69244 .51781 m
.94767 .19408 L
s
.55369 .36169 m
.69244 .51781 L
s
.27858 .44895 m
.55369 .36169 L
s
.55369 .36169 m
.82983 .01827 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{190, 129},
  ImageMargins->{{84, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 189}, {128, 0}} -> {0.0206381, 0.147119, 0.00518898, \
0.00518898}},
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tConeOfRays[45, NumberOfRays -> 6],
\tDovePrism[6, 8.5, 25.37],
\tBoundary[30]
}];\
\>", "Input",
  CellTags->"DovePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.42216 .58164 m
.10855 .26104 L
s
.91022 .42206 m
.42216 .58164 L
s
.40598 1.06315 m
.42216 .58164 L
s
.66497 .02988 m
.91022 .42206 L
s
.91022 .42206 m
.97657 .93008 L
s
.39324 .71695 m
.29649 .64874 L
s
.29649 .64874 m
.7513 .50241 L
s
.29649 .64874 m
.22978 .58798 L
s
.40598 1.06315 m
.97657 .93008 L
s
.02877 .79167 m
.40598 1.06315 L
s
.039 .916 .04 r
.38017 .59504 m
.59223 .65157 L
s
0 0 0 r
2 Mabswid
.38017 .59504 Mdot
.039 .916 .04 r
.5 Mabswid
.30327 .64772 m
.38017 .59504 L
s
.25961 .66843 m
.30327 .64772 L
s
.25961 .66843 m
.29309 .6384 L
s
.25961 .66843 m
.29696 .63921 L
s
.25961 .66843 m
.32768 .66137 L
s
.25961 .66843 m
.34929 .68126 L
s
.25961 .66843 m
.32466 .66459 L
s
0 0 0 r
2 Mabswid
.30327 .64772 Mdot
.039 .916 .04 r
.5 Mabswid
.45537 .61136 m
.49291 .57608 L
s
0 0 0 r
2 Mabswid
.45537 .61136 Mdot
.039 .916 .04 r
.5 Mabswid
.32466 .66459 m
.45537 .61136 L
s
0 0 0 r
2 Mabswid
.32466 .66459 Mdot
0 g
.5 Mabswid
.32673 .65557 m
.22978 .58798 L
s
.22978 .58798 m
.69716 .42977 L
s
.039 .916 .04 r
.29309 .6384 m
.358 .57312 L
s
0 0 0 r
2 Mabswid
.29309 .6384 Mdot
.039 .916 .04 r
.5 Mabswid
.49291 .57608 m
.65602 .54199 L
s
0 0 0 r
2 Mabswid
.49291 .57608 Mdot
.039 .916 .04 r
.5 Mabswid
.358 .57312 m
.53925 .59364 L
s
0 0 0 r
2 Mabswid
.358 .57312 Mdot
.74268 .26644 Mdot
.039 .916 .04 r
.5 Mabswid
.67467 .44723 m
.74268 .26644 L
s
0 0 0 r
2 Mabswid
.74197 .26536 Mdot
.039 .916 .04 r
.5 Mabswid
.71811 .50402 m
.74197 .26536 L
s
0 g
.10855 .26104 m
.66497 .02988 L
s
.02877 .79167 m
.10855 .26104 L
s
.39324 .71695 m
.32673 .65557 L
s
.63968 .64249 m
.39324 .71695 L
s
.039 .916 .04 r
.29696 .63921 m
.39239 .54682 L
s
0 0 0 r
2 Mabswid
.29696 .63921 Mdot
.039 .916 .04 r
.5 Mabswid
.34929 .68126 m
.65861 .56966 L
s
0 0 0 r
2 Mabswid
.34929 .68126 Mdot
.039 .916 .04 r
.5 Mabswid
.32768 .66137 m
.60095 .50022 L
s
0 0 0 r
2 Mabswid
.32768 .66137 Mdot
.039 .916 .04 r
.5 Mabswid
.44548 .52522 m
.66461 .55249 L
s
0 0 0 r
2 Mabswid
.44548 .52522 Mdot
.039 .916 .04 r
.5 Mabswid
.39239 .54682 m
.44548 .52522 L
s
0 0 0 r
2 Mabswid
.39239 .54682 Mdot
.039 .916 .04 r
.5 Mabswid
.65861 .56966 m
.71652 .53671 L
s
0 0 0 r
2 Mabswid
.65861 .56966 Mdot
.71811 .50402 Mdot
.039 .916 .04 r
.5 Mabswid
.71652 .53671 m
.71811 .50402 L
s
0 g
.7513 .50241 m
.63968 .64249 L
s
.69716 .42977 m
.7513 .50241 L
s
.039 .916 .04 r
.71635 .5019 m
.81459 .35468 L
s
0 0 0 r
2 Mabswid
.71635 .5019 Mdot
.039 .916 .04 r
.5 Mabswid
.6891 .57248 m
.71635 .5019 L
s
0 0 0 r
2 Mabswid
.81459 .35468 Mdot
0 g
.5 Mabswid
.32673 .65557 m
.58019 .57486 L
s
.039 .916 .04 r
.64631 .61428 m
.6891 .57248 L
s
0 0 0 r
2 Mabswid
.64631 .61428 Mdot
.039 .916 .04 r
.5 Mabswid
.59223 .65157 m
.64631 .61428 L
s
0 0 0 r
2 Mabswid
.59223 .65157 Mdot
.71652 .53671 Mdot
.6891 .57248 Mdot
.80452 .33927 Mdot
.039 .916 .04 r
.5 Mabswid
.67631 .44956 m
.80452 .33927 L
s
0 g
.58019 .57486 m
.63968 .64249 L
s
.039 .916 .04 r
.66461 .55249 m
.85611 .54055 L
s
0 0 0 r
2 Mabswid
.66461 .55249 Mdot
.67631 .44956 Mdot
.039 .916 .04 r
.5 Mabswid
.63884 .51069 m
.67631 .44956 L
s
.65602 .54199 m
.79056 .44697 L
s
0 0 0 r
2 Mabswid
.65602 .54199 Mdot
.85611 .54055 Mdot
.67467 .44723 Mdot
.039 .916 .04 r
.5 Mabswid
.66856 .47526 m
.67467 .44723 L
s
.60095 .50022 m
.66856 .47526 L
s
0 0 0 r
2 Mabswid
.60095 .50022 Mdot
0 g
.5 Mabswid
.97657 .93008 m
.6952 .58531 L
s
.69716 .42977 m
.58019 .57486 L
s
0 0 0 r
2 Mabswid
.66856 .47526 Mdot
.039 .916 .04 r
.5 Mabswid
.53925 .59364 m
.58752 .54595 L
s
0 0 0 r
2 Mabswid
.53925 .59364 Mdot
.63884 .51069 Mdot
.039 .916 .04 r
.5 Mabswid
.58752 .54595 m
.63884 .51069 L
s
0 0 0 r
2 Mabswid
.58752 .54595 Mdot
0 g
.5 Mabswid
.6952 .58531 m
.66497 .02988 L
s
0 0 0 r
2 Mabswid
.79056 .44697 Mdot
0 g
.5 Mabswid
.6952 .58531 m
.02877 .79167 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->True,
  ImageSize->{161.812, 175.562},
  ImageMargins->{{105, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 160.812}, {174.562, 0}} -> {0.0486402, -6.07106*^-6, \
0.00533281, 0.00533281}},
  CellTags->"DovePrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["FresnelRhomb[entranceface, options]", "Subsection",
  CellTags->"FresnelRhomb"],

Cell[CellGroupData[{

Cell["?FresnelRhomb", "Input",
  CellTags->"FresnelRhomb"],

Cell[BoxData[
    \("FresnelRhomb[entranceface, options] is a special construction of \
RhomboidPrism that uses total-internal Fresnel reflections to perform an \
achromatic retardation of either 1/4 wave or 1/2 wave on the incident light \
for polarization applications. \n\nThe FullForm option is used to switch \
between half-wave and quarter-wave prism models. The default setting of \
FullForm->False gives a 1/4 wave retardation by modeling a single \
RhomboidPrism-type object to create two internal reflections. FullForm->True \
gives a 1/2 wave retardation by modeling a joined pair of RhomboidPrism-type \
objects to create four internal reflections. FresnelRhomb is aligned with its \
entrance face at x=0 and located in the x-y plane to maintain a parallel exit \
beam with the x-axis. The entranceface specifies the smaller thickness \
dimension of the entrance face (the longer slant dimension is then internally \
calculated). FresnelRhomb uses the DefaultAngleSetting option to set the \
entrance angle. DefaultAngleSetting->Automatic calculates the angle based on \
the given DesignWaveLength and ComponentMedium options. \n\nSee also: \
RhomboidPrism, Prism, PentaPrism, WedgePrism, and PellinBrocaPrism."\)], \
"Print",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelRhomb[10, FullForm->True]", "Input",
  CellTags->"FresnelRhomb"],

Cell[BoxData[
    TagBox[\(FresnelRhomb[
        10, {DefaultAngleSetting \[Rule] 55.4195168081208144`}]\),
      HoldForm]], "Output",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DrawSystem[\ FresnelRhomb[10, \ FullForm -> True], 
        PlotType -> TopView];\)\)], "Input",
  CellTags->"FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59891 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0199351 0.135323 0.0199351 [
[ 0 0 0 0 ]
[ 1 .59891 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .25639 m
.02381 .01426 L
.02381 .01426 L
.02381 .25639 L
.02381 .25639 L
s
.5 .58465 m
.02381 .25639 L
.02381 .25639 L
.5 .58465 L
.5 .58465 L
s
.5 .34252 m
.02381 .01426 L
.02381 .01426 L
.5 .34252 L
.5 .34252 L
s
.02381 .25639 m
.02381 .01426 L
.5 .34252 L
.5 .58465 L
.02381 .25639 L
s
.02381 .25639 m
.02381 .01426 L
.5 .34252 L
.5 .58465 L
.02381 .25639 L
s
.97619 .01426 m
.5 .34252 L
.5 .34252 L
.97619 .01426 L
.97619 .01426 L
s
.97619 .25639 m
.5 .58465 L
.5 .58465 L
.97619 .25639 L
.97619 .25639 L
s
.97619 .01426 m
.97619 .25639 L
.97619 .25639 L
.97619 .01426 L
.97619 .01426 L
s
.5 .34252 m
.5 .58465 L
.97619 .25639 L
.97619 .01426 L
.5 .34252 L
s
.5 .34252 m
.5 .58465 L
.97619 .25639 L
.97619 .01426 L
.5 .34252 L
s
0 0 m
1 0 L
1 .59891 L
0 .59891 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{185.938, 111.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 184.938}, {110.312, 0}} -> {-1.29656, -6.78833, \
0.272347, 0.272347}},
  CellTags->"FresnelRhomb"],

Cell[BoxData[
    TagBox[\(DrawSystem[{FresnelRhomb[
            10, {DefaultAngleSetting \[Rule] 55.4195168081208144`, 
              FullForm \[Rule] True}]}, PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"FresnelRhomb"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowSystem[%];\)\)], "Input",
  CellTags->"FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64867 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.00611 -0.14588 1.00611 [
[ 0 0 0 0 ]
[ 1 .64867 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .64867 L
0 .64867 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.60935 .41025 m
.8548 .14797 L
s
.61291 .54206 m
.60935 .41025 L
s
.5199 .30953 m
.60935 .41025 L
s
.60935 .41025 m
.15456 .38198 L
s
.15456 .38198 m
.04099 .27838 L
s
.14275 .51473 m
.15456 .38198 L
s
.86812 .28747 m
.61291 .54206 L
s
.52049 .44455 m
.61291 .54206 L
s
.61291 .54206 m
.14275 .51473 L
s
.14275 .51473 m
.02452 .41433 L
s
.04099 .27838 m
.5199 .30953 L
s
.5199 .30953 m
.52049 .44455 L
s
.76696 .01882 m
.5199 .30953 L
s
.04099 .27838 m
.02452 .41433 L
s
.02452 .41433 m
.52049 .44455 L
s
.77754 .16129 m
.52049 .44455 L
s
.8548 .14797 m
.76696 .01882 L
s
.86812 .28747 m
.8548 .14797 L
s
.86812 .28747 m
.77754 .16129 L
s
.76696 .01882 m
.77754 .16129 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{180, 116.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 179}, {115.75, 0}} -> {-0.0015589, 0.144991, \
0.00557008, 0.00557008}},
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{Ray[Polarization->{1,1,0}],
\tMove[FresnelRhomb[10, FullForm->True],10],
\tBoundary[75]},
\tPlotType->TopView, ThresholdIntensity->10];\
\>", "Input",
  CellTags->"FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0126984 0.5 0.0126984 [
[.45412 .38479 -36 -4.5 ]
[.45412 .38479 36 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15079 .57712 m
.15079 .42288 L
.15079 .42288 L
.15079 .57712 L
.15079 .57712 L
s
.45412 .78622 m
.15079 .57712 L
.15079 .57712 L
.45412 .78622 L
.45412 .78622 L
s
.45412 .63198 m
.15079 .42288 L
.15079 .42288 L
.45412 .63198 L
.45412 .63198 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.15079 .57712 m
.15079 .42288 L
.45412 .63198 L
.45412 .78622 L
.15079 .57712 L
s
.75745 .57712 m
.45412 .78622 L
.45412 .78622 L
.75745 .57712 L
.75745 .57712 L
s
.75745 .42288 m
.45412 .63198 L
.45412 .63198 L
.75745 .42288 L
.75745 .42288 L
s
.75745 .42288 m
.75745 .57712 L
.75745 .57712 L
.75745 .42288 L
.75745 .42288 L
s
.45412 .63198 m
.45412 .78622 L
.75745 .57712 L
.75745 .42288 L
.45412 .63198 L
s
.45412 .63198 m
.45412 .78622 L
.75745 .57712 L
.75745 .42288 L
.45412 .63198 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.15079 .5 L
s
0 0 0 r
2 Mabswid
.15079 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.15079 .5 m
.26266 .5 L
s
0 0 0 r
2 Mabswid
.26266 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.26266 .5 m
.34225 .7091 L
s
0 0 0 r
2 Mabswid
.34225 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.34225 .7091 m
.56599 .7091 L
s
0 0 0 r
2 Mabswid
.56599 .7091 Mdot
.039 .916 .04 r
.5 Mabswid
.56599 .7091 m
.64558 .5 L
s
0 0 0 r
2 Mabswid
.64558 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.64558 .5 m
.75745 .5 L
s
0 0 0 r
2 Mabswid
.75745 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.75745 .5 m
.97619 .5 L
s
0 0 0 r
2 Mabswid
.97619 .5 Mdot
[(FresnelRhomb)] .45412 .38479 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{189.812, 189.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 188.812}, {188.812, 0}} -> {-1.87539, -39.3754, \
0.417085, 0.417085}},
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = DrawSystem[
\t{Ray[Polarization->{1,1,0}],
\tMove[FresnelRhomb[10],10],
\tBoundary[50]},
\tPlotType->TopView, ThresholdIntensity->10];\
\>", "Input",
  CellTags->"FresnelRhomb"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .61567 m
.21429 .38433 L
.21429 .38433 L
.21429 .61567 L
.21429 .61567 L
s
.66928 .92932 m
.66928 .69798 L
.66928 .69798 L
.66928 .92932 L
.66928 .92932 L
s
.66928 .92932 m
.21429 .61567 L
.21429 .61567 L
.66928 .92932 L
.66928 .92932 L
s
.66928 .69798 m
.21429 .38433 L
.21429 .38433 L
.66928 .69798 L
.66928 .69798 L
s
.21429 .61567 m
.21429 .38433 L
.66928 .69798 L
.66928 .92932 L
.21429 .61567 L
s
.21429 .61567 m
.21429 .38433 L
.66928 .69798 L
.66928 .92932 L
.21429 .61567 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2 Mabswid
.21429 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .5 m
.38209 .5 L
s
0 0 0 r
2 Mabswid
.38209 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.38209 .5 m
.50148 .81365 L
s
0 0 0 r
2 Mabswid
.50148 .81365 Mdot
.039 .916 .04 r
.5 Mabswid
.50148 .81365 m
.66928 .81365 L
s
0 0 0 r
2 Mabswid
.66928 .81365 Mdot
.039 .916 .04 r
.5 Mabswid
.66928 .81365 m
.97619 .81365 L
s
0 0 0 r
2 Mabswid
.97619 .81365 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{195.875, 195.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 194.875}, {194.875, 0}} -> {-1.25026, -26.2503, \
0.269406, 0.269406}},
  CellTags->"FresnelRhomb"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PechanPrism[smallentranceside, options]", "Subsection",
  CellTags->"PechanPrism"],

Cell[CellGroupData[{

Cell["?PechanPrism", "Input",
  CellTags->"PechanPrism"],

Cell[BoxData[
    \("PechanPrism[smallentranceside, options] refers to an image erecting \
prism that does not deviate or displace an image but can be used to invert or \
revert an image. \n\nPechanPrism performs the same function as the DovePrism, \
but it also works with converging and diverging beams. PechanPrism is located \
with its small entrance face centered in the y-z plane and its rotation axis \
aligned with the x-axis. Two surfaces of PechanPrism are reflectorized. \
PechanPrism uses the option SurfaceSeparation to denote the airspace between \
the two prism halves. SurfaceSeparation->relativevector gives a relative \
vector factor that gets multiplied by smallentranceside to determine the \
airspaced offset for the prism interface. See also: DovePrism, WedgePrism, \
RhomboidalPrism, RoofPrism, AmiciRoofPrism, and Prism."\)], "Print",
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["prism = PechanPrism[10]", "Input",
  CellTags->"PechanPrism"],

Cell[BoxData[
    TagBox[\(PechanPrism[10]\),
      HoldForm]], "Output",
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[PechanPrism[10],PlotType->TopView];", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52301 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0788978 0.757559 0.0788978 [
[ 0 0 0 0 ]
[ 1 1.52301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.15205 m
.02381 .36307 L
.02381 .36307 L
.02381 1.15205 L
.02381 1.15205 L
s
.97619 .19967 m
.02381 1.15204 L
.02381 1.15204 L
.97619 .19967 L
.97619 .19967 L
s
.5 g
.81279 .03626 m
.02381 .36307 L
.02381 .36307 L
.81279 .03626 L
.81279 .03626 L
F
0 g
.81279 .03626 m
.02381 .36307 L
.02381 .36307 L
.81279 .03626 L
.81279 .03626 L
s
.97619 .03626 m
.81279 .03626 L
.81279 .03626 L
.97619 .03626 L
.97619 .03626 L
s
.97619 .19966 m
.97619 .03626 L
.97619 .03626 L
.97619 .19966 L
.97619 .19966 L
s
.97619 .03626 m
.81279 .03626 L
.02381 .36307 L
.02381 1.15205 L
.97619 .19966 L
.97619 .03626 L
s
.97619 .03626 m
.81279 .03626 L
.02381 .36307 L
.02381 1.15205 L
.97619 .19966 L
.97619 .03626 L
s
.97619 1.48673 m
.97619 .20756 L
.97619 .20756 L
.97619 1.48673 L
.97619 1.48673 L
s
.97619 .20755 m
.02381 1.15993 L
.02381 1.15993 L
.97619 .20755 L
.97619 .20755 L
s
.5 g
.81279 1.48675 m
.02381 1.15994 L
.02381 1.15994 L
.81279 1.48675 L
.81279 1.48675 L
F
0 g
.81279 1.48675 m
.02381 1.15994 L
.02381 1.15994 L
.81279 1.48675 L
.81279 1.48675 L
s
.97619 1.48675 m
.81279 1.48675 L
.81279 1.48675 L
.97619 1.48675 L
.97619 1.48675 L
s
.97619 .20755 m
.02381 1.15994 L
.81279 1.48675 L
.97619 1.48675 L
.97619 .20755 L
s
.97619 .20755 m
.02381 1.15994 L
.81279 1.48675 L
.97619 1.48675 L
.97619 .20755 L
s
0 0 m
1 0 L
1 1.52301 L
0 1.52301 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{85.4375, 129.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 84.4375}, {128.312, 0}} -> {-0.315998, -9.60187, \
0.150443, 0.150443}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03738 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0323612 1.13543 1.11022e-16 1.13543 [
[ 0 0 0 0 ]
[ 1 1.03738 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.03738 L
0 1.03738 L
closepath
clip
newpath
.86172 .55115 m .41506 .57859 L .40458 .94008 L .671 .439 .561 r
F
.86172 .55115 m .40458 .94008 L .89052 .9151 L F
0 g
.5 Mabswid
[ ] 0 setdash
.86172 .55115 m
.89052 .9151 L
s
.86172 .55115 m
.94196 .52643 L
s
.40458 .94008 m
.41506 .57858 L
s
.41506 .57859 m
.86172 .55115 L
s
.40458 .94008 m
.41506 .57859 L
s
.94196 .52643 m
.63245 .09665 L
s
.97828 .89255 m
.94196 .52643 L
s
.97828 .89254 m
.94196 .52642 L
s
.94196 .52642 m
.63246 .09665 L
s
.40458 .94008 m
.89052 .9151 L
s
.89052 .9151 m
.97828 .89255 L
s
.49138 .06638 m .18561 .34333 L .1516 .72413 L .256 .075 .434 r
F
0 g
.29197 .45239 m
.41506 .57859 L
s
.97828 .89255 m
.64295 .49331 L
s
.64295 .49332 m
.97828 .89254 L
s
.49138 .06638 m .1516 .72413 L .48657 .46467 L .256 .075 .434 r
F
0 g
.1516 .72413 m
.48657 .46467 L
s
.41506 .57858 m
.45564 .48863 L
s
.48713 .41882 m
.63245 .09665 L
s
.41506 .57859 m
.45564 .48863 L
s
.48713 .41882 m
.63245 .09665 L
s
.40458 .94008 m
.64295 .49331 L
s
.1516 .72413 m
.40458 .94008 L
s
.40458 .94008 m
.64295 .49331 L
s
.18561 .34333 m
.49138 .06638 L
s
.1516 .72413 m
.18561 .34333 L
s
.63246 .09665 m
.64295 .49332 L
s
.64295 .49331 m
.63245 .09665 L
s
.64295 .49331 m
.63245 .09665 L
s
.63245 .09665 m
.58425 .02971 L
s
.48657 .46467 m
.49138 .06638 L
s
.49138 .06638 m
.58425 .02971 L
s
.58425 .02971 m
.58968 .42989 L
s
.64295 .49331 m
.58968 .42989 L
s
.48657 .46467 m
.58968 .42989 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{111.438, 115.562},
  ImageMargins->{{42, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 110.438}, {114.562, 0}} -> {0.0284847, -4.56827*^-6, \
0.00797516, 0.00797516}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8,NumberOfRays->7],
Move[PechanPrism[10],{15,0,180}],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91922 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.461989 0.047619 [
[.45069 .89732 -33 -4.5 ]
[.45069 .89732 33 4.5 ]
[ 0 0 0 0 ]
[ 1 .91922 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7381 .22389 m
.7381 .70008 L
.7381 .70008 L
.7381 .22389 L
.7381 .22389 L
s
.16328 .79871 m
.73809 .2239 L
.73809 .2239 L
.16328 .79871 L
.16328 .79871 L
s
.5 g
.2619 .89733 m
.7381 .70008 L
.7381 .70008 L
.2619 .89733 L
.2619 .89733 L
F
0 g
.2619 .89733 m
.7381 .70008 L
.7381 .70008 L
.2619 .89733 L
.2619 .89733 L
s
.16328 .89733 m
.2619 .89733 L
.2619 .89733 L
.16328 .89733 L
.16328 .89733 L
s
.16328 .79871 m
.16328 .89733 L
.16328 .89733 L
.16328 .79871 L
.16328 .79871 L
s
.16328 .89733 m
.2619 .89733 L
.7381 .70008 L
.7381 .22389 L
.16328 .79871 L
.16328 .89733 L
s
.16328 .89733 m
.2619 .89733 L
.7381 .70008 L
.7381 .22389 L
.16328 .79871 L
.16328 .89733 L
s
.16328 .02189 m
.16328 .79394 L
.16328 .79394 L
.16328 .02189 L
.16328 .02189 L
s
.16328 .79395 m
.73809 .21914 L
.73809 .21914 L
.16328 .79395 L
.16328 .79395 L
s
.5 g
.2619 .02189 m
.7381 .21913 L
.7381 .21913 L
.2619 .02189 L
.2619 .02189 L
F
0 g
.2619 .02189 m
.7381 .21913 L
.7381 .21913 L
.2619 .02189 L
.2619 .02189 L
s
.16328 .02189 m
.2619 .02189 L
.2619 .02189 L
.16328 .02189 L
.16328 .02189 L
s
.16328 .79395 m
.7381 .21913 L
.2619 .02189 L
.16328 .02189 L
.16328 .79395 L
s
.16328 .79395 m
.7381 .21913 L
.2619 .02189 L
.16328 .02189 L
.16328 .79395 L
s
.039 .916 .04 r
.02381 .27151 m
.16328 .27151 L
s
0 0 0 r
2 Mabswid
.16328 .27151 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33501 m
.16328 .33501 L
s
0 0 0 r
2 Mabswid
.16328 .33501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .3985 m
.16328 .3985 L
s
0 0 0 r
2 Mabswid
.16328 .3985 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46199 m
.16328 .46199 L
s
0 0 0 r
2 Mabswid
.16328 .46199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52548 m
.16328 .52548 L
s
0 0 0 r
2 Mabswid
.16328 .52548 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58897 m
.16328 .58897 L
s
0 0 0 r
2 Mabswid
.16328 .58897 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .65247 m
.16328 .65247 L
s
0 0 0 r
2 Mabswid
.16328 .65247 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .27151 m
.68572 .27151 L
s
0 0 0 r
2 Mabswid
.68572 .27151 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .33501 m
.62222 .33501 L
s
0 0 0 r
2 Mabswid
.62222 .33501 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .3985 m
.55873 .3985 L
s
0 0 0 r
2 Mabswid
.55873 .3985 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .46199 m
.49524 .46199 L
s
0 0 0 r
2 Mabswid
.49524 .46199 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .52548 m
.43175 .52548 L
s
0 0 0 r
2 Mabswid
.43175 .52548 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .58897 m
.36826 .58897 L
s
0 0 0 r
2 Mabswid
.36826 .58897 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .65247 m
.30476 .65247 L
s
0 0 0 r
2 Mabswid
.30476 .65247 Mdot
.039 .916 .04 r
.5 Mabswid
.68572 .27151 m
.68572 .19744 L
s
0 0 0 r
2 Mabswid
.68572 .19744 Mdot
.039 .916 .04 r
.5 Mabswid
.62222 .33501 m
.62222 .17114 L
s
0 0 0 r
2 Mabswid
.62222 .17114 Mdot
.039 .916 .04 r
.5 Mabswid
.55873 .3985 m
.55873 .14484 L
s
0 0 0 r
2 Mabswid
.55873 .14484 Mdot
.039 .916 .04 r
.5 Mabswid
.49524 .46199 m
.49524 .11854 L
s
0 0 0 r
2 Mabswid
.49524 .11854 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .52548 m
.43175 .09224 L
s
0 0 0 r
2 Mabswid
.43175 .09224 Mdot
.039 .916 .04 r
.5 Mabswid
.36826 .58897 m
.36826 .06594 L
s
0 0 0 r
2 Mabswid
.36826 .06594 Mdot
.039 .916 .04 r
.5 Mabswid
.30476 .65247 m
.30476 .03964 L
s
0 0 0 r
2 Mabswid
.30476 .03964 Mdot
.039 .916 .04 r
.5 Mabswid
.68572 .19744 m
.16328 .71987 L
s
0 0 0 r
2 Mabswid
.16328 .71987 Mdot
.039 .916 .04 r
.5 Mabswid
.62222 .17114 m
.16328 .63008 L
s
0 0 0 r
2 Mabswid
.16328 .63008 Mdot
.039 .916 .04 r
.5 Mabswid
.55873 .14484 m
.16328 .54029 L
s
0 0 0 r
2 Mabswid
.16328 .54029 Mdot
.039 .916 .04 r
.5 Mabswid
.49524 .11854 m
.16328 .4505 L
s
0 0 0 r
2 Mabswid
.16328 .4505 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .09224 m
.16328 .3607 L
s
0 0 0 r
2 Mabswid
.16328 .3607 Mdot
.039 .916 .04 r
.5 Mabswid
.36826 .06594 m
.16328 .27091 L
s
0 0 0 r
2 Mabswid
.16328 .27091 Mdot
.039 .916 .04 r
.5 Mabswid
.30476 .03964 m
.16328 .18112 L
s
0 0 0 r
2 Mabswid
.16328 .18112 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .71987 m
.20032 .75691 L
s
0 0 0 r
2 Mabswid
.20032 .75691 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .63008 m
.24522 .71201 L
s
0 0 0 r
2 Mabswid
.24522 .71201 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .54029 m
.29011 .66712 L
s
0 0 0 r
2 Mabswid
.29011 .66712 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .4505 m
.33501 .62222 L
s
0 0 0 r
2 Mabswid
.33501 .62222 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .3607 m
.3799 .57733 L
s
0 0 0 r
2 Mabswid
.3799 .57733 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .27091 m
.4248 .53243 L
s
0 0 0 r
2 Mabswid
.4248 .53243 Mdot
.039 .916 .04 r
.5 Mabswid
.16328 .18112 m
.46969 .48753 L
s
0 0 0 r
2 Mabswid
.46969 .48753 Mdot
.039 .916 .04 r
.5 Mabswid
.20032 .75691 m
.2027 .75929 L
s
0 0 0 r
2 Mabswid
.2027 .75929 Mdot
.039 .916 .04 r
.5 Mabswid
.24522 .71201 m
.2476 .71439 L
s
0 0 0 r
2 Mabswid
.2476 .71439 Mdot
.039 .916 .04 r
.5 Mabswid
.29011 .66712 m
.29249 .6695 L
s
0 0 0 r
2 Mabswid
.29249 .6695 Mdot
.039 .916 .04 r
.5 Mabswid
.33501 .62222 m
.33739 .6246 L
s
0 0 0 r
2 Mabswid
.33739 .6246 Mdot
.039 .916 .04 r
.5 Mabswid
.3799 .57733 m
.38228 .57971 L
s
0 0 0 r
2 Mabswid
.38228 .57971 Mdot
.039 .916 .04 r
.5 Mabswid
.4248 .53243 m
.42718 .53481 L
s
0 0 0 r
2 Mabswid
.42718 .53481 Mdot
.039 .916 .04 r
.5 Mabswid
.46969 .48753 m
.47208 .48992 L
s
0 0 0 r
2 Mabswid
.47208 .48992 Mdot
.039 .916 .04 r
.5 Mabswid
.2027 .75929 m
.31765 .87424 L
s
0 0 0 r
2 Mabswid
.31765 .87424 Mdot
.039 .916 .04 r
.5 Mabswid
.2476 .71439 m
.38114 .84794 L
s
0 0 0 r
2 Mabswid
.38114 .84794 Mdot
.039 .916 .04 r
.5 Mabswid
.29249 .6695 m
.44463 .82164 L
s
0 0 0 r
2 Mabswid
.44463 .82164 Mdot
.039 .916 .04 r
.5 Mabswid
.33739 .6246 m
.50813 .79534 L
s
0 0 0 r
2 Mabswid
.50813 .79534 Mdot
.039 .916 .04 r
.5 Mabswid
.38228 .57971 m
.57162 .76904 L
s
0 0 0 r
2 Mabswid
.57162 .76904 Mdot
.039 .916 .04 r
.5 Mabswid
.42718 .53481 m
.63511 .74274 L
s
0 0 0 r
2 Mabswid
.63511 .74274 Mdot
.039 .916 .04 r
.5 Mabswid
.47208 .48992 m
.6986 .71644 L
s
0 0 0 r
2 Mabswid
.6986 .71644 Mdot
.039 .916 .04 r
.5 Mabswid
.31765 .87424 m
.31765 .64434 L
s
0 0 0 r
2 Mabswid
.31765 .64434 Mdot
.039 .916 .04 r
.5 Mabswid
.38114 .84794 m
.38114 .58085 L
s
0 0 0 r
2 Mabswid
.38114 .58085 Mdot
.039 .916 .04 r
.5 Mabswid
.44463 .82164 m
.44463 .51736 L
s
0 0 0 r
2 Mabswid
.44463 .51736 Mdot
.039 .916 .04 r
.5 Mabswid
.50813 .79534 m
.50813 .45386 L
s
0 0 0 r
2 Mabswid
.50813 .45386 Mdot
.039 .916 .04 r
.5 Mabswid
.57162 .76904 m
.57162 .39037 L
s
0 0 0 r
2 Mabswid
.57162 .39037 Mdot
.039 .916 .04 r
.5 Mabswid
.63511 .74274 m
.63511 .32688 L
s
0 0 0 r
2 Mabswid
.63511 .32688 Mdot
.039 .916 .04 r
.5 Mabswid
.6986 .71644 m
.6986 .26339 L
s
0 0 0 r
2 Mabswid
.6986 .26339 Mdot
.039 .916 .04 r
.5 Mabswid
.31765 .64434 m
.7381 .64434 L
s
0 0 0 r
2 Mabswid
.7381 .64434 Mdot
.039 .916 .04 r
.5 Mabswid
.38114 .58085 m
.7381 .58085 L
s
0 0 0 r
2 Mabswid
.7381 .58085 Mdot
.039 .916 .04 r
.5 Mabswid
.44463 .51736 m
.7381 .51736 L
s
0 0 0 r
2 Mabswid
.7381 .51736 Mdot
.039 .916 .04 r
.5 Mabswid
.50813 .45386 m
.7381 .45386 L
s
0 0 0 r
2 Mabswid
.7381 .45386 Mdot
.039 .916 .04 r
.5 Mabswid
.57162 .39037 m
.7381 .39037 L
s
0 0 0 r
2 Mabswid
.7381 .39037 Mdot
.039 .916 .04 r
.5 Mabswid
.63511 .32688 m
.7381 .32688 L
s
0 0 0 r
2 Mabswid
.7381 .32688 Mdot
.039 .916 .04 r
.5 Mabswid
.6986 .26339 m
.7381 .26339 L
s
0 0 0 r
2 Mabswid
.7381 .26339 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .64434 m
.97619 .64434 L
s
0 0 0 r
2 Mabswid
.97619 .64434 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .58085 m
.97619 .58085 L
s
0 0 0 r
2 Mabswid
.97619 .58085 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .51736 m
.97619 .51736 L
s
0 0 0 r
2 Mabswid
.97619 .51736 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .45386 m
.97619 .45386 L
s
0 0 0 r
2 Mabswid
.97619 .45386 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .39037 m
.97619 .39037 L
s
0 0 0 r
2 Mabswid
.97619 .39037 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .32688 m
.97619 .32688 L
s
0 0 0 r
2 Mabswid
.97619 .32688 Mdot
.039 .916 .04 r
.5 Mabswid
.7381 .26339 m
.97619 .26339 L
s
0 0 0 r
2 Mabswid
.97619 .26339 Mdot
[(PechanPrism)] .45069 .89732 0 0 Mshowa
0 0 m
1 0 L
1 .91922 L
0 .91922 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{155.375, 142.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 154.375}, {141.812, 0}} -> {-0.59273, -9.70187, \
0.137234, 0.137234}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8,NumberOfRays->7],
Move[PechanPrism[10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91922 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.457227 0.047619 [
[.45407 .02189 -33 -4.5 ]
[.45407 .02189 33 4.5 ]
[ 0 0 0 0 ]
[ 1 .91922 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .69532 m
.16667 .21913 L
.16667 .21913 L
.16667 .69532 L
.16667 .69532 L
s
.74148 .12051 m
.16667 .69532 L
.16667 .69532 L
.74148 .12051 L
.74148 .12051 L
s
.5 g
.64286 .02189 m
.16667 .21913 L
.16667 .21913 L
.64286 .02189 L
.64286 .02189 L
F
0 g
.64286 .02189 m
.16667 .21913 L
.16667 .21913 L
.64286 .02189 L
.64286 .02189 L
s
.74148 .02189 m
.64286 .02189 L
.64286 .02189 L
.74148 .02189 L
.74148 .02189 L
s
.74148 .12051 m
.74148 .02189 L
.74148 .02189 L
.74148 .12051 L
.74148 .12051 L
s
.74148 .02189 m
.64286 .02189 L
.16667 .21913 L
.16667 .69532 L
.74148 .12051 L
.74148 .02189 L
s
.74148 .02189 m
.64286 .02189 L
.16667 .21913 L
.16667 .69532 L
.74148 .12051 L
.74148 .02189 L
s
.74148 .89732 m
.74148 .12527 L
.74148 .12527 L
.74148 .89732 L
.74148 .89732 L
s
.74148 .12527 m
.16667 .70008 L
.16667 .70008 L
.74148 .12527 L
.74148 .12527 L
s
.5 g
.64286 .89733 m
.16667 .70008 L
.16667 .70008 L
.64286 .89733 L
.64286 .89733 L
F
0 g
.64286 .89733 m
.16667 .70008 L
.16667 .70008 L
.64286 .89733 L
.64286 .89733 L
s
.74148 .89733 m
.64286 .89733 L
.64286 .89733 L
.74148 .89733 L
.74148 .89733 L
s
.74148 .12527 m
.16667 .70008 L
.64286 .89733 L
.74148 .89733 L
.74148 .12527 L
s
.74148 .12527 m
.16667 .70008 L
.64286 .89733 L
.74148 .89733 L
.74148 .12527 L
s
.039 .916 .04 r
.02381 .26675 m
.16667 .26675 L
s
0 0 0 r
2 Mabswid
.16667 .26675 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33024 m
.16667 .33024 L
s
0 0 0 r
2 Mabswid
.16667 .33024 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39374 m
.16667 .39374 L
s
0 0 0 r
2 Mabswid
.16667 .39374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45723 m
.16667 .45723 L
s
0 0 0 r
2 Mabswid
.16667 .45723 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52072 m
.16667 .52072 L
s
0 0 0 r
2 Mabswid
.16667 .52072 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58421 m
.16667 .58421 L
s
0 0 0 r
2 Mabswid
.16667 .58421 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .6477 m
.16667 .6477 L
s
0 0 0 r
2 Mabswid
.16667 .6477 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .26675 m
.59524 .26675 L
s
0 0 0 r
2 Mabswid
.59524 .26675 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .33024 m
.53174 .33024 L
s
0 0 0 r
2 Mabswid
.53174 .33024 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .39374 m
.46825 .39374 L
s
0 0 0 r
2 Mabswid
.46825 .39374 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .45723 m
.40476 .45723 L
s
0 0 0 r
2 Mabswid
.40476 .45723 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .52072 m
.34127 .52072 L
s
0 0 0 r
2 Mabswid
.34127 .52072 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .58421 m
.27778 .58421 L
s
0 0 0 r
2 Mabswid
.27778 .58421 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .6477 m
.21428 .6477 L
s
0 0 0 r
2 Mabswid
.21428 .6477 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .26675 m
.59524 .04161 L
s
0 0 0 r
2 Mabswid
.59524 .04161 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .33024 m
.53174 .06791 L
s
0 0 0 r
2 Mabswid
.53174 .06791 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .39374 m
.46825 .09421 L
s
0 0 0 r
2 Mabswid
.46825 .09421 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45723 m
.40476 .12051 L
s
0 0 0 r
2 Mabswid
.40476 .12051 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .52072 m
.34127 .14681 L
s
0 0 0 r
2 Mabswid
.34127 .14681 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .58421 m
.27778 .17311 L
s
0 0 0 r
2 Mabswid
.27778 .17311 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .6477 m
.21428 .19941 L
s
0 0 0 r
2 Mabswid
.21428 .19941 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .04161 m
.7078 .15418 L
s
0 0 0 r
2 Mabswid
.7078 .15418 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .06791 m
.66291 .19908 L
s
0 0 0 r
2 Mabswid
.66291 .19908 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .09421 m
.61801 .24397 L
s
0 0 0 r
2 Mabswid
.61801 .24397 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .12051 m
.57312 .28887 L
s
0 0 0 r
2 Mabswid
.57312 .28887 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .14681 m
.52822 .33376 L
s
0 0 0 r
2 Mabswid
.52822 .33376 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .17311 m
.48333 .37866 L
s
0 0 0 r
2 Mabswid
.48333 .37866 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .19941 m
.43843 .42356 L
s
0 0 0 r
2 Mabswid
.43843 .42356 Mdot
.039 .916 .04 r
.5 Mabswid
.7078 .15418 m
.71019 .15656 L
s
0 0 0 r
2 Mabswid
.71019 .15656 Mdot
.039 .916 .04 r
.5 Mabswid
.66291 .19908 m
.66529 .20146 L
s
0 0 0 r
2 Mabswid
.66529 .20146 Mdot
.039 .916 .04 r
.5 Mabswid
.61801 .24397 m
.62039 .24635 L
s
0 0 0 r
2 Mabswid
.62039 .24635 Mdot
.039 .916 .04 r
.5 Mabswid
.57312 .28887 m
.5755 .29125 L
s
0 0 0 r
2 Mabswid
.5755 .29125 Mdot
.039 .916 .04 r
.5 Mabswid
.52822 .33376 m
.5306 .33615 L
s
0 0 0 r
2 Mabswid
.5306 .33615 Mdot
.039 .916 .04 r
.5 Mabswid
.48333 .37866 m
.48571 .38104 L
s
0 0 0 r
2 Mabswid
.48571 .38104 Mdot
.039 .916 .04 r
.5 Mabswid
.43843 .42356 m
.44081 .42594 L
s
0 0 0 r
2 Mabswid
.44081 .42594 Mdot
.039 .916 .04 r
.5 Mabswid
.71019 .15656 m
.74148 .18786 L
s
0 0 0 r
2 Mabswid
.74148 .18786 Mdot
.039 .916 .04 r
.5 Mabswid
.66529 .20146 m
.74148 .27765 L
s
0 0 0 r
2 Mabswid
.74148 .27765 Mdot
.039 .916 .04 r
.5 Mabswid
.62039 .24635 m
.74148 .36744 L
s
0 0 0 r
2 Mabswid
.74148 .36744 Mdot
.039 .916 .04 r
.5 Mabswid
.5755 .29125 m
.74148 .45723 L
s
0 0 0 r
2 Mabswid
.74148 .45723 Mdot
.039 .916 .04 r
.5 Mabswid
.5306 .33615 m
.74148 .54702 L
s
0 0 0 r
2 Mabswid
.74148 .54702 Mdot
.039 .916 .04 r
.5 Mabswid
.48571 .38104 m
.74148 .63681 L
s
0 0 0 r
2 Mabswid
.74148 .63681 Mdot
.039 .916 .04 r
.5 Mabswid
.44081 .42594 m
.74148 .7266 L
s
0 0 0 r
2 Mabswid
.74148 .7266 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .18786 m
.21092 .71842 L
s
0 0 0 r
2 Mabswid
.21092 .71842 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .27765 m
.27441 .74471 L
s
0 0 0 r
2 Mabswid
.27441 .74471 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .36744 m
.33791 .77101 L
s
0 0 0 r
2 Mabswid
.33791 .77101 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .45723 m
.4014 .79731 L
s
0 0 0 r
2 Mabswid
.4014 .79731 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .54702 m
.46489 .82361 L
s
0 0 0 r
2 Mabswid
.46489 .82361 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .63681 m
.52838 .84991 L
s
0 0 0 r
2 Mabswid
.52838 .84991 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .7266 m
.59187 .87621 L
s
0 0 0 r
2 Mabswid
.59187 .87621 Mdot
.039 .916 .04 r
.5 Mabswid
.21092 .71842 m
.21092 .65583 L
s
0 0 0 r
2 Mabswid
.21092 .65583 Mdot
.039 .916 .04 r
.5 Mabswid
.27441 .74471 m
.27441 .59234 L
s
0 0 0 r
2 Mabswid
.27441 .59234 Mdot
.039 .916 .04 r
.5 Mabswid
.33791 .77101 m
.33791 .52884 L
s
0 0 0 r
2 Mabswid
.33791 .52884 Mdot
.039 .916 .04 r
.5 Mabswid
.4014 .79731 m
.4014 .46535 L
s
0 0 0 r
2 Mabswid
.4014 .46535 Mdot
.039 .916 .04 r
.5 Mabswid
.46489 .82361 m
.46489 .40186 L
s
0 0 0 r
2 Mabswid
.46489 .40186 Mdot
.039 .916 .04 r
.5 Mabswid
.52838 .84991 m
.52838 .33837 L
s
0 0 0 r
2 Mabswid
.52838 .33837 Mdot
.039 .916 .04 r
.5 Mabswid
.59187 .87621 m
.59187 .27488 L
s
0 0 0 r
2 Mabswid
.59187 .27488 Mdot
.039 .916 .04 r
.5 Mabswid
.21092 .65583 m
.74148 .65583 L
s
0 0 0 r
2 Mabswid
.74148 .65583 Mdot
.039 .916 .04 r
.5 Mabswid
.27441 .59234 m
.74148 .59234 L
s
0 0 0 r
2 Mabswid
.74148 .59234 Mdot
.039 .916 .04 r
.5 Mabswid
.33791 .52884 m
.74148 .52884 L
s
0 0 0 r
2 Mabswid
.74148 .52884 Mdot
.039 .916 .04 r
.5 Mabswid
.4014 .46535 m
.74148 .46535 L
s
0 0 0 r
2 Mabswid
.74148 .46535 Mdot
.039 .916 .04 r
.5 Mabswid
.46489 .40186 m
.74148 .40186 L
s
0 0 0 r
2 Mabswid
.74148 .40186 Mdot
.039 .916 .04 r
.5 Mabswid
.52838 .33837 m
.74148 .33837 L
s
0 0 0 r
2 Mabswid
.74148 .33837 Mdot
.039 .916 .04 r
.5 Mabswid
.59187 .27488 m
.74148 .27488 L
s
0 0 0 r
2 Mabswid
.74148 .27488 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .65583 m
.97619 .65583 L
s
0 0 0 r
2 Mabswid
.97619 .65583 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .59234 m
.97619 .59234 L
s
0 0 0 r
2 Mabswid
.97619 .59234 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .52884 m
.97619 .52884 L
s
0 0 0 r
2 Mabswid
.97619 .52884 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .46535 m
.97619 .46535 L
s
0 0 0 r
2 Mabswid
.97619 .46535 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .40186 m
.97619 .40186 L
s
0 0 0 r
2 Mabswid
.97619 .40186 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .33837 m
.97619 .33837 L
s
0 0 0 r
2 Mabswid
.97619 .33837 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .27488 m
.97619 .27488 L
s
0 0 0 r
2 Mabswid
.97619 .27488 Mdot
[(PechanPrism)] .45407 .02189 0 0 Mshowa
0 0 m
1 0 L
1 .91922 L
0 .91922 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{156.125, 143.438},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 155.125}, {142.438, 0}} -> {-0.596081, -9.75694, \
0.136614, 0.136614}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8,NumberOfRays->7],
Move[PechanPrism[10,SurfaceSeparation->{1/10,0}],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91422 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.457108 0.047619 [
[.45407 .02177 -33 -4.5 ]
[.45407 .02177 33 4.5 ]
[ 0 0 0 0 ]
[ 1 .91422 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .6952 m
.16667 .21901 L
.16667 .21901 L
.16667 .6952 L
.16667 .6952 L
s
.74148 .12039 m
.16667 .6952 L
.16667 .6952 L
.74148 .12039 L
.74148 .12039 L
s
.5 g
.64286 .02177 m
.16667 .21901 L
.16667 .21901 L
.64286 .02177 L
.64286 .02177 L
F
0 g
.64286 .02177 m
.16667 .21901 L
.16667 .21901 L
.64286 .02177 L
.64286 .02177 L
s
.74148 .02177 m
.64286 .02177 L
.64286 .02177 L
.74148 .02177 L
.74148 .02177 L
s
.74148 .12039 m
.74148 .02177 L
.74148 .02177 L
.74148 .12039 L
.74148 .12039 L
s
.74148 .02177 m
.64286 .02177 L
.16667 .21901 L
.16667 .6952 L
.74148 .12039 L
.74148 .02177 L
s
.74148 .02177 m
.64286 .02177 L
.16667 .21901 L
.16667 .6952 L
.74148 .12039 L
.74148 .02177 L
s
.7891 .89244 m
.7891 .12039 L
.7891 .12039 L
.7891 .89244 L
.7891 .89244 L
s
.7891 .12039 m
.21429 .6952 L
.21429 .6952 L
.7891 .12039 L
.7891 .12039 L
s
.5 g
.69048 .89245 m
.21429 .6952 L
.21429 .6952 L
.69048 .89245 L
.69048 .89245 L
F
0 g
.69048 .89245 m
.21429 .6952 L
.21429 .6952 L
.69048 .89245 L
.69048 .89245 L
s
.7891 .89245 m
.69048 .89245 L
.69048 .89245 L
.7891 .89245 L
.7891 .89245 L
s
.7891 .12039 m
.21429 .6952 L
.69048 .89245 L
.7891 .89245 L
.7891 .12039 L
s
.7891 .12039 m
.21429 .6952 L
.69048 .89245 L
.7891 .89245 L
.7891 .12039 L
s
.039 .916 .04 r
.02381 .26663 m
.16667 .26663 L
s
0 0 0 r
2 Mabswid
.16667 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33012 m
.16667 .33012 L
s
0 0 0 r
2 Mabswid
.16667 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39362 m
.16667 .39362 L
s
0 0 0 r
2 Mabswid
.16667 .39362 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45711 m
.16667 .45711 L
s
0 0 0 r
2 Mabswid
.16667 .45711 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5206 m
.16667 .5206 L
s
0 0 0 r
2 Mabswid
.16667 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58409 m
.16667 .58409 L
s
0 0 0 r
2 Mabswid
.16667 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64758 m
.16667 .64758 L
s
0 0 0 r
2 Mabswid
.16667 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .26663 m
.59524 .26663 L
s
0 0 0 r
2 Mabswid
.59524 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .33012 m
.53174 .33012 L
s
0 0 0 r
2 Mabswid
.53174 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .39362 m
.46825 .39362 L
s
0 0 0 r
2 Mabswid
.46825 .39362 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .45711 m
.40476 .45711 L
s
0 0 0 r
2 Mabswid
.40476 .45711 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .5206 m
.34127 .5206 L
s
0 0 0 r
2 Mabswid
.34127 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .58409 m
.27778 .58409 L
s
0 0 0 r
2 Mabswid
.27778 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .64758 m
.21428 .64758 L
s
0 0 0 r
2 Mabswid
.21428 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .26663 m
.59524 .04149 L
s
0 0 0 r
2 Mabswid
.59524 .04149 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .33012 m
.53174 .06779 L
s
0 0 0 r
2 Mabswid
.53174 .06779 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .39362 m
.46825 .09409 L
s
0 0 0 r
2 Mabswid
.46825 .09409 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45711 m
.40476 .12039 L
s
0 0 0 r
2 Mabswid
.40476 .12039 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5206 m
.34127 .14669 L
s
0 0 0 r
2 Mabswid
.34127 .14669 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .58409 m
.27778 .17299 L
s
0 0 0 r
2 Mabswid
.27778 .17299 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .64758 m
.21428 .19929 L
s
0 0 0 r
2 Mabswid
.21428 .19929 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .04149 m
.7078 .15406 L
s
0 0 0 r
2 Mabswid
.7078 .15406 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .06779 m
.66291 .19896 L
s
0 0 0 r
2 Mabswid
.66291 .19896 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .09409 m
.61801 .24385 L
s
0 0 0 r
2 Mabswid
.61801 .24385 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .12039 m
.57312 .28875 L
s
0 0 0 r
2 Mabswid
.57312 .28875 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .14669 m
.52822 .33365 L
s
0 0 0 r
2 Mabswid
.52822 .33365 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .17299 m
.48333 .37854 L
s
0 0 0 r
2 Mabswid
.48333 .37854 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .19929 m
.43843 .42344 L
s
0 0 0 r
2 Mabswid
.43843 .42344 Mdot
.039 .916 .04 r
.5 Mabswid
.7078 .15406 m
.73161 .17787 L
s
0 0 0 r
2 Mabswid
.73161 .17787 Mdot
.039 .916 .04 r
.5 Mabswid
.66291 .19896 m
.68672 .22277 L
s
0 0 0 r
2 Mabswid
.68672 .22277 Mdot
.039 .916 .04 r
.5 Mabswid
.61801 .24385 m
.64182 .26766 L
s
0 0 0 r
2 Mabswid
.64182 .26766 Mdot
.039 .916 .04 r
.5 Mabswid
.57312 .28875 m
.59693 .31256 L
s
0 0 0 r
2 Mabswid
.59693 .31256 Mdot
.039 .916 .04 r
.5 Mabswid
.52822 .33365 m
.55203 .35746 L
s
0 0 0 r
2 Mabswid
.55203 .35746 Mdot
.039 .916 .04 r
.5 Mabswid
.48333 .37854 m
.50714 .40235 L
s
0 0 0 r
2 Mabswid
.50714 .40235 Mdot
.039 .916 .04 r
.5 Mabswid
.43843 .42344 m
.46224 .44725 L
s
0 0 0 r
2 Mabswid
.46224 .44725 Mdot
.039 .916 .04 r
.5 Mabswid
.73161 .17787 m
.7891 .23536 L
s
0 0 0 r
2 Mabswid
.7891 .23536 Mdot
.039 .916 .04 r
.5 Mabswid
.68672 .22277 m
.7891 .32515 L
s
0 0 0 r
2 Mabswid
.7891 .32515 Mdot
.039 .916 .04 r
.5 Mabswid
.64182 .26766 m
.7891 .41494 L
s
0 0 0 r
2 Mabswid
.7891 .41494 Mdot
.039 .916 .04 r
.5 Mabswid
.59693 .31256 m
.7891 .50473 L
s
0 0 0 r
2 Mabswid
.7891 .50473 Mdot
.039 .916 .04 r
.5 Mabswid
.55203 .35746 m
.7891 .59452 L
s
0 0 0 r
2 Mabswid
.7891 .59452 Mdot
.039 .916 .04 r
.5 Mabswid
.50714 .40235 m
.7891 .68431 L
s
0 0 0 r
2 Mabswid
.7891 .68431 Mdot
.039 .916 .04 r
.5 Mabswid
.46224 .44725 m
.7891 .7741 L
s
0 0 0 r
2 Mabswid
.7891 .7741 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .23536 m
.29558 .72888 L
s
0 0 0 r
2 Mabswid
.29558 .72888 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .32515 m
.35907 .75518 L
s
0 0 0 r
2 Mabswid
.35907 .75518 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .41494 m
.42256 .78147 L
s
0 0 0 r
2 Mabswid
.42256 .78147 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .50473 m
.48606 .80777 L
s
0 0 0 r
2 Mabswid
.48606 .80777 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .59452 m
.54955 .83407 L
s
0 0 0 r
2 Mabswid
.54955 .83407 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .68431 m
.61304 .86037 L
s
0 0 0 r
2 Mabswid
.61304 .86037 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .7741 m
.67653 .88667 L
s
0 0 0 r
2 Mabswid
.67653 .88667 Mdot
.039 .916 .04 r
.5 Mabswid
.29558 .72888 m
.29558 .61391 L
s
0 0 0 r
2 Mabswid
.29558 .61391 Mdot
.039 .916 .04 r
.5 Mabswid
.35907 .75518 m
.35907 .55042 L
s
0 0 0 r
2 Mabswid
.35907 .55042 Mdot
.039 .916 .04 r
.5 Mabswid
.42256 .78147 m
.42256 .48692 L
s
0 0 0 r
2 Mabswid
.42256 .48692 Mdot
.039 .916 .04 r
.5 Mabswid
.48606 .80777 m
.48606 .42343 L
s
0 0 0 r
2 Mabswid
.48606 .42343 Mdot
.039 .916 .04 r
.5 Mabswid
.54955 .83407 m
.54955 .35994 L
s
0 0 0 r
2 Mabswid
.54955 .35994 Mdot
.039 .916 .04 r
.5 Mabswid
.61304 .86037 m
.61304 .29645 L
s
0 0 0 r
2 Mabswid
.61304 .29645 Mdot
.039 .916 .04 r
.5 Mabswid
.67653 .88667 m
.67653 .23296 L
s
0 0 0 r
2 Mabswid
.67653 .23296 Mdot
.039 .916 .04 r
.5 Mabswid
.29558 .61391 m
.7891 .61391 L
s
0 0 0 r
2 Mabswid
.7891 .61391 Mdot
.039 .916 .04 r
.5 Mabswid
.35907 .55042 m
.7891 .55042 L
s
0 0 0 r
2 Mabswid
.7891 .55042 Mdot
.039 .916 .04 r
.5 Mabswid
.42256 .48692 m
.7891 .48692 L
s
0 0 0 r
2 Mabswid
.7891 .48692 Mdot
.039 .916 .04 r
.5 Mabswid
.48606 .42343 m
.7891 .42343 L
s
0 0 0 r
2 Mabswid
.7891 .42343 Mdot
.039 .916 .04 r
.5 Mabswid
.54955 .35994 m
.7891 .35994 L
s
0 0 0 r
2 Mabswid
.7891 .35994 Mdot
.039 .916 .04 r
.5 Mabswid
.61304 .29645 m
.7891 .29645 L
s
0 0 0 r
2 Mabswid
.7891 .29645 Mdot
.039 .916 .04 r
.5 Mabswid
.67653 .23296 m
.7891 .23296 L
s
0 0 0 r
2 Mabswid
.7891 .23296 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .61391 m
.97619 .61391 L
s
0 0 0 r
2 Mabswid
.97619 .61391 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .55042 m
.97619 .55042 L
s
0 0 0 r
2 Mabswid
.97619 .55042 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .48692 m
.97619 .48692 L
s
0 0 0 r
2 Mabswid
.97619 .48692 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .42343 m
.97619 .42343 L
s
0 0 0 r
2 Mabswid
.97619 .42343 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .35994 m
.97619 .35994 L
s
0 0 0 r
2 Mabswid
.97619 .35994 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .29645 m
.97619 .29645 L
s
0 0 0 r
2 Mabswid
.97619 .29645 Mdot
.039 .916 .04 r
.5 Mabswid
.7891 .23296 m
.97619 .23296 L
s
0 0 0 r
2 Mabswid
.97619 .23296 Mdot
[(PechanPrism)] .45407 .02177 0 0 Mshowa
0 0 m
1 0 L
1 .91422 L
0 .91422 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{196, 179.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 195}, {178.125, 0}} -> {-0.524462, -9.62795, \
0.107943, 0.107943}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8,NumberOfRays->7],
Move[PechanPrism[10,SurfaceSeparation->{0,0}],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91422 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.457108 0.047619 [
[.45407 .02177 -33 -4.5 ]
[.45407 .02177 33 4.5 ]
[ 0 0 0 0 ]
[ 1 .91422 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .6952 m
.16667 .21901 L
.16667 .21901 L
.16667 .6952 L
.16667 .6952 L
s
.74148 .12039 m
.16667 .6952 L
.16667 .6952 L
.74148 .12039 L
.74148 .12039 L
s
.5 g
.64286 .02177 m
.16667 .21901 L
.16667 .21901 L
.64286 .02177 L
.64286 .02177 L
F
0 g
.64286 .02177 m
.16667 .21901 L
.16667 .21901 L
.64286 .02177 L
.64286 .02177 L
s
.74148 .02177 m
.64286 .02177 L
.64286 .02177 L
.74148 .02177 L
.74148 .02177 L
s
.74148 .12039 m
.74148 .02177 L
.74148 .02177 L
.74148 .12039 L
.74148 .12039 L
s
.74148 .02177 m
.64286 .02177 L
.16667 .21901 L
.16667 .6952 L
.74148 .12039 L
.74148 .02177 L
s
.74148 .02177 m
.64286 .02177 L
.16667 .21901 L
.16667 .6952 L
.74148 .12039 L
.74148 .02177 L
s
.74148 .89244 m
.74148 .12039 L
.74148 .12039 L
.74148 .89244 L
.74148 .89244 L
s
.74148 .12039 m
.16667 .6952 L
.16667 .6952 L
.74148 .12039 L
.74148 .12039 L
s
.5 g
.64286 .89245 m
.16667 .6952 L
.16667 .6952 L
.64286 .89245 L
.64286 .89245 L
F
0 g
.64286 .89245 m
.16667 .6952 L
.16667 .6952 L
.64286 .89245 L
.64286 .89245 L
s
.74148 .89245 m
.64286 .89245 L
.64286 .89245 L
.74148 .89245 L
.74148 .89245 L
s
.74148 .12039 m
.16667 .6952 L
.64286 .89245 L
.74148 .89245 L
.74148 .12039 L
s
.74148 .12039 m
.16667 .6952 L
.64286 .89245 L
.74148 .89245 L
.74148 .12039 L
s
.039 .916 .04 r
.02381 .26663 m
.16667 .26663 L
s
0 0 0 r
2 Mabswid
.16667 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .33012 m
.16667 .33012 L
s
0 0 0 r
2 Mabswid
.16667 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39362 m
.16667 .39362 L
s
0 0 0 r
2 Mabswid
.16667 .39362 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45711 m
.16667 .45711 L
s
0 0 0 r
2 Mabswid
.16667 .45711 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5206 m
.16667 .5206 L
s
0 0 0 r
2 Mabswid
.16667 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58409 m
.16667 .58409 L
s
0 0 0 r
2 Mabswid
.16667 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .64758 m
.16667 .64758 L
s
0 0 0 r
2 Mabswid
.16667 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .26663 m
.59524 .26663 L
s
0 0 0 r
2 Mabswid
.59524 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .33012 m
.53174 .33012 L
s
0 0 0 r
2 Mabswid
.53174 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .39362 m
.46825 .39362 L
s
0 0 0 r
2 Mabswid
.46825 .39362 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .45711 m
.40476 .45711 L
s
0 0 0 r
2 Mabswid
.40476 .45711 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .5206 m
.34127 .5206 L
s
0 0 0 r
2 Mabswid
.34127 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .58409 m
.27778 .58409 L
s
0 0 0 r
2 Mabswid
.27778 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .64758 m
.21428 .64758 L
s
0 0 0 r
2 Mabswid
.21428 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .26663 m
.59524 .04149 L
s
0 0 0 r
2 Mabswid
.59524 .04149 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .33012 m
.53174 .06779 L
s
0 0 0 r
2 Mabswid
.53174 .06779 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .39362 m
.46825 .09409 L
s
0 0 0 r
2 Mabswid
.46825 .09409 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .45711 m
.40476 .12039 L
s
0 0 0 r
2 Mabswid
.40476 .12039 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5206 m
.34127 .14669 L
s
0 0 0 r
2 Mabswid
.34127 .14669 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .58409 m
.27778 .17299 L
s
0 0 0 r
2 Mabswid
.27778 .17299 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .64758 m
.21428 .19929 L
s
0 0 0 r
2 Mabswid
.21428 .19929 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .04149 m
.7078 .15406 L
s
0 0 0 r
2 Mabswid
.7078 .15406 Mdot
.039 .916 .04 r
.5 Mabswid
.53174 .06779 m
.66291 .19896 L
s
0 0 0 r
2 Mabswid
.66291 .19896 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .09409 m
.61801 .24385 L
s
0 0 0 r
2 Mabswid
.61801 .24385 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .12039 m
.57312 .28875 L
s
0 0 0 r
2 Mabswid
.57312 .28875 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .14669 m
.52822 .33365 L
s
0 0 0 r
2 Mabswid
.52822 .33365 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .17299 m
.48333 .37854 L
s
0 0 0 r
2 Mabswid
.48333 .37854 Mdot
.039 .916 .04 r
.5 Mabswid
.21428 .19929 m
.43843 .42344 L
s
0 0 0 r
2 Mabswid
.43843 .42344 Mdot
.039 .916 .04 r
.5 Mabswid
.7078 .15406 m
.7078 .15406 L
s
0 0 0 r
2 Mabswid
.7078 .15406 Mdot
.039 .916 .04 r
.5 Mabswid
.66291 .19896 m
.66291 .19896 L
s
0 0 0 r
2 Mabswid
.66291 .19896 Mdot
.039 .916 .04 r
.5 Mabswid
.61801 .24385 m
.61801 .24385 L
s
0 0 0 r
2 Mabswid
.61801 .24385 Mdot
.039 .916 .04 r
.5 Mabswid
.57312 .28875 m
.57312 .28875 L
s
0 0 0 r
2 Mabswid
.57312 .28875 Mdot
.039 .916 .04 r
.5 Mabswid
.52822 .33365 m
.52822 .33365 L
s
0 0 0 r
2 Mabswid
.52822 .33365 Mdot
.039 .916 .04 r
.5 Mabswid
.48333 .37854 m
.48333 .37854 L
s
0 0 0 r
2 Mabswid
.48333 .37854 Mdot
.039 .916 .04 r
.5 Mabswid
.43843 .42344 m
.43843 .42344 L
s
0 0 0 r
2 Mabswid
.43843 .42344 Mdot
.039 .916 .04 r
.5 Mabswid
.7078 .15406 m
.74148 .18774 L
s
0 0 0 r
2 Mabswid
.74148 .18774 Mdot
.039 .916 .04 r
.5 Mabswid
.66291 .19896 m
.74148 .27753 L
s
0 0 0 r
2 Mabswid
.74148 .27753 Mdot
.039 .916 .04 r
.5 Mabswid
.61801 .24385 m
.74148 .36732 L
s
0 0 0 r
2 Mabswid
.74148 .36732 Mdot
.039 .916 .04 r
.5 Mabswid
.57312 .28875 m
.74148 .45711 L
s
0 0 0 r
2 Mabswid
.74148 .45711 Mdot
.039 .916 .04 r
.5 Mabswid
.52822 .33365 m
.74148 .5469 L
s
0 0 0 r
2 Mabswid
.74148 .5469 Mdot
.039 .916 .04 r
.5 Mabswid
.48333 .37854 m
.74148 .63669 L
s
0 0 0 r
2 Mabswid
.74148 .63669 Mdot
.039 .916 .04 r
.5 Mabswid
.43843 .42344 m
.74148 .72649 L
s
0 0 0 r
2 Mabswid
.74148 .72649 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .18774 m
.21429 .71493 L
s
0 0 0 r
2 Mabswid
.21429 .71493 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .27753 m
.27778 .74123 L
s
0 0 0 r
2 Mabswid
.27778 .74123 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .36732 m
.34127 .76753 L
s
0 0 0 r
2 Mabswid
.34127 .76753 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .45711 m
.40476 .79383 L
s
0 0 0 r
2 Mabswid
.40476 .79383 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .5469 m
.46826 .82013 L
s
0 0 0 r
2 Mabswid
.46826 .82013 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .63669 m
.53175 .84643 L
s
0 0 0 r
2 Mabswid
.53175 .84643 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .72649 m
.59524 .87272 L
s
0 0 0 r
2 Mabswid
.59524 .87272 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .71493 m
.21429 .64758 L
s
0 0 0 r
2 Mabswid
.21429 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .74123 m
.27778 .58409 L
s
0 0 0 r
2 Mabswid
.27778 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .76753 m
.34127 .5206 L
s
0 0 0 r
2 Mabswid
.34127 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .79383 m
.40476 .4571 L
s
0 0 0 r
2 Mabswid
.40476 .4571 Mdot
.039 .916 .04 r
.5 Mabswid
.46826 .82013 m
.46826 .39361 L
s
0 0 0 r
2 Mabswid
.46826 .39361 Mdot
.039 .916 .04 r
.5 Mabswid
.53175 .84643 m
.53175 .33012 L
s
0 0 0 r
2 Mabswid
.53175 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .87272 m
.59524 .26663 L
s
0 0 0 r
2 Mabswid
.59524 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .64758 m
.74148 .64758 L
s
0 0 0 r
2 Mabswid
.74148 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.27778 .58409 m
.74148 .58409 L
s
0 0 0 r
2 Mabswid
.74148 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .5206 m
.74148 .5206 L
s
0 0 0 r
2 Mabswid
.74148 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .4571 m
.74148 .4571 L
s
0 0 0 r
2 Mabswid
.74148 .4571 Mdot
.039 .916 .04 r
.5 Mabswid
.46826 .39361 m
.74148 .39361 L
s
0 0 0 r
2 Mabswid
.74148 .39361 Mdot
.039 .916 .04 r
.5 Mabswid
.53175 .33012 m
.74148 .33012 L
s
0 0 0 r
2 Mabswid
.74148 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .26663 m
.74148 .26663 L
s
0 0 0 r
2 Mabswid
.74148 .26663 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .64758 m
.97619 .64758 L
s
0 0 0 r
2 Mabswid
.97619 .64758 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .58409 m
.97619 .58409 L
s
0 0 0 r
2 Mabswid
.97619 .58409 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .5206 m
.97619 .5206 L
s
0 0 0 r
2 Mabswid
.97619 .5206 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .4571 m
.97619 .4571 L
s
0 0 0 r
2 Mabswid
.97619 .4571 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .39361 m
.97619 .39361 L
s
0 0 0 r
2 Mabswid
.97619 .39361 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .33012 m
.97619 .33012 L
s
0 0 0 r
2 Mabswid
.97619 .33012 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .26663 m
.97619 .26663 L
s
0 0 0 r
2 Mabswid
.97619 .26663 Mdot
[(PechanPrism)] .45407 .02177 0 0 Mshowa
0 0 m
1 0 L
1 .91422 L
0 .91422 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{176, 160.875},
  ImageMargins->{{41, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 175}, {159.875, 0}} -> {-0.554422, -9.685, 0.120622, \
0.120622}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{WedgeOfRays[90,NumberOfRays->10],
Move[PechanPrism[10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.5 0.047619 [
[.45407 .06467 -33 -4.5 ]
[.45407 .06467 33 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .7381 m
.16667 .2619 L
.16667 .2619 L
.16667 .7381 L
.16667 .7381 L
s
.74148 .16328 m
.16667 .73809 L
.16667 .73809 L
.74148 .16328 L
.74148 .16328 L
s
.5 g
.64286 .06466 m
.16667 .2619 L
.16667 .2619 L
.64286 .06466 L
.64286 .06466 L
F
0 g
.64286 .06466 m
.16667 .2619 L
.16667 .2619 L
.64286 .06466 L
.64286 .06466 L
s
.74148 .06466 m
.64286 .06466 L
.64286 .06466 L
.74148 .06466 L
.74148 .06466 L
s
.74148 .16328 m
.74148 .06466 L
.74148 .06466 L
.74148 .16328 L
.74148 .16328 L
s
.74148 .06466 m
.64286 .06466 L
.16667 .2619 L
.16667 .7381 L
.74148 .16328 L
.74148 .06466 L
s
.74148 .06466 m
.64286 .06466 L
.16667 .2619 L
.16667 .7381 L
.74148 .16328 L
.74148 .06466 L
s
.74148 .9401 m
.74148 .16805 L
.74148 .16805 L
.74148 .9401 L
.74148 .9401 L
s
.74148 .16804 m
.16667 .74285 L
.16667 .74285 L
.74148 .16804 L
.74148 .16804 L
s
.5 g
.64286 .9401 m
.16667 .74286 L
.16667 .74286 L
.64286 .9401 L
.64286 .9401 L
F
0 g
.64286 .9401 m
.16667 .74286 L
.16667 .74286 L
.64286 .9401 L
.64286 .9401 L
s
.74148 .9401 m
.64286 .9401 L
.64286 .9401 L
.74148 .9401 L
.74148 .9401 L
s
.74148 .16804 m
.16667 .74286 L
.64286 .9401 L
.74148 .9401 L
.74148 .16804 L
s
.74148 .16804 m
.16667 .74286 L
.64286 .9401 L
.74148 .9401 L
.74148 .16804 L
s
.039 .916 .04 r
.02381 .5 m
.16667 .35714 L
s
0 0 0 r
2 Mabswid
.16667 .35714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .39997 L
s
0 0 0 r
2 Mabswid
.16667 .39997 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .43338 L
s
0 0 0 r
2 Mabswid
.16667 .43338 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .46172 L
s
0 0 0 r
2 Mabswid
.16667 .46172 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .4875 L
s
0 0 0 r
2 Mabswid
.16667 .4875 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .5125 L
s
0 0 0 r
2 Mabswid
.16667 .5125 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .53828 L
s
0 0 0 r
2 Mabswid
.16667 .53828 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .56662 L
s
0 0 0 r
2 Mabswid
.16667 .56662 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .60003 L
s
0 0 0 r
2 Mabswid
.16667 .60003 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .64286 L
s
0 0 0 r
2 Mabswid
.16667 .64286 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .35714 m
.72297 .06466 L
s
0 0 0 r
2 Mabswid
.72297 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .39997 m
.73748 .16728 L
s
0 0 0 r
2 Mabswid
.73748 .16728 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .43338 m
.59557 .30919 L
s
0 0 0 r
2 Mabswid
.59557 .30919 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .46172 m
.5008 .40396 L
s
0 0 0 r
2 Mabswid
.5008 .40396 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .4875 m
.43253 .47223 L
s
0 0 0 r
2 Mabswid
.43253 .47223 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .5125 m
.38 .52476 L
s
0 0 0 r
2 Mabswid
.38 .52476 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .53828 m
.33703 .56773 L
s
0 0 0 r
2 Mabswid
.33703 .56773 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .56662 m
.29964 .60512 L
s
0 0 0 r
2 Mabswid
.29964 .60512 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .60003 m
.26475 .64001 L
s
0 0 0 r
2 Mabswid
.26475 .64001 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .64286 m
.22909 .67567 L
s
0 0 0 r
2 Mabswid
.22909 .67567 Mdot
.039 .916 .04 r
.5 Mabswid
.72297 .06466 m
.74148 .07439 L
s
0 0 0 r
2 Mabswid
.74148 .07439 Mdot
.039 .916 .04 r
.5 Mabswid
.73748 .16728 m
.74148 .15746 L
s
0 0 0 r
2 Mabswid
.74148 .15746 Mdot
.039 .916 .04 r
.5 Mabswid
.59557 .30919 m
.66637 .06466 L
s
0 0 0 r
2 Mabswid
.66637 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.5008 .40396 m
.55302 .10187 L
s
0 0 0 r
2 Mabswid
.55302 .10187 Mdot
.039 .916 .04 r
.5 Mabswid
.43253 .47223 m
.45139 .14397 L
s
0 0 0 r
2 Mabswid
.45139 .14397 Mdot
.039 .916 .04 r
.5 Mabswid
.38 .52476 m
.36029 .1817 L
s
0 0 0 r
2 Mabswid
.36029 .1817 Mdot
.039 .916 .04 r
.5 Mabswid
.33703 .56773 m
.34373 .56579 L
s
0 0 0 r
2 Mabswid
.34373 .56579 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .60512 m
.30459 .60493 L
s
0 0 0 r
2 Mabswid
.30459 .60493 Mdot
.039 .916 .04 r
.5 Mabswid
.26475 .64001 m
.26887 .64066 L
s
0 0 0 r
2 Mabswid
.26887 .64066 Mdot
.039 .916 .04 r
.5 Mabswid
.22909 .67567 m
.23267 .67685 L
s
0 0 0 r
2 Mabswid
.23267 .67685 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .07439 m
.97619 .3091 L
s
0 0 0 r
2 Mabswid
.97619 .3091 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .15746 m
.70365 .06466 L
s
0 0 0 r
2 Mabswid
.70365 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.66637 .06466 m
.68542 .02381 L
s
0 0 0 r
2 Mabswid
.68542 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.55302 .10187 m
.69955 .20521 L
s
0 0 0 r
2 Mabswid
.69955 .20521 Mdot
.039 .916 .04 r
.5 Mabswid
.45139 .14397 m
.61498 .28978 L
s
0 0 0 r
2 Mabswid
.61498 .28978 Mdot
.039 .916 .04 r
.5 Mabswid
.36029 .1817 m
.53126 .3735 L
s
0 0 0 r
2 Mabswid
.53126 .3735 Mdot
.039 .916 .04 r
.5 Mabswid
.34373 .56579 m
.74148 .63455 L
s
0 0 0 r
2 Mabswid
.74148 .63455 Mdot
.039 .916 .04 r
.5 Mabswid
.30459 .60493 m
.74148 .73144 L
s
0 0 0 r
2 Mabswid
.74148 .73144 Mdot
.039 .916 .04 r
.5 Mabswid
.26887 .64066 m
.74148 .83331 L
s
0 0 0 r
2 Mabswid
.74148 .83331 Mdot
.039 .916 .04 r
.5 Mabswid
.23267 .67685 m
.73337 .9401 L
s
0 0 0 r
2 Mabswid
.73337 .9401 Mdot
.039 .916 .04 r
.5 Mabswid
.70365 .06466 m
.67505 .02381 L
s
0 0 0 r
2 Mabswid
.67505 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.69955 .20521 m
.70257 .20696 L
s
0 0 0 r
2 Mabswid
.70257 .20696 Mdot
.039 .916 .04 r
.5 Mabswid
.61498 .28978 m
.61757 .29195 L
s
0 0 0 r
2 Mabswid
.61757 .29195 Mdot
.039 .916 .04 r
.5 Mabswid
.53126 .3735 m
.53343 .37609 L
s
0 0 0 r
2 Mabswid
.53343 .37609 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .63455 m
.97619 .69744 L
s
0 0 0 r
2 Mabswid
.97619 .69744 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .73144 m
.97619 .84089 L
s
0 0 0 r
2 Mabswid
.97619 .84089 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .83331 m
.94553 .97619 L
s
0 0 0 r
2 Mabswid
.94553 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.73337 .9401 m
.74148 .93584 L
s
0 0 0 r
2 Mabswid
.74148 .93584 Mdot
.039 .916 .04 r
.5 Mabswid
.70257 .20696 m
.74148 .2344 L
s
0 0 0 r
2 Mabswid
.74148 .2344 Mdot
.039 .916 .04 r
.5 Mabswid
.61757 .29195 m
.74148 .4024 L
s
0 0 0 r
2 Mabswid
.74148 .4024 Mdot
.039 .916 .04 r
.5 Mabswid
.53343 .37609 m
.74148 .60951 L
s
0 0 0 r
2 Mabswid
.74148 .60951 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .93584 m
.97619 .70113 L
s
0 0 0 r
2 Mabswid
.97619 .70113 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .2344 m
.97619 .6601 L
s
0 0 0 r
2 Mabswid
.97619 .6601 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .4024 m
.29833 .79739 L
s
0 0 0 r
2 Mabswid
.29833 .79739 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .60951 m
.49967 .88079 L
s
0 0 0 r
2 Mabswid
.49967 .88079 Mdot
.039 .916 .04 r
.5 Mabswid
.29833 .79739 m
.28821 .62131 L
s
0 0 0 r
2 Mabswid
.28821 .62131 Mdot
.039 .916 .04 r
.5 Mabswid
.49967 .88079 m
.52838 .38114 L
s
0 0 0 r
2 Mabswid
.52838 .38114 Mdot
.039 .916 .04 r
.5 Mabswid
.28821 .62131 m
.74148 .64735 L
s
0 0 0 r
2 Mabswid
.74148 .64735 Mdot
.039 .916 .04 r
.5 Mabswid
.52838 .38114 m
.74148 .3689 L
s
0 0 0 r
2 Mabswid
.74148 .3689 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .64735 m
.97619 .66789 L
s
0 0 0 r
2 Mabswid
.97619 .66789 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .3689 m
.97619 .34836 L
s
0 0 0 r
2 Mabswid
.97619 .34836 Mdot
[(PechanPrism)] .45407 .06467 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{183.438, 183.438},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 182.438}, {182.438, 0}} -> {-0.500105, -10.5001, \
0.115109, 0.115109}},
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{WedgeOfRays[90,NumberOfRays->10],
Move[PechanPrism[10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView,QuickTrace->False];\
\>", "Input",
  CellTags->"PechanPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.5 0.047619 [
[.45407 .06467 -33 -4.5 ]
[.45407 .06467 33 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .7381 m
.16667 .2619 L
.16667 .2619 L
.16667 .7381 L
.16667 .7381 L
s
.74148 .16328 m
.16667 .73809 L
.16667 .73809 L
.74148 .16328 L
.74148 .16328 L
s
.5 g
.64286 .06466 m
.16667 .2619 L
.16667 .2619 L
.64286 .06466 L
.64286 .06466 L
F
0 g
.64286 .06466 m
.16667 .2619 L
.16667 .2619 L
.64286 .06466 L
.64286 .06466 L
s
.74148 .06466 m
.64286 .06466 L
.64286 .06466 L
.74148 .06466 L
.74148 .06466 L
s
.74148 .16328 m
.74148 .06466 L
.74148 .06466 L
.74148 .16328 L
.74148 .16328 L
s
.74148 .06466 m
.64286 .06466 L
.16667 .2619 L
.16667 .7381 L
.74148 .16328 L
.74148 .06466 L
s
.74148 .06466 m
.64286 .06466 L
.16667 .2619 L
.16667 .7381 L
.74148 .16328 L
.74148 .06466 L
s
.74148 .9401 m
.74148 .16805 L
.74148 .16805 L
.74148 .9401 L
.74148 .9401 L
s
.74148 .16804 m
.16667 .74285 L
.16667 .74285 L
.74148 .16804 L
.74148 .16804 L
s
.5 g
.64286 .9401 m
.16667 .74286 L
.16667 .74286 L
.64286 .9401 L
.64286 .9401 L
F
0 g
.64286 .9401 m
.16667 .74286 L
.16667 .74286 L
.64286 .9401 L
.64286 .9401 L
s
.74148 .9401 m
.64286 .9401 L
.64286 .9401 L
.74148 .9401 L
.74148 .9401 L
s
.74148 .16804 m
.16667 .74286 L
.64286 .9401 L
.74148 .9401 L
.74148 .16804 L
s
.74148 .16804 m
.16667 .74286 L
.64286 .9401 L
.74148 .9401 L
.74148 .16804 L
s
.039 .916 .04 r
.02381 .5 m
.16667 .35714 L
s
0 0 0 r
2 Mabswid
.16667 .35714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .39997 L
s
0 0 0 r
2 Mabswid
.16667 .39997 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .43338 L
s
0 0 0 r
2 Mabswid
.16667 .43338 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .46172 L
s
0 0 0 r
2 Mabswid
.16667 .46172 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .4875 L
s
0 0 0 r
2 Mabswid
.16667 .4875 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .5125 L
s
0 0 0 r
2 Mabswid
.16667 .5125 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .53828 L
s
0 0 0 r
2 Mabswid
.16667 .53828 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .56662 L
s
0 0 0 r
2 Mabswid
.16667 .56662 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .60003 L
s
0 0 0 r
2 Mabswid
.16667 .60003 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .5 m
.16667 .64286 L
s
0 0 0 r
2 Mabswid
.16667 .64286 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .35714 m
.72297 .06466 L
s
0 0 0 r
2 Mabswid
.72297 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .39997 m
.73748 .16728 L
s
0 0 0 r
2 Mabswid
.73748 .16728 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .43338 m
.59557 .30919 L
s
0 0 0 r
2 Mabswid
.59557 .30919 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .46172 m
.5008 .40396 L
s
0 0 0 r
2 Mabswid
.5008 .40396 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .4875 m
.43253 .47223 L
s
0 0 0 r
2 Mabswid
.43253 .47223 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .5125 m
.38 .52476 L
s
0 0 0 r
2 Mabswid
.38 .52476 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .53828 m
.33703 .56773 L
s
0 0 0 r
2 Mabswid
.33703 .56773 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .56662 m
.29964 .60512 L
s
0 0 0 r
2 Mabswid
.29964 .60512 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .60003 m
.26475 .64001 L
s
0 0 0 r
2 Mabswid
.26475 .64001 Mdot
.039 .916 .04 r
.5 Mabswid
.16667 .64286 m
.22909 .67567 L
s
0 0 0 r
2 Mabswid
.22909 .67567 Mdot
.039 .916 .04 r
.5 Mabswid
.72297 .06466 m
.74148 .07439 L
s
0 0 0 r
2 Mabswid
.74148 .07439 Mdot
.039 .916 .04 r
.5 Mabswid
.73748 .16728 m
.74148 .15746 L
s
0 0 0 r
2 Mabswid
.74148 .15746 Mdot
.039 .916 .04 r
.5 Mabswid
.59557 .30919 m
.66637 .06466 L
s
0 0 0 r
2 Mabswid
.66637 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.5008 .40396 m
.55302 .10187 L
s
0 0 0 r
2 Mabswid
.55302 .10187 Mdot
.039 .916 .04 r
.5 Mabswid
.43253 .47223 m
.45139 .14397 L
s
0 0 0 r
2 Mabswid
.45139 .14397 Mdot
.039 .916 .04 r
.5 Mabswid
.38 .52476 m
.36029 .1817 L
s
0 0 0 r
2 Mabswid
.36029 .1817 Mdot
.039 .916 .04 r
.5 Mabswid
.33703 .56773 m
.34373 .56579 L
s
0 0 0 r
2 Mabswid
.34373 .56579 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .60512 m
.30459 .60493 L
s
0 0 0 r
2 Mabswid
.30459 .60493 Mdot
.039 .916 .04 r
.5 Mabswid
.26475 .64001 m
.26887 .64066 L
s
0 0 0 r
2 Mabswid
.26887 .64066 Mdot
.039 .916 .04 r
.5 Mabswid
.22909 .67567 m
.23267 .67685 L
s
0 0 0 r
2 Mabswid
.23267 .67685 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .07439 m
.97619 .3091 L
s
0 0 0 r
2 Mabswid
.97619 .3091 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .15746 m
.70365 .06466 L
s
0 0 0 r
2 Mabswid
.70365 .06466 Mdot
.039 .916 .04 r
.5 Mabswid
.66637 .06466 m
.68542 .02381 L
s
0 0 0 r
2 Mabswid
.68542 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.55302 .10187 m
.69955 .20521 L
s
0 0 0 r
2 Mabswid
.69955 .20521 Mdot
.039 .916 .04 r
.5 Mabswid
.45139 .14397 m
.61498 .28978 L
s
0 0 0 r
2 Mabswid
.61498 .28978 Mdot
.039 .916 .04 r
.5 Mabswid
.36029 .1817 m
.53126 .3735 L
s
0 0 0 r
2 Mabswid
.53126 .3735 Mdot
.039 .916 .04 r
.5 Mabswid
.34373 .56579 m
.74148 .63455 L
s
0 0 0 r
2 Mabswid
.74148 .63455 Mdot
.039 .916 .04 r
.5 Mabswid
.30459 .60493 m
.74148 .73144 L
s
0 0 0 r
2 Mabswid
.74148 .73144 Mdot
.039 .916 .04 r
.5 Mabswid
.26887 .64066 m
.74148 .83331 L
s
0 0 0 r
2 Mabswid
.74148 .83331 Mdot
.039 .916 .04 r
.5 Mabswid
.23267 .67685 m
.73337 .9401 L
s
0 0 0 r
2 Mabswid
.73337 .9401 Mdot
.039 .916 .04 r
.5 Mabswid
.70365 .06466 m
.67505 .02381 L
s
0 0 0 r
2 Mabswid
.67505 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.69955 .20521 m
.70257 .20696 L
s
0 0 0 r
2 Mabswid
.70257 .20696 Mdot
.039 .916 .04 r
.5 Mabswid
.61498 .28978 m
.61757 .29195 L
s
0 0 0 r
2 Mabswid
.61757 .29195 Mdot
.039 .916 .04 r
.5 Mabswid
.53126 .3735 m
.53343 .37609 L
s
0 0 0 r
2 Mabswid
.53343 .37609 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .63455 m
.97619 .69744 L
s
0 0 0 r
2 Mabswid
.97619 .69744 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .73144 m
.97619 .84089 L
s
0 0 0 r
2 Mabswid
.97619 .84089 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .83331 m
.94553 .97619 L
s
0 0 0 r
2 Mabswid
.94553 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.73337 .9401 m
.74148 .93584 L
s
0 0 0 r
2 Mabswid
.74148 .93584 Mdot
.039 .916 .04 r
.5 Mabswid
.70257 .20696 m
.74148 .2344 L
s
0 0 0 r
2 Mabswid
.74148 .2344 Mdot
.039 .916 .04 r
.5 Mabswid
.61757 .29195 m
.74148 .4024 L
s
0 0 0 r
2 Mabswid
.74148 .4024 Mdot
.039 .916 .04 r
.5 Mabswid
.53343 .37609 m
.74148 .60951 L
s
0 0 0 r
2 Mabswid
.74148 .60951 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .93584 m
.97619 .70113 L
s
0 0 0 r
2 Mabswid
.97619 .70113 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .2344 m
.97619 .6601 L
s
0 0 0 r
2 Mabswid
.97619 .6601 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .4024 m
.29833 .79739 L
s
0 0 0 r
2 Mabswid
.29833 .79739 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .60951 m
.49967 .88079 L
s
0 0 0 r
2 Mabswid
.49967 .88079 Mdot
.039 .916 .04 r
.5 Mabswid
.29833 .79739 m
.28821 .62131 L
s
0 0 0 r
2 Mabswid
.28821 .62131 Mdot
.039 .916 .04 r
.5 Mabswid
.49967 .88079 m
.52838 .38114 L
s
0 0 0 r
2 Mabswid
.52838 .38114 Mdot
.039 .916 .04 r
.5 Mabswid
.28821 .62131 m
.74148 .64735 L
s
0 0 0 r
2 Mabswid
.74148 .64735 Mdot
.039 .916 .04 r
.5 Mabswid
.52838 .38114 m
.74148 .3689 L
s
0 0 0 r
2 Mabswid
.74148 .3689 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .64735 m
.97619 .66789 L
s
0 0 0 r
2 Mabswid
.97619 .66789 Mdot
.039 .916 .04 r
.5 Mabswid
.74148 .3689 m
.97619 .34836 L
s
0 0 0 r
2 Mabswid
.97619 .34836 Mdot
[(PechanPrism)] .45407 .06467 0 0 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{191, 191},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 190}, {190, 0}} -> {-0.500105, -10.5001, 0.110528, \
0.110528}},
  CellTags->"PechanPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PellinBrocaPrism[alpha, Bside, Aside, beta, thickness, \
options]\
\>", "Subsection",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{

Cell["?PellinBrocaPrism", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[BoxData[
    \("PellinBrocaPrism[alpha, Bside, Aside, beta, thickness, options] refers \
to a six-sided prism having polygon dimensions on two sides and rectangular \
dimensions on the remaining sides. \n\nPellinBrocaPrism is initially \
generated with the alpha corner vertex placed at the origin of the global \
coordinate system and with the large polygon prism faces lieing in the \
horizontal x-y plane direction. The Bside is initially generated to touch the \
x-axis. The PellinBrocaPrism is primarily used in wavelength dispersion and \
beam separation applications. For normal operation, the alpha angle is set at \
60 degrees and the beta angle is roughly between 75 and 80 degrees. Typical \
values for the remaining parameters are: Aside = 24 mm, Bside = 40 mm, and \
thickness = 10 mm. The beam entrance can be on either the Aside or Bside at \
roughly the Brewster angle of incidence and depending on which side is \
chosen, the result will have either positive or negative dispersion. The \
resulting output beams leave the prism at roughly the Brewster angle and \
approximately 90 degrees to the input beam. One can orient PellinBrocaPrism \
such that the degree of deflection is exactly 90 for one desired wavelength. \
(Notes by Alex Angerhofer, Dept of Chemistry, University of Florida) See \
also: Prism and RhomboidalPrism."\)], "Print",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[PellinBrocaPrism[60,40.0,23.5,75,10.0],PlotType->TopView]\
\
\>", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.0139881 0.0238095 [
[ 0 0 0 0 ]
[ 1 .5875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .01399 m
.97619 .57351 L
.97619 .57351 L
.97619 .01399 L
.97619 .01399 L
s
.97619 .01399 m
.02381 .01399 L
.02381 .01399 L
.97619 .01399 L
.97619 .01399 L
s
.23167 .37402 m
.02381 .01399 L
.02381 .01399 L
.23167 .37402 L
.23167 .37402 L
s
.23167 .37402 m
.97619 .57351 L
.97619 .57351 L
.23167 .37402 L
.23167 .37402 L
s
.02381 .01399 m
.97619 .01399 L
.97619 .57351 L
.23167 .37402 L
.02381 .01399 L
s
.02381 .01399 m
.97619 .01399 L
.97619 .57351 L
.23167 .37402 L
.02381 .01399 L
s
0 0 m
1 0 L
1 .5875 L
0 .5875 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{217, 127.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 216}, {126.375, 0}} -> {-1.08745, -0.587624, \
0.195254, 0.195254}},
  CellTags->"PellinBrocaPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"PellinBrocaPrism", "[", 
              RowBox[{"60", ",", 
                StyleBox["40.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3], ",", 
                StyleBox["23.5000000000000008`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3], ",", "75", ",", 
                StyleBox["10.`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3]}], "]"}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"PellinBrocaPrism"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67165 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.00491 -0.134222 1.00491 [
[ 0 0 0 0 ]
[ 1 .67165 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67165 L
0 .67165 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.33992 .54357 m
.34625 .385 L
s
.34625 .385 m
.95671 .29854 L
s
.34625 .385 m
.04411 .27907 L
s
.97592 .46033 m
.33992 .54357 L
s
.33992 .54357 m
.02455 .44156 L
s
.76773 .01931 m
.95671 .29854 L
s
.95671 .29854 m
.97592 .46033 L
s
.04411 .27907 m
.76773 .01931 L
s
.04411 .27907 m
.02455 .44156 L
s
.78047 .1896 m
.97592 .46033 L
s
.02455 .44156 m
.78047 .1896 L
s
.78047 .1896 m
.76773 .01931 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{183, 122.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 182}, {121.812, 0}} -> {-0.00175239, 0.133563, \
0.00548692, 0.00548692}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{Move[LineOfRays[5],{0,-10}],
\tMove[PellinBrocaPrism[60,40.0,23.5,79.5,10.0],{0,0,-33}],
\tBoundary[100,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2826 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0205494 1.05801 0.0205494 [
[.34481 .79771 -54 -4.5 ]
[.34481 .79771 54 4.5 ]
[ 0 0 0 0 ]
[ 1 1.2826 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.71318 .61033 m
.97619 1.01533 L
.97619 1.01533 L
.71318 .61033 L
.71318 .61033 L
s
.71318 .61033 m
.02381 1.05801 L
.02381 1.05801 L
.71318 .61033 L
.71318 .61033 L
s
.40467 1.25207 m
.02381 1.05801 L
.02381 1.05801 L
.40467 1.25207 L
.40467 1.25207 L
s
.40467 1.25207 m
.97619 1.01533 L
.97619 1.01533 L
.40467 1.25207 L
.40467 1.25207 L
s
.02381 1.05801 m
.71318 .61033 L
.97619 1.01533 L
.40467 1.25207 L
.02381 1.05801 L
s
.02381 1.05801 m
.71318 .61033 L
.97619 1.01533 L
.40467 1.25207 L
.02381 1.05801 L
s
.039 .916 .04 r
.02381 .80114 m
.41935 .80114 L
s
0 0 0 r
2 Mabswid
.41935 .80114 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .85252 m
.34024 .85252 L
s
0 0 0 r
2 Mabswid
.34024 .85252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .90389 m
.26113 .90389 L
s
0 0 0 r
2 Mabswid
.26113 .90389 Mdot
.039 .916 .04 r
.5 Mabswid
.41935 .80114 m
.9433 1.02895 L
s
0 0 0 r
2 Mabswid
.9433 1.02895 Mdot
.039 .916 .04 r
.5 Mabswid
.34024 .85252 m
.84228 1.0708 L
s
0 0 0 r
2 Mabswid
.84228 1.0708 Mdot
.039 .916 .04 r
.5 Mabswid
.26113 .90389 m
.74126 1.11265 L
s
0 0 0 r
2 Mabswid
.74126 1.11265 Mdot
.039 .916 .04 r
.5 Mabswid
.9433 1.02895 m
.95906 .98896 L
s
0 0 0 r
2 Mabswid
.95906 .98896 Mdot
.039 .916 .04 r
.5 Mabswid
.84228 1.0708 m
.90644 .90793 L
s
0 0 0 r
2 Mabswid
.90644 .90793 Mdot
.039 .916 .04 r
.5 Mabswid
.74126 1.11265 m
.85382 .8269 L
s
0 0 0 r
2 Mabswid
.85382 .8269 Mdot
.039 .916 .04 r
.5 Mabswid
.95906 .98896 m
.87645 .03054 L
s
0 0 0 r
2 Mabswid
.87645 .03054 Mdot
.039 .916 .04 r
.5 Mabswid
.90644 .90793 m
.83081 .03054 L
s
0 0 0 r
2 Mabswid
.83081 .03054 Mdot
.039 .916 .04 r
.5 Mabswid
.85382 .8269 m
.78518 .03054 L
s
0 0 0 r
2 Mabswid
.78518 .03054 Mdot
[(Pellin-Broca Prism)] .34481 .79771 0 0 Mshowa
0 0 m
1 0 L
1 1.2826 L
0 1.2826 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{151.5, 194.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 150.5}, {193.312, 0}} -> {-2.22105, -52.2141, \
0.330404, 0.330404}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bangle\  = \ 
      ArcTan[\(ModelRefractiveIndex[BK7]\)[{WaveLength ->  .532}]]/
        Degree\)], "Input",
  CellTags->"PellinBrocaPrism"],

Cell[BoxData[
    \(56.6501594034559641`\)], "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{40./3,0,bangle-90}", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[BoxData[
    \({13.3333333333333348`, 0, \(-90\) + angle}\)], "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{Ray[],
\tMove[Move[PellinBrocaPrism[60,40.0,23.5,78,10.0],-40/3],{10,0,bangle-90}],
\tBoundary[100,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.42847 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.047196 0.0205554 1.06178 0.0205554 [
[ 0 0 0 0 ]
[ 1 1.42847 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.71063 .76044 m
.97619 1.16395 L
.97619 1.16395 L
.71063 .76044 L
.71063 .76044 L
s
.71063 .76044 m
.02381 1.21245 L
.02381 1.21245 L
.71063 .76044 L
.71063 .76044 L
s
.38647 1.39446 m
.02381 1.21245 L
.02381 1.21245 L
.38647 1.39446 L
.38647 1.39446 L
s
.38647 1.39446 m
.97619 1.16395 L
.97619 1.16395 L
.38647 1.39446 L
.38647 1.39446 L
s
.02381 1.21245 m
.71063 .76044 L
.97619 1.16395 L
.38647 1.39446 L
.02381 1.21245 L
s
.02381 1.21245 m
.71063 .76044 L
.97619 1.16395 L
.38647 1.39446 L
.02381 1.21245 L
s
.039 .916 .04 r
.0472 1.06178 m
.25275 1.06178 L
s
0 0 0 r
2 Mabswid
.25275 1.06178 Mdot
.039 .916 .04 r
.5 Mabswid
.25275 1.06178 m
.72131 1.26358 L
s
0 0 0 r
2 Mabswid
.72131 1.26358 Mdot
.039 .916 .04 r
.5 Mabswid
.72131 1.26358 m
.85062 .97314 L
s
0 0 0 r
2 Mabswid
.85062 .97314 Mdot
.039 .916 .04 r
.5 Mabswid
.85062 .97314 m
.87666 .03401 L
s
0 0 0 r
2 Mabswid
.87666 .03401 Mdot
0 0 m
1 0 L
1 1.42847 L
0 1.42847 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{141, 201.562},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 140}, {200.562, 0}} -> {-2.29628, -51.7551, \
0.347496, 0.347496}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell["prism = PellinBrocaPrism[60,40.0,23.5,75,10.0];", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{
\tMove[LineOfRays[5],{100,19,180}],
\tMove[PellinBrocaPrism[60,40.0,23.5,75,10.0],{30,0,0}],
\tBoundary[100,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8053 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.067286 0.0104348 0.540912 0.0104348 [
[.66315 .52766 -6 -4.5 ]
[.66315 .52766 6 4.5 ]
[.02381 .31896 -6 -4.5 ]
[.02381 .31896 6 4.5 ]
[.02381 .31896 -6 -4.5 ]
[.02381 .31896 6 4.5 ]
[.32405 .69527 -6 -4.5 ]
[.32405 .69527 6 4.5 ]
[.34348 .71018 -6 -4.5 ]
[.34348 .71018 6 4.5 ]
[.6764 .54091 -6 -4.5 ]
[.6764 .54091 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .8053 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.66315 .54091 m
.66315 .56135 L
.66315 .58178 L
.66315 .60222 L
.66315 .62265 L
.66315 .64309 L
.66315 .66352 L
.66315 .68396 L
.66315 .70439 L
.66315 .72482 L
.66315 .74526 L
.66315 .76569 L
.66315 .78613 L
.66315 .78613 L
.66315 .76569 L
.66315 .74526 L
.66315 .72482 L
.66315 .70439 L
.66315 .68396 L
.66315 .66352 L
.66315 .64309 L
.66315 .62265 L
.66315 .60222 L
.66315 .58178 L
.66315 .56135 L
.66315 .54091 L
.66315 .54091 L
s
.66315 .66352 m
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
s
.66315 .54091 m
.62836 .54091 L
.59358 .54091 L
.5588 .54091 L
.52402 .54091 L
.48923 .54091 L
.45445 .54091 L
.41967 .54091 L
.38489 .54091 L
.3501 .54091 L
.31532 .54091 L
.28054 .54091 L
.24576 .54091 L
.24576 .54091 L
.28054 .54091 L
.31532 .54091 L
.3501 .54091 L
.38489 .54091 L
.41967 .54091 L
.45445 .54091 L
.48923 .54091 L
.52402 .54091 L
.5588 .54091 L
.59358 .54091 L
.62836 .54091 L
.66315 .54091 L
.66315 .54091 L
s
.45445 .54091 m
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
s
.33686 .6987 m
.32926 .68555 L
.32167 .6724 L
.31408 .65925 L
.30649 .6461 L
.2989 .63295 L
.29131 .61981 L
.28371 .60666 L
.27612 .59351 L
.26853 .58036 L
.26094 .56721 L
.25335 .55406 L
.24576 .54091 L
.24576 .54091 L
.25335 .55406 L
.26094 .56721 L
.26853 .58036 L
.27612 .59351 L
.28371 .60666 L
.29131 .61981 L
.2989 .63295 L
.30649 .6461 L
.31408 .65925 L
.32167 .6724 L
.32926 .68555 L
.33686 .6987 L
.33686 .6987 L
s
.29131 .61981 m
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
s
.33686 .6987 m
.36405 .70599 L
.39124 .71327 L
.41843 .72056 L
.44562 .72784 L
.47281 .73513 L
.5 .74241 L
.52719 .7497 L
.55438 .75699 L
.58157 .76427 L
.60877 .77156 L
.63596 .77884 L
.66315 .78613 L
.66315 .78613 L
.63596 .77884 L
.60877 .77156 L
.58157 .76427 L
.55438 .75699 L
.52719 .7497 L
.5 .74241 L
.47281 .73513 L
.44562 .72784 L
.41843 .72056 L
.39124 .71327 L
.36405 .70599 L
.33686 .6987 L
.33686 .6987 L
s
.5 .74241 m
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
s
.66315 .54091 m
.66315 .78613 L
.66315 .78613 L
.66315 .54091 L
.66315 .54091 L
s
.66315 .54091 m
.24576 .54091 L
.24576 .54091 L
.66315 .54091 L
.66315 .54091 L
s
.33686 .6987 m
.24576 .54091 L
.24576 .54091 L
.33686 .6987 L
.33686 .6987 L
s
.33686 .6987 m
.66315 .78613 L
.66315 .78613 L
.33686 .6987 L
.33686 .6987 L
s
.24576 .54091 m
.66315 .54091 L
.66315 .78613 L
.33686 .6987 L
.24576 .54091 L
s
.24576 .54091 m
.66315 .54091 L
.66315 .78613 L
.33686 .6987 L
.24576 .54091 L
s
.039 .916 .04 r
.97619 .76526 m
.66315 .76526 L
s
0 0 0 r
2 Mabswid
.66315 .76526 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .73917 m
.66315 .73917 L
s
0 0 0 r
2 Mabswid
.66315 .73917 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .71309 m
.66315 .71309 L
s
0 0 0 r
2 Mabswid
.66315 .71309 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .76526 m
.58526 .76526 L
s
0 0 0 r
2 Mabswid
.58526 .76526 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .73917 m
.4879 .73917 L
s
0 0 0 r
2 Mabswid
.4879 .73917 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .71309 m
.39055 .71309 L
s
0 0 0 r
2 Mabswid
.39055 .71309 Mdot
.039 .916 .04 r
.5 Mabswid
.58526 .76526 m
.2703 .58341 L
s
0 0 0 r
2 Mabswid
.2703 .58341 Mdot
.039 .916 .04 r
.5 Mabswid
.4879 .73917 m
.29638 .6286 L
s
0 0 0 r
2 Mabswid
.29638 .6286 Mdot
.039 .916 .04 r
.5 Mabswid
.39055 .71309 m
.32247 .67378 L
s
0 0 0 r
2 Mabswid
.32247 .67378 Mdot
.039 .916 .04 r
.5 Mabswid
.2703 .58341 m
.2703 .54091 L
s
0 0 0 r
2 Mabswid
.2703 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .6286 m
.29638 .54091 L
s
0 0 0 r
2 Mabswid
.29638 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.32247 .67378 m
.32247 .54091 L
s
0 0 0 r
2 Mabswid
.32247 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.2703 .54091 m
.2703 .01917 L
s
0 0 0 r
2 Mabswid
.2703 .01917 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .54091 m
.29638 .01917 L
s
0 0 0 r
2 Mabswid
.29638 .01917 Mdot
.039 .916 .04 r
.5 Mabswid
.32247 .54091 m
.32247 .01917 L
s
0 0 0 r
2 Mabswid
.32247 .01917 Mdot
[(L1)] .66315 .52766 0 0 Mshowa
[(L2)] .02381 .31896 0 0 Mshowa
[(L3)] .02381 .31896 0 0 Mshowa
[(L4)] .32405 .69527 0 0 Mshowa
[(L5)] .34348 .71018 0 0 Mshowa
[(L6)] .6764 .54091 0 0 Mshowa
0 0 m
1 0 L
1 .8053 L
0 .8053 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{157, 126.375},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 156}, {125.375, 0}} -> {4.98746, -52.3472, 0.623682, \
0.623682}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell["prism = PellinBrocaPrism[60,40.0,23.5,75,10.0];", "Input",
  CellTags->"PellinBrocaPrism"],

Cell["prism = Move[prism,{40,0,180},TwistAngle->180];", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{

Cell["\<\
Do[
DrawSystem[
\t{
\tMove[LineOfRays[5],{-10,0,90}],
\tMove[prism,{0,0,angle}],
\tBoundary[60,GraphicDesign->Off]},PlotType->TopView
],
{angle,35,45,2}];\
\>", "Input",
  AspectRatioFixed->True,
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42294 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.192205 0.0124931 0.0259624 0.0124931 [
[.20318 .01029 -6 -4.5 ]
[.20318 .01029 6 4.5 ]
[.97619 .24653 -6 -4.5 ]
[.97619 .24653 6 4.5 ]
[.97619 .24653 -6 -4.5 ]
[.97619 .24653 6 4.5 ]
[.42183 .41132 -6 -4.5 ]
[.42183 .41132 6 4.5 ]
[.38652 .41287 -6 -4.5 ]
[.38652 .41287 6 4.5 ]
[.17653 .01499 -6 -4.5 ]
[.17653 .01499 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .42294 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.1922 .02596 m
.17817 .046 L
.16414 .06604 L
.15011 .08609 L
.13607 .10613 L
.12204 .12617 L
.10801 .14621 L
.09397 .16625 L
.07994 .18629 L
.06591 .20633 L
.05188 .22637 L
.03784 .24641 L
.02381 .26646 L
.02381 .26646 L
.03784 .24641 L
.05188 .22637 L
.06591 .20633 L
.07994 .18629 L
.09397 .16625 L
.10801 .14621 L
.12204 .12617 L
.13607 .10613 L
.15011 .08609 L
.16414 .06604 L
.17817 .046 L
.1922 .02596 L
.1922 .02596 L
s
.10801 .14621 m
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
.10801 .14621 L
s
.1922 .02596 m
.22632 .04985 L
.26043 .07373 L
.29454 .09762 L
.32866 .12151 L
.36277 .14539 L
.39688 .16928 L
.43099 .19316 L
.46511 .21705 L
.49922 .24094 L
.53333 .26482 L
.56744 .28871 L
.60156 .31259 L
.60156 .31259 L
.56744 .28871 L
.53333 .26482 L
.49922 .24094 L
.46511 .21705 L
.43099 .19316 L
.39688 .16928 L
.36277 .14539 L
.32866 .12151 L
.29454 .09762 L
.26043 .07373 L
.22632 .04985 L
.1922 .02596 L
.1922 .02596 L
s
.39688 .16928 m
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
.39688 .16928 L
s
.40386 .40478 m
.42033 .3971 L
.43681 .38942 L
.45328 .38173 L
.46976 .37405 L
.48623 .36637 L
.50271 .35869 L
.51918 .351 L
.53566 .34332 L
.55213 .33564 L
.56861 .32796 L
.58508 .32028 L
.60156 .31259 L
.60156 .31259 L
.58508 .32028 L
.56861 .32796 L
.55213 .33564 L
.53566 .34332 L
.51918 .351 L
.50271 .35869 L
.48623 .36637 L
.46976 .37405 L
.45328 .38173 L
.43681 .38942 L
.42033 .3971 L
.40386 .40478 L
.40386 .40478 L
s
.50271 .35869 m
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
.50271 .35869 L
s
.40386 .40478 m
.37219 .39325 L
.34051 .38173 L
.30884 .3702 L
.27717 .35867 L
.2455 .34715 L
.21383 .33562 L
.18216 .32409 L
.15049 .31256 L
.11882 .30104 L
.08715 .28951 L
.05548 .27798 L
.02381 .26646 L
.02381 .26646 L
.05548 .27798 L
.08715 .28951 L
.11882 .30104 L
.15049 .31256 L
.18216 .32409 L
.21383 .33562 L
.2455 .34715 L
.27717 .35867 L
.30884 .3702 L
.34051 .38173 L
.37219 .39325 L
.40386 .40478 L
.40386 .40478 L
s
.21383 .33562 m
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
.21383 .33562 L
s
.1922 .02596 m
.02381 .26646 L
.02381 .26646 L
.1922 .02596 L
.1922 .02596 L
s
.1922 .02596 m
.60156 .31259 L
.60156 .31259 L
.1922 .02596 L
.1922 .02596 L
s
.40386 .40478 m
.60156 .31259 L
.60156 .31259 L
.40386 .40478 L
.40386 .40478 L
s
.40386 .40478 m
.02381 .26646 L
.02381 .26646 L
.40386 .40478 L
.40386 .40478 L
s
.60156 .31259 m
.1922 .02596 L
.02381 .26646 L
.40386 .40478 L
.60156 .31259 L
s
.60156 .31259 m
.1922 .02596 L
.02381 .26646 L
.40386 .40478 L
.60156 .31259 L
s
.039 .916 .04 r
.09851 .02596 m
.09851 .15978 L
s
0 0 0 r
2 Mabswid
.09851 .15978 Mdot
.039 .916 .04 r
.5 Mabswid
.06727 .02596 m
.06727 .20438 L
s
0 0 0 r
2 Mabswid
.06727 .20438 Mdot
.039 .916 .04 r
.5 Mabswid
.03604 .02596 m
.03604 .24899 L
s
0 0 0 r
2 Mabswid
.03604 .24899 Mdot
.039 .916 .04 r
.5 Mabswid
.09851 .15978 m
.16333 .31724 L
s
0 0 0 r
2 Mabswid
.16333 .31724 Mdot
.039 .916 .04 r
.5 Mabswid
.06727 .20438 m
.105 .29601 L
s
0 0 0 r
2 Mabswid
.105 .29601 Mdot
.039 .916 .04 r
.5 Mabswid
.03604 .24899 m
.04666 .27477 L
s
0 0 0 r
2 Mabswid
.04666 .27477 Mdot
.039 .916 .04 r
.5 Mabswid
.16333 .31724 m
.41793 .18401 L
s
0 0 0 r
2 Mabswid
.41793 .18401 Mdot
.039 .916 .04 r
.5 Mabswid
.105 .29601 m
.37562 .15439 L
s
0 0 0 r
2 Mabswid
.37562 .15439 Mdot
.039 .916 .04 r
.5 Mabswid
.04666 .27477 m
.33331 .12477 L
s
0 0 0 r
2 Mabswid
.33331 .12477 Mdot
.039 .916 .04 r
.5 Mabswid
.41793 .18401 m
.94179 .08527 L
s
0 0 0 r
2 Mabswid
.94179 .08527 Mdot
.039 .916 .04 r
.5 Mabswid
.37562 .15439 m
.94179 .04767 L
s
0 0 0 r
2 Mabswid
.94179 .04767 Mdot
.039 .916 .04 r
.5 Mabswid
.33331 .12477 m
.94179 .01007 L
s
0 0 0 r
2 Mabswid
.94179 .01007 Mdot
[(L1)] .20318 .01029 0 0 Mshowa
[(L2)] .97619 .24653 0 0 Mshowa
[(L3)] .97619 .24653 0 0 Mshowa
[(L4)] .42183 .41132 0 0 Mshowa
[(L5)] .38652 .41287 0 0 Mshowa
[(L6)] .17653 .01499 0 0 Mshowa
0 0 m
1 0 L
1 .42294 L
0 .42294 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-17.1537, -2.71387, \
0.324272, 0.324272}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42918 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.200447 0.0124897 0.0255762 0.0124897 [
[.21202 .01022 -6 -4.5 ]
[.21202 .01022 6 4.5 ]
[.97619 .27329 -6 -4.5 ]
[.97619 .27329 6 4.5 ]
[.97619 .27329 -6 -4.5 ]
[.97619 .27329 6 4.5 ]
[.41652 .41865 -6 -4.5 ]
[.41652 .41865 6 4.5 ]
[.38099 .41896 -6 -4.5 ]
[.38099 .41896 6 4.5 ]
[.18509 .014 -6 -4.5 ]
[.18509 .014 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .42918 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.20045 .02558 m
.18573 .04511 L
.17101 .06464 L
.15629 .08418 L
.14157 .10371 L
.12685 .12325 L
.11213 .14278 L
.09741 .16231 L
.08269 .18185 L
.06797 .20138 L
.05325 .22091 L
.03853 .24045 L
.02381 .25998 L
.02381 .25998 L
.03853 .24045 L
.05325 .22091 L
.06797 .20138 L
.08269 .18185 L
.09741 .16231 L
.11213 .14278 L
.12685 .12325 L
.14157 .10371 L
.15629 .08418 L
.17101 .06464 L
.18573 .04511 L
.20045 .02558 L
.20045 .02558 L
s
.11213 .14278 m
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
.11213 .14278 L
s
.20045 .02558 m
.2337 .05063 L
.26695 .07569 L
.30019 .10074 L
.33344 .1258 L
.36669 .15085 L
.39994 .17591 L
.43319 .20096 L
.46644 .22602 L
.49969 .25107 L
.53294 .27613 L
.56619 .30118 L
.59944 .32624 L
.59944 .32624 L
.56619 .30118 L
.53294 .27613 L
.49969 .25107 L
.46644 .22602 L
.43319 .20096 L
.39994 .17591 L
.36669 .15085 L
.33344 .1258 L
.30019 .10074 L
.26695 .07569 L
.2337 .05063 L
.20045 .02558 L
.20045 .02558 L
s
.39994 .17591 m
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
.39994 .17591 L
s
.39869 .41145 m
.41542 .40434 L
.43215 .39724 L
.44888 .39014 L
.46561 .38304 L
.48234 .37594 L
.49907 .36884 L
.51579 .36174 L
.53252 .35464 L
.54925 .34754 L
.56598 .34044 L
.58271 .33334 L
.59944 .32624 L
.59944 .32624 L
.58271 .33334 L
.56598 .34044 L
.54925 .34754 L
.53252 .35464 L
.51579 .36174 L
.49907 .36884 L
.48234 .37594 L
.46561 .38304 L
.44888 .39014 L
.43215 .39724 L
.41542 .40434 L
.39869 .41145 L
.39869 .41145 L
s
.49907 .36884 m
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
.49907 .36884 L
s
.39869 .41145 m
.36745 .39882 L
.33621 .3862 L
.30497 .37358 L
.27373 .36096 L
.24249 .34834 L
.21125 .33571 L
.18001 .32309 L
.14877 .31047 L
.11753 .29785 L
.08629 .28523 L
.05505 .2726 L
.02381 .25998 L
.02381 .25998 L
.05505 .2726 L
.08629 .28523 L
.11753 .29785 L
.14877 .31047 L
.18001 .32309 L
.21125 .33571 L
.24249 .34834 L
.27373 .36096 L
.30497 .37358 L
.33621 .3862 L
.36745 .39882 L
.39869 .41145 L
.39869 .41145 L
s
.21125 .33571 m
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
.21125 .33571 L
s
.20045 .02558 m
.02381 .25998 L
.02381 .25998 L
.20045 .02558 L
.20045 .02558 L
s
.20045 .02558 m
.59944 .32624 L
.59944 .32624 L
.20045 .02558 L
.20045 .02558 L
s
.39869 .41145 m
.59944 .32624 L
.59944 .32624 L
.39869 .41145 L
.39869 .41145 L
s
.39869 .41145 m
.02381 .25998 L
.02381 .25998 L
.39869 .41145 L
.39869 .41145 L
s
.59944 .32624 m
.20045 .02558 L
.02381 .25998 L
.39869 .41145 L
.59944 .32624 L
s
.59944 .32624 m
.20045 .02558 L
.02381 .25998 L
.39869 .41145 L
.59944 .32624 L
s
.039 .916 .04 r
.10677 .02558 m
.10677 .14988 L
s
0 0 0 r
2 Mabswid
.10677 .14988 Mdot
.039 .916 .04 r
.5 Mabswid
.07555 .02558 m
.07555 .19132 L
s
0 0 0 r
2 Mabswid
.07555 .19132 Mdot
.039 .916 .04 r
.5 Mabswid
.04433 .02558 m
.04433 .23276 L
s
0 0 0 r
2 Mabswid
.04433 .23276 Mdot
.039 .916 .04 r
.5 Mabswid
.10677 .14988 m
.1732 .32034 L
s
0 0 0 r
2 Mabswid
.1732 .32034 Mdot
.039 .916 .04 r
.5 Mabswid
.07555 .19132 m
.11698 .29762 L
s
0 0 0 r
2 Mabswid
.11698 .29762 Mdot
.039 .916 .04 r
.5 Mabswid
.04433 .23276 m
.06075 .27491 L
s
0 0 0 r
2 Mabswid
.06075 .27491 Mdot
.039 .916 .04 r
.5 Mabswid
.1732 .32034 m
.43299 .20081 L
s
0 0 0 r
2 Mabswid
.43299 .20081 Mdot
.039 .916 .04 r
.5 Mabswid
.11698 .29762 m
.39295 .17064 L
s
0 0 0 r
2 Mabswid
.39295 .17064 Mdot
.039 .916 .04 r
.5 Mabswid
.06075 .27491 m
.35292 .14047 L
s
0 0 0 r
2 Mabswid
.35292 .14047 Mdot
.039 .916 .04 r
.5 Mabswid
.43299 .20081 m
.94983 .13797 L
s
0 0 0 r
2 Mabswid
.94983 .13797 Mdot
.039 .916 .04 r
.5 Mabswid
.39295 .17064 m
.94983 .10293 L
s
0 0 0 r
2 Mabswid
.94983 .10293 Mdot
.039 .916 .04 r
.5 Mabswid
.35292 .14047 m
.94983 .0679 L
s
0 0 0 r
2 Mabswid
.94983 .0679 Mdot
[(L1)] .21202 .01022 0 0 Mshowa
[(L2)] .97619 .27329 0 0 Mshowa
[(L3)] .97619 .27329 0 0 Mshowa
[(L4)] .41652 .41865 0 0 Mshowa
[(L5)] .38099 .41896 0 0 Mshowa
[(L6)] .18509 .014 0 0 Mshowa
0 0 m
1 0 L
1 .42918 L
0 .42918 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-18.4433, -2.71163, \
0.329323, 0.329323}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .43661 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.208701 0.0125019 0.0254171 0.0125019 [
[.22087 .0104 -6 -4.5 ]
[.22087 .0104 6 4.5 ]
[.97619 .30031 -6 -4.5 ]
[.97619 .30031 6 4.5 ]
[.97619 .30031 -6 -4.5 ]
[.97619 .30031 6 4.5 ]
[.4112 .42622 -6 -4.5 ]
[.4112 .42622 6 4.5 ]
[.3755 .42528 -6 -4.5 ]
[.3755 .42528 6 4.5 ]
[.19368 .01325 -6 -4.5 ]
[.19368 .01325 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .43661 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2087 .02542 m
.19329 .04444 L
.17789 .06347 L
.16248 .0825 L
.14707 .10152 L
.13166 .12055 L
.11626 .13958 L
.10085 .1586 L
.08544 .17763 L
.07003 .19666 L
.05462 .21569 L
.03922 .23471 L
.02381 .25374 L
.02381 .25374 L
.03922 .23471 L
.05462 .21569 L
.07003 .19666 L
.08544 .17763 L
.10085 .1586 L
.11626 .13958 L
.13166 .12055 L
.14707 .10152 L
.16248 .0825 L
.17789 .06347 L
.19329 .04444 L
.2087 .02542 L
.2087 .02542 L
s
.11626 .13958 m
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
.11626 .13958 L
s
.2087 .02542 m
.24109 .05164 L
.27347 .07787 L
.30586 .10409 L
.33825 .13032 L
.37063 .15655 L
.40302 .18277 L
.4354 .209 L
.46779 .23522 L
.50018 .26145 L
.53256 .28767 L
.56495 .3139 L
.59733 .34013 L
.59733 .34013 L
.56495 .3139 L
.53256 .28767 L
.50018 .26145 L
.46779 .23522 L
.4354 .209 L
.40302 .18277 L
.37063 .15655 L
.33825 .13032 L
.30586 .10409 L
.27347 .07787 L
.24109 .05164 L
.2087 .02542 L
.2087 .02542 L
s
.40302 .18277 m
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
.40302 .18277 L
s
.39354 .41835 m
.41052 .41184 L
.42751 .40532 L
.44449 .3988 L
.46147 .39228 L
.47846 .38576 L
.49544 .37924 L
.51242 .37272 L
.5294 .3662 L
.54639 .35968 L
.56337 .35316 L
.58035 .34664 L
.59733 .34013 L
.59733 .34013 L
.58035 .34664 L
.56337 .35316 L
.54639 .35968 L
.5294 .3662 L
.51242 .37272 L
.49544 .37924 L
.47846 .38576 L
.46147 .39228 L
.44449 .3988 L
.42751 .40532 L
.41052 .41184 L
.39354 .41835 L
.39354 .41835 L
s
.49544 .37924 m
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
.49544 .37924 L
s
.39354 .41835 m
.36273 .40464 L
.33192 .39092 L
.30111 .3772 L
.2703 .36348 L
.23949 .34976 L
.20868 .33605 L
.17786 .32233 L
.14705 .30861 L
.11624 .29489 L
.08543 .28117 L
.05462 .26746 L
.02381 .25374 L
.02381 .25374 L
.05462 .26746 L
.08543 .28117 L
.11624 .29489 L
.14705 .30861 L
.17786 .32233 L
.20868 .33605 L
.23949 .34976 L
.2703 .36348 L
.30111 .3772 L
.33192 .39092 L
.36273 .40464 L
.39354 .41835 L
.39354 .41835 L
s
.20868 .33605 m
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
.20868 .33605 L
s
.2087 .02542 m
.02381 .25374 L
.02381 .25374 L
.2087 .02542 L
.2087 .02542 L
s
.2087 .02542 m
.59733 .34013 L
.59733 .34013 L
.2087 .02542 L
.2087 .02542 L
s
.39354 .41835 m
.59733 .34013 L
.59733 .34013 L
.39354 .41835 L
.39354 .41835 L
s
.39354 .41835 m
.02381 .25374 L
.02381 .25374 L
.39354 .41835 L
.39354 .41835 L
s
.59733 .34013 m
.2087 .02542 L
.02381 .25374 L
.39354 .41835 L
.59733 .34013 L
s
.59733 .34013 m
.2087 .02542 L
.02381 .25374 L
.39354 .41835 L
.59733 .34013 L
s
.039 .916 .04 r
.11494 .02542 m
.11494 .14121 L
s
0 0 0 r
2 Mabswid
.11494 .14121 Mdot
.039 .916 .04 r
.5 Mabswid
.08368 .02542 m
.08368 .1798 L
s
0 0 0 r
2 Mabswid
.08368 .1798 Mdot
.039 .916 .04 r
.5 Mabswid
.05243 .02542 m
.05243 .2184 L
s
0 0 0 r
2 Mabswid
.05243 .2184 Mdot
.039 .916 .04 r
.5 Mabswid
.11494 .14121 m
.18247 .32438 L
s
0 0 0 r
2 Mabswid
.18247 .32438 Mdot
.039 .916 .04 r
.5 Mabswid
.08368 .1798 m
.12805 .30015 L
s
0 0 0 r
2 Mabswid
.12805 .30015 Mdot
.039 .916 .04 r
.5 Mabswid
.05243 .2184 m
.07364 .27592 L
s
0 0 0 r
2 Mabswid
.07364 .27592 Mdot
.039 .916 .04 r
.5 Mabswid
.18247 .32438 m
.44733 .21865 L
s
0 0 0 r
2 Mabswid
.44733 .21865 Mdot
.039 .916 .04 r
.5 Mabswid
.12805 .30015 m
.40932 .18788 L
s
0 0 0 r
2 Mabswid
.40932 .18788 Mdot
.039 .916 .04 r
.5 Mabswid
.07364 .27592 m
.37131 .1571 L
s
0 0 0 r
2 Mabswid
.37131 .1571 Mdot
.039 .916 .04 r
.5 Mabswid
.44733 .21865 m
.95882 .19112 L
s
0 0 0 r
2 Mabswid
.95882 .19112 Mdot
.039 .916 .04 r
.5 Mabswid
.40932 .18788 m
.95882 .15829 L
s
0 0 0 r
2 Mabswid
.95882 .15829 Mdot
.039 .916 .04 r
.5 Mabswid
.37131 .1571 m
.95882 .12547 L
s
0 0 0 r
2 Mabswid
.95882 .12547 Mdot
[(L1)] .22087 .0104 0 0 Mshowa
[(L2)] .97619 .30031 0 0 Mshowa
[(L3)] .97619 .30031 0 0 Mshowa
[(L4)] .4112 .42622 0 0 Mshowa
[(L5)] .3755 .42528 0 0 Mshowa
[(L6)] .19368 .01325 0 0 Mshowa
0 0 m
1 0 L
1 .43661 L
0 .43661 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-19.8032, -2.7075, \
0.334701, 0.334701}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44438 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.216988 0.0125299 0.0252442 0.0125299 [
[.22973 .01058 -6 -4.5 ]
[.22973 .01058 6 4.5 ]
[.97619 .32742 -6 -4.5 ]
[.97619 .32742 6 4.5 ]
[.97619 .32742 -6 -4.5 ]
[.97619 .32742 6 4.5 ]
[.40585 .4338 -6 -4.5 ]
[.40585 .4338 6 4.5 ]
[.37001 .43161 -6 -4.5 ]
[.37001 .43161 6 4.5 ]
[.20232 .0125 -6 -4.5 ]
[.20232 .0125 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .44438 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.21699 .02524 m
.20089 .04376 L
.18479 .06228 L
.16869 .0808 L
.15259 .09932 L
.1365 .11784 L
.1204 .13636 L
.1043 .15488 L
.0882 .17339 L
.0721 .19191 L
.05601 .21043 L
.03991 .22895 L
.02381 .24747 L
.02381 .24747 L
.03991 .22895 L
.05601 .21043 L
.0721 .19191 L
.0882 .17339 L
.1043 .15488 L
.1204 .13636 L
.1365 .11784 L
.15259 .09932 L
.16869 .0808 L
.18479 .06228 L
.20089 .04376 L
.21699 .02524 L
.21699 .02524 L
s
.1204 .13636 m
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
.1204 .13636 L
s
.21699 .02524 m
.24851 .05265 L
.28003 .08005 L
.31155 .10745 L
.34307 .13485 L
.37459 .16225 L
.40612 .18965 L
.43764 .21705 L
.46916 .24445 L
.50068 .27185 L
.5322 .29926 L
.56372 .32666 L
.59524 .35406 L
.59524 .35406 L
.56372 .32666 L
.5322 .29926 L
.50068 .27185 L
.46916 .24445 L
.43764 .21705 L
.40612 .18965 L
.37459 .16225 L
.34307 .13485 L
.31155 .10745 L
.28003 .08005 L
.24851 .05265 L
.21699 .02524 L
.21699 .02524 L
s
.40612 .18965 m
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
.40612 .18965 L
s
.38838 .42529 m
.40562 .41935 L
.42286 .41341 L
.4401 .40748 L
.45734 .40154 L
.47458 .39561 L
.49181 .38967 L
.50905 .38374 L
.52629 .3778 L
.54353 .37186 L
.56077 .36593 L
.57801 .35999 L
.59524 .35406 L
.59524 .35406 L
.57801 .35999 L
.56077 .36593 L
.54353 .37186 L
.52629 .3778 L
.50905 .38374 L
.49181 .38967 L
.47458 .39561 L
.45734 .40154 L
.4401 .40748 L
.42286 .41341 L
.40562 .41935 L
.38838 .42529 L
.38838 .42529 L
s
.49181 .38967 m
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
.49181 .38967 L
s
.38838 .42529 m
.358 .41047 L
.32762 .39565 L
.29724 .38083 L
.26686 .36601 L
.23648 .3512 L
.2061 .33638 L
.17572 .32156 L
.14533 .30674 L
.11495 .29192 L
.08457 .27711 L
.05419 .26229 L
.02381 .24747 L
.02381 .24747 L
.05419 .26229 L
.08457 .27711 L
.11495 .29192 L
.14533 .30674 L
.17572 .32156 L
.2061 .33638 L
.23648 .3512 L
.26686 .36601 L
.29724 .38083 L
.32762 .39565 L
.358 .41047 L
.38838 .42529 L
.38838 .42529 L
s
.2061 .33638 m
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
.2061 .33638 L
s
.21699 .02524 m
.02381 .24747 L
.02381 .24747 L
.21699 .02524 L
.21699 .02524 L
s
.21699 .02524 m
.59524 .35406 L
.59524 .35406 L
.21699 .02524 L
.21699 .02524 L
s
.38838 .42529 m
.59524 .35406 L
.59524 .35406 L
.38838 .42529 L
.38838 .42529 L
s
.38838 .42529 m
.02381 .24747 L
.02381 .24747 L
.38838 .42529 L
.38838 .42529 L
s
.59524 .35406 m
.21699 .02524 L
.02381 .24747 L
.38838 .42529 L
.59524 .35406 L
s
.59524 .35406 m
.21699 .02524 L
.02381 .24747 L
.38838 .42529 L
.59524 .35406 L
s
.039 .916 .04 r
.12301 .02524 m
.12301 .13335 L
s
0 0 0 r
2 Mabswid
.12301 .13335 Mdot
.039 .916 .04 r
.5 Mabswid
.09169 .02524 m
.09169 .16938 L
s
0 0 0 r
2 Mabswid
.09169 .16938 Mdot
.039 .916 .04 r
.5 Mabswid
.06036 .02524 m
.06036 .20542 L
s
0 0 0 r
2 Mabswid
.06036 .20542 Mdot
.039 .916 .04 r
.5 Mabswid
.12301 .13335 m
.19127 .32915 L
s
0 0 0 r
2 Mabswid
.19127 .32915 Mdot
.039 .916 .04 r
.5 Mabswid
.09169 .16938 m
.13839 .30336 L
s
0 0 0 r
2 Mabswid
.13839 .30336 Mdot
.039 .916 .04 r
.5 Mabswid
.06036 .20542 m
.08551 .27757 L
s
0 0 0 r
2 Mabswid
.08551 .27757 Mdot
.039 .916 .04 r
.5 Mabswid
.19127 .32915 m
.46105 .2374 L
s
0 0 0 r
2 Mabswid
.46105 .2374 Mdot
.039 .916 .04 r
.5 Mabswid
.13839 .30336 m
.42485 .20594 L
s
0 0 0 r
2 Mabswid
.42485 .20594 Mdot
.039 .916 .04 r
.5 Mabswid
.08551 .27757 m
.38866 .17448 L
s
0 0 0 r
2 Mabswid
.38866 .17448 Mdot
.039 .916 .04 r
.5 Mabswid
.46105 .2374 m
.96878 .24525 L
s
0 0 0 r
2 Mabswid
.96878 .24525 Mdot
.039 .916 .04 r
.5 Mabswid
.42485 .20594 m
.96878 .21434 L
s
0 0 0 r
2 Mabswid
.96878 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.38866 .17448 m
.96878 .18344 L
s
0 0 0 r
2 Mabswid
.96878 .18344 Mdot
[(L1)] .22973 .01058 0 0 Mshowa
[(L2)] .97619 .32742 0 0 Mshowa
[(L3)] .97619 .32742 0 0 Mshowa
[(L4)] .40585 .4338 0 0 Mshowa
[(L5)] .37001 .43161 0 0 Mshowa
[(L6)] .20232 .0125 0 0 Mshowa
0 0 m
1 0 L
1 .44438 L
0 .44438 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-21.1688, -2.70004, \
0.339896, 0.339896}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4505 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.224577 0.0125269 0.0249571 0.0125269 [
[.23785 .01073 -6 -4.5 ]
[.23785 .01073 6 4.5 ]
[.97264 .35336 -6 -4.5 ]
[.97264 .35336 6 4.5 ]
[.97264 .35336 -6 -4.5 ]
[.97264 .35336 6 4.5 ]
[.39905 .43977 -6 -4.5 ]
[.39905 .43977 6 4.5 ]
[.36326 .43633 -6 -4.5 ]
[.36326 .43633 6 4.5 ]
[.21035 .01169 -6 -4.5 ]
[.21035 .01169 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .4505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.22458 .02496 m
.20785 .0429 L
.19112 .06084 L
.17439 .07878 L
.15765 .09672 L
.14092 .11466 L
.12419 .13261 L
.10746 .15055 L
.09073 .16849 L
.074 .18643 L
.05727 .20437 L
.04054 .22231 L
.02381 .24025 L
.02381 .24025 L
.04054 .22231 L
.05727 .20437 L
.074 .18643 L
.09073 .16849 L
.10746 .15055 L
.12419 .13261 L
.14092 .11466 L
.15765 .09672 L
.17439 .07878 L
.19112 .06084 L
.20785 .0429 L
.22458 .02496 L
.22458 .02496 L
s
.12419 .13261 m
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
.12419 .13261 L
s
.22458 .02496 m
.25512 .05343 L
.28565 .08191 L
.31619 .11039 L
.34673 .13887 L
.37727 .16735 L
.40781 .19582 L
.43835 .2243 L
.46889 .25278 L
.49942 .28126 L
.52996 .30973 L
.5605 .33821 L
.59104 .36669 L
.59104 .36669 L
.5605 .33821 L
.52996 .30973 L
.49942 .28126 L
.46889 .25278 L
.43835 .2243 L
.40781 .19582 L
.37727 .16735 L
.34673 .13887 L
.31619 .11039 L
.28565 .08191 L
.25512 .05343 L
.22458 .02496 L
.22458 .02496 L
s
.40781 .19582 m
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
.40781 .19582 L
s
.38187 .43064 m
.3993 .42531 L
.41673 .41998 L
.43416 .41465 L
.45159 .40932 L
.46903 .40399 L
.48646 .39866 L
.50389 .39334 L
.52132 .38801 L
.53875 .38268 L
.55618 .37735 L
.57361 .37202 L
.59104 .36669 L
.59104 .36669 L
.57361 .37202 L
.55618 .37735 L
.53875 .38268 L
.52132 .38801 L
.50389 .39334 L
.48646 .39866 L
.46903 .40399 L
.45159 .40932 L
.43416 .41465 L
.41673 .41998 L
.3993 .42531 L
.38187 .43064 L
.38187 .43064 L
s
.48646 .39866 m
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
.48646 .39866 L
s
.38187 .43064 m
.35203 .41477 L
.32219 .39891 L
.29236 .38304 L
.26252 .36718 L
.23268 .35131 L
.20284 .33545 L
.173 .31958 L
.14316 .30372 L
.11332 .28785 L
.08349 .27199 L
.05365 .25612 L
.02381 .24025 L
.02381 .24025 L
.05365 .25612 L
.08349 .27199 L
.11332 .28785 L
.14316 .30372 L
.173 .31958 L
.20284 .33545 L
.23268 .35131 L
.26252 .36718 L
.29236 .38304 L
.32219 .39891 L
.35203 .41477 L
.38187 .43064 L
.38187 .43064 L
s
.20284 .33545 m
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
.20284 .33545 L
s
.22458 .02496 m
.02381 .24025 L
.02381 .24025 L
.22458 .02496 L
.22458 .02496 L
s
.22458 .02496 m
.59104 .36669 L
.59104 .36669 L
.22458 .02496 L
.22458 .02496 L
s
.38187 .43064 m
.59104 .36669 L
.59104 .36669 L
.38187 .43064 L
.38187 .43064 L
s
.38187 .43064 m
.02381 .24025 L
.02381 .24025 L
.38187 .43064 L
.38187 .43064 L
s
.59104 .36669 m
.22458 .02496 L
.02381 .24025 L
.38187 .43064 L
.59104 .36669 L
s
.59104 .36669 m
.22458 .02496 L
.02381 .24025 L
.38187 .43064 L
.59104 .36669 L
s
.039 .916 .04 r
.13063 .02496 m
.13063 .12571 L
s
0 0 0 r
2 Mabswid
.13063 .12571 Mdot
.039 .916 .04 r
.5 Mabswid
.09931 .02496 m
.09931 .15929 L
s
0 0 0 r
2 Mabswid
.09931 .15929 Mdot
.039 .916 .04 r
.5 Mabswid
.06799 .02496 m
.06799 .19288 L
s
0 0 0 r
2 Mabswid
.06799 .19288 Mdot
.039 .916 .04 r
.5 Mabswid
.13063 .12571 m
.19903 .33342 L
s
0 0 0 r
2 Mabswid
.19903 .33342 Mdot
.039 .916 .04 r
.5 Mabswid
.09931 .15929 m
.14766 .30611 L
s
0 0 0 r
2 Mabswid
.14766 .30611 Mdot
.039 .916 .04 r
.5 Mabswid
.06799 .19288 m
.09629 .27879 L
s
0 0 0 r
2 Mabswid
.09629 .27879 Mdot
.039 .916 .04 r
.5 Mabswid
.19903 .33342 m
.47253 .25618 L
s
0 0 0 r
2 Mabswid
.47253 .25618 Mdot
.039 .916 .04 r
.5 Mabswid
.14766 .30611 m
.4381 .22407 L
s
0 0 0 r
2 Mabswid
.4381 .22407 Mdot
.039 .916 .04 r
.5 Mabswid
.09629 .27879 m
.40368 .19197 L
s
0 0 0 r
2 Mabswid
.40368 .19197 Mdot
.039 .916 .04 r
.5 Mabswid
.47253 .25618 m
.97619 .30004 L
s
0 0 0 r
2 Mabswid
.97619 .30004 Mdot
.039 .916 .04 r
.5 Mabswid
.4381 .22407 m
.97619 .27094 L
s
0 0 0 r
2 Mabswid
.97619 .27094 Mdot
.039 .916 .04 r
.5 Mabswid
.40368 .19197 m
.97619 .24183 L
s
0 0 0 r
2 Mabswid
.97619 .24183 Mdot
[(L1)] .23785 .01073 0 0 Mshowa
[(L2)] .97264 .35336 0 0 Mshowa
[(L3)] .97264 .35336 0 0 Mshowa
[(L4)] .39905 .43977 0 0 Mshowa
[(L5)] .36326 .43633 0 0 Mshowa
[(L6)] .21035 .01169 0 0 Mshowa
0 0 m
1 0 L
1 .4505 L
0 .4505 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-22.4521, -2.68683, \
0.344652, 0.344652}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45263 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.230366 0.0124304 0.0244369 0.0124304 [
[.24403 .01078 -6 -4.5 ]
[.24403 .01078 6 4.5 ]
[.96086 .37602 -6 -4.5 ]
[.96086 .37602 6 4.5 ]
[.96086 .37602 -6 -4.5 ]
[.96086 .37602 6 4.5 ]
[.38903 .44186 -6 -4.5 ]
[.38903 .44186 6 4.5 ]
[.35364 .4372 -6 -4.5 ]
[.35364 .4372 6 4.5 ]
[.21671 .01078 -6 -4.5 ]
[.21671 .01078 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .45263 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.23037 .02444 m
.21315 .04165 L
.19594 .05886 L
.17873 .07608 L
.16151 .09329 L
.1443 .1105 L
.12709 .12772 L
.10987 .14493 L
.09266 .16214 L
.07545 .17935 L
.05824 .19657 L
.04102 .21378 L
.02381 .23099 L
.02381 .23099 L
.04102 .21378 L
.05824 .19657 L
.07545 .17935 L
.09266 .16214 L
.10987 .14493 L
.12709 .12772 L
.1443 .1105 L
.16151 .09329 L
.17873 .07608 L
.19594 .05886 L
.21315 .04165 L
.23037 .02444 L
.23037 .02444 L
s
.12709 .12772 m
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
.12709 .12772 L
s
.23037 .02444 m
.25966 .05374 L
.28896 .08303 L
.31826 .11233 L
.34756 .14163 L
.37686 .17093 L
.40616 .20023 L
.43546 .22953 L
.46476 .25883 L
.49405 .28813 L
.52335 .31742 L
.55265 .34672 L
.58195 .37602 L
.58195 .37602 L
.55265 .34672 L
.52335 .31742 L
.49405 .28813 L
.46476 .25883 L
.43546 .22953 L
.40616 .20023 L
.37686 .17093 L
.34756 .14163 L
.31826 .11233 L
.28896 .08303 L
.25966 .05374 L
.23037 .02444 L
.23037 .02444 L
s
.40616 .20023 m
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
.40616 .20023 L
s
.3723 .4322 m
.38977 .42752 L
.40725 .42283 L
.42472 .41815 L
.44219 .41347 L
.45966 .40879 L
.47713 .40411 L
.4946 .39943 L
.51207 .39475 L
.52954 .39007 L
.54701 .38538 L
.56448 .3807 L
.58195 .37602 L
.58195 .37602 L
.56448 .3807 L
.54701 .38538 L
.52954 .39007 L
.51207 .39475 L
.4946 .39943 L
.47713 .40411 L
.45966 .40879 L
.44219 .41347 L
.42472 .41815 L
.40725 .42283 L
.38977 .42752 L
.3723 .4322 L
.3723 .4322 L
s
.47713 .40411 m
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
.47713 .40411 L
s
.3723 .4322 m
.34326 .41543 L
.31422 .39866 L
.28518 .3819 L
.25614 .36513 L
.2271 .34836 L
.19806 .33159 L
.16902 .31483 L
.13997 .29806 L
.11093 .28129 L
.08189 .26453 L
.05285 .24776 L
.02381 .23099 L
.02381 .23099 L
.05285 .24776 L
.08189 .26453 L
.11093 .28129 L
.13997 .29806 L
.16902 .31483 L
.19806 .33159 L
.2271 .34836 L
.25614 .36513 L
.28518 .3819 L
.31422 .39866 L
.34326 .41543 L
.3723 .4322 L
.3723 .4322 L
s
.19806 .33159 m
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
.19806 .33159 L
s
.23037 .02444 m
.02381 .23099 L
.02381 .23099 L
.23037 .02444 L
.23037 .02444 L
s
.23037 .02444 m
.58195 .37602 L
.58195 .37602 L
.23037 .02444 L
.23037 .02444 L
s
.3723 .4322 m
.58195 .37602 L
.58195 .37602 L
.3723 .4322 L
.3723 .4322 L
s
.3723 .4322 m
.02381 .23099 L
.02381 .23099 L
.3723 .4322 L
.3723 .4322 L
s
.58195 .37602 m
.23037 .02444 L
.02381 .23099 L
.3723 .4322 L
.58195 .37602 L
s
.58195 .37602 m
.23037 .02444 L
.02381 .23099 L
.3723 .4322 L
.58195 .37602 L
s
.039 .916 .04 r
.13714 .02444 m
.13714 .11766 L
s
0 0 0 r
2 Mabswid
.13714 .11766 Mdot
.039 .916 .04 r
.5 Mabswid
.10606 .02444 m
.10606 .14874 L
s
0 0 0 r
2 Mabswid
.10606 .14874 Mdot
.039 .916 .04 r
.5 Mabswid
.07499 .02444 m
.07499 .17982 L
s
0 0 0 r
2 Mabswid
.07499 .17982 Mdot
.039 .916 .04 r
.5 Mabswid
.13714 .11766 m
.20485 .33552 L
s
0 0 0 r
2 Mabswid
.20485 .33552 Mdot
.039 .916 .04 r
.5 Mabswid
.10606 .14874 m
.15521 .30686 L
s
0 0 0 r
2 Mabswid
.15521 .30686 Mdot
.039 .916 .04 r
.5 Mabswid
.07499 .17982 m
.10556 .27819 L
s
0 0 0 r
2 Mabswid
.10556 .27819 Mdot
.039 .916 .04 r
.5 Mabswid
.20485 .33552 m
.4794 .27347 L
s
0 0 0 r
2 Mabswid
.4794 .27347 Mdot
.039 .916 .04 r
.5 Mabswid
.15521 .30686 m
.44687 .24094 L
s
0 0 0 r
2 Mabswid
.44687 .24094 Mdot
.039 .916 .04 r
.5 Mabswid
.10556 .27819 m
.41434 .20842 L
s
0 0 0 r
2 Mabswid
.41434 .20842 Mdot
.039 .916 .04 r
.5 Mabswid
.4794 .27347 m
.97619 .35403 L
s
0 0 0 r
2 Mabswid
.97619 .35403 Mdot
.039 .916 .04 r
.5 Mabswid
.44687 .24094 m
.97619 .32678 L
s
0 0 0 r
2 Mabswid
.97619 .32678 Mdot
.039 .916 .04 r
.5 Mabswid
.41434 .20842 m
.97619 .29953 L
s
0 0 0 r
2 Mabswid
.97619 .29953 Mdot
[(L1)] .24403 .01078 0 0 Mshowa
[(L2)] .96086 .37602 0 0 Mshowa
[(L3)] .96086 .37602 0 0 Mshowa
[(L4)] .38903 .44186 0 0 Mshowa
[(L5)] .35364 .4372 0 0 Mshowa
[(L6)] .21671 .01078 0 0 Mshowa
0 0 m
1 0 L
1 .45263 L
0 .45263 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-23.3051, -2.66925, \
0.34898, 0.34898}},
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8053 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.067286 0.0104348 0.540912 0.0104348 [
[.66315 .52766 -6 -4.5 ]
[.66315 .52766 6 4.5 ]
[.02381 .31896 -6 -4.5 ]
[.02381 .31896 6 4.5 ]
[.02381 .31896 -6 -4.5 ]
[.02381 .31896 6 4.5 ]
[.32405 .69527 -6 -4.5 ]
[.32405 .69527 6 4.5 ]
[.34348 .71018 -6 -4.5 ]
[.34348 .71018 6 4.5 ]
[.6764 .54091 -6 -4.5 ]
[.6764 .54091 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .8053 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.66315 .54091 m
.66315 .56135 L
.66315 .58178 L
.66315 .60222 L
.66315 .62265 L
.66315 .64309 L
.66315 .66352 L
.66315 .68396 L
.66315 .70439 L
.66315 .72482 L
.66315 .74526 L
.66315 .76569 L
.66315 .78613 L
.66315 .78613 L
.66315 .76569 L
.66315 .74526 L
.66315 .72482 L
.66315 .70439 L
.66315 .68396 L
.66315 .66352 L
.66315 .64309 L
.66315 .62265 L
.66315 .60222 L
.66315 .58178 L
.66315 .56135 L
.66315 .54091 L
.66315 .54091 L
s
.66315 .66352 m
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
.66315 .66352 L
s
.66315 .54091 m
.62836 .54091 L
.59358 .54091 L
.5588 .54091 L
.52402 .54091 L
.48923 .54091 L
.45445 .54091 L
.41967 .54091 L
.38489 .54091 L
.3501 .54091 L
.31532 .54091 L
.28054 .54091 L
.24576 .54091 L
.24576 .54091 L
.28054 .54091 L
.31532 .54091 L
.3501 .54091 L
.38489 .54091 L
.41967 .54091 L
.45445 .54091 L
.48923 .54091 L
.52402 .54091 L
.5588 .54091 L
.59358 .54091 L
.62836 .54091 L
.66315 .54091 L
.66315 .54091 L
s
.45445 .54091 m
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
.45445 .54091 L
s
.33686 .6987 m
.32926 .68555 L
.32167 .6724 L
.31408 .65925 L
.30649 .6461 L
.2989 .63295 L
.29131 .61981 L
.28371 .60666 L
.27612 .59351 L
.26853 .58036 L
.26094 .56721 L
.25335 .55406 L
.24576 .54091 L
.24576 .54091 L
.25335 .55406 L
.26094 .56721 L
.26853 .58036 L
.27612 .59351 L
.28371 .60666 L
.29131 .61981 L
.2989 .63295 L
.30649 .6461 L
.31408 .65925 L
.32167 .6724 L
.32926 .68555 L
.33686 .6987 L
.33686 .6987 L
s
.29131 .61981 m
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
.29131 .61981 L
s
.33686 .6987 m
.36405 .70599 L
.39124 .71327 L
.41843 .72056 L
.44562 .72784 L
.47281 .73513 L
.5 .74241 L
.52719 .7497 L
.55438 .75699 L
.58157 .76427 L
.60877 .77156 L
.63596 .77884 L
.66315 .78613 L
.66315 .78613 L
.63596 .77884 L
.60877 .77156 L
.58157 .76427 L
.55438 .75699 L
.52719 .7497 L
.5 .74241 L
.47281 .73513 L
.44562 .72784 L
.41843 .72056 L
.39124 .71327 L
.36405 .70599 L
.33686 .6987 L
.33686 .6987 L
s
.5 .74241 m
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
.5 .74241 L
s
.66315 .54091 m
.66315 .78613 L
.66315 .78613 L
.66315 .54091 L
.66315 .54091 L
s
.66315 .54091 m
.24576 .54091 L
.24576 .54091 L
.66315 .54091 L
.66315 .54091 L
s
.33686 .6987 m
.24576 .54091 L
.24576 .54091 L
.33686 .6987 L
.33686 .6987 L
s
.33686 .6987 m
.66315 .78613 L
.66315 .78613 L
.33686 .6987 L
.33686 .6987 L
s
.24576 .54091 m
.66315 .54091 L
.66315 .78613 L
.33686 .6987 L
.24576 .54091 L
s
.24576 .54091 m
.66315 .54091 L
.66315 .78613 L
.33686 .6987 L
.24576 .54091 L
s
.039 .916 .04 r
.97619 .76526 m
.66315 .76526 L
s
0 0 0 r
2 Mabswid
.66315 .76526 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .73917 m
.66315 .73917 L
s
0 0 0 r
2 Mabswid
.66315 .73917 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .71309 m
.66315 .71309 L
s
0 0 0 r
2 Mabswid
.66315 .71309 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .76526 m
.58526 .76526 L
s
0 0 0 r
2 Mabswid
.58526 .76526 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .73917 m
.4879 .73917 L
s
0 0 0 r
2 Mabswid
.4879 .73917 Mdot
.039 .916 .04 r
.5 Mabswid
.66315 .71309 m
.39055 .71309 L
s
0 0 0 r
2 Mabswid
.39055 .71309 Mdot
.039 .916 .04 r
.5 Mabswid
.58526 .76526 m
.2703 .58341 L
s
0 0 0 r
2 Mabswid
.2703 .58341 Mdot
.039 .916 .04 r
.5 Mabswid
.4879 .73917 m
.29638 .6286 L
s
0 0 0 r
2 Mabswid
.29638 .6286 Mdot
.039 .916 .04 r
.5 Mabswid
.39055 .71309 m
.32247 .67378 L
s
0 0 0 r
2 Mabswid
.32247 .67378 Mdot
.039 .916 .04 r
.5 Mabswid
.2703 .58341 m
.2703 .54091 L
s
0 0 0 r
2 Mabswid
.2703 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .6286 m
.29638 .54091 L
s
0 0 0 r
2 Mabswid
.29638 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.32247 .67378 m
.32247 .54091 L
s
0 0 0 r
2 Mabswid
.32247 .54091 Mdot
.039 .916 .04 r
.5 Mabswid
.2703 .54091 m
.2703 .01917 L
s
0 0 0 r
2 Mabswid
.2703 .01917 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .54091 m
.29638 .01917 L
s
0 0 0 r
2 Mabswid
.29638 .01917 Mdot
.039 .916 .04 r
.5 Mabswid
.32247 .54091 m
.32247 .01917 L
s
0 0 0 r
2 Mabswid
.32247 .01917 Mdot
[(L1)] .66315 .52766 0 0 Mshowa
[(L2)] .02381 .31896 0 0 Mshowa
[(L3)] .02381 .31896 0 0 Mshowa
[(L4)] .32405 .69527 0 0 Mshowa
[(L5)] .34348 .71018 0 0 Mshowa
[(L6)] .6764 .54091 0 0 Mshowa
0 0 m
1 0 L
1 .8053 L
0 .8053 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.875, 109.375},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 257.875}, {108.375, 0}} -> {-38.4487, -51.8377, \
0.712113, 0.712113}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[2,WaveLength->0.680], LineOfRays[2,WaveLength->0.710], \
LineOfRays[2,WaveLength->0.410],
Move[PellinBrocaPrism[60,40.0,23.5,79.5,10.0,ComponentMedium->BK7],{30,8,-33}]\
,
Move[Prism[{45,40,45},10,ComponentMedium->BK7],{58,-150,-47}],
Move[Prism[{45,40,45},10,ComponentMedium->BK7],{308,-150,47}],
Boundary[{0,-200,-50},{350,50,50}]},PlotType->TopView
];\
\>", "Input",
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68631 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.061108 0.00261452 0.539245 0.00261452 [
[.21016 .47689 -6 -4.5 ]
[.21016 .47689 6 4.5 ]
[.02381 .53556 -6 -4.5 ]
[.02381 .53556 6 4.5 ]
[.02381 .53556 -6 -4.5 ]
[.02381 .53556 6 4.5 ]
[.15901 .59686 -6 -4.5 ]
[.15901 .59686 6 4.5 ]
[.21596 .59909 -6 -4.5 ]
[.21596 .59909 6 4.5 ]
[.25357 .48611 -6 -4.5 ]
[.25357 .48611 6 4.5 ]
[.1898 .12567 -6 -4.5 ]
[.1898 .12567 6 4.5 ]
[.88933 .12567 -6 -4.5 ]
[.88933 .12567 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .68631 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.22725 .5032 m
.23004 .5075 L
.23283 .51179 L
.23562 .51608 L
.23841 .52038 L
.2412 .52467 L
.24398 .52897 L
.24677 .53326 L
.24956 .53756 L
.25235 .54185 L
.25514 .54614 L
.25793 .55044 L
.26072 .55473 L
.26072 .55473 L
.25793 .55044 L
.25514 .54614 L
.25235 .54185 L
.24956 .53756 L
.24677 .53326 L
.24398 .52897 L
.2412 .52467 L
.23841 .52038 L
.23562 .51608 L
.23283 .51179 L
.23004 .5075 L
.22725 .5032 L
.22725 .5032 L
s
.24398 .52897 m
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
.24398 .52897 L
s
.22725 .5032 m
.21994 .50795 L
.21263 .5127 L
.20533 .51744 L
.19802 .52219 L
.19071 .52694 L
.1834 .53168 L
.17609 .53643 L
.16878 .54117 L
.16147 .54592 L
.15416 .55067 L
.14685 .55541 L
.13954 .56016 L
.13954 .56016 L
.14685 .55541 L
.15416 .55067 L
.16147 .54592 L
.16878 .54117 L
.17609 .53643 L
.1834 .53168 L
.19071 .52694 L
.19802 .52219 L
.20533 .51744 L
.21263 .5127 L
.21994 .50795 L
.22725 .5032 L
.22725 .5032 L
s
.1834 .53168 m
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
.1834 .53168 L
s
.188 .58485 m
.18396 .58279 L
.17992 .58074 L
.17589 .57868 L
.17185 .57662 L
.16781 .57456 L
.16377 .57251 L
.15973 .57045 L
.1557 .56839 L
.15166 .56633 L
.14762 .56428 L
.14358 .56222 L
.13954 .56016 L
.13954 .56016 L
.14358 .56222 L
.14762 .56428 L
.15166 .56633 L
.1557 .56839 L
.15973 .57045 L
.16377 .57251 L
.16781 .57456 L
.17185 .57662 L
.17589 .57868 L
.17992 .58074 L
.18396 .58279 L
.188 .58485 L
.188 .58485 L
s
.16377 .57251 m
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
.16377 .57251 L
s
.188 .58485 m
.19406 .58234 L
.20012 .57983 L
.20618 .57732 L
.21224 .57481 L
.2183 .5723 L
.22436 .56979 L
.23042 .56728 L
.23648 .56477 L
.24254 .56226 L
.2486 .55975 L
.25466 .55724 L
.26072 .55473 L
.26072 .55473 L
.25466 .55724 L
.2486 .55975 L
.24254 .56226 L
.23648 .56477 L
.23042 .56728 L
.22436 .56979 L
.2183 .5723 L
.21224 .57481 L
.20618 .57732 L
.20012 .57983 L
.19406 .58234 L
.188 .58485 L
.188 .58485 L
s
.22436 .56979 m
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
.22436 .56979 L
s
.22725 .5032 m
.26072 .55473 L
.26072 .55473 L
.22725 .5032 L
.22725 .5032 L
s
.22725 .5032 m
.13954 .56016 L
.13954 .56016 L
.22725 .5032 L
.22725 .5032 L
s
.188 .58485 m
.13954 .56016 L
.13954 .56016 L
.188 .58485 L
.188 .58485 L
s
.188 .58485 m
.26072 .55473 L
.26072 .55473 L
.188 .58485 L
.188 .58485 L
s
.13954 .56016 m
.22725 .5032 L
.26072 .55473 L
.188 .58485 L
.13954 .56016 L
s
.13954 .56016 m
.22725 .5032 L
.26072 .55473 L
.188 .58485 L
.13954 .56016 L
s
.17709 .18531 m
.24841 .10882 L
.24841 .10882 L
.17709 .18531 L
.17709 .18531 L
s
.24841 .10882 m
.25099 .18273 L
.25099 .18273 L
.24841 .10882 L
.24841 .10882 L
s
.17709 .18531 m
.25099 .18273 L
.25099 .18273 L
.17709 .18531 L
.17709 .18531 L
s
.24841 .10882 m
.17709 .18531 L
.25099 .18273 L
.24841 .10882 L
s
.24841 .10882 m
.17709 .18531 L
.25099 .18273 L
.24841 .10882 L
s
.83072 .10882 m
.90204 .18531 L
.90204 .18531 L
.83072 .10882 L
.83072 .10882 L
s
.90204 .18531 m
.82814 .18273 L
.82814 .18273 L
.90204 .18531 L
.90204 .18531 L
s
.83072 .10882 m
.82814 .18273 L
.82814 .18273 L
.83072 .10882 L
.83072 .10882 L
s
.90204 .18531 m
.83072 .10882 L
.82814 .18273 L
.90204 .18531 L
s
.90204 .18531 m
.83072 .10882 L
.82814 .18273 L
.90204 .18531 L
s
.97619 .66997 m
.97619 .01634 L
.97619 .01634 L
.97619 .66997 L
.97619 .66997 L
s
.97619 .01634 m
.06111 .01634 L
.06111 .01634 L
.97619 .01634 L
.97619 .01634 L
s
.06111 .01634 m
.06111 .66997 L
.06111 .66997 L
.06111 .01634 L
.06111 .01634 L
s
.06111 .66997 m
.97619 .66997 L
.97619 .66997 L
.06111 .66997 L
.06111 .66997 L
s
.97619 .01634 m
.97619 .66997 L
.06111 .66997 L
.06111 .01634 L
.97619 .01634 L
s
.97619 .66997 m
.97619 .01634 L
.06111 .01634 L
.06111 .66997 L
.97619 .66997 L
s
.927 .004 .008 r
.06111 .53663 m
.17578 .53663 L
s
0 0 0 r
2 Mabswid
.17578 .53663 Mdot
.927 .004 .008 r
.5 Mabswid
.06111 .53925 m
.17175 .53925 L
s
0 0 0 r
2 Mabswid
.17175 .53925 Mdot
.927 .004 .008 r
.5 Mabswid
.06111 .54186 m
.16773 .54186 L
s
0 0 0 r
2 Mabswid
.16773 .54186 Mdot
.844 .001 .007 r
.5 Mabswid
.06111 .53663 m
.17578 .53663 L
s
0 0 0 r
2 Mabswid
.17578 .53663 Mdot
.844 .001 .007 r
.5 Mabswid
.06111 .53925 m
.17175 .53925 L
s
0 0 0 r
2 Mabswid
.17175 .53925 Mdot
.844 .001 .007 r
.5 Mabswid
.06111 .54186 m
.16773 .54186 L
s
0 0 0 r
2 Mabswid
.16773 .54186 Mdot
.001 .037 .937 r
.5 Mabswid
.06111 .53663 m
.17578 .53663 L
s
0 0 0 r
2 Mabswid
.17578 .53663 Mdot
.001 .037 .937 r
.5 Mabswid
.06111 .53925 m
.17175 .53925 L
s
0 0 0 r
2 Mabswid
.17175 .53925 Mdot
.001 .037 .937 r
.5 Mabswid
.06111 .54186 m
.16773 .54186 L
s
0 0 0 r
2 Mabswid
.16773 .54186 Mdot
.927 .004 .008 r
.5 Mabswid
.17578 .53663 m
.23876 .56382 L
s
0 0 0 r
2 Mabswid
.23876 .56382 Mdot
.927 .004 .008 r
.5 Mabswid
.17175 .53925 m
.23362 .56596 L
s
0 0 0 r
2 Mabswid
.23362 .56596 Mdot
.927 .004 .008 r
.5 Mabswid
.16773 .54186 m
.22847 .56809 L
s
0 0 0 r
2 Mabswid
.22847 .56809 Mdot
.844 .001 .007 r
.5 Mabswid
.17578 .53663 m
.23879 .56381 L
s
0 0 0 r
2 Mabswid
.23879 .56381 Mdot
.844 .001 .007 r
.5 Mabswid
.17175 .53925 m
.23365 .56594 L
s
0 0 0 r
2 Mabswid
.23365 .56594 Mdot
.844 .001 .007 r
.5 Mabswid
.16773 .54186 m
.2285 .56807 L
s
0 0 0 r
2 Mabswid
.2285 .56807 Mdot
.001 .037 .937 r
.5 Mabswid
.17578 .53663 m
.23816 .56408 L
s
0 0 0 r
2 Mabswid
.23816 .56408 Mdot
.001 .037 .937 r
.5 Mabswid
.17175 .53925 m
.23302 .5662 L
s
0 0 0 r
2 Mabswid
.23302 .5662 Mdot
.001 .037 .937 r
.5 Mabswid
.16773 .54186 m
.22789 .56833 L
s
0 0 0 r
2 Mabswid
.22789 .56833 Mdot
.927 .004 .008 r
.5 Mabswid
.23876 .56382 m
.24933 .5372 L
s
0 0 0 r
2 Mabswid
.24933 .5372 Mdot
.927 .004 .008 r
.5 Mabswid
.23362 .56596 m
.24666 .53309 L
s
0 0 0 r
2 Mabswid
.24666 .53309 Mdot
.927 .004 .008 r
.5 Mabswid
.22847 .56809 m
.24399 .52898 L
s
0 0 0 r
2 Mabswid
.24399 .52898 Mdot
.844 .001 .007 r
.5 Mabswid
.23879 .56381 m
.24935 .53723 L
s
0 0 0 r
2 Mabswid
.24935 .53723 Mdot
.844 .001 .007 r
.5 Mabswid
.23365 .56594 m
.24669 .53313 L
s
0 0 0 r
2 Mabswid
.24669 .53313 Mdot
.844 .001 .007 r
.5 Mabswid
.2285 .56807 m
.24402 .52902 L
s
0 0 0 r
2 Mabswid
.24402 .52902 Mdot
.001 .037 .937 r
.5 Mabswid
.23816 .56408 m
.24888 .5365 L
s
0 0 0 r
2 Mabswid
.24888 .5365 Mdot
.001 .037 .937 r
.5 Mabswid
.23302 .5662 m
.24618 .53235 L
s
0 0 0 r
2 Mabswid
.24618 .53235 Mdot
.001 .037 .937 r
.5 Mabswid
.22789 .56833 m
.24349 .52821 L
s
0 0 0 r
2 Mabswid
.24349 .52821 Mdot
.927 .004 .008 r
.5 Mabswid
.24933 .5372 m
.22376 .18368 L
s
0 0 0 r
2 Mabswid
.22376 .18368 Mdot
.927 .004 .008 r
.5 Mabswid
.24666 .53309 m
.22139 .18376 L
s
0 0 0 r
2 Mabswid
.22139 .18376 Mdot
.927 .004 .008 r
.5 Mabswid
.24399 .52898 m
.21902 .18385 L
s
0 0 0 r
2 Mabswid
.21902 .18385 Mdot
.844 .001 .007 r
.5 Mabswid
.24935 .53723 m
.22444 .18366 L
s
0 0 0 r
2 Mabswid
.22444 .18366 Mdot
.844 .001 .007 r
.5 Mabswid
.24669 .53313 m
.22207 .18374 L
s
0 0 0 r
2 Mabswid
.22207 .18374 Mdot
.844 .001 .007 r
.5 Mabswid
.24402 .52902 m
.2197 .18382 L
s
0 0 0 r
2 Mabswid
.2197 .18382 Mdot
.001 .037 .937 r
.5 Mabswid
.24888 .5365 m
.20977 .18417 L
s
0 0 0 r
2 Mabswid
.20977 .18417 Mdot
.001 .037 .937 r
.5 Mabswid
.24618 .53235 m
.20755 .18425 L
s
0 0 0 r
2 Mabswid
.20755 .18425 Mdot
.001 .037 .937 r
.5 Mabswid
.24349 .52821 m
.20532 .18432 L
s
0 0 0 r
2 Mabswid
.20532 .18432 Mdot
.927 .004 .008 r
.5 Mabswid
.22376 .18368 m
.22104 .13817 L
s
0 0 0 r
2 Mabswid
.22104 .13817 Mdot
.927 .004 .008 r
.5 Mabswid
.22139 .18376 m
.21881 .14056 L
s
0 0 0 r
2 Mabswid
.21881 .14056 Mdot
.927 .004 .008 r
.5 Mabswid
.21902 .18385 m
.21659 .14295 L
s
0 0 0 r
2 Mabswid
.21659 .14295 Mdot
.844 .001 .007 r
.5 Mabswid
.22444 .18366 m
.22174 .13742 L
s
0 0 0 r
2 Mabswid
.22174 .13742 Mdot
.844 .001 .007 r
.5 Mabswid
.22207 .18374 m
.21951 .13982 L
s
0 0 0 r
2 Mabswid
.21951 .13982 Mdot
.844 .001 .007 r
.5 Mabswid
.2197 .18382 m
.21727 .14222 L
s
0 0 0 r
2 Mabswid
.21727 .14222 Mdot
.001 .037 .937 r
.5 Mabswid
.20977 .18417 m
.20715 .15308 L
s
0 0 0 r
2 Mabswid
.20715 .15308 Mdot
.001 .037 .937 r
.5 Mabswid
.20755 .18425 m
.2051 .15527 L
s
0 0 0 r
2 Mabswid
.2051 .15527 Mdot
.001 .037 .937 r
.5 Mabswid
.20532 .18432 m
.20305 .15747 L
s
0 0 0 r
2 Mabswid
.20305 .15747 Mdot
.927 .004 .008 r
.5 Mabswid
.22104 .13817 m
.24943 .13788 L
s
0 0 0 r
2 Mabswid
.24943 .13788 Mdot
.927 .004 .008 r
.5 Mabswid
.21881 .14056 m
.24951 .14025 L
s
0 0 0 r
2 Mabswid
.24951 .14025 Mdot
.927 .004 .008 r
.5 Mabswid
.21659 .14295 m
.24959 .14261 L
s
0 0 0 r
2 Mabswid
.24959 .14261 Mdot
.844 .001 .007 r
.5 Mabswid
.22174 .13742 m
.2494 .1371 L
s
0 0 0 r
2 Mabswid
.2494 .1371 Mdot
.844 .001 .007 r
.5 Mabswid
.21951 .13982 m
.24948 .13948 L
s
0 0 0 r
2 Mabswid
.24948 .13948 Mdot
.844 .001 .007 r
.5 Mabswid
.21727 .14222 m
.24957 .14185 L
s
0 0 0 r
2 Mabswid
.24957 .14185 Mdot
.001 .037 .937 r
.5 Mabswid
.20715 .15308 m
.24998 .1537 L
s
0 0 0 r
2 Mabswid
.24998 .1537 Mdot
.001 .037 .937 r
.5 Mabswid
.2051 .15527 m
.25006 .15592 L
s
0 0 0 r
2 Mabswid
.25006 .15592 Mdot
.001 .037 .937 r
.5 Mabswid
.20305 .15747 m
.25013 .15815 L
s
0 0 0 r
2 Mabswid
.25013 .15815 Mdot
.927 .004 .008 r
.5 Mabswid
.24943 .13788 m
.82966 .13928 L
s
0 0 0 r
2 Mabswid
.82966 .13928 Mdot
.927 .004 .008 r
.5 Mabswid
.24951 .14025 m
.82957 .14164 L
s
0 0 0 r
2 Mabswid
.82957 .14164 Mdot
.927 .004 .008 r
.5 Mabswid
.24959 .14261 m
.82949 .14401 L
s
0 0 0 r
2 Mabswid
.82949 .14401 Mdot
.844 .001 .007 r
.5 Mabswid
.2494 .1371 m
.82972 .13741 L
s
0 0 0 r
2 Mabswid
.82972 .13741 Mdot
.844 .001 .007 r
.5 Mabswid
.24948 .13948 m
.82964 .13978 L
s
0 0 0 r
2 Mabswid
.82964 .13978 Mdot
.844 .001 .007 r
.5 Mabswid
.24957 .14185 m
.82955 .14215 L
s
0 0 0 r
2 Mabswid
.82955 .14215 Mdot
.001 .037 .937 r
.5 Mabswid
.24998 .1537 m
.82833 .17726 L
s
0 0 0 r
2 Mabswid
.82833 .17726 Mdot
.001 .037 .937 r
.5 Mabswid
.25006 .15592 m
.82825 .17948 L
s
0 0 0 r
2 Mabswid
.82825 .17948 Mdot
.001 .037 .937 r
.5 Mabswid
.25013 .15815 m
.82817 .1817 L
s
0 0 0 r
2 Mabswid
.82817 .1817 Mdot
.927 .004 .008 r
.5 Mabswid
.82966 .13928 m
.85949 .13968 L
s
0 0 0 r
2 Mabswid
.85949 .13968 Mdot
.927 .004 .008 r
.5 Mabswid
.82957 .14164 m
.86173 .14208 L
s
0 0 0 r
2 Mabswid
.86173 .14208 Mdot
.927 .004 .008 r
.5 Mabswid
.82949 .14401 m
.86396 .14447 L
s
0 0 0 r
2 Mabswid
.86396 .14447 Mdot
.844 .001 .007 r
.5 Mabswid
.82972 .13741 m
.85769 .13775 L
s
0 0 0 r
2 Mabswid
.85769 .13775 Mdot
.844 .001 .007 r
.5 Mabswid
.82964 .13978 m
.85993 .14015 L
s
0 0 0 r
2 Mabswid
.85993 .14015 Mdot
.844 .001 .007 r
.5 Mabswid
.82955 .14215 m
.86217 .14255 L
s
0 0 0 r
2 Mabswid
.86217 .14255 Mdot
.001 .037 .937 r
.5 Mabswid
.82833 .17726 m
.89702 .17992 L
s
0 0 0 r
2 Mabswid
.89702 .17992 Mdot
.001 .037 .937 r
.5 Mabswid
.82825 .17948 m
.89917 .18223 L
s
0 0 0 r
2 Mabswid
.89917 .18223 Mdot
.001 .037 .937 r
.5 Mabswid
.82817 .1817 m
.90132 .18453 L
s
0 0 0 r
2 Mabswid
.90132 .18453 Mdot
.927 .004 .008 r
.5 Mabswid
.85949 .13968 m
.85701 .18374 L
s
0 0 0 r
2 Mabswid
.85701 .18374 Mdot
.927 .004 .008 r
.5 Mabswid
.86173 .14208 m
.85937 .18382 L
s
0 0 0 r
2 Mabswid
.85937 .18382 Mdot
.927 .004 .008 r
.5 Mabswid
.86396 .14447 m
.86174 .1839 L
s
0 0 0 r
2 Mabswid
.86174 .1839 Mdot
.844 .001 .007 r
.5 Mabswid
.85769 .13775 m
.85504 .18367 L
s
0 0 0 r
2 Mabswid
.85504 .18367 Mdot
.844 .001 .007 r
.5 Mabswid
.85993 .14015 m
.85741 .18375 L
s
0 0 0 r
2 Mabswid
.85741 .18375 Mdot
.844 .001 .007 r
.5 Mabswid
.86217 .14255 m
.85979 .18383 L
s
0 0 0 r
2 Mabswid
.85979 .18383 Mdot
.001 .037 .937 r
.5 Mabswid
.89702 .17992 m
.89686 .18513 L
s
0 0 0 r
2 Mabswid
.89686 .18513 Mdot
.001 .037 .937 r
.5 Mabswid
.89917 .18223 m
.89908 .18521 L
s
0 0 0 r
2 Mabswid
.89908 .18521 Mdot
.001 .037 .937 r
.5 Mabswid
.90132 .18453 m
.9013 .18528 L
s
0 0 0 r
2 Mabswid
.9013 .18528 Mdot
.927 .004 .008 r
.5 Mabswid
.85701 .18374 m
.82418 .66997 L
s
0 0 0 r
2 Mabswid
.82418 .66997 Mdot
.927 .004 .008 r
.5 Mabswid
.85937 .18382 m
.82655 .66997 L
s
0 0 0 r
2 Mabswid
.82655 .66997 Mdot
.927 .004 .008 r
.5 Mabswid
.86174 .1839 m
.82892 .66997 L
s
0 0 0 r
2 Mabswid
.82892 .66997 Mdot
.844 .001 .007 r
.5 Mabswid
.85504 .18367 m
.82129 .66997 L
s
0 0 0 r
2 Mabswid
.82129 .66997 Mdot
.844 .001 .007 r
.5 Mabswid
.85741 .18375 m
.82367 .66997 L
s
0 0 0 r
2 Mabswid
.82367 .66997 Mdot
.844 .001 .007 r
.5 Mabswid
.85979 .18383 m
.82605 .66997 L
s
0 0 0 r
2 Mabswid
.82605 .66997 Mdot
.001 .037 .937 r
.5 Mabswid
.89686 .18513 m
.88275 .66997 L
s
0 0 0 r
2 Mabswid
.88275 .66997 Mdot
.001 .037 .937 r
.5 Mabswid
.89908 .18521 m
.88497 .66997 L
s
0 0 0 r
2 Mabswid
.88497 .66997 Mdot
.001 .037 .937 r
.5 Mabswid
.9013 .18528 m
.88719 .66997 L
s
0 0 0 r
2 Mabswid
.88719 .66997 Mdot
[(L1)] .21016 .47689 0 0 Mshowa
[(L2)] .02381 .53556 0 0 Mshowa
[(L3)] .02381 .53556 0 0 Mshowa
[(L4)] .15901 .59686 0 0 Mshowa
[(L5)] .21596 .59909 0 0 Mshowa
[(L6)] .25357 .48611 0 0 Mshowa
[(P1)] .1898 .12567 0 0 Mshowa
[(P2)] .88933 .12567 0 0 Mshowa
0 0 m
1 0 L
1 .68631 L
0 .68631 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{286, 196.188},
  ImageMargins->{{42, 0}, {0, 4}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 285}, {195.188, 0}} -> {-23.777, -206.251, 1.34487, \
1.34487}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "DrawSystem[{\nLineOfRays[5,WaveLength->1.064],\n\
LineOfRays[5,WaveLength->0.532],\nLineOfRays[5,WaveLength->0.355],\n\n\
Move[PellinBrocaPrism[60,40.0,23.5,79.5,10.0,ComponentMedium->BK7],{30,8,-33}]\
,\nBoundary[{0,-500,-50},{100,50,50}]}, PlotType->TopView];",
  StyleBox["\n",
    FontFamily->"Mishawaka",
    FontSize->9]
}], "Input",
  CellTags->"PellinBrocaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.75576 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.152682 0.00823508 4.23077 0.00823508 [
[.61769 4.02746 -6 -4.5 ]
[.61769 4.02746 6 4.5 ]
[.02381 4.21675 -6 -4.5 ]
[.02381 4.21675 6 4.5 ]
[.02381 4.21675 -6 -4.5 ]
[.02381 4.21675 6 4.5 ]
[.45345 4.41539 -6 -4.5 ]
[.45345 4.41539 6 4.5 ]
[.64775 4.42302 -6 -4.5 ]
[.64775 4.42302 6 4.5 ]
[.76578 4.05894 -6 -4.5 ]
[.76578 4.05894 6 4.5 ]
[ 0 0 0 0 ]
[ 1 4.75576 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.676 4.11725 m
.68478 4.13077 L
.69356 4.1443 L
.70235 4.15782 L
.71113 4.17135 L
.71991 4.18488 L
.7287 4.1984 L
.73748 4.21193 L
.74626 4.22545 L
.75505 4.23898 L
.76383 4.2525 L
.77261 4.26603 L
.7814 4.27955 L
.7814 4.27955 L
.77261 4.26603 L
.76383 4.2525 L
.75505 4.23898 L
.74626 4.22545 L
.73748 4.21193 L
.7287 4.1984 L
.71991 4.18488 L
.71113 4.17135 L
.70235 4.15782 L
.69356 4.1443 L
.68478 4.13077 L
.676 4.11725 L
.676 4.11725 L
s
.7287 4.1984 m
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
.7287 4.1984 L
s
.676 4.11725 m
.65297 4.1322 L
.62995 4.14715 L
.60693 4.1621 L
.58391 4.17705 L
.56089 4.192 L
.53787 4.20695 L
.51484 4.2219 L
.49182 4.23685 L
.4688 4.2518 L
.44578 4.26675 L
.42276 4.2817 L
.39973 4.29665 L
.39973 4.29665 L
.42276 4.2817 L
.44578 4.26675 L
.4688 4.2518 L
.49182 4.23685 L
.51484 4.2219 L
.53787 4.20695 L
.56089 4.192 L
.58391 4.17705 L
.60693 4.1621 L
.62995 4.14715 L
.65297 4.1322 L
.676 4.11725 L
.676 4.11725 L
s
.53787 4.20695 m
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
.53787 4.20695 L
s
.55236 4.37442 m
.53964 4.36794 L
.52692 4.36146 L
.5142 4.35498 L
.50149 4.3485 L
.48877 4.34202 L
.47605 4.33554 L
.46333 4.32906 L
.45061 4.32258 L
.43789 4.3161 L
.42517 4.30962 L
.41245 4.30314 L
.39973 4.29665 L
.39973 4.29665 L
.41245 4.30314 L
.42517 4.30962 L
.43789 4.3161 L
.45061 4.32258 L
.46333 4.32906 L
.47605 4.33554 L
.48877 4.34202 L
.50149 4.3485 L
.5142 4.35498 L
.52692 4.36146 L
.53964 4.36794 L
.55236 4.37442 L
.55236 4.37442 L
s
.47605 4.33554 m
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
.47605 4.33554 L
s
.55236 4.37442 m
.57145 4.36652 L
.59053 4.35861 L
.60962 4.3507 L
.62871 4.3428 L
.64779 4.33489 L
.66688 4.32699 L
.68597 4.31908 L
.70505 4.31118 L
.72414 4.30327 L
.74322 4.29536 L
.76231 4.28746 L
.7814 4.27955 L
.7814 4.27955 L
.76231 4.28746 L
.74322 4.29536 L
.72414 4.30327 L
.70505 4.31118 L
.68597 4.31908 L
.66688 4.32699 L
.64779 4.33489 L
.62871 4.3428 L
.60962 4.3507 L
.59053 4.35861 L
.57145 4.36652 L
.55236 4.37442 L
.55236 4.37442 L
s
.66688 4.32699 m
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
.66688 4.32699 L
s
.676 4.11725 m
.7814 4.27955 L
.7814 4.27955 L
.676 4.11725 L
.676 4.11725 L
s
.676 4.11725 m
.39973 4.29665 L
.39973 4.29665 L
.676 4.11725 L
.676 4.11725 L
s
.55236 4.37442 m
.39973 4.29665 L
.39973 4.29665 L
.55236 4.37442 L
.55236 4.37442 L
s
.55236 4.37442 m
.7814 4.27955 L
.7814 4.27955 L
.55236 4.37442 L
.55236 4.37442 L
s
.39973 4.29665 m
.676 4.11725 L
.7814 4.27955 L
.55236 4.37442 L
.39973 4.29665 L
s
.39973 4.29665 m
.676 4.11725 L
.7814 4.27955 L
.55236 4.37442 L
.39973 4.29665 L
s
.97619 4.64253 m
.97619 .11323 L
.97619 .11323 L
.97619 4.64253 L
.97619 4.64253 L
s
.97619 .11323 m
.15268 .11323 L
.15268 .11323 L
.97619 .11323 L
.97619 .11323 L
s
.15268 .11323 m
.15268 4.64253 L
.15268 4.64253 L
.15268 .11323 L
.15268 .11323 L
s
.15268 4.64253 m
.97619 4.64253 L
.97619 4.64253 L
.15268 4.64253 L
.15268 4.64253 L
s
.97619 .11323 m
.97619 4.64253 L
.15268 4.64253 L
.15268 .11323 L
.97619 .11323 L
s
.97619 4.64253 m
.97619 .11323 L
.15268 .11323 L
.15268 4.64253 L
.97619 4.64253 L
s
.05 .919 .037 r
.15268 4.21019 m
.53288 4.21019 L
s
0 0 0 r
2 Mabswid
.53288 4.21019 Mdot
.05 .919 .037 r
.5 Mabswid
.15268 4.23077 m
.50118 4.23077 L
s
0 0 0 r
2 Mabswid
.50118 4.23077 Mdot
.05 .919 .037 r
.5 Mabswid
.15268 4.25136 m
.46948 4.25136 L
s
0 0 0 r
2 Mabswid
.46948 4.25136 Mdot
.039 .916 .04 r
.5 Mabswid
.15268 4.21019 m
.53288 4.21019 L
s
0 0 0 r
2 Mabswid
.53288 4.21019 Mdot
.039 .916 .04 r
.5 Mabswid
.15268 4.23077 m
.50118 4.23077 L
s
0 0 0 r
2 Mabswid
.50118 4.23077 Mdot
.039 .916 .04 r
.5 Mabswid
.15268 4.25136 m
.46948 4.25136 L
s
0 0 0 r
2 Mabswid
.46948 4.25136 Mdot
.002 .019 .73 r
.5 Mabswid
.15268 4.21019 m
.53288 4.21019 L
s
0 0 0 r
2 Mabswid
.53288 4.21019 Mdot
.002 .019 .73 r
.5 Mabswid
.15268 4.23077 m
.50118 4.23077 L
s
0 0 0 r
2 Mabswid
.50118 4.23077 Mdot
.002 .019 .73 r
.5 Mabswid
.15268 4.25136 m
.46948 4.25136 L
s
0 0 0 r
2 Mabswid
.46948 4.25136 Mdot
.05 .919 .037 r
.5 Mabswid
.53288 4.21019 m
.73744 4.29776 L
s
0 0 0 r
2 Mabswid
.73744 4.29776 Mdot
.05 .919 .037 r
.5 Mabswid
.50118 4.23077 m
.69689 4.31456 L
s
0 0 0 r
2 Mabswid
.69689 4.31456 Mdot
.05 .919 .037 r
.5 Mabswid
.46948 4.25136 m
.65634 4.33135 L
s
0 0 0 r
2 Mabswid
.65634 4.33135 Mdot
.039 .916 .04 r
.5 Mabswid
.53288 4.21019 m
.73583 4.29843 L
s
0 0 0 r
2 Mabswid
.73583 4.29843 Mdot
.039 .916 .04 r
.5 Mabswid
.50118 4.23077 m
.69535 4.3152 L
s
0 0 0 r
2 Mabswid
.69535 4.3152 Mdot
.039 .916 .04 r
.5 Mabswid
.46948 4.25136 m
.65486 4.33196 L
s
0 0 0 r
2 Mabswid
.65486 4.33196 Mdot
.002 .019 .73 r
.5 Mabswid
.53288 4.21019 m
.73357 4.29936 L
s
0 0 0 r
2 Mabswid
.73357 4.29936 Mdot
.002 .019 .73 r
.5 Mabswid
.50118 4.23077 m
.69318 4.31609 L
s
0 0 0 r
2 Mabswid
.69318 4.31609 Mdot
.002 .019 .73 r
.5 Mabswid
.46948 4.25136 m
.6528 4.33282 L
s
0 0 0 r
2 Mabswid
.6528 4.33282 Mdot
.05 .919 .037 r
.5 Mabswid
.73744 4.29776 m
.75872 4.24463 L
s
0 0 0 r
2 Mabswid
.75872 4.24463 Mdot
.05 .919 .037 r
.5 Mabswid
.69689 4.31456 m
.7378 4.21241 L
s
0 0 0 r
2 Mabswid
.7378 4.21241 Mdot
.05 .919 .037 r
.5 Mabswid
.65634 4.33135 m
.71687 4.18019 L
s
0 0 0 r
2 Mabswid
.71687 4.18019 Mdot
.039 .916 .04 r
.5 Mabswid
.73583 4.29843 m
.75766 4.243 L
s
0 0 0 r
2 Mabswid
.75766 4.243 Mdot
.039 .916 .04 r
.5 Mabswid
.69535 4.3152 m
.73657 4.21053 L
s
0 0 0 r
2 Mabswid
.73657 4.21053 Mdot
.039 .916 .04 r
.5 Mabswid
.65486 4.33196 m
.71549 4.17806 L
s
0 0 0 r
2 Mabswid
.71549 4.17806 Mdot
.002 .019 .73 r
.5 Mabswid
.73357 4.29936 m
.75615 4.24067 L
s
0 0 0 r
2 Mabswid
.75615 4.24067 Mdot
.002 .019 .73 r
.5 Mabswid
.69318 4.31609 m
.73483 4.20784 L
s
0 0 0 r
2 Mabswid
.73483 4.20784 Mdot
.002 .019 .73 r
.5 Mabswid
.6528 4.33282 m
.71351 4.17501 L
s
0 0 0 r
2 Mabswid
.71351 4.17501 Mdot
.05 .919 .037 r
.5 Mabswid
.75872 4.24463 m
.52619 .11323 L
s
0 0 0 r
2 Mabswid
.52619 .11323 Mdot
.05 .919 .037 r
.5 Mabswid
.7378 4.21241 m
.50708 .11323 L
s
0 0 0 r
2 Mabswid
.50708 .11323 Mdot
.05 .919 .037 r
.5 Mabswid
.71687 4.18019 m
.48797 .11323 L
s
0 0 0 r
2 Mabswid
.48797 .11323 Mdot
.039 .916 .04 r
.5 Mabswid
.75766 4.243 m
.40169 .11323 L
s
0 0 0 r
2 Mabswid
.40169 .11323 Mdot
.039 .916 .04 r
.5 Mabswid
.73657 4.21053 m
.3834 .11323 L
s
0 0 0 r
2 Mabswid
.3834 .11323 Mdot
.039 .916 .04 r
.5 Mabswid
.71549 4.17806 m
.36511 .11323 L
s
0 0 0 r
2 Mabswid
.36511 .11323 Mdot
.002 .019 .73 r
.5 Mabswid
.75615 4.24067 m
.20674 .11323 L
s
0 0 0 r
2 Mabswid
.20674 .11323 Mdot
.002 .019 .73 r
.5 Mabswid
.73483 4.20784 m
.18979 .11323 L
s
0 0 0 r
2 Mabswid
.18979 .11323 Mdot
.002 .019 .73 r
.5 Mabswid
.71351 4.17501 m
.17284 .11323 L
s
0 0 0 r
2 Mabswid
.17284 .11323 Mdot
[(L1)] .61769 4.02746 0 0 Mshowa
[(L2)] .02381 4.21675 0 0 Mshowa
[(L3)] .02381 4.21675 0 0 Mshowa
[(L4)] .45345 4.41539 0 0 Mshowa
[(L5)] .64775 4.42302 0 0 Mshowa
[(L6)] .76578 4.05894 0 0 Mshowa
0 0 m
1 0 L
1 4.75576 L
0 4.75576 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{79.5, 378.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 78.5}, {377.375, 0}} -> {-25.4601, -533.514, \
1.63506, 1.63506}},
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[TextData[StyleBox["As you can see, the prism disperses light of \
different wavelength. The nice thing about the PellinBroca is that you can \
enter the beam on either the A or B side at roughly the Brewster angle of \
incidence and depending on which side you choose your result is positive or \
negative dispersion. The output beams will leave the prism at also roughly \
the Brewster angle, and approximately 90 degree to the input beam. You can \
orient your PellinBroca such that the degree of deflection is exactly 90 for \
one desired wavelength. Thus, by using two  PellinBrocas, two 90 degree \
deflection prisms, and a pin hole you can easily separate the harmonics of a \
Nd:YAG laser, or the output of an optical parametric oscillator. The latter \
is my application, and I  will send you a copy of the complete set-up, once \
it is done.\n\nAlex Angerhofer\nUniversity of Florida\nDept. of Chemistry",
  FontFamily->"Mishawaka",
  FontSize->9]], "Text",
  CellTags->"PellinBrocaPrism"]
}, Closed]],

Cell[CellGroupData[{

Cell["PentaPrism[entranceheight, prismthickness, options]", "Subsection",
  CellTags->"PentaPrism"],

Cell[CellGroupData[{

Cell["?PentaPrism", "Input",
  CellTags->"PentaPrism"],

Cell[BoxData[
    \("PentaPrism[entranceheight, prismthickness, options] refers to a prism \
having and five rectangular faces and two pentagon faces. \n\nPentaPrism is \
located with its entrance face centered in the y-z plane and its polygon \
faces lieing in the horizontal x-y plane direction. PentaPrism is commonly \
used to deviate a beam by exactly 90 degrees. Two surfaces of PentaPrism are \
reflectorized. See also: DovePrism, Wedge, RhomboidalPrism, RoofPrism, \
AmiciPrism, and Prism."\)], "Print",
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[PentaPrism[10,10],PlotType->TopView];", "Input",
  CellTags->"PentaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0673435 0.360527 0.0673435 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.02381 .69724 L
.02381 .69724 L
.02381 .02381 L
.02381 .02381 L
s
.5 g
.02381 .69724 m
.69724 .97619 L
.69724 .97619 L
.02381 .69724 L
.02381 .69724 L
F
0 g
.02381 .69724 m
.69724 .97619 L
.69724 .97619 L
.02381 .69724 L
.02381 .69724 L
s
.5 g
.97619 .69724 m
.69724 .97619 L
.69724 .97619 L
.97619 .69724 L
.97619 .69724 L
F
0 g
.97619 .69724 m
.69724 .97619 L
.69724 .97619 L
.97619 .69724 L
.97619 .69724 L
s
.5 g
.69724 .02381 m
.97619 .69724 L
.97619 .69724 L
.69724 .02381 L
.69724 .02381 L
F
0 g
.69724 .02381 m
.97619 .69724 L
.97619 .69724 L
.69724 .02381 L
.69724 .02381 L
s
.02381 .02381 m
.69724 .02381 L
.69724 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.02381 .69724 L
.69724 .97619 L
.97619 .69724 L
.69724 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.02381 .69724 L
.69724 .97619 L
.97619 .69724 L
.69724 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{146.562, 146.562},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 145.562}, {145.562, 0}} -> {-0.353627, -5.35363, \
0.102014, 0.102014}},
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"PentaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95637 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.000317684 1.05183 0 1.05183 [
[ 0 0 0 0 ]
[ 1 .95637 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .95637 L
0 .95637 L
closepath
clip
newpath
.33136 .50496 m .79685 .84008 L .30932 .86433 L .671 .44 .562 r
F
.33136 .50496 m .76876 .47752 L .79685 .84008 L F
0 g
.5 Mabswid
[ ] 0 setdash
.33136 .50496 m
.76876 .47752 L
s
.08573 .26355 m
.33136 .50496 L
s
.30932 .86433 m
.33136 .50496 L
s
.48627 .1024 m .8639 .32587 L .90676 .70441 L .878 .579 .477 r
F
0 g
.77132 .5105 m
.79685 .84008 L
s
.30932 .86433 m
.79685 .84008 L
s
.02795 .64786 m
.30932 .86433 L
s
.02795 .64786 m
.08573 .26355 L
s
.48627 .1024 m .90676 .70441 L .48062 .49945 L .878 .579 .477 r
F
0 g
.48062 .49945 m
.48627 .1024 L
s
.08573 .26355 m
.48627 .1024 L
s
.79685 .84008 m
.90676 .70441 L
s
.48627 .1024 m
.8639 .32587 L
s
.8639 .32587 m
.90676 .70441 L
s
.48062 .49945 m
.90676 .70441 L
s
.02795 .64786 m
.48062 .49945 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 167.312},
  ImageMargins->{{42, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 174}, {166.312, 0}} -> {2.32248*^-5, -4.54626*^-6, \
0.00546714, 0.00546714}},
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8],
Move[PentaPrism[10,10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PentaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0555579 0.582166 0.0555579 [
[.46827 .27295 -6 -4.5 ]
[.46827 .27295 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1.11667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.19048 .30438 m
.19048 .85996 L
.19048 .85996 L
.19048 .30438 L
.19048 .30438 L
s
.5 g
.19048 .85996 m
.74606 1.09008 L
.74606 1.09008 L
.19048 .85996 L
.19048 .85996 L
F
0 g
.19048 .85996 m
.74606 1.09008 L
.74606 1.09008 L
.19048 .85996 L
.19048 .85996 L
s
.97619 .85996 m
.74606 1.09008 L
.74606 1.09008 L
.97619 .85996 L
.97619 .85996 L
s
.5 g
.74606 .30438 m
.97619 .85996 L
.97619 .85996 L
.74606 .30438 L
.74606 .30438 L
F
0 g
.74606 .30438 m
.97619 .85996 L
.97619 .85996 L
.74606 .30438 L
.74606 .30438 L
s
.19048 .30438 m
.74606 .30438 L
.74606 .30438 L
.19048 .30438 L
.19048 .30438 L
s
.19048 .30438 m
.19048 .85996 L
.74606 1.09008 L
.97619 .85996 L
.74606 .30438 L
.19048 .30438 L
s
.19048 .30438 m
.19048 .85996 L
.74606 1.09008 L
.97619 .85996 L
.74606 .30438 L
.19048 .30438 L
s
.039 .916 .04 r
.02381 .35993 m
.19048 .35993 L
s
0 0 0 r
2 Mabswid
.19048 .35993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58217 m
.19048 .58217 L
s
0 0 0 r
2 Mabswid
.19048 .58217 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .8044 m
.19048 .8044 L
s
0 0 0 r
2 Mabswid
.19048 .8044 Mdot
.039 .916 .04 r
.5 Mabswid
.19048 .35993 m
.76907 .35993 L
s
0 0 0 r
2 Mabswid
.76907 .35993 Mdot
.039 .916 .04 r
.5 Mabswid
.19048 .58217 m
.86113 .58217 L
s
0 0 0 r
2 Mabswid
.86113 .58217 Mdot
.039 .916 .04 r
.5 Mabswid
.19048 .8044 m
.95318 .8044 L
s
0 0 0 r
2 Mabswid
.95318 .8044 Mdot
.039 .916 .04 r
.5 Mabswid
.76907 .35993 m
.24604 .88297 L
s
0 0 0 r
2 Mabswid
.24604 .88297 Mdot
.039 .916 .04 r
.5 Mabswid
.86113 .58217 m
.46827 .97502 L
s
0 0 0 r
2 Mabswid
.46827 .97502 Mdot
.039 .916 .04 r
.5 Mabswid
.95318 .8044 m
.6905 1.06707 L
s
0 0 0 r
2 Mabswid
.6905 1.06707 Mdot
.039 .916 .04 r
.5 Mabswid
.24604 .88297 m
.24604 .30438 L
s
0 0 0 r
2 Mabswid
.24604 .30438 Mdot
.039 .916 .04 r
.5 Mabswid
.46827 .97502 m
.46827 .30438 L
s
0 0 0 r
2 Mabswid
.46827 .30438 Mdot
.039 .916 .04 r
.5 Mabswid
.6905 1.06707 m
.6905 .30438 L
s
0 0 0 r
2 Mabswid
.6905 .30438 Mdot
.039 .916 .04 r
.5 Mabswid
.24604 .30438 m
.24604 .02659 L
s
0 0 0 r
2 Mabswid
.24604 .02659 Mdot
.039 .916 .04 r
.5 Mabswid
.46827 .30438 m
.46827 .02659 L
s
0 0 0 r
2 Mabswid
.46827 .02659 Mdot
.039 .916 .04 r
.5 Mabswid
.6905 .30438 m
.6905 .02659 L
s
0 0 0 r
2 Mabswid
.6905 .02659 Mdot
[(PP)] .46827 .27295 0 0 Mshowa
0 0 m
1 0 L
1 1.11667 L
0 1.11667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{185.375, 206.938},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 184.375}, {205.938, 0}} -> {-0.428643, -10.4812, \
0.097624, 0.097624}},
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{Move[LineOfRays[6,NumberOfRays->7],{0,-2,30}],
Move[PentaPrism[10,10],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"PentaPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0902547 0.0442968 0.464166 0.0442968 [
[ 0 0 0 0 ]
[ 1 .89033 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.22315 .24268 m
.22315 .68565 L
.22315 .68565 L
.22315 .24268 L
.22315 .24268 L
s
.5 g
.22315 .68565 m
.66611 .86913 L
.66611 .86913 L
.22315 .68565 L
.22315 .68565 L
F
0 g
.22315 .68565 m
.66611 .86913 L
.66611 .86913 L
.22315 .68565 L
.22315 .68565 L
s
.8496 .68565 m
.66611 .86913 L
.66611 .86913 L
.8496 .68565 L
.8496 .68565 L
s
.5 g
.66611 .24268 m
.8496 .68565 L
.8496 .68565 L
.66611 .24268 L
.66611 .24268 L
F
0 g
.66611 .24268 m
.8496 .68565 L
.8496 .68565 L
.66611 .24268 L
.66611 .24268 L
s
.22315 .24268 m
.66611 .24268 L
.66611 .24268 L
.22315 .24268 L
.22315 .24268 L
s
.22315 .24268 m
.22315 .68565 L
.66611 .86913 L
.8496 .68565 L
.66611 .24268 L
.22315 .24268 L
s
.22315 .24268 m
.22315 .68565 L
.66611 .86913 L
.8496 .68565 L
.66611 .24268 L
.22315 .24268 L
s
.039 .916 .04 r
.1567 .26049 m
.22315 .29885 L
s
0 0 0 r
2 Mabswid
.22315 .29885 Mdot
.039 .916 .04 r
.5 Mabswid
.13455 .29885 m
.22315 .35 L
s
0 0 0 r
2 Mabswid
.22315 .35 Mdot
.039 .916 .04 r
.5 Mabswid
.1124 .33721 m
.22315 .40115 L
s
0 0 0 r
2 Mabswid
.22315 .40115 Mdot
.039 .916 .04 r
.5 Mabswid
.09025 .37557 m
.22315 .4523 L
s
0 0 0 r
2 Mabswid
.22315 .4523 Mdot
.039 .916 .04 r
.5 Mabswid
.06811 .41393 m
.22315 .50345 L
s
0 0 0 r
2 Mabswid
.22315 .50345 Mdot
.039 .916 .04 r
.5 Mabswid
.04596 .4523 m
.22315 .5546 L
s
0 0 0 r
2 Mabswid
.22315 .5546 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49066 m
.22315 .60575 L
s
0 0 0 r
2 Mabswid
.22315 .60575 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .29885 m
.76803 .48872 L
s
0 0 0 r
2 Mabswid
.76803 .48872 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .35 m
.79279 .5485 L
s
0 0 0 r
2 Mabswid
.79279 .5485 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .40115 m
.81755 .60828 L
s
0 0 0 r
2 Mabswid
.81755 .60828 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .4523 m
.84231 .66806 L
s
0 0 0 r
2 Mabswid
.84231 .66806 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .50345 m
.82283 .71242 L
s
0 0 0 r
2 Mabswid
.82283 .71242 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .5546 m
.7849 .75035 L
s
0 0 0 r
2 Mabswid
.7849 .75035 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .60575 m
.74697 .78828 L
s
0 0 0 r
2 Mabswid
.74697 .78828 Mdot
.039 .916 .04 r
.5 Mabswid
.76803 .48872 m
.59788 .84087 L
s
0 0 0 r
2 Mabswid
.59788 .84087 Mdot
.039 .916 .04 r
.5 Mabswid
.79279 .5485 m
.64258 .85939 L
s
0 0 0 r
2 Mabswid
.64258 .85939 Mdot
.039 .916 .04 r
.5 Mabswid
.81755 .60828 m
.71526 .81999 L
s
0 0 0 r
2 Mabswid
.71526 .81999 Mdot
.039 .916 .04 r
.5 Mabswid
.84231 .66806 m
.81905 .7162 L
s
0 0 0 r
2 Mabswid
.81905 .7162 Mdot
.039 .916 .04 r
.5 Mabswid
.82283 .71242 m
.97619 .72212 L
s
0 0 0 r
2 Mabswid
.97619 .72212 Mdot
.039 .916 .04 r
.5 Mabswid
.7849 .75035 m
.97619 .76245 L
s
0 0 0 r
2 Mabswid
.97619 .76245 Mdot
.039 .916 .04 r
.5 Mabswid
.74697 .78828 m
.97619 .80279 L
s
0 0 0 r
2 Mabswid
.97619 .80279 Mdot
.039 .916 .04 r
.5 Mabswid
.59788 .84087 m
.74227 .42653 L
s
0 0 0 r
2 Mabswid
.74227 .42653 Mdot
.039 .916 .04 r
.5 Mabswid
.64258 .85939 m
.77004 .4936 L
s
0 0 0 r
2 Mabswid
.77004 .4936 Mdot
.039 .916 .04 r
.5 Mabswid
.71526 .81999 m
.63781 .85741 L
s
0 0 0 r
2 Mabswid
.63781 .85741 Mdot
.039 .916 .04 r
.5 Mabswid
.81905 .7162 m
.57803 .83265 L
s
0 0 0 r
2 Mabswid
.57803 .83265 Mdot
.039 .916 .04 r
.5 Mabswid
.74227 .42653 m
.36176 .24268 L
s
0 0 0 r
2 Mabswid
.36176 .24268 Mdot
.039 .916 .04 r
.5 Mabswid
.77004 .4936 m
.25073 .24268 L
s
0 0 0 r
2 Mabswid
.25073 .24268 Mdot
.039 .916 .04 r
.5 Mabswid
.63781 .85741 m
.4236 .24268 L
s
0 0 0 r
2 Mabswid
.4236 .24268 Mdot
.039 .916 .04 r
.5 Mabswid
.57803 .83265 m
.37245 .24268 L
s
0 0 0 r
2 Mabswid
.37245 .24268 Mdot
.039 .916 .04 r
.5 Mabswid
.36176 .24268 m
.22315 .30966 L
s
0 0 0 r
2 Mabswid
.22315 .30966 Mdot
.039 .916 .04 r
.5 Mabswid
.25073 .24268 m
.22315 .25601 L
s
0 0 0 r
2 Mabswid
.22315 .25601 Mdot
.039 .916 .04 r
.5 Mabswid
.4236 .24268 m
.29572 .0212 L
s
0 0 0 r
2 Mabswid
.29572 .0212 Mdot
.039 .916 .04 r
.5 Mabswid
.37245 .24268 m
.24457 .0212 L
s
0 0 0 r
2 Mabswid
.24457 .0212 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .30966 m
.09025 .42673 L
s
0 0 0 r
2 Mabswid
.09025 .42673 Mdot
.039 .916 .04 r
.5 Mabswid
.22315 .25601 m
.09025 .37308 L
s
0 0 0 r
2 Mabswid
.09025 .37308 Mdot
0 0 m
1 0 L
1 .89033 L
0 .89033 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{183.812, 163.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 182.812}, {162.625, 0}} -> {-2.04722, -10.4786, \
0.123594, 0.123594}},
  CellTags->"PentaPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PorroPrism[entrancelength, thickness, options]", "Subsection",
  CellTags->"PorroPrism"],

Cell[CellGroupData[{

Cell["?PorroPrism", "Input",
  CellTags->"PorroPrism"],

Cell[BoxData[
    \("PorroPrism[entrancelength, thickness, options] designates a triangular \
corner prism that has rounded edges. \n\nPorroPrism is created with entrance \
face lying in the vertical y-z plane. If the Mirrored->True option is given, \
a reflectorized surface is placed on the two reflective faces of the prism. \
For Baffled->False, the side surface panels are refractive surfaces. If the \
Baffled->True option is given, the side panels absorb any rays hitting them. \
See also: Prism."\)], "Print",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[PorroPrism]", "Input",
  CellTags->"PorroPrism"],

Cell[BoxData[
    \({Labels \[Rule] "P", LabelPositions \[Rule] Automatic, 
      Mirrored \[Rule] False, ComponentDescription \[Rule] Automatic, 
      GraphicDesign \[Rule] Automatic, ComponentMedium \[Rule] BK7, 
      Temperature \[Rule] Temperature, Tension \[Rule] Tension, 
      Transmittance \[Rule] Transmittance, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Off \[Rule] {SurfaceRendering \[Rule] Empty, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          EdgeRendering \[Rule] Mesh, CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
          EdgeRendering \[Rule] Fill, CrossRendering \[Rule] Empty}, 
      Mirror \[Rule] {Automatic \[Rule] {SurfaceRendering \[Rule] {{Fill, 
                    Trace}}, EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}, 
          Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
              EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}}}\)], "Output",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PorroPrism[30, 10]", "Input",
  CellTags->"PorroPrism"],

Cell[BoxData[
    TagBox[\(PorroPrism[30, 10]\),
      HoldForm]], "Output",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[PorroPrism[30, 10]];", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9794 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00226099 1.08226 -5.55112e-17 1.08226 [
[ 0 0 0 0 ]
[ 1 .9794 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9794 L
0 .9794 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.52823 .72531 m
.5368 .75236 L
s
.51775 .69962 m
.52823 .72531 L
s
.5368 .75236 m
.54317 .77985 L
s
.53692 .75283 m
.54849 .83238 L
s
.52544 .71784 m
.53692 .75283 L
s
.5139 .69151 m
.52544 .71784 L
s
.50573 .67618 m
.51775 .69962 L
s
.54317 .77985 m
.54712 .80683 L
s
.50228 .67036 m
.5139 .69151 L
s
.49256 .65581 m
.50573 .67618 L
s
.54712 .80683 m
.54849 .83238 L
s
.49055 .65312 m
.50228 .67036 L
s
.58384 .73904 m
.59377 .69744 L
s
.57427 .82507 m
.58384 .73904 L
s
.58395 .7385 m
.59134 .70652 L
s
.57853 .76958 m
.58395 .7385 L
s
.57527 .79876 m
.57853 .76958 L
s
.59134 .70652 m
.60049 .6747 L
s
.57427 .82507 m
.57527 .79876 L
s
.47868 .63928 m
.49256 .65581 L
s
.54849 .83238 m
.55278 .83117 L
s
.53687 .8913 m
.54849 .83238 L
s
.54849 .83238 m
.5472 .85558 L
s
.59377 .69744 m
.60387 .66431 L
s
.47868 .63928 m
.49055 .65312 L
s
.55278 .83117 m
.55707 .82995 L
s
.55707 .82995 m
.56136 .82873 L
s
.56136 .82873 m
.56566 .82752 L
s
.56566 .82752 m
.56997 .8263 L
s
.56997 .8263 m
.57427 .82507 L
s
.60049 .6747 m
.61109 .64408 L
s
.57427 .82507 m
.58509 .87796 L
s
.57562 .84761 m
.57427 .82507 L
s
.60387 .66431 m
.61415 .63618 L
s
.50436 .63131 m
.47868 .63928 L
s
.47868 .63928 m
.15354 .30653 L
s
.63531 .59068 m
.47868 .63928 L
s
.33443 .49165 m
.47868 .63928 L
s
.5472 .85558 m
.54325 .87556 L
s
.53021 .62329 m
.50436 .63131 L
s
.61109 .64408 m
.62283 .61573 L
s
.57929 .86553 m
.57562 .84761 L
s
.61415 .63618 m
.62463 .61182 L
s
.55623 .61522 m
.53021 .62329 L
s
.54325 .87556 m
.53674 .89154 L
s
.58242 .60709 m
.55623 .61522 L
s
.62283 .61573 m
.63531 .59068 L
s
.58521 .87813 m
.57929 .86553 L
s
.62463 .61182 m
.63531 .59068 L
s
.60878 .59891 m
.58242 .60709 L
s
.52493 .9051 m
.53687 .8913 L
s
.53674 .89154 m
.52785 .90283 L
s
.63531 .59068 m
.60878 .59891 L
s
.77033 .3457 m
.63531 .59068 L
s
.58509 .87796 m
.59586 .88557 L
s
.59323 .88482 m
.58521 .87813 L
s
.52785 .90283 m
.51686 .9089 L
s
.5128 .9097 m
.52493 .9051 L
s
.51686 .9089 m
.50416 .9094 L
s
.60312 .88517 m
.59323 .88482 L
s
.5005 .90856 m
.5128 .9097 L
s
.59586 .88557 m
.60678 .88384 L
s
.50416 .9094 m
.49021 .90417 L
s
.48808 .90292 m
.5005 .90856 L
s
.61456 .87899 m
.60312 .88517 L
s
.60678 .88384 m
.61785 .8762 L
s
.49021 .90417 m
.47555 .89331 L
s
.47555 .89331 m
.48808 .90292 L
s
.62715 .86629 m
.61456 .87899 L
s
.50256 .88579 m
.47555 .89331 L
s
.47555 .89331 m
.13065 .57702 L
s
.64042 .84739 m
.47555 .89331 L
s
.47555 .89331 m
.32313 .75353 L
s
.61785 .8762 m
.62907 .86389 L
s
.52976 .87821 m
.50256 .88579 L
s
.55714 .87059 m
.52976 .87821 L
s
.33443 .49165 m
.32313 .75353 L
s
.31824 .47508 m
.33443 .49165 L
s
.58471 .86291 m
.55714 .87059 L
s
.64042 .84739 m
.62715 .86629 L
s
.62907 .86389 m
.64042 .84739 L
s
.31824 .47508 m
.30596 .73779 L
s
.15354 .30653 m
.31824 .47508 L
s
.61247 .85518 m
.58471 .86291 L
s
.64042 .84739 m
.61247 .85518 L
s
.78387 .61447 m
.64042 .84739 L
s
.32313 .75353 m
.30596 .73779 L
s
.75614 .32722 m
.77033 .3457 L
s
.77033 .3457 m
.78387 .61447 L
s
.30596 .73779 m
.13065 .57702 L
s
.32444 .24381 m
.75614 .32722 L
s
.76894 .59681 m
.75614 .32722 L
s
.1815 .29627 m
.15354 .30653 L
s
.15354 .30653 m
.13792 .2925 L
s
.15354 .30653 m
.32444 .24381 L
s
.13521 .29046 m
.15354 .30653 L
s
.20967 .28593 m
.1815 .29627 L
s
.13792 .2925 m
.12177 .28206 L
s
.11687 .27973 m
.13521 .29046 L
s
.23805 .27552 m
.20967 .28593 L
s
.26663 .26503 m
.23805 .27552 L
s
.12177 .28206 m
.10498 .27581 L
s
.29543 .25446 m
.26663 .26503 L
s
.09921 .27487 m
.11687 .27973 L
s
.32444 .24381 m
.29543 .25446 L
s
.10498 .27581 m
.08735 .27519 L
s
.28524 .23806 m
.32444 .24381 L
s
.27851 .23744 m
.32444 .24381 L
s
.0829 .27622 m
.09921 .27487 L
s
.24555 .23605 m
.28524 .23806 L
s
.23368 .23625 m
.27851 .23744 L
s
.20522 .23839 m
.24555 .23605 L
s
.08735 .27519 m
.0684 .28406 L
s
.19159 .24034 m
.23368 .23625 L
s
.06863 .28388 m
.0829 .27622 L
s
.16402 .2465 m
.20522 .23839 L
s
.15384 .24966 m
.19159 .24034 L
s
.12142 .26423 m
.16402 .2465 L
s
.057 .29772 m
.06863 .28388 L
s
.0684 .28406 m
.04375 .342 L
s
.12191 .26395 m
.15384 .24966 L
s
.76894 .59681 m
.78387 .61447 L
s
.09712 .28276 m
.12191 .26395 L
s
.07313 .3312 m
.12142 .26423 L
s
.04856 .31732 m
.057 .29772 L
s
.31141 .5169 m
.76894 .59681 L
s
.08059 .30545 m
.09712 .28276 L
s
.04375 .342 m
.04856 .31732 L
s
.13065 .57702 m
.11431 .55986 L
s
.1602 .56719 m
.13065 .57702 L
s
.13065 .57702 m
.31141 .5169 L
s
.13065 .57702 m
.11155 .55651 L
s
.07313 .3312 m
.08059 .30545 L
s
.18997 .55729 m
.1602 .56719 L
s
.11431 .55986 m
.09818 .53831 L
s
.04375 .342 m
.04863 .34021 L
s
.0527 .43533 m
.04375 .342 L
s
.04282 .37081 m
.04375 .342 L
s
.11155 .55651 m
.09345 .53101 L
s
.04863 .34021 m
.05351 .33841 L
s
.05351 .33841 m
.05841 .33661 L
s
.21997 .54731 m
.18997 .55729 L
s
.05841 .33661 m
.06331 .33481 L
s
.06331 .33481 m
.06821 .33301 L
s
.06821 .33301 m
.07313 .3312 L
s
.07313 .3312 m
.10738 .41592 L
s
.0752 .35902 m
.07313 .3312 L
s
.09818 .53831 m
.08235 .51174 L
s
.04588 .40256 m
.04282 .37081 L
s
.09345 .53101 m
.07717 .50156 L
s
.25021 .53725 m
.21997 .54731 L
s
.08235 .51174 m
.06703 .47871 L
s
.05285 .4359 m
.04588 .40256 L
s
.07717 .50156 m
.06343 .46939 L
s
.08688 .38782 m
.0752 .35902 L
s
.28069 .52711 m
.25021 .53725 L
s
.06703 .47871 m
.0527 .43533 L
s
.06343 .46939 m
.05285 .4359 L
s
.31141 .5169 m
.28069 .52711 L
s
.10782 .4164 m
.08688 .38782 L
s
.27 .50762 m
.31141 .5169 L
s
.31141 .5169 m
.26294 .50562 L
s
.10738 .41592 m
.14697 .45086 L
s
.13724 .44358 m
.10782 .4164 L
s
.22867 .49406 m
.27 .50762 L
s
.26294 .50562 m
.21647 .48915 L
s
.17397 .46818 m
.13724 .44358 L
s
.14697 .45086 m
.18757 .47562 L
s
.18757 .47562 m
.22867 .49406 L
s
.21647 .48915 m
.17397 .46818 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{160.188, 156.812},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 159.188}, {155.812, 0}} -> {0.00180065, \
-4.52484*^-6, 0.00580805, 0.00580805}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->TopView];", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.93548 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0614439 1.42857 0.0614439 [
[ 0 0 0 0 ]
[ 1 1.93548 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .99846 m
.02381 .99846 L
.02381 1.58218 L
.02381 1.64212 L
.02381 1.69975 L
.02381 1.75286 L
.02381 1.79942 L
.02381 1.83763 L
.02381 1.86602 L
.02381 1.8835 L
.02381 1.8894 L
.02381 1.8835 L
.02381 1.86602 L
.02381 1.83763 L
.02381 1.79942 L
.02381 1.75286 L
.02381 1.69975 L
.02381 1.64212 L
.02381 1.58218 L
.02381 .99846 L
s
.02381 .93702 m
.02381 .99846 L
.02381 .99846 L
.02381 .93702 L
.02381 .93702 L
s
.39247 .3533 m
.33254 .29337 L
.27491 .23573 L
.22179 .18262 L
.17524 .13607 L
.13703 .09786 L
.10864 .06947 L
.09116 .05199 L
.08525 .04608 L
.09116 .05199 L
.10864 .06947 L
.13703 .09786 L
.17524 .13607 L
.22179 .18262 L
.27491 .23573 L
.33254 .29337 L
.39247 .3533 L
.97619 .93702 L
.97619 .93702 L
.39247 .3533 L
s
.97619 .99846 m
.97619 .99846 L
.39247 1.58218 L
.33254 1.64212 L
.27491 1.69975 L
.22179 1.75286 L
.17524 1.79942 L
.13703 1.83763 L
.10864 1.86602 L
.09116 1.8835 L
.08525 1.8894 L
.09116 1.8835 L
.10864 1.86602 L
.13703 1.83763 L
.17524 1.79942 L
.22179 1.75286 L
.27491 1.69975 L
.33254 1.64212 L
.39247 1.58218 L
.97619 .99846 L
s
.97619 .93702 m
.97619 .99846 L
.97619 .99846 L
.97619 .93702 L
.97619 .93702 L
s
.02381 .3533 m
.02381 .29337 L
.02381 .23573 L
.02381 .18262 L
.02381 .13607 L
.02381 .09786 L
.02381 .06947 L
.02381 .05199 L
.02381 .04608 L
.02381 .05199 L
.02381 .06947 L
.02381 .09786 L
.02381 .13607 L
.02381 .18262 L
.02381 .23573 L
.02381 .29337 L
.02381 .3533 L
.02381 .93702 L
.02381 .93702 L
.02381 .3533 L
s
.02381 .3533 m
.39247 .3533 L
.97619 .93702 L
.97619 .99846 L
.39247 1.58218 L
.02381 1.58218 L
.02381 .3533 L
s
.02381 .3533 m
.39247 .3533 L
.97619 .93702 L
.97619 .99846 L
.39247 1.58218 L
.02381 1.58218 L
.02381 .3533 L
s
.39247 1.58218 m
.36175 1.58218 L
.33103 1.58218 L
.30031 1.58218 L
.26959 1.58218 L
.23886 1.58218 L
.20814 1.58218 L
.17742 1.58218 L
.1467 1.58218 L
.11598 1.58218 L
.08525 1.58218 L
.05453 1.58218 L
.02381 1.58218 L
.02381 1.58218 L
.02381 1.60778 L
.02381 1.63338 L
.02381 1.65899 L
.02381 1.68459 L
.02381 1.71019 L
.02381 1.73579 L
.02381 1.76139 L
.02381 1.78699 L
.02381 1.8126 L
.02381 1.8382 L
.02381 1.8638 L
.02381 1.8894 L
.02381 1.8894 L
.02893 1.8894 L
.03405 1.8894 L
.03917 1.8894 L
.04429 1.8894 L
.04941 1.8894 L
.05453 1.8894 L
.05965 1.8894 L
.06477 1.8894 L
.06989 1.8894 L
.07501 1.8894 L
.08013 1.8894 L
.08525 1.8894 L
.08525 1.8894 L
.11086 1.8638 L
.13646 1.8382 L
.16206 1.8126 L
.18766 1.78699 L
.21326 1.76139 L
.23886 1.73579 L
.26446 1.71019 L
.29007 1.68459 L
.31567 1.65899 L
.34127 1.63338 L
Mistroke
.36687 1.60778 L
.39247 1.58218 L
Mfstroke
.02381 1.58218 m
.02381 1.60778 L
.02381 1.63338 L
.02381 1.65899 L
.02381 1.68459 L
.02381 1.71019 L
.02381 1.73579 L
.02381 1.76139 L
.02381 1.78699 L
.02381 1.8126 L
.02381 1.8382 L
.02381 1.8638 L
.02381 1.8894 L
.02381 1.8894 L
.02893 1.8894 L
.03405 1.8894 L
.03917 1.8894 L
.04429 1.8894 L
.04941 1.8894 L
.05453 1.8894 L
.05965 1.8894 L
.06477 1.8894 L
.06989 1.8894 L
.07501 1.8894 L
.08013 1.8894 L
.08525 1.8894 L
.08525 1.8894 L
.11086 1.8638 L
.13646 1.8382 L
.16206 1.8126 L
.18766 1.78699 L
.21326 1.76139 L
.23886 1.73579 L
.26446 1.71019 L
.29007 1.68459 L
.31567 1.65899 L
.34127 1.63338 L
.36687 1.60778 L
.39247 1.58218 L
.39247 1.58218 L
.36175 1.58218 L
.33103 1.58218 L
.30031 1.58218 L
.26959 1.58218 L
.23886 1.58218 L
.20814 1.58218 L
.17742 1.58218 L
.1467 1.58218 L
.11598 1.58218 L
.08525 1.58218 L
Mistroke
.05453 1.58218 L
.02381 1.58218 L
Mfstroke
.02381 .3533 m
.02381 .3277 L
.02381 .3021 L
.02381 .2765 L
.02381 .2509 L
.02381 .22529 L
.02381 .19969 L
.02381 .17409 L
.02381 .14849 L
.02381 .12289 L
.02381 .09729 L
.02381 .07168 L
.02381 .04608 L
.02381 .04608 L
.02893 .04608 L
.03405 .04608 L
.03917 .04608 L
.04429 .04608 L
.04941 .04608 L
.05453 .04608 L
.05965 .04608 L
.06477 .04608 L
.06989 .04608 L
.07501 .04608 L
.08013 .04608 L
.08525 .04608 L
.08525 .04608 L
.11086 .07168 L
.13646 .09729 L
.16206 .12289 L
.18766 .14849 L
.21326 .17409 L
.23886 .19969 L
.26446 .22529 L
.29007 .2509 L
.31567 .2765 L
.34127 .3021 L
.36687 .3277 L
.39247 .3533 L
.39247 .3533 L
.36175 .3533 L
.33103 .3533 L
.30031 .3533 L
.26959 .3533 L
.23886 .3533 L
.20814 .3533 L
.17742 .3533 L
.1467 .3533 L
.11598 .3533 L
.08525 .3533 L
Mistroke
.05453 .3533 L
.02381 .3533 L
Mfstroke
.39247 .3533 m
.36175 .3533 L
.33103 .3533 L
.30031 .3533 L
.26959 .3533 L
.23886 .3533 L
.20814 .3533 L
.17742 .3533 L
.1467 .3533 L
.11598 .3533 L
.08525 .3533 L
.05453 .3533 L
.02381 .3533 L
.02381 .3533 L
.02381 .3277 L
.02381 .3021 L
.02381 .2765 L
.02381 .2509 L
.02381 .22529 L
.02381 .19969 L
.02381 .17409 L
.02381 .14849 L
.02381 .12289 L
.02381 .09729 L
.02381 .07168 L
.02381 .04608 L
.02381 .04608 L
.02893 .04608 L
.03405 .04608 L
.03917 .04608 L
.04429 .04608 L
.04941 .04608 L
.05453 .04608 L
.05965 .04608 L
.06477 .04608 L
.06989 .04608 L
.07501 .04608 L
.08013 .04608 L
.08525 .04608 L
.08525 .04608 L
.11086 .07168 L
.13646 .09729 L
.16206 .12289 L
.18766 .14849 L
.21326 .17409 L
.23886 .19969 L
.26446 .22529 L
.29007 .2509 L
.31567 .2765 L
.34127 .3021 L
Mistroke
.36687 .3277 L
.39247 .3533 L
Mfstroke
0 0 m
1 0 L
1 1.93548 L
0 1.93548 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{70.3125, 136},
  ImageMargins->{{44, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 69.3125}, {135, 0}} -> {-0.387581, -23.3496, \
0.234809, 0.234809}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->FrontView];", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.031746 0.166667 0.031746 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.51587 .3254 m
.51587 .00794 L
.81746 .00794 L
.84843 .01099 L
.8782 .02002 L
.90565 .03469 L
.9297 .05443 L
.94944 .07848 L
.96411 .10592 L
.97314 .1357 L
.97619 .16667 L
.97314 .19763 L
.96411 .22741 L
.94944 .25485 L
.9297 .27891 L
.90565 .29865 L
.8782 .31331 L
.84843 .32235 L
.81746 .3254 L
.51587 .3254 L
s
.48413 .00794 m
.51587 .00794 L
.51587 .3254 L
.48413 .3254 L
.48413 .00794 L
s
.18254 .3254 m
.15157 .32235 L
.1218 .31331 L
.09435 .29865 L
.0703 .27891 L
.05056 .25485 L
.03589 .22741 L
.02686 .19763 L
.02381 .16667 L
.02686 .1357 L
.03589 .10592 L
.05056 .07848 L
.0703 .05443 L
.09435 .03469 L
.1218 .02002 L
.15157 .01099 L
.18254 .00794 L
.48413 .00794 L
.48413 .3254 L
.18254 .3254 L
s
.51587 .00794 m
.51587 .3254 L
.81746 .3254 L
.84843 .32235 L
.8782 .31331 L
.90565 .29865 L
.9297 .27891 L
.94944 .25485 L
.96411 .22741 L
.97314 .19763 L
.97619 .16667 L
.97314 .1357 L
.96411 .10592 L
.94944 .07848 L
.9297 .05443 L
.90565 .03469 L
.8782 .02002 L
.84843 .01099 L
.81746 .00794 L
.51587 .00794 L
s
.48413 .00794 m
.51587 .00794 L
.51587 .3254 L
.48413 .3254 L
.48413 .00794 L
s
.18254 .3254 m
.15157 .32235 L
.1218 .31331 L
.09435 .29865 L
.0703 .27891 L
.05056 .25485 L
.03589 .22741 L
.02686 .19763 L
.02381 .16667 L
.02686 .1357 L
.03589 .10592 L
.05056 .07848 L
.0703 .05443 L
.09435 .03469 L
.1218 .02002 L
.15157 .01099 L
.18254 .00794 L
.48413 .00794 L
.48413 .3254 L
.18254 .3254 L
s
.18254 .3254 m
.18254 .3254 L
.48413 .3254 L
.51587 .3254 L
.81746 .3254 L
.81746 .3254 L
.18254 .3254 L
s
.18254 .00794 m
.18254 .00794 L
.48413 .00794 L
.51587 .00794 L
.81746 .00794 L
.81746 .00794 L
.18254 .00794 L
s
.81746 .00794 m
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.81746 .00794 L
.83069 .00849 L
.84392 .01016 L
.85714 .01298 L
.87037 .01701 L
.8836 .02237 L
.89683 .0292 L
.91005 .03774 L
.92328 .04836 L
.93651 .06168 L
.94974 .07893 L
.96296 .10323 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.96296 .10323 L
.94974 .07893 L
.93651 .06168 L
.92328 .04836 L
.91005 .03774 L
.89683 .0292 L
.8836 .02237 L
.87037 .01701 L
.85714 .01298 L
.84392 .01016 L
Mistroke
.83069 .00849 L
.81746 .00794 L
Mfstroke
.81746 .3254 m
.83069 .32484 L
.84392 .32318 L
.85714 .32036 L
.87037 .31632 L
.8836 .31096 L
.89683 .30413 L
.91005 .29559 L
.92328 .28498 L
.93651 .27166 L
.94974 .25441 L
.96296 .2301 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.96296 .2301 L
.94974 .25441 L
.93651 .27166 L
.92328 .28498 L
.91005 .29559 L
.89683 .30413 L
.8836 .31096 L
.87037 .31632 L
.85714 .32036 L
.84392 .32318 L
.83069 .32484 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
.81746 .3254 L
Mistroke
.81746 .3254 L
.81746 .3254 L
Mfstroke
.18254 .00794 m
.16931 .00849 L
.15608 .01016 L
.14286 .01298 L
.12963 .01701 L
.1164 .02237 L
.10317 .0292 L
.08995 .03774 L
.07672 .04836 L
.06349 .06168 L
.05026 .07893 L
.03704 .10323 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.03704 .10323 L
.05026 .07893 L
.06349 .06168 L
.07672 .04836 L
.08995 .03774 L
.10317 .0292 L
.1164 .02237 L
.12963 .01701 L
.14286 .01298 L
.15608 .01016 L
.16931 .00849 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
.18254 .00794 L
Mistroke
.18254 .00794 L
.18254 .00794 L
Mfstroke
.18254 .3254 m
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.18254 .3254 L
.16931 .32484 L
.15608 .32318 L
.14286 .32036 L
.12963 .31632 L
.1164 .31096 L
.10317 .30413 L
.08995 .29559 L
.07672 .28498 L
.06349 .27166 L
.05026 .25441 L
.03704 .2301 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.02381 .16667 L
.03704 .2301 L
.05026 .25441 L
.06349 .27166 L
.07672 .28498 L
.08995 .29559 L
.10317 .30413 L
.1164 .31096 L
.12963 .31632 L
.14286 .32036 L
.15608 .32318 L
Mistroke
.16931 .32484 L
.18254 .3254 L
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{208, 69.1875},
  ImageMargins->{{9, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 207}, {68.1875, 0}} -> {-23.4377, -5.25007, \
0.153987, 0.153987}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->SideView];", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64516 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0614439 0.322581 0.0614439 [
[ 0 0 0 0 ]
[ 1 .64516 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .6298 m
.02381 .01536 L
.02381 .01536 L
.02381 .02126 L
.02381 .03875 L
.02381 .06714 L
.02381 .10534 L
.02381 .1519 L
.02381 .20501 L
.02381 .26265 L
.02381 .32258 L
.02381 .38252 L
.02381 .44015 L
.02381 .49326 L
.02381 .53982 L
.02381 .57802 L
.02381 .60641 L
.02381 .6239 L
.02381 .6298 L
.02381 .6298 L
s
.02381 .01536 m
.02381 .01536 L
.02381 .6298 L
.02381 .6298 L
.02381 .01536 L
s
.39247 .6298 m
.33254 .6239 L
.27491 .60641 L
.22179 .57802 L
.17524 .53982 L
.13703 .49326 L
.10864 .44015 L
.09116 .38252 L
.08525 .32258 L
.09116 .26265 L
.10864 .20501 L
.13703 .1519 L
.17524 .10534 L
.22179 .06714 L
.27491 .03875 L
.33254 .02126 L
.39247 .01536 L
.97619 .01536 L
.97619 .6298 L
.39247 .6298 L
s
.97619 .01536 m
.97619 .6298 L
.39247 .6298 L
.33254 .6239 L
.27491 .60641 L
.22179 .57802 L
.17524 .53982 L
.13703 .49326 L
.10864 .44015 L
.09116 .38252 L
.08525 .32258 L
.09116 .26265 L
.10864 .20501 L
.13703 .1519 L
.17524 .10534 L
.22179 .06714 L
.27491 .03875 L
.33254 .02126 L
.39247 .01536 L
.97619 .01536 L
s
.97619 .01536 m
.97619 .01536 L
.97619 .6298 L
.97619 .6298 L
.97619 .01536 L
s
.02381 .6298 m
.02381 .6239 L
.02381 .60641 L
.02381 .57802 L
.02381 .53982 L
.02381 .49326 L
.02381 .44015 L
.02381 .38252 L
.02381 .32258 L
.02381 .26265 L
.02381 .20501 L
.02381 .1519 L
.02381 .10534 L
.02381 .06714 L
.02381 .03875 L
.02381 .02126 L
.02381 .01536 L
.02381 .01536 L
.02381 .6298 L
.02381 .6298 L
s
.02381 .6298 m
.39247 .6298 L
.97619 .6298 L
.97619 .6298 L
.39247 .6298 L
.02381 .6298 L
.02381 .6298 L
s
.02381 .01536 m
.39247 .01536 L
.97619 .01536 L
.97619 .01536 L
.39247 .01536 L
.02381 .01536 L
.02381 .01536 L
s
.39247 .01536 m
.36175 .01536 L
.33103 .01536 L
.30031 .01536 L
.26959 .01536 L
.23886 .01536 L
.20814 .01536 L
.17742 .01536 L
.1467 .01536 L
.11598 .01536 L
.08525 .01536 L
.05453 .01536 L
.02381 .01536 L
.02381 .01536 L
.02381 .01643 L
.02381 .01966 L
.02381 .02512 L
.02381 .03293 L
.02381 .0433 L
.02381 .05652 L
.02381 .07305 L
.02381 .09359 L
.02381 .11937 L
.02381 .15276 L
.02381 .1998 L
.02381 .32258 L
.02381 .32258 L
.02893 .32258 L
.03405 .32258 L
.03917 .32258 L
.04429 .32258 L
.04941 .32258 L
.05453 .32258 L
.05965 .32258 L
.06477 .32258 L
.06989 .32258 L
.07501 .32258 L
.08013 .32258 L
.08525 .32258 L
.08525 .32258 L
.11086 .1998 L
.13646 .15276 L
.16206 .11937 L
.18766 .09359 L
.21326 .07305 L
.23886 .05652 L
.26446 .0433 L
.29007 .03293 L
.31567 .02512 L
.34127 .01966 L
Mistroke
.36687 .01643 L
.39247 .01536 L
Mfstroke
.02381 .6298 m
.02381 .62873 L
.02381 .6255 L
.02381 .62004 L
.02381 .61223 L
.02381 .60186 L
.02381 .58864 L
.02381 .57211 L
.02381 .55157 L
.02381 .52579 L
.02381 .4924 L
.02381 .44536 L
.02381 .32258 L
.02381 .32258 L
.02893 .32258 L
.03405 .32258 L
.03917 .32258 L
.04429 .32258 L
.04941 .32258 L
.05453 .32258 L
.05965 .32258 L
.06477 .32258 L
.06989 .32258 L
.07501 .32258 L
.08013 .32258 L
.08525 .32258 L
.08525 .32258 L
.11086 .44536 L
.13646 .4924 L
.16206 .52579 L
.18766 .55157 L
.21326 .57211 L
.23886 .58864 L
.26446 .60186 L
.29007 .61223 L
.31567 .62004 L
.34127 .6255 L
.36687 .62873 L
.39247 .6298 L
.39247 .6298 L
.36175 .6298 L
.33103 .6298 L
.30031 .6298 L
.26959 .6298 L
.23886 .6298 L
.20814 .6298 L
.17742 .6298 L
.1467 .6298 L
.11598 .6298 L
.08525 .6298 L
Mistroke
.05453 .6298 L
.02381 .6298 L
Mfstroke
.02381 .01536 m
.02381 .01643 L
.02381 .01966 L
.02381 .02512 L
.02381 .03293 L
.02381 .0433 L
.02381 .05652 L
.02381 .07305 L
.02381 .09359 L
.02381 .11937 L
.02381 .15276 L
.02381 .1998 L
.02381 .32258 L
.02381 .32258 L
.02893 .32258 L
.03405 .32258 L
.03917 .32258 L
.04429 .32258 L
.04941 .32258 L
.05453 .32258 L
.05965 .32258 L
.06477 .32258 L
.06989 .32258 L
.07501 .32258 L
.08013 .32258 L
.08525 .32258 L
.08525 .32258 L
.11086 .1998 L
.13646 .15276 L
.16206 .11937 L
.18766 .09359 L
.21326 .07305 L
.23886 .05652 L
.26446 .0433 L
.29007 .03293 L
.31567 .02512 L
.34127 .01966 L
.36687 .01643 L
.39247 .01536 L
.39247 .01536 L
.36175 .01536 L
.33103 .01536 L
.30031 .01536 L
.26959 .01536 L
.23886 .01536 L
.20814 .01536 L
.17742 .01536 L
.1467 .01536 L
.11598 .01536 L
.08525 .01536 L
Mistroke
.05453 .01536 L
.02381 .01536 L
Mfstroke
.39247 .6298 m
.36175 .6298 L
.33103 .6298 L
.30031 .6298 L
.26959 .6298 L
.23886 .6298 L
.20814 .6298 L
.17742 .6298 L
.1467 .6298 L
.11598 .6298 L
.08525 .6298 L
.05453 .6298 L
.02381 .6298 L
.02381 .6298 L
.02381 .62873 L
.02381 .6255 L
.02381 .62004 L
.02381 .61223 L
.02381 .60186 L
.02381 .58864 L
.02381 .57211 L
.02381 .55157 L
.02381 .52579 L
.02381 .4924 L
.02381 .44536 L
.02381 .32258 L
.02381 .32258 L
.02893 .32258 L
.03405 .32258 L
.03917 .32258 L
.04429 .32258 L
.04941 .32258 L
.05453 .32258 L
.05965 .32258 L
.06477 .32258 L
.06989 .32258 L
.07501 .32258 L
.08013 .32258 L
.08525 .32258 L
.08525 .32258 L
.11086 .44536 L
.13646 .4924 L
.16206 .52579 L
.18766 .55157 L
.21326 .57211 L
.23886 .58864 L
.26446 .60186 L
.29007 .61223 L
.31567 .62004 L
.34127 .6255 L
Mistroke
.36687 .62873 L
.39247 .6298 L
Mfstroke
0 0 m
1 0 L
1 .64516 L
0 .64516 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{146, 94.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 145}, {93.125, 0}} -> {-0.424562, -5.25006, \
0.112753, 0.112753}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[PorroPrism[30, 10, Baffled->True]];", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9794 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00226099 1.08226 -5.55112e-17 1.08226 [
[ 0 0 0 0 ]
[ 1 .9794 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9794 L
0 .9794 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.53118 .73383 m
.53692 .75283 L
s
.52544 .71784 m
.53118 .73383 L
s
.52823 .72531 m
.5368 .75236 L
s
.51775 .69962 m
.52823 .72531 L
s
.5368 .75236 m
.54317 .77985 L
s
.53692 .75283 m
.54267 .77727 L
s
.51968 .7039 m
.52544 .71784 L
s
.5139 .69151 m
.51968 .7039 L
s
.54267 .77727 m
.54849 .83238 L
s
.50573 .67618 m
.51775 .69962 L
s
.54317 .77985 m
.54712 .80683 L
s
.55095 .76081 m
.55011 .77511 L
s
.55179 .74846 m
.55095 .76081 L
s
.55264 .73737 m
.55179 .74846 L
s
.55348 .72722 m
.55264 .73737 L
s
.5081 .68039 m
.5139 .69151 L
s
.55011 .77511 m
.54928 .79305 L
s
.55434 .71779 m
.55348 .72722 L
s
.55519 .70896 m
.55434 .71779 L
s
.54928 .79305 m
.54849 .83238 L
s
.50228 .67036 m
.5081 .68039 L
s
.55519 .70896 m
.55605 .70062 L
s
.56757 .73297 m
.56885 .74344 L
s
.56628 .72343 m
.56757 .73297 L
s
.56885 .74344 m
.57015 .7552 L
s
.49256 .65581 m
.50573 .67618 L
s
.56501 .71462 m
.56628 .72343 L
s
.57015 .7552 m
.57145 .76891 L
s
.54712 .80683 m
.54849 .83238 L
s
.56501 .71462 m
.56373 .70641 L
s
.55691 .69271 m
.55605 .70062 L
s
.57145 .76891 m
.57279 .78627 L
s
.56373 .70641 m
.56246 .6987 L
s
.49643 .66129 m
.50228 .67036 L
s
.56118 .69142 m
.56246 .6987 L
s
.55777 .68518 m
.55691 .69271 L
s
.57895 .76673 m
.58384 .73904 L
s
.57427 .82507 m
.57895 .76673 L
s
.58384 .73904 m
.58878 .71676 L
s
.58395 .7385 m
.59134 .70652 L
s
.57853 .76958 m
.58395 .7385 L
s
.57527 .79876 m
.57853 .76958 L
s
.55991 .68453 m
.56118 .69142 L
s
.57279 .78627 m
.57427 .82507 L
s
.55864 .67798 m
.55777 .68518 L
s
.55864 .67798 m
.55991 .68453 L
s
.58878 .71676 m
.59377 .69744 L
s
.49055 .65312 m
.49643 .66129 L
s
.55864 .67798 m
.552 .67337 L
s
.55864 .67798 m
.56487 .66947 L
s
.59134 .70652 m
.60049 .6747 L
s
.552 .67337 m
.54537 .66906 L
s
.57427 .82507 m
.57527 .79876 L
s
.54537 .66906 m
.53873 .66503 L
s
.53873 .66503 m
.53209 .66125 L
s
.54849 .83238 m
.55064 .83178 L
s
.54849 .83238 m
.54849 .83238 L
s
.54849 .83238 m
.54943 .86448 L
s
.54849 .83238 m
.54849 .83238 L
s
.54275 .87724 m
.54849 .83238 L
s
.54849 .83238 m
.5472 .85558 L
s
.54943 .86448 m
.54849 .83238 L
s
.59377 .69744 m
.5988 .68011 L
s
.53209 .66125 m
.52545 .65772 L
s
.55064 .83178 m
.55278 .83117 L
s
.48463 .64579 m
.49055 .65312 L
s
.55278 .83117 m
.55492 .83056 L
s
.52545 .65772 m
.51879 .65443 L
s
.55492 .83056 m
.55707 .82995 L
s
.57113 .66123 m
.56487 .66947 L
s
.55707 .82995 m
.55922 .82934 L
s
.51879 .65443 m
.51213 .65137 L
s
.55922 .82934 m
.56136 .82873 L
s
.56136 .82873 m
.56351 .82813 L
s
.50546 .64853 m
.51213 .65137 L
s
.56351 .82813 m
.56566 .82752 L
s
.56566 .82752 m
.56781 .82691 L
s
.5988 .68011 m
.60387 .66431 L
s
.50546 .64853 m
.49878 .6459 L
s
.56781 .82691 m
.56997 .8263 L
s
.56997 .8263 m
.57212 .82568 L
s
.57742 .65324 m
.57113 .66123 L
s
.49878 .6459 m
.49209 .64348 L
s
.57212 .82568 m
.57427 .82507 L
s
.60049 .6747 m
.61109 .64408 L
s
.57427 .82507 m
.57975 .86695 L
s
.57427 .82507 m
.57427 .82507 L
s
.57327 .85781 m
.57427 .82507 L
s
.57562 .84761 m
.57427 .82507 L
s
.49209 .64348 m
.48539 .64128 L
s
.58373 .64548 m
.57742 .65324 L
s
.60387 .66431 m
.60899 .64972 L
s
.52247 .41745 m .63531 .59068 L .47868 .63928 L .662 .743 .91 r
F
.52247 .41745 m .47868 .63928 L .15354 .30653 L F
0 g
.47868 .63928 m
.49256 .65581 L
s
.47868 .63928 m
.48463 .64579 L
s
.47868 .63928 m
.48539 .64128 L
s
.47868 .63928 m
.47868 .63928 L
s
.47868 .63928 m
.4915 .6353 L
s
.5472 .85558 m
.54325 .87556 L
s
.4915 .6353 m
.50436 .63131 L
s
.58373 .64548 m
.59007 .63794 L
s
.60899 .64972 m
.61415 .63618 L
s
.50436 .63131 m
.51727 .6273 L
s
.61109 .64408 m
.62283 .61573 L
s
.59007 .63794 m
.59644 .63061 L
s
.54943 .86448 m
.55034 .87513 L
s
.57929 .86553 m
.57562 .84761 L
s
.51727 .6273 m
.53021 .62329 L
s
.61415 .63618 m
.61937 .62358 L
s
.59644 .63061 m
.60283 .62348 L
s
.53021 .62329 m
.5432 .61926 L
s
.57327 .85781 m
.5721 .86908 L
s
.54325 .87556 m
.53674 .89154 L
s
.53687 .8913 m
.54275 .87724 L
s
.60283 .62348 m
.60926 .61655 L
s
.5432 .61926 m
.55623 .61522 L
s
.55034 .87513 m
.55124 .8821 L
s
.61937 .62358 m
.62463 .61182 L
s
.55623 .61522 m
.5693 .61116 L
s
.60926 .61655 m
.61572 .60981 L
s
.57091 .87665 m
.5721 .86908 L
s
.58521 .87813 m
.57929 .86553 L
s
.5693 .61116 m
.58242 .60709 L
s
.57975 .86695 m
.58509 .87796 L
s
.62463 .61182 m
.62994 .60086 L
s
.55215 .88708 m
.55124 .8821 L
s
.61572 .60981 m
.62222 .60325 L
s
.58242 .60709 m
.59558 .60301 L
s
.53093 .89977 m
.53687 .8913 L
s
.53674 .89154 m
.52785 .90283 L
s
.59558 .60301 m
.60878 .59891 L
s
.56969 .88223 m
.57091 .87665 L
s
.62222 .60325 m
.62875 .59687 L
s
.55215 .88708 m
.55306 .89073 L
s
.60878 .59891 m
.62202 .5948 L
s
.56969 .88223 m
.56845 .88648 L
s
.55306 .89073 m
.55397 .89342 L
s
.52493 .9051 m
.53093 .89977 L
s
.52247 .41745 m .77033 .3457 L .63531 .59068 L .662 .743 .91 r
F
0 g
.63531 .59068 m
.63531 .59068 L
s
.62202 .5948 m
.63531 .59068 L
s
.62875 .59687 m
.63531 .59068 L
s
.62994 .60086 m
.63531 .59068 L
s
.62283 .61573 m
.63531 .59068 L
s
.47868 .63928 m
.63531 .59068 L
s
.58509 .87796 m
.59046 .88335 L
s
.59323 .88482 m
.58521 .87813 L
s
.56845 .88648 m
.5672 .88977 L
s
.52785 .90283 m
.51686 .9089 L
s
.55489 .89533 m
.55397 .89342 L
s
.56594 .89228 m
.5672 .88977 L
s
.51888 .90825 m
.52493 .9051 L
s
.55489 .89533 m
.55581 .8966 L
s
.56594 .89228 m
.56467 .89416 L
s
.59046 .88335 m
.59586 .88557 L
s
.55673 .89733 m
.55581 .8966 L
s
.5128 .9097 m
.51888 .90825 L
s
.5634 .8955 m
.56467 .89416 L
s
.51686 .9089 m
.50416 .9094 L
s
.60312 .88517 m
.59323 .88482 L
s
.55765 .89758 m
.55673 .89733 L
s
.56211 .89636 m
.5634 .8955 L
s
.50667 .90974 m
.5128 .9097 L
s
.59586 .88557 m
.6013 .88557 L
s
.55765 .89758 m
.55858 .89741 L
s
.56211 .89636 m
.56081 .89679 L
s
.55858 .89741 m
.55951 .89685 L
s
.5005 .90856 m
.50667 .90974 L
s
.55951 .89685 m
.56081 .89679 L
s
.50416 .9094 m
.49021 .90417 L
s
.5526 .89809 m
.55951 .89685 L
s
.55951 .89685 m
.56606 .89438 L
s
.6013 .88557 m
.60678 .88384 L
s
.49431 .90626 m
.5005 .90856 L
s
.54568 .899 m
.5526 .89809 L
s
.61456 .87899 m
.60312 .88517 L
s
.54568 .899 m
.53873 .89962 L
s
.56606 .89438 m
.57264 .89158 L
s
.53176 .89994 m
.53873 .89962 L
s
.48808 .90292 m
.49431 .90626 L
s
.52478 .89999 m
.53176 .89994 L
s
.60678 .88384 m
.6123 .88066 L
s
.57264 .89158 m
.57927 .88845 L
s
.52478 .89999 m
.51779 .89977 L
s
.51078 .8993 m
.51779 .89977 L
s
.48183 .8986 m
.48808 .90292 L
s
.50376 .89858 m
.51078 .8993 L
s
.57927 .88845 m
.58592 .88501 L
s
.50376 .89858 m
.49672 .89762 L
s
.48967 .89642 m
.49672 .89762 L
s
.48967 .89642 m
.48262 .89498 L
s
.52154 .68294 m .64042 .84739 L .47555 .89331 L .648 .761 .931 r
F
0 g
.61456 .87899 m
.62715 .86629 L
s
.58592 .88501 m
.59262 .88127 L
s
.6123 .88066 m
.61785 .8762 L
s
.31824 .47508 m .33443 .49165 L .32313 .75353 L .952 .687 .497 r
F
.31824 .47508 m .32313 .75353 L .30596 .73779 L F
.52154 .68294 m .47555 .89331 L .13065 .57702 L .648 .761 .931 r
F
0 g
.47555 .89331 m
.49021 .90417 L
s
.47555 .89331 m
.48183 .8986 L
s
.47555 .89331 m
.48262 .89498 L
s
.47555 .89331 m
.47555 .89331 L
s
.47555 .89331 m
.48904 .88956 L
s
.33443 .49165 m
.47868 .63928 L
s
.32313 .75353 m
.47555 .89331 L
s
.59262 .88127 m
.59935 .87725 L
s
.48904 .88956 m
.50256 .88579 L
s
.61785 .8762 m
.62345 .87059 L
s
.50256 .88579 m
.51614 .88201 L
s
.59935 .87725 m
.60611 .87294 L
s
.51614 .88201 m
.52976 .87821 L
s
.52976 .87821 m
.54343 .87441 L
s
.60611 .87294 m
.61291 .86837 L
s
.32843 .63061 m
.33443 .49165 L
s
.31824 .47508 m
.33443 .49165 L
s
.62345 .87059 m
.62907 .86389 L
s
.54343 .87441 m
.55714 .87059 L
s
.61291 .86837 m
.61974 .86352 L
s
.55714 .87059 m
.57091 .86676 L
s
.57091 .86676 m
.58471 .86291 L
s
.62907 .86389 m
.63473 .85615 L
s
.61974 .86352 m
.6266 .85841 L
s
.31119 .62594 m
.31824 .47508 L
s
.58471 .86291 m
.59857 .85905 L
s
.6266 .85841 m
.6335 .85303 L
s
.59857 .85905 m
.61247 .85518 L
s
.61247 .85518 m
.62642 .85129 L
s
.52154 .68294 m .78387 .61447 L .64042 .84739 L .648 .761 .931 r
F
0 g
.64042 .84739 m
.64042 .84739 L
s
.62642 .85129 m
.64042 .84739 L
s
.6335 .85303 m
.64042 .84739 L
s
.63473 .85615 m
.64042 .84739 L
s
.62715 .86629 m
.64042 .84739 L
s
.47555 .89331 m
.64042 .84739 L
s
.52247 .41745 m .75614 .32722 L .77033 .3457 L .662 .743 .91 r
F
.52247 .41745 m .32444 .24381 L .75614 .32722 L F
.52247 .41745 m .15354 .30653 L .32444 .24381 L F
0 g
.15354 .30653 m
.47868 .63928 L
s
.15354 .30653 m
.31824 .47508 L
s
.30596 .73779 m
.32313 .75353 L
s
.75614 .32722 m .77033 .3457 L .78387 .61447 L .976 .681 .39 r
F
0 g
.63531 .59068 m
.75977 .36485 L
s
.75614 .32722 m .78387 .61447 L .76894 .59681 L .976 .681 .39 r
F
0 g
.32444 .24381 m
.75614 .32722 L
s
.75614 .32722 m
.77033 .3457 L
s
.15354 .30653 m
.15375 .30121 L
s
.15354 .30653 m
.15354 .30653 L
s
.15354 .30653 m
.1675 .30141 L
s
.14579 .29909 m
.15354 .30653 L
s
.15354 .30653 m
.32444 .24381 L
s
.13521 .29046 m
.15354 .30653 L
s
.1675 .30141 m
.1815 .29627 L
s
.15375 .30121 m
.15394 .29609 L
s
.14579 .29909 m
.13792 .2925 L
s
.1815 .29627 m
.19556 .29111 L
s
.15394 .29609 m
.15412 .29117 L
s
.19556 .29111 m
.20967 .28593 L
s
.13792 .2925 m
.12992 .28681 L
s
.15412 .29117 m
.15428 .28646 L
s
.11687 .27973 m
.13521 .29046 L
s
.20967 .28593 m
.22383 .28074 L
s
.15428 .28646 m
.15441 .28196 L
s
.22383 .28074 m
.23805 .27552 L
s
.12992 .28681 m
.12177 .28206 L
s
.15441 .28196 m
.15453 .27768 L
s
.23805 .27552 m
.25231 .27028 L
s
.15453 .27768 m
.15463 .27363 L
s
.25231 .27028 m
.26663 .26503 L
s
.12177 .28206 m
.11347 .27835 L
s
.26663 .26503 m
.28101 .25976 L
s
.15463 .27363 m
.15471 .26982 L
s
.52154 .68294 m .76894 .59681 L .78387 .61447 L .648 .761 .931 r
F
0 g
.77033 .3457 m
.78387 .61447 L
s
.52154 .68294 m .31141 .5169 L .76894 .59681 L .648 .761 .931 r
F
0 g
.75614 .32722 m
.76894 .59681 L
s
.64042 .84739 m
.78387 .61447 L
s
.52154 .68294 m .13065 .57702 L .31141 .5169 L .648 .761 .931 r
F
0 g
.13065 .57702 m
.47555 .89331 L
s
.13065 .57702 m
.30596 .73779 L
s
.09921 .27487 m
.11687 .27973 L
s
.28101 .25976 m
.29543 .25446 L
s
.11347 .27835 m
.10498 .27581 L
s
.15471 .26982 m
.15476 .26625 L
s
.29543 .25446 m
.30991 .24915 L
s
.15476 .26625 m
.15479 .26295 L
s
.30991 .24915 m
.32444 .24381 L
s
.10498 .27581 m
.09629 .27465 L
s
.32444 .24381 m
.32444 .24381 L
s
.31044 .2436 m
.32444 .24381 L
s
.30489 .24049 m
.32444 .24381 L
s
.27851 .23744 m
.32444 .24381 L
s
.15479 .26295 m
.15479 .25994 L
s
.29642 .24361 m
.31044 .2436 L
s
.28238 .24385 m
.29642 .24361 L
s
.26832 .24431 m
.28238 .24385 L
s
.25424 .24501 m
.26832 .24431 L
s
.24013 .24595 m
.25424 .24501 L
s
.28524 .23806 m
.30489 .24049 L
s
.0829 .27622 m
.09921 .27487 L
s
.226 .24714 m
.24013 .24595 L
s
.21183 .24858 m
.226 .24714 L
s
.19763 .2503 m
.21183 .24858 L
s
.15479 .25994 m
.15477 .25722 L
s
.26546 .23656 m
.28524 .23806 L
s
.09629 .27465 m
.08735 .27519 L
s
.18339 .2523 m
.19763 .2503 L
s
.23368 .23625 m
.27851 .23744 L
s
.1691 .2546 m
.18339 .2523 L
s
.15477 .25722 m
.1691 .2546 L
s
.24555 .23605 m
.26546 .23656 L
s
.15477 .25722 m
.14874 .25708 L
s
.15477 .25722 m
.14635 .25797 L
s
.14635 .25797 m
.13787 .25911 L
s
.22547 .23662 m
.24555 .23605 L
s
.14874 .25708 m
.14265 .25732 L
s
.08735 .27519 m
.0781 .27798 L
s
.19159 .24034 m
.23368 .23625 L
s
.13787 .25911 m
.12933 .26067 L
s
.14265 .25732 m
.1365 .25798 L
s
.20522 .23839 m
.22547 .23662 L
s
.12933 .26067 m
.1207 .26271 L
s
.06863 .28388 m
.0829 .27622 L
s
.1365 .25798 m
.13028 .25912 L
s
.18475 .24158 m
.20522 .23839 L
s
.1207 .26271 m
.11199 .26532 L
s
.0781 .27798 m
.0684 .28406 L
s
.13028 .25912 m
.12399 .26083 L
s
.15384 .24966 m
.19159 .24034 L
s
.11199 .26532 m
.10319 .26858 L
s
.16402 .2465 m
.18475 .24158 L
s
.12399 .26083 m
.1176 .26319 L
s
.10319 .26858 m
.09426 .27266 L
s
.14295 .2537 m
.16402 .2465 L
s
.1176 .26319 m
.1111 .26636 L
s
.09426 .27266 m
.08519 .27778 L
s
.057 .29772 m
.06863 .28388 L
s
.0684 .28406 m
.05796 .29616 L
s
.12191 .26395 m
.15384 .24966 L
s
.76894 .59681 m
.78387 .61447 L
s
.1111 .26636 m
.10447 .27057 L
s
.08519 .27778 m
.07593 .28432 L
s
.12142 .26423 m
.14295 .2537 L
s
.10447 .27057 m
.09766 .2762 L
s
.07593 .28432 m
.0664 .29302 L
s
.09712 .28276 m
.12191 .26395 L
s
.09911 .28082 m
.12142 .26423 L
s
.05796 .29616 m
.04375 .342 L
s
.09766 .2762 m
.0906 .28399 L
s
.04856 .31732 m
.057 .29772 L
s
.31141 .5169 m
.76894 .59681 L
s
.0664 .29302 m
.05638 .30575 L
s
.0906 .28399 m
.08309 .29581 L
s
.05638 .30575 m
.04375 .342 L
s
.04375 .342 m
.05638 .30575 L
s
.07313 .3312 m
.09911 .28082 L
s
.08059 .30545 m
.09712 .28276 L
s
.04375 .342 m
.04856 .31732 L
s
.12246 .56896 m
.13065 .57702 L
s
.13065 .57702 m
.13065 .57702 L
s
.13065 .57702 m
.13085 .57169 L
s
.13065 .57702 m
.1454 .57211 L
s
.13065 .57702 m
.31141 .5169 L
s
.11155 .55651 m
.13065 .57702 L
s
.08309 .29581 m
.07313 .3312 L
s
.1454 .57211 m
.1602 .56719 L
s
.13085 .57169 m
.13107 .56609 L
s
.12246 .56896 m
.11431 .55986 L
s
.07313 .3312 m
.08059 .30545 L
s
.1602 .56719 m
.17505 .56225 L
s
.13107 .56609 m
.13131 .56022 L
s
.11431 .55986 m
.10622 .54966 L
s
.17505 .56225 m
.18997 .55729 L
s
.13131 .56022 m
.13158 .55407 L
s
.04375 .342 m
.04375 .342 L
s
.04375 .342 m
.04618 .3411 L
s
.04375 .342 m
.04375 .342 L
s
.04808 .38405 m
.04375 .342 L
s
.04638 .40564 m
.04375 .342 L
s
.04282 .37081 m
.04375 .342 L
s
.04618 .3411 m
.04863 .34021 L
s
.11155 .55651 m
.09345 .53101 L
s
.04863 .34021 m
.05107 .33931 L
s
.05107 .33931 m
.05351 .33841 L
s
.05351 .33841 m
.05596 .33751 L
s
.05596 .33751 m
.05841 .33661 L
s
.18997 .55729 m
.20494 .55231 L
s
.13158 .55407 m
.13187 .54763 L
s
.05841 .33661 m
.06086 .33571 L
s
.10622 .54966 m
.09818 .53831 L
s
.06086 .33571 m
.06331 .33481 L
s
.06331 .33481 m
.06576 .33391 L
s
.06576 .33391 m
.06821 .33301 L
s
.06821 .33301 m
.07067 .3321 L
s
.07067 .3321 m
.07313 .3312 L
s
.13187 .54763 m
.13218 .54091 L
s
.20494 .55231 m
.21997 .54731 L
s
.07313 .3312 m
.08846 .39053 L
s
.07313 .3312 m
.07313 .3312 L
s
.07523 .37423 m
.07313 .3312 L
s
.0752 .35902 m
.07313 .3312 L
s
.09818 .53831 m
.09022 .52572 L
s
.04588 .40256 m
.04282 .37081 L
s
.13218 .54091 m
.13251 .53388 L
s
.09345 .53101 m
.07717 .50156 L
s
.21997 .54731 m
.23506 .54229 L
s
.09022 .52572 m
.08235 .51174 L
s
.13251 .53388 m
.13287 .52655 L
s
.055 .40254 m
.04808 .38405 L
s
.23506 .54229 m
.25021 .53725 L
s
.08235 .51174 m
.07461 .49618 L
s
.05285 .4359 m
.04588 .40256 L
s
.13287 .52655 m
.13326 .51889 L
s
.07717 .50156 m
.06343 .46939 L
s
.0527 .43533 m
.04638 .40564 L
s
.07461 .49618 m
.06703 .47871 L
s
.08688 .38782 m
.0752 .35902 L
s
.25021 .53725 m
.26542 .53219 L
s
.06238 .41696 m
.055 .40254 L
s
.06703 .47871 m
.05969 .45878 L
s
.13326 .51889 m
.13368 .51089 L
s
.05969 .45878 m
.0527 .43533 L
s
.06343 .46939 m
.05285 .4359 L
s
.07976 .39366 m
.07523 .37423 L
s
.26542 .53219 m
.28069 .52711 L
s
.07001 .42918 m
.06238 .41696 L
s
.13412 .50254 m
.13368 .51089 L
s
.07781 .43995 m
.07001 .42918 L
s
.08471 .40899 m
.07976 .39366 L
s
.13412 .50254 m
.1346 .49381 L
s
.28069 .52711 m
.29602 .52202 L
s
.08572 .44963 m
.07781 .43995 L
s
.10782 .4164 m
.08688 .38782 L
s
.09372 .45847 m
.08572 .44963 L
s
.08846 .39053 m
.10738 .41592 L
s
.0899 .42213 m
.08471 .40899 L
s
.1018 .4666 m
.09372 .45847 L
s
.14916 .49739 m
.1346 .49381 L
s
.1346 .49381 m
.12885 .48682 L
s
.1346 .49381 m
.12634 .48768 L
s
.10993 .47413 m
.1018 .4666 L
s
.12634 .48768 m
.11812 .48114 L
s
.11812 .48114 m
.10993 .47413 L
s
.12885 .48682 m
.12312 .47941 L
s
.16377 .50063 m
.14916 .49739 L
s
.29602 .52202 m
.31141 .5169 L
s
.09523 .43379 m
.0899 .42213 L
s
.12312 .47941 m
.11743 .47153 L
s
.17841 .50353 m
.16377 .50063 L
s
.10068 .44438 m
.09523 .43379 L
s
.11743 .47153 m
.11179 .46312 L
s
.1062 .4541 m
.10068 .44438 L
s
.11179 .46312 m
.1062 .4541 L
s
.1931 .50612 m
.17841 .50353 L
s
.20781 .50842 m
.1931 .50612 L
s
.22255 .51043 m
.20781 .50842 L
s
.23731 .51216 m
.22255 .51043 L
s
.23731 .51216 m
.2521 .51362 L
s
.29656 .51646 m
.31141 .5169 L
s
.31141 .5169 m
.31141 .5169 L
s
.2907 .51277 m
.31141 .5169 L
s
.26294 .50562 m
.31141 .5169 L
s
.26691 .51483 m
.2521 .51362 L
s
.29656 .51646 m
.28173 .51577 L
s
.28173 .51577 m
.26691 .51483 L
s
.10738 .41592 m
.12699 .43513 L
s
.13724 .44358 m
.10782 .4164 L
s
.27 .50762 m
.2907 .51277 L
s
.12699 .43513 m
.14697 .45086 L
s
.24931 .5014 m
.27 .50762 L
s
.26294 .50562 m
.21647 .48915 L
s
.17397 .46818 m
.13724 .44358 L
s
.22867 .49406 m
.24931 .5014 L
s
.14697 .45086 m
.16719 .46417 L
s
.20808 .48551 m
.22867 .49406 L
s
.16719 .46417 m
.18757 .47562 L
s
.21647 .48915 m
.17397 .46818 L
s
.18757 .47562 m
.20808 .48551 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{148.875, 145.688},
  ImageMargins->{{42, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 147.875}, {144.688, 0}} -> {0.00163341, \
-4.52484*^-6, 0.00625463, 0.00625463}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[PorroPrism[30, 10, Mirrored->True, \
Baffled->True]];\
\>", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9794 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00226099 1.08226 -5.55112e-17 1.08226 [
[ 0 0 0 0 ]
[ 1 .9794 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9794 L
0 .9794 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.53118 .73383 m
.53692 .75283 L
s
.52544 .71784 m
.53118 .73383 L
s
.52823 .72531 m
.5368 .75236 L
s
.51775 .69962 m
.52823 .72531 L
s
.5368 .75236 m
.54317 .77985 L
s
.53692 .75283 m
.54267 .77727 L
s
.51968 .7039 m
.52544 .71784 L
s
.5139 .69151 m
.51968 .7039 L
s
.54267 .77727 m
.54849 .83238 L
s
.50573 .67618 m
.51775 .69962 L
s
.54317 .77985 m
.54712 .80683 L
s
.55095 .76081 m
.55011 .77511 L
s
.55179 .74846 m
.55095 .76081 L
s
.55264 .73737 m
.55179 .74846 L
s
.55348 .72722 m
.55264 .73737 L
s
.5081 .68039 m
.5139 .69151 L
s
.55011 .77511 m
.54928 .79305 L
s
.55434 .71779 m
.55348 .72722 L
s
.55519 .70896 m
.55434 .71779 L
s
.54928 .79305 m
.54849 .83238 L
s
.50228 .67036 m
.5081 .68039 L
s
.55519 .70896 m
.55605 .70062 L
s
.56757 .73297 m
.56885 .74344 L
s
.56628 .72343 m
.56757 .73297 L
s
.56885 .74344 m
.57015 .7552 L
s
.49256 .65581 m
.50573 .67618 L
s
.56501 .71462 m
.56628 .72343 L
s
.57015 .7552 m
.57145 .76891 L
s
.54712 .80683 m
.54849 .83238 L
s
.56501 .71462 m
.56373 .70641 L
s
.55691 .69271 m
.55605 .70062 L
s
.57145 .76891 m
.57279 .78627 L
s
.56373 .70641 m
.56246 .6987 L
s
.49643 .66129 m
.50228 .67036 L
s
.56118 .69142 m
.56246 .6987 L
s
.55777 .68518 m
.55691 .69271 L
s
.57895 .76673 m
.58384 .73904 L
s
.6761 .64979 m .58395 .7385 L .59134 .70652 L .002 0 .41 r
F
.6761 .64979 m .57853 .76958 L .58395 .7385 L F
.6761 .64979 m .57527 .79876 L .57853 .76958 L F
0 g
.57853 .76958 m
.58395 .7385 L
s
.58384 .73904 m
.58878 .71676 L
s
.55991 .68453 m
.56118 .69142 L
s
.55864 .67798 m
.55777 .68518 L
s
.55864 .67798 m
.55991 .68453 L
s
.49055 .65312 m
.49643 .66129 L
s
.55864 .67798 m
.552 .67337 L
s
.55864 .67798 m
.56487 .66947 L
s
.6761 .64979 m .59134 .70652 L .60049 .6747 L .002 0 .41 r
F
0 g
.58395 .7385 m
.59134 .70652 L
s
.552 .67337 m
.54537 .66906 L
s
.6761 .64979 m .57427 .82507 L .57527 .79876 L .002 0 .41 r
F
0 g
.58878 .71676 m
.59377 .69744 L
s
.57527 .79876 m
.57853 .76958 L
s
.54537 .66906 m
.53873 .66503 L
s
.53873 .66503 m
.53209 .66125 L
s
.54849 .83238 m
.55064 .83178 L
s
.54849 .83238 m
.54849 .83238 L
s
.54849 .83238 m
.54943 .86448 L
s
.54849 .83238 m
.54849 .83238 L
s
.54275 .87724 m
.54849 .83238 L
s
.54849 .83238 m
.5472 .85558 L
s
.54943 .86448 m
.54849 .83238 L
s
.59377 .69744 m
.5988 .68011 L
s
.53209 .66125 m
.52545 .65772 L
s
.55064 .83178 m
.55278 .83117 L
s
.48463 .64579 m
.49055 .65312 L
s
.55278 .83117 m
.55492 .83056 L
s
.52545 .65772 m
.51879 .65443 L
s
.55492 .83056 m
.55707 .82995 L
s
.57113 .66123 m
.56487 .66947 L
s
.55707 .82995 m
.55922 .82934 L
s
.51879 .65443 m
.51213 .65137 L
s
.55922 .82934 m
.56136 .82873 L
s
.56136 .82873 m
.56351 .82813 L
s
.50546 .64853 m
.51213 .65137 L
s
.56351 .82813 m
.56566 .82752 L
s
.56566 .82752 m
.56781 .82691 L
s
.50546 .64853 m
.49878 .6459 L
s
.56781 .82691 m
.56997 .8263 L
s
.56997 .8263 m
.57212 .82568 L
s
.49878 .6459 m
.49209 .64348 L
s
.6761 .64979 m .60049 .6747 L .61109 .64408 L .002 0 .41 r
F
0 g
.59134 .70652 m
.60049 .6747 L
s
.6761 .64979 m .57562 .84761 L .57427 .82507 L .002 0 .41 r
F
0 g
.57327 .85781 m
.57427 .82507 L
s
.57427 .82507 m
.57427 .82507 L
s
.5988 .68011 m
.60387 .66431 L
s
.57212 .82568 m
.57427 .82507 L
s
.57113 .66123 m
.57742 .65324 L
s
.57427 .82507 m
.57895 .76673 L
s
.57279 .78627 m
.57427 .82507 L
s
.57427 .82507 m
.57527 .79876 L
s
.49209 .64348 m
.48539 .64128 L
s
.57742 .65324 m
.58373 .64548 L
s
.60387 .66431 m
.60899 .64972 L
s
.52247 .41745 m .63531 .59068 L .47868 .63928 L .662 .743 .91 r
F
.52247 .41745 m .47868 .63928 L .15354 .30653 L F
0 g
.47868 .63928 m
.49256 .65581 L
s
.47868 .63928 m
.48463 .64579 L
s
.47868 .63928 m
.48539 .64128 L
s
.47868 .63928 m
.47868 .63928 L
s
.47868 .63928 m
.4915 .6353 L
s
.5472 .85558 m
.54325 .87556 L
s
.4915 .6353 m
.50436 .63131 L
s
.58373 .64548 m
.59007 .63794 L
s
.50436 .63131 m
.51727 .6273 L
s
.6761 .64979 m .61109 .64408 L .62283 .61573 L .002 0 .41 r
F
0 g
.60899 .64972 m
.61415 .63618 L
s
.60049 .6747 m
.61109 .64408 L
s
.59007 .63794 m
.59644 .63061 L
s
.54943 .86448 m
.55034 .87513 L
s
.6761 .64979 m .57929 .86553 L .57562 .84761 L .002 0 .41 r
F
0 g
.57427 .82507 m
.57562 .84761 L
s
.51727 .6273 m
.53021 .62329 L
s
.61415 .63618 m
.61937 .62358 L
s
.59644 .63061 m
.60283 .62348 L
s
.53021 .62329 m
.5432 .61926 L
s
.57327 .85781 m
.5721 .86908 L
s
.54325 .87556 m
.53674 .89154 L
s
.53687 .8913 m
.54275 .87724 L
s
.60283 .62348 m
.60926 .61655 L
s
.5432 .61926 m
.55623 .61522 L
s
.55034 .87513 m
.55124 .8821 L
s
.55623 .61522 m
.5693 .61116 L
s
.60926 .61655 m
.61572 .60981 L
s
.6761 .64979 m .62283 .61573 L .63531 .59068 L .002 0 .41 r
F
0 g
.61937 .62358 m
.62463 .61182 L
s
.61109 .64408 m
.62283 .61573 L
s
.57091 .87665 m
.5721 .86908 L
s
.6761 .64979 m .58521 .87813 L .57929 .86553 L .002 0 .41 r
F
0 g
.57427 .82507 m
.57975 .86695 L
s
.57562 .84761 m
.57929 .86553 L
s
.5693 .61116 m
.58242 .60709 L
s
.57975 .86695 m
.58509 .87796 L
s
.62463 .61182 m
.62994 .60086 L
s
.55215 .88708 m
.55124 .8821 L
s
.61572 .60981 m
.62222 .60325 L
s
.58242 .60709 m
.59558 .60301 L
s
.53093 .89977 m
.53687 .8913 L
s
.53674 .89154 m
.52785 .90283 L
s
.59558 .60301 m
.60878 .59891 L
s
.56969 .88223 m
.57091 .87665 L
s
.62222 .60325 m
.62875 .59687 L
s
.55215 .88708 m
.55306 .89073 L
s
.60878 .59891 m
.62202 .5948 L
s
.56969 .88223 m
.56845 .88648 L
s
.55306 .89073 m
.55397 .89342 L
s
.52493 .9051 m
.53093 .89977 L
s
.52247 .41745 m .77033 .3457 L .63531 .59068 L .662 .743 .91 r
F
.6761 .64979 m .63531 .59068 L .77033 .3457 L .002 0 .41 r
F
0 g
.62283 .61573 m
.63531 .59068 L
s
.47868 .63928 m
.63531 .59068 L
s
.62994 .60086 m
.63531 .59068 L
s
.62875 .59687 m
.63531 .59068 L
s
.62202 .5948 m
.63531 .59068 L
s
.63531 .59068 m
.63531 .59068 L
s
.6761 .64979 m .59323 .88482 L .58521 .87813 L .002 0 .41 r
F
0 g
.58509 .87796 m
.59046 .88335 L
s
.57929 .86553 m
.58521 .87813 L
s
.56845 .88648 m
.5672 .88977 L
s
.52785 .90283 m
.51686 .9089 L
s
.55489 .89533 m
.55397 .89342 L
s
.56594 .89228 m
.5672 .88977 L
s
.51888 .90825 m
.52493 .9051 L
s
.55489 .89533 m
.55581 .8966 L
s
.56594 .89228 m
.56467 .89416 L
s
.55673 .89733 m
.55581 .8966 L
s
.5128 .9097 m
.51888 .90825 L
s
.5634 .8955 m
.56467 .89416 L
s
.51686 .9089 m
.50416 .9094 L
s
.6761 .64979 m .60312 .88517 L .59323 .88482 L .002 0 .41 r
F
0 g
.59046 .88335 m
.59586 .88557 L
s
.58521 .87813 m
.59323 .88482 L
s
.55765 .89758 m
.55673 .89733 L
s
.56211 .89636 m
.5634 .8955 L
s
.50667 .90974 m
.5128 .9097 L
s
.59586 .88557 m
.6013 .88557 L
s
.55765 .89758 m
.55858 .89741 L
s
.56211 .89636 m
.56081 .89679 L
s
.55858 .89741 m
.55951 .89685 L
s
.5005 .90856 m
.50667 .90974 L
s
.55951 .89685 m
.56081 .89679 L
s
.50416 .9094 m
.49021 .90417 L
s
.5526 .89809 m
.55951 .89685 L
s
.55951 .89685 m
.56606 .89438 L
s
.49431 .90626 m
.5005 .90856 L
s
.54568 .899 m
.5526 .89809 L
s
.6761 .64979 m .61456 .87899 L .60312 .88517 L .002 0 .41 r
F
0 g
.6013 .88557 m
.60678 .88384 L
s
.59323 .88482 m
.60312 .88517 L
s
.54568 .899 m
.53873 .89962 L
s
.56606 .89438 m
.57264 .89158 L
s
.53176 .89994 m
.53873 .89962 L
s
.48808 .90292 m
.49431 .90626 L
s
.52478 .89999 m
.53176 .89994 L
s
.60678 .88384 m
.6123 .88066 L
s
.57264 .89158 m
.57927 .88845 L
s
.52478 .89999 m
.51779 .89977 L
s
.51078 .8993 m
.51779 .89977 L
s
.48183 .8986 m
.48808 .90292 L
s
.50376 .89858 m
.51078 .8993 L
s
.57927 .88845 m
.58592 .88501 L
s
.50376 .89858 m
.49672 .89762 L
s
.48967 .89642 m
.49672 .89762 L
s
.48967 .89642 m
.48262 .89498 L
s
.6761 .64979 m .62715 .86629 L .61456 .87899 L .002 0 .41 r
F
0 g
.60312 .88517 m
.61456 .87899 L
s
.6761 .64979 m .64042 .84739 L .62715 .86629 L .002 0 .41 r
F
.52154 .68294 m .64042 .84739 L .47555 .89331 L .648 .761 .931 r
F
0 g
.6123 .88066 m
.61785 .8762 L
s
.61456 .87899 m
.62715 .86629 L
s
.58592 .88501 m
.59262 .88127 L
s
.31824 .47508 m .33443 .49165 L .32313 .75353 L .952 .687 .497 r
F
.31824 .47508 m .32313 .75353 L .30596 .73779 L F
.52154 .68294 m .47555 .89331 L .13065 .57702 L .648 .761 .931 r
F
0 g
.47555 .89331 m
.49021 .90417 L
s
.47555 .89331 m
.48183 .8986 L
s
.47555 .89331 m
.48262 .89498 L
s
.47555 .89331 m
.47555 .89331 L
s
.47555 .89331 m
.48904 .88956 L
s
.33443 .49165 m
.47868 .63928 L
s
.32313 .75353 m
.47555 .89331 L
s
.59262 .88127 m
.59935 .87725 L
s
.48904 .88956 m
.50256 .88579 L
s
.61785 .8762 m
.62345 .87059 L
s
.50256 .88579 m
.51614 .88201 L
s
.59935 .87725 m
.60611 .87294 L
s
.51614 .88201 m
.52976 .87821 L
s
.52976 .87821 m
.54343 .87441 L
s
.60611 .87294 m
.61291 .86837 L
s
.32843 .63061 m
.33443 .49165 L
s
.31824 .47508 m
.33443 .49165 L
s
.62345 .87059 m
.62907 .86389 L
s
.54343 .87441 m
.55714 .87059 L
s
.61291 .86837 m
.61974 .86352 L
s
.55714 .87059 m
.57091 .86676 L
s
.57091 .86676 m
.58471 .86291 L
s
.62907 .86389 m
.63473 .85615 L
s
.61974 .86352 m
.6266 .85841 L
s
.31119 .62594 m
.31824 .47508 L
s
.58471 .86291 m
.59857 .85905 L
s
.6266 .85841 m
.6335 .85303 L
s
.59857 .85905 m
.61247 .85518 L
s
.61247 .85518 m
.62642 .85129 L
s
.6761 .64979 m .78387 .61447 L .64042 .84739 L .002 0 .41 r
F
.6761 .64979 m .77033 .3457 L .78387 .61447 L F
.52154 .68294 m .78387 .61447 L .64042 .84739 L .648 .761 .931 r
F
0 g
.64042 .84739 m
.64042 .84739 L
s
.62642 .85129 m
.64042 .84739 L
s
.6335 .85303 m
.64042 .84739 L
s
.63473 .85615 m
.64042 .84739 L
s
.62715 .86629 m
.64042 .84739 L
s
.47555 .89331 m
.64042 .84739 L
s
.52247 .41745 m .75614 .32722 L .77033 .3457 L .662 .743 .91 r
F
.52247 .41745 m .32444 .24381 L .75614 .32722 L F
.52247 .41745 m .15354 .30653 L .32444 .24381 L F
0 g
.15354 .30653 m
.31824 .47508 L
s
.30596 .73779 m
.32313 .75353 L
s
.75614 .32722 m .77033 .3457 L .78387 .61447 L .976 .681 .39 r
F
0 g
.63531 .59068 m
.75977 .36485 L
s
.75614 .32722 m .78387 .61447 L .76894 .59681 L .976 .681 .39 r
F
.45187 .40097 m .75614 .32722 L .76894 .59681 L .764 .494 .525 r
F
.45187 .40097 m .32444 .24381 L .75614 .32722 L F
0 g
.15354 .30653 m
.47868 .63928 L
s
.75614 .32722 m
.77033 .3457 L
s
.15354 .30653 m
.15375 .30121 L
s
.15354 .30653 m
.15354 .30653 L
s
.15354 .30653 m
.1675 .30141 L
s
.14579 .29909 m
.15354 .30653 L
s
.13521 .29046 m
.15354 .30653 L
s
.1675 .30141 m
.1815 .29627 L
s
.15375 .30121 m
.15394 .29609 L
s
.14579 .29909 m
.13792 .2925 L
s
.1815 .29627 m
.19556 .29111 L
s
.15394 .29609 m
.15412 .29117 L
s
.19556 .29111 m
.20967 .28593 L
s
.13792 .2925 m
.12992 .28681 L
s
.15412 .29117 m
.15428 .28646 L
s
.11687 .27973 m
.13521 .29046 L
s
.20967 .28593 m
.22383 .28074 L
s
.15428 .28646 m
.15441 .28196 L
s
.22383 .28074 m
.23805 .27552 L
s
.12992 .28681 m
.12177 .28206 L
s
.15441 .28196 m
.15453 .27768 L
s
.23805 .27552 m
.25231 .27028 L
s
.15453 .27768 m
.15463 .27363 L
s
.25231 .27028 m
.26663 .26503 L
s
.12177 .28206 m
.11347 .27835 L
s
.26663 .26503 m
.28101 .25976 L
s
.15463 .27363 m
.15471 .26982 L
s
.52154 .68294 m .76894 .59681 L .78387 .61447 L .648 .761 .931 r
F
0 g
.77033 .3457 m
.78387 .61447 L
s
.52154 .68294 m .31141 .5169 L .76894 .59681 L .648 .761 .931 r
F
0 g
.64042 .84739 m
.78387 .61447 L
s
.52154 .68294 m .13065 .57702 L .31141 .5169 L .648 .761 .931 r
F
0 g
.13065 .57702 m
.30596 .73779 L
s
.09921 .27487 m
.11687 .27973 L
s
.28101 .25976 m
.29543 .25446 L
s
.11347 .27835 m
.10498 .27581 L
s
.15471 .26982 m
.15476 .26625 L
s
.29543 .25446 m
.30991 .24915 L
s
.15476 .26625 m
.15479 .26295 L
s
.10498 .27581 m
.09629 .27465 L
s
.45187 .40097 m .27851 .23744 L .32444 .24381 L .764 .494 .525 r
F
0 g
.30489 .24049 m
.32444 .24381 L
s
.32444 .24381 m
.32444 .24381 L
s
.15354 .30653 m
.29624 .25417 L
s
.32444 .24381 m
.75614 .32722 L
s
.15479 .26295 m
.15479 .25994 L
s
.28238 .24385 m
.28524 .2438 L
s
.26832 .24431 m
.28238 .24385 L
s
.25424 .24501 m
.26832 .24431 L
s
.24013 .24595 m
.25424 .24501 L
s
.28524 .23806 m
.30489 .24049 L
s
.0829 .27622 m
.09921 .27487 L
s
.226 .24714 m
.24013 .24595 L
s
.21183 .24858 m
.226 .24714 L
s
.19763 .2503 m
.21183 .24858 L
s
.15479 .25994 m
.15477 .25722 L
s
.09629 .27465 m
.08735 .27519 L
s
.18339 .2523 m
.19763 .2503 L
s
.45187 .40097 m .23368 .23625 L .27851 .23744 L .764 .494 .525 r
F
0 g
.26546 .23656 m
.28524 .23806 L
s
.27851 .23744 m
.32444 .24381 L
s
.1691 .2546 m
.18339 .2523 L
s
.15477 .25722 m
.1691 .2546 L
s
.24555 .23605 m
.26546 .23656 L
s
.15477 .25722 m
.14874 .25708 L
s
.15477 .25722 m
.14635 .25797 L
s
.14635 .25797 m
.13787 .25911 L
s
.14874 .25708 m
.14265 .25732 L
s
.08735 .27519 m
.0781 .27798 L
s
.45187 .40097 m .19159 .24034 L .23368 .23625 L .764 .494 .525 r
F
0 g
.22547 .23662 m
.24555 .23605 L
s
.23368 .23625 m
.27851 .23744 L
s
.13787 .25911 m
.12933 .26067 L
s
.14265 .25732 m
.1365 .25798 L
s
.20522 .23839 m
.22547 .23662 L
s
.12933 .26067 m
.1207 .26271 L
s
.06863 .28388 m
.0829 .27622 L
s
.1365 .25798 m
.13028 .25912 L
s
.1207 .26271 m
.11199 .26532 L
s
.0781 .27798 m
.0684 .28406 L
s
.13028 .25912 m
.12399 .26083 L
s
.45187 .40097 m .15384 .24966 L .19159 .24034 L .764 .494 .525 r
F
0 g
.18475 .24158 m
.20522 .23839 L
s
.19159 .24034 m
.23368 .23625 L
s
.11199 .26532 m
.10319 .26858 L
s
.16402 .2465 m
.18475 .24158 L
s
.12399 .26083 m
.1176 .26319 L
s
.10319 .26858 m
.09426 .27266 L
s
.09426 .27266 m
.08519 .27778 L
s
.057 .29772 m
.06863 .28388 L
s
.0684 .28406 m
.05796 .29616 L
s
.45187 .40097 m .12191 .26395 L .15384 .24966 L .764 .494 .525 r
F
0 g
.14295 .2537 m
.16402 .2465 L
s
.15384 .24966 m
.19159 .24034 L
s
.45187 .40097 m .09712 .28276 L .12191 .26395 L .764 .494 .525 r
F
0 g
.12191 .26395 m
.15384 .24966 L
s
.1111 .26636 m
.1176 .26319 L
s
.45187 .40097 m .08059 .30545 L .09712 .28276 L .764 .494 .525 r
F
.45187 .40097 m .07313 .3312 L .08059 .30545 L F
.45187 .40097 m .0752 .35902 L .07313 .3312 L F
.45187 .40097 m .08688 .38782 L .0752 .35902 L F
.45187 .40097 m .10782 .4164 L .08688 .38782 L F
.45187 .40097 m .13724 .44358 L .10782 .4164 L F
.45187 .40097 m .17397 .46818 L .13724 .44358 L F
.45187 .40097 m .21647 .48915 L .17397 .46818 L F
.45187 .40097 m .26294 .50562 L .21647 .48915 L F
.45187 .40097 m .31141 .5169 L .26294 .50562 L F
.45187 .40097 m .76894 .59681 L .31141 .5169 L F
0 g
.13065 .57702 m
.47555 .89331 L
s
.75614 .32722 m
.76894 .59681 L
s
.76894 .59681 m
.78387 .61447 L
s
.10447 .27057 m
.1111 .26636 L
s
.07593 .28432 m
.08519 .27778 L
s
.12142 .26423 m
.14295 .2537 L
s
.09766 .2762 m
.10447 .27057 L
s
.07593 .28432 m
.0664 .29302 L
s
.09712 .28276 m
.12191 .26395 L
s
.09911 .28082 m
.12142 .26423 L
s
.05796 .29616 m
.04375 .342 L
s
.0906 .28399 m
.09766 .2762 L
s
.04856 .31732 m
.057 .29772 L
s
.31141 .5169 m
.76894 .59681 L
s
.0664 .29302 m
.05638 .30575 L
s
.08309 .29581 m
.0906 .28399 L
s
.05638 .30575 m
.04375 .342 L
s
.04375 .342 m
.05638 .30575 L
s
.07313 .3312 m
.09911 .28082 L
s
.08059 .30545 m
.09712 .28276 L
s
.04375 .342 m
.04856 .31732 L
s
.12246 .56896 m
.13065 .57702 L
s
.13065 .57702 m
.13065 .57702 L
s
.13065 .57702 m
.13085 .57169 L
s
.13065 .57702 m
.1454 .57211 L
s
.13065 .57702 m
.31141 .5169 L
s
.11155 .55651 m
.13065 .57702 L
s
.07313 .3312 m
.08309 .29581 L
s
.1454 .57211 m
.1602 .56719 L
s
.13085 .57169 m
.13107 .56609 L
s
.12246 .56896 m
.11431 .55986 L
s
.07313 .3312 m
.08059 .30545 L
s
.1602 .56719 m
.17505 .56225 L
s
.13107 .56609 m
.13131 .56022 L
s
.11431 .55986 m
.10622 .54966 L
s
.17505 .56225 m
.18997 .55729 L
s
.13131 .56022 m
.13158 .55407 L
s
.04375 .342 m
.04375 .342 L
s
.04375 .342 m
.04618 .3411 L
s
.04375 .342 m
.04375 .342 L
s
.04808 .38405 m
.04375 .342 L
s
.04638 .40564 m
.04375 .342 L
s
.04282 .37081 m
.04375 .342 L
s
.04618 .3411 m
.04863 .34021 L
s
.11155 .55651 m
.09345 .53101 L
s
.04863 .34021 m
.05107 .33931 L
s
.05107 .33931 m
.05351 .33841 L
s
.05351 .33841 m
.05596 .33751 L
s
.05596 .33751 m
.05841 .33661 L
s
.18997 .55729 m
.20494 .55231 L
s
.13158 .55407 m
.13187 .54763 L
s
.05841 .33661 m
.06086 .33571 L
s
.10622 .54966 m
.09818 .53831 L
s
.06086 .33571 m
.06331 .33481 L
s
.06331 .33481 m
.06576 .33391 L
s
.06576 .33391 m
.06821 .33301 L
s
.06821 .33301 m
.07067 .3321 L
s
.07067 .3321 m
.07313 .3312 L
s
.13187 .54763 m
.13218 .54091 L
s
.20494 .55231 m
.21997 .54731 L
s
.07313 .3312 m
.08846 .39053 L
s
.07313 .3312 m
.07313 .3312 L
s
.07313 .3312 m
.07523 .37423 L
s
.07313 .3312 m
.0752 .35902 L
s
.09818 .53831 m
.09022 .52572 L
s
.04588 .40256 m
.04282 .37081 L
s
.13218 .54091 m
.13251 .53388 L
s
.09345 .53101 m
.07717 .50156 L
s
.21997 .54731 m
.23506 .54229 L
s
.09022 .52572 m
.08235 .51174 L
s
.13251 .53388 m
.13287 .52655 L
s
.055 .40254 m
.04808 .38405 L
s
.23506 .54229 m
.25021 .53725 L
s
.08235 .51174 m
.07461 .49618 L
s
.05285 .4359 m
.04588 .40256 L
s
.13287 .52655 m
.13326 .51889 L
s
.07717 .50156 m
.06343 .46939 L
s
.0527 .43533 m
.04638 .40564 L
s
.07461 .49618 m
.06703 .47871 L
s
.0752 .35902 m
.08688 .38782 L
s
.25021 .53725 m
.26542 .53219 L
s
.06238 .41696 m
.055 .40254 L
s
.06703 .47871 m
.05969 .45878 L
s
.13326 .51889 m
.13368 .51089 L
s
.05969 .45878 m
.0527 .43533 L
s
.06343 .46939 m
.05285 .4359 L
s
.07523 .37423 m
.07976 .39366 L
s
.26542 .53219 m
.28069 .52711 L
s
.07001 .42918 m
.06238 .41696 L
s
.13412 .50254 m
.13368 .51089 L
s
.07781 .43995 m
.07001 .42918 L
s
.07976 .39366 m
.08471 .40899 L
s
.13412 .50254 m
.1346 .49381 L
s
.28069 .52711 m
.29602 .52202 L
s
.08572 .44963 m
.07781 .43995 L
s
.08688 .38782 m
.10782 .4164 L
s
.09372 .45847 m
.08572 .44963 L
s
.08846 .39053 m
.10738 .41592 L
s
.08471 .40899 m
.0899 .42213 L
s
.1018 .4666 m
.09372 .45847 L
s
.14916 .49739 m
.1346 .49381 L
s
.1346 .49381 m
.12885 .48682 L
s
.1346 .49381 m
.12634 .48768 L
s
.10993 .47413 m
.1018 .4666 L
s
.12634 .48768 m
.11812 .48114 L
s
.11812 .48114 m
.10993 .47413 L
s
.12885 .48682 m
.12312 .47941 L
s
.16377 .50063 m
.14916 .49739 L
s
.29602 .52202 m
.31141 .5169 L
s
.09523 .43379 m
.0899 .42213 L
s
.12312 .47941 m
.11743 .47153 L
s
.17841 .50353 m
.16377 .50063 L
s
.10068 .44438 m
.09523 .43379 L
s
.11743 .47153 m
.11179 .46312 L
s
.1062 .4541 m
.10068 .44438 L
s
.11179 .46312 m
.1062 .4541 L
s
.1931 .50612 m
.17841 .50353 L
s
.20781 .50842 m
.1931 .50612 L
s
.22255 .51043 m
.20781 .50842 L
s
.23731 .51216 m
.22255 .51043 L
s
.23731 .51216 m
.2521 .51362 L
s
.29656 .51646 m
.31141 .5169 L
s
.31141 .5169 m
.31141 .5169 L
s
.2907 .51277 m
.31141 .5169 L
s
.26294 .50562 m
.31141 .5169 L
s
.2521 .51362 m
.26691 .51483 L
s
.28173 .51577 m
.29656 .51646 L
s
.26691 .51483 m
.28173 .51577 L
s
.10738 .41592 m
.12699 .43513 L
s
.10782 .4164 m
.13724 .44358 L
s
.27 .50762 m
.2907 .51277 L
s
.12699 .43513 m
.14697 .45086 L
s
.24931 .5014 m
.27 .50762 L
s
.21647 .48915 m
.26294 .50562 L
s
.13724 .44358 m
.17397 .46818 L
s
.22867 .49406 m
.24931 .5014 L
s
.14697 .45086 m
.16719 .46417 L
s
.20808 .48551 m
.22867 .49406 L
s
.16719 .46417 m
.18757 .47562 L
s
.17397 .46818 m
.21647 .48915 L
s
.18757 .47562 m
.20808 .48551 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{137.875, 134.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 136.875}, {133.938, 0}} -> {0.00167792, \
-4.52484*^-6, 0.00675664, 0.00675664}},
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{LineOfRays[8,NumberOfRays->7],
\tMove[PorroPrism[30,10],10],
\tBoundary[45,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  CellTags->"PorroPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.21216 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0373483 0.903184 0.0373483 [
[.43128 .02886 -3 -4.5 ]
[.43128 .02886 3 4.5 ]
[ 0 0 0 0 ]
[ 1 1.21216 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.39729 .64175 m
.39729 .64175 L
.39729 .99655 L
.39729 1.03299 L
.39729 1.06802 L
.39729 1.1003 L
.39729 1.1286 L
.39729 1.15182 L
.39729 1.16908 L
.39729 1.17971 L
.39729 1.1833 L
.39729 1.17971 L
.39729 1.16908 L
.39729 1.15182 L
.39729 1.1286 L
.39729 1.1003 L
.39729 1.06802 L
.39729 1.03299 L
.39729 .99655 L
.39729 .64175 L
s
.39729 .6044 m
.39729 .64175 L
.39729 .64175 L
.39729 .6044 L
.39729 .6044 L
s
.62138 .24959 m
.58495 .21316 L
.54992 .17813 L
.51763 .14584 L
.48934 .11754 L
.46611 .09432 L
.44886 .07706 L
.43823 .06644 L
.43464 .06285 L
.43823 .06644 L
.44886 .07706 L
.46611 .09432 L
.48934 .11754 L
.51763 .14584 L
.54992 .17813 L
.58495 .21316 L
.62138 .24959 L
.97619 .6044 L
.97619 .6044 L
.62138 .24959 L
s
.97619 .64175 m
.97619 .64175 L
.62138 .99655 L
.58495 1.03299 L
.54992 1.06802 L
.51763 1.1003 L
.48934 1.1286 L
.46611 1.15182 L
.44886 1.16908 L
.43823 1.17971 L
.43464 1.1833 L
.43823 1.17971 L
.44886 1.16908 L
.46611 1.15182 L
.48934 1.1286 L
.51763 1.1003 L
.54992 1.06802 L
.58495 1.03299 L
.62138 .99655 L
.97619 .64175 L
s
.97619 .6044 m
.97619 .64175 L
.97619 .64175 L
.97619 .6044 L
.97619 .6044 L
s
.39729 .24959 m
.39729 .21316 L
.39729 .17813 L
.39729 .14584 L
.39729 .11754 L
.39729 .09432 L
.39729 .07706 L
.39729 .06644 L
.39729 .06285 L
.39729 .06644 L
.39729 .07706 L
.39729 .09432 L
.39729 .11754 L
.39729 .14584 L
.39729 .17813 L
.39729 .21316 L
.39729 .24959 L
.39729 .6044 L
.39729 .6044 L
.39729 .24959 L
s
.39729 .24959 m
.62138 .24959 L
.97619 .6044 L
.97619 .64175 L
.62138 .99655 L
.39729 .99655 L
.39729 .24959 L
s
.39729 .24959 m
.62138 .24959 L
.97619 .6044 L
.97619 .64175 L
.62138 .99655 L
.39729 .99655 L
.39729 .24959 L
s
.62138 .99655 m
.60271 .99655 L
.58403 .99655 L
.56536 .99655 L
.54669 .99655 L
.52801 .99655 L
.50934 .99655 L
.49066 .99655 L
.47199 .99655 L
.45331 .99655 L
.43464 .99655 L
.41597 .99655 L
.39729 .99655 L
.39729 .99655 L
.39729 1.01212 L
.39729 1.02768 L
.39729 1.04324 L
.39729 1.0588 L
.39729 1.07436 L
.39729 1.08993 L
.39729 1.10549 L
.39729 1.12105 L
.39729 1.13661 L
.39729 1.15217 L
.39729 1.16773 L
.39729 1.1833 L
.39729 1.1833 L
.4004 1.1833 L
.40352 1.1833 L
.40663 1.1833 L
.40974 1.1833 L
.41285 1.1833 L
.41597 1.1833 L
.41908 1.1833 L
.42219 1.1833 L
.4253 1.1833 L
.42842 1.1833 L
.43153 1.1833 L
.43464 1.1833 L
.43464 1.1833 L
.4502 1.16773 L
.46576 1.15217 L
.48133 1.13661 L
.49689 1.12105 L
.51245 1.10549 L
.52801 1.08993 L
.54357 1.07436 L
.55913 1.0588 L
.5747 1.04324 L
.59026 1.02768 L
Mistroke
.60582 1.01212 L
.62138 .99655 L
Mfstroke
.39729 .99655 m
.39729 1.01212 L
.39729 1.02768 L
.39729 1.04324 L
.39729 1.0588 L
.39729 1.07436 L
.39729 1.08993 L
.39729 1.10549 L
.39729 1.12105 L
.39729 1.13661 L
.39729 1.15217 L
.39729 1.16773 L
.39729 1.1833 L
.39729 1.1833 L
.4004 1.1833 L
.40352 1.1833 L
.40663 1.1833 L
.40974 1.1833 L
.41285 1.1833 L
.41597 1.1833 L
.41908 1.1833 L
.42219 1.1833 L
.4253 1.1833 L
.42842 1.1833 L
.43153 1.1833 L
.43464 1.1833 L
.43464 1.1833 L
.4502 1.16773 L
.46576 1.15217 L
.48133 1.13661 L
.49689 1.12105 L
.51245 1.10549 L
.52801 1.08993 L
.54357 1.07436 L
.55913 1.0588 L
.5747 1.04324 L
.59026 1.02768 L
.60582 1.01212 L
.62138 .99655 L
.62138 .99655 L
.60271 .99655 L
.58403 .99655 L
.56536 .99655 L
.54669 .99655 L
.52801 .99655 L
.50934 .99655 L
.49066 .99655 L
.47199 .99655 L
.45331 .99655 L
.43464 .99655 L
Mistroke
.41597 .99655 L
.39729 .99655 L
Mfstroke
.39729 .24959 m
.39729 .23403 L
.39729 .21847 L
.39729 .2029 L
.39729 .18734 L
.39729 .17178 L
.39729 .15622 L
.39729 .14066 L
.39729 .12509 L
.39729 .10953 L
.39729 .09397 L
.39729 .07841 L
.39729 .06285 L
.39729 .06285 L
.4004 .06285 L
.40352 .06285 L
.40663 .06285 L
.40974 .06285 L
.41285 .06285 L
.41597 .06285 L
.41908 .06285 L
.42219 .06285 L
.4253 .06285 L
.42842 .06285 L
.43153 .06285 L
.43464 .06285 L
.43464 .06285 L
.4502 .07841 L
.46576 .09397 L
.48133 .10953 L
.49689 .12509 L
.51245 .14066 L
.52801 .15622 L
.54357 .17178 L
.55913 .18734 L
.5747 .2029 L
.59026 .21847 L
.60582 .23403 L
.62138 .24959 L
.62138 .24959 L
.60271 .24959 L
.58403 .24959 L
.56536 .24959 L
.54669 .24959 L
.52801 .24959 L
.50934 .24959 L
.49066 .24959 L
.47199 .24959 L
.45331 .24959 L
.43464 .24959 L
Mistroke
.41597 .24959 L
.39729 .24959 L
Mfstroke
.62138 .24959 m
.60271 .24959 L
.58403 .24959 L
.56536 .24959 L
.54669 .24959 L
.52801 .24959 L
.50934 .24959 L
.49066 .24959 L
.47199 .24959 L
.45331 .24959 L
.43464 .24959 L
.41597 .24959 L
.39729 .24959 L
.39729 .24959 L
.39729 .23403 L
.39729 .21847 L
.39729 .2029 L
.39729 .18734 L
.39729 .17178 L
.39729 .15622 L
.39729 .14066 L
.39729 .12509 L
.39729 .10953 L
.39729 .09397 L
.39729 .07841 L
.39729 .06285 L
.39729 .06285 L
.4004 .06285 L
.40352 .06285 L
.40663 .06285 L
.40974 .06285 L
.41285 .06285 L
.41597 .06285 L
.41908 .06285 L
.42219 .06285 L
.4253 .06285 L
.42842 .06285 L
.43153 .06285 L
.43464 .06285 L
.43464 .06285 L
.4502 .07841 L
.46576 .09397 L
.48133 .10953 L
.49689 .12509 L
.51245 .14066 L
.52801 .15622 L
.54357 .17178 L
.55913 .18734 L
.5747 .2029 L
.59026 .21847 L
Mistroke
.60582 .23403 L
.62138 .24959 L
Mfstroke
.039 .916 .04 r
.02381 .75379 m
.39729 .75379 L
s
0 0 0 r
2 Mabswid
.39729 .75379 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .80359 m
.39729 .80359 L
s
0 0 0 r
2 Mabswid
.39729 .80359 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .85339 m
.39729 .85339 L
s
0 0 0 r
2 Mabswid
.39729 .85339 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .90318 m
.39729 .90318 L
s
0 0 0 r
2 Mabswid
.39729 .90318 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .95298 m
.39729 .95298 L
s
0 0 0 r
2 Mabswid
.39729 .95298 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 1.00278 m
.39729 1.00278 L
s
0 0 0 r
2 Mabswid
.39729 1.00278 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 1.05258 m
.39729 1.05258 L
s
0 0 0 r
2 Mabswid
.39729 1.05258 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .75379 m
.86415 .75379 L
s
0 0 0 r
2 Mabswid
.86415 .75379 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .80359 m
.81435 .80359 L
s
0 0 0 r
2 Mabswid
.81435 .80359 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .85339 m
.76455 .85339 L
s
0 0 0 r
2 Mabswid
.76455 .85339 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .90318 m
.71475 .90318 L
s
0 0 0 r
2 Mabswid
.71475 .90318 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .95298 m
.66495 .95298 L
s
0 0 0 r
2 Mabswid
.66495 .95298 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 1.00278 m
.61516 1.00278 L
s
0 0 0 r
2 Mabswid
.61516 1.00278 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 1.05258 m
.56536 1.05258 L
s
0 0 0 r
2 Mabswid
.56536 1.05258 Mdot
.039 .916 .04 r
.5 Mabswid
.86415 .75379 m
.86415 .49235 L
s
0 0 0 r
2 Mabswid
.86415 .49235 Mdot
.039 .916 .04 r
.5 Mabswid
.81435 .80359 m
.81435 .44256 L
s
0 0 0 r
2 Mabswid
.81435 .44256 Mdot
.039 .916 .04 r
.5 Mabswid
.76455 .85339 m
.76455 .39276 L
s
0 0 0 r
2 Mabswid
.76455 .39276 Mdot
.039 .916 .04 r
.5 Mabswid
.71475 .90318 m
.71475 .34296 L
s
0 0 0 r
2 Mabswid
.71475 .34296 Mdot
.039 .916 .04 r
.5 Mabswid
.66495 .95298 m
.66495 .29316 L
s
0 0 0 r
2 Mabswid
.66495 .29316 Mdot
.039 .916 .04 r
.5 Mabswid
.61516 1.00278 m
.61516 .24336 L
s
0 0 0 r
2 Mabswid
.61516 .24336 Mdot
.039 .916 .04 r
.5 Mabswid
.56536 1.05258 m
.56536 .19357 L
s
0 0 0 r
2 Mabswid
.56536 .19357 Mdot
.039 .916 .04 r
.5 Mabswid
.86415 .49235 m
.39729 .49235 L
s
0 0 0 r
2 Mabswid
.39729 .49235 Mdot
.039 .916 .04 r
.5 Mabswid
.81435 .44256 m
.39729 .44256 L
s
0 0 0 r
2 Mabswid
.39729 .44256 Mdot
.039 .916 .04 r
.5 Mabswid
.76455 .39276 m
.39729 .39276 L
s
0 0 0 r
2 Mabswid
.39729 .39276 Mdot
.039 .916 .04 r
.5 Mabswid
.71475 .34296 m
.39729 .34296 L
s
0 0 0 r
2 Mabswid
.39729 .34296 Mdot
.039 .916 .04 r
.5 Mabswid
.66495 .29316 m
.39729 .29316 L
s
0 0 0 r
2 Mabswid
.39729 .29316 Mdot
.039 .916 .04 r
.5 Mabswid
.61516 .24336 m
.39729 .24336 L
s
0 0 0 r
2 Mabswid
.39729 .24336 Mdot
.039 .916 .04 r
.5 Mabswid
.56536 .19357 m
.39729 .19357 L
s
0 0 0 r
2 Mabswid
.39729 .19357 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .49235 m
.02381 .49235 L
s
0 0 0 r
2 Mabswid
.02381 .49235 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .44256 m
.02381 .44256 L
s
0 0 0 r
2 Mabswid
.02381 .44256 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .39276 m
.02381 .39276 L
s
0 0 0 r
2 Mabswid
.02381 .39276 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .34296 m
.02381 .34296 L
s
0 0 0 r
2 Mabswid
.02381 .34296 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .29316 m
.02381 .29316 L
s
0 0 0 r
2 Mabswid
.02381 .29316 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .24336 m
.02381 .24336 L
s
0 0 0 r
2 Mabswid
.02381 .24336 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .19357 m
.02381 .19357 L
s
0 0 0 r
2 Mabswid
.02381 .19357 Mdot
[(P)] .43128 .02886 0 0 Mshowa
0 0 m
1 0 L
1 1.21216 L
0 1.21216 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{184.875, 223.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 183.875}, {222.875, 0}} -> {-0.638289, -24.1829, \
0.145624, 0.145624}},
  CellTags->"PorroPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Prism[{angle, side, angle}, height, options]", "Subsection",
  CellTags->"Prism"],

Cell[CellGroupData[{

Cell["?Prism", "Input",
  CellTags->"Prism"],

Cell[BoxData[
    \("Prism[{alpha, side, beta}, height, options] designates a triangular \
refractive prism specified by two angles, alpha and beta, a side between the \
two angles, and a height. \n\nPrism is created with its triangle lying in the \
horizontal x-y plane and its height pointing vertically. The specified side \
is bisected by the origin, pointing in line with the x axis. If the \
Mirrored->True option is given, a reflectorized surface is placed on the \
hypotenuse of the prism. If Mirrored->Base is given, a reflectorized surface \
is placed on the base of the prism. For Baffled->False, the triangular \
surface panels are refractive surfaces. If the Baffled->True option is given, \
the triangular surface panels absorb any rays hitting them. See also: \
DovePrism, ReversionPrism, WedgePrism, RhomboidalPrism, RoofPrism, \
PellinBrocaPrism, and AmiciRoofPrism."\)], "Print",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[Prism]", "Input",
  CellTags->"Prism"],

Cell[BoxData[
    \({Labels \[Rule] "P", LabelPositions \[Rule] Automatic, 
      Mirrored \[Rule] False, ComponentDescription \[Rule] Automatic, 
      GraphicDesign \[Rule] Automatic, ComponentMedium \[Rule] BK7, 
      Temperature \[Rule] Temperature, Tension \[Rule] Tension, 
      Transmittance \[Rule] Transmittance, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Off \[Rule] {SurfaceRendering \[Rule] Empty, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          EdgeRendering \[Rule] Mesh, CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
          EdgeRendering \[Rule] Fill, CrossRendering \[Rule] Empty}, 
      Mirror \[Rule] {Automatic \[Rule] {SurfaceRendering \[Rule] {{Fill, 
                    Trace}}, EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}, 
          Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
              EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}}}\)], "Output",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Base", "Input",
  CellTags->"Prism"],

Cell[BoxData[
    \("Base is an value for the Mirrored option that indicates a \
reflectorized base for the optical component."\)], "Print",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{45, 10, 90}, 10],PlotType->TopView]", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.97619 .97619 L
.97619 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.97619 .02381 m
.97619 .97619 L
.97619 .97619 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.97619 .97619 L
.97619 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.97619 .97619 L
.97619 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{104.812, 104.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 103.812}, {103.812, 0}} -> {-5.25005, -0.250052, \
0.101145, 0.101145}},
  CellTags->"Prism"],

Cell[BoxData[
    TagBox[\(DrawSystem[{Prism[{45, 10, 90}, 10]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  CellTags->"Prism"],

Cell[BoxData[
    \("-rendered element-"\)], "Output",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.91022 .42206 m
.66497 .02988 L
s
.10855 .26104 m
.91022 .42206 L
s
.91022 .42206 m
.97657 .93008 L
s
.66497 .02988 m
.10855 .26104 L
s
.02877 .79167 m
.10855 .26104 L
s
.97657 .93008 m
.6952 .58531 L
s
.02877 .79167 m
.97657 .93008 L
s
.66497 .02988 m
.6952 .58531 L
s
.6952 .58531 m
.02877 .79167 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{170.125, 184.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 169.125}, {183.625, 0}} -> {0.0486402, -0.000105593, \
0.0050707, 0.0050707}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{90, 10, 45}, 10],PlotType->TopView];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.5 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.97619 .02381 m
.02381 .97619 L
.02381 .97619 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.97619 .02381 L
.97619 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.97619 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.97619 .02381 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{104.75, 104.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 103.75}, {103.75, 0}} -> {-0.250052, -5.25005, \
0.101206, 0.101206}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-16 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.42216 .58164 m
.66497 .02988 L
s
.10855 .26104 m
.42216 .58164 L
s
.42216 .58164 m
.40598 1.06315 L
s
.40598 1.06315 m
.6952 .58531 L
s
.02877 .79167 m
.40598 1.06315 L
s
.66497 .02988 m
.10855 .26104 L
s
.02877 .79167 m
.10855 .26104 L
s
.66497 .02988 m
.6952 .58531 L
s
.6952 .58531 m
.02877 .79167 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{170.062, 184.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 169.062}, {183.562, 0}} -> {0.0486402, -0.000119184, \
0.00507258, 0.00507258}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{40, 10, 130}, 10],PlotType->TopView];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8391 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0281821 0.41955 0.0281821 [
[ 0 0 0 0 ]
[ 1 .8391 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01998 m
.97619 .81912 L
.97619 .81912 L
.02381 .01998 L
.02381 .01998 L
s
.30563 .01998 m
.97619 .81912 L
.97619 .81912 L
.30563 .01998 L
.30563 .01998 L
s
.02381 .01998 m
.30563 .01998 L
.30563 .01998 L
.02381 .01998 L
.02381 .01998 L
s
.02381 .01998 m
.97619 .81912 L
.30563 .01998 L
.02381 .01998 L
s
.02381 .01998 m
.97619 .81912 L
.30563 .01998 L
.02381 .01998 L
s
0 0 m
1 0 L
1 .8391 L
0 .8391 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{161.875, 135.812},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 160.875}, {134.812, 0}} -> {-0.86841, -14.8873, \
0.220859, 0.220859}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .73808 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.032 -0.103095 1.032 [
[ 0 0 0 0 ]
[ 1 .73808 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .73808 L
0 .73808 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.95554 .384 m
.23056 .20223 L
s
.05023 .26968 m
.95554 .384 L
s
.95554 .384 m
.97707 .55468 L
s
.97707 .55468 m
.21519 .38019 L
s
.02598 .44513 m
.97707 .55468 L
s
.02598 .44513 m
.05023 .26968 L
s
.23056 .20223 m
.05023 .26968 L
s
.21519 .38019 m
.23056 .20223 L
s
.21519 .38019 m
.02598 .44513 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{206.188, 152.125},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 205.188}, {151.125, 0}} -> {-0.00103008, 0.0998947, \
0.00473251, 0.00473251}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{90, 10, 45}, 10, Mirrored->True]];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-16 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.66497 .02988 m .42216 .58164 L .40598 1.06315 L 0 0 .346 r
F
.66497 .02988 m .40598 1.06315 L .6952 .58531 L F
0 g
.5 Mabswid
[ ] 0 setdash
.02877 .79167 m
.40598 1.06315 L
s
.40598 1.06315 m
.6952 .58531 L
s
.42216 .58164 m
.66497 .02988 L
s
.10855 .26104 m
.42216 .58164 L
s
.40598 1.06315 m
.42216 .58164 L
s
.10855 .26104 m
.66497 .02988 L
s
.02877 .79167 m
.10855 .26104 L
s
.66497 .02988 m
.6952 .58531 L
s
.02877 .79167 m
.6952 .58531 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{154.375, 167.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 153.375}, {166.562, 0}} -> {0.0486402, -0.000211362, \
0.00559141, 0.00559141}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{45, 10, 90}, 10, Mirrored->True]];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-16 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.10855 .26104 m .91022 .42206 L .97657 .93008 L .762 .501 .538 r
F
.10855 .26104 m .97657 .93008 L .02877 .79167 L F
0 g
.5 Mabswid
[ ] 0 setdash
.02877 .79167 m
.10855 .26104 L
s
.10855 .26104 m
.66497 .02988 L
s
.66497 .02988 m
.91022 .42206 L
s
.10855 .26104 m
.91022 .42206 L
s
.91022 .42206 m
.97657 .93008 L
s
.6952 .58531 m
.97657 .93008 L
s
.02877 .79167 m
.97657 .93008 L
s
.66497 .02988 m
.6952 .58531 L
s
.02877 .79167 m
.6952 .58531 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{188.312, 204.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 187.312}, {203.375, 0}} -> {0.0486402, -0.00011289, \
0.00457835, 0.00457835}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[Prism[{45, 10, 45}, 10, Mirrored->True]];", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.10148 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0651548 1.12552 1.11022e-16 1.12552 [
[ 0 0 0 0 ]
[ 1 1.10148 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.10148 L
0 1.10148 L
closepath
clip
newpath
.09792 .28199 m .80437 .68968 L .02573 .91254 L .524 .296 .511 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.58794 .75163 m
.59341 .99181 L
s
.09792 .28199 m .75226 .02737 L .80437 .68968 L .524 .296 .511 r
F
0 g
.09792 .28199 m
.75226 .02737 L
s
.02573 .91254 m
.09792 .28199 L
s
.75226 .02737 m
.80437 .68968 L
s
.59341 .99181 m
.80437 .68968 L
s
.02573 .91254 m
.59341 .99181 L
s
.02573 .91254 m
.80437 .68968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{145.438, 160.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 144.438}, {159.188, 0}} -> {0.0578842, -0.00028934, \
0.00615136, 0.00615136}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{LineOfRays[8,NumberOfRays->7],
Move[Prism[{90,10,45},10,Reflectance->100,Centered->True],3],
Boundary[20,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0732601 0.760073 0.0732601 [
[.21429 .36447 -15 -4.5 ]
[.21429 .36447 15 4.5 ]
[ 0 0 0 0 ]
[ 1 1.15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.24359 .39377 m
.24359 1.12637 L
.24359 1.12637 L
.24359 .39377 L
.24359 .39377 L
s
.97619 .39377 m
.24359 1.12637 L
.24359 1.12637 L
.97619 .39377 L
.97619 .39377 L
s
.24359 .39377 m
.97619 .39377 L
.97619 .39377 L
.24359 .39377 L
.24359 .39377 L
s
.24359 .39377 m
.24359 1.12637 L
.97619 .39377 L
.24359 .39377 L
s
.24359 .39377 m
.24359 1.12637 L
.97619 .39377 L
.24359 .39377 L
s
.039 .916 .04 r
.02381 .46703 m
.24359 .46703 L
s
0 0 0 r
2 Mabswid
.24359 .46703 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56471 m
.24359 .56471 L
s
0 0 0 r
2 Mabswid
.24359 .56471 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .66239 m
.24359 .66239 L
s
0 0 0 r
2 Mabswid
.24359 .66239 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .76007 m
.24359 .76007 L
s
0 0 0 r
2 Mabswid
.24359 .76007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .85775 m
.24359 .85775 L
s
0 0 0 r
2 Mabswid
.24359 .85775 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .95543 m
.24359 .95543 L
s
0 0 0 r
2 Mabswid
.24359 .95543 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 1.05311 m
.24359 1.05311 L
s
0 0 0 r
2 Mabswid
.24359 1.05311 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .46703 m
.90293 .46703 L
s
0 0 0 r
2 Mabswid
.90293 .46703 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .56471 m
.80525 .56471 L
s
0 0 0 r
2 Mabswid
.80525 .56471 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .66239 m
.70757 .66239 L
s
0 0 0 r
2 Mabswid
.70757 .66239 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .76007 m
.60989 .76007 L
s
0 0 0 r
2 Mabswid
.60989 .76007 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .85775 m
.51221 .85775 L
s
0 0 0 r
2 Mabswid
.51221 .85775 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 .95543 m
.41453 .95543 L
s
0 0 0 r
2 Mabswid
.41453 .95543 Mdot
.039 .916 .04 r
.5 Mabswid
.24359 1.05311 m
.31685 1.05311 L
s
0 0 0 r
2 Mabswid
.31685 1.05311 Mdot
.039 .916 .04 r
.5 Mabswid
.90293 .46703 m
.90293 .39377 L
s
0 0 0 r
2 Mabswid
.90293 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.80525 .56471 m
.80525 .39377 L
s
0 0 0 r
2 Mabswid
.80525 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.70757 .66239 m
.70757 .39377 L
s
0 0 0 r
2 Mabswid
.70757 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.60989 .76007 m
.60989 .39377 L
s
0 0 0 r
2 Mabswid
.60989 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .85775 m
.51221 .39377 L
s
0 0 0 r
2 Mabswid
.51221 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.41453 .95543 m
.41453 .39377 L
s
0 0 0 r
2 Mabswid
.41453 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.31685 1.05311 m
.31685 .39377 L
s
0 0 0 r
2 Mabswid
.31685 .39377 Mdot
.039 .916 .04 r
.5 Mabswid
.90293 .39377 m
.90293 .02747 L
s
0 0 0 r
2 Mabswid
.90293 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.80525 .39377 m
.80525 .02747 L
s
0 0 0 r
2 Mabswid
.80525 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.70757 .39377 m
.70757 .02747 L
s
0 0 0 r
2 Mabswid
.70757 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.60989 .39377 m
.60989 .02747 L
s
0 0 0 r
2 Mabswid
.60989 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .39377 m
.51221 .02747 L
s
0 0 0 r
2 Mabswid
.51221 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.41453 .39377 m
.41453 .02747 L
s
0 0 0 r
2 Mabswid
.41453 .02747 Mdot
.039 .916 .04 r
.5 Mabswid
.31685 .39377 m
.31685 .02747 L
s
0 0 0 r
2 Mabswid
.31685 .02747 Mdot
[(Prism)] .21429 .36447 0 0 Mshowa
0 0 m
1 0 L
1 1.15385 L
0 1.15385 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{140.875, 162.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 139.875}, {161.5, 0}} -> {-0.325068, -10.3802, \
0.0975881, 0.0975881}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{LineOfRays[5],
\tMove[Prism[{90, 10, 45}, 10, Mirrored->False],5],
\tBoundary[45,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 1.47222 0.0634921 [
[ 0 0 0 0 ]
[ 1 1.83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 1.15476 m
.34127 1.78968 L
.34127 1.78968 L
.34127 1.15476 L
.34127 1.15476 L
s
.97619 1.15476 m
.34127 1.78968 L
.34127 1.78968 L
.97619 1.15476 L
.97619 1.15476 L
s
.34127 1.15476 m
.97619 1.15476 L
.97619 1.15476 L
.34127 1.15476 L
.34127 1.15476 L
s
.34127 1.15476 m
.34127 1.78968 L
.97619 1.15476 L
.34127 1.15476 L
s
.34127 1.15476 m
.34127 1.78968 L
.97619 1.15476 L
.34127 1.15476 L
s
.039 .916 .04 r
.02381 1.31349 m
.34127 1.31349 L
s
0 0 0 r
2 Mabswid
.34127 1.31349 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 1.47222 m
.34127 1.47222 L
s
0 0 0 r
2 Mabswid
.34127 1.47222 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 1.63095 m
.34127 1.63095 L
s
0 0 0 r
2 Mabswid
.34127 1.63095 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 1.31349 m
.81746 1.31349 L
s
0 0 0 r
2 Mabswid
.81746 1.31349 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 1.47222 m
.65873 1.47222 L
s
0 0 0 r
2 Mabswid
.65873 1.47222 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 1.63095 m
.5 1.63095 L
s
0 0 0 r
2 Mabswid
.5 1.63095 Mdot
.039 .916 .04 r
.5 Mabswid
.81746 1.31349 m
.81746 1.15476 L
s
0 0 0 r
2 Mabswid
.81746 1.15476 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 1.47222 m
.65873 1.15476 L
s
0 0 0 r
2 Mabswid
.65873 1.15476 Mdot
.039 .916 .04 r
.5 Mabswid
.5 1.63095 m
.5 1.15476 L
s
0 0 0 r
2 Mabswid
.5 1.15476 Mdot
.039 .916 .04 r
.5 Mabswid
.81746 1.15476 m
.81746 .04365 L
s
0 0 0 r
2 Mabswid
.81746 .04365 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 1.15476 m
.65873 .04365 L
s
0 0 0 r
2 Mabswid
.65873 .04365 Mdot
.039 .916 .04 r
.5 Mabswid
.5 1.15476 m
.5 .04365 L
s
0 0 0 r
2 Mabswid
.5 .04365 Mdot
0 0 m
1 0 L
1 1.83333 L
0 1.83333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{77.0625, 141.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 76.0625}, {140.25, 0}} -> {-0.375078, -23.2707, \
0.207069, 0.207069}},
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{LineOfRays[5],
\tMove[Prism[{90, 10, 45}, 10],5],
\tMove[Prism[{45, 10, 90}, 10],{10,-20,90}],
\tBoundary[45,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  CellTags->"Prism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55556 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.436508 0.021164 [
[ 0 0 0 0 ]
[ 1 .55556 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .33069 m
.12963 .54233 L
.12963 .54233 L
.12963 .33069 L
.12963 .33069 L
s
.34127 .33069 m
.12963 .54233 L
.12963 .54233 L
.34127 .33069 L
.34127 .33069 L
s
.12963 .33069 m
.34127 .33069 L
.34127 .33069 L
.12963 .33069 L
.12963 .33069 L
s
.12963 .33069 m
.12963 .54233 L
.34127 .33069 L
.12963 .33069 L
s
.12963 .33069 m
.12963 .54233 L
.34127 .33069 L
.12963 .33069 L
s
.34127 .01323 m
.12963 .22487 L
.12963 .22487 L
.34127 .01323 L
.34127 .01323 L
s
.34127 .22487 m
.12963 .22487 L
.12963 .22487 L
.34127 .22487 L
.34127 .22487 L
s
.34127 .01323 m
.34127 .22487 L
.34127 .22487 L
.34127 .01323 L
.34127 .01323 L
s
.34127 .01323 m
.12963 .22487 L
.34127 .22487 L
.34127 .01323 L
s
.34127 .01323 m
.12963 .22487 L
.34127 .22487 L
.34127 .01323 L
s
.039 .916 .04 r
.02381 .3836 m
.12963 .3836 L
s
0 0 0 r
2 Mabswid
.12963 .3836 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43651 m
.12963 .43651 L
s
0 0 0 r
2 Mabswid
.12963 .43651 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48942 m
.12963 .48942 L
s
0 0 0 r
2 Mabswid
.12963 .48942 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .3836 m
.28836 .3836 L
s
0 0 0 r
2 Mabswid
.28836 .3836 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .43651 m
.23545 .43651 L
s
0 0 0 r
2 Mabswid
.23545 .43651 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .48942 m
.18254 .48942 L
s
0 0 0 r
2 Mabswid
.18254 .48942 Mdot
.039 .916 .04 r
.5 Mabswid
.28836 .3836 m
.28836 .33069 L
s
0 0 0 r
2 Mabswid
.28836 .33069 Mdot
.039 .916 .04 r
.5 Mabswid
.23545 .43651 m
.23545 .33069 L
s
0 0 0 r
2 Mabswid
.23545 .33069 Mdot
.039 .916 .04 r
.5 Mabswid
.18254 .48942 m
.18254 .33069 L
s
0 0 0 r
2 Mabswid
.18254 .33069 Mdot
.039 .916 .04 r
.5 Mabswid
.28836 .33069 m
.28836 .22487 L
s
0 0 0 r
2 Mabswid
.28836 .22487 Mdot
.039 .916 .04 r
.5 Mabswid
.23545 .33069 m
.23545 .22487 L
s
0 0 0 r
2 Mabswid
.23545 .22487 Mdot
.039 .916 .04 r
.5 Mabswid
.18254 .33069 m
.18254 .22487 L
s
0 0 0 r
2 Mabswid
.18254 .22487 Mdot
.039 .916 .04 r
.5 Mabswid
.28836 .22487 m
.28836 .06614 L
s
0 0 0 r
2 Mabswid
.28836 .06614 Mdot
.039 .916 .04 r
.5 Mabswid
.23545 .22487 m
.23545 .11905 L
s
0 0 0 r
2 Mabswid
.23545 .11905 Mdot
.039 .916 .04 r
.5 Mabswid
.18254 .22487 m
.18254 .17196 L
s
0 0 0 r
2 Mabswid
.18254 .17196 Mdot
.039 .916 .04 r
.5 Mabswid
.28836 .06614 m
.34127 .06614 L
s
0 0 0 r
2 Mabswid
.34127 .06614 Mdot
.039 .916 .04 r
.5 Mabswid
.23545 .11905 m
.34127 .11905 L
s
0 0 0 r
2 Mabswid
.34127 .11905 Mdot
.039 .916 .04 r
.5 Mabswid
.18254 .17196 m
.34127 .17196 L
s
0 0 0 r
2 Mabswid
.34127 .17196 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .06614 m
.97619 .06614 L
s
0 0 0 r
2 Mabswid
.97619 .06614 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .11905 m
.97619 .11905 L
s
0 0 0 r
2 Mabswid
.97619 .11905 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .17196 m
.97619 .17196 L
s
0 0 0 r
2 Mabswid
.97619 .17196 Mdot
0 0 m
1 0 L
1 .55556 L
0 .55556 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{182, 101.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 181}, {100.062, 0}} -> {-1.24184, -20.6252, \
0.262341, 0.262341}},
  CellTags->"Prism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ReversionPrism[side, thickness, options]", "Subsection",
  CellTags->"ReversionPrism"],

Cell[CellGroupData[{

Cell["?ReversionPrism", "Input",
  CellTags->"ReversionPrism"],

Cell[BoxData[
    \("ReversionPrism[entranceheight, thickness, options] refers to a \
combination of two prism elements cemented together that reverses the image \
orientation without deviating the beam position. \n\nReversionPrism is \
created with its entrance surface centered in the y-z plane at the global \
origin, its trapizoidal dimensions parallel to the x-y plane, and the exit \
surface centered further down about the positive x-axis. The middle prism \
surface is reflectorized. Similar in function to a DovePrism, ReversionPrism \
is commonly used as an image rotator. Unlike DovePrism, ReversionPrism works \
equally well for converging and diverging beams as well as collimated beams. \
See also: DovePrism, DovePrismMirrored and Prism."\)], "Print",
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[ReversionPrism[10,10],PlotType->TopView];", "Input",
  CellTags->"ReversionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57735 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0274929 0.151211 0.0274929 [
[ 0 0 0 0 ]
[ 1 .57735 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01375 m
.02381 .28868 L
.02381 .28868 L
.02381 .01375 L
.02381 .01375 L
s
.02381 .28868 m
.29874 .5636 L
.29874 .5636 L
.02381 .28868 L
.02381 .28868 L
s
.02381 .01375 m
.5 .28868 L
.5 .28868 L
.02381 .01375 L
.02381 .01375 L
s
.5 g
.70126 .5636 m
.29874 .5636 L
.29874 .5636 L
.70126 .5636 L
.70126 .5636 L
F
0 g
.70126 .5636 m
.29874 .5636 L
.29874 .5636 L
.70126 .5636 L
.70126 .5636 L
s
.80189 .46297 m
.70126 .5636 L
.70126 .5636 L
.80189 .46297 L
.80189 .46297 L
s
.97619 .28868 m
.80189 .46297 L
.80189 .46297 L
.97619 .28868 L
.97619 .28868 L
s
.97619 .01375 m
.5 .28868 L
.5 .28868 L
.97619 .01375 L
.97619 .01375 L
s
.97619 .01375 m
.97619 .28868 L
.97619 .28868 L
.97619 .01375 L
.97619 .01375 L
s
.02381 .01375 m
.02381 .28868 L
.29874 .5636 L
.70126 .5636 L
.80189 .46297 L
.02381 .01375 L
s
.5 .28868 m
.80189 .46297 L
.97619 .28868 L
.97619 .01375 L
.5 .28868 L
s
.02381 .01375 m
.02381 .28868 L
.29874 .5636 L
.70126 .5636 L
.80189 .46297 L
.02381 .01375 L
s
.5 .28868 m
.80189 .46297 L
.97619 .28868 L
.97619 .01375 L
.5 .28868 L
s
0 0 m
1 0 L
1 .57735 L
0 .57735 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{186.812, 107.688},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 185.812}, {106.688, 0}} -> {-0.967011, -5.50011, \
0.196838, 0.196838}},
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"ReversionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .69365 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.00384 -0.123164 1.00384 [
[ 0 0 0 0 ]
[ 1 .69365 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .69365 L
0 .69365 L
closepath
clip
newpath
.74751 .35909 m .46673 .44654 L .46513 .62689 L .562 .35 .551 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.17393 .3969 m
.46673 .44654 L
s
.04704 .27968 m
.17393 .3969 L
s
.15864 .57956 m
.17393 .3969 L
s
.74751 .35909 m .46513 .62689 L .75918 .54344 L .562 .35 .551 r
F
0 g
.74751 .35909 m
.75918 .54344 L
s
.74751 .35909 m
.78866 .29212 L
s
.46673 .44654 m
.74751 .35909 L
s
.46513 .62689 m
.46673 .44654 L
s
.46513 .62689 m
.75918 .54344 L
s
.15864 .57956 m
.46513 .62689 L
s
.02458 .46738 m
.15864 .57956 L
s
.78866 .29212 m
.86647 .1655 L
s
.50192 .28731 m
.78866 .29212 L
s
.78866 .29212 m
.04704 .27968 L
s
.78866 .29212 m
.80274 .47931 L
s
.76829 .01977 m
.50192 .28731 L
s
.50192 .28731 m
.50192 .4747 L
s
.04704 .27968 m
.50192 .28731 L
s
.02458 .46738 m
.04704 .27968 L
s
.75918 .54344 m
.80274 .47931 L
s
.80274 .47931 m
.88546 .35753 L
s
.50192 .4747 m
.80274 .47931 L
s
.80274 .47931 m
.02458 .46738 L
s
.78309 .21651 m
.50192 .4747 L
s
.50192 .4747 m
.02458 .46738 L
s
.86647 .1655 m
.76829 .01977 L
s
.86647 .1655 m
.88546 .35753 L
s
.88546 .35753 m
.78309 .21651 L
s
.78309 .21651 m
.76829 .01977 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{182, 126.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 181}, {125.188, 0}} -> {-0.00144987, 0.122689, \
0.00551975, 0.00551975}},
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
\t{LineOfRays[5],
\tMove[ReversionPrism[10,10],5],
\tBoundary[45,GraphicDesign->Off]},PlotType->TopView
];\
\>", "Input",
  CellTags->"ReversionPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46873 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.140109 0.021164 [
[.4962 .01116 -42 -4.5 ]
[.4962 .01116 42 4.5 ]
[ 0 0 0 0 ]
[ 1 .46873 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.12963 .03429 m
.12963 .24593 L
.12963 .24593 L
.12963 .03429 L
.12963 .03429 L
s
.12963 .24593 m
.34127 .45757 L
.34127 .45757 L
.12963 .24593 L
.12963 .24593 L
s
.12963 .03429 m
.4962 .24593 L
.4962 .24593 L
.12963 .03429 L
.12963 .03429 L
s
.5 g
.65113 .45757 m
.34127 .45757 L
.34127 .45757 L
.65113 .45757 L
.65113 .45757 L
F
0 g
.65113 .45757 m
.34127 .45757 L
.34127 .45757 L
.65113 .45757 L
.65113 .45757 L
s
.7286 .3801 m
.65113 .45757 L
.65113 .45757 L
.7286 .3801 L
.7286 .3801 L
s
.86277 .24593 m
.7286 .3801 L
.7286 .3801 L
.86277 .24593 L
.86277 .24593 L
s
.86277 .03429 m
.4962 .24593 L
.4962 .24593 L
.86277 .03429 L
.86277 .03429 L
s
.86277 .03429 m
.86277 .24593 L
.86277 .24593 L
.86277 .03429 L
.86277 .03429 L
s
.12963 .03429 m
.12963 .24593 L
.34127 .45757 L
.65113 .45757 L
.7286 .3801 L
.12963 .03429 L
s
.4962 .24593 m
.7286 .3801 L
.86277 .24593 L
.86277 .03429 L
.4962 .24593 L
s
.12963 .03429 m
.12963 .24593 L
.34127 .45757 L
.65113 .45757 L
.7286 .3801 L
.12963 .03429 L
s
.4962 .24593 m
.7286 .3801 L
.86277 .24593 L
.86277 .03429 L
.4962 .24593 L
s
.039 .916 .04 r
.02381 .0872 m
.12963 .0872 L
s
0 0 0 r
2 Mabswid
.12963 .0872 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14011 m
.12963 .14011 L
s
0 0 0 r
2 Mabswid
.12963 .14011 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19302 m
.12963 .19302 L
s
0 0 0 r
2 Mabswid
.12963 .19302 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .0872 m
.22127 .0872 L
s
0 0 0 r
2 Mabswid
.22127 .0872 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .14011 m
.31292 .14011 L
s
0 0 0 r
2 Mabswid
.31292 .14011 Mdot
.039 .916 .04 r
.5 Mabswid
.12963 .19302 m
.40456 .19302 L
s
0 0 0 r
2 Mabswid
.40456 .19302 Mdot
.039 .916 .04 r
.5 Mabswid
.22127 .0872 m
.43511 .45757 L
s
0 0 0 r
2 Mabswid
.43511 .45757 Mdot
.039 .916 .04 r
.5 Mabswid
.31292 .14011 m
.4962 .45757 L
s
0 0 0 r
2 Mabswid
.4962 .45757 Mdot
.039 .916 .04 r
.5 Mabswid
.40456 .19302 m
.5573 .45757 L
s
0 0 0 r
2 Mabswid
.5573 .45757 Mdot
.039 .916 .04 r
.5 Mabswid
.43511 .45757 m
.58784 .19302 L
s
0 0 0 r
2 Mabswid
.58784 .19302 Mdot
.039 .916 .04 r
.5 Mabswid
.4962 .45757 m
.67949 .14011 L
s
0 0 0 r
2 Mabswid
.67949 .14011 Mdot
.039 .916 .04 r
.5 Mabswid
.5573 .45757 m
.77113 .0872 L
s
0 0 0 r
2 Mabswid
.77113 .0872 Mdot
.039 .916 .04 r
.5 Mabswid
.58784 .19302 m
.86277 .19302 L
s
0 0 0 r
2 Mabswid
.86277 .19302 Mdot
.039 .916 .04 r
.5 Mabswid
.67949 .14011 m
.86277 .14011 L
s
0 0 0 r
2 Mabswid
.86277 .14011 Mdot
.039 .916 .04 r
.5 Mabswid
.77113 .0872 m
.86277 .0872 L
s
0 0 0 r
2 Mabswid
.86277 .0872 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .19302 m
.97619 .19302 L
s
0 0 0 r
2 Mabswid
.97619 .19302 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .14011 m
.97619 .14011 L
s
0 0 0 r
2 Mabswid
.97619 .14011 Mdot
.039 .916 .04 r
.5 Mabswid
.86277 .0872 m
.97619 .0872 L
s
0 0 0 r
2 Mabswid
.97619 .0872 Mdot
[(ReversionPrism)] .4962 .01116 0 0 Mshowa
0 0 m
1 0 L
1 .46873 L
0 .46873 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{231.688, 108.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 230.688}, {107.562, 0}} -> {-1.69675, -7.03696, \
0.20978, 0.20978}},
  CellTags->"ReversionPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["RhomboidPrism[angle, width, length, options]", "Subsection",
  CellTags->"RhomboidPrism"],

Cell[CellGroupData[{

Cell["?RhomboidPrism", "Input",
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    \("RhomboidalPrism[angle, width, length, options] refers to a six-sided \
prism having asymmetric trapezoidal dimensions on two sides and rectangular \
dimensions on the remaining sides. \n\nRhomboidalPrism is commonly used in \
laser resonators and for beam displacement applications. The angle parameter \
gives the angle of the two inclined entrance and exist faces. RhomboidalPrism \
is normally aligned with its entrance face at x=0 and the exit face \
positioned along the x-axis. However, if Automatic is given for the angle \
parameter then the brewster's angle is used according to the ComponentMedium \
and DesignWaveLength options, and the prism is automatically tilted in the \
x-y plane to maintain a parallel exit beam with the x-axis. \n\nSee also: \
Prism, PentaPrism, Wedge, and PellinBrocaPrism."\)], "Print",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DrawSystem[\ RhomboidPrism[53, 10, 50], PlotType -> TopView]\)], "Input",\

  CellTags->"RhomboidPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .17381 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0861771 0.0165529 0.0869028 0.0165529 [
[ 0 0 0 0 ]
[ 1 .17381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.14854 .00414 m
.02381 .16967 L
.02381 .16967 L
.14854 .00414 L
.14854 .00414 L
s
.85146 .16967 m
.02381 .16967 L
.02381 .16967 L
.85146 .16967 L
.85146 .16967 L
s
.97619 .00414 m
.85146 .16967 L
.85146 .16967 L
.97619 .00414 L
.97619 .00414 L
s
.97619 .00414 m
.14854 .00414 L
.14854 .00414 L
.97619 .00414 L
.97619 .00414 L
s
.14854 .00414 m
.02381 .16967 L
.85146 .16967 L
.97619 .00414 L
.14854 .00414 L
s
.14854 .00414 m
.02381 .16967 L
.85146 .16967 L
.97619 .00414 L
.14854 .00414 L
s
0 0 m
1 0 L
1 .17381 L
0 .17381 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{322.125, 55.9375},
  ImageMargins->{{41, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 321.125}, {54.9375, 0}} -> {-5.6888, -5.25006, \
0.191133, 0.191133}},
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    TagBox[\(DrawSystem[{RhomboidalPrism[53, 10, 50]}, 
        PlotType \[Rule] TopView]\),
      HoldForm]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" RhomboidPrism[Automatic,10,50]", "Input",
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"Move", "[", 
        RowBox[{\(RhomboidPrism[56.6501594034559641`, 10, 50]\), ",", 
          RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
              StyleBox["23.3003188069119371`",
                StyleBoxAutoDelete->True,
                PrintPrecision->16]}], "}"}]}], "]"}],
      HoldForm]], "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DrawSystem[\ RhomboidPrism[Automatic, 10, 50], 
        PlotType -> TopView];\)\)], "Input",
  CellTags->"RhomboidPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47135 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.108962 0.0170305 0.0672632 0.0170305 [
[ 0 0 0 0 ]
[ 1 .47135 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.19411 .01122 m
.02381 .1233 L
.02381 .1233 L
.19411 .01122 L
.19411 .01122 L
s
.80589 .46012 m
.02381 .1233 L
.02381 .1233 L
.80589 .46012 L
.80589 .46012 L
s
.97619 .34804 m
.80589 .46012 L
.80589 .46012 L
.97619 .34804 L
.97619 .34804 L
s
.97619 .34804 m
.19411 .01122 L
.19411 .01122 L
.97619 .34804 L
.97619 .34804 L
s
.19411 .01122 m
.02381 .1233 L
.80589 .46012 L
.97619 .34804 L
.19411 .01122 L
s
.19411 .01122 m
.02381 .1233 L
.80589 .46012 L
.97619 .34804 L
.19411 .01122 L
s
0 0 m
1 0 L
1 .47135 L
0 .47135 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{132, 62.1875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 131}, {61.1875, 0}} -> {-6.66674, -3.94971, \
0.452332, 0.452332}},
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bangle\  = \ 
      ArcTan[\(ModelRefractiveIndex[BK7]\)[{WaveLength ->  .532}]]/
        Degree\)], "Input",
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    \(56.6501594034559641`\)], "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DrawSystem[\ {\n\t\tRay[], \n\t\tMove[RhomboidPrism[Automatic, 10, 50], 
          10], \n\t\tBoundary[100, GraphicDesign -> Off]}, 
      PlotType -> TopView]\)], "Input",
  CellTags->"RhomboidPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .26359 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0376151 0.00952381 [
[.36608 .06595 -12 -4.5 ]
[.36608 .06595 12 4.5 ]
[ 0 0 0 0 ]
[ 1 .26359 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .00628 m
.07143 .06895 L
.07143 .06895 L
.16667 .00628 L
.16667 .00628 L
s
.50878 .25731 m
.07143 .06895 L
.07143 .06895 L
.50878 .25731 L
.50878 .25731 L
s
.60402 .19463 m
.50878 .25731 L
.50878 .25731 L
.60402 .19463 L
.60402 .19463 L
s
.60402 .19463 m
.16667 .00628 L
.16667 .00628 L
.60402 .19463 L
.60402 .19463 L
s
.16667 .00628 m
.07143 .06895 L
.50878 .25731 L
.60402 .19463 L
.16667 .00628 L
s
.16667 .00628 m
.07143 .06895 L
.50878 .25731 L
.60402 .19463 L
.16667 .00628 L
s
.039 .916 .04 r
.02381 .03762 m
.11905 .03762 L
s
0 0 0 r
2 Mabswid
.11905 .03762 Mdot
.039 .916 .04 r
.5 Mabswid
.11905 .03762 m
.5564 .22597 L
s
0 0 0 r
2 Mabswid
.5564 .22597 Mdot
.039 .916 .04 r
.5 Mabswid
.5564 .22597 m
.97619 .22597 L
s
0 0 0 r
2 Mabswid
.97619 .22597 Mdot
[(Rhom)] .36608 .06595 0 0 Mshowa
0 0 m
1 0 L
1 .26359 L
0 .26359 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{364.312, 96},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 363.312}, {95, 0}} -> {-2.92306, -3.94959, 0.291336, \
0.291336}},
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(SingleRay[]\), ",", 
              RowBox[{"Move", "[", 
                
                RowBox[{\(RhomboidPrism[56.6501594034559641`, 10, 50]\), ",", 
                  
                  RowBox[{"{", 
                    RowBox[{
                      StyleBox["10.`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->16], ",", "0", ",", 
                      StyleBox["23.3003188069119371`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->16]}], "}"}]}], "]"}], 
              ",", \(Boundary[{0, \(-50\), \(-50\)}, {100, 50, 
                  50}, {GraphicDesign \[Rule] Off}]\)}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"RhomboidPrism"],

Cell[BoxData[
    \("-3 ray/surface intersections-"\)], "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["RoofPrism[side, options]", "Subsection",
  CellTags->"RoofPrism"],

Cell[CellGroupData[{

Cell["?RoofPrism", "Input",
  CellTags->"RoofPrism"],

Cell[BoxData[
    \("RoofPrism[side, options] refers to a six-sided prism used to invert, \
revert, and deviate an image by 90 degrees. \n\nRoofPrism is generated with \
its entranceface located in the y-z plane and its exit face parallel to the \
x-y plane. If the Centered->True option is specified, RoofPrism is centered \
about the x-axis. If Mirrored->True option is given, two reflectorized \
surfaces are placed on the roof of the prism. RoofPrism is a simplified form \
of the AmiciPrism. See also: DovePrism, Wedge, RhomboidalPrism, AmiciPrism, \
and Prism."\)], "Print",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[RoofPrism]", "Input",
  CellTags->"RoofPrism"],

Cell[BoxData[
    \({Labels \[Rule] "Roof Prism", Mirrored \[Rule] False, 
      Centered \[Rule] True, FullForm \[Rule] False, 
      LabelPositions \[Rule] Automatic, 
      ComponentDescription \[Rule] Automatic, ComponentMedium \[Rule] BK7, 
      Temperature \[Rule] Temperature, Reflectance \[Rule] 100, 
      Transmittance \[Rule] Transmittance, GraphicDesign \[Rule] Automatic, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Off \[Rule] {SurfaceRendering \[Rule] Empty, 
          CrossRendering \[Rule] Empty}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {Fill, Mesh}, 
          CrossRendering \[Rule] Empty}, 
      Mirror \[Rule] {Automatic \[Rule] {SurfaceRendering \[Rule] {{Fill, 
                    Trace}}, EdgeRendering \[Rule] Fill, 
              CrossRendering \[Rule] Empty}, 
          Off \[Rule] {SurfaceRendering \[Rule] Empty, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
              EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}}}\)], "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[RoofPrism]", "Input",
  CellTags->"RoofPrism"],

Cell[BoxData[
    \({Labels \[Rule] "Roof Prism", LabelPositions \[Rule] Automatic, 
      ComponentDescription \[Rule] Automatic, Mirrored \[Rule] False, 
      Centered \[Rule] True, FullForm \[Rule] False, 
      ComponentMedium \[Rule] BK7, Temperature \[Rule] Temperature, 
      Reflectance \[Rule] 100, Transmittance \[Rule] Transmittance, 
      GraphicDesign \[Rule] Automatic, 
      Automatic \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Off \[Rule] {SurfaceRendering \[Rule] Empty, 
          CrossRendering \[Rule] Empty}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          CrossRendering \[Rule] Trace}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {Fill, Mesh}, 
          CrossRendering \[Rule] Empty}, 
      Mirror \[Rule] {Automatic \[Rule] {SurfaceRendering \[Rule] {{Fill, 
                    Trace}}, EdgeRendering \[Rule] Fill, 
              CrossRendering \[Rule] Empty}, 
          Off \[Rule] {SurfaceRendering \[Rule] Empty, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
              EdgeRendering \[Rule] Empty, CrossRendering \[Rule] Empty}, 
          Solid \[Rule] {SurfaceRendering \[Rule] {{Fill, Trace}}, 
              EdgeRendering \[Rule] Empty, 
              CrossRendering \[Rule] Empty}}}\)], "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{CircleOfRays[6,NumberOfRays->8],
Move[RoofPrism[10],3],
Boundary[25,GraphicDesign->Off]},
PlotType->SideView];\
\>", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.057596 0.745149 0.057596 [
[.1966 .74515 -30 -4.5 ]
[.1966 .74515 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1.05833 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.1966 .45717 m
.1966 .8295 L
.1966 1.03313 L
.1966 1.03313 L
.1966 .8295 L
.1966 .45717 L
.1966 .45717 L
s
.40023 .25354 m
.77256 .25354 L
.97619 .25354 L
.97619 .25354 L
.77256 .25354 L
.40023 .25354 L
.40023 .25354 L
s
.1966 .8295 m
.1966 1.03313 L
.40023 1.03313 L
.97619 .45717 L
.97619 .25354 L
.77256 .25354 L
.1966 .8295 L
s
.77256 .25354 m
.97619 .25354 L
.97619 .45717 L
.40023 1.03313 L
.1966 1.03313 L
.1966 .8295 L
.77256 .25354 L
s
.40023 .25354 m
.77256 .25354 L
.1966 .8295 L
.1966 .45717 L
.40023 .25354 L
s
.1966 .45717 m
.1966 .8295 L
.77256 .25354 L
.40023 .25354 L
.1966 .45717 L
s
.97619 .25354 m
.97619 .45717 L
.97619 .25354 L
.97619 .25354 L
s
.1966 1.03313 m
.40023 1.03313 L
.1966 1.03313 L
.1966 1.03313 L
s
.40023 .25354 m
.40023 .25354 L
.1966 .45717 L
.1966 .45717 L
.40023 .25354 L
s
.039 .916 .04 r
.02381 .74515 m
.1966 .74515 L
s
0 0 0 r
2 Mabswid
.1966 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86733 m
.1966 .86733 L
s
0 0 0 r
2 Mabswid
.1966 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .91794 m
.1966 .91794 L
s
0 0 0 r
2 Mabswid
.1966 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86733 m
.1966 .86733 L
s
0 0 0 r
2 Mabswid
.1966 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .74515 m
.1966 .74515 L
s
0 0 0 r
2 Mabswid
.1966 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62297 m
.1966 .62297 L
s
0 0 0 r
2 Mabswid
.1966 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57236 m
.1966 .57236 L
s
0 0 0 r
2 Mabswid
.1966 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62297 m
.1966 .62297 L
s
0 0 0 r
2 Mabswid
.1966 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .74515 m
.44385 .74515 L
s
0 0 0 r
2 Mabswid
.44385 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .86733 m
.39324 .86733 L
s
0 0 0 r
2 Mabswid
.39324 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .91794 m
.51542 .91794 L
s
0 0 0 r
2 Mabswid
.51542 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .86733 m
.39324 .86733 L
s
0 0 0 r
2 Mabswid
.39324 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .74515 m
.44385 .74515 L
s
0 0 0 r
2 Mabswid
.44385 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .62297 m
.6376 .62297 L
s
0 0 0 r
2 Mabswid
.6376 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .57236 m
.861 .57236 L
s
0 0 0 r
2 Mabswid
.861 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .62297 m
.6376 .62297 L
s
0 0 0 r
2 Mabswid
.6376 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.44385 .74515 m
.68821 .50079 L
s
0 0 0 r
2 Mabswid
.68821 .50079 Mdot
.039 .916 .04 r
.5 Mabswid
.39324 .86733 m
.56603 .69454 L
s
0 0 0 r
2 Mabswid
.56603 .69454 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .91794 m
.51542 .91794 L
s
0 0 0 r
2 Mabswid
.51542 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.39324 .86733 m
.56603 .69454 L
s
0 0 0 r
2 Mabswid
.56603 .69454 Mdot
.039 .916 .04 r
.5 Mabswid
.44385 .74515 m
.68821 .50079 L
s
0 0 0 r
2 Mabswid
.68821 .50079 Mdot
.039 .916 .04 r
.5 Mabswid
.6376 .62297 m
.81039 .45018 L
s
0 0 0 r
2 Mabswid
.81039 .45018 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .57236 m
.861 .57236 L
s
0 0 0 r
2 Mabswid
.861 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.6376 .62297 m
.81039 .45018 L
s
0 0 0 r
2 Mabswid
.81039 .45018 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .50079 m
.68821 .25354 L
s
0 0 0 r
2 Mabswid
.68821 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .69454 m
.56603 .25354 L
s
0 0 0 r
2 Mabswid
.56603 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .91794 m
.51542 .25354 L
s
0 0 0 r
2 Mabswid
.51542 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .69454 m
.56603 .25354 L
s
0 0 0 r
2 Mabswid
.56603 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .50079 m
.68821 .25354 L
s
0 0 0 r
2 Mabswid
.68821 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .45018 m
.81039 .25354 L
s
0 0 0 r
2 Mabswid
.81039 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .57236 m
.861 .25354 L
s
0 0 0 r
2 Mabswid
.861 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .45018 m
.81039 .25354 L
s
0 0 0 r
2 Mabswid
.81039 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .25354 m
.68821 .0252 L
s
0 0 0 r
2 Mabswid
.68821 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .25354 m
.56603 .0252 L
s
0 0 0 r
2 Mabswid
.56603 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .25354 m
.51542 .0252 L
s
0 0 0 r
2 Mabswid
.51542 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .25354 m
.56603 .0252 L
s
0 0 0 r
2 Mabswid
.56603 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .25354 m
.68821 .0252 L
s
0 0 0 r
2 Mabswid
.68821 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .25354 m
.81039 .0252 L
s
0 0 0 r
2 Mabswid
.81039 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .25354 m
.861 .0252 L
s
0 0 0 r
2 Mabswid
.861 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .25354 m
.81039 .0252 L
s
0 0 0 r
2 Mabswid
.81039 .0252 Mdot
[(Roof Prism)] .1966 .74515 0 0 Mshowa
0 0 m
1 0 L
1 1.05833 L
0 1.05833 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{204.562, 216.438},
  ImageMargins->{{41, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003<0000f2000`400?l00000o`00003oc03oool0
0<`0oooo003<0?ooo`00c03oool00<`0oooo001X0?ooo`800000203oool2000001L0oooo0P00000G
0?ooo`800000203oool2000001`0oooo001X0?ooo`800000203oool2000001L0oooo0P00000G0?oo
o`800000203oool2000001`0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ
2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0
oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0
oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo
0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`03
00WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00
J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0
oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?oo
o`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?oo
o`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3o
ool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203o
ool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203o
ool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09
jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F
0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J
0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?oo
o`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool0
0`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool0
06P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo
01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:
0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01X0oooo001X0?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0E0?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3oool006P0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00J03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo01X0oooo001X0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3o
ool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool06P3o
ool006P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0
oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`00D@3oool00`00
0000oooo0?ooo`0D0?ooo`0300WZ2P000000oooo00L0oooo00<0000000WZ2P3oool05P3oool00`00
00002NX:0?ooo`0F0?ooo`0300WZ2P000000oooo00L0oooo00<0000000WZ2P3oool05@3oool00`00
0000oooo0?ooo`030?ooo`00D@3ooolG0000000300WZ2P000000000000P0000000<02NX:00000000
00005P0000000`09jPX000000000000E0000000300WZ2P000000000000P0000000<02NX:00000000
00005@0000050?ooo`00D03oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo
001?0?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0F0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool00`3oool004h0oooo00<00000
0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00C@3oool00`000000oooo0?ooo`0H0?oo
o`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?oo
o`030000003oool0oooo00<0oooo001<0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3o
ool00`3oool004/0oooo00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00BP3o
ool00`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3o
ool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0203o
ool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00190?ooo`030000003oool0
oooo01`0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo01@0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool07@3oool00`09
jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01@3oool00`00
0000oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`00
0000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0
oooo00160?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0F0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool00`3oool004D0oooo00<0
00000?ooo`3oool0803oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01H0oooo00<0
2NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00A03oool00`000000oooo0?ooo`0Q
0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool05P3oool01@09jPX0oooo0?ooo`3o
ool0000001<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00130?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`0F0?ooo`0400WZ2P3oool0oooo000001@0oooo00<02NX:0?ooo`3oool0203o
ool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00120?ooo`030000003oool0
oooo02<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0
000001D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0
oooo00<0oooo00110?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0F0?ooo`0300WZ2P000000oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo02D0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01D0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0
oooo000o0?ooo`030000003oool0oooo02H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0E0?ooo`0300000009jPX0oooo01H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo
0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000n0?ooo`030000003oool0oooo02L0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool02NX:01L0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000m
0?ooo`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0C
0?ooo`040000003oool0oooo00WZ2QL0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`0D0?ooo`030000003oool0oooo00<0oooo000l0?ooo`030000003oool0oooo02T0oooo00<02NX:
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`09jPX05`3o
ool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool00`3o
ool003/0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0
oooo0140oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00>P3oool00`00
0000oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000i0?ooo`030000003oool0oooo02`0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0
oooo00<000000?ooo`3oool00`3oool003P0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo
0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo
0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo00P0oooo00<0
2NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01D0oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000f
0?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool00`3oool003D0oooo00<000000?oo
o`3oool0<03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?oo
o`3oool0203oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?oo
o`3oool0503oool00`000000oooo0?ooo`030?ooo`00=03oool00`000000oooo0?ooo`0a0?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
00WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`03
0000003oool0oooo00<0oooo000c0?ooo`030000003oool0oooo0380oooo00<02NX:0?ooo`3oool0
203oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<02NX:0?ooo`3oool0
5@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0
0`3oool00380oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3o
ool0oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00<@3oool0
0`000000oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool0203oool0
0`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo
03D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo
01@0oooo00<000000?ooo`3oool00`3oool002l0oooo00<000000?ooo`3oool0=P3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`09jPX0
oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0503oool00`000000
oooo0?ooo`030?ooo`00;P3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo01D0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo
000]0?ooo`030000003oool0oooo03P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?oo
o`030?ooo`030000003oool0oooo0100oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool00`3oool002`0oooo00<00000
0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:
0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`00:`3oool00`000000oooo0?ooo`0j0?oo
o`0300WZ2P3oool0oooo00P0oooo00D02NX:0?ooo`3oool0oooo0000000D0?ooo`0300WZ2P3oool0
oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0
oooo00<0oooo000Z0?ooo`030000003oool0oooo03/0oooo00<02NX:0?ooo`3oool0203oool01009
jPX0oooo0?ooo`00000E0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0000003oool0203oool0
0`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo
03`0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0000000F0?ooo`0300WZ2P3oool0oooo
01D0oooo00<02NX:0000003oool0203oool00`09jPX0oooo0?ooo`0D0?ooo`030000003oool0oooo
00<0oooo000X0?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
00000?ooo`0F0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0
oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030000003oool0oooo03d0oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
000X0?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool01`3oool00`0000002NX:0?oo
o`0G0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo03d0oooo00<02NX:
0?ooo`3oool01P3oool00`000000oooo00WZ2P0H0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:
0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo000X0?oo
o`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool01@3oool010000000oooo0?ooo`09jPXH
0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo03d0oooo00<02NX:0?oo
o`3oool0103oool01@000000oooo0?ooo`3oool02NX:01P0oooo00<02NX:0?ooo`3oool03`3oool0
0`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00l0oooo00<000000?ooo`3oool0203oool0
02P0oooo00<000000?ooo`3oool0?@3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo
00l0oooo00<02NX:0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000
oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo000X0?ooo`030000003oool0oooo03d0oooo
00D02NX:0?ooo`3oool0oooo000000060?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3o
ool0303oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool002P0oooo00<000000?ooo`3oool0?@3oool01009jPX0oooo0?ooo`0000070?ooo`03
00WZ2P3oool0oooo01D0oooo00<0000000WZ2P3oool0303oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0303oool002P0oooo00<000000?ooo`3oool0
?@3oool00`09jPX0oooo000000080?ooo`0300WZ2P3oool0oooo01D0oooo0P00000<0?ooo`0300WZ
2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`00:03o
ool00`000000oooo0?ooo`0m0?ooo`0300WZ2P000000oooo00P0oooo00<02NX:0?ooo`3oool0503o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool02@3o
ool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo01D0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00:03oool00`00
0000oooo0?ooo`0l0?ooo`0300000009jPX0oooo00T0oooo00<02NX:0?ooo`3oool04P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0@0?ooo`00:03oool00`000000oooo0?ooo`0k0?ooo`030000003oool02NX:00X0
oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01L0
oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00:03oool00`000000oooo
0?ooo`0j0?ooo`040000003oool0oooo00WZ2PX0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`00:03oool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo0?ooo`09
jPX02P3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool06@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo000X0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ
2P3oool0oooo00<0oooo00<000000?ooo`3oool0503oool002P0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool00P3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool0703oool01@09jPX0oooo0?ooo`3oool0000001P0oooo000X
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0M
0?ooo`0400WZ2P3oool0oooo000001T0oooo000X0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0000001X0oooo000X0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0O0?oo
o`0300WZ2P000000oooo01X0oooo000W0?ooo`800000=03oool00`000000oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo01l0oooo00<0000000WZ2P3oool06`3oool000@0oooo8`09jPX00`0000002NX:
00WZ2P2400WZ2P0300000009jPX0oooo01/0oooo000X0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo01`0oooo000X
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`08
0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0P
0?ooo`030000003oool0oooo01d0oooo000X0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0303oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo000X0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo000X0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
3P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo000X0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`080?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX03@3oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo
000X0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0403oool00`09jPX0oooo0?oo
o`080?ooo`0400WZ2P3oool0oooo00WZ2Pd0oooo00<02NX:0?ooo`3oool0803oool00`000000oooo
0?ooo`0R0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<0
2NX:0?ooo`3oool0203oool00`09jPX0oooo00WZ2P0=0?ooo`0300WZ2P3oool0oooo0200oooo00<0
00000?ooo`3oool08`3oool002L0oooo0P00000Z0?ooo`030000003oool0oooo0180oooo00<02NX:
0?ooo`3oool0203oool200WZ2P`0oooo00<0000000WZ2P3oool08@3oool00`000000oooo0?ooo`0T
0?ooo`00103ooolS00WZ2P0300000009jPX02NX:05P02NX:00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0U0?ooo`00:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0
oooo00<02NX:0?ooo`3oool01`3oool200WZ2Rl0oooo00<000000?ooo`3oool09P3oool002P0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`09jPX0;P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo01H0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo0?oo
o`09jPX]0?ooo`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`040?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
;03oool00`000000oooo0?ooo`0Y0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01P0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3o
ool0oooo02T0oooo00<000000?ooo`3oool0:P3oool002P0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo02/0oooo000X0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool06P3oool01@09jPX0oooo0?ooo`3oool02NX:00H0oooo00<02NX:
0?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`00:03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01/0oooo00@02NX:0?ooo`3oool02NX:1`3oool00`09jPX0oooo0?ooo`0V
0?ooo`030000003oool0oooo02d0oooo000X0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0703oool00`09jPX0oooo00WZ2P080?ooo`0300WZ2P3oool0oooo02D0oooo00<000000?oo
o`3oool0;P3oool002P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`80
2NX:2@3oool00`09jPX0oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo000X0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool0oooo02<0oooo00<000000?ooo`3oool0<03oool002P0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0N0?ooo`802NX:2P3oool00`09jPX0oooo0?ooo`0R0?ooo`030000003o
ool0oooo0340oooo000X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool0
0`09jPX0oooo00WZ2P0:0?ooo`0300WZ2P3oool0oooo0240oooo00<000000?ooo`3oool0<P3oool0
02P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`0400WZ2P3oool0oooo
00WZ2PT0oooo00<0000000WZ2P3oool08@3oool00`000000oooo0?ooo`0c0?ooo`00:03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P09
0?ooo`8000008@3oool00`000000oooo0?ooo`0d0?ooo`00:03oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01h0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`070?oo
o`0300WZ2P3oool0oooo01l0oooo00<000000?ooo`3oool0=@3oool002P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0O0?ooo`030000003oool0oooo03H0oooo000X0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`0g0?ooo`00:03o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo00<02NX:0?ooo`3oool01@3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01l0oooo00<000000?ooo`3oool0>03o
ool002P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0O0?ooo`030000003oool0
oooo03T0oooo000X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`09
jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0j0?ooo`00:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0
oooo00<02NX:0?ooo`3oool0203oool01@09jPX0oooo0?ooo`3oool02NX:0240oooo00<000000?oo
o`3oool0>`3oool00140oooo0`0000020?ooo`80000000@0oooo00000000000000000P3oool30000
00040?ooo`0000000000000000<0oooo0`0000030?ooo`P000000P3oool00`000000oooo00000003
000001h0oooo00<02NX:0?ooo`3oool02@3oool01009jPX0oooo0?ooo`09jPXQ0?ooo`030000003o
ool0oooo03`0oooo000B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`030000003oool0000000<0oooo0`0000040?ooo`040000003oool0oooo000000@0
oooo00L000000?ooo`000000oooo0000003oool0000001`0oooo0P0000000`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool02NX:0240oooo00<000000?ooo`3oool0?@3oool000@0oooo3P09jPX01000
00002NX:00WZ2P00000200WZ2P0400000009jPX02NX:00WZ2P8000000`09jPX00`0000002NX:0000
000300WZ2P0300000009jPX00000008000000P09jPX0100000002NX:00WZ2P00000200WZ2P800000
0P09jPX01@0000002NX:00000009jPX0000001`02NX:00<0000000WZ2P3oool0303oool200WZ2R40
oooo00<000000?ooo`3oool0?P3oool00180oooo100000020?ooo`040000003oool0oooo0?ooo`80
00000`3oool00`000000oooo000000040?ooo`8000000P3oool00`000000oooo000000020?ooo`03
0000003oool0000000@0oooo00D000000?ooo`000000oooo0000000[0?ooo`0300WZ2P3oool0oooo
01l0oooo00<000000?ooo`3oool0?`3oool00180oooo00D000000?ooo`3oool0oooo000000020?oo
o`<000000P3oool3000000040?ooo`0000000000000000<0oooo0P0000020?ooo`H000000P3oool8
000002/0oooo0P09jPXP0?ooo`030000003oool0oooo0400oooo000B0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`09jPX07`3oool00`000000oooo0?ooo`11
0?ooo`004@3oool5000000h0oooo0P0000020?ooo`@000001@3oool01@000000oooo0?ooo`3oool0
000002l0oooo00@02NX:0?ooo`3oool02NX:7P3oool00`000000oooo0?ooo`120?ooo`00:03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P0M0?ooo`030000003oool0oooo04<0oooo000X0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01X0oooo00<00000
0?ooo`3oool0A03oool002P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?oo
o`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool06@3oool00`000000oooo0?ooo`150?oo
o`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`0H0?ooo`030000003oool0oooo04H0oooo000X0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool002P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool05P3o
ool00`000000oooo0?ooo`180?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02d0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0
oooo04T0oooo000X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`09
jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<000000?ooo`3oool0BP3oool002P0
oooo00D000000?ooo`3oool0oooo0000000_0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?oo
o`3oool04`3oool00`000000oooo0?ooo`1;0?ooo`00:03oool010000000oooo0?ooo`00000_0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`1<0?oo
o`00:03oool00`000000oooo0000000_0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool04@3oool00`000000oooo0?ooo`1=0?ooo`00:03oool2000002l0oooo00<02NX:0?ooo`3oool0
303oool00`09jPX0oooo0?ooo`0@0?ooo`030000003oool0oooo04h0oooo000X0?ooo`030000003o
ool0oooo02d0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003o
ool0oooo04l0oooo000X0?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool03P3oool0
0`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo0500oooo000X0?ooo`030000003oool0oooo
02/0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0=0?ooo`030000003oool0oooo
0540oooo000X0?ooo`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0
oooo0?ooo`0<0?ooo`030000003oool0oooo0580oooo000X0?ooo`030000003oool0oooo02T0oooo
00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo
000X0?ooo`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?oo
o`0:0?ooo`030000003oool0oooo05@0oooo000X0?ooo`030000003oool0oooo02L0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo05D0oooo000W0?oo
o`8000009P3oool20000000300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0203oool00`00
0000oooo0?ooo`1F0?ooo`00103ooolS00WZ2P0300000009jPX02NX:02D02NX:00<0000000WZ2P3o
ool05P3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo05L0oooo000X0?ooo`030000
003oool0oooo03d0oooo00<02NX:0?ooo`3oool01P3oool00`000000oooo0?ooo`1H0?ooo`00:03o
ool00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool0F@3o
ool002P0oooo00<000000?ooo`3oool0?@3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0
oooo05X0oooo000X0?ooo`030000003oool0oooo03d0oooo00<02NX:0?ooo`3oool00`3oool00`00
0000oooo0?ooo`1K0?ooo`00:03oool00`000000oooo0?ooo`0m0?ooo`0300WZ2P3oool0oooo0080
oooo00<000000?ooo`3oool0G03oool002P0oooo00<000000?ooo`3oool0?@3oool01@09jPX0oooo
0?ooo`3oool0000005l0oooo000X0?ooo`030000003oool0oooo03d0oooo00@02NX:0?ooo`3oool0
0000H03oool002P0oooo00<000000?ooo`3oool0?@3oool00`09jPX0oooo0000001Q0?ooo`009`3o
ool2000003l0oooo00<02NX:0000003oool0H@3oool000@0oooo8`09jPX00`0000002NX:00WZ2P0o
00WZ2P030000003oool0oooo0600oooo000X0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0HP3oool002P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1S0?ooo`00
:03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo06@0oooo000X0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0I@3oool002P0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`1V0?ooo`00:03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
06L0oooo000X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0J03oool002P0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1Y0?ooo`00:03oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo06X0oooo000X0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0J`3oool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1/0?oo
o`00:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo06d0oooo000X0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0KP3oool002P0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1_0?ooo`00:03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0700oooo000X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0L@3oool002P0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1b0?ooo`00:03oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo07<0oooo000X0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0M03oool002P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1e
0?ooo`00:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07H0oooo000X0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0M`3oool002P0oooo:P00001j0?ooo`00c03o
ool00<`0oooo003<0?ooo`00c03oool00<`0oooo0000\
\>"],
  ImageRangeCache->{{{0, 203.562}, {215.438, 0}} -> {-0.413475, -12.9377, \
0.0852932, 0.0852932}},
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13399 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0784237 1.16369 1.11022e-16 1.16369 [
[ 0 0 0 0 ]
[ 1 1.13399 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.13399 L
0 1.13399 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.53814 .55054 m
.41142 .70748 L
s
.32746 .31275 m
.53814 .55054 L
s
.53814 .55054 m
.7779 .47303 L
s
.41142 .70748 m
.18359 .48499 L
s
.40599 .94067 m
.41142 .70748 L
s
0 0 0 r
2 Mabswid
.58603 .32491 Mdot
.039 .916 .04 r
.5 Mabswid
.58895 .45131 m
.58603 .32491 L
s
0 0 0 r
2 Mabswid
.67998 .31842 Mdot
.039 .916 .04 r
.5 Mabswid
.68626 .44496 m
.67998 .31842 L
s
0 0 0 r
2 Mabswid
.51323 .28485 Mdot
.039 .916 .04 r
.5 Mabswid
.51358 .41208 m
.51323 .28485 L
s
0 0 0 r
2 Mabswid
.74444 .26857 Mdot
.039 .916 .04 r
.5 Mabswid
.7532 .39612 m
.74444 .26857 L
s
0 g
.7779 .47303 m
.40599 .94067 L
s
.87585 .36666 m
.7779 .47303 L
s
0 0 0 r
2 Mabswid
.58895 .45131 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .72268 m
.58895 .45131 L
s
.23747 .78339 m
.34681 .75046 L
s
0 0 0 r
2 Mabswid
.68626 .44496 Mdot
.039 .916 .04 r
.5 Mabswid
.69359 .59254 m
.68626 .44496 L
s
0 0 0 r
2 Mabswid
.50332 .2187 Mdot
.039 .916 .04 r
.5 Mabswid
.50332 .34719 m
.50332 .2187 L
s
.25286 .87834 m
.36355 .84679 L
s
0 0 0 r
2 Mabswid
.74102 .20149 Mdot
.039 .916 .04 r
.5 Mabswid
.74992 .33028 m
.74102 .20149 L
s
.18986 .70833 m
.30002 .67353 L
s
0 0 0 r
2 Mabswid
.51358 .41208 Mdot
.039 .916 .04 r
.5 Mabswid
.51477 .84066 m
.51358 .41208 L
s
.34681 .75046 m
.64436 .66084 L
s
0 0 0 r
2 Mabswid
.34681 .75046 Mdot
0 g
.5 Mabswid
.34497 1.03496 m
.40599 .94067 L
s
0 0 0 r
2 Mabswid
.7532 .39612 Mdot
.039 .916 .04 r
.5 Mabswid
.76128 .51364 m
.7532 .39612 L
s
.36355 .84679 m
.52905 .79961 L
s
0 0 0 r
2 Mabswid
.36355 .84679 Mdot
.56665 .16441 Mdot
.039 .916 .04 r
.5 Mabswid
.56905 .29383 m
.56665 .16441 L
s
0 0 0 r
2 Mabswid
.6671 .15699 Mdot
.039 .916 .04 r
.5 Mabswid
.67334 .28653 m
.6671 .15699 L
s
.30002 .67353 m
.76351 .52713 L
s
0 0 0 r
2 Mabswid
.30002 .67353 Mdot
0 g
.5 Mabswid
.87585 .36666 m
.78682 .23281 L
s
.84413 .42551 m
.87585 .36666 L
s
.039 .916 .04 r
.22695 .94252 m
.3405 .91121 L
s
0 0 0 r
2 Mabswid
.69359 .59254 Mdot
.039 .916 .04 r
.5 Mabswid
.39346 .66555 m
.69359 .59254 L
s
0 0 0 r
2 Mabswid
.50332 .34719 Mdot
.039 .916 .04 r
.5 Mabswid
.50331 .62446 m
.50332 .34719 L
s
.13478 .69487 m
.24753 .65868 L
s
0 0 0 r
2 Mabswid
.74992 .33028 Mdot
.039 .916 .04 r
.5 Mabswid
.76351 .52713 m
.74992 .33028 L
s
.52905 .79961 m
.57187 .44555 L
s
0 0 0 r
2 Mabswid
.52905 .79961 Mdot
.76128 .51364 Mdot
.039 .916 .04 r
.5 Mabswid
.55535 .55988 m
.76128 .51364 L
s
.3405 .91121 m
.47496 .87413 L
s
0 0 0 r
2 Mabswid
.3405 .91121 Mdot
0 g
.5 Mabswid
.18359 .48499 m
.32746 .31275 L
s
.58696 .21612 m
.32746 .31275 L
s
.039 .916 .04 r
.64436 .66084 m
.67911 .40628 L
s
0 0 0 r
2 Mabswid
.64436 .66084 Mdot
.039 .916 .04 r
.5 Mabswid
.24753 .65868 m
.55535 .55988 L
s
0 0 0 r
2 Mabswid
.24753 .65868 Mdot
.56905 .29383 Mdot
.039 .916 .04 r
.5 Mabswid
.57187 .44555 m
.56905 .29383 L
s
0 0 0 r
2 Mabswid
.59524 .72268 Mdot
.039 .916 .04 r
.5 Mabswid
.37579 .78273 m
.59524 .72268 L
s
0 0 0 r
2 Mabswid
.67334 .28653 Mdot
.039 .916 .04 r
.5 Mabswid
.67911 .40628 m
.67334 .28653 L
s
0 g
.18359 .48499 m
.16236 .73214 L
s
.039 .916 .04 r
.17174 .93646 m
.28804 .90398 L
s
.10424 .75592 m
.21993 .71977 L
s
.47496 .87413 m
.50331 .62446 L
s
0 0 0 r
2 Mabswid
.47496 .87413 Mdot
0 g
.5 Mabswid
.2187 .93596 m
.34497 1.03496 L
s
.34497 1.03496 m
.42948 .94817 L
s
.039 .916 .04 r
.11947 .85826 m
.2367 .82371 L
s
.28804 .90398 m
.51477 .84066 L
s
0 0 0 r
2 Mabswid
.28804 .90398 Mdot
0 g
.5 Mabswid
.78682 .23281 m
.84413 .42551 L
s
.58696 .21612 m
.78682 .23281 L
s
.039 .916 .04 r
.21993 .71977 m
.39346 .66555 L
s
0 0 0 r
2 Mabswid
.21993 .71977 Mdot
0 g
.5 Mabswid
.84413 .42551 m
.42948 .94817 L
s
.16236 .73214 m
.58696 .21612 L
s
0 0 0 r
2 Mabswid
.67911 .40628 Mdot
.76351 .52713 Mdot
.039 .916 .04 r
.5 Mabswid
.76351 .52713 m
.76351 .52713 L
s
0 0 0 r
2 Mabswid
.76351 .52713 Mdot
.039 .916 .04 r
.5 Mabswid
.2367 .82371 m
.37579 .78273 L
s
0 0 0 r
2 Mabswid
.2367 .82371 Mdot
.57187 .44555 Mdot
.55535 .55988 Mdot
.50331 .62446 Mdot
.39346 .66555 Mdot
.51477 .84066 Mdot
.039 .916 .04 r
.5 Mabswid
.51477 .84066 m
.51477 .84066 L
s
0 0 0 r
2 Mabswid
.51477 .84066 Mdot
.37579 .78273 Mdot
0 g
.5 Mabswid
.42948 .94817 m
.2187 .93596 L
s
.16236 .73214 m
.2187 .93596 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{161.562, 183.125},
  ImageMargins->{{54, 0}, {0, 0}},
  ImageRegion->{{-0.154643, 1.16821}, {-0.136984, 1.06066}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002Q0000]b000`400?l00000o`00003oX@3oool0
0:40oooo002Q0?ooo`00X@3oool00:40oooo001a0?ooo`800000;P3oool005d0oooo0P00000B0?oo
o`0300WZ2P000000oooo02d0oooo001M0?ooo`0300000009jPX0oooo0140oooo00<02NX:0?ooo`3o
ool0;@3oool005h0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0]0?ooo`00GP3o
ool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02d0oooo001N0?ooo`0300WZ2P3oool0
oooo0100oooo00<02NX:0?ooo`3oool0;@3oool005h0oooo00<02NX:0?ooo`3oool0403oool00`09
jPX0oooo0?ooo`0]0?ooo`00GP3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02d0
oooo001N0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0;@3oool005h0oooo00<0
2NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P000000oooo01l0oooo001N
0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02`3oool00`09jPX000000?ooo`0O
0?ooo`00GP3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool07`3oool00540oooo00<0000000WZ2P3oool02P3oool00`09jPX0oooo0?ooo`08000000P0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0O0?ooo`00D@3oool00`0000002NX:
0?ooo`0:0?ooo`<0000000<0oooo0000003oool01@3oool=000000T0oooo00<02NX:0?ooo`3oool0
7`3oool00580oooo00<02NX:0?ooo`3oool01P3oool30000000400WZ2P3oool0oooo00000100oooo
00@02NX:0?ooo`3oool0oooo3@00000N0?ooo`00DP3oool00`09jPX0oooo0?ooo`040?ooo`800000
0`3oool00`09jPX0oooo0000000A0?ooo`0300WZ2P3oool0oooo00X0oooo00@02NX:0?ooo`3oool0
oooo1P00000H0?ooo`00DP3oool01009jPX0oooo0?ooo`3oool3000000D0oooo00<02NX:0000003o
ool04@3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3o
ool05P3oool00580oooo00@02NX:0?ooo`0000000000203oool00`000000oooo0?ooo`0A0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01@3oool2000001L0oooo001A0?ooo`<00000
2@3oool00`0000002NX:0?ooo`0B0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
1P3oool2000001H0oooo001>0?ooo`<0000000<0oooo00WZ2P3oool02@3oool00`0000002NX:0?oo
o`0B0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01P3oool2000001H0oooo001<
0?ooo`800000103oool00`09jPX0oooo0?ooo`070?ooo`030000003oool02NX:01<0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0000001D0oooo00190?oo
o`<000001P3oool00`09jPX0oooo0?ooo`060?ooo`040000003oool0oooo00WZ2Q<0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0000001@0oooo00160?oo
o`<000002@3oool00`09jPX0oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`09jPX04`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300000009jPX0oooo00P0oooo00<000000?ooo`000000503oool0
04@0oooo0P00000<0?ooo`0300WZ2P3oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00X0oooo00<0000000WZ2P3oool0203oool01000
0000oooo0?ooo`00000C0?ooo`00@@3oool3000000h0oooo00<02NX:0?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`080?ooo`040000003oool0oooo00000180oooo000n0?ooo`<000004@3oool200WZ
2P050000003oool0oooo0?ooo`0000001@3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P000000
oooo00/0oooo00<02NX:0?ooo`3oool0203oool010000000oooo0?ooo`00000B0?ooo`00?03oool2
000001@0oooo0P09jPX010000000oooo0?ooo`0000060?ooo`8000004P3oool00`09jPX000000?oo
o`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`00>@3o
ool3000001H0oooo0P09jPX20?ooo`030000003oool0oooo00D0oooo00<02NX:0000003oool04@3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0>0?ooo`00=`3oool2000001T0oooo0P09jPX00`3oool000000?ooo`07
0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`000000403oool003@0oooo0`00000K0?ooo`802NX:00<00000
0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo000a0?oo
o`<000007P3oool200WZ2P030000003oool0oooo00L0oooo00<02NX:0?ooo`3oool04@3oool00`09
jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`00<03oool00`000000oooo0?ooo`0O0?ooo`0300WZ2P000000oooo00T0
oooo00<02NX:0?ooo`3oool04@3oool00`09jPX000000000000<0?ooo`0300WZ2P3oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00<03oool00`000000oooo
0?ooo`0O0?ooo`0300000009jPX0oooo00T0oooo00<02NX:0?ooo`3oool00P00000?0?ooo`0300WZ
2P0000002NX:00`0oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo000_0?ooo`030000003oool0000001l0oooo00<0000000WZ2P09jPX02P3o
ool01@09jPX0oooo0?ooo`09jPX0000000l0oooo00<02NX:0?ooo`09jPX02`3oool2000000/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`00;P3oool01@000000oooo0?oo
o`3oool0000001d0oooo00@000000?ooo`09jPX02NX:2P3oool01009jPX0oooo0?ooo`09jPX@0?oo
o`0300WZ2P3oool02NX:00/0oooo00<0000000WZ2P3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo000]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0200WZ2PX0oooo00@02NX:0?ooo`3oool02NX:403oool00`09
jPX0oooo00WZ2P0<0?ooo`0300WZ2P3oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`00;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool00P09jPX:0?ooo`0400WZ2P3oool0oooo00WZ2Q00oooo00<02NX:0?oo
o`09jPX0303oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool002/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`04
0000003oool0oooo000000802NX:2P3oool01009jPX0oooo0?ooo`09jPX@0?ooo`0300WZ2P3oool0
2NX:00`0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0?ooo`3oool0000000802NX:2P3oool01009jPX0oooo0?ooo`09jPXA0?ooo`802NX:303o
ool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool002X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo0P09jPX:0?ooo`0400WZ2P3oool0oooo00WZ2Q40oooo0P09jPX<0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00:@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool2
00WZ2PX0oooo00@02NX:0?ooo`3oool02NX:4@3oool200WZ2P`0oooo00<02NX:0?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo000X0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`802NX:2P3oool0
1009jPX0oooo0?ooo`09jPXA0?ooo`802NX:303oool200WZ2Pd0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01@3oool200WZ2P/0oooo00<02NX:0?ooo`09jPX04@3oool2
00WZ2Pd0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo000V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`060?ooo`802NX:2`3oool00`09jPX0oooo00WZ2P0A0?ooo`802NX:3@3oool00`09
jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool002D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo0P09jPX;0?ooo`0300WZ2P3oool02NX:0140oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo00/0
oooo00<000000?ooo`3oool0103oool2000000P0oooo000U0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`802NX:2`3oool00`09jPX0oooo
00WZ2P0A0?ooo`0300WZ2P3oool02NX:00`0oooo00<02NX:0?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`8000002@3oool002@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo0P09jPX;0?ooo`0400WZ2P3oool0oooo00WZ2Q00oooo
00<02NX:0?ooo`09jPX02`3oool00`0000002NX:0?ooo`0=0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000090?ooo`008`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02P3oool200WZ2P/0oooo00@02NX:0?ooo`3oool02NX:403oool00`09
jPX0oooo00WZ2P0;0?ooo`0300000009jPX0oooo00d0oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool200WZ2P/0oooo00@02NX:0?ooo`3oool02NX:403oool20000000300WZ2P3o
ool0oooo00X0oooo00<02NX:0?ooo`3oool03@3oool2000000030?ooo`000000oooo00X0oooo000Q
0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`0300WZ2P00
0000000000X0oooo00@02NX:0?ooo`3oool02NX:403oool20000000300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool03@3oool010000000oooo0?ooo`00000;0?ooo`00803oool00`000000oooo
0?ooo`0M0?ooo`040000003oool0oooo000000h0oooo0P09jPX00`000000oooo0?ooo`080?ooo`04
00WZ2P3oool0oooo00WZ2Q00oooo00<02NX:0?ooo`09jPX0303oool00`09jPX0oooo0?ooo`0<0?oo
o`80000000<0oooo0000003oool02`3oool001l0oooo00<000000?ooo`3oool07`3oool2000000l0
oooo0P09jPX;0?ooo`0400WZ2P3oool0oooo00WZ2Q00oooo00<02NX:0?ooo`09jPX0303oool00`09
jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00800000303oool001l0oooo00<000000?ooo`3o
ool07`3oool2000000l0oooo0P09jPX;0?ooo`0400WZ2P3oool0oooo00WZ2Q00oooo00<02NX:0?oo
o`09jPX0303oool00`09jPX0oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool0
01h0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`00000>0?ooo`802NX:2`3oool0
1009jPX0oooo0?ooo`09jPX@0?ooo`0300WZ2P3oool02NX:00`0oooo00<02NX:0?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0
oooo0200oooo00D000000?ooo`3oool0oooo0000000=0?ooo`802NX:2`3oool01009jPX0oooo0?oo
o`09jPX?0?ooo`0400WZ2P3oool0oooo00WZ2P`0oooo0P09jPX90?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0303oool001`0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo0P09jPX;0?ooo`0400WZ2P3oool0oooo00WZ2Pl0
oooo00@02NX:0?ooo`0000000000303oool200WZ2PP0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`006`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool200WZ2PX0oooo0P0000020?ooo`0300WZ2P3oool0oooo00d0
oooo00@02NX:0?ooo`0000002NX:303oool200WZ2PL0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool200WZ2PX0oooo0P0000000`3oool0000000WZ2P0?0?ooo`04
00WZ2P3oool0oooo00WZ2P`0oooo0P09jPX60?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool001X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo0P09jPX;0?ooo`0400WZ2P3oool0000000WZ2Pl0oooo00@02NX:0?oo
o`3oool02NX:303oool200WZ2PD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?
0?ooo`006@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01`3oool200WZ2P/0oooo00@02NX:0?ooo`3oool02NX:3`3oool01009jPX0oooo0?ooo`09
jPX=0?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`00603oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool200WZ2P/0oooo00@02NX:0?ooo`3oool02NX:3`3oool01009jPX0oooo0?oo
o`09jPX=0?ooo`0500WZ2P3oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0A0?ooo`00
5`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool200WZ2PX0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0?0?ooo`0400WZ2P3oool0oooo00WZ
2Pd0oooo00@02NX:00000000000000001@3oool00`000000oooo0?ooo`0B0?ooo`005P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool200WZ
2PX0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0>0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02`3o
ool20000000400WZ2P3oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool001D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo0P09
jPX:0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX03P3oool01@09jPX0oooo0?ooo`3oool02NX:00P0
oooo0`0000020?ooo`0300WZ2P3oool0000000D0oooo00<000000?ooo`3oool04`3oool001@0oooo
0P00000Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool200WZ2PX0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P0>0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool30000
00D0oooo00<02NX:0000003oool0103oool00`000000oooo0?ooo`0D0?ooo`00503oool00`000000
oooo0000000P0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0P09jPX:0?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX03P3oool01@09jPX0oooo0?ooo`3oool02NX:0080oooo0`00
00080?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool05@3oool001@0oooo00@00000
0?ooo`3oool000007P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00802NX:2P3o
ool01@09jPX0oooo0?ooo`3oool02NX:00h0oooo00D02NX:0?ooo`3oool0oooo00WZ2P02000000X0
oooo00<0000000WZ2P3oool00`3oool00`000000oooo0?ooo`0F0?ooo`00503oool01@000000oooo
0?ooo`3oool0000001`0oooo00<000000?ooo`3oool0603oool010000000oooo00WZ2P09jPX:0?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX03P3oool01@09jPX000000000000000002NX:00`0oooo00<0
000000WZ2P09jPX00`3oool00`000000oooo0?ooo`0F0?ooo`00503oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool010000000oooo00WZ2P09
jPX90?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02P3oool20000000500WZ2P3o
ool0oooo0?ooo`09jPX02`3oool010000000oooo00WZ2P09jPX20?ooo`030000003oool0oooo01L0
oooo000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0K0?ooo`0300000009jPX02NX:00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`070?ooo`<000000P3oool01@09jPX0oooo0?ooo`3oool02NX:00X0oooo00L0000000WZ2P09
jPX02NX:0000003oool0000001X0oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0M0?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo00@0oooo0`0000040?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool0103oool500WZ2P80oooo0`00000K0?ooo`004`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool200WZ2PT0oooo00<02NX:0?ooo`3o
ool00P3oool01009jPX0oooo0?ooo`3oool3000000L0oooo00<02NX:0?ooo`3oool00`3oool00`09
jPX0oooo00WZ2P0300WZ2P<0oooo00@000000?ooo`3oool0oooo0P00000L0?ooo`004`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07P3oool200WZ
2P030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0000000000000000:
0?ooo`0400WZ2P3oool0oooo0?ooo`@02NX:1P3oool01@000000oooo0?ooo`3oool02NX:00800000
703oool001<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01l0oooo0P09jPX00`3oool000000?ooo`060?ooo`0300WZ2P3oool0oooo0080000000<0
2NX:0?ooo`3oool02P3oool500WZ2P80oooo00<02NX:0?ooo`3oool0103oool00`000000oooo00WZ
2P0200WZ2P030?ooo`000000oooo01`0oooo000C0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`802NX:0P3oool00`000000oooo0?ooo`04
0?ooo`0300WZ2P00000000000080oooo00<02NX:0?ooo`3oool01P3oool400WZ2P030?ooo`09jPX0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool300WZ2P<0oooo00<000000?ooo`3oool0703oool0
01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0240oooo0P09jPX30?ooo`030000003oool0oooo00<0000000<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`020?ooo`@02NX:1@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo
00<02NX:1@3oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool200WZ2P@0oooo0P0000020?ooo`03
00WZ2P3oool0oooo00<0oooo1@09jPX90?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPX20?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool001<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo0P09jPX40?ooo`060000
003oool0oooo0?ooo`09jPX0oooo1@09jPX=0?ooo`0300WZ2P3oool02NX:00@02NX:0`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo000C0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`802NX:0`3oool010000000
oooo0?ooo`09jPX20000000300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02P3oool300WZ
2P@0oooo00@02NX:0?ooo`3oool000001@3oool00`000000oooo0?ooo`0O0?ooo`004`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool200WZ
2P80oooo00D0000000WZ2P09jPX02NX:0?ooo`02000000D0oooo00<02NX:0?ooo`3oool01`3oool4
00WZ2PH0oooo00<02NX:0?ooo`0000001@3oool00`000000oooo0?ooo`0P0?ooo`004`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool500WZ
2PD0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`<02NX:0`3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P000000oooo00@0oooo00<000000?ooo`3oool08@3oool001<0
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000W0?ooo`<02NX:00<000000?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@02NX:1P3oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P000000oooo00<0oooo00<000000?ooo`3oool08P3oool001<0
oooo00<000000?ooo`3oool04@3oool2000002D0oooo0`09jPX0103oool02NX:00WZ2P0000070?oo
o`0300WZ2P3oool0oooo00<0oooo0`09jPX:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?oo
o`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`004P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0200oooo0`09jPX40?ooo`802NX:1`3oool01009jPX0oooo0?ooo`3oool400WZ
2P`0oooo00<02NX:0?ooo`3oool00`3oool00`0000002NX:0?ooo`030?ooo`030000003oool0oooo
02<0oooo000B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000007@3oool400WZ2PL0
oooo0P09jPX70?ooo`@02NX:103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0080
oooo0`09jPX010000000oooo0?ooo`00000V0?ooo`004P3oool00`000000oooo0?ooo`0A0?ooo`04
0000003oool0oooo0?ooo`800000603oool300WZ2PX0oooo00<0000000WZ2P09jPX01@3oool300WZ
2PL0oooo00<02NX:0?ooo`3oool02@3oool500WZ2P80oooo0P0000000`3oool000000?ooo`0V0?oo
o`004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04P3oool300WZ2P`0oooo00D000000?ooo`09jPX02NX:0?ooo`0400WZ2P80oooo00<02NX:0?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`060?ooo`@02NX:0`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02H0oooo000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0>0?ooo`<02NX:3`3oool00`000000oooo00WZ2P0200WZ2PH0
oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo0?ooo`3oool500WZ2P80oooo00D02NX:0?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`<02NX:4@3oool500WZ
2PL0oooo00<02NX:0?ooo`3oool01@3oool400WZ2PL0oooo00@02NX:0?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool300WZ2Q40oooo0`09jPX30?ooo`802NX:1`3oool01009
jPX0oooo0?ooo`3oool500WZ2PX0oooo00<02NX:0?ooo`0000001@3oool00`000000oooo0?ooo`0X
0?ooo`004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool300WZ2Q40oooo0`09jPX00`3oool000000?ooo`020?ooo`80000000<02NX:0?oo
o`3oool01@3oool400WZ2P@0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo000000040?oo
o`030000003oool0oooo02T0oooo000B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool400WZ2Q00oooo1009jPX30?ooo`030000003oool0oooo0080oooo0P0000001009jPX0
oooo0?ooo`3oool400WZ2PP0oooo00<02NX:0?ooo`3oool0203oool00`09jPX000000?ooo`040?oo
o`030000003oool0oooo02T0oooo000B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool300WZ2P030?ooo`000000oooo00h0oooo0`09jPX70?ooo`030000003oool0oooo00<0
oooo1@09jPX30?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo000B0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool300WZ2PD0oooo00<000000?ooo`3oool02@3oool300WZ2PT0oooo
00@000000?ooo`3oool0oooo1009jPX00`3oool02NX:0?ooo`040?ooo`0300WZ2P3oool0oooo00H0
oooo00<02NX:0?ooo`3oool01`3oool00`0000002NX:0?ooo`030?ooo`030000003oool0oooo02/0
oooo000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool300WZ2PT0oooo
00<000000?ooo`3oool01@3oool300WZ2P/0oooo1@09jPX30?ooo`0300WZ2P3oool02NX:00D0oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`060?ooo`0300000009jPX0oooo00<0oooo
00<000000?ooo`3oool0;03oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`<02NX:3@3oool00`000000oooo0?ooo`0400WZ2PX0oooo1009jPX70?ooo`0400WZ2P3o
ool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`060?ooo`030000
0009jPX0oooo0080oooo00<000000?ooo`3oool0;@3oool00140oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`<02NX:403oool300WZ2PX0oooo1009jPX20?ooo`030000003o
ool0oooo00H0oooo00@02NX:0?ooo`3oool02NX:1@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo00D0oooo00<000000?ooo`09jPX00`3oool00`000000oooo0?ooo`0]0?ooo`004@3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00WZ2P800000403oool300WZ2P80oooo
00<000000?ooo`3oool0103oool400WZ2PH0oooo00<000000?ooo`3oool01P3oool01009jPX0oooo
0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool010000000
2NX:0000000000020?ooo`030000003oool0oooo02h0oooo000A0?ooo`030000003oool0oooo00L0
oooo00D0000000WZ2P09jPX02NX:0?ooo`02000000d0oooo0`09jPX60?ooo`040000003oool0oooo
00WZ2P8000002@3oool00`000000oooo0?ooo`070?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:00D0oooo000000000000oooo
0000000a0?ooo`004@3oool00`000000oooo0?ooo`050?ooo`0300WZ2P0000002NX:00h0oooo0P00
000300WZ2PT0oooo0`09jPX00`3oool00000000000080?ooo`030000003oool0oooo00P0oooo00@0
2NX:0?ooo`3oool02NX:103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00802NX:
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`004@3oool00`000000oooo0?oo
o`020?ooo`<02NX:00<0oooo0000003oool03@3oool00`09jPX00000000000090?ooo`<02NX:0P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00@02NX:0?ooo`3oool02NX:
103oool00`09jPX0oooo0?ooo`060?ooo`<02NX:0`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0340oooo000A0?ooo`030000003oool02NX:00802NX:0`3oool00`000000oooo0?oo
o`0:0?ooo`<02NX:2@3oool300WZ2PH0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`0400WZ2P3oool0oooo00WZ2P@0oooo00<02NX:0?ooo`3oool00P3oool400WZ2P030?oo
o`09jPX0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`00403o
ool00`09jPX0000000WZ2P050?ooo`030000003oool0oooo00P0oooo0`09jPX90?ooo`<02NX:2P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00@02NX:0?ooo`3oool02NX:
103oool00`09jPX0oooo00WZ2P0200WZ2PD0oooo00@02NX:0?ooo`3oool000001@3oool00`000000
oooo0?ooo`0b0?ooo`003@3oool300WZ2P030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0
1P3oool300WZ2PT0oooo0`09jPX>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo0`09jPX80?ooo`0300WZ2P3oool0000000D0
oooo00<000000?ooo`3oool0<`3oool000/0oooo0P09jPX40?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool300WZ2PT0oooo0`09jPXB0?ooo`050000003oool0oooo0?ooo`00
00003@3oool01009jPX0oooo0?ooo`3oool400WZ2P030?ooo`09jPX0oooo00P0oooo00<02NX:0000
003oool0103oool00`000000oooo0?ooo`0d0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
00@0oooo0`09jPX90?ooo`<02NX:5P3oool00`000000oooo0000000>0?ooo`0300WZ2P3oool02NX:
00802NX:103oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P000000oooo00<0oooo00<000000?oo
o`3oool0=@3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo00WZ2P0200WZ2PT0
oooo0`09jPXJ0?ooo`030000003oool0oooo00/0oooo1009jPX20?ooo`0500WZ2P3oool0oooo0?oo
o`09jPX02P3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo000@0?ooo`05
0000003oool0oooo0?ooo`0000000P09jPX90?ooo`<02NX:7@3oool00`000000oooo0?ooo`080?oo
o`<02NX:0P3oool01@09jPX0oooo0?ooo`3oool02NX:00<0oooo00<02NX:0?ooo`3oool01`3oool0
0`0000002NX:0?ooo`030?ooo`030000003oool0oooo03H0oooo000@0?ooo`040000003oool0oooo
000000H0oooo0P000000103oool02NX:00WZ2P09jPXP0?ooo`030000003oool0oooo00D0oooo0`09
jPX50?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`060?ooo`030000
003oool02NX:00<0oooo00<000000?ooo`3oool0=`3oool00100oooo00<000000?ooo`0000001P3o
ool01009jPX0000000000009jPXS0?ooo`030000003oool0oooo0080oooo0`09jPX80?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`060?ooo`<02NX:00<000000?ooo`00
0000>P3oool00100oooo0P0000040?ooo`<02NX:9`3oool00`0000002NX:00WZ2P0200WZ2P/0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPX20?ooo`<0
0000>`3oool00100oooo00<000000?ooo`3oool00`09jPXX0?ooo`<02NX:3P3oool00`09jPX0oooo
0?ooo`020?ooo`0600WZ2P3oool0oooo0?ooo`09jPX0oooo1009jPX00`3oool000000?ooo`040?oo
o`030000003oool0oooo03T0oooo000@0?ooo`0300000009jPX02NX:02P0oooo0`09jPX20?ooo`03
0000003oool0oooo00`0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0300WZ2P@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`003@3oool300WZ2P030000
003oool0oooo02D0oooo0`09jPX50?ooo`030000003oool0oooo00`0oooo00@02NX:0?ooo`3oool0
oooo1009jPX00`3oool02NX:0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0>`3oool000X0oooo0`09jPX40?ooo`030000003oool0oooo01l0oooo0P00000300WZ2PP0oooo
00<000000?ooo`3oool0303oool400WZ2P050?ooo`09jPX0oooo0?ooo`09jPX01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03`0oooo00070?ooo`<02NX:1`3oool00`000000oooo
0?ooo`0M0?ooo`802NX:0P00000;0?ooo`030000003oool0oooo00T0oooo1009jPX40?ooo`0400WZ
2P3oool0oooo00WZ2P@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00
1@3oool200WZ2PX0oooo00<000000?ooo`3oool06P3oool300WZ2Pl0oooo00<000000?ooo`3oool0
1P3oool300WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool01009jPX0oooo0?ooo`09jPX30?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool00180oooo00<000000?ooo`3oool0
5@3oool400WZ2Q80oooo00<000000?ooo`3oool00P3oool400WZ2PH0oooo00<02NX:0?ooo`3oool0
0P3oool01009jPX0oooo0?ooo`09jPX20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0?P3oool00180oooo00<000000?ooo`3oool04P3oool300WZ2QH0oooo00<000000?ooo`09jPX0
0P09jPX:0?ooo`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3oool02NX:0?ooo`0000050?oo
o`030000003oool0oooo03l0oooo000B0?ooo`030000003oool0oooo00h0oooo1009jPXG0?ooo`@0
2NX:3@3oool00`09jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0oooo00WZ2P3oool00000103oool0
0`000000oooo0?ooo`100?ooo`004P3oool00`000000oooo0?ooo`0;0?ooo`<02NX:5@3oool20000
00040?ooo`09jPX02NX:00WZ2P80oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`03
0?ooo`0500WZ2P3oool0oooo00WZ2P0000001@3oool00`000000oooo0?ooo`100?ooo`004`3oool0
0`000000oooo0?ooo`080?ooo`802NX:5`3oool01009jPX0000000000009jPX50?ooo`030000003o
ool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool01009jPX0oooo00WZ2P0000050?ooo`030000
003oool0oooo0440oooo000C0?ooo`030000003oool0oooo01h0oooo0`09jPX90?ooo`030000003o
ool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ2P050?ooo`030000003o
ool0oooo0480oooo000C0?ooo`030000003oool0oooo01/0oooo0`09jPX<0?ooo`030000003oool0
oooo00/0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0000000WZ2P040?ooo`030000003oool0
oooo04<0oooo000D0?ooo`030000003oool0oooo01H0oooo1009jPX?0?ooo`030000003oool0oooo
00/0oooo00<02NX:0?ooo`3oool00`3oool200WZ2P8000000P3oool00`000000oooo0?ooo`140?oo
o`00503oool00`000000oooo0?ooo`0C0?ooo`<02NX:4`3oool00`000000oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00@02NX:00<0oooo0000000000000P3oool00`000000oooo0?ooo`140?ooo`00
503oool00`000000oooo0?ooo`0?0?ooo`@02NX:5P3oool00`000000oooo0?ooo`0:0?ooo`@02NX:
0P3oool00`0000002NX:0?ooo`030?ooo`030000003oool0oooo04D0oooo000D0?ooo`030000003o
ool0oooo00`0oooo0`09jPXJ0?ooo`030000003oool0oooo00L0oooo0`09jPX00`3oool02NX:0?oo
o`020?ooo`030000003oool02NX:00<0oooo00<000000?ooo`3oool0AP3oool001D0oooo00<00000
0?ooo`3oool01P3oool2000000<02NX:7@3oool00`000000oooo0?ooo`030?ooo`@02NX:0`3oool0
0`09jPX0oooo0?ooo`020?ooo`030000003oool02NX:0080oooo00<000000?ooo`3oool0A`3oool0
01D0oooo00<000000?ooo`3oool0103oool200WZ2P8000007`3oool010000000oooo0?ooo`3oool3
00WZ2PL0oooo00D02NX:0?ooo`3oool0oooo000000020?ooo`0300WZ2P3oool0000004X0oooo000E
0?ooo`030000003oool0oooo00@02NX:8`3oool0100000002NX:00WZ2P09jPX:0?ooo`0400WZ2P3o
ool0oooo000000<0oooo00<02NX:0?ooo`000000BP3oool001D0oooo00<02NX:00000009jPX0903o
ool400WZ2Pd0oooo00<02NX:0?ooo`000000103oool00`09jPX000000?ooo`1:0?ooo`004@3oool4
00WZ2P030?ooo`000000oooo0240oooo0`09jPX30?ooo`030000003oool0oooo00/0oooo00<02NX:
0000003oool00P3oool00`09jPX000000000001<0?ooo`003@3oool400WZ2PD0oooo00<000000?oo
o`3oool0703oool01009jPX0000000000009jPX60?ooo`030000003oool0oooo00/0oooo1@09jPX0
0`3oool000000000001<0?ooo`002P3oool300WZ2PT0oooo00<000000?ooo`3oool0603oool400WZ
2P030?ooo`000000000000L0oooo00<000000?ooo`3oool02@3oool300WZ2P@0oooo00<000000?oo
o`3oool0C03oool000P0oooo0P09jPX=0?ooo`030000003oool0oooo01@0oooo0`09jPX>0?ooo`03
0000003oool0oooo00D0oooo1009jPX00`3oool0000000WZ2P040?ooo`030000003oool0oooo04`0
oooo000G0?ooo`030000003oool0oooo0100oooo1009jPXA0?ooo`040000003oool0oooo0?ooo`@0
2NX:103oool00`0000002NX:0?ooo`030?ooo`030000003oool0oooo04d0oooo000G0?ooo`030000
003oool0oooo00`0oooo1009jPXE0?ooo`0400000009jPX02NX:00WZ2PL0oooo00<000000?ooo`09
jPX00`3oool00`000000oooo0?ooo`1>0?ooo`005`3oool00`000000oooo0?ooo`090?ooo`<02NX:
5P3oool400WZ2PX0oooo00H000000?ooo`00000000000?ooo`00001A0?ooo`00603oool00`000000
oooo0?ooo`060?ooo`802NX:5@3oool400WZ2P<0oooo00<000000?ooo`3oool01`3oool00`000000
2NX:00WZ2P0300000580oooo000H0?ooo`030000003oool0oooo01X0oooo0`09jPX70?ooo`030000
003oool0oooo00@0oooo1009jPX40?ooo`030000003oool0oooo0500oooo000H0?ooo`030000003o
ool0oooo01H0oooo1009jPX:0?ooo`040000003oool0oooo0?ooo`<02NX:00<0oooo0000003oool0
103oool00`000000oooo0?ooo`1A0?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@02NX:3P3o
ool400WZ2P<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`006@3oool0
0`000000oooo0?ooo`0>0?ooo`<02NX:3P3oool400WZ2P030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?ooo`006@3oool00`000000oooo0?ooo`0:0?oo
o`802NX:0P00000>0?ooo`<02NX:103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0D`3oool001T0oooo00<000000?ooo`3oool01`3oool300WZ2P80
oooo0P0000080?ooo`8000001009jPX70?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1D0?ooo`006P3oool00`000000oooo0?ooo`030?ooo`<02NX:
3@3oool200WZ2P8000002`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool0E@3oool001X0oooo00<000000?ooo`3oool00`09jPX<0?ooo`@02NX:3`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0EP3oool001X0oooo00<0000000WZ2P09jPX0
303oool300WZ2Q<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1G0?ooo`00
5`3oool300WZ2P030?ooo`000000oooo00P0oooo1009jPXF0?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool0E`3oool001@0oooo0`09jPX40?ooo`P000000P09jPXJ0?ooo`8000001@3o
ool00`000000oooo0?ooo`1H0?ooo`004P3oool200WZ2PT0oooo00@0000000WZ2P09jPX02NX:0P3o
ool=000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1I0?ooo`00703oool2
00WZ2P030000003oool0oooo00l0oooo3@0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0FP3oool001l0oooo00<000000?ooo`3oool06`3oool7000005d0oooo000P0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
8@3oool2000001X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1L0?ooo`008`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G@3o
ool002@0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000600oooo000U
0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`009P3oool0
0`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`000000HP3oool002L0oooo0P00000A
0?ooo`040000003oool0oooo000006<0oooo000Y0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool00000I03oool002X0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00
001U0?ooo`00:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000006H0oooo000/0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`000000I`3oool002d0oooo0P0000070?ooo`03
0000003oool0000006P0oooo000_0?ooo`030000003oool0oooo00@0oooo0P00001Y0?ooo`00<03o
ool00`000000oooo0?ooo`020?ooo`800000JP3oool00340oooo00D000000?ooo`3oool0oooo0000
001[0?ooo`00<P3oool00`000000oooo0000001/0?ooo`00<`3oool00`000000oooo0?ooo`1[0?oo
o`00X@3oool00:40oooo002Q0?ooo`00X@3oool00:40oooo002Q0?ooo`00X@3oool00001\
\>"],
  ImageRangeCache->{{{-24.9375, 187.688}, {207.188, -11.0625}} -> {0.13372, \
-0.049399, 0.00446501, 0.00446501}},
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[RoofPrism[10,Mirrored->True]]", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.09311 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0608473 1.14433 -1.11022e-16 1.14433 [
[ 0 0 0 0 ]
[ 1 1.09311 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09311 L
0 1.09311 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.49101 .48619 m
.35194 .65685 L
s
.57119 .63749 m .86058 .27555 L .75207 .39839 L 0 0 0 r
F
.57119 .63749 m .75207 .39839 L .3403 .91287 L F
0 g
.49101 .48619 m
.75207 .39839 L
s
.57119 .63749 m .3403 .91287 L .26507 1.02034 L 0 0 0 r
F
0 g
.3403 .91287 m
.35194 .65685 L
s
.3403 .91287 m
.75207 .39839 L
s
.57119 .63749 m .82606 .3335 L .86058 .27555 L 0 0 0 r
F
0 g
.75207 .39839 m
.86058 .27555 L
s
.57119 .63749 m .35414 .9244 L .82606 .3335 L 0 0 0 r
F
0 g
.24828 .21223 m
.49101 .48619 L
s
.57119 .63749 m .26507 1.02034 L .35414 .9244 L 0 0 0 r
F
0 g
.08548 .40348 m
.35194 .65685 L
s
.26507 1.02034 m
.3403 .91287 L
s
.08548 .40348 m
.24828 .21223 L
s
.44687 .50184 m .76142 .11698 L .82606 .3335 L .729 .576 .683 r
F
.44687 .50184 m .53573 .09688 L .76142 .11698 L F
0 g
.76142 .11698 m
.86058 .27555 L
s
.44687 .50184 m .82606 .3335 L .35414 .9244 L .729 .576 .683 r
F
0 g
.76142 .11698 m
.82606 .3335 L
s
.82606 .3335 m
.86058 .27555 L
s
.44687 .50184 m .04951 .67824 L .53573 .09688 L .729 .576 .683 r
F
0 g
.53573 .09688 m
.76142 .11698 L
s
.24828 .21223 m
.53573 .09688 L
s
.44687 .50184 m .11271 .91068 L .04951 .67824 L .729 .576 .683 r
F
0 g
.04951 .67824 m
.08548 .40348 L
s
.44687 .50184 m .35414 .9244 L .11271 .91068 L .729 .576 .683 r
F
0 g
.11271 .91068 m
.26507 1.02034 L
s
.04951 .67824 m
.53573 .09688 L
s
.35414 .9244 m
.82606 .3335 L
s
.26507 1.02034 m
.35414 .9244 L
s
.11271 .91068 m
.35414 .9244 L
s
.04951 .67824 m
.11271 .91068 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{157.438, 172.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002M0000[2000`400?l00000o`00003oW@3oool0
09d0oooo002M0?ooo`00W@3oool009d0oooo002M0?ooo`00W@3oool009d0oooo002M0?ooo`00W@3o
ool009d0oooo002M0?ooo`00W@3oool009d0oooo002M0?ooo`00W@3oool00580oooo200000130?oo
o`00C`3oool3000000030?ooo`000000^Y>^00D0^Y>^3000000g0?ooo`00C@3oool2000000<0oooo
00<000000;ZC[P2jTjh04@2jTjh<000002/0oooo001:0?ooo`<00000103oool00`000000^Y>^0;ZC
[P0N0;ZC[PH000009@3oool004P0oooo0P0000060?ooo`030000002jTjh0^Y>^02@0^Y>^00<00000
0?ooo`3oool08`3oool004D0oooo0`0000070?ooo`030000002jTjh0^Y>^02D0^Y>^0P00000T0?oo
o`00@`3oool2000000T0oooo00<000000;ZC[P2jTjh09`2jTjh2000002<0oooo00100?ooo`<00000
2`3oool00`000000^Y>^0;ZC[P0W0;ZC[P8000008`3oool003h0oooo0P00000=0?ooo`030000002j
Tjh0^Y>^02P0^Y>^00<000000?ooo`0000008P3oool003/0oooo0`00000>0?ooo`030000002jTjh0
^Y>^02X0^Y>^0P00000R0?ooo`00>@3oool200000100oooo00<000000;ZC[P2jTjh0:`2jTjh00`00
0000oooo0000000Q0?ooo`00=P3oool300000140oooo00<000000;ZC[P2jTjh0;02jTjh010000000
oooo0?ooo`00000P0?ooo`00=03oool2000001<0oooo00<000000;ZC[P2jTjh0;P2jTjh00`000000
oooo0000000P0?ooo`00<@3oool3000001D0oooo00<000000;ZC[P2jTjh0;P2jTjh010000000oooo
0?ooo`00000O0?ooo`00;`3oool2000001L0oooo00<000000;ZC[P2jTjh0;`2jTjh010000000oooo
0?ooo`00000O0?ooo`00;03oool3000001P0oooo00<000000;ZC[P2jTjh0<02jTjh01@000000oooo
0?ooo`3oool0000001h0oooo000Z0?ooo`8000006P3oool00`000000^Y>^0;ZC[P0b0;ZC[P050000
003oool0oooo0?ooo`0000007@3oool002L0oooo0`00000K0?ooo`030000002jTjh0^Y>^03<0^Y>^
00D000000?ooo`3oool0oooo0000000M0?ooo`009P3oool00`000000oooo0?ooo`0K0?ooo`030000
002jTjh0^Y>^03@0^Y>^00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`009P3o
ool00`000000oooo0?ooo`0K0?ooo`030000002jTjh0^Y>^03D0^Y>^00D000000?ooo`3oool0oooo
0000000L0?ooo`009@3oool00`000000oooo0000000K0?ooo`030000002jTjh0^Y>^03H0^Y>^00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`00903oool01@000000oooo0?ooo`3o
ool0000001T0oooo00<000000;ZC[P2jTjh0=`2jTjh00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01P0oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool0
0`000000^Y>^0;ZC[P0h0;ZC[P030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool0
0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000002jTjh0^Y>^
03X0^Y>^00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`008@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000;ZC[P2jTjh0>`2jTjh00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo000Q0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0403oool00`000000^Y>^0;ZC[P0k0;ZC[P030000003oool0oooo00@0oooo
00<000000?ooo`3oool05P3oool00200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0>0?ooo`030000002jTjh0^Y>^03d0^Y>^00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0;ZC[P2jTjh0?P2jTjh00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo000N0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000^Y>^0;ZC[P0o0;ZC
[P030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool001d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`090?ooo`030000002jTjh0^Y>^0440^Y>^00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0D0?ooo`00703oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00L0oooo00<000000;ZC[P2jTjh0@P2jTjh00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01D0oooo000L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3o
ool00`000000^Y>^0;ZC[P120;ZC[P030000003oool0oooo0080oooo0P00000G0?ooo`006`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000;ZC[P2jTjh0@`2jTjh0
10000000oooo0?ooo`3oool2000001P0oooo000J0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool00P3oool00`000000^Y>^0;ZC[P150;ZC[P040000003oool00000000001T0oooo000I
0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool00000B02jTjh4000001T0oooo000H
0?ooo`030000003oool0oooo01X0oooo0P0000190;ZC[P<000006P3oool001L0oooo00<000000?oo
o`3oool06`3oool00`000000^Y>^0;ZC[P190;ZC[P8000006P3oool001L0oooo00<000000?ooo`3o
ool06`3oool00`000000^Y>^0;ZC[P190;ZC[P030000003oool0oooo01T0oooo000F0?ooo`030000
003oool0oooo01/0oooo00<000000;ZC[P2jTjh0BP2jTjh00`000000oooo0?ooo`0I0?ooo`005@3o
ool00`000000oooo0?ooo`0K0?ooo`030000002jTjh0^Y>^04X0^Y>^00<000000?ooo`3oool06P3o
ool001@0oooo00<000000?ooo`3oool06`3oool00`000000^Y>^0;ZC[P1:0;ZC[P030000003oool0
oooo01/0oooo000C0?ooo`030000003oool0oooo01/0oooo00<000000;ZC[P2jTjh0BP2jTjh00`00
0000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo0?ooo`0K0?ooo`030000002jTjh0^Y>^04X0
^Y>^00<000000?ooo`3oool07@3oool00180oooo00<000000?ooo`3oool06`3oool00`000000^Y>^
0;ZC[P1:0;ZC[P030000003oool0oooo01d0oooo000A0?ooo`030000003oool0oooo01/0oooo00<0
00000;ZC[P2jTjh0BP2jTjh00`000000oooo0?ooo`0N0?ooo`00403oool00`000000oooo0?ooo`0K
0?ooo`030000002jTjh0^Y>^04X0^Y>^00<000000?ooo`3oool07`3oool000l0oooo00<000000?oo
o`3oool06`3oool00`000000^Y>^0;ZC[P1:0;ZC[P030000003oool0oooo0200oooo000>0?ooo`03
0000003oool0oooo01/0oooo00<000000;ZC[P2jTjh0BP2jTjh00`000000oooo0?ooo`0Q0?ooo`00
3@3oool2000001`0oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?ooo`0Q0?ooo`003@3o
ool00`000000oooo0000000J0?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?ooo`3oool08P3o
ool000d0oooo00@000000?ooo`3oool000006@3oool00`000000^Y>^0;ZC[P1:0;ZC[P030000003o
ool0oooo02<0oooo000=0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000^Y>^0;ZC
[P1:0;ZC[P030000003oool0oooo02@0oooo000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04`3oool00`000000^Y>^0;ZC[P1:0;ZC[P030000003oool0oooo02D0oooo000<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000^Y>^0;ZC[P1;0;ZC
[P030000003oool0oooo02D0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03`3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo02H0oooo000<0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000
003oool0oooo02L0oooo000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303o
ool00`000000^Y>^0;ZC[P1:0;ZC[P030000003oool0oooo02P0oooo000<0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000^Y>^0;ZC[P1:0;ZC[P030000003oool0
oooo02T0oooo000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo02T0oooo000<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01P3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo02X0
oooo000;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000^Y>^
0;ZC[P1;0;ZC[P030000003oool0oooo02/0oooo000;0?ooo`030000003oool0oooo00d0oooo0P00
00030?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?ooo`3oool0;03oool000/0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00001<0;ZC[P030000003oool0oooo02d0oooo000;
0?ooo`030000003oool0oooo0100oooo0P00001<0;ZC[P030000003oool0oooo02h0oooo000;0?oo
o`030000003oool0oooo0100oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?ooo`0^0?oo
o`002`3oool00`000000oooo0?ooo`0?0?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?ooo`3o
ool0;`3oool000/0oooo00<000000?ooo`3oool03P3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000
003oool0oooo0300oooo000:0?ooo`030000003oool0oooo00h0oooo00<000000;ZC[P2jTjh0B`2j
Tjh00`000000oooo0?ooo`0a0?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`030000002jTjh0
^Y>^04X0^Y>^00<000000?ooo`3oool0<P3oool000X0oooo00<000000?ooo`3oool03@3oool00`00
0000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo0380oooo000:0?ooo`030000003oool0oooo00`0
oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?ooo`0c0?ooo`002P3oool00`000000oooo
0?ooo`0;0?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?ooo`3oool0=03oool000X0oooo00<0
00000?ooo`3oool02P3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo03D0oooo000:
0?ooo`030000003oool0oooo00T0oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?ooo`0f
0?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?oo
o`3oool0=P3oool000T0oooo00<000000?ooo`3oool02@3oool00`000000^Y>^0;ZC[P1;0;ZC[P03
0000003oool0oooo03L0oooo00090?ooo`030000003oool0oooo00P0oooo00<000000;ZC[P2jTjh0
B`2jTjh00`000000oooo0?ooo`0h0?ooo`002@3oool00`000000oooo0?ooo`070?ooo`030000002j
Tjh0^Y>^04/0^Y>^00<000000?ooo`3oool0>@3oool000T0oooo00<000000?ooo`3oool01P3oool0
0`000000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo03X0oooo00090?ooo`030000003oool0oooo
00D0oooo00<000000;ZC[P2jTjh0C02jTjh00`000000oooo0?ooo`0j0?ooo`002@3oool00`000000
oooo0?ooo`050?ooo`030000002jTjh0^Y>^04/0^Y>^00<000000?ooo`3oool0>`3oool000P0oooo
00<000000?ooo`3oool01@3oool00`000000^Y>^0;ZC[P1;0;ZC[P030000003oool0oooo03`0oooo
00080?ooo`030000003oool0oooo00@0oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?oo
o`0m0?ooo`00203oool00`000000oooo0?ooo`030?ooo`030000002jTjh0^Y>^04/0^Y>^00<00000
0?ooo`3oool0?P3oool000P0oooo00<000000?ooo`3oool00P3oool00`000000^Y>^0;ZC[P1<0;ZC
[P030000003oool0oooo03h0oooo00080?ooo`050000003oool0oooo0?ooo`000000CP2jTjh00`00
0000oooo0?ooo`0o0?ooo`00203oool01@000000oooo0?ooo`3oool0000004d0^Y>^00<000000?oo
o`3oool0@03oool000P0oooo00@000000?ooo`3oool00000C@2jTjh00`000000oooo0?ooo`110?oo
o`001`3oool010000000oooo0?ooo`00001=0;ZC[P030000003oool0oooo0480oooo00070?ooo`03
0000003oool0000004h0^Y>^00<000000?ooo`3oool0@P3oool000L0oooo0P00001>0;ZC[P030000
003oool0oooo04<0oooo00070?ooo`030000002jTjh0^Y>^04`0^Y>^00<000000?ooo`3oool0A03o
ool000L0oooo00<000000;ZC[P2jTjh0B`2jTjh00`000000oooo0?ooo`150?ooo`001`3oool00`00
0000^Y>^0;ZC[P1:0;ZC[P030000003oool0oooo04H0oooo00080?ooo`030000002jTjh0^Y>^04T0
^Y>^00<000000?ooo`3oool0AP3oool000P0oooo00<000000;ZC[P2jTjh0B02jTjh00`000000oooo
0?ooo`170?ooo`00203oool00`000000^Y>^0;ZC[P170;ZC[P030000003oool0oooo04P0oooo0009
0?ooo`030000002jTjh0^Y>^04D0^Y>^00<000000?ooo`3oool0B@3oool000T0oooo00<000000;ZC
[P2jTjh0A02jTjh00`000000oooo0?ooo`1:0?ooo`002@3oool00`000000^Y>^0;ZC[P140;ZC[P03
0000003oool0oooo04X0oooo00090?ooo`030000002jTjh0^Y>^04<0^Y>^00<000000?ooo`3oool0
B`3oool000X0oooo00<000000;ZC[P2jTjh0@@2jTjh00`000000oooo0?ooo`1<0?ooo`002P3oool0
0`000000^Y>^0;ZC[P100;ZC[P030000003oool0oooo04d0oooo000:0?ooo`030000002jTjh0^Y>^
03l0^Y>^00<000000?ooo`3oool0CP3oool000X0oooo00<000000;ZC[P2jTjh0?`2jTjh00`000000
oooo0?ooo`1>0?ooo`002`3oool00`000000^Y>^0;ZC[P0m0;ZC[P030000003oool0oooo04l0oooo
000;0?ooo`030000002jTjh0^Y>^03`0^Y>^00<000000?ooo`3oool0D03oool000/0oooo00<00000
0;ZC[P2jTjh0>`2jTjh00`000000oooo0?ooo`1A0?ooo`00303oool00`000000^Y>^0;ZC[P0i0;ZC
[P030000003oool0oooo0580oooo000<0?ooo`030000002jTjh0^Y>^03P0^Y>^00<000000?ooo`3o
ool0D`3oool000`0oooo00<000000;ZC[P2jTjh0>02jTjh00`000000oooo0?ooo`1C0?ooo`00303o
ool00`000000^Y>^0;ZC[P0g0;ZC[P030000003oool0oooo05@0oooo000=0?ooo`030000002jTjh0
^Y>^03D0^Y>^00<000000?ooo`3oool0E@3oool000d0oooo00<000000;ZC[P2jTjh0=02jTjh00`00
0000oooo0?ooo`1F0?ooo`003@3oool00`000000^Y>^0;ZC[P0c0;ZC[P030000003oool0oooo05L0
oooo000>0?ooo`030000002jTjh0^Y>^0380^Y>^00<000000?ooo`3oool0E`3oool000h0oooo00<0
00000;ZC[P2jTjh0<@2jTjh00`000000oooo0?ooo`1H0?ooo`003P3oool00`000000^Y>^0;ZC[P0`
0;ZC[P030000003oool0oooo05T0oooo000>0?ooo`030000002jTjh0^Y>^02l0^Y>^00<000000?oo
o`3oool0FP3oool000l0oooo00<000000;ZC[P2jTjh0;@2jTjh00`000000oooo0?ooo`1K0?ooo`00
3`3oool00`000000^Y>^0;ZC[P0]0;ZC[P030000003oool0oooo05/0oooo000?0?ooo`030000002j
Tjh0^Y>^02`0^Y>^00<000000?ooo`3oool0G03oool000l0oooo00<000000;ZC[P2jTjh0:`2jTjh0
0`000000oooo0?ooo`1M0?ooo`00403oool00`000000^Y>^0;ZC[P0Y0;ZC[P030000003oool0oooo
05h0oooo000@0?ooo`030000002jTjh0^Y>^02P0^Y>^00<000000?ooo`3oool0G`3oool00100oooo
00<000000;ZC[P2jTjh0:02jTjh00`000000oooo0?ooo`1O0?ooo`004@3oool00`000000^Y>^0;ZC
[P0V0;ZC[P030000003oool0oooo0600oooo000A0?ooo`/000007@2jTjh00`000000oooo0?ooo`1Q
0?ooo`004`3oool00`000000oooo0?ooo`060?oooa<000002@2jTjh00`000000oooo0?ooo`1R0?oo
o`00503oool2000001T0oooo2@00001U0?ooo`005P3oool00`000000oooo0?ooo`0J0?ooo`D00000
I@3oool001L0oooo00<000000?ooo`3oool06@3oool4000006H0oooo000H0?ooo`800000603oool4
000006L0oooo000J0?ooo`030000003oool0oooo01@0oooo1000001X0?ooo`006`3oool2000001<0
oooo1000001Y0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`<00000JP3oool001h0oooo00<0
00000?ooo`3oool03P3oool3000006/0oooo000O0?ooo`8000003@3oool3000006`0oooo000Q0?oo
o`030000003oool0oooo00X0oooo0P00001]0?ooo`008P3oool2000000T0oooo0P00001^0?ooo`00
903oool00`000000oooo0?ooo`050?ooo`800000K`3oool002D0oooo00<000000?ooo`3oool00`3o
ool200000700oooo000V0?ooo`8000000`3oool00`000000oooo0?ooo`1_0?ooo`00:03oool00`00
0000oooo0000001b0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`00W@3oool009d0oooo002M
0?ooo`00W@3oool009d0oooo002M0?ooo`00W@3oool009d0oooo002M0?ooo`00W@3oool009d0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 156.438}, {171.062, 0}} -> {0.0531685, -0.000169859, \
0.00558614, 0.00558614}},
  CellTags->"RoofPrism"],

Cell[BoxData[
    TagBox[\(DrawSystem[{RoofPrism[10, {Mirrored \[Rule] True}]}]\),
      HoldForm]], "Print",
  CellTags->"RoofPrism"],

Cell[BoxData[
    \("-rendered element-"\)], "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{CircleOfRays[6,NumberOfRays->8],
Move[RoofPrism[10],3],
Boundary[25,GraphicDesign->Off]},
PlotType->SideView];\
\>", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.057596 0.745149 0.057596 [
[.1966 .74515 -30 -4.5 ]
[.1966 .74515 30 4.5 ]
[ 0 0 0 0 ]
[ 1 1.05833 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.1966 .45717 m
.1966 .8295 L
.1966 1.03313 L
.1966 1.03313 L
.1966 .8295 L
.1966 .45717 L
.1966 .45717 L
s
.40023 .25354 m
.77256 .25354 L
.97619 .25354 L
.97619 .25354 L
.77256 .25354 L
.40023 .25354 L
.40023 .25354 L
s
.1966 .8295 m
.1966 1.03313 L
.40023 1.03313 L
.97619 .45717 L
.97619 .25354 L
.77256 .25354 L
.1966 .8295 L
s
.77256 .25354 m
.97619 .25354 L
.97619 .45717 L
.40023 1.03313 L
.1966 1.03313 L
.1966 .8295 L
.77256 .25354 L
s
.40023 .25354 m
.77256 .25354 L
.1966 .8295 L
.1966 .45717 L
.40023 .25354 L
s
.1966 .45717 m
.1966 .8295 L
.77256 .25354 L
.40023 .25354 L
.1966 .45717 L
s
.97619 .25354 m
.97619 .45717 L
.97619 .25354 L
.97619 .25354 L
s
.1966 1.03313 m
.40023 1.03313 L
.1966 1.03313 L
.1966 1.03313 L
s
.40023 .25354 m
.40023 .25354 L
.1966 .45717 L
.1966 .45717 L
.40023 .25354 L
s
.039 .916 .04 r
.02381 .74515 m
.1966 .74515 L
s
0 0 0 r
2 Mabswid
.1966 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86733 m
.1966 .86733 L
s
0 0 0 r
2 Mabswid
.1966 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .91794 m
.1966 .91794 L
s
0 0 0 r
2 Mabswid
.1966 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .86733 m
.1966 .86733 L
s
0 0 0 r
2 Mabswid
.1966 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .74515 m
.1966 .74515 L
s
0 0 0 r
2 Mabswid
.1966 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62297 m
.1966 .62297 L
s
0 0 0 r
2 Mabswid
.1966 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57236 m
.1966 .57236 L
s
0 0 0 r
2 Mabswid
.1966 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .62297 m
.1966 .62297 L
s
0 0 0 r
2 Mabswid
.1966 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .74515 m
.44385 .74515 L
s
0 0 0 r
2 Mabswid
.44385 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .86733 m
.39324 .86733 L
s
0 0 0 r
2 Mabswid
.39324 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .91794 m
.51542 .91794 L
s
0 0 0 r
2 Mabswid
.51542 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .86733 m
.39324 .86733 L
s
0 0 0 r
2 Mabswid
.39324 .86733 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .74515 m
.44385 .74515 L
s
0 0 0 r
2 Mabswid
.44385 .74515 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .62297 m
.6376 .62297 L
s
0 0 0 r
2 Mabswid
.6376 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .57236 m
.861 .57236 L
s
0 0 0 r
2 Mabswid
.861 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.1966 .62297 m
.6376 .62297 L
s
0 0 0 r
2 Mabswid
.6376 .62297 Mdot
.039 .916 .04 r
.5 Mabswid
.44385 .74515 m
.68821 .50079 L
s
0 0 0 r
2 Mabswid
.68821 .50079 Mdot
.039 .916 .04 r
.5 Mabswid
.39324 .86733 m
.56603 .69454 L
s
0 0 0 r
2 Mabswid
.56603 .69454 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .91794 m
.51542 .91794 L
s
0 0 0 r
2 Mabswid
.51542 .91794 Mdot
.039 .916 .04 r
.5 Mabswid
.39324 .86733 m
.56603 .69454 L
s
0 0 0 r
2 Mabswid
.56603 .69454 Mdot
.039 .916 .04 r
.5 Mabswid
.44385 .74515 m
.68821 .50079 L
s
0 0 0 r
2 Mabswid
.68821 .50079 Mdot
.039 .916 .04 r
.5 Mabswid
.6376 .62297 m
.81039 .45018 L
s
0 0 0 r
2 Mabswid
.81039 .45018 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .57236 m
.861 .57236 L
s
0 0 0 r
2 Mabswid
.861 .57236 Mdot
.039 .916 .04 r
.5 Mabswid
.6376 .62297 m
.81039 .45018 L
s
0 0 0 r
2 Mabswid
.81039 .45018 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .50079 m
.68821 .25354 L
s
0 0 0 r
2 Mabswid
.68821 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .69454 m
.56603 .25354 L
s
0 0 0 r
2 Mabswid
.56603 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .91794 m
.51542 .25354 L
s
0 0 0 r
2 Mabswid
.51542 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .69454 m
.56603 .25354 L
s
0 0 0 r
2 Mabswid
.56603 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .50079 m
.68821 .25354 L
s
0 0 0 r
2 Mabswid
.68821 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .45018 m
.81039 .25354 L
s
0 0 0 r
2 Mabswid
.81039 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .57236 m
.861 .25354 L
s
0 0 0 r
2 Mabswid
.861 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .45018 m
.81039 .25354 L
s
0 0 0 r
2 Mabswid
.81039 .25354 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .25354 m
.68821 .0252 L
s
0 0 0 r
2 Mabswid
.68821 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .25354 m
.56603 .0252 L
s
0 0 0 r
2 Mabswid
.56603 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.51542 .25354 m
.51542 .0252 L
s
0 0 0 r
2 Mabswid
.51542 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.56603 .25354 m
.56603 .0252 L
s
0 0 0 r
2 Mabswid
.56603 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.68821 .25354 m
.68821 .0252 L
s
0 0 0 r
2 Mabswid
.68821 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .25354 m
.81039 .0252 L
s
0 0 0 r
2 Mabswid
.81039 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.861 .25354 m
.861 .0252 L
s
0 0 0 r
2 Mabswid
.861 .0252 Mdot
.039 .916 .04 r
.5 Mabswid
.81039 .25354 m
.81039 .0252 L
s
0 0 0 r
2 Mabswid
.81039 .0252 Mdot
[(Roof Prism)] .1966 .74515 0 0 Mshowa
0 0 m
1 0 L
1 1.05833 L
0 1.05833 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{182.812, 191.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000_b000`400?l00000o`00003o]P3oool0
0;H0oooo002f0?ooo`00]P3oool005d0oooo0P0000070?ooo`800000503oool2000001@0oooo0P00
00070?ooo`8000006@3oool005d0oooo0P0000070?ooo`800000503oool2000001@0oooo0P000007
0?ooo`8000006@3oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H0?oo
o`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3o
ool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ
2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool005d0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C
0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H
0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool0
0`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool0
05d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo
01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3o
ool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603o
ool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0
oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09
jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0
oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0
oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<0
2NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0
4`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0
603oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0H0?ooo`00G@3oool0
0`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool04`3oool0
0`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo001M0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool0603oool005d0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0H0?ooo`00G@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01P0oooo
001M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0603oool004T0oooo00<00000
0?ooo`3oool04@3oool00`09jPX000000?ooo`060?ooo`0300WZ2P000000oooo01<0oooo00<02NX:
0000003oool04`3oool00`09jPX000000?ooo`060?ooo`0300WZ2P000000oooo0180oooo00<00000
0?ooo`3oool00`3oool004P0oooo5@0000000`09jPX00000000000060000000300WZ2P0000000000
01<0000000<02NX:0000000000004`0000000`09jPX00000000000060000000300WZ2P0000000000
01<000001@3oool004L0oooo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`00
AP3oool00`000000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0
4`3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00150?ooo`030000003o
ool0oooo01D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo0180oooo00<000000?ooo`3oool00`3oool004@0oooo00<000000?ooo`3oool05P3oool0
0`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00120?ooo`030000003oool0oooo01P0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool00`3oool00440oooo
00<000000?ooo`3oool06@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`00@03oool00`000000oooo0?oo
o`0J0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0B0?ooo`030000003oool0oooo00<0oooo000o0?ooo`030000003oool0oooo01/0oooo00<02NX:
0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0180oooo00<00000
0?ooo`3oool00`3oool003h0oooo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`030?oo
o`00?@3oool00`000000oooo0?ooo`0M0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3o
ool04`3oool01@09jPX0oooo0?ooo`3oool000000140oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000l0?ooo`030000003oool0oooo01h0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0400WZ2P3oool0oooo0000
0180oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000k0?ooo`030000003oool0oooo01l0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0000001<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000j0?ooo`030000003oool0oooo0200oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P000000oooo01<0oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo
000i0?ooo`030000003oool0oooo0240oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0C0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0B0?ooo`030000003oool0oooo00<0oooo000h0?ooo`030000003oool0oooo0280oooo00<02NX:
0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`0300000009jPX0oooo01@0oooo00<02NX:
0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000g0?oo
o`030000003oool0oooo02<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0A0?oo
o`030000003oool02NX:01D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo000f0?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0@0?ooo`040000003oool0oooo00WZ2QD0oooo00<02NX:0?oo
o`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000e0?ooo`03
0000003oool0oooo02D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`09jPX05@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo
0180oooo00<000000?ooo`3oool00`3oool003@0oooo00<000000?ooo`3oool09P3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`000000
oooo0?ooo`030?ooo`00<`3oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01<0oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo
000b0?ooo`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`0<0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`060?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool00`3oool00340oooo00<00000
0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00/0oooo00<00000
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:
0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0Z0?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool02P3oool00`000000oooo0?ooo`060?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo000_0?ooo`030000003oool0oooo02/0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3o
ool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3o
ool00`3oool002h0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`00;@3o
ool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000/0?ooo`030000003oool0
oooo02h0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo0180oooo00<000000?ooo`3oool00`3oool002/0oooo00<000000?ooo`3oool0;`3oool00`09
jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`00
0000oooo0?ooo`030?ooo`00:P3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo00H0
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01<0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0
oooo000Y0?ooo`030000003oool0oooo0340oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo0180oooo00<000000?ooo`3oool00`3oool002P0oooo00<0
00000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00H0oooo00<0
2NX:0?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`009`3oool00`000000oooo0?ooo`0c
0?ooo`0300WZ2P3oool0oooo00H0oooo00D02NX:0?ooo`3oool0oooo0000000A0?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003o
ool0oooo00<0oooo000V0?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3oool01P3oool0
1009jPX0oooo0?ooo`00000B0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0000003oool01P3o
ool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000U0?ooo`030000003oool0
oooo03D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0000000C0?ooo`0300WZ2P3oool0
oooo01<0oooo00<02NX:0000003oool01P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo000T0?ooo`030000003oool0oooo03H0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX000000?ooo`0C0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool01`3oool00`09
jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo000T0?ooo`030000003oool0oooo03H0
oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo0140
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000T0?ooo`030000003oool0oooo03H0oooo00<02NX:0?ooo`3oool01@3oool00`0000002NX:
0?ooo`0D0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000T0?ooo`030000003oool0oooo03H0oooo00<0
2NX:0?ooo`3oool0103oool00`000000oooo00WZ2P0E0?ooo`0300WZ2P3oool0oooo00l0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo000T
0?ooo`030000003oool0oooo03H0oooo00<02NX:0?ooo`3oool00`3oool010000000oooo0?ooo`09
jPXE0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo000T0?ooo`030000003oool0oooo03H0oooo00<02NX:
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool02NX:01D0oooo00<02NX:0?ooo`3oool03@3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool0203o
ool002@0oooo00<000000?ooo`3oool0=P3oool01@09jPX0oooo0?ooo`3oool0000000@0oooo00<0
2NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00903oool00`000000oooo0?ooo`0f
0?ooo`0400WZ2P3oool0oooo000000D0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`00903oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0000000H0oooo00<02NX:
0?ooo`3oool04`3oool00`09jPX000000?ooo`0:0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`00903oool00`000000oooo0?ooo`0f0?oo
o`0300WZ2P000000oooo00H0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX000000000000:0?oo
o`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`00903oool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3o
ool04@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3o
ool0203oool00`000000oooo0?ooo`0=0?ooo`00903oool00`000000oooo0?ooo`0e0?ooo`030000
0009jPX0oooo00L0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo0180oooo00<02NX:0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00903o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool02NX:00P0oooo00<02NX:0?ooo`3oool03`3o
ool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3o
ool00`000000oooo0?ooo`0?0?ooo`00903oool00`000000oooo0?ooo`0c0?ooo`040000003oool0
oooo00WZ2PP0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo01@0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00903oool0
0`000000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`09jPX0203oool00`09jPX0oooo0?oo
o`0=0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?oo
o`040?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00<0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?oo
o`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?oo
o`00903oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3o
ool01P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool0603oool01@09jPX0oooo0?ooo`3oool0000001H0oooo000T0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00T0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0I0?ooo`0400WZ2P3oool0oooo0000
01L0oooo000T0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0J0?ooo`0300WZ2P3oool0000001P0oooo000S0?ooo`800000;P3oool00`000000oooo
0?ooo`070?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0000003oool0603oool000D0oooo7P09
jPX00`0000002NX:00WZ2P1f00WZ2P030000003oool0oooo01L0oooo000T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool02@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo00D0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0L0?ooo`030000003oool0
oooo01T0oooo000T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000T0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo01/0
oooo000T0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303oool00`09jPX0oooo
0?ooo`060?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0L0?ooo`030000003oool0oooo01`0oooo000T0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`060?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
303oool00`09jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000T0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`09jPX0oooo0?ooo`060?ooo`0400WZ2P3o
ool0oooo00WZ2P`0oooo00<02NX:0?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`00903o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00l0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo00WZ2P0<0?ooo`0300WZ2P3oool0oooo01`0oooo00<000000?ooo`3oool07`3o
ool002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0
oooo00H0oooo0P09jPX<0?ooo`0300WZ2P3oool0oooo01`0oooo00<000000?ooo`3oool0803oool0
00D0oooo7P09jPX00`0000002NX:00WZ2P1>00WZ2P030000003oool0oooo01/0oooo00<000000?oo
o`3oool08@3oool002<0oooo0P00000S0?ooo`030000003oool0oooo0180oooo00<02NX:0?ooo`3o
ool01@3oool200WZ2P`0oooo0P00000L0?ooo`030000003oool0oooo0280oooo000T0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool04`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool02NX:02T0oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:
:03oool00`000000oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01D0oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo0?ooo`3oool02NX:02L0oooo
00<000000?ooo`3oool09@3oool002@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0F0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`0T0?ooo`030000
003oool0oooo02H0oooo000T0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3o
ool01009jPX0oooo0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo02<0oooo00<000000?ooo`3oool0
9`3oool002@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?ooo`0300WZ2P3o
ool02NX:00H0oooo00<02NX:0?ooo`3oool08P3oool00`000000oooo0?ooo`0X0?ooo`00903oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo0P09jPX70?ooo`0300WZ2P3oool0
oooo0240oooo00<000000?ooo`3oool0:@3oool002@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0803oool00`00
0000oooo0?ooo`0Z0?ooo`00903oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0
oooo0P09jPX80?ooo`0300WZ2P3oool0oooo01l0oooo00<000000?ooo`3oool0:`3oool002@0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool02NX:00P0oooo
00<02NX:0?ooo`3oool07P3oool00`000000oooo0?ooo`0/0?ooo`00903oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01X0oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX00000
0?ooo`0M0?ooo`030000003oool0oooo02d0oooo000T0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool06P3oool01@09jPX0oooo0?ooo`3oool02NX:00P0oooo00<02NX:0000003oool0
703oool00`000000oooo0?ooo`0^0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01X0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo01`0oooo00<000000?ooo`3oool0;`3oool002@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo0300oooo000T0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool0703oool00`000000oooo0?ooo`0a0?ooo`00903oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01`0oooo00<000000?ooo`3oool0<P3oool002@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00H0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P0N0?ooo`030000003oool0oooo03<0oooo000T0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool06P3oool00`09jPX0oooo0?ooo`070?ooo`0400WZ
2P3oool0oooo00WZ2Qh0oooo00<000000?ooo`3oool0=03oool000d0oooo0`0000020?ooo`800000
00@0oooo00000000000000000P3oool3000000040?ooo`0000000000000000<0oooo0`0000030?oo
o`P000000P3oool3000000030?ooo`000000000001P0oooo00<02NX:0?ooo`3oool0203oool00`09
jPX0oooo00WZ2P0N0?ooo`030000003oool0oooo03D0oooo000>0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0000000@0oooo0P000004
0?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`000000oooo0000003oool0000001P0
oooo00<02NX:0?ooo`3oool02@3oool200WZ2Qh0oooo00<000000?ooo`3oool0=P3oool000D0oooo
2@09jPX0100000002NX:00WZ2P00000200WZ2P0400000009jPX02NX:00WZ2P8000000`09jPX00`00
00002NX:0000000300WZ2P0300000009jPX00000008000000P09jPX0100000002NX:00WZ2P000002
00WZ2P8000000P09jPX01@0000002NX:00000009jPX0000001P02NX:00<000000?ooo`3oool02@3o
ool00`09jPX0oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000>0?ooo`@000000P3oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`0000000`3oool300000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`000000
oooo0000000G0?ooo`8000002P3oool200WZ2Qd0oooo00<000000?ooo`3oool0>03oool000h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`<000000P3oool3000000040?ooo`00000000000000
00<0oooo0P0000020?ooo`H000000P3oool8000002<0oooo00<02NX:0?ooo`09jPX0703oool00`00
0000oooo0?ooo`0i0?ooo`003P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool00P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?oo
o`0400WZ2P3oool0oooo00WZ2Q/0oooo00<000000?ooo`3oool0>P3oool000d0oooo1@00000>0?oo
o`8000000P3oool4000000D0oooo00<000000?ooo`000000:@3oool01@09jPX0oooo0?ooo`3oool0
2NX:01X0oooo00<000000?ooo`3oool0>`3oool002@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool05`3oool00`00
0000oooo0?ooo`0l0?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0F0?ooo`030000003oool0oooo03d0
oooo000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo01D0oooo00<000000?ooo`3oool0?P3oool002@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`00903oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02L0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`0C
0?ooo`030000003oool0oooo0400oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool09`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo0180oooo00<000000?oo
o`3oool0@@3oool002@0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`0300WZ2P3oool0oooo
00P0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`120?ooo`00903oool010000000
oooo0?ooo`00000Y0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0403oool00`00
0000oooo0?ooo`130?ooo`00903oool00`000000oooo0000000Y0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`00903oool2000002T0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0>0?ooo`030000003oool0oooo04D0oooo
000T0?ooo`030000003oool0oooo02L0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?oo
o`0=0?ooo`030000003oool0oooo04H0oooo000T0?ooo`030000003oool0oooo02H0oooo00<02NX:
0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo000T0?oo
o`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0;0?oo
o`030000003oool0oooo04P0oooo000T0?ooo`030000003oool0oooo02@0oooo00<02NX:0?ooo`3o
ool03`3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo000T0?ooo`030000
003oool0oooo02<0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`090?ooo`030000
003oool0oooo04X0oooo000T0?ooo`030000003oool0oooo0280oooo00<02NX:0?ooo`3oool04@3o
ool00`09jPX0oooo0?ooo`080?ooo`030000003oool0oooo04/0oooo000T0?ooo`030000003oool0
oooo0240oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`070?ooo`030000003oool0
oooo04`0oooo00050?oooah02NX:00<0000000WZ2P09jPX08P09jPX00`000000oooo0?ooo`0B0?oo
o`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool0C@3oool002<0oooo0P00000R0?ooo`80
0000503oool00`09jPX0oooo0?ooo`050?ooo`030000003oool0oooo04h0oooo000T0?ooo`030000
003oool0oooo03H0oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`1?0?ooo`00903o
ool00`000000oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool0D03o
ool002@0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0
oooo0540oooo000T0?ooo`030000003oool0oooo03H0oooo00D02NX:0?ooo`3oool0oooo0000001D
0?ooo`00903oool00`000000oooo0?ooo`0f0?ooo`0400WZ2P3oool0oooo000005D0oooo000T0?oo
o`030000003oool0oooo03H0oooo00<02NX:0?ooo`000000EP3oool002@0oooo00<000000?ooo`3o
ool0=P3oool00`09jPX000000?ooo`1F0?ooo`001@3ooolN00WZ2P0300000009jPX02NX:03P02NX:
00<000000?ooo`3oool0E@3oool002<0oooo0P00000g0?ooo`<00000E`3oool002@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`1H0?ooo`00903oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo05T0oooo000T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0FP3oool002@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1K0?ooo`00903o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05`0oooo000T0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0G@3oool002@0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1N0?ooo`00903oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05l0
oooo000T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0H03oool002@0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`1Q0?ooo`00903oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0680oooo000T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H`3oool002@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1T0?ooo`00
903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo06D0oooo000T0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0IP3oool002@0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`1W0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
06P0oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0J@3oool002@0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1Z0?ooo`00903ooolU000006d0oooo002f
0?ooo`00]P3oool00;H0oooo002f0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 181.812}, {190.562, 0}} -> {-0.497987, -12.9376, \
0.0964263, 0.0964263}},
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13302 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0783254 1.15189 -1.11022e-16 1.15189 [
[ 0 0 0 0 ]
[ 1 1.13302 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.13302 L
0 1.13302 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.67608 .44994 m
.36766 .5518 L
s
.36766 .5518 m
.35793 .84614 L
s
.17828 .35589 m
.36766 .5518 L
s
0 0 0 r
2 Mabswid
.51388 .32335 Mdot
.039 .916 .04 r
.5 Mabswid
.51436 .43134 m
.51388 .32335 L
s
0 0 0 r
2 Mabswid
.59416 .31783 Mdot
.039 .916 .04 r
.5 Mabswid
.59698 .42591 m
.59416 .31783 L
s
0 0 0 r
2 Mabswid
.45073 .28933 Mdot
.039 .916 .04 r
.5 Mabswid
.44934 .39791 m
.45073 .28933 L
s
0 0 0 r
2 Mabswid
.6476 .27557 Mdot
.039 .916 .04 r
.5 Mabswid
.65206 .38437 m
.6476 .27557 L
s
0 g
.35793 .84614 m
.67608 .44994 L
s
.83977 .26144 m
.67608 .44994 L
s
0 0 0 r
2 Mabswid
.51436 .43134 Mdot
.039 .916 .04 r
.5 Mabswid
.51536 .6588 m
.51436 .43134 L
s
.21514 .71388 m
.30778 .68491 L
s
0 0 0 r
2 Mabswid
.59698 .42591 Mdot
.039 .916 .04 r
.5 Mabswid
.60023 .55031 m
.59698 .42591 L
s
0 0 0 r
2 Mabswid
.441 .23361 Mdot
.039 .916 .04 r
.5 Mabswid
.43928 .34308 m
.441 .23361 L
s
.22815 .79396 m
.32172 .76594 L
s
0 0 0 r
2 Mabswid
.64239 .2192 Mdot
.039 .916 .04 r
.5 Mabswid
.6468 .32889 m
.64239 .2192 L
s
.17465 .6493 m
.26785 .61902 L
s
0 0 0 r
2 Mabswid
.44934 .39791 Mdot
.039 .916 .04 r
.5 Mabswid
.44479 .75382 m
.44934 .39791 L
s
.30778 .68491 m
.55692 .60701 L
s
0 0 0 r
2 Mabswid
.30778 .68491 Mdot
0 g
.5 Mabswid
.35793 .84614 m
.24586 1.00182 L
s
0 0 0 r
2 Mabswid
.65206 .38437 Mdot
.039 .916 .04 r
.5 Mabswid
.65612 .4834 m
.65206 .38437 L
s
.32172 .76594 m
.4605 .72438 L
s
0 0 0 r
2 Mabswid
.32172 .76594 Mdot
.49355 .18828 Mdot
.039 .916 .04 r
.5 Mabswid
.49342 .29843 m
.49355 .18828 L
s
0 0 0 r
2 Mabswid
.57834 .18211 Mdot
.039 .916 .04 r
.5 Mabswid
.58084 .29235 m
.57834 .18211 L
s
.26785 .61902 m
.65343 .49374 L
s
0 0 0 r
2 Mabswid
.26785 .61902 Mdot
0 g
.5 Mabswid
.15201 .66317 m
.17828 .35589 L
s
.17828 .35589 m
.50645 .23407 L
s
.039 .916 .04 r
.20602 .84604 m
.30155 .81812 L
s
0 0 0 r
2 Mabswid
.60023 .55031 Mdot
.039 .916 .04 r
.5 Mabswid
.34406 .60841 m
.60023 .55031 L
s
0 0 0 r
2 Mabswid
.43928 .34308 Mdot
.039 .916 .04 r
.5 Mabswid
.43566 .57446 m
.43928 .34308 L
s
.12823 .63643 m
.22321 .60515 L
s
0 0 0 r
2 Mabswid
.6468 .32889 Mdot
.039 .916 .04 r
.5 Mabswid
.65343 .49374 m
.6468 .32889 L
s
.4605 .72438 m
.49328 .42563 L
s
0 0 0 r
2 Mabswid
.4605 .72438 Mdot
.65612 .4834 Mdot
.039 .916 .04 r
.5 Mabswid
.47921 .52083 m
.65612 .4834 L
s
.30155 .81812 m
.41384 .7853 L
s
0 0 0 r
2 Mabswid
.30155 .81812 Mdot
.039 .916 .04 r
.5 Mabswid
.55692 .60701 m
.58312 .3929 L
s
0 0 0 r
2 Mabswid
.55692 .60701 Mdot
.039 .916 .04 r
.5 Mabswid
.22321 .60515 m
.47921 .52083 L
s
0 0 0 r
2 Mabswid
.22321 .60515 Mdot
.49342 .29843 Mdot
.039 .916 .04 r
.5 Mabswid
.49328 .42563 m
.49342 .29843 L
s
0 0 0 r
2 Mabswid
.51536 .6588 Mdot
.039 .916 .04 r
.5 Mabswid
.32922 .7055 m
.51536 .6588 L
s
0 0 0 r
2 Mabswid
.58084 .29235 Mdot
.039 .916 .04 r
.5 Mabswid
.58312 .3929 m
.58084 .29235 L
s
.15951 .83818 m
.25692 .80938 L
s
.10291 .68624 m
.1999 .65493 L
s
.41384 .7853 m
.43566 .57446 L
s
0 0 0 r
2 Mabswid
.41384 .7853 Mdot
0 g
.5 Mabswid
.83977 .26144 m
.24586 1.00182 L
s
.50645 .23407 m
.83977 .26144 L
s
.039 .916 .04 r
.11582 .77133 m
.21385 .74109 L
s
.25692 .80938 m
.44479 .75382 L
s
0 0 0 r
2 Mabswid
.25692 .80938 Mdot
.039 .916 .04 r
.5 Mabswid
.1999 .65493 m
.34406 .60841 L
s
0 0 0 r
2 Mabswid
.1999 .65493 Mdot
0 g
.5 Mabswid
.50645 .23407 m
.15201 .66317 L
s
0 0 0 r
2 Mabswid
.58312 .3929 Mdot
.65343 .49374 Mdot
.039 .916 .04 r
.5 Mabswid
.65343 .49374 m
.65343 .49374 L
s
0 0 0 r
2 Mabswid
.65343 .49374 Mdot
.039 .916 .04 r
.5 Mabswid
.21385 .74109 m
.32922 .7055 L
s
0 0 0 r
2 Mabswid
.21385 .74109 Mdot
.49328 .42563 Mdot
.47921 .52083 Mdot
.43566 .57446 Mdot
.34406 .60841 Mdot
.44479 .75382 Mdot
.039 .916 .04 r
.5 Mabswid
.44479 .75382 m
.44479 .75382 L
s
0 0 0 r
2 Mabswid
.44479 .75382 Mdot
.32922 .7055 Mdot
0 g
.5 Mabswid
.15201 .66317 m
.24586 1.00182 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175.125, 198.312},
  ImageMargins->{{49, 0}, {0, 0}},
  ImageRegion->{{-0.216075, 1.23102}, {-0.18815, 1.14189}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000aR000`400?l00000o`00003o[`3oool0
0:l0oooo002_0?ooo`00[`3oool00:l0oooo001Z0?ooo`0300WZ2P000000oooo0480oooo001F0?oo
o`8000004P3oool00`09jPX000000?ooo`120?ooo`00EP3oool00`09jPX000000?ooo`0A0?ooo`03
00WZ2P3oool0oooo0480oooo001F0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0
@P3oool005H0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`120?ooo`00EP3oool0
0`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo0480oooo001F0?ooo`0300WZ2P3oool0oooo
0140oooo00<02NX:0?ooo`3oool0@P3oool005H0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0
oooo0?ooo`120?ooo`00EP3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00/0oooo
0P00000e0?ooo`00EP3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
000000WZ2P3oool0=03oool005H0oooo00<02NX:0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0<
0?ooo`0300WZ2P3oool0oooo03<0oooo001F0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?oo
o`3oool0303oool00`09jPX0oooo0?ooo`0c0?ooo`00BP3oool00`09jPX000000?ooo`090?ooo`03
00WZ2P3oool0000000L000002P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo03<0
oooo001:0?ooo`0300WZ2P000000oooo00P0oooo0`0000000`3oool000000?ooo`050?ooo`/00000
3P3oool00`09jPX0oooo0?ooo`0c0?ooo`00BP3oool00`09jPX0oooo0?ooo`050?ooo`<0000000@0
oooo00WZ2P3oool000004P3oool;000000<0oooo00<02NX:0?ooo`3oool0<`3oool004X0oooo00<0
2NX:0?ooo`3oool00P3oool3000000@0oooo00<02NX:0000003oool04P3oool00`09jPX0oooo0?oo
o`080?ooo`/00000;P3oool004X0oooo00<02NX:0?ooo`3oool00P0000070?ooo`030000003oool0
oooo0180oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`050?ooo`/000008`3oool0
04X0oooo0`0000080?ooo`0300000009jPX0oooo01<0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0@0?ooo`/00000603oool004L0oooo0`0000000`09jPX0oooo0?ooo`070?ooo`03
0000003oool02NX:01@0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0K0?ooo`/0
00003@3oool004D0oooo0P0000030?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`09jPX0
503oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo02H0oooo1P0000070?ooo`00@P3o
ool3000000D0oooo00<02NX:0?ooo`3oool01P3oool010000000oooo0?ooo`09jPXD0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`00?`3o
ool3000000P0oooo00<02NX:0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool02NX:01@0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX000000000000Z0?ooo`030000003oool0oooo00H0oooo
000l0?ooo`<000002`3oool00`09jPX0oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
2NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P000000oooo02P0oooo00<0
00000?ooo`3oool01`3oool003X0oooo0P00000>0?ooo`0300WZ2P3oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:
0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00=`3oool300000100oooo00<02NX:0?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?oo
o`3oool0303oool00`09jPX0oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo000d0?ooo`<0
00004`3oool01P09jPX0oooo00WZ2P000000oooo000000H0oooo00<02NX:0?ooo`3oool04@3oool2
000000h0oooo00<02NX:0?ooo`3oool09@3oool2000000/0oooo000b0?ooo`8000005P3oool00`09
jPX0oooo00WZ2P02000000L0oooo00<02NX:0?ooo`3oool04@3oool00`0000002NX:0?ooo`0=0?oo
o`0300WZ2P3oool0oooo02@0oooo0P00000<0?ooo`00;`3oool3000001P0oooo00@02NX:0?ooo`09
jPX00000203oool00`09jPX000000?ooo`0B0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?oo
o`3oool08`3oool2000000d0oooo000/0?ooo`<000006`3oool00`09jPX0oooo000000090?ooo`03
00WZ2P000000oooo0180oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0R0?ooo`80
00003P3oool002T0oooo0`00000N0?ooo`0300WZ2P0000002NX:00T0oooo00<02NX:0?ooo`3oool0
4P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0280oooo00<000000?ooo`3oool0
3@3oool002L0oooo0P00000Q0?ooo`0300WZ2P0000002NX:00T0oooo00<02NX:0?ooo`3oool04P3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0240oooo0P00000?0?ooo`00903oool3
000002<0oooo00<000000?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`0B0?ooo`0400WZ2P3oool0
0000000000/0oooo00<02NX:0?ooo`3oool0803oool200000100oooo000Q0?ooo`<000009@3oool0
100000002NX:0?ooo`09jPX90?ooo`0300WZ2P3oool0oooo0080oooo0P00000>0?ooo`0400WZ2P3o
ool0000000WZ2P/0oooo00<02NX:0?ooo`3oool07`3oool200000140oooo000O0?ooo`8000009`3o
ool01@000000oooo00WZ2P3oool02NX:00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX00000
0?ooo`0=0?ooo`0400WZ2P3oool0oooo00WZ2P/0oooo00<02NX:0?ooo`3oool07P3oool200000180
oooo000L0?ooo`<00000:03oool01P000000oooo0?ooo`09jPX0oooo00WZ2PT0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`0400WZ2P3oool0oooo00WZ2PX0oooo00<00000
00WZ2P3oool07P3oool2000001<0oooo000I0?ooo`<00000:`3oool01P000000oooo0?ooo`09jPX0
oooo00WZ2PT0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`0400WZ2P3o
ool0oooo00WZ2PX0oooo00<0000000WZ2P09jPX07@3oool2000001@0oooo000F0?ooo`<00000;@3o
ool01`000000oooo0?ooo`3oool02NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`03
00WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:2`3oool200WZ2Q`0oooo00<000000?oo
o`000000503oool001@0oooo0P00000_0?ooo`080000003oool0oooo0?ooo`0000002NX:0?ooo`09
jPX90?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool03@3oool01009jPX0oooo0?oo
o`09jPX;0?ooo`802NX:703oool2000001D0oooo000A0?ooo`<00000<03oool00`000000oooo0?oo
o`020?ooo`0400000009jPX0oooo00WZ2PT0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`0=0?ooo`0400WZ2P3oool0oooo00WZ2P/0oooo0P09jPXK0?ooo`8000005P3oool000h0oooo
0`00000b0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:2`3oool200WZ2QX0
oooo0P00000G0?ooo`003@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo
00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo
00@02NX:0?ooo`3oool02NX:2`3oool200WZ2QT0oooo0P00000H0?ooo`003@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:2`3oool200WZ2QP0
oooo00<000000?ooo`000000603oool000d0oooo0P00000b0?ooo`030000003oool0oooo00H0oooo
00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo
00@02NX:0?ooo`3oool02NX:2`3oool200WZ2QL0oooo00<000000?ooo`0000006@3oool000d0oooo
00<000000?ooo`000000<03oool00`000000oooo0?ooo`070?ooo`0300WZ2P3oool02NX:00T0oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`0400WZ2P3oool0oooo00WZ2P/0
oooo0P09jPXF0?ooo`030000003oool0000001X0oooo000=0?ooo`040000003oool0oooo000002h0
oooo00<000000?ooo`3oool0203oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo0080
oooo00<02NX:0?ooo`3oool03@3oool01009jPX0oooo0?ooo`09jPX;0?ooo`802NX:5@3oool00`00
0000oooo0000000K0?ooo`003@3oool01@000000oooo0?ooo`3oool0000002`0oooo00<000000?oo
o`3oool02@3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool03@3oool01009jPX0oooo0?ooo`09jPX;0?ooo`802NX:503oool00`000000oooo0000000L
0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool03@3oool01009jPX0oooo0?ooo`09jPX;0?ooo`802NX:503oool00`000000oooo0000000L
0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02P3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool03@3oool01009jPX0oooo0?ooo`09jPX;0?ooo`802NX:00<000000?ooo`3oool0403oool0
0`000000oooo0000000M0?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool03@3oool01009jPX0oooo0?ooo`09jPX;0?ooo`802NX:00<00000
0?ooo`3oool03`3oool00`000000oooo0000000N0?ooo`00303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`09jPX0oooo00WZ2P090?oo
o`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool03@3oool2000000030?ooo`09jPX0oooo
00X0oooo0P09jPXA0?ooo`030000003oool0000001l0oooo000<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0=0?ooo`0400WZ2P3oool02NX:0000
00P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`80000000<0oooo00WZ
2P3oool02P3oool200WZ2Q00oooo00<000000?ooo`000000803oool000`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo00@02NX:0?ooo`09
jPX00000203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:0?oo
o`3oool02NX:2`3oool200WZ2Pl0oooo00@000000?ooo`3oool00000803oool000`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00h0oooo00<02NX:
0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00@02NX:
0?ooo`3oool02NX:2`3oool200WZ2Ph0oooo00@000000?ooo`3oool000008@3oool000`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00<0
2NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00d0oooo00@0
2NX:0?ooo`3oool02NX:2`3oool200WZ2Pd0oooo00@000000?ooo`3oool000008P3oool000`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo
00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00`0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`00
00008`3oool000`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0140oooo00<02NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo00`0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`0300WZ2P3oool0oooo00X0
oooo00<000000?ooo`000000903oool000`0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<02NX:0?ooo`09jPX02@3oool2000000<0oooo
00<02NX:0?ooo`3oool0303oool01009jPX0oooo0?ooo`3oool2000000/0oooo00<02NX:0?ooo`3o
ool02@3oool010000000oooo0?ooo`00000T0?ooo`00303oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`09jPX0oooo00WZ2P090?ooo`80
00000`3oool2000000d0oooo00H02NX:0?ooo`3oool0oooo00WZ2P00000;0?ooo`0300WZ2P3oool0
oooo00P0oooo00@000000?ooo`3oool000009@3oool000`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<02NX:0?ooo`09jPX02@3oool0
0`09jPX0oooo0?ooo`020?ooo`0300WZ2P000000oooo00`0oooo00D02NX:0?ooo`3oool0oooo00WZ
2P0<0?ooo`0300WZ2P3oool0oooo00L0oooo00@000000?ooo`3oool000009P3oool000/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo00<0
2NX:0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00`0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0<0?ooo`802NX:1`3oool010000000oooo0?ooo`00000W0?ooo`00
2`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
5@3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0
303oool01@09jPX0oooo0?ooo`3oool02NX:00`0oooo0P09jPX60?ooo`040000003oool0oooo0000
02P0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0F0?ooo`0300WZ2P3oool02NX:00T0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0<0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0303oool200WZ2PD0oooo00D000000?oo
o`3oool0oooo0000000X0?ooo`002`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool05`3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo
00X0oooo0P09jPX30?ooo`8000000`3oool00`000000oooo0?ooo`0W0?ooo`002`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool00`09jPX0
oooo00WZ2P080?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX3000000050?ooo`000000oooo0?oo
o`000000:P3oool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01P0oooo00<02NX:0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`090?ooo`03
00000009jPX02NX:00<0oooo00@000000?ooo`3oool00000:`3oool000/0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo00@02NX:0?ooo`3o
ool02NX:203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool00P3oool00`09jPX0oooo0?ooo`060?ooo`<0000000<0oooo00WZ2P09jPX00P3oool01000
0000oooo0?ooo`00000/0?ooo`002`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06@3oool01009jPX0oooo0?ooo`09jPX80?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo00<0oooo0`0000040?ooo`802NX:00D0oooo0000003oool0oooo0000000]0?ooo`002`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool0
1009jPX0oooo0?ooo`09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00<000001`3oool200WZ2P050000003o
ool0oooo0?ooo`000000;@3oool000/0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?oo
o`3oool0000001d0oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX000000000000:0?ooo`80
2NX:00@000000?ooo`3oool00000;P3oool000/0oooo00<000000?ooo`3oool06P3oool010000000
oooo0?ooo`00000M0?ooo`0400WZ2P3oool0oooo00WZ2PP0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool000000080000000<02NX:0?ooo`3oool02P3oool2
00WZ2P80oooo00<000000?ooo`3oool0;@3oool000/0oooo00<000000?ooo`3oool06`3oool20000
01h0oooo00@02NX:0?ooo`3oool02NX:203oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00X0oooo00<0000000WZ2P0000000`3oool00`09jPX0oooo0?ooo`090?ooo`<02NX:0P00000`
0?ooo`002P3oool00`000000oooo0?ooo`0L0?ooo`8000007P3oool01009jPX0oooo0?ooo`09jPX8
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool01`3oool30000000300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool500WZ2P0400000009jPX0000000000340oooo000:
0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool000007@3oool01009jPX0oooo0?oo
o`09jPX80?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool3000000<0oooo
00<02NX:0?ooo`3oool0103oool00`09jPX0oooo00WZ2P0300WZ2P@0oooo0P09jPX300000340oooo
000:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0J0?ooo`0400WZ2P3oool0oooo00WZ2PL0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo
0?ooo`3oool3000000H0oooo00@02NX:0?ooo`3oool0oooo1@09jPX50?ooo`<02NX:00@000000?oo
o`0000000000<P3oool000X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00@02NX:0?ooo`3oool02NX:1`3oool00`09jPX0oooo0?ooo`04
0?ooo`0400WZ2P0000000000000000P0oooo1@09jPX30?ooo`0400WZ2P3oool0oooo0?ooo`<02NX:
0P3oool010000000oooo0?ooo`00000c0?ooo`002P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0603oool01009jPX0oooo0?ooo`09jPX70?ooo`03
00WZ2P3oool0oooo0080oooo0P0000000`09jPX0oooo0?ooo`050?ooo`@02NX:00<0oooo00WZ2P3o
ool01@3oool400WZ2P@0oooo00@000000?ooo`3oool00000=03oool000X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo00@02NX:0?ooo`3o
ool02NX:1`3oool00`09jPX0oooo0000000200000080oooo00<02NX:0?ooo`3oool01@09jPX50?oo
o`0300WZ2P3oool0oooo0080oooo0`09jPX60?ooo`040000003oool0oooo000003D0oooo000:0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?oo
o`0400WZ2P3oool0oooo00WZ2PH0oooo00<0000000WZ2P000000103oool400WZ2PX0oooo00<02NX:
0?ooo`09jPX00P09jPX20?ooo`0300WZ2P3oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
000e0?ooo`002P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool05@3oool01009jPX0oooo0?ooo`09jPX30?ooo`D000001@09jPX00`3oool02NX:0?oo
o`0:0?ooo`<02NX:1@3oool00`09jPX0oooo0?ooo`030?ooo`040000003oool0oooo000003H0oooo
000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0D0?ooo`0400WZ2P3oool0oooo00WZ2P<0000000<0oooo00WZ2P09jPX00P0000060?ooo`0300WZ
2P3oool0oooo00H0oooo1009jPX70?ooo`0300WZ2P3oool0oooo0080oooo00@000000?ooo`3oool0
0000=`3oool000X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01<0oooo00D02NX:0000000000002NX:0?ooo`0300WZ2P<0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`<02NX:0`3oool00`09jPX0oooo0?ooo`050?ooo`05
00WZ2P3oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0f0?ooo`002P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool200000003
00WZ2P3oool02NX:00802NX:1P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
2NX:1P3oool00`09jPX0oooo0?ooo`050?ooo`0400WZ2P3oool0oooo00000080oooo00<000000?oo
o`3oool0=`3oool000X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00`0oooo0`0000001P3oool02NX:00WZ2P09jPX0oooo00WZ2PL0oooo00<02NX:
0?ooo`3oool0103oool300WZ2PT0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo00000003
0?ooo`030000003oool0oooo03L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`080?ooo`<0000000H0oooo00WZ2P09jPX02NX:0?ooo`09
jPX20?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00P3oool400WZ2P/0oooo00<0
2NX:0?ooo`3oool01@3oool00`09jPX0oooo000000020?ooo`030000003oool0oooo03P0oooo0009
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`04
0?ooo`<0000000@0oooo00WZ2P09jPX02NX:103oool01009jPX0oooo0?ooo`09jPX60?ooo`0300WZ
2P3oool02NX:00802NX:0`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00D0oooo
00D02NX:0000003oool0oooo0000000k0?ooo`002@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00`000000103oool02NX:00WZ2P09jPX70?ooo`04
00WZ2P3oool0oooo00WZ2PD0oooo0`09jPX60?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?oo
o`3oool01@3oool2000000030?ooo`000000oooo03/0oooo00090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool06@3oool2000000040?ooo`09jPX02NX:00WZ2PX0oooo00D02NX:0?oo
o`3oool02NX:0?ooo`0400WZ2P030?ooo`09jPX0oooo00H0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`030?ooo`<02NX:0P00000m0?ooo`002@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01X0oooo0`09jPX=0?ooo`0300WZ2P3oool02NX:00802NX:1@3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`09jPX01009jPX01@00
0000oooo0?ooo`3oool0000003d0oooo00090?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool05`3oool400WZ2P030000003oool0oooo00`0oooo0`09jPX00`3oool02NX:0?ooo`050?oo
o`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool01P3oool400WZ2P@0oooo00D000000?oo
o`3oool0oooo0000000n0?ooo`002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01D0oooo0`09jPX40?ooo`030000003oool0oooo00T0oooo0`09jPX01@3oool02NX:0?ooo`3oool0
2NX:00H0oooo00<02NX:0?ooo`3oool01@3oool01009jPX0oooo0?ooo`3oool500WZ2P80oooo00<0
2NX:0?ooo`3oool00`3oool010000000oooo0?ooo`00000o0?ooo`002@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01<0oooo0`09jPX70?ooo`030000003oool0oooo00H0oooo0`09
jPX40?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool01@3oool400WZ2PL0oooo
00<02NX:0?ooo`3oool00P3oool010000000oooo0?ooo`0000100?ooo`002@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0100oooo0`09jPX:0?ooo`030000003oool0oooo00<0oooo
0`09jPX60?ooo`8000000P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00H02NX:
2P3oool01@09jPX0oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0?`3oool000T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`<02NX:3@3oool00`000000oooo
0?ooo`0300WZ2PT0oooo0P0000000`3oool02NX:0?ooo`040?ooo`D02NX:1@3oool00`09jPX0oooo
0?ooo`080?ooo`0400WZ2P3oool0oooo00000080oooo00<000000?ooo`3oool0@03oool000T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`<02NX:403oool300WZ2Pd0oooo
00@02NX:0?ooo`09jPX0oooo1009jPX00`3oool02NX:0?ooo`070?ooo`0300WZ2P3oool0oooo00P0
oooo00<02NX:0?ooo`0000000`3oool00`000000oooo0?ooo`100?ooo`002@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo0`09jPX@0?ooo`<02NX:00<000000?ooo`3oool0
303oool500WZ2PD0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ
2P3oool000000080oooo00<000000?ooo`3oool0@@3oool000P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`<02NX:403oool300WZ2P<0oooo00<000000?ooo`3oool0203o
ool400WZ2P040?ooo`09jPX0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`080?ooo`0500WZ2P000000oooo0?ooo`000000A03oool000P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`<02NX:403oool300WZ2PH0oooo00<000000?ooo`3oool0
0`3oool500WZ2PD0oooo00<02NX:0?ooo`09jPX01P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo00L0oooo00D02NX:0000003oool0oooo000000150?ooo`00203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo0`09jPX@0?ooo`<02NX:2@3oool00`000000oooo
00WZ2P0300WZ2PT0oooo00@02NX:0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo00L0oooo00@02NX:0?ooo`3oool00000AP3oool000P0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`09jPX20000000300WZ2P3oool0oooo00h0oooo0`09jPX60?oo
o`80000000<0oooo00WZ2P09jPX00`09jPX=0?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo00<02NX:
0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`060?ooo`<0000000<0oooo0000003oool0A@3oool0
00P0oooo00<000000?ooo`3oool01`3oool01@0000002NX:00WZ2P09jPX0oooo008000003P3oool3
00WZ2PP0oooo00@02NX:0000000000002NX:0`3oool00`000000oooo0?ooo`0<0?ooo`0400WZ2P3o
ool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:
0`0000170?ooo`00203oool00`000000oooo0?ooo`050?ooo`0300WZ2P0000002NX:0140oooo0`09
jPX80?ooo`<02NX:1`3oool00`000000oooo0?ooo`0<0?ooo`0400WZ2P3oool0oooo00WZ2PH0oooo
00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`020?ooo`<02NX:00@000000?ooo`3oool0
0000B03oool000P0oooo00<000000?ooo`3oool00P3oool300WZ2P030000003oool0oooo00d0oooo
0P09jPX2000000P0oooo0`09jPX:0?ooo`030000003oool0oooo00`0oooo00@02NX:0?ooo`3oool0
2NX:1P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool02NX:00802NX:0P3oool010000000
oooo0?ooo`0000190?ooo`00203oool00`000000oooo00WZ2P0200WZ2P<0oooo00<000000?ooo`3o
ool02P3oool300WZ2P80oooo0P0000050?ooo`<02NX:3@3oool00`000000oooo0?ooo`0<0?ooo`04
00WZ2P3oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool01P3oool300WZ2P@0oooo00@000000?oo
o`3oool00000BP3oool000L0oooo0`09jPX50?ooo`030000003oool0oooo00P0oooo0`09jPX90?oo
o`<02NX:403oool00`000000oooo0?ooo`0<0?ooo`0400WZ2P3oool0oooo00WZ2PD0oooo00<02NX:
0?ooo`3oool00P3oool400WZ2P030?ooo`09jPX0oooo00<0oooo00D000000?ooo`3oool0oooo0000
001:0?ooo`00103oool300WZ2P030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool3
00WZ2PT0oooo0`09jPXB0?ooo`030000003oool0oooo00d0oooo00@02NX:0?ooo`3oool02NX:1@3o
ool00`09jPX0oooo00WZ2P0200WZ2PD0oooo00<02NX:0?ooo`3oool00P3oool010000000oooo0?oo
o`00001;0?ooo`000P3oool200WZ2P@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`<02NX:2@3oool300WZ2QD0oooo00<000000?ooo`3oool03@3oool01009jPX0oooo0?oo
o`09jPX40?ooo`<02NX:203oool01@09jPX0oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0BP3oool000P0oooo00D000000?ooo`3oool0oooo000000040?ooo`<02NX:2@3oool300WZ2QP0
oooo00<000000?ooo`3oool03@3oool01@09jPX0oooo0?ooo`09jPX0oooo00<02NX:00<0oooo00WZ
2P3oool0203oool01009jPX0oooo0?ooo`0000020?ooo`030000003oool0oooo04/0oooo00070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`09jPX00P09jPX90?ooo`<02NX:6`3oool00`00
0000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00<02NX:103oool00`09jPX0oooo0?ooo`070?oo
o`0300WZ2P3oool000000080oooo00<000000?ooo`3oool0C03oool000L0oooo00D000000?ooo`3o
ool0oooo0000000200WZ2PT0oooo0`09jPXN0?ooo`030000003oool0oooo00/0oooo1009jPX00`3o
ool02NX:0?ooo`040?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0000003oool00P3oool00`00
0000oooo0?ooo`1<0?ooo`001`3oool010000000oooo0?ooo`0000070?ooo`8000000`09jPXQ0?oo
o`030000003oool0oooo00P0oooo0`09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo
00<0oooo00<02NX:0?ooo`3oool01`3oool01@09jPX000000?ooo`3oool0000004l0oooo00070?oo
o`030000003oool0000000H0oooo0P09jPX2000002@0oooo00<000000?ooo`3oool01@3oool300WZ
2P@0oooo00D02NX:0?ooo`3oool0oooo00WZ2P050?ooo`0300WZ2P3oool0oooo00L0oooo0P000000
0`3oool000000?ooo`1?0?ooo`001`3oool2000000@0oooo0`09jPXX0?ooo`030000003oool0oooo
0080oooo0`09jPX70?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`05
0?ooo`<02NX:0P00001A0?ooo`001`3oool00`000000oooo0?ooo`0300WZ2R/0oooo00<0000000WZ
2P09jPX00P09jPX:0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0103oool00`09jPX0oooo0?ooo`02
0?ooo`@02NX:00@000000?ooo`3oool00000DP3oool000L0oooo00<0000000WZ2P09jPX0;03oool3
00WZ2Ph0oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`D02NX:0`3oool01@000000oooo0?oo
o`3oool000000580oooo00040?ooo`<02NX:00<000000?ooo`3oool0:@3oool300WZ2P80oooo00<0
00000?ooo`3oool0303oool01P09jPX0oooo0?ooo`3oool02NX:0?ooo`@02NX:1`3oool010000000
oooo0?ooo`00001C0?ooo`0000@0oooo00WZ2P09jPX02NX:103oool00`000000oooo0?ooo`0U0?oo
o`<02NX:1@3oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool02NX:00<02NX:0`3oool00`09
jPX0oooo0?ooo`040?ooo`040000003oool0oooo000005@0oooo00000`09jPX0oooo0?ooo`050?oo
o`030000003oool0oooo0200oooo0P00000300WZ2PP0oooo00<000000?ooo`3oool02P3oool400WZ
2P80oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`030?ooo`040000003oool0oooo
000005D0oooo00080?ooo`030000003oool0oooo01h0oooo0P09jPX2000000/0oooo00<000000?oo
o`3oool01`3oool300WZ2P030?ooo`09jPX0oooo00<0oooo00<02NX:0?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`020?ooo`040000003oool0oooo000005H0oooo00090?ooo`030000003oool0oooo
01X0oooo0`09jPX?0?ooo`030000003oool0oooo00<0oooo1009jPX40?ooo`0300WZ2P3oool0oooo
0080oooo00<02NX:0?ooo`3oool00P3oool01@09jPX0oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0E03oool000T0oooo00<000000?ooo`3oool05P3oool400WZ2Q80oooo00<000000?oo
o`09jPX00`09jPX80?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01@09
jPX0oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0E@3oool000T0oooo00<000000?oo
o`3oool04`3oool300WZ2Q@0oooo1009jPX<0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool00P3oool01009jPX0oooo0?ooo`0000020?ooo`030000003oool0oooo05H0oooo00090?oo
o`030000003oool0oooo00l0oooo1009jPXA0?ooo`8000001009jPX20?ooo`030000003oool0oooo
00/0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool00000
0080oooo00<000000?ooo`3oool0E`3oool000X0oooo00<000000?ooo`3oool02`3oool300WZ2Q<0
oooo0P09jPX2000000H0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`020?ooo`07
00WZ2P3oool0oooo0?ooo`09jPX0oooo000000020?ooo`030000003oool0oooo05P0oooo000:0?oo
o`030000003oool0oooo00T0oooo0P09jPXC0?ooo`<02NX:2P3oool00`000000oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo0080oooo00H02NX:0?ooo`3oool0oooo00WZ2P0000020?ooo`030000003o
ool0oooo05T0oooo000:0?ooo`030000003oool0oooo01/0oooo0`09jPX=0?ooo`030000003oool0
oooo00/0oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?ooo`3oool02NX:00000080oooo
00<000000?ooo`3oool0F@3oool000/0oooo00<000000?ooo`3oool05`3oool300WZ2Q00oooo00<0
00000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo008000000P3o
ool00`000000oooo0?ooo`1J0?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`@02NX:4`3oool0
0`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX00P000000
0`3oool000000?ooo`1L0?ooo`002`3oool00`000000oooo0?ooo`0@0?ooo`<02NX:5`3oool00`00
0000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0080oooo0`09jPX010000000oooo0?ooo`00001N
0?ooo`002`3oool00`000000oooo0?ooo`0=0?ooo`<02NX:6P3oool00`000000oooo0?ooo`0:0?oo
o`0300WZ2P3oool02NX:00802NX:00<0oooo00WZ2P0000000P3oool00`000000oooo0?ooo`1M0?oo
o`00303oool00`000000oooo0?ooo`060?ooo`80000000@0oooo00WZ2P09jPX02NX:7@3oool00`00
0000oooo0?ooo`090?ooo`<02NX:103oool01@09jPX000000?ooo`3oool0000005l0oooo000<0?oo
o`030000003oool0oooo00D0oooo00@02NX:0000000000002NX:803oool00`000000oooo0?ooo`06
0?ooo`<02NX:00<0oooo00WZ2P3oool0103oool01009jPX0oooo0?ooo`00001P0?ooo`00303oool0
0`000000oooo0?ooo`020?ooo`<02NX:903oool00`000000oooo0?ooo`020?ooo`@02NX:103oool0
0`09jPX0oooo0?ooo`020?ooo`0400000009jPX0oooo00000640oooo000=0?ooo`0400000009jPX0
2NX:00WZ2RL0oooo00<000000?ooo`09jPX00P09jPX80?ooo`0600WZ2P3oool0oooo0?ooo`000000
oooo0P00001R0?ooo`002P3oool300WZ2P030000003oool0oooo02L0oooo0`09jPX;0?ooo`0400WZ
2P3oool0oooo000000802NX:0P00001R0?ooo`001`3oool300WZ2P<0oooo00<000000?ooo`3oool0
903oool300WZ2P030?ooo`000000oooo00/0oooo1009jPX20?ooo`030000003oool0oooo0640oooo
00040?ooo`<02NX:1P3oool00`000000oooo0?ooo`0N0?ooo`80000000@0oooo00WZ2P09jPX02NX:
103oool00`000000oooo0?ooo`080?ooo`<02NX:00D0oooo0000003oool0oooo0000001T0?ooo`00
00@0oooo00WZ2P09jPX02NX:2P3oool00`000000oooo0?ooo`0L0?ooo`0400WZ2P000000000000WZ
2PL0oooo00<000000?ooo`3oool0103oool400WZ2P040?ooo`09jPX0oooo00000080oooo00<00000
0?ooo`3oool0H`3oool0000300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0603oool400WZ
2P/0oooo00@000000?ooo`3oool0oooo0`09jPX50?ooo`0500WZ2P000000oooo0?ooo`000000IP3o
ool000h0oooo00<000000?ooo`3oool05@3oool300WZ2Ph0oooo00<000000?ooo`09jPX00P09jPX8
0?ooo`0400WZ2P3oool0oooo000006L0oooo000>0?ooo`030000003oool0oooo0140oooo1009jPX?
0?ooo`@02NX:2P3oool01@0000002NX:0?ooo`3oool0000006L0oooo000?0?ooo`030000003oool0
oooo00`0oooo1009jPX@0?ooo`<02NX:0P3oool00`000000oooo0?ooo`080?ooo`0500WZ2P000000
00000?ooo`000000J03oool000l0oooo00<000000?ooo`3oool02@3oool300WZ2Q40oooo0`09jPX5
0?ooo`030000003oool0oooo00D0oooo0`09jPX4000006T0oooo000?0?ooo`030000003oool0oooo
00L0oooo0P09jPXA0?ooo`<02NX:203oool00`000000oooo0?ooo`020?ooo`<02NX:0P3oool01000
0000oooo0?ooo`00001Z0?ooo`00403oool00`000000oooo0?ooo`0E0?ooo`@02NX:2`3oool00`00
0000oooo00WZ2P0200WZ2P@0oooo00@000000?ooo`3oool00000J`3oool00100oooo00<000000?oo
o`3oool04P3oool300WZ2Pd0oooo1009jPX60?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0100oooo00<000000?ooo`3oool0303oool2000000040?ooo`09jPX02NX:00WZ2Pd0oooo0`09jPX2
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000K03oool00100oooo00<00000
0?ooo`3oool02`3oool01009jPX0000000000009jPX=0?ooo`<02NX:1@3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000006d0oooo000A0?ooo`030000003oool0oooo00H0oooo1009
jPX;0?ooo`80000000@0oooo00WZ2P09jPX02NX:203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000006h0oooo000A0?ooo`030000003oool0oooo0080oooo1009jPX>0?ooo`0400WZ
2P000000000000WZ2P/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00001_0?oo
o`004@3oool00`000000oooo00WZ2P0200WZ2Ph0oooo1009jPX?0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`1^0?ooo`003`3oool300WZ2P030000003oool0oooo00`0
oooo0`09jPXC0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1^0?oo
o`002`3oool400WZ2P<0oooo00<000000?ooo`3oool0203oool400WZ2QH0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`1_0?ooo`002@3oool200WZ2PL0oooo00<000000?ooo`3o
ool0103oool400WZ2QX0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1`0?ooo`00
4P3oool010000000oooo0?ooo`3oool300WZ2Qh0oooo0P0000020?ooo`030000003oool0oooo0740
oooo000C0?ooo`0300000009jPX02NX:0240oooo00@000000?ooo`3oool00000M03oool001<0oooo
00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00001d0?ooo`004`3oool00`000000oooo
0?ooo`0P0?ooo`040000003oool0oooo000007D0oooo000D0?ooo`030000003oool0oooo01h0oooo
00@000000?ooo`3oool00000MP3oool001@0oooo00<000000?ooo`3oool07@3oool010000000oooo
0?ooo`00001g0?ooo`00503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0000007P0oooo
000D0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool00000N03oool001D0oooo00<0
00000?ooo`3oool06P3oool010000000oooo0?ooo`00001i0?ooo`005@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0000007X0oooo000E0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`000000N`3oool001H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000001l0?oo
o`005P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000007`0oooo000F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`000000O@3oool001H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0000001n0?ooo`005`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0000007l0oooo000G0?ooo`030000003oool0oooo01<0oooo0P0000200?ooo`005`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool000000800oooo000H0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`000000P@3oool001P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
000000220?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`800000P`3oool001P0oooo00<00000
0?ooo`3oool03P3oool2000008@0oooo000I0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000Q03oool001T0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000250?ooo`00
6@3oool00`000000oooo0?ooo`0;0?ooo`800000QP3oool001T0oooo00<000000?ooo`3oool02P3o
ool2000008L0oooo000J0?ooo`030000003oool0oooo00P0oooo0P0000280?ooo`006P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo08L0oooo000J0?ooo`030000003oool0oooo00L0
oooo0P0000290?ooo`006`3oool00`000000oooo0?ooo`050?ooo`800000RP3oool001/0oooo00<0
00000?ooo`3oool0103oool2000008/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0RP3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2;0?oo
o`00703oool010000000oooo0?ooo`3oool2000008d0oooo000L0?ooo`050000003oool0oooo0?oo
o`000000SP3oool001`0oooo00@000000?ooo`3oool00000S`3oool001d0oooo0P00002@0?ooo`00
7@3oool00`000000oooo0?ooo`2?0?ooo`00[`3oool00:l0oooo0000\
\>"],
  ImageRangeCache->{{{-37.8125, 214.562}, {234.562, -28.125}} -> {0.171148, \
-0.105318, 0.00374448, 0.00374448}},
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->TopView];", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49823 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0474504 0.249115 0.0474504 [
[ 0 0 0 0 ]
[ 1 .49823 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16616 .01186 m
.16616 .01186 L
.16616 .24911 L
.16616 .48637 L
.16616 .48637 L
.16616 .01186 L
s
.16616 .48637 m
.64067 .48637 L
.97619 .24911 L
.64067 .01186 L
.16616 .01186 L
.16616 .48637 L
s
.16616 .48637 m
.16616 .24911 L
.97619 .24911 L
.64067 .48637 L
.16616 .48637 L
s
.64067 .01186 m
.97619 .24911 L
.16616 .24911 L
.16616 .01186 L
.64067 .01186 L
s
.16616 .48637 m
.16616 .48637 L
.64067 .48637 L
.16616 .48637 L
s
.16616 .01186 m
.64067 .01186 L
.16616 .01186 L
.16616 .01186 L
s
.039 .916 .04 r
.02381 .39147 m
.16616 .39147 L
s
0 0 0 r
2 Mabswid
.16616 .39147 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .34977 m
.16616 .34977 L
s
0 0 0 r
2 Mabswid
.16616 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24911 m
.16616 .24911 L
s
0 0 0 r
2 Mabswid
.16616 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14846 m
.16616 .14846 L
s
0 0 0 r
2 Mabswid
.16616 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .10676 m
.16616 .10676 L
s
0 0 0 r
2 Mabswid
.16616 .10676 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14846 m
.16616 .14846 L
s
0 0 0 r
2 Mabswid
.16616 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24911 m
.16616 .24911 L
s
0 0 0 r
2 Mabswid
.16616 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .34977 m
.16616 .34977 L
s
0 0 0 r
2 Mabswid
.16616 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .39147 m
.36986 .39147 L
s
0 0 0 r
2 Mabswid
.36986 .39147 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .34977 m
.32817 .34977 L
s
0 0 0 r
2 Mabswid
.32817 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .24911 m
.42882 .24911 L
s
0 0 0 r
2 Mabswid
.42882 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .14846 m
.32817 .14846 L
s
0 0 0 r
2 Mabswid
.32817 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .10676 m
.36986 .10676 L
s
0 0 0 r
2 Mabswid
.36986 .10676 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .14846 m
.52948 .14846 L
s
0 0 0 r
2 Mabswid
.52948 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .24911 m
.71353 .24911 L
s
0 0 0 r
2 Mabswid
.71353 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.16616 .34977 m
.52948 .34977 L
s
0 0 0 r
2 Mabswid
.52948 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.36986 .39147 m
.57118 .10676 L
s
0 0 0 r
2 Mabswid
.57118 .10676 Mdot
.039 .916 .04 r
.5 Mabswid
.32817 .34977 m
.47052 .14846 L
s
0 0 0 r
2 Mabswid
.47052 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.42882 .24911 m
.42882 .24911 L
s
0 0 0 r
2 Mabswid
.42882 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.32817 .14846 m
.47052 .34977 L
s
0 0 0 r
2 Mabswid
.47052 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.36986 .10676 m
.57118 .39147 L
s
0 0 0 r
2 Mabswid
.57118 .39147 Mdot
.039 .916 .04 r
.5 Mabswid
.52948 .14846 m
.67183 .34977 L
s
0 0 0 r
2 Mabswid
.67183 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.71353 .24911 m
.71353 .24911 L
s
0 0 0 r
2 Mabswid
.71353 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.52948 .34977 m
.67183 .14846 L
s
0 0 0 r
2 Mabswid
.67183 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.57118 .10676 m
.57118 .10676 L
s
0 0 0 r
2 Mabswid
.57118 .10676 Mdot
.039 .916 .04 r
.5 Mabswid
.47052 .14846 m
.47052 .14846 L
s
0 0 0 r
2 Mabswid
.47052 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.42882 .24911 m
.42882 .24911 L
s
0 0 0 r
2 Mabswid
.42882 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.47052 .34977 m
.47052 .34977 L
s
0 0 0 r
2 Mabswid
.47052 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.57118 .39147 m
.57118 .39147 L
s
0 0 0 r
2 Mabswid
.57118 .39147 Mdot
.039 .916 .04 r
.5 Mabswid
.67183 .34977 m
.67183 .34977 L
s
0 0 0 r
2 Mabswid
.67183 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.71353 .24911 m
.71353 .24911 L
s
0 0 0 r
2 Mabswid
.71353 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.67183 .14846 m
.67183 .14846 L
s
0 0 0 r
2 Mabswid
.67183 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.57118 .10676 m
.57118 .10676 L
s
0 0 0 r
2 Mabswid
.57118 .10676 Mdot
.039 .916 .04 r
.5 Mabswid
.47052 .14846 m
.47052 .14846 L
s
0 0 0 r
2 Mabswid
.47052 .14846 Mdot
.039 .916 .04 r
.5 Mabswid
.42882 .24911 m
.42882 .24911 L
s
0 0 0 r
2 Mabswid
.42882 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.47052 .34977 m
.47052 .34977 L
s
0 0 0 r
2 Mabswid
.47052 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.57118 .39147 m
.57118 .39147 L
s
0 0 0 r
2 Mabswid
.57118 .39147 Mdot
.039 .916 .04 r
.5 Mabswid
.67183 .34977 m
.67183 .34977 L
s
0 0 0 r
2 Mabswid
.67183 .34977 Mdot
.039 .916 .04 r
.5 Mabswid
.71353 .24911 m
.71353 .24911 L
s
0 0 0 r
2 Mabswid
.71353 .24911 Mdot
.039 .916 .04 r
.5 Mabswid
.67183 .14846 m
.67183 .14846 L
s
0 0 0 r
2 Mabswid
.67183 .14846 Mdot
0 0 m
1 0 L
1 .49823 L
0 .49823 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{263, 130.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000470000PR000`400?l00000o`00003oo`3oool8
0?ooo`00o`3oool80?ooo`00;03oool00`000000oooo0?ooo`3H0?ooo`00:`3ooomn000005h0oooo
000[0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0F`3oool002/0oooo00<00000
0?ooo`3oool0O03oool2000005/0oooo000[0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0F03oool002/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1G0?ooo`00
:`3oool00`000000oooo0?ooo`200?ooo`800000E`3oool002/0oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`1D0?ooo`00:`3oool00`000000oooo0?ooo`230?ooo`800000E03oool0
02/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1A0?ooo`00:`3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0500oooo000[0?ooo`030000003oool0oooo08L0oooo
0P00001@0?ooo`00:`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04d0oooo000[
0?ooo`030000003oool0oooo08X0oooo0P00001=0?ooo`00:`3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo04X0oooo000[0?ooo`030000003oool0oooo08d0oooo0P00001:0?ooo`00
:`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo04L0oooo000[0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0AP3oool002/0oooo00<000000?ooo`3oool0T@3oool2
000004H0oooo000[0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0@`3oool002/0
oooo00<000000?ooo`3oool0U03oool2000004<0oooo000[0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0@03oool002/0oooo00<000000?ooo`3oool0U`3oool200000400oooo000[
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0?@3oool002/0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`0l0?ooo`001P3ooomJ00WZ2P0300000009jPX0oooo0380
oooo0P00000b0?ooo`800000?03oool002/0oooo0P00000c0?ooo`0300000009jPX0oooo0380oooo
0P00000d0?ooo`030000003oool0oooo03T0oooo000[0?ooo`030000003oool0oooo03@0oooo00<0
2NX:0?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`0e0?ooo`800000>@3oool002/0oooo00<00000
0?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo03P0oooo00<00000
0?ooo`3oool0=P3oool002/0oooo00<000000?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`0]0?oo
o`0300WZ2P3oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool002/0oooo00<000000?ooo`3o
ool0=P3oool00`09jPX0oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo03/0oooo0P00000e0?ooo`00
:`3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3oool0oooo02T0oooo00<02NX:0?ooo`3oool0
?P3oool00`000000oooo0?ooo`0b0?ooo`00:`3oool00`000000oooo0?ooo`0h0?ooo`0300WZ2P3o
ool0oooo02L0oooo00<02NX:0?ooo`3oool0@03oool200000380oooo000[0?ooo`030000003oool0
oooo03P0oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`120?ooo`030000003oool0
oooo02l0oooo000[0?ooo`030000003oool0oooo03T0oooo00<02NX:0?ooo`3oool09@3oool00`09
jPX0oooo0?ooo`140?ooo`800000;`3oool002/0oooo00<000000?ooo`3oool0>P3oool00`09jPX0
oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo04L0oooo00<000000?ooo`3oool0;03oool000H0oooo
M009jPX2000000l02NX:00@000000?ooo`3oool02NX:803oool2000002P0oooo00<000000?ooo`3o
ool0:`3oool002/0oooo0P00000X0?ooo`0300000009jPX0oooo0140oooo00<02NX:0?ooo`3oool0
3P3oool2000000h0oooo00@02NX:0000003oool02NX:8@3oool2000002T0oooo0P00000[0?ooo`00
:`3oool00`000000oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0
3@3oool00`09jPX0oooo0?ooo`0>0?ooo`802NX:8@3oool00`09jPX0oooo0?ooo`0[0?ooo`030000
003oool0oooo02P0oooo000[0?ooo`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool03`3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool07P3o
ool00`09jPX0oooo0?ooo`0]0?ooo`800000:03oool002/0oooo00<000000?ooo`3oool0:P3oool0
0`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03`3oool2
00WZ2R00oooo00<02NX:0?ooo`3oool0;`3oool00`000000oooo0?ooo`0U0?ooo`00:`3oool00`00
0000oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02@3oool00`09
jPX0oooo0?ooo`0?0?ooo`0400WZ2P3oool0oooo00WZ2Qh0oooo00<02NX:0?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0T0?ooo`00:`3oool00`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo
00l0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0@0?ooo`0500WZ2P3oool0oooo
0?ooo`09jPX0703oool00`09jPX0oooo0?ooo`0c0?ooo`800000903oool002/0oooo00<000000?oo
o`3oool0;@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?oo
o`3oool0=P3oool00`000000oooo0?ooo`0Q0?ooo`00:`3oool00`000000oooo0?ooo`0]0?ooo`03
00WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0?0?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`0g0?ooo`80
00008@3oool002/0oooo00<000000?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`00:`3o
ool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0503o
ool00`09jPX0oooo0?ooo`0l0?ooo`8000007P3oool002/0oooo00<000000?ooo`3oool0;`3oool0
0`09jPX0oooo0?ooo`0@0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX04@3oool00`09jPX0oooo0?oo
o`080?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool0?P3oool00`000000oooo0?oo
o`0K0?ooo`00:`3oool00`000000oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:
0?ooo`09jPX04@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:
0?ooo`3oool0@03oool00`000000oooo0?ooo`0J0?ooo`00:`3oool00`000000oooo0?ooo`0a0?oo
o`0300WZ2P3oool0oooo00l0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`120?ooo`8000006P3oool002/0oooo00<000000?ooo`3o
ool0<@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3o
ool0303oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo04@0oooo00<000000?ooo`3o
ool05`3oool002/0oooo00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ
2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ
2P3oool0oooo04H0oooo0P00000G0?ooo`00:`3oool00`000000oooo0?ooo`0c0?ooo`0300WZ2P3o
ool0oooo00`0oooo00@02NX:0?ooo`3oool02NX:3`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ
2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool0B@3oool00`000000oooo0?ooo`0D0?ooo`00:`3o
ool00`000000oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`1;0?ooo`800000503oool002/0oooo00<000000?ooo`3oool0=03oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool02@3oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0A0?ooo`00:`3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo
00P0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo
01<0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000[0?ooo`030000003oool0oooo03H0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0540oooo0P00000@0?ooo`00:`3oool00`000000oooo
0?ooo`0f0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`1C0?ooo`030000003oool0oooo00d0oooo000[0?ooo`030000003oool0oooo03L0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool0603oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo05D0oooo0P00
000=0?ooo`00:`3oool00`000000oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`1H0?ooo`030000003oool0oooo00X0oooo000[0?oo
o`030000003oool0oooo03P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0500WZ2P3oool0oooo0?ooo`09jPX0703oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0
oooo05T0oooo00<000000?ooo`3oool02@3oool002/0oooo00<000000?ooo`3oool0>@3oool01009
jPX0oooo0?ooo`09jPX?0?ooo`0300WZ2P3oool02NX:01h0oooo00@02NX:0?ooo`3oool02NX:G@3o
ool2000000T0oooo000[0?ooo`800000>`3oool200WZ2PD0oooo0P0000090?ooo`0300WZ2P3oool0
2NX:01l0oooo0P09jPXL0?ooo`800000@P3oool00`000000oooo0?ooo`060?ooo`001P3ooomY00WZ
2P800000B@09jPY6000000L0oooo000[0?ooo`030000003oool0oooo03X0oooo0P09jPX@0?ooo`03
00WZ2P3oool02NX:01l0oooo0P09jPYO0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030000
003oool0oooo03T0oooo00@02NX:0?ooo`3oool02NX:3`3oool00`09jPX0oooo00WZ2P0N0?ooo`04
00WZ2P3oool0oooo00WZ2U`0oooo0P00000:0?ooo`00:`3oool00`000000oooo0?ooo`0h0?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02`3oool01@09jPX0oooo0?ooo`3oool02NX:
01`0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`1H0?ooo`030000003oool0oooo
00X0oooo000[0?ooo`030000003oool0oooo03P0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo05L0oooo00<000000?ooo`3oool02`3oool002/0oooo
00<000000?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T0oooo
00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00@0oooo
00<02NX:0?ooo`3oool0E03oool2000000h0oooo000[0?ooo`030000003oool0oooo03H0oooo00<0
2NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo0580oooo00<0
00000?ooo`3oool03P3oool002/0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`06
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0E
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0D03oool200000140oooo000[0?oo
o`030000003oool0oooo03D0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`040?oo
o`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`080?oo
o`0300WZ2P3oool0oooo04h0oooo00<000000?ooo`3oool04@3oool002/0oooo00<000000?ooo`3o
ool0=03oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool02@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool0B`3oool2000001@0oooo000[0?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3oool0
2P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
4@3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo04X0oooo00<000000?ooo`3oool0
503oool002/0oooo00<000000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`0<0?ooo`0400WZ2P3o
ool0oooo00WZ2Pl0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ
2P3oool0oooo04L0oooo0P00000G0?ooo`00:`3oool00`000000oooo0?ooo`0b0?ooo`0300WZ2P3o
ool0oooo00h0oooo00<02NX:0?ooo`09jPX03`3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3o
ool0oooo00h0oooo00<02NX:0?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool0
0`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool03`3oool0
0`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo
00l0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0403oool00`09
jPX0oooo0?ooo`110?ooo`8000006`3oool002/0oooo00<000000?ooo`3oool0<03oool00`09jPX0
oooo0?ooo`0@0?ooo`0300WZ2P3oool02NX:0140oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo03l0oooo00<000000?ooo`3oool06`3oool002/0oooo
00<000000?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`0@0?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX04@3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:0?ooo`3o
ool0?03oool2000001h0oooo000[0?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool0
3`3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0
1`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo03/0oooo00<000000?ooo`3oool0
7P3oool002/0oooo00<000000?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3o
ool0oooo01H0oooo00<02NX:0?ooo`3oool0>03oool200000240oooo000[0?ooo`030000003oool0
oooo02d0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0
oooo03H0oooo00<000000?ooo`3oool08@3oool002/0oooo00<000000?ooo`3oool0;@3oool00`09
jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0403oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0=03oool20000
02@0oooo000[0?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0100oooo00D02NX:0?ooo`3oool0oooo00WZ2P0L0?oo
o`0300WZ2P3oool0oooo0380oooo00<000000?ooo`3oool0903oool002/0oooo00<000000?ooo`3o
ool0:`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3o
ool03`3oool01009jPX0oooo0?ooo`09jPXN0?ooo`0300WZ2P3oool0oooo0300oooo00<000000?oo
o`3oool09@3oool002/0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`0@0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03`3oool200WZ2R00oooo00<02NX:0?ooo`3o
ool0;@3oool2000002P0oooo000[0?ooo`030000003oool0oooo02X0oooo00<02NX:0?ooo`3oool0
3`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool0
7P3oool00`09jPX0oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo000[0?ooo`800000:03o
ool20000000300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool03@3oool2000000h0oooo00<0
000000WZ2P09jPX08@3oool00`09jPX000000000000Y0?ooo`800000:`3oool000H0ooooM009jPX2
000000l02NX:00<000000?ooo`09jPX08@3oool2000002P0oooo00<000000?ooo`3oool0:`3oool0
02/0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo
04H0oooo0P00000^0?ooo`00:`3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo02<0
oooo00<02NX:0?ooo`3oool0A@3oool00`000000oooo0?ooo`0^0?ooo`00:`3oool00`000000oooo
0?ooo`0i0?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool0@P3oool200000340oooo
000[0?ooo`030000003oool0oooo03P0oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?oo
o`100?ooo`030000003oool0oooo0340oooo000[0?ooo`030000003oool0oooo03P0oooo00<02NX:
0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0o0?ooo`030000003oool0oooo0380oooo000[0?oo
o`030000003oool0oooo03L0oooo00<02NX:0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0l0?oo
o`800000=@3oool002/0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0[0?ooo`03
00WZ2P3oool0oooo03X0oooo00<000000?ooo`3oool0=@3oool002/0oooo00<000000?ooo`3oool0
=@3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo03L0oooo0P00000h0?ooo`00:`3o
ool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo02d0oooo00<02NX:0?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00:`3oool2000003<0oooo0P0000000`09jPX0oooo0?ooo`0_
0?ooo`0300WZ2P000000000003<0oooo0P00000k0?ooo`001P3ooomJ00WZ2P0300000009jPX0oooo
0380oooo0P00000b0?ooo`030000003oool0oooo03/0oooo000[0?ooo`030000003oool0oooo09T0
oooo0P00000n0?ooo`00:`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo03h0oooo
000[0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0?`3oool002/0oooo00<00000
0?ooo`3oool0U@3oool200000480oooo000[0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0@P3oool002/0oooo00<000000?ooo`3oool0TP3oool2000004D0oooo000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0A@3oool002/0oooo00<000000?ooo`3oool0S`3o
ool2000004P0oooo000[0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0B03oool0
02/0oooo00<000000?ooo`3oool0S03oool2000004/0oooo000[0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0B`3oool002/0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`1<0?ooo`00:`3oool00`000000oooo0?ooo`280?ooo`800000C`3oool002/0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`1?0?ooo`00:`3oool00`000000oooo0?ooo`250?oo
o`800000DP3oool002/0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1B0?ooo`00
:`3oool00`000000oooo0?ooo`220?ooo`800000E@3oool002/0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`1E0?ooo`00:`3oool00`000000oooo0?ooo`1o0?ooo`800000F03oool0
02/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1H0?ooo`00:`3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo05T0oooo000[0?ooo`030000003oool0oooo07/0oooo
0P00001L0?ooo`00:`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo05`0oooo000[
0?ooogd00000G`3oool00?l0oooo203oool00?l0oooo203oool00?l0oooo203oool00001\
\>"],
  ImageRangeCache->{{{0, 262}, {129.938, 0}} -> {-0.550439, -5.25006, \
0.080809, 0.080809}},
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[RoofPrism[10,Mirrored->True,FullForm->True]]", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.09828 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0635357 1.13214 1.11022e-16 1.13214 [
[ 0 0 0 0 ]
[ 1 1.09828 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09828 L
0 1.09828 L
closepath
clip
newpath
.48742 .58149 m .82311 .16935 L .64496 .38367 L 0 0 0 r
F
.48742 .58149 m .64496 .38367 L .29746 .81353 L F
0 g
.5 Mabswid
[ ] 0 setdash
.31417 .49682 m
.64496 .38367 L
s
.09968 .27755 m
.31417 .49682 L
s
.48742 .58149 m .29746 .81353 L .16273 .98658 L 0 0 0 r
F
0 g
.29746 .81353 m
.31417 .49682 L
s
.29746 .81353 m
.64496 .38367 L
s
.48742 .58149 m .16273 .98658 L .82311 .16935 L 0 0 0 r
F
.38177 .46807 m .82311 .16935 L .16273 .98658 L .728 .576 .684 r
F
.38177 .46807 m .45519 .13768 L .82311 .16935 L F
.38177 .46807 m .05967 .61022 L .45519 .13768 L F
0 g
.45519 .13768 m
.82311 .16935 L
s
.09968 .27755 m
.45519 .13768 L
s
.38177 .46807 m .16273 .98658 L .05967 .61022 L .728 .576 .684 r
F
0 g
.05967 .61022 m
.09968 .27755 L
s
.16273 .98658 m
.82311 .16935 L
s
.05967 .61022 m
.45519 .13768 L
s
.05967 .61022 m
.16273 .98658 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{147.188, 161.25},
  ImageMargins->{{38, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002C0000XB000`400?l00000o`00003oT`3oool0
09<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3o
ool009<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00
T`3oool009<0oooo00110?ooo`L00000B`3oool003h0oooo0`0000000`3oool000000;ZC[`040;ZC
[`/00000@03oool003`0oooo0P0000030?ooo`030000002jTjl0^Y>_00l0^Y>_2`00000e0?ooo`00
>@3oool3000000@0oooo00<000000;ZC[`2jTjl06`2jTjl;000002X0oooo000g0?ooo`8000001P3o
ool00`000000^Y>_0;ZC[`0W0;ZC[`/000007`3oool003@0oooo0`0000070?ooo`030000002jTjl0
^Y>_03<0^Y>_1@00000J0?ooo`00<P3oool2000000T0oooo00<000000;ZC[`2jTjl0>02jTjl00`00
0000oooo0?ooo`0H0?ooo`00;`3oool3000000/0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000
oooo0?ooo`0I0?ooo`00;@3oool2000000d0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo
0?ooo`0J0?ooo`00:P3oool3000000h0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo0?oo
o`0K0?ooo`00:03oool200000100oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo0?ooo`0L
0?ooo`009P3oool200000140oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0L0?oo
o`008`3oool300000180oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0M0?ooo`00
8@3oool2000001@0oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0N0?ooo`007P3o
ool3000001H0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo0?ooo`0O0?ooo`00703oool2
000001P0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo0?ooo`0P0?ooo`006@3oool30000
01T0oooo00<000000;ZC[`2jTjl0=`2jTjl00`000000oooo0?ooo`0Q0?ooo`005`3oool2000001/0
oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0Q0?ooo`00503oool3000001`0oooo
00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0R0?ooo`004P3oool2000001h0oooo00<0
00000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0S0?ooo`003`3oool300000200oooo00<00000
0;ZC[`2jTjl0=`2jTjl00`000000oooo0?ooo`0T0?ooo`003P3oool00`000000oooo0?ooo`0P0?oo
o`030000002jTjl0^Y>_03L0^Y>_00<000000?ooo`3oool09@3oool000h0oooo00<000000?ooo`3o
ool07`3oool00`000000^Y>_0;ZC[`0h0;ZC[`030000003oool0oooo02D0oooo000>0?ooo`800000
7`3oool00`000000^Y>_0;ZC[`0h0;ZC[`030000003oool0oooo02H0oooo000>0?ooo`030000003o
ool0000001d0oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0W0?ooo`003P3oool0
10000000oooo0?ooo`00000K0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0:03o
ool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000002jTjl0
^Y>_03L0^Y>_00<000000?ooo`3oool0:@3oool000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0F0?ooo`030000002jTjl0^Y>_03L0^Y>_00<000000?ooo`3oool0:P3oool000d0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000002jTjl0^Y>_03P0
^Y>_00<000000?ooo`3oool0:P3oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0B0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0:`3oool000d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000002jTjl0^Y>_03P0^Y>_00<0
00000?ooo`3oool0;03oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0;@3oool000d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000002jTjl0^Y>_03L0^Y>_00<000000?oo
o`3oool0;P3oool000d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0;P3oool000`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0
;`3oool000`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000002j
Tjl0^Y>_03P0^Y>_00<000000?ooo`3oool0<03oool000`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0<@3oool0
00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000002jTjl0^Y>_
03P0^Y>_00<000000?ooo`3oool0<P3oool000`0oooo00<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool0000003/0^Y>_00<000000?ooo`3oool0<P3oool000`0oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000j0;ZC[`030000003oool0oooo03<0oooo000<0?ooo`03
0000003oool0oooo0140oooo0P00000j0;ZC[`030000003oool0oooo03@0oooo000<0?ooo`030000
003oool0oooo0140oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0e0?ooo`002`3o
ool00`000000oooo0?ooo`0A0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0=P3o
ool000/0oooo00<000000?ooo`3oool0403oool00`000000^Y>_0;ZC[`0h0;ZC[`030000003oool0
oooo03L0oooo000;0?ooo`030000003oool0oooo00l0oooo00<000000;ZC[`2jTjl0>@2jTjl00`00
0000oooo0?ooo`0g0?ooo`002`3oool00`000000oooo0?ooo`0?0?ooo`030000002jTjl0^Y>_03P0
^Y>_00<000000?ooo`3oool0>03oool000/0oooo00<000000?ooo`3oool03P3oool00`000000^Y>_
0;ZC[`0h0;ZC[`030000003oool0oooo03T0oooo000;0?ooo`030000003oool0oooo00d0oooo00<0
00000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`0j0?ooo`002`3oool00`000000oooo0?ooo`0<
0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0>`3oool000/0oooo00<000000?oo
o`3oool02`3oool00`000000^Y>_0;ZC[`0i0;ZC[`030000003oool0oooo03/0oooo000:0?ooo`03
0000003oool0oooo00/0oooo00<000000;ZC[`2jTjl0>@2jTjl00`000000oooo0?ooo`0l0?ooo`00
2P3oool00`000000oooo0?ooo`0;0?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0
?@3oool000X0oooo00<000000?ooo`3oool02P3oool00`000000^Y>_0;ZC[`0h0;ZC[`030000003o
ool0oooo03h0oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000;ZC[`2jTjl0>02jTjl0
0`000000oooo0?ooo`0o0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000002jTjl0^Y>_
03P0^Y>_00<000000?ooo`3oool0@03oool000X0oooo00<000000?ooo`3oool01`3oool00`000000
^Y>_0;ZC[`0i0;ZC[`030000003oool0oooo0400oooo000:0?ooo`030000003oool0oooo00H0oooo
00<000000;ZC[`2jTjl0>@2jTjl00`000000oooo0?ooo`110?ooo`002P3oool00`000000oooo0?oo
o`060?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0@P3oool000T0oooo00<00000
0?ooo`3oool01P3oool00`000000^Y>_0;ZC[`0h0;ZC[`030000003oool0oooo04<0oooo00090?oo
o`030000003oool0oooo00D0oooo00<000000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`140?oo
o`002@3oool00`000000oooo0?ooo`040?ooo`030000002jTjl0^Y>_03T0^Y>_00<000000?ooo`3o
ool0A03oool000T0oooo00<000000?ooo`3oool00`3oool00`000000^Y>_0;ZC[`0i0;ZC[`030000
003oool0oooo04D0oooo00090?ooo`030000003oool0oooo0080oooo00<000000;ZC[`2jTjl0>@2j
Tjl00`000000oooo0?ooo`160?ooo`002@3oool01@000000oooo0?ooo`3oool0000003/0^Y>_00<0
00000?ooo`3oool0A`3oool000T0oooo00D000000?ooo`3oool0oooo0000000j0;ZC[`030000003o
ool0oooo04P0oooo00090?ooo`040000003oool0oooo000003X0^Y>_00<000000?ooo`3oool0B@3o
ool000P0oooo00@000000?ooo`3oool00000>`2jTjl00`000000oooo0?ooo`190?ooo`00203oool0
0`000000oooo0000000k0;ZC[`030000003oool0oooo04X0oooo00080?ooo`800000>`2jTjl00`00
0000oooo0?ooo`1;0?ooo`00203oool00`000000^Y>_0;ZC[`0i0;ZC[`030000003oool0oooo04`0
oooo00080?ooo`030000002jTjl0^Y>_03P0^Y>_00<000000?ooo`3oool0C@3oool000P0oooo00<0
00000;ZC[`2jTjl0>02jTjl00`000000oooo0?ooo`1=0?ooo`002@3oool00`000000^Y>_0;ZC[`0f
0;ZC[`030000003oool0oooo04h0oooo00090?ooo`030000002jTjl0^Y>_03D0^Y>_00<000000?oo
o`3oool0C`3oool000T0oooo00<000000;ZC[`2jTjl0=02jTjl00`000000oooo0?ooo`1@0?ooo`00
2P3oool00`000000^Y>_0;ZC[`0b0;ZC[`030000003oool0oooo0540oooo000:0?ooo`030000002j
Tjl0^Y>_0380^Y>_00<000000?ooo`3oool0D@3oool000X0oooo00<000000;ZC[`2jTjl0<@2jTjl0
0`000000oooo0?ooo`1B0?ooo`002P3oool00`000000^Y>_0;ZC[`0`0;ZC[`030000003oool0oooo
05<0oooo000;0?ooo`030000002jTjl0^Y>_02h0^Y>_00<000000?ooo`3oool0E03oool000/0oooo
00<000000;ZC[`2jTjl0;@2jTjl00`000000oooo0?ooo`1E0?ooo`002`3oool00`000000^Y>_0;ZC
[`0/0;ZC[`030000003oool0oooo05H0oooo000;0?ooo`030000002jTjl0^Y>_02`0^Y>_00<00000
0?ooo`3oool0EP3oool000`0oooo00<000000;ZC[`2jTjl0:P2jTjl00`000000oooo0?ooo`1G0?oo
o`00303oool00`000000^Y>_0;ZC[`0Y0;ZC[`030000003oool0oooo05P0oooo000<0?ooo`030000
002jTjl0^Y>_02P0^Y>_00<000000?ooo`3oool0F@3oool000d0oooo00<000000;ZC[`2jTjl09P2j
Tjl00`000000oooo0?ooo`1J0?ooo`003@3oool00`000000^Y>_0;ZC[`0V0;ZC[`030000003oool0
oooo05X0oooo000=0?ooo`030000002jTjl0^Y>_02D0^Y>_00<000000?ooo`3oool0F`3oool000d0
oooo00<000000;ZC[`2jTjl0902jTjl00`000000oooo0?ooo`1L0?ooo`003P3oool00`000000^Y>_
0;ZC[`0R0;ZC[`030000003oool0oooo05d0oooo000>0?ooo`030000002jTjl0^Y>_0240^Y>_00<0
00000?ooo`3oool0GP3oool000h0oooo00<000000;ZC[`2jTjl0802jTjl00`000000oooo0?ooo`1O
0?ooo`003P3oool00`000000^Y>_0;ZC[`0P0;ZC[`030000003oool0oooo05l0oooo000?0?ooo`03
0000002jTjl0^Y>_01h0^Y>_00<000000?ooo`3oool0H03oool000l0oooo00<000000;ZC[`2jTjl0
7@2jTjl00`000000oooo0?ooo`1Q0?ooo`003`3oool00`000000^Y>_0;ZC[`0L0;ZC[`030000003o
ool0oooo0680oooo000@0?ooo`030000002jTjl0^Y>_01X0^Y>_00<000000?ooo`3oool0H`3oool0
0100oooo00<000000;ZC[`2jTjl06P2jTjl00`000000oooo0?ooo`1S0?ooo`00403oool00`000000
^Y>_0;ZC[`0I0;ZC[`030000003oool0oooo06@0oooo000@0?ooo`030000002jTjl0^Y>_01P0^Y>_
00<000000?ooo`3oool0I@3oool00140oooo00<000000;ZC[`2jTjl05P2jTjl00`000000oooo0?oo
o`1V0?ooo`004@3oool00`000000^Y>_0;ZC[`0E0;ZC[`030000003oool0oooo06L0oooo000A0?oo
o`030000002jTjl0^Y>_01D0^Y>_00<000000?ooo`3oool0I`3oool00140oooo00<000000;ZC[`2j
Tjl0502jTjl00`000000oooo0?ooo`1X0?ooo`004P3oool00`000000^Y>_0;ZC[`0B0;ZC[`030000
003oool0oooo06T0oooo000B0?ooo`030000002jTjl0^Y>_0140^Y>_00<000000?ooo`3oool0JP3o
ool00180oooo00<000000;ZC[`2jTjl0402jTjl00`000000oooo0?ooo`1[0?ooo`004`3oool00`00
0000^Y>_0;ZC[`0>0;ZC[`030000003oool0oooo06`0oooo000C0?ooo`030000002jTjl0^Y>_00h0
^Y>_00<000000?ooo`3oool0K03oool001<0oooo00<000000;ZC[`2jTjl03@2jTjl00`000000oooo
0?ooo`1]0?ooo`004`3oool00`000000^Y>_0;ZC[`0<0;ZC[`030000003oool0oooo06h0oooo000D
0?ooo`030000002jTjl0^Y>_00X0^Y>_00<000000?ooo`3oool0K`3oool001@0oooo00<000000;ZC
[`2jTjl02@2jTjl00`000000oooo0?ooo`1`0?ooo`00503oool00`000000^Y>_0;ZC[`090;ZC[`03
0000003oool0oooo0700oooo000D0?ooo`030000002jTjl0^Y>_00P0^Y>_00<000000?ooo`3oool0
L@3oool001D0oooo00<000000;ZC[`2jTjl01P2jTjl00`000000oooo0?ooo`1b0?ooo`005@3oool0
0`000000^Y>_0;ZC[`050;ZC[`030000003oool0oooo07<0oooo000E0?ooo`030000002jTjl0^Y>_
00@0^Y>_00<000000?ooo`3oool0M03oool001H0oooo00<000000;ZC[`2jTjl00P2jTjl00`000000
oooo0?ooo`1e0?ooo`005P3oool00`000000^Y>_0;ZC[`020;ZC[`030000003oool0oooo07D0oooo
000F0?ooo`050000002jTjl0^Y>_0;ZC[`000000N03oool001H0oooo00@000000;ZC[`2jTjl00000
N@3oool001L0oooo0P00001j0?ooo`005`3oool00`000000oooo0?ooo`1i0?ooo`00T`3oool009<0
oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3oool0
09<0oooo002C0?ooo`00T`3oool009<0oooo002C0?ooo`00T`3oool00001\
\>"],
  ImageRangeCache->{{{0, 146.188}, {160.25, 0}} -> {0.0552755, -4.85051*^-6, \
0.00605368, 0.00605368}},
  CellTags->"RoofPrism"],

Cell[BoxData[
    TagBox[\(DrawSystem[{RoofPrism[
            10, {FullForm \[Rule] True, Mirrored \[Rule] True}]}]\),
      HoldForm]], "Print",
  CellTags->"RoofPrism"],

Cell[BoxData[
    \("-rendered unpropagated system-"\)], "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->SideView];", "Input",
  CellTags->"RoofPrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0557892 0.5 0.0557892 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02381 m
.02381 .5817 L
.02381 .97619 L
.02381 .5817 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.5817 .02381 L
.97619 .02381 L
.5817 .02381 L
.02381 .02381 L
.02381 .02381 L
s
.5 g
.40138 .40138 m
.5817 .02381 L
.02381 .5817 L
.40138 .40138 L
F
.40138 .40138 m
.02381 .5817 L
.02381 .97619 L
.40138 .40138 L
F
.40138 .40138 m
.02381 .97619 L
.97619 .02381 L
.40138 .40138 L
F
.40138 .40138 m
.97619 .02381 L
.5817 .02381 L
.40138 .40138 L
F
0 g
.02381 .5817 m
.02381 .97619 L
.97619 .02381 L
.5817 .02381 L
.02381 .5817 L
s
.5 g
.40138 .40138 m
.02381 .5817 L
.5817 .02381 L
.40138 .40138 L
F
.40138 .40138 m
.5817 .02381 L
.97619 .02381 L
.40138 .40138 L
F
.40138 .40138 m
.97619 .02381 L
.02381 .97619 L
.40138 .40138 L
F
.40138 .40138 m
.02381 .97619 L
.02381 .5817 L
.40138 .40138 L
F
0 g
.5817 .02381 m
.97619 .02381 L
.02381 .97619 L
.02381 .5817 L
.5817 .02381 L
s
.02381 .02381 m
.02381 .5817 L
.5817 .02381 L
.02381 .02381 L
s
.02381 .02381 m
.5817 .02381 L
.02381 .5817 L
.02381 .02381 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{172.625, 172.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002/0000[2000`400?l00000o`00003o[03oool0
0:`0oooo002/0?ooo`00[03oool000@0ooooY00000040?ooo`00103oool00`000000oooo0?ooo`1L
0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool00`3oool000@0oooo00<000000?oo
o`3oool0F`3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo00@0oooo00040?ooo`03
0000003oool0oooo05X0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`050?ooo`00
103oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0
1P3oool000@0oooo00<000000?ooo`3oool0F03oool00`000000Ogmo07moO`1007moO`030000003o
ool0oooo00L0oooo00040?ooo`030000003oool0oooo05L0oooo00<0000007moO`1oOgl0@01oOgl0
0`000000oooo0?ooo`080?ooo`00103oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo
0400Ogmo00<000000?ooo`3oool02@3oool000@0oooo00<000000?ooo`3oool0E@3oool00`000000
Ogmo07moO`1007moO`030000003oool0oooo00X0oooo00040?ooo`030000003oool0oooo05@0oooo
00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0;0?ooo`00103oool00`000000oooo0?oo
o`1C0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0303oool000@0oooo00<00000
0?ooo`3oool0DP3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo00d0oooo00040?oo
o`030000003oool0oooo0540oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0>0?oo
o`00103oool00`000000oooo0?ooo`1@0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3o
ool03`3oool000@0oooo00<000000?ooo`3oool0C`3oool00`000000Ogmo07moO`1007moO`030000
003oool0oooo0100oooo00040?ooo`030000003oool0oooo04h0oooo00<0000007moO`1oOgl0@01o
Ogl00`000000oooo0?ooo`0A0?ooo`00103oool00`000000oooo0?ooo`1=0?ooo`030000001oOgl0
Ogmo0400Ogmo00<000000?ooo`3oool04P3oool000@0oooo00<000000?ooo`3oool0C03oool00`00
0000Ogmo07moO`1007moO`030000003oool0oooo01<0oooo00040?ooo`030000003oool0oooo04/0
oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0D0?ooo`00103oool00`000000oooo
0?ooo`1:0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool05@3oool000@0oooo00<0
00000?ooo`3oool0B@3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo01H0oooo0004
0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0G
0?ooo`00103oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?oo
o`3oool0603oool000@0oooo00<000000?ooo`3oool0AP3oool00`000000Ogmo07moO`1007moO`03
0000003oool0oooo01T0oooo00040?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl0
@01oOgl00`000000oooo0?ooo`0J0?ooo`00103oool00`000000oooo0?ooo`140?ooo`030000001o
Ogl0Ogmo0400Ogmo00<000000?ooo`3oool06`3oool000@0oooo00<000000?ooo`3oool0@`3oool0
0`000000Ogmo07moO`1007moO`030000003oool0oooo01`0oooo00040?ooo`030000003oool0oooo
0480oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0M0?ooo`00103oool00`000000
oooo0?ooo`110?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool07P3oool000@0oooo
00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`1007moO`030000003oool0oooo01l0oooo
00040?ooo`030000003oool0oooo03l0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?oo
o`0P0?ooo`00103oool00`000000oooo0?ooo`0n0?ooo`030000001oOgl0Ogmo0400Ogmo00<00000
0?ooo`3oool08@3oool000@0oooo00<000000?ooo`3oool0?@3oool00`000000Ogmo07moO`1007mo
O`030000003oool0oooo0280oooo00040?ooo`030000003oool0oooo03`0oooo00<0000007moO`1o
Ogl0@01oOgl00`000000oooo0?ooo`0S0?ooo`00103oool00`000000oooo0?ooo`0k0?ooo`030000
001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0903oool000@0oooo00<000000?ooo`3oool0>P3o
ool00`000000Ogmo07moO`1007moO`030000003oool0oooo02D0oooo00040?ooo`030000003oool0
oooo03T0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0V0?ooo`00103oool00`00
0000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool09`3oool000@0
oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo02P0
oooo00040?ooo`030000003oool0oooo03H0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo
0?ooo`0Y0?ooo`00103oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo0400Ogmo00<0
00000?ooo`3oool0:P3oool000@0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`10
07moO`030000003oool0oooo02/0oooo00040?ooo`030000003oool0oooo03<0oooo00<0000007mo
O`1oOgl0@01oOgl00`000000oooo0?ooo`0/0?ooo`00103oool00`000000oooo0?ooo`0b0?ooo`03
0000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0;@3oool000@0oooo00<000000?ooo`3oool0
<@3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo02h0oooo00040?ooo`030000003o
ool0oooo0300oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0_0?ooo`00103oool0
0`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0<03oool0
00@0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo
0340oooo00040?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl0@01oOgl00`000000
oooo0?ooo`0b0?ooo`00103oool00`000000oooo0?ooo`0/0?ooo`030000001oOgl0Ogmo0400Ogmo
00<000000?ooo`3oool0<`3oool000@0oooo00<000000?ooo`3oool0:`3oool00`000000Ogmo07mo
O`1007moO`030000003oool0oooo03@0oooo00040?ooo`030000003oool0oooo02X0oooo00<00000
07moO`1oOgl0@01oOgl00`000000oooo0?ooo`0e0?ooo`00103oool00`000000oooo0?ooo`0Y0?oo
o`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0=P3oool000@0oooo00<000000?ooo`3o
ool0:03oool00`000000Ogmo07moO`1007moO`030000003oool0oooo03L0oooo00040?ooo`030000
003oool0oooo02L0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0h0?ooo`00103o
ool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0>@3o
ool000@0oooo00<000000?ooo`3oool09@3oool00`000000Ogmo07moO`1007moO`030000003oool0
oooo03X0oooo00040?ooo`030000003oool0oooo02@0oooo00<0000007moO`1oOgl0@01oOgl00`00
0000oooo0?ooo`0k0?ooo`00103oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo0400
Ogmo00<000000?ooo`3oool0?03oool000@0oooo00<000000?ooo`3oool08P3oool00`000000Ogmo
07moO`1007moO`030000003oool0oooo03d0oooo00040?ooo`030000003oool0oooo0240oooo00<0
000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`0n0?ooo`00103oool00`000000oooo0?ooo`0P
0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0?`3oool000@0oooo00<000000?oo
o`3oool07`3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo0400oooo00040?ooo`03
0000003oool0oooo01h0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`110?ooo`00
103oool00`000000oooo0?ooo`0M0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0
@P3oool000@0oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`1007moO`030000003o
ool0oooo04<0oooo00040?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0@01oOgl0
0`000000oooo0?ooo`140?ooo`00103oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo
0400Ogmo00<000000?ooo`3oool0A@3oool000@0oooo00<000000?ooo`3oool06@3oool00`000000
Ogmo07moO`1007moO`030000003oool0oooo04H0oooo00040?ooo`030000003oool0oooo01P0oooo
00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`170?ooo`00103oool00`000000oooo0?oo
o`0G0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0B03oool000@0oooo00<00000
0?ooo`3oool05P3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo04T0oooo00040?oo
o`030000003oool0oooo01D0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`1:0?oo
o`00103oool00`000000oooo0?ooo`0D0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3o
ool0B`3oool000@0oooo00<000000?ooo`3oool04`3oool00`000000Ogmo07moO`1007moO`030000
003oool0oooo04`0oooo00040?ooo`030000003oool0oooo0180oooo00<0000007moO`1oOgl0@01o
Ogl00`000000oooo0?ooo`1=0?ooo`00103oool00`000000oooo0?ooo`0A0?ooo`030000001oOgl0
Ogmo0400Ogmo00<000000?ooo`3oool0CP3oool000@0oooo00<000000?ooo`3oool0403oool00`00
0000Ogmo07moO`1007moO`030000003oool0oooo04l0oooo00040?ooo`030000003oool0oooo00l0
oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`1@0?ooo`00103oool00`000000oooo
0?ooo`0>0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0D@3oool000@0oooo00<0
00000?ooo`3oool03@3oool00`000000Ogmo07moO`1007moO`030000003oool0oooo0580oooo0004
0?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`1C
0?ooo`00103oool00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?oo
o`3oool0E03oool000@0oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`1007moO`03
0000003oool0oooo05D0oooo00040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
@01oOgl00`000000oooo0?ooo`1F0?ooo`00103oool00`000000oooo0?ooo`080?ooo`030000001o
Ogl0Ogmo0400Ogmo00<000000?ooo`3oool0E`3oool000@0oooo00<000000?ooo`3oool01`3oool0
0`000000Ogmo07moO`1007moO`030000003oool0oooo05P0oooo00040?ooo`030000003oool0oooo
00H0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?ooo`1I0?ooo`00103oool00`000000
oooo0?ooo`050?ooo`030000001oOgl0Ogmo0400Ogmo00<000000?ooo`3oool0FP3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000Ogmo07moO`1007moO`030000003oool0oooo05/0oooo
00040?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo0?oo
o`1L0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo0400Ogmo00<00000
0?ooo`3oool0G@3oool000@0oooo00D000000?ooo`3oool0oooo0000001207moO`030000003oool0
oooo05h0oooo00040?ooo`040000003oool0oooo00000480Ogmo00<000000?ooo`3oool0G`3oool0
00@0oooo00<000000?ooo`000000@P1oOgl00`000000oooo0?ooo`1P0?ooo`00103oool200000480
Ogmo00<000000?ooo`3oool0H@3oool000@0oooo00<0000007moO`1oOgl0@01oOgl00`000000oooo
0?ooo`1R0?ooo`00103oool00`000000Ogmo07moO`0o07moO`030000003oool0oooo06<0oooo0004
0?ooo`030000001oOgl0Ogmo03h0Ogmo00<000000?ooo`3oool0I03oool000@0oooo00<0000007mo
O`1oOgl0?@1oOgl00`000000oooo0?ooo`1U0?ooo`00103oool00`000000Ogmo07moO`0l07moO`03
0000003oool0oooo06H0oooo00040?ooo`030000001oOgl0Ogmo03/0Ogmo00<000000?ooo`3oool0
I`3oool000@0oooo00<0000007moO`1oOgl0>P1oOgl00`000000oooo0?ooo`1X0?ooo`00103oool0
0`000000Ogmo07moO`0i07moO`030000003oool0oooo06T0oooo00040?ooo`030000001oOgl0Ogmo
03P0Ogmo00<000000?ooo`3oool0JP3oool000@0oooo00<0000007moO`1oOgl0=`1oOgl00`000000
oooo0?ooo`1[0?ooo`00103oool00`000000Ogmo07moO`0f07moO`030000003oool0oooo06`0oooo
00040?ooo`030000001oOgl0Ogmo03D0Ogmo00<000000?ooo`3oool0K@3oool000@0oooo00<00000
07moO`1oOgl0=01oOgl00`000000oooo0?ooo`1^0?ooo`00103oool00`000000Ogmo07moO`0c07mo
O`030000003oool0oooo06l0oooo00040?ooo`030000001oOgl0Ogmo0380Ogmo00<000000?ooo`3o
ool0L03oool000@0oooo00<0000007moO`1oOgl0<@1oOgl00`000000oooo0?ooo`1a0?ooo`00103o
ool00`000000Ogmo07moO`0`07moO`030000003oool0oooo0780oooo00040?ooo`030000001oOgl0
Ogmo02l0Ogmo00<000000?ooo`3oool0L`3oool000@0oooo00<0000007moO`1oOgl0;P1oOgl00`00
0000oooo0?ooo`1d0?ooo`00103oool00`000000Ogmo07moO`0]07moO`030000003oool0oooo07D0
oooo00040?ooo`030000001oOgl0Ogmo02`0Ogmo00<000000?ooo`3oool0MP3oool000@0oooo00<0
000007moO`1oOgl0:`1oOgl00`000000oooo0?ooo`1g0?ooo`00103oool00`000000Ogmo07moO`0Z
07moO`030000003oool0oooo07P0oooo00040?ooo`030000001oOgl0Ogmo02T0Ogmo00<000000?oo
o`3oool0N@3oool000@0oooo00<0000007moO`1oOgl0:01oOgl00`000000oooo0?ooo`1j0?ooo`00
103oool00`000000Ogmo07moO`0W07moO`030000003oool0oooo07/0oooo00040?ooo`030000001o
Ogl0Ogmo02H0Ogmo00<000000?ooo`3oool0O03oool000@0oooo00<0000007moO`1oOgl09@1oOgl0
0`000000oooo0?ooo`1m0?ooo`00103oool00`000000Ogmo07moO`0T07moO`030000003oool0oooo
07h0oooo00040?ooo`030000001oOgl0Ogmo02<0Ogmo00<000000?ooo`3oool0O`3oool000@0oooo
00<0000007moO`1oOgl08P1oOgl00`000000oooo0?ooo`200?ooo`00103oool00`000000Ogmo07mo
O`0Q07moO`030000003oool0oooo0840oooo00040?ooo`030000001oOgl0Ogmo0200Ogmo00<00000
0?ooo`3oool0PP3oool000@0oooo00<0000007moO`1oOgl07`1oOgl00`000000oooo0?ooo`230?oo
o`00103oool00`000000Ogmo07moO`0N07moO`030000003oool0oooo08@0oooo00040?ooo`030000
001oOgl0Ogmo01d0Ogmo00<000000?ooo`3oool0Q@3oool000@0oooo00<0000007moO`1oOgl0701o
Ogl00`000000oooo0?ooo`260?ooo`00103oool00`000000Ogmo07moO`0K07moO`030000003oool0
oooo08L0oooo00040?ooo`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0R03oool000@0
oooo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`290?ooo`00103oool00`000000Ogmo
07moO`0H07moO`030000003oool0oooo08X0oooo00040?ooo`030000001oOgl0Ogmo01L0Ogmo00<0
00000?ooo`3oool0R`3oool000@0oooo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`2<
0?ooo`00103oool00`000000Ogmo07moO`0E07moO`030000003oool0oooo08d0oooo00040?ooo`03
0000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0SP3oool000@0oooo00<0000007moO`1oOgl0
4`1oOgl00`000000oooo0?ooo`2?0?ooo`00103oool00`000000Ogmo07moO`0B07moO`030000003o
ool0oooo0900oooo00040?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0T@3oool0
00@0oooo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`2B0?ooo`00103oool00`000000
Ogmo07moO`0?07moO`030000003oool0oooo09<0oooo00040?ooo`030000001oOgl0Ogmo00h0Ogmo
00<000000?ooo`3oool0U03oool000@0oooo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?oo
o`2E0?ooo`00103oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo09H0oooo00040?oo
o`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0U`3oool000@0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`2H0?ooo`00103oool00`000000Ogmo07moO`0907moO`030000
003oool0oooo09T0oooo00040?ooo`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0VP3o
ool000@0oooo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`2K0?ooo`00103oool00`00
0000Ogmo07moO`0607moO`030000003oool0oooo09`0oooo00040?ooo`030000001oOgl0Ogmo00D0
Ogmo00<000000?ooo`3oool0W@3oool000@0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`2N0?ooo`00103oool00`000000Ogmo07moO`0307moO`030000003oool0oooo09l0oooo0004
0?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0X03oool000@0oooo00D0000007mo
O`1oOgl0Ogmo0000002S0?ooo`00103oool010000000Ogmo07moO`00002T0?ooo`00103oool00`00
0000Ogmo0000002U0?ooo`00103oool200000:H0oooo00040?ooo`030000003oool0oooo0:D0oooo
002/0?ooo`00[03oool00:`0oooo002/0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 171.625}, {171.625, 0}} -> {-0.426866, -8.9624, \
0.104442, 0.104442}},
  CellTags->"RoofPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["WedgePrism[angle, aperture, smalledgethickness, options]", "Subsection",
  CellTags->"WedgePrism"],

Cell[CellGroupData[{

Cell["?WedgePrism", "Input",
  CellTags->"WedgePrism"],

Cell[BoxData[
    \("WedgePrism[angle, aperture, smalledgethickness, options] indicates a \
wedge-shaped beamsteering prism element. \n\nWedgePrism is created with the \
first surface centered vertically about the origin and its second surface \
positioned down the positive x axis with a tilt in the x-y direction. The \
aperture argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. See also: Prism, DovePrism, \
PentaPrism, and RhomboidalPrism."\)], "Print",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WedgePrism[8, 25, 3]", "Input",
  CellTags->"WedgePrism"],

Cell[BoxData[
    TagBox[\(WedgePrism[8, 25, 3]\),
      HoldForm]], "Output",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{Move[Ray[],-5],WedgePrism[8, 25, 3],Move[WedgePrism[8, \
25, 3],20],Boundary[30,GraphicDesign->Off]},PlotType->TopView]\
\>", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74372 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.159864 0.0272109 0.385878 0.0272109 [
[.22458 .01771 -18 -4.5 ]
[.22458 .01771 18 4.5 ]
[.7688 .01771 -18 -4.5 ]
[.7688 .01771 18 4.5 ]
[ 0 0 0 0 ]
[ 1 .74372 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.15986 .04574 m
.3371 .04574 L
.32914 .10243 L
.15986 .10243 L
.15986 .04574 L
F
.15986 .10243 m
.32914 .10243 L
.32117 .15912 L
.15986 .15912 L
.15986 .10243 L
F
.15986 .15912 m
.32117 .15912 L
.3132 .21581 L
.15986 .21581 L
.15986 .15912 L
F
.15986 .21581 m
.3132 .21581 L
.30523 .2725 L
.15986 .2725 L
.15986 .21581 L
F
.15986 .2725 m
.30523 .2725 L
.29727 .32919 L
.15986 .32919 L
.15986 .2725 L
F
.15986 .32919 m
.29727 .32919 L
.2893 .38588 L
.15986 .38588 L
.15986 .32919 L
F
.15986 .38588 m
.2893 .38588 L
.28133 .44257 L
.15986 .44257 L
.15986 .38588 L
F
.15986 .44257 m
.28133 .44257 L
.27337 .49926 L
.15986 .49926 L
.15986 .44257 L
F
.15986 .49926 m
.27337 .49926 L
.2654 .55595 L
.15986 .55595 L
.15986 .49926 L
F
.15986 .55595 m
.2654 .55595 L
.25743 .61264 L
.15986 .61264 L
.15986 .55595 L
F
.15986 .61264 m
.25743 .61264 L
.24946 .66933 L
.15986 .66933 L
.15986 .61264 L
F
.15986 .66933 m
.24946 .66933 L
.2415 .72601 L
.15986 .72601 L
.15986 .66933 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.15986 .04574 m
.15986 .10243 L
.15986 .15912 L
.15986 .21581 L
.15986 .2725 L
.15986 .32919 L
.15986 .38588 L
.15986 .44257 L
.15986 .49926 L
.15986 .55595 L
.15986 .61264 L
.15986 .66933 L
.15986 .72601 L
.2415 .72601 L
.24946 .66933 L
.25743 .61264 L
.2654 .55595 L
.27337 .49926 L
.28133 .44257 L
.2893 .38588 L
.29727 .32919 L
.30523 .2725 L
.3132 .21581 L
.32117 .15912 L
.32914 .10243 L
.3371 .04574 L
.15986 .04574 L
s
.5 g
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
.15986 .38588 m
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
.15986 .38588 L
F
0 g
.15986 .38588 m
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.15986 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.2893 .38588 L
.15986 .38588 L
s
.15986 .72601 m
.2415 .72601 L
.24191 .7231 L
.15986 .7231 L
.15986 .72601 L
s
.15986 .7231 m
.24191 .7231 L
.24313 .71442 L
.15986 .71442 L
.15986 .7231 L
s
.15986 .71442 m
.24313 .71442 L
.24514 .70012 L
.15986 .70012 L
.15986 .71442 L
s
.15986 .70012 m
.24514 .70012 L
.2479 .68044 L
.15986 .68044 L
.15986 .70012 L
s
.15986 .68044 m
.2479 .68044 L
.25137 .65573 L
.15986 .65573 L
.15986 .68044 L
s
.15986 .65573 m
.25137 .65573 L
.2555 .62639 L
.15986 .62639 L
.15986 .65573 L
s
.15986 .62639 m
.2555 .62639 L
.2602 .59294 L
.15986 .59294 L
.15986 .62639 L
s
.15986 .59294 m
.2602 .59294 L
.2654 .55595 L
.15986 .55595 L
.15986 .59294 L
s
.15986 .55595 m
.2654 .55595 L
.27101 .51604 L
.15986 .51604 L
.15986 .55595 L
s
.15986 .51604 m
.27101 .51604 L
.27693 .47391 L
.15986 .47391 L
.15986 .51604 L
s
.15986 .47391 m
.27693 .47391 L
.28306 .43027 L
.15986 .43027 L
.15986 .47391 L
s
.15986 .43027 m
.28306 .43027 L
.2893 .38588 L
.15986 .38588 L
.15986 .43027 L
s
.15986 .38588 m
.2893 .38588 L
.29554 .34148 L
.15986 .34148 L
.15986 .38588 L
s
.15986 .34148 m
.29554 .34148 L
.30167 .29784 L
.15986 .29784 L
.15986 .34148 L
s
.15986 .29784 m
.30167 .29784 L
.30759 .25571 L
.15986 .25571 L
.15986 .29784 L
s
.15986 .25571 m
.30759 .25571 L
.3132 .21581 L
.15986 .21581 L
.15986 .25571 L
s
.15986 .21581 m
.3132 .21581 L
.3184 .17882 L
.15986 .17882 L
.15986 .21581 L
s
.15986 .17882 m
.3184 .17882 L
.3231 .14537 L
.15986 .14537 L
.15986 .17882 L
s
.15986 .14537 m
.3231 .14537 L
.32722 .11603 L
.15986 .11603 L
.15986 .14537 L
s
.15986 .11603 m
.32722 .11603 L
.3307 .09131 L
.15986 .09131 L
.15986 .11603 L
s
.15986 .09131 m
.3307 .09131 L
.33346 .07163 L
.15986 .07163 L
.15986 .09131 L
s
.15986 .07163 m
.33346 .07163 L
.33547 .05733 L
.15986 .05733 L
.15986 .07163 L
s
.15986 .05733 m
.33547 .05733 L
.33669 .04865 L
.15986 .04865 L
.15986 .05733 L
s
.15986 .04865 m
.33669 .04865 L
.3371 .04574 L
.15986 .04574 L
.15986 .04865 L
s
.15986 .04574 m
.3371 .04574 L
.33669 .04865 L
.15986 .04865 L
.15986 .04574 L
s
.15986 .04865 m
.33669 .04865 L
.33547 .05733 L
.15986 .05733 L
.15986 .04865 L
s
.15986 .05733 m
.33547 .05733 L
.33346 .07163 L
.15986 .07163 L
.15986 .05733 L
s
.15986 .07163 m
.33346 .07163 L
.3307 .09131 L
.15986 .09131 L
.15986 .07163 L
s
.15986 .09131 m
.3307 .09131 L
.32722 .11603 L
.15986 .11603 L
.15986 .09131 L
s
.15986 .11603 m
.32722 .11603 L
.3231 .14537 L
.15986 .14537 L
.15986 .11603 L
s
.15986 .14537 m
.3231 .14537 L
.3184 .17882 L
.15986 .17882 L
.15986 .14537 L
s
.15986 .17882 m
.3184 .17882 L
.3132 .21581 L
.15986 .21581 L
.15986 .17882 L
s
.15986 .21581 m
.3132 .21581 L
.30759 .25571 L
.15986 .25571 L
.15986 .21581 L
s
.15986 .25571 m
.30759 .25571 L
.30167 .29784 L
.15986 .29784 L
.15986 .25571 L
s
.15986 .29784 m
.30167 .29784 L
.29554 .34148 L
.15986 .34148 L
.15986 .29784 L
s
.15986 .34148 m
.29554 .34148 L
.2893 .38588 L
.15986 .38588 L
.15986 .34148 L
s
.15986 .38588 m
.2893 .38588 L
.28306 .43027 L
.15986 .43027 L
.15986 .38588 L
s
.15986 .43027 m
.28306 .43027 L
.27693 .47391 L
.15986 .47391 L
.15986 .43027 L
s
.15986 .47391 m
.27693 .47391 L
.27101 .51604 L
.15986 .51604 L
.15986 .47391 L
s
.15986 .51604 m
.27101 .51604 L
.2654 .55595 L
.15986 .55595 L
.15986 .51604 L
s
.15986 .55595 m
.2654 .55595 L
.2602 .59294 L
.15986 .59294 L
.15986 .55595 L
s
.15986 .59294 m
.2602 .59294 L
.2555 .62639 L
.15986 .62639 L
.15986 .59294 L
s
.15986 .62639 m
.2555 .62639 L
.25137 .65573 L
.15986 .65573 L
.15986 .62639 L
s
.15986 .65573 m
.25137 .65573 L
.2479 .68044 L
.15986 .68044 L
.15986 .65573 L
s
.15986 .68044 m
.2479 .68044 L
.24514 .70012 L
.15986 .70012 L
.15986 .68044 L
s
.15986 .70012 m
.24514 .70012 L
.24313 .71442 L
.15986 .71442 L
.15986 .70012 L
s
.15986 .71442 m
.24313 .71442 L
.24191 .7231 L
.15986 .7231 L
.15986 .71442 L
s
.15986 .7231 m
.24191 .7231 L
.2415 .72601 L
.15986 .72601 L
.15986 .7231 L
s
.5 g
.70408 .04574 m
.88132 .04574 L
.87335 .10243 L
.70408 .10243 L
.70408 .04574 L
F
.70408 .10243 m
.87335 .10243 L
.86539 .15912 L
.70408 .15912 L
.70408 .10243 L
F
.70408 .15912 m
.86539 .15912 L
.85742 .21581 L
.70408 .21581 L
.70408 .15912 L
F
.70408 .21581 m
.85742 .21581 L
.84945 .2725 L
.70408 .2725 L
.70408 .21581 L
F
.70408 .2725 m
.84945 .2725 L
.84148 .32919 L
.70408 .32919 L
.70408 .2725 L
F
.70408 .32919 m
.84148 .32919 L
.83352 .38588 L
.70408 .38588 L
.70408 .32919 L
F
.70408 .38588 m
.83352 .38588 L
.82555 .44257 L
.70408 .44257 L
.70408 .38588 L
F
.70408 .44257 m
.82555 .44257 L
.81758 .49926 L
.70408 .49926 L
.70408 .44257 L
F
.70408 .49926 m
.81758 .49926 L
.80962 .55595 L
.70408 .55595 L
.70408 .49926 L
F
.70408 .55595 m
.80962 .55595 L
.80165 .61264 L
.70408 .61264 L
.70408 .55595 L
F
.70408 .61264 m
.80165 .61264 L
.79368 .66933 L
.70408 .66933 L
.70408 .61264 L
F
.70408 .66933 m
.79368 .66933 L
.78571 .72601 L
.70408 .72601 L
.70408 .66933 L
F
0 g
.70408 .04574 m
.70408 .10243 L
.70408 .15912 L
.70408 .21581 L
.70408 .2725 L
.70408 .32919 L
.70408 .38588 L
.70408 .44257 L
.70408 .49926 L
.70408 .55595 L
.70408 .61264 L
.70408 .66933 L
.70408 .72601 L
.78571 .72601 L
.79368 .66933 L
.80165 .61264 L
.80962 .55595 L
.81758 .49926 L
.82555 .44257 L
.83352 .38588 L
.84148 .32919 L
.84945 .2725 L
.85742 .21581 L
.86539 .15912 L
.87335 .10243 L
.88132 .04574 L
.70408 .04574 L
s
.5 g
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
.70408 .38588 m
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
.70408 .38588 L
F
0 g
.70408 .38588 m
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.70408 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.83352 .38588 L
.70408 .38588 L
s
.70408 .72601 m
.78571 .72601 L
.78612 .7231 L
.70408 .7231 L
.70408 .72601 L
s
.70408 .7231 m
.78612 .7231 L
.78734 .71442 L
.70408 .71442 L
.70408 .7231 L
s
.70408 .71442 m
.78734 .71442 L
.78935 .70012 L
.70408 .70012 L
.70408 .71442 L
s
.70408 .70012 m
.78935 .70012 L
.79212 .68044 L
.70408 .68044 L
.70408 .70012 L
s
.70408 .68044 m
.79212 .68044 L
.79559 .65573 L
.70408 .65573 L
.70408 .68044 L
s
.70408 .65573 m
.79559 .65573 L
.79972 .62639 L
.70408 .62639 L
.70408 .65573 L
s
.70408 .62639 m
.79972 .62639 L
.80442 .59294 L
.70408 .59294 L
.70408 .62639 L
s
.70408 .59294 m
.80442 .59294 L
.80962 .55595 L
.70408 .55595 L
.70408 .59294 L
s
.70408 .55595 m
.80962 .55595 L
.81522 .51604 L
.70408 .51604 L
.70408 .55595 L
s
.70408 .51604 m
.81522 .51604 L
.82114 .47391 L
.70408 .47391 L
.70408 .51604 L
s
.70408 .47391 m
.82114 .47391 L
.82728 .43027 L
.70408 .43027 L
.70408 .47391 L
s
.70408 .43027 m
.82728 .43027 L
.83352 .38588 L
.70408 .38588 L
.70408 .43027 L
s
.70408 .38588 m
.83352 .38588 L
.83976 .34148 L
.70408 .34148 L
.70408 .38588 L
s
.70408 .34148 m
.83976 .34148 L
.84589 .29784 L
.70408 .29784 L
.70408 .34148 L
s
.70408 .29784 m
.84589 .29784 L
.85181 .25571 L
.70408 .25571 L
.70408 .29784 L
s
.70408 .25571 m
.85181 .25571 L
.85742 .21581 L
.70408 .21581 L
.70408 .25571 L
s
.70408 .21581 m
.85742 .21581 L
.86262 .17882 L
.70408 .17882 L
.70408 .21581 L
s
.70408 .17882 m
.86262 .17882 L
.86732 .14537 L
.70408 .14537 L
.70408 .17882 L
s
.70408 .14537 m
.86732 .14537 L
.87144 .11603 L
.70408 .11603 L
.70408 .14537 L
s
.70408 .11603 m
.87144 .11603 L
.87492 .09131 L
.70408 .09131 L
.70408 .11603 L
s
.70408 .09131 m
.87492 .09131 L
.87768 .07163 L
.70408 .07163 L
.70408 .09131 L
s
.70408 .07163 m
.87768 .07163 L
.87969 .05733 L
.70408 .05733 L
.70408 .07163 L
s
.70408 .05733 m
.87969 .05733 L
.88091 .04865 L
.70408 .04865 L
.70408 .05733 L
s
.70408 .04865 m
.88091 .04865 L
.88132 .04574 L
.70408 .04574 L
.70408 .04865 L
s
.70408 .04574 m
.88132 .04574 L
.88091 .04865 L
.70408 .04865 L
.70408 .04574 L
s
.70408 .04865 m
.88091 .04865 L
.87969 .05733 L
.70408 .05733 L
.70408 .04865 L
s
.70408 .05733 m
.87969 .05733 L
.87768 .07163 L
.70408 .07163 L
.70408 .05733 L
s
.70408 .07163 m
.87768 .07163 L
.87492 .09131 L
.70408 .09131 L
.70408 .07163 L
s
.70408 .09131 m
.87492 .09131 L
.87144 .11603 L
.70408 .11603 L
.70408 .09131 L
s
.70408 .11603 m
.87144 .11603 L
.86732 .14537 L
.70408 .14537 L
.70408 .11603 L
s
.70408 .14537 m
.86732 .14537 L
.86262 .17882 L
.70408 .17882 L
.70408 .14537 L
s
.70408 .17882 m
.86262 .17882 L
.85742 .21581 L
.70408 .21581 L
.70408 .17882 L
s
.70408 .21581 m
.85742 .21581 L
.85181 .25571 L
.70408 .25571 L
.70408 .21581 L
s
.70408 .25571 m
.85181 .25571 L
.84589 .29784 L
.70408 .29784 L
.70408 .25571 L
s
.70408 .29784 m
.84589 .29784 L
.83976 .34148 L
.70408 .34148 L
.70408 .29784 L
s
.70408 .34148 m
.83976 .34148 L
.83352 .38588 L
.70408 .38588 L
.70408 .34148 L
s
.70408 .38588 m
.83352 .38588 L
.82728 .43027 L
.70408 .43027 L
.70408 .38588 L
s
.70408 .43027 m
.82728 .43027 L
.82114 .47391 L
.70408 .47391 L
.70408 .43027 L
s
.70408 .47391 m
.82114 .47391 L
.81522 .51604 L
.70408 .51604 L
.70408 .47391 L
s
.70408 .51604 m
.81522 .51604 L
.80962 .55595 L
.70408 .55595 L
.70408 .51604 L
s
.70408 .55595 m
.80962 .55595 L
.80442 .59294 L
.70408 .59294 L
.70408 .55595 L
s
.70408 .59294 m
.80442 .59294 L
.79972 .62639 L
.70408 .62639 L
.70408 .59294 L
s
.70408 .62639 m
.79972 .62639 L
.79559 .65573 L
.70408 .65573 L
.70408 .62639 L
s
.70408 .65573 m
.79559 .65573 L
.79212 .68044 L
.70408 .68044 L
.70408 .65573 L
s
.70408 .68044 m
.79212 .68044 L
.78935 .70012 L
.70408 .70012 L
.70408 .68044 L
s
.70408 .70012 m
.78935 .70012 L
.78734 .71442 L
.70408 .71442 L
.70408 .70012 L
s
.70408 .71442 m
.78734 .71442 L
.78612 .7231 L
.70408 .7231 L
.70408 .71442 L
s
.70408 .7231 m
.78612 .7231 L
.78571 .72601 L
.70408 .72601 L
.70408 .7231 L
s
.039 .916 .04 r
.02381 .38588 m
.15986 .38588 L
s
0 0 0 r
2 Mabswid
.15986 .38588 Mdot
.039 .916 .04 r
.5 Mabswid
.15986 .38588 m
.2893 .38588 L
s
0 0 0 r
2 Mabswid
.2893 .38588 Mdot
.039 .916 .04 r
.5 Mabswid
.2893 .38588 m
.70408 .35536 L
s
0 0 0 r
2 Mabswid
.70408 .35536 Mdot
.039 .916 .04 r
.5 Mabswid
.70408 .35536 m
.83872 .34885 L
s
0 0 0 r
2 Mabswid
.83872 .34885 Mdot
.039 .916 .04 r
.5 Mabswid
.83872 .34885 m
.97619 .32832 L
s
0 0 0 r
2 Mabswid
.97619 .32832 Mdot
[(Wedge1)] .22458 .01771 0 0 Mshowa
[(Wedge2)] .7688 .01771 0 0 Mshowa
0 0 m
1 0 L
1 .74372 L
0 .74372 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{218.812, 162.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003J0000XR000`400?l00000o`00003o<`3oool2
000007@0oooo0P00000_0?ooo`00<P3oool010000000oooo0?ooo`00001b0?ooo`040000003oool0
oooo000002h0oooo000T0?ooo`030000003oool0000000@0oooo0P0000020?ooo`H000000`3oool2
00000080oooo0`00001K0?ooo`030000003oool0000000@0oooo0P0000020?ooo`H000000`3oool2
000000030?ooo`0000000000008000009@3oool002@0oooo00<000000?ooo`0000000`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0S0?ooo`008`3oool01@000000oooo0000003oool000000080oooo0`0000001P3o
ool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000P0000030?ooo`030000003o
ool0oooo05T0oooo00D000000?ooo`000000oooo000000020?ooo`<0000000H0oooo0000003oool0
00000?ooo`0000020?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0U0?oo
o`008`3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0F@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0903oool00280oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`80
00000P3oool4000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0F03oool00`000000
oooo000000030?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`@0000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`0S0?ooo`008P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool2000005X0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000009@3oool00240oooo1@000000103oool000000000000000050?ooo`800000303oool00`00
0000oooo0?ooo`1G0?ooo`D0000000@0oooo00000000000000001@3oool2000000/0oooo0P00000V
0?ooo`00fP3oool00=X0oooo000S0?ooobL00000C`3ooolW000001X0oooo000S0?ooo`030000001o
Ogl0Ogmo02<0Ogmo00<000000?ooo`3oool0C@3oool00`000000Ogmo07moO`0S07moO`030000003o
ool0oooo01P0oooo000S0?ooobL00000C`3ooolW000001X0oooo000S0?ooo`030000001oOgl0Ogmo
02<0Ogmo00<000000?ooo`3oool0C@3oool00`000000Ogmo07moO`0S07moO`030000003oool0oooo
01P0oooo000S0?ooo`030000001oOgl0Ogmo0280Ogmo00<000000?ooo`3oool0CP3oool00`000000
Ogmo07moO`0R07moO`030000003oool0oooo01T0oooo000S0?ooobH00000D03ooolV000001/0oooo
000S0?ooo`030000001oOgl0Ogmo0280Ogmo00<000000?ooo`3oool0CP3oool00`000000Ogmo07mo
O`0R07moO`030000003oool0oooo01T0oooo000S0?ooo`030000001oOgl0Ogmo0280Ogmo00<00000
0?ooo`3oool0CP3oool00`000000Ogmo07moO`0R07moO`030000003oool0oooo01T0oooo000S0?oo
o`030000001oOgl0Ogmo0280Ogmo00<000000?ooo`3oool0CP3oool00`000000Ogmo07moO`0R07mo
O`030000003oool0oooo01T0oooo000S0?ooobH00000D03ooolV000001/0oooo000S0?ooo`030000
001oOgl0Ogmo0240Ogmo0P00001@0?ooo`030000001oOgl0Ogmo0240Ogmo0P00000K0?ooo`008`3o
ool00`000000Ogmo07moO`0Q07moO`800000D03oool00`000000Ogmo07moO`0Q07moO`8000006`3o
ool002<0oooo00<0000007moO`1oOgl08@1oOgl200000500oooo00<0000007moO`1oOgl08@1oOgl2
000001/0oooo000S0?ooo`030000001oOgl0Ogmo0240Ogmo00<000000?ooo`3oool0C`3oool00`00
0000Ogmo07moO`0Q07moO`030000003oool0oooo01X0oooo000S0?ooo`030000001oOgl0Ogmo0240
Ogmo00<000000?ooo`3oool0C`3oool00`000000Ogmo07moO`0Q07moO`030000003oool0oooo01X0
oooo000S0?ooobD00000D@3ooolU000001`0oooo000S0?ooo`030000001oOgl0Ogmo0240Ogmo00<0
00000?ooo`3oool0C`3oool00`000000Ogmo07moO`0P07moO`800000703oool002<0oooo00<00000
07moO`1oOgl08@1oOgl00`000000oooo0?ooo`1?0?ooo`030000001oOgl0Ogmo0200Ogmo0P00000L
0?ooo`008`3oool00`000000Ogmo07moO`0Q07moO`030000003oool0oooo04l0oooo00<0000007mo
O`1oOgl0801oOgl2000001`0oooo000S0?ooo`030000001oOgl0Ogmo0200Ogmo00<000000?ooo`3o
ool0D03oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo01/0oooo000S0?ooo`030000
001oOgl0Ogmo0200Ogmo00<000000?ooo`3oool0D03oool00`000000Ogmo07moO`0P07moO`030000
003oool0oooo01/0oooo000S0?ooob@00000DP3ooolT000001d0oooo000S0?ooo`030000001oOgl0
Ogmo0200Ogmo00<000000?ooo`3oool0D03oool00`000000Ogmo07moO`0O07moO`8000007@3oool0
02<0oooo00<0000007moO`1oOgl0801oOgl00`000000oooo0?ooo`1@0?ooo`030000001oOgl0Ogmo
01l0Ogmo0P00000M0?ooo`008`3oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo0500
oooo00<0000007moO`1oOgl07`1oOgl2000001d0oooo000S0?ooo`030000001oOgl0Ogmo01l0Ogmo
0P00001B0?ooo`030000001oOgl0Ogmo01l0Ogmo00<000000?ooo`3oool0703oool002<0oooo00<0
000007moO`1oOgl07`1oOgl200000580oooo00<0000007moO`1oOgl07`1oOgl00`000000oooo0?oo
o`0L0?ooo`008`3oool00`000000Ogmo07moO`0O07moO`800000DP3oool00`000000Ogmo07moO`0O
07moO`030000003oool0oooo01`0oooo000S0?ooob<00000D`3ooolS000001h0oooo000S0?ooo`03
0000001oOgl0Ogmo01l0Ogmo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0O07moO`03
0000003oool0oooo01`0oooo000S0?ooo`030000001oOgl0Ogmo01l0Ogmo00<000000?ooo`3oool0
D@3oool00`000000Ogmo07moO`0O07moO`030000003oool0oooo01`0oooo000S0?ooo`030000001o
Ogl0Ogmo01l0Ogmo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0N07moO`8000007P3o
ool002<0oooo00<0000007moO`1oOgl07`1oOgl00`000000oooo0?ooo`1A0?ooo`030000001oOgl0
Ogmo01h0Ogmo0P00000N0?ooo`008`3oool00`000000Ogmo07moO`0N07moO`800000D`3oool00`00
0000Ogmo07moO`0N07moO`030000003oool0oooo01d0oooo000S0?ooo`030000001oOgl0Ogmo01h0
Ogmo00<000000?ooo`3oool0DP3oool00`000000Ogmo07moO`0N07moO`030000003oool0oooo01d0
oooo000S0?ooo`030000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0DP3oool00`000000Ogmo
07moO`0N07moO`030000003oool0oooo01d0oooo000S0?ooob800000E03ooolR000001l0oooo000S
0?ooo`030000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0DP3oool00`000000Ogmo07moO`0N
07moO`030000003oool0oooo01d0oooo000S0?ooo`030000001oOgl0Ogmo01h0Ogmo00<000000?oo
o`3oool0DP3oool00`000000Ogmo07moO`0N07moO`030000003oool0oooo01d0oooo000S0?ooo`03
0000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0DP3oool00`000000Ogmo07moO`0N07moO`03
0000003oool0oooo01d0oooo000S0?ooo`030000001oOgl0Ogmo01d0Ogmo0P00001D0?ooo`030000
001oOgl0Ogmo01d0Ogmo0P00000O0?ooo`008`3oool00`000000Ogmo07moO`0M07moO`030000003o
ool0oooo05<0oooo00<0000007moO`1oOgl07@1oOgl00`000000oooo0?ooo`0N0?ooo`008`3oool0
0`000000Ogmo07moO`0M07moO`030000003oool0oooo05<0oooo00<0000007moO`1oOgl07@1oOgl0
0`000000oooo0?ooo`0N0?ooo`008`3oool00`000000Ogmo07moO`0M07moO`030000003oool0oooo
05<0oooo00<0000007moO`1oOgl07@1oOgl00`000000oooo0?ooo`0N0?ooo`008`3oool00`000000
Ogmo07moO`0M07moO`030000003oool0oooo05<0oooo00<0000007moO`1oOgl07@1oOgl00`000000
oooo0?ooo`0N0?ooo`008`3ooolQ000005D0oooo8@00000P0?ooo`008`3oool00`000000Ogmo07mo
O`0M07moO`030000003oool0oooo05<0oooo00<0000007moO`1oOgl07@1oOgl00`000000oooo0?oo
o`0N0?ooo`008`3oool00`000000Ogmo07moO`0L07moO`800000E@3oool00`000000Ogmo07moO`0L
07moO`800000803oool002<0oooo00<0000007moO`1oOgl0701oOgl2000005D0oooo00<0000007mo
O`1oOgl0701oOgl00`000000oooo0?ooo`0O0?ooo`008`3oool00`000000Ogmo07moO`0L07moO`80
0000E@3oool00`000000Ogmo07moO`0L07moO`030000003oool0oooo01l0oooo000S0?ooo`030000
001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0L07moO`030000
003oool0oooo01l0oooo000S0?ooo`030000001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool0E03o
ool00`000000Ogmo07moO`0L07moO`030000003oool0oooo01l0oooo000S0?ooo`030000001oOgl0
Ogmo01`0Ogmo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0L07moO`030000003oool0
oooo01l0oooo000S0?ooo`030000001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool0E03oool00`00
0000Ogmo07moO`0K07moO`030000003oool0oooo0200oooo000S0?ooob000000EP3ooolO00000280
oooo000S0?ooo`030000001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool0E03oool00`000000Ogmo
07moO`0K07moO`030000003oool0oooo0200oooo000S0?ooo`030000001oOgl0Ogmo01/0Ogmo0P00
001F0?ooo`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0803oool002<0oooo00<00000
07moO`1oOgl06`1oOgl00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo01/0Ogmo00<00000
0?ooo`3oool0803oool002<0oooo00<0000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0803oool002<0oooo00<0000007moO`1o
Ogl06`1oOgl00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3o
ool08@3oool002<0oooo00<0000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`1E0?ooo`030000
001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool06P3oool2000000D0oooo000S0?ooo`030000001o
Ogl0Ogmo01/0Ogmo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0J07moO`030000003o
ool0oooo01H0oooo1009jPX2000000D0oooo000S0?ooo`030000001oOgl0Ogmo01X0Ogmo0P00001G
0?ooo`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool03`3oool700WZ2P/0oooo000S0?oo
oal00000E`3ooolN000000X0oooo1`09jPXB0?ooo`008`3oool00`000000Ogmo07moO`0J07moO`80
0000E`3oool00`000000Ogmo07moO`0J07moO`040000003oool0oooo0?ooo`L02NX:6@3oool002<0
oooo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0
Ogmo3@09jPX00`0000002NX:00WZ2P0200WZ2R00oooo000S0?ooo`030000001oOgl0Ogmo01X0Ogmo
00<000000?ooo`3oool0D03oool500WZ2P0300000009jPX02NX:00d02NX:3@1oOgl2000002<0oooo
000S0?ooo`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0@`3oool=00WZ2PD0oooo0P00
000L07moO`030000003oool0oooo0240oooo000S0?ooo`030000001oOgl0Ogmo01X0Ogmo00<00000
0?ooo`3oool0=P3oool=00WZ2Q<0oooo00<0000007moO`1oOgl06@1oOgl2000002<0oooo000S0?oo
o`030000001oOgl0Ogmo01T0Ogmo0P00000[0?ooo`d02NX:803oool00`000000Ogmo07moO`0I07mo
O`030000003oool0oooo0280oooo000S0?ooo`030000001oOgl0Ogmo01T0Ogmo0P00000N0?ooo`d0
2NX:;@3oool00`000000Ogmo07moO`0I07moO`030000003oool0oooo0280oooo000S0?ooo`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0403oool=00WZ2SX0oooo00<0000007moO`1oOgl0
6@1oOgl00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000Ogmo07moO`0I07moO`030000003o
ool0oooo00<0oooo3@09jPY70?ooo`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool08P3o
ool000D0oooo7@09jPX00`0000002NX:00WZ2P0I00WZ2P0300000009jPX02NX:00@02NX:E03ooolM
000002@0oooo000R0?ooo`8000006P1oOgl2000005T0oooo00<0000007moO`1oOgl06@1oOgl00`00
0000oooo0?ooo`0R0?ooo`008`3oool00`000000Ogmo07moO`0I07moO`030000003oool0oooo05L0
oooo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000Ogmo
07moO`0H07moO`800000F@3oool00`000000Ogmo07moO`0H07moO`800000903oool002<0oooo00<0
000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1H0?ooo`030000001oOgl0Ogmo01P0Ogmo00<0
00000?ooo`3oool08`3oool002<0oooo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1H
0?ooo`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool08`3oool002<0oooo00<0000007mo
O`1oOgl0601oOgl00`000000oooo0?ooo`1H0?ooo`030000001oOgl0Ogmo01P0Ogmo00<000000?oo
o`3oool08`3oool002<0oooo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1H0?ooo`03
0000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool08`3oool002<0oooo00<0000007moO`1oOgl0
5`1oOgl2000005X0oooo00<0000007moO`1oOgl05`1oOgl2000002D0oooo000S0?ooo`030000001o
Ogl0Ogmo01L0Ogmo0P00001J0?ooo`030000001oOgl0Ogmo01L0Ogmo0P00000U0?ooo`008`3ooolK
000005/0oooo6`00000V0?ooo`008`3oool00`000000Ogmo07moO`0G07moO`030000003oool0oooo
05T0oooo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0T0?ooo`008`3oool00`000000
Ogmo07moO`0G07moO`030000003oool0oooo05T0oooo00<0000007moO`1oOgl05`1oOgl00`000000
oooo0?ooo`0T0?ooo`008`3oool00`000000Ogmo07moO`0G07moO`030000003oool0oooo05T0oooo
00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0T0?ooo`008`3oool00`000000Ogmo07mo
O`0G07moO`030000003oool0oooo05T0oooo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?oo
o`0T0?ooo`008`3oool00`000000Ogmo07moO`0F07moO`800000F`3oool00`000000Ogmo07moO`0F
07moO`8000009P3oool002<0oooo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`1J0?oo
o`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool09@3oool002<0oooo00<0000007moO`1o
Ogl05P1oOgl00`000000oooo0?ooo`1J0?ooo`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3o
ool09@3oool002<0oooo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`1J0?ooo`030000
001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool09@3oool002<0oooo6P00001L0?oooaX000009`3o
ool002<0oooo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`1J0?ooo`030000001oOgl0
Ogmo01H0Ogmo00<000000?ooo`3oool09@3oool002<0oooo00<0000007moO`1oOgl05P1oOgl00`00
0000oooo0?ooo`1J0?ooo`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool09@3oool002<0
oooo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`1J0?ooo`030000001oOgl0Ogmo01H0
Ogmo00<000000?ooo`3oool09@3oool002<0oooo00<0000007moO`1oOgl05@1oOgl2000005`0oooo
00<0000007moO`1oOgl05@1oOgl2000002L0oooo000S0?ooo`030000001oOgl0Ogmo01D0Ogmo00<0
00000?ooo`3oool0F`3oool00`000000Ogmo07moO`0E07moO`030000003oool0oooo02H0oooo000S
0?ooo`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool0F`3oool00`000000Ogmo07moO`0E
07moO`030000003oool0oooo02H0oooo000S0?ooo`030000001oOgl0Ogmo01D0Ogmo00<000000?oo
o`3oool0F`3oool00`000000Ogmo07moO`0E07moO`030000003oool0oooo02H0oooo000S0?ooo`03
0000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool0F`3oool00`000000Ogmo07moO`0E07moO`03
0000003oool0oooo02H0oooo000S0?oooaT00000G@3ooolI000002P0oooo000S0?ooo`030000001o
Ogl0Ogmo01D0Ogmo00<000000?ooo`3oool0F`3oool00`000000Ogmo07moO`0D07moO`800000:03o
ool002<0oooo00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`1K0?ooo`030000001oOgl0
Ogmo01@0Ogmo0P00000X0?ooo`008`3oool00`000000Ogmo07moO`0E07moO`030000003oool0oooo
05/0oooo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`0W0?ooo`008`3oool00`000000
Ogmo07moO`0D07moO`800000G@3oool00`000000Ogmo07moO`0D07moO`030000003oool0oooo02L0
oooo000S0?ooo`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0G03oool00`000000Ogmo
07moO`0D07moO`030000003oool0oooo02L0oooo000S0?ooo`030000001oOgl0Ogmo01@0Ogmo00<0
00000?ooo`3oool0G03oool00`000000Ogmo07moO`0D07moO`030000003oool0oooo02L0oooo000S
0?ooo`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0G03oool00`000000Ogmo07moO`0C
07moO`800000:@3oool002<0oooo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`1L0?oo
o`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0:03oool002<0oooo6000001N0?oooaL0
0000:P3oool002<0oooo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`1L0?ooo`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0:03oool002<0oooo00<0000007moO`1oOgl0501o
Ogl00`000000oooo0?ooo`1L0?ooo`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0:03o
ool002<0oooo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`1L0?ooo`030000001oOgl0
Ogmo01<0Ogmo00<000000?ooo`3oool0:03oool002<0oooo00<0000007moO`1oOgl04`1oOgl20000
05h0oooo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`0X0?ooo`008`3oool00`000000
Ogmo07moO`0C07moO`030000003oool0oooo05d0oooo00<0000007moO`1oOgl04P1oOgl2000002X0
oooo000S0?ooo`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0G@3oool00`000000Ogmo
07moO`0B07moO`800000:P3oool002<0oooo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?oo
o`1M0?ooo`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0:@3oool002<0oooo5`00001O
0?oooaH00000:`3oool002<0oooo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`1M0?oo
o`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0:@3oool002<0oooo00<0000007moO`1o
Ogl04P1oOgl2000005l0oooo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`0Y0?ooo`00
8`3oool00`000000Ogmo07moO`0B07moO`800000G`3oool00`000000Ogmo07moO`0B07moO`030000
003oool0oooo02T0oooo000S0?ooo`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0GP3o
ool00`000000Ogmo07moO`0A07moO`800000:`3oool002<0oooo00<0000007moO`1oOgl04P1oOgl0
0`000000oooo0?ooo`1N0?ooo`030000001oOgl0Ogmo0140Ogmo0P00000[0?ooo`008`3oool00`00
0000Ogmo07moO`0B07moO`030000003oool0oooo05h0oooo00<0000007moO`1oOgl04@1oOgl20000
02/0oooo000S0?oooaH00000H03ooolF000002/0oooo000S0?ooo`030000001oOgl0Ogmo0140Ogmo
0P00001P0?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0:P3oool002<0oooo00<0
000007moO`1oOgl04@1oOgl200000600oooo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?oo
o`0Z0?ooo`008`3oool00`000000Ogmo07moO`0A07moO`800000H03oool00`000000Ogmo07moO`0A
07moO`030000003oool0oooo02X0oooo000S0?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?oo
o`3oool0G`3oool00`000000Ogmo07moO`0@07moO`800000;03oool002<0oooo00<0000007moO`1o
Ogl04@1oOgl00`000000oooo0?ooo`1O0?ooo`030000001oOgl0Ogmo0100Ogmo0P00000/0?ooo`00
8`3ooolE00000640oooo5@00000/0?ooo`008`3oool00`000000Ogmo07moO`0@07moO`800000H@3o
ool00`000000Ogmo07moO`0@07moO`030000003oool0oooo02/0oooo000S0?ooo`030000001oOgl0
Ogmo0100Ogmo0P00001Q0?ooo`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0:`3oool0
02<0oooo00<0000007moO`1oOgl0401oOgl200000640oooo00<0000007moO`1oOgl0401oOgl00`00
0000oooo0?ooo`0[0?ooo`008`3oool00`000000Ogmo07moO`0@07moO`030000003oool0oooo0600
oooo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0[0?ooo`008`3oool00`000000Ogmo
07moO`0@07moO`030000003oool0oooo0600oooo00<0000007moO`1oOgl0401oOgl00`000000oooo
0?ooo`0[0?ooo`008`3ooolD00000680oooo5000000]0?ooo`008`3oool00`000000Ogmo07moO`0?
07moO`800000HP3oool00`000000Ogmo07moO`0?07moO`800000;@3oool002<0oooo00<0000007mo
O`1oOgl03`1oOgl200000680oooo00<0000007moO`1oOgl03`1oOgl2000002d0oooo000S0?ooo`03
0000001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0?07moO`03
0000003oool0oooo02`0oooo000S0?oooa<00000H`3ooolC000002h0oooo000S0?ooo`030000001o
Ogl0Ogmo00l0Ogmo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0?07moO`030000003o
ool0oooo02`0oooo000S0?ooo`030000001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool0H@3oool0
0`000000Ogmo07moO`0?07moO`030000003oool0oooo02`0oooo000S0?oooa<00000H`3ooolC0000
02h0oooo000S0?ooo`030000001oOgl0Ogmo00h0Ogmo0P00001S0?ooo`030000001oOgl0Ogmo00h0
Ogmo0P00000^0?ooo`008`3ooolC000006<0oooo4P00000_0?ooo`008`3ooolB000006@0oooo4P00
000_0?ooo`00fP3oool00=X0oooo003J0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 217.812}, {161.562, 0}} -> {-6.00055, -14.2947, \
0.169876, 0.169876}},
  CellTags->"WedgePrism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DrawSystem", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Move", "[", 
                RowBox[{
                  RowBox[{"SingleRay", "[", 
                    RowBox[{
                      RowBox[{"Ray", "[", 
                        RowBox[{\(OpticalMedium \[Rule] Vacuum\), ",", 
                          RowBox[{"RayLineRGB", "\[Rule]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["0.0387474297047988933`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16], ",", 
                                StyleBox["0.916161755242403863`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16], ",", 
                                StyleBox["0.0398472122691814192`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->16]}], "}"}]}], 
                          ",", \(RefractiveIndex \[Rule] 1\)}], "]"}], ",", 
                      "1"}], "]"}], ",", 
                  RowBox[{"-", 
                    StyleBox["5.`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->16]}]}], "]"}], 
              ",", \(WedgePrism[8, 25, 3]\), ",", 
              RowBox[{"Move", "[", 
                RowBox[{\(WedgePrism[8, 25, 3]\), ",", 
                  StyleBox["20.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->16]}], "]"}], 
              ",", \(Boundary[{0, \(-15\), \(-15\)}, {30, 15, 
                  15}, {GraphicDesign \[Rule] Off}]\)}], "}"}], 
          ",", \(PlotType \[Rule] TopView\)}], "]"}],
      HoldForm]], "Print",
  CellTags->"WedgePrism"],

Cell[BoxData[
    \("-5 ray/surface intersections-"\)], "Output",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[WedgePrism[8, 25, 3],PlotType->TopView];", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.83817 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.146216 1.91908 0.146216 [
[ 0 0 0 0 ]
[ 1 3.83817 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.02381 .09138 m
.97619 .09138 L
.89057 .70062 L
.02381 .70062 L
.02381 .09138 L
F
.02381 .70062 m
.89057 .70062 L
.80495 1.30985 L
.02381 1.30985 L
.02381 .70062 L
F
.02381 1.30985 m
.80495 1.30985 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.30985 L
F
.02381 1.91908 m
.71932 1.91908 L
.6337 2.52832 L
.02381 2.52832 L
.02381 1.91908 L
F
.02381 2.52832 m
.6337 2.52832 L
.54808 3.13755 L
.02381 3.13755 L
.02381 2.52832 L
F
.02381 3.13755 m
.54808 3.13755 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.13755 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .09138 m
.02381 .70062 L
.02381 1.30985 L
.02381 1.91908 L
.02381 2.52832 L
.02381 3.13755 L
.02381 3.74678 L
.46246 3.74678 L
.54808 3.13755 L
.6337 2.52832 L
.71932 1.91908 L
.80495 1.30985 L
.89057 .70062 L
.97619 .09138 L
.02381 .09138 L
s
.5 g
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
0 g
.02381 1.91908 m
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
s
.02381 3.74678 m
.46246 3.74678 L
.47121 3.68451 L
.02381 3.68451 L
.02381 3.74678 L
s
.02381 3.68451 m
.47121 3.68451 L
.49687 3.50192 L
.02381 3.50192 L
.02381 3.68451 L
s
.02381 3.50192 m
.49687 3.50192 L
.53769 3.21146 L
.02381 3.21146 L
.02381 3.50192 L
s
.02381 3.21146 m
.53769 3.21146 L
.59089 2.83293 L
.02381 2.83293 L
.02381 3.21146 L
s
.02381 2.83293 m
.59089 2.83293 L
.65284 2.39213 L
.02381 2.39213 L
.02381 2.83293 L
s
.02381 2.39213 m
.65284 2.39213 L
.71932 1.91908 L
.02381 1.91908 L
.02381 2.39213 L
s
.02381 1.91908 m
.71932 1.91908 L
.78581 1.44604 L
.02381 1.44604 L
.02381 1.91908 L
s
.02381 1.44604 m
.78581 1.44604 L
.84776 1.00523 L
.02381 1.00523 L
.02381 1.44604 L
s
.02381 1.00523 m
.84776 1.00523 L
.90096 .62671 L
.02381 .62671 L
.02381 1.00523 L
s
.02381 .62671 m
.90096 .62671 L
.94178 .33625 L
.02381 .33625 L
.02381 .62671 L
s
.02381 .33625 m
.94178 .33625 L
.96744 .15366 L
.02381 .15366 L
.02381 .33625 L
s
.02381 .15366 m
.96744 .15366 L
.97619 .09138 L
.02381 .09138 L
.02381 .15366 L
s
.02381 .09138 m
.97619 .09138 L
.96744 .15366 L
.02381 .15366 L
.02381 .09138 L
s
.02381 .15366 m
.96744 .15366 L
.94178 .33625 L
.02381 .33625 L
.02381 .15366 L
s
.02381 .33625 m
.94178 .33625 L
.90096 .62671 L
.02381 .62671 L
.02381 .33625 L
s
.02381 .62671 m
.90096 .62671 L
.84776 1.00523 L
.02381 1.00523 L
.02381 .62671 L
s
.02381 1.00523 m
.84776 1.00523 L
.78581 1.44604 L
.02381 1.44604 L
.02381 1.00523 L
s
.02381 1.44604 m
.78581 1.44604 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.44604 L
s
.02381 1.91908 m
.71932 1.91908 L
.65284 2.39213 L
.02381 2.39213 L
.02381 1.91908 L
s
.02381 2.39213 m
.65284 2.39213 L
.59089 2.83293 L
.02381 2.83293 L
.02381 2.39213 L
s
.02381 2.83293 m
.59089 2.83293 L
.53769 3.21146 L
.02381 3.21146 L
.02381 2.83293 L
s
.02381 3.21146 m
.53769 3.21146 L
.49687 3.50192 L
.02381 3.50192 L
.02381 3.21146 L
s
.02381 3.50192 m
.49687 3.50192 L
.47121 3.68451 L
.02381 3.68451 L
.02381 3.50192 L
s
.02381 3.68451 m
.47121 3.68451 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.68451 L
s
0 0 m
1 0 L
1 3.83817 L
0 3.83817 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{53.5625, 205.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000e0000cB000`400?l00000o`00003o=Oooool0
03Gooooo000eooooo`00=Oooool003Gooooo000eooooo`0000?oooooo`000?l00000<Ol00001oooo
o`0000?oooooo`000?moOgl0<?moOgl1o`00007ooooo00000ooooooo0000ogmoO`0_ogmoO`;o0000
0Oooool00003ooooool0003o0000037o00000Oooool00003ooooool0003oOgmo02ooOgmo0Ol00001
ooooo`7ooooo00000ooooooo0000ogmoO`0_ogmoO`7o00000Oooool1ooooo`0000?oooooo`000?mo
Ogl0;omoOgl1o`00007ooooo0Oooool00003ooooool0003oOgmo02ooOgmo0Ol00001ooooo`7ooooo
00000ooooooo0000ogmoO`0_ogmoO`7o00000Oooool1ooooo`0000?oooooo`000?moOgl0;_moOgl2
o`0000;ooooo00000ooooooo0000ogmoO`0^ogmoO`;o00000_ooool00003ooooool0003oOgmo02ko
Ogmo00?o0000ooooooooool00Oooool00003ooooool0003oOgmo02koOgmo00?o0000ooooooooool0
0Oooool00003ooooool0003o000002oo00000oooool00003ooooool0003oOgmo02koOgmo00?o0000
ooooooooool00Oooool00003ooooool0003oOgmo02koOgmo00?o0000ooooooooool00Oooool00003
ooooool0003oOgmo02koOgmo00?o0000ooooooooool00Oooool00003ooooool0003oOgmo02goOgmo
0_l00003ooooo`0000?oooooo`000?moOgl0;OmoOgl00ol0003oooooooooo`02ooooo`0000?ooooo
o`000?moOgl0;OmoOgl00ol0003oooooooooo`02ooooo`0000?oooooo`000?moOgl0;OmoOgl00ol0
003oooooooooo`02ooooo`0000?oooooo`000?moOgl0;OmoOgl00ol0003oooooooooo`02ooooo`00
00?oooooo`000?moOgl0;OmoOgl00ol0003oooooooooo`02ooooo`0000?oooooo`000?moOgl0;?mo
Ogl2o`0000Cooooo00000ooooooo0000ogmoO`0/ogmoO`;o00001?ooool00003ooooool0003oOgmo
02coOgmo00?o0000ooooooooool00oooool00003ooooool0003oOgmo02coOgmo00?o0000oooooooo
ool00oooool00003ooooool0003oOgmo02coOgmo00?o0000ooooooooool00oooool00003ooooool0
003o000002go00001Oooool00003ooooool0003oOgmo02coOgmo00?o0000ooooooooool00oooool0
0003ooooool0003oOgmo02_oOgmo0_l00005ooooo`0000?oooooo`000?moOgl0:omoOgl2o`0000Go
oooo00000ooooooo0000ogmoO`0[ogmoO`03o`000?oooooooooo00Cooooo00000ooooooo0000ogmo
O`0[ogmoO`03o`000?oooooooooo00Cooooo00000ooooooo0000ogmoO`0[ogmoO`03o`000?oooooo
oooo00Cooooo00000ooooooo0000ogmoO`0[ogmoO`03o`000?oooooooooo00Cooooo00000ooooooo
0000ogmoO`0[ogmoO`03o`000?oooooooooo00Cooooo00000ooooooo0000ogmoO`0ZogmoO`;o0000
1_ooool00003ooooool0003oOgmo02[oOgmo0_l00006ooooo`0000?oooooo`000?moOgl0:_moOgl0
0ol0003oooooooooo`05ooooo`0000?oooooo`000?moOgl0:_moOgl00ol0003oooooooooo`05oooo
o`0000?oooooo`000?moOgl0:_moOgl00ol0003oooooooooo`05ooooo`0000?oooooo`000?moOgl0
:_moOgl00ol0003oooooooooo`05ooooo`0000?oooooo`000?moOgl0:_moOgl00ol0003ooooooooo
o`05ooooo`0000?oooooo`000?moOgl0:_moOgl00ol0003oooooooooo`05ooooo`0000?oooooo`00
0?moOgl0:OmoOgl2o`0000Oooooo00000ooooooo0000ogmoO`0YogmoO`03o`000?oooooooooo00Ko
oooo00000ooooooo0000ogmoO`0YogmoO`03o`000?oooooooooo00Kooooo00000ooooooo0000o`00
000Zo`0000Sooooo00000ooooooo0000ogmoO`0YogmoO`03o`000?oooooooooo00Kooooo00000ooo
oooo0000ogmoO`0YogmoO`03o`000?oooooooooo00Kooooo00000ooooooo0000ogmoO`0YogmoO`03
o`000?oooooooooo00Kooooo00000ooooooo0000ogmoO`0YogmoO`03o`000?oooooooooo00Kooooo
00000ooooooo0000ogmoO`0XogmoO`03o`000?oooooooooo00Oooooo00000ooooooo0000ogmoO`0X
ogmoO`03o`000?oooooooooo00Oooooo00000ooooooo0000ogmoO`0XogmoO`03o`000?oooooooooo
00Oooooo00000ooooooo0000ogmoO`0XogmoO`03o`000?oooooooooo00Oooooo00000ooooooo0000
ogmoO`0XogmoO`03o`000?oooooooooo00Oooooo00000ooooooo0000ogmoO`0XogmoO`03o`000?oo
oooooooo00Oooooo00000ooooooo0000ogmoO`0XogmoO`03o`000?oooooooooo00Oooooo00000ooo
oooo0000ogmoO`0WogmoO`;o00002Oooool00003ooooool0003oOgmo02OoOgmo00?o0000oooooooo
ool02?ooool00003ooooool0003oOgmo02OoOgmo00?o0000ooooooooool02?ooool00003ooooool0
003oOgmo02OoOgmo00?o0000ooooooooool02?ooool00003ooooool0003oOgmo02OoOgmo00?o0000
ooooooooool02?ooool00003ooooool0003oOgmo02OoOgmo00?o0000ooooooooool02?ooool00003
ooooool0003oOgmo02OoOgmo00?o0000ooooooooool02?ooool00003ooooool0003oOgmo02OoOgmo
00?o0000ooooooooool02?ooool00003ooooool0003oOgmo02KoOgmo00?o0000ooooooooool02Ooo
ool00003ooooool0003oOgmo02KoOgmo00?o0000ooooooooool02Oooool00003ooooool0003oOgmo
02KoOgmo00?o0000ooooooooool02Oooool00003ooooool0003o000002Oo00002oooool00003oooo
ool0003oOgmo02KoOgmo00?o0000ooooooooool02Oooool00003ooooool0003oOgmo02KoOgmo00?o
0000ooooooooool02Oooool00003ooooool0003oOgmo02KoOgmo00?o0000ooooooooool02Oooool0
0003ooooool0003oOgmo02GoOgmo00?o0000ooooooooool02_ooool00003ooooool0003oOgmo02Go
Ogmo00?o0000ooooooooool02_ooool00003ooooool0003oOgmo02GoOgmo00?o0000ooooooooool0
2_ooool00003ooooool0003oOgmo02GoOgmo00?o0000ooooooooool02_ooool00003ooooool0003o
Ogmo02GoOgmo00?o0000ooooooooool02_ooool00003ooooool0003oOgmo02GoOgmo00?o0000oooo
ooooool02_ooool00003ooooool0003oOgmo02CoOgmo00?o0000ooooooooool02oooool00003oooo
ool0003oOgmo02CoOgmo00?o0000ooooooooool02oooool00003ooooool0003oOgmo02CoOgmo00?o
0000ooooooooool02oooool00003ooooool0003oOgmo02CoOgmo00?o0000ooooooooool02oooool0
0003ooooool0003oOgmo02CoOgmo00?o0000ooooooooool02oooool00003ooooool0003oOgmo02Co
Ogmo00?o0000ooooooooool02oooool00003ooooool0003oOgmo02?oOgmo0_l0000=ooooo`0000?o
ooooo`000?moOgl08omoOgl00ol0003oooooooooo`0<ooooo`0000?oooooo`000?moOgl08omoOgl0
0ol0003oooooooooo`0<ooooo`0000?oooooo`000?moOgl08omoOgl00ol0003oooooooooo`0<oooo
o`0000?oooooo`000?moOgl08omoOgl00ol0003oooooooooo`0<ooooo`0000?oooooo`000?moOgl0
8omoOgl00ol0003oooooooooo`0<ooooo`0000?oooooo`000?moOgl08omoOgl00ol0003ooooooooo
o`0<ooooo`0000?oooooo`000?moOgl08_moOgl00ol0003oooooooooo`0=ooooo`0000?oooooo`00
0?moOgl08_moOgl00ol0003oooooooooo`0=ooooo`0000?oooooo`000?l000009?l0000>ooooo`00
00?oooooo`000?moOgl08_moOgl00ol0003oooooooooo`0=ooooo`0000?oooooo`000?moOgl08_mo
Ogl00ol0003oooooooooo`0=ooooo`0000?oooooo`000?moOgl08_moOgl00ol0003oooooooooo`0=
ooooo`0000?oooooo`000?moOgl08_moOgl00ol0003oooooooooo`0=ooooo`0000?oooooo`000?mo
Ogl08OmoOgl00ol0003oooooooooo`0>ooooo`0000?oooooo`000?moOgl08OmoOgl00ol0003ooooo
ooooo`0>ooooo`0000?oooooo`000?moOgl08OmoOgl00ol0003oooooooooo`0>ooooo`0000?ooooo
o`000?moOgl08OmoOgl00ol0003oooooooooo`0>ooooo`0000?oooooo`000?moOgl08OmoOgl00ol0
003oooooooooo`0>ooooo`0000?oooooo`000?moOgl08OmoOgl00ol0003oooooooooo`0>ooooo`00
00?oooooo`000?moOgl08OmoOgl00ol0003oooooooooo`0>ooooo`0000?oooooo`000?moOgl08Omo
Ogl00ol0003oooooooooo`0>ooooo`0000?oooooo`000?moOgl08?moOgl00ol0003oooooooooo`0?
ooooo`0000?oooooo`000?moOgl08?moOgl00ol0003oooooooooo`0?ooooo`0000?oooooo`000?mo
Ogl08?moOgl00ol0003oooooooooo`0?ooooo`0000?oooooo`000?moOgl08?moOgl00ol0003ooooo
ooooo`0?ooooo`0000?oooooo`000?moOgl08?moOgl00ol0003oooooooooo`0?ooooo`0000?ooooo
o`000?moOgl08?moOgl00ol0003oooooooooo`0?ooooo`0000?oooooo`000?moOgl08?moOgl00ol0
003oooooooooo`0?ooooo`0000?oooooo`000?moOgl08?moOgl00ol0003oooooooooo`0?ooooo`00
00?oooooo`000?moOgl07omoOgl2o`00017ooooo00000ooooooo0000ogmoO`0OogmoO`03o`000?oo
oooooooo013ooooo00000ooooooo0000ogmoO`0OogmoO`03o`000?oooooooooo013ooooo00000ooo
oooo0000ogmoO`0OogmoO`03o`000?oooooooooo013ooooo00000ooooooo0000o`00000Po`0001;o
oooo00000ooooooo0000ogmoO`0OogmoO`03o`000?oooooooooo013ooooo00000ooooooo0000ogmo
O`0OogmoO`03o`000?oooooooooo013ooooo00000ooooooo0000ogmoO`0OogmoO`03o`000?oooooo
oooo013ooooo00000ooooooo0000ogmoO`0NogmoO`;o00004_ooool00003ooooool0003oOgmo01ko
Ogmo00?o0000ooooooooool04Oooool00003ooooool0003oOgmo01koOgmo00?o0000ooooooooool0
4Oooool00003ooooool0003oOgmo01koOgmo00?o0000ooooooooool04Oooool00003ooooool0003o
Ogmo01koOgmo00?o0000ooooooooool04Oooool00003ooooool0003oOgmo01koOgmo00?o0000oooo
ooooool04Oooool00003ooooool0003oOgmo01koOgmo00?o0000ooooooooool04Oooool00003oooo
ool0003oOgmo01goOgmo0_l0000Cooooo`0000?oooooo`000?moOgl07OmoOgl00ol0003ooooooooo
o`0Booooo`0000?oooooo`000?moOgl07OmoOgl00ol0003oooooooooo`0Booooo`0000?oooooo`00
0?moOgl07OmoOgl00ol0003oooooooooo`0Booooo`0000?oooooo`000?moOgl07OmoOgl00ol0003o
ooooooooo`0Booooo`0000?oooooo`000?moOgl07OmoOgl00ol0003oooooooooo`0Booooo`0000?o
ooooo`000?moOgl07OmoOgl00ol0003oooooooooo`0Booooo`0000?oooooo`000?moOgl07?moOgl2
o`0001Cooooo00000ooooooo0000ogmoO`0LogmoO`;o00005?ooool00003ooooool0003oOgmo01co
Ogmo00?o0000ooooooooool04oooool00003ooooool0003oOgmo01coOgmo00?o0000ooooooooool0
4oooool00003ooooool0003oOgmo01coOgmo00?o0000ooooooooool04oooool00003ooooool0003o
000001go00005Oooool00003ooooool0003oOgmo01_oOgmo0_l0000Eooooo`0000?oooooo`000?mo
Ogl06omoOgl2o`0001Gooooo00000ooooooo0000ogmoO`0KogmoO`;o00005Oooool00003ooooool0
003oOgmo01_oOgmo00?o0000ooooooooool05?ooool00003ooooool0003oOgmo01_oOgmo00?o0000
ooooooooool05?ooool00003ooooool0003oOgmo01_oOgmo00?o0000ooooooooool05?ooool00003
ooooool0003oOgmo01[oOgmo0_l0000Fooooo`0000?oooooo`000?moOgl06_moOgl2o`0001Kooooo
00000ooooooo0000ogmoO`0JogmoO`;o00005_ooool00003ooooool0003oOgmo01[oOgmo0_l0000F
ooooo`0000?oooooo`000?moOgl06_moOgl00ol0003oooooooooo`0Eooooo`0000?oooooo`000?mo
Ogl06_moOgl00ol0003oooooooooo`0Eooooo`0000?oooooo`000?moOgl06_moOgl00ol0003ooooo
ooooo`0Eooooo`0000?oooooo`000?moOgl06OmoOgl2o`0001Oooooo00000ooooooo0000ogmoO`0I
ogmoO`;o00005oooool00003ooooool0003oOgmo01WoOgmo0_l0000Gooooo`0000?oooooo`000?mo
Ogl06OmoOgl2o`0001Oooooo00000ooooooo0000ogmoO`0IogmoO`03o`000?oooooooooo01Kooooo
00000ooooooo0000ogmoO`0IogmoO`03o`000?oooooooooo01Kooooo00000ooooooo0000o`00000J
o`0001Sooooo00000ooooooo0000ogmoO`0HogmoO`;o00006?ooool00003ooooool0003oOgmo01So
Ogmo0_l0000Hooooo`0000?oooooo`000?moOgl06?moOgl2o`0001Sooooo00000ooooooo0000ogmo
O`0HogmoO`;o00006?ooool00003ooooool0003oOgmo01SoOgmo00?o0000ooooooooool05oooool0
0003ooooool0003oOgmo01SoOgmo00?o0000ooooooooool05oooool00003ooooool0003oOgmo01So
Ogmo00?o0000ooooooooool05oooool00003ooooool0003oOgmo01SoOgmo00?o0000ooooooooool0
5oooool00003ooooool0003oOgmo01OoOgmo0_l0000Iooooo`0000?oooooo`000?moOgl05omoOgl2
o`0001Wooooo00000ooooooo0000ogmoO`0GogmoO`;o00006Oooool00003ooooool0003oOgmo01Oo
Ogmo00?o0000ooooooooool06?ooool00003ooooool0003oOgmo01OoOgmo00?o0000ooooooooool0
6?ooool00003ooooool0003oOgmo01OoOgmo00?o0000ooooooooool06?ooool00003ooooool0003o
000001So00006_ooool00003ooooool0003oOgmo01OoOgmo00?o0000ooooooooool06?ooool00003
ooooool0003oOgmo01KoOgmo0_l0000Jooooo`0000?oooooo`000?moOgl05_moOgl00ol0003ooooo
ooooo`0Iooooo`0000?oooooo`000?moOgl05_moOgl00ol0003oooooooooo`0Iooooo`0000?ooooo
o`000?moOgl05_moOgl00ol0003oooooooooo`0Iooooo`0000?oooooo`000?moOgl05_moOgl00ol0
003oooooooooo`0Iooooo`0000?oooooo`000?moOgl05_moOgl00ol0003oooooooooo`0Iooooo`00
00?oooooo`000?moOgl05OmoOgl2o`0001_ooooo00000ooooooo0000ogmoO`0EogmoO`;o00006ooo
ool00003ooooool0003o000001Ko00007?ooool00003ooooool0003oOgmo01GoOgmo00?o0000oooo
ooooool06_ooool00003ooooool0003oOgmo01GoOgmo00?o0000ooooooooool06_ooool00003oooo
ool0003o000001Ko00007?ooool003Gooooo000eooooo`00=Oooool003Gooooo000eooooo`00=Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 52.5625}, {204.562, 0}} -> {-0.162872, -13.3085, \
0.130117, 0.130117}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.79526 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.377275 1.85318 -2.22045e-16 1.85318 [
[ 0 0 0 0 ]
[ 1 1.79526 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.79526 L
0 1.79526 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.64728 .99075 m
.62866 .92371 L
s
.62866 .92371 m
.75749 .88276 L
s
.62866 .92371 m
.60678 .85747 L
s
.60678 .85747 m
.74124 .81374 L
s
.60678 .85747 m
.58186 .79277 L
s
.66239 1.05783 m
.64728 .99075 L
s
.64728 .99075 m
.77158 .95214 L
s
.58186 .79277 m
.723 .74583 L
s
.58186 .79277 m
.55417 .73036 L
s
.6738 1.12416 m
.66239 1.05783 L
s
.66239 1.05783 m
.78335 1.02112 L
s
.55417 .73036 m
.70297 .6798 L
s
.55417 .73036 m
.52401 .671 L
s
.68129 1.18897 m
.6738 1.12416 L
s
.6738 1.12416 m
.79265 1.08892 L
s
.75749 .88276 m
.77158 .95214 L
s
.74124 .81374 m
.75749 .88276 L
s
.52401 .671 m
.68133 .61644 L
s
.52401 .671 m
.49168 .61544 L
s
.723 .74583 m
.74124 .81374 L
s
.77158 .95214 m
.78335 1.02112 L
s
.70297 .6798 m
.723 .74583 L
s
.78335 1.02112 m
.79265 1.08892 L
s
.68129 1.18897 m
.79933 1.15476 L
s
.49168 .61544 m
.65831 .55653 L
s
.49168 .61544 m
.45753 .56446 L
s
.68133 .61644 m
.70297 .6798 L
s
.79265 1.08892 m
.79933 1.15476 L
s
.64263 1.20819 m .80326 1.21782 L .68471 1.25143 L .656 .751 .92 r
F
0 g
.6839 1.31071 m
.68471 1.25143 L
s
.68129 1.18897 m
.68248 1.21058 L
s
.65831 .55653 m
.68133 .61644 L
s
.67872 1.36592 m
.6839 1.31071 L
s
.6839 1.31071 m
.80432 1.27727 L
s
.63415 .50088 m
.65831 .55653 L
s
.64263 1.20819 m .77434 1.17012 L .80326 1.21782 L .656 .751 .92 r
F
0 g
.80326 1.21782 m
.80432 1.27727 L
s
.79933 1.15476 m
.80326 1.21782 L
s
.68471 1.25143 m
.80326 1.21782 L
s
.42193 .51884 m .60989 .52131 L .4203 .58934 L .544 .324 .532 r
F
.42193 .51884 m .60911 .45034 L .60989 .52131 L F
0 g
.60976 .50966 m
.63415 .50088 L
s
.42193 .51884 m
.60911 .45034 L
s
.59924 1.16362 m .77434 1.17012 L .64263 1.20819 L .656 .751 .92 r
F
0 g
.64263 1.20819 m
.68471 1.25143 L
s
.3853 .47936 m
.42193 .51884 L
s
.60911 .45034 m
.63415 .50088 L
s
.80432 1.27727 m
.80239 1.33224 L
s
.66909 1.41617 m
.67872 1.36592 L
s
.67872 1.36592 m
.80239 1.33224 L
s
.3853 .47936 m
.58349 .40576 L
s
.3853 .47936 m
.34812 .44679 L
s
.4203 .58934 m .61069 .59415 L .41862 .66166 L .544 .324 .532 r
F
.4203 .58934 m .60989 .52131 L .61069 .59415 L F
0 g
.4203 .58934 m
.42193 .51884 L
s
.59924 1.16362 m .74445 1.12082 L .77434 1.17012 L .656 .751 .92 r
F
0 g
.77434 1.17012 m
.80326 1.21782 L
s
.5545 1.11766 m .74445 1.12082 L .59924 1.16362 L .656 .751 .92 r
F
0 g
.59924 1.16362 m
.64263 1.20819 L
s
.60911 .45034 m
.60989 .52131 L
s
.58349 .40576 m
.60911 .45034 L
s
.80239 1.33224 m
.7974 1.38184 L
s
.65497 1.46056 m
.66909 1.41617 L
s
.66909 1.41617 m
.7974 1.38184 L
s
.41862 .66166 m .61151 .66894 L .41691 .73588 L .544 .324 .532 r
F
.41862 .66166 m .61069 .59415 L .61151 .66894 L F
0 g
.41862 .66166 m
.4203 .58934 L
s
.34812 .44679 m
.55761 .368 L
s
.34812 .44679 m
.3109 .42191 L
s
.5545 1.11766 m .71354 1.06983 L .74445 1.12082 L .656 .751 .92 r
F
0 g
.74445 1.12082 m
.77434 1.17012 L
s
.50834 1.07023 m .71354 1.06983 L .5545 1.11766 L .656 .751 .92 r
F
0 g
.5545 1.11766 m
.59924 1.16362 L
s
.60989 .52131 m
.61069 .59415 L
s
.55761 .368 m
.58349 .40576 L
s
.7974 1.38184 m
.78927 1.42516 L
s
.63637 1.49814 m
.65497 1.46056 L
s
.65497 1.46056 m
.78927 1.42516 L
s
.41691 .73588 m .61235 .74577 L .41515 .81207 L .544 .324 .532 r
F
.41691 .73588 m .61151 .66894 L .61235 .74577 L F
0 g
.41691 .73588 m
.41862 .66166 L
s
.3109 .42191 m
.53185 .33792 L
s
.3109 .42191 m
.2742 .40545 L
s
.61069 .59415 m
.61151 .66894 L
s
.50834 1.07023 m .68155 1.01707 L .71354 1.06983 L .656 .751 .92 r
F
0 g
.71354 1.06983 m
.74445 1.12082 L
s
.46069 1.02128 m .68155 1.01707 L .50834 1.07023 L .656 .751 .92 r
F
0 g
.50834 1.07023 m
.5545 1.11766 L
s
.53185 .33792 m
.55761 .368 L
s
.78927 1.42516 m
.778 1.46128 L
s
.61336 1.52802 m
.63637 1.49814 L
s
.63637 1.49814 m
.778 1.46128 L
s
.41515 .81207 m .61322 .8247 L .41334 .89033 L .544 .324 .532 r
F
.41515 .81207 m .61235 .74577 L .61322 .8247 L F
0 g
.41515 .81207 m
.41691 .73588 L
s
.2742 .40545 m
.5066 .31637 L
s
.2742 .40545 m
.23863 .39806 L
s
.61151 .66894 m
.61235 .74577 L
s
.41148 .97072 m .64843 .96244 L .46069 1.02128 L .656 .751 .92 r
F
.46069 1.02128 m .64843 .96244 L .68155 1.01707 L F
0 g
.46069 1.02128 m
.50834 1.07023 L
s
.68155 1.01707 m
.71354 1.06983 L
s
.5066 .31637 m
.53185 .33792 L
s
.778 1.46128 m
.76358 1.48928 L
s
.41334 .89033 m .61411 .90584 L .41148 .97072 L .544 .324 .532 r
F
.41334 .89033 m .61322 .8247 L .61411 .90584 L F
0 g
.41334 .89033 m
.41515 .81207 L
s
.76358 1.48928 m
.61336 1.52802 L
s
.58611 1.54931 m
.61336 1.52802 L
s
.61235 .74577 m
.61322 .8247 L
s
.23863 .39806 m
.48229 .30413 L
s
.23863 .39806 m
.20485 .40034 L
s
.41148 .97072 m .61503 .98928 L .40957 1.05334 L .544 .324 .532 r
F
.41148 .97072 m .61411 .90584 L .64843 .96244 L .656 .751 .92 r
F
.41148 .97072 m .61411 .90584 L .61503 .98928 L .544 .324 .532 r
F
0 g
.64843 .96244 m
.68155 1.01707 L
s
.36062 .91847 m .61411 .90584 L .41148 .97072 L .656 .751 .92 r
F
0 g
.41275 .91587 m
.41334 .89033 L
s
.48229 .30413 m
.5066 .31637 L
s
.76358 1.48928 m
.74609 1.50828 L
s
.55488 1.56121 m
.58611 1.54931 L
s
.58611 1.54931 m
.74609 1.50828 L
s
.20485 .40034 m
.4594 .30193 L
s
.20485 .40034 m
.17355 .41273 L
s
.40957 1.05334 m .61597 1.07511 L .4076 1.13828 L .544 .324 .532 r
F
.40957 1.05334 m .61503 .98928 L .61597 1.07511 L F
0 g
.40957 1.05334 m
.41148 .97072 L
s
.36062 .91847 m .57854 .84717 L .61411 .90584 L .656 .751 .92 r
F
0 g
.61322 .8247 m
.61411 .90584 L
s
.61411 .90584 m
.64843 .96244 L
s
.30804 .86445 m .57854 .84717 L .36062 .91847 L .656 .751 .92 r
F
0 g
.36062 .91847 m
.41148 .97072 L
s
.4594 .30193 m
.48229 .30413 L
s
.61411 .90584 m
.61503 .98928 L
s
.74609 1.50828 m
.72567 1.51748 L
s
.52002 1.56301 m
.55488 1.56121 L
s
.55488 1.56121 m
.72567 1.51748 L
s
.4076 1.13828 m .61694 1.16344 L .40558 1.22564 L .544 .324 .532 r
F
.4076 1.13828 m .61597 1.07511 L .61694 1.16344 L F
0 g
.4076 1.13828 m
.40957 1.05334 L
s
.17355 .41273 m
.43841 .31035 L
s
.17355 .41273 m
.14545 .43554 L
s
.30804 .86445 m .54163 .7863 L .57854 .84717 L .656 .751 .92 r
F
0 g
.57854 .84717 m
.61411 .90584 L
s
.25365 .80856 m .54163 .7863 L .30804 .86445 L .656 .751 .92 r
F
0 g
.30804 .86445 m
.36062 .91847 L
s
.61503 .98928 m
.61597 1.07511 L
s
.43841 .31035 m
.4594 .30193 L
s
.48203 1.55416 m
.52002 1.56301 L
s
.52002 1.56301 m
.70251 1.51615 L
s
.72567 1.51748 m
.70251 1.51615 L
s
.40558 1.22564 m .61794 1.25438 L .4035 1.31553 L .544 .324 .532 r
F
.40558 1.22564 m .61694 1.16344 L .61794 1.25438 L F
0 g
.40558 1.22564 m
.4076 1.13828 L
s
.14545 .43554 m
.41982 .32982 L
s
.14545 .43554 m
.12124 .46885 L
s
.61597 1.07511 m
.61694 1.16344 L
s
.25365 .80856 m .50332 .72311 L .54163 .7863 L .656 .751 .92 r
F
0 g
.54163 .7863 m
.57854 .84717 L
s
.19734 .75072 m .50332 .72311 L .25365 .80856 L .656 .751 .92 r
F
0 g
.25365 .80856 m
.30804 .86445 L
s
.4415 1.53431 m
.48203 1.55416 L
s
.48203 1.55416 m
.67692 1.50375 L
s
.41982 .32982 m
.43841 .31035 L
s
.4035 1.31553 m .61897 1.34805 L .40137 1.40806 L .544 .324 .532 r
F
.4035 1.31553 m .61794 1.25438 L .61897 1.34805 L F
0 g
.4035 1.31553 m
.40558 1.22564 L
s
.70251 1.51615 m
.67692 1.50375 L
s
.12124 .46885 m
.40415 .36055 L
s
.12124 .46885 m
.10162 .51249 L
s
.61694 1.16344 m
.61794 1.25438 L
s
.19734 .75072 m .46353 .65747 L .50332 .72311 L .656 .751 .92 r
F
0 g
.50332 .72311 m
.54163 .7863 L
s
.13902 .6908 m .46353 .65747 L .19734 .75072 L .656 .751 .92 r
F
0 g
.19734 .75072 m
.25365 .80856 L
s
.40137 1.40806 m .62003 1.44458 L .39916 1.50334 L .544 .324 .532 r
F
.40137 1.40806 m .61897 1.34805 L .62003 1.44458 L F
0 g
.40137 1.40806 m
.4035 1.31553 L
s
.39916 1.50334 m
.40137 1.40806 L
s
.39916 1.50334 m
.4415 1.53431 L
s
.4415 1.53431 m
.64927 1.47992 L
s
.40415 .36055 m
.41982 .32982 L
s
.67692 1.50375 m
.64927 1.47992 L
s
.10162 .51249 m
.39186 .4025 L
s
.10162 .51249 m
.08722 .56603 L
s
.61794 1.25438 m
.61897 1.34805 L
s
.39916 1.50334 m
.62003 1.44458 L
s
.35586 1.46143 m
.39916 1.50334 L
s
.13902 .6908 m .42215 .58923 L .46353 .65747 L .656 .751 .92 r
F
0 g
.46353 .65747 m
.50332 .72311 L
s
.07859 .62871 m .42215 .58923 L .13902 .6908 L .656 .751 .92 r
F
0 g
.13902 .6908 m
.19734 .75072 L
s
.39186 .4025 m
.40415 .36055 L
s
.62003 1.44458 m
.64927 1.47992 L
s
.61897 1.34805 m
.62003 1.44458 L
s
.31252 1.40909 m
.35586 1.46143 L
s
.35586 1.46143 m
.58977 1.39792 L
s
.07859 .62871 m .37911 .51823 L .42215 .58923 L .656 .751 .92 r
F
0 g
.07859 .62871 m
.37911 .51823 L
s
.42215 .58923 m
.46353 .65747 L
s
.07859 .62871 m
.08722 .56603 L
s
.08722 .56603 m
.38339 .45529 L
s
.07859 .62871 m
.13902 .6908 L
s
.07613 .69945 m
.07859 .62871 L
s
.38339 .45529 m
.39186 .4025 L
s
.58977 1.39792 m
.62003 1.44458 L
s
.27015 1.34714 m
.31252 1.40909 L
s
.31252 1.40909 m
.55912 1.34049 L
s
.07613 .69945 m
.37928 .59025 L
s
.07613 .69945 m
.08011 .77688 L
s
.37911 .51823 m
.42215 .58923 L
s
.22977 1.27678 m
.27015 1.34714 L
s
.27015 1.34714 m
.52878 1.27322 L
s
.37911 .51823 m
.38339 .45529 L
s
.58977 1.39792 m
.55912 1.34049 L
s
.08011 .77688 m
.38405 .66993 L
s
.08011 .77688 m
.09062 .85933 L
s
.19242 1.19951 m
.22977 1.27678 L
s
.22977 1.27678 m
.49951 1.19739 L
s
.09062 .85933 m
.39343 .75553 L
s
.09062 .85933 m
.10753 .94489 L
s
.15905 1.11709 m
.19242 1.19951 L
s
.19242 1.19951 m
.47203 1.11462 L
s
.37911 .51823 m
.37928 .59025 L
s
.10753 .94489 m
.40728 .84503 L
s
.10753 .94489 m
.13052 1.03152 L
s
.55912 1.34049 m
.52878 1.27322 L
s
.13052 1.03152 m
.15905 1.11709 L
s
.15905 1.11709 m
.44708 1.02686 L
s
.13052 1.03152 m
.42531 .93624 L
s
.38405 .66993 m
.37928 .59025 L
s
.52878 1.27322 m
.49951 1.19739 L
s
.39343 .75553 m
.38405 .66993 L
s
.49951 1.19739 m
.47203 1.11462 L
s
.40728 .84503 m
.39343 .75553 L
s
.47203 1.11462 m
.44708 1.02686 L
s
.42531 .93624 m
.40728 .84503 L
s
.44708 1.02686 m
.42531 .93624 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{86.375, 155.062},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 85.375}, {154.062, 0}} -> {0.20358, -0.00250835, \
0.00632057, 0.00632057}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem[WedgePrism[8, {25,25}, 3],PlotType->TopView];", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.83817 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.146216 1.91908 0.146216 [
[ 0 0 0 0 ]
[ 1 3.83817 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.02381 .09138 m
.97619 .09138 L
.93338 .396 L
.02381 .396 L
.02381 .09138 L
F
.02381 .396 m
.93338 .396 L
.89057 .70062 L
.02381 .70062 L
.02381 .396 L
F
.02381 .70062 m
.89057 .70062 L
.84776 1.00523 L
.02381 1.00523 L
.02381 .70062 L
F
.02381 1.00523 m
.84776 1.00523 L
.80495 1.30985 L
.02381 1.30985 L
.02381 1.00523 L
F
.02381 1.30985 m
.80495 1.30985 L
.76214 1.61447 L
.02381 1.61447 L
.02381 1.30985 L
F
.02381 1.61447 m
.76214 1.61447 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.61447 L
F
.02381 1.91908 m
.71932 1.91908 L
.67651 2.2237 L
.02381 2.2237 L
.02381 1.91908 L
F
.02381 2.2237 m
.67651 2.2237 L
.6337 2.52832 L
.02381 2.52832 L
.02381 2.2237 L
F
.02381 2.52832 m
.6337 2.52832 L
.59089 2.83293 L
.02381 2.83293 L
.02381 2.52832 L
F
.02381 2.83293 m
.59089 2.83293 L
.54808 3.13755 L
.02381 3.13755 L
.02381 2.83293 L
F
.02381 3.13755 m
.54808 3.13755 L
.50527 3.44217 L
.02381 3.44217 L
.02381 3.13755 L
F
.02381 3.44217 m
.50527 3.44217 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.44217 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .09138 m
.02381 .396 L
.02381 .70062 L
.02381 1.00523 L
.02381 1.30985 L
.02381 1.61447 L
.02381 1.91908 L
.02381 2.2237 L
.02381 2.52832 L
.02381 2.83293 L
.02381 3.13755 L
.02381 3.44217 L
.02381 3.74678 L
.46246 3.74678 L
.50527 3.44217 L
.54808 3.13755 L
.59089 2.83293 L
.6337 2.52832 L
.67651 2.2237 L
.71932 1.91908 L
.76214 1.61447 L
.80495 1.30985 L
.84776 1.00523 L
.89057 .70062 L
.93338 .396 L
.97619 .09138 L
.02381 .09138 L
s
.5 g
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
.02381 1.91908 m
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
F
0 g
.02381 1.91908 m
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.02381 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.71932 1.91908 L
.02381 1.91908 L
s
.02381 .09138 m
.97619 .09138 L
.93338 .396 L
.02381 .396 L
.02381 .09138 L
s
.02381 .396 m
.93338 .396 L
.89057 .70062 L
.02381 .70062 L
.02381 .396 L
s
.02381 .70062 m
.89057 .70062 L
.84776 1.00523 L
.02381 1.00523 L
.02381 .70062 L
s
.02381 1.00523 m
.84776 1.00523 L
.80495 1.30985 L
.02381 1.30985 L
.02381 1.00523 L
s
.02381 1.30985 m
.80495 1.30985 L
.76214 1.61447 L
.02381 1.61447 L
.02381 1.30985 L
s
.02381 1.61447 m
.76214 1.61447 L
.71932 1.91908 L
.02381 1.91908 L
.02381 1.61447 L
s
.02381 1.91908 m
.71932 1.91908 L
.67651 2.2237 L
.02381 2.2237 L
.02381 1.91908 L
s
.02381 2.2237 m
.67651 2.2237 L
.6337 2.52832 L
.02381 2.52832 L
.02381 2.2237 L
s
.02381 2.52832 m
.6337 2.52832 L
.59089 2.83293 L
.02381 2.83293 L
.02381 2.52832 L
s
.02381 2.83293 m
.59089 2.83293 L
.54808 3.13755 L
.02381 3.13755 L
.02381 2.83293 L
s
.02381 3.13755 m
.54808 3.13755 L
.50527 3.44217 L
.02381 3.44217 L
.02381 3.13755 L
s
.02381 3.44217 m
.50527 3.44217 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.44217 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.46246 3.74678 L
.02381 3.74678 L
.02381 3.74678 L
s
.02381 3.74678 m
.46246 3.74678 L
.50527 3.44217 L
.02381 3.44217 L
.02381 3.74678 L
s
.02381 3.44217 m
.50527 3.44217 L
.54808 3.13755 L
.02381 3.13755 L
.02381 3.44217 L
s
.02381 3.13755 m
.54808 3.13755 L
.59089 2.83293 L
.02381 2.83293 L
.02381 3.13755 L
s
.02381 2.83293 m
.59089 2.83293 L
.6337 2.52832 L
.02381 2.52832 L
.02381 2.83293 L
s
.02381 2.52832 m
.6337 2.52832 L
.67651 2.2237 L
.02381 2.2237 L
.02381 2.52832 L
s
.02381 2.2237 m
.67651 2.2237 L
.71932 1.91908 L
.02381 1.91908 L
.02381 2.2237 L
s
.02381 1.91908 m
.71932 1.91908 L
.76214 1.61447 L
.02381 1.61447 L
.02381 1.91908 L
s
.02381 1.61447 m
.76214 1.61447 L
.80495 1.30985 L
.02381 1.30985 L
.02381 1.61447 L
s
.02381 1.30985 m
.80495 1.30985 L
.84776 1.00523 L
.02381 1.00523 L
.02381 1.30985 L
s
.02381 1.00523 m
.84776 1.00523 L
.89057 .70062 L
.02381 .70062 L
.02381 1.00523 L
s
.02381 .70062 m
.89057 .70062 L
.93338 .396 L
.02381 .396 L
.02381 .70062 L
s
.02381 .396 m
.93338 .396 L
.97619 .09138 L
.02381 .09138 L
.02381 .396 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
.02381 .09138 m
.97619 .09138 L
.97619 .09138 L
.02381 .09138 L
.02381 .09138 L
s
0 0 m
1 0 L
1 3.83817 L
0 3.83817 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{53.5625, 205.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 52.5625}, {204.562, 0}} -> {-0.162872, -13.3085, \
0.130117, 0.130117}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.79526 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.377275 1.85318 -2.22045e-16 1.85318 [
[ 0 0 0 0 ]
[ 1 1.79526 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.79526 L
0 1.79526 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.63605 .77143 m
.6753 .81773 L
s
.6753 .81773 m
.78542 .78172 L
s
.6753 .81773 m
.67678 .88578 L
s
.78542 .78172 m
.75829 .73073 L
s
.78822 .8501 m
.78542 .78172 L
s
.67678 .88578 m
.78822 .8501 L
s
.67678 .88578 m
.67829 .95544 L
s
.59567 .7238 m
.63605 .77143 L
s
.63605 .77143 m
.75829 .73073 L
s
.79108 .92012 m
.78822 .8501 L
s
.67829 .95544 m
.79108 .92012 L
s
.67829 .95544 m
.67984 1.02678 L
s
.75829 .73073 m
.73032 .67815 L
s
.55413 .67479 m
.59567 .7238 L
s
.59567 .7238 m
.73032 .67815 L
s
.79402 .99183 m
.79108 .92012 L
s
.67984 1.02678 m
.79402 .99183 L
s
.67984 1.02678 m
.68142 1.09984 L
s
.73032 .67815 m
.70145 .62391 L
s
.70145 .62391 m
.55413 .67479 L
s
.51136 .62434 m
.55413 .67479 L
s
.79702 1.06531 m
.79402 .99183 L
s
.68142 1.09984 m
.79702 1.06531 L
s
.68142 1.09984 m
.68305 1.17471 L
s
.46731 .57238 m
.51136 .62434 L
s
.51136 .62434 m
.67166 .56791 L
s
.70145 .62391 m
.67166 .56791 L
s
.8001 1.14062 m
.79702 1.06531 L
s
.68305 1.17471 m
.8001 1.14062 L
s
.64263 1.20819 m .80326 1.21782 L .68471 1.25143 L .656 .751 .92 r
F
0 g
.68305 1.17471 m
.68383 1.21066 L
s
.68471 1.25143 m
.68642 1.33009 L
s
.67166 .56791 m
.6409 .51009 L
s
.64263 1.20819 m .77434 1.17012 L .80326 1.21782 L .656 .751 .92 r
F
0 g
.80326 1.21782 m
.8065 1.29699 L
s
.8001 1.14062 m
.80326 1.21782 L
s
.68471 1.25143 m
.80326 1.21782 L
s
.68642 1.33009 m
.8065 1.29699 L
s
.68642 1.33009 m
.68817 1.41076 L
s
.42193 .51884 m .60989 .52131 L .4203 .58934 L .544 .324 .532 r
F
.42193 .51884 m .60911 .45034 L .60989 .52131 L F
0 g
.60989 .52122 m
.6409 .51009 L
s
.37515 .46366 m
.42193 .51884 L
s
.42193 .51884 m
.60911 .45034 L
s
.59924 1.16362 m .77434 1.17012 L .64263 1.20819 L .656 .751 .92 r
F
0 g
.64263 1.20819 m
.68471 1.25143 L
s
.60911 .45034 m
.6409 .51009 L
s
.80982 1.3782 m
.8065 1.29699 L
s
.68817 1.41076 m
.80982 1.3782 L
s
.68817 1.41076 m
.68996 1.49351 L
s
.4203 .58934 m .61069 .59415 L .41862 .66166 L .544 .324 .532 r
F
.4203 .58934 m .60989 .52131 L .61069 .59415 L F
0 g
.4203 .58934 m
.42193 .51884 L
s
.59924 1.16362 m .74445 1.12082 L .77434 1.17012 L .656 .751 .92 r
F
0 g
.77434 1.17012 m
.80326 1.21782 L
s
.37515 .46366 m
.57624 .38858 L
s
.5545 1.11766 m .74445 1.12082 L .59924 1.16362 L .656 .751 .92 r
F
0 g
.59924 1.16362 m
.64263 1.20819 L
s
.3269 .40675 m
.37515 .46366 L
s
.57624 .38858 m
.60911 .45034 L
s
.60911 .45034 m
.60989 .52131 L
s
.81323 1.46155 m
.80982 1.3782 L
s
.68996 1.49351 m
.81323 1.46155 L
s
.68996 1.49351 m
.69181 1.57844 L
s
.41862 .66166 m .61151 .66894 L .41691 .73588 L .544 .324 .532 r
F
.41862 .66166 m .61069 .59415 L .61151 .66894 L F
0 g
.41862 .66166 m
.4203 .58934 L
s
.5545 1.11766 m .71354 1.06983 L .74445 1.12082 L .656 .751 .92 r
F
0 g
.74445 1.12082 m
.77434 1.17012 L
s
.54225 .32469 m
.3269 .40675 L
s
.27713 .34804 m
.3269 .40675 L
s
.50834 1.07023 m .71354 1.06983 L .5545 1.11766 L .656 .751 .92 r
F
0 g
.5545 1.11766 m
.59924 1.16362 L
s
.60989 .52131 m
.61069 .59415 L
s
.81673 1.5471 m
.81323 1.46155 L
s
.57624 .38858 m
.54225 .32469 L
s
.69181 1.57844 m
.81673 1.5471 L
s
.69181 1.57844 m
.6937 1.66561 L
s
.41691 .73588 m .61235 .74577 L .41515 .81207 L .544 .324 .532 r
F
.41691 .73588 m .61151 .66894 L .61235 .74577 L F
0 g
.41691 .73588 m
.41862 .66166 L
s
.61069 .59415 m
.61151 .66894 L
s
.50706 .25856 m
.27713 .34804 L
s
.22575 .28742 m
.27713 .34804 L
s
.50834 1.07023 m .68155 1.01707 L .71354 1.06983 L .656 .751 .92 r
F
0 g
.71354 1.06983 m
.74445 1.12082 L
s
.46069 1.02128 m .68155 1.01707 L .50834 1.07023 L .656 .751 .92 r
F
0 g
.50834 1.07023 m
.5545 1.11766 L
s
.82032 1.63495 m
.81673 1.5471 L
s
.6937 1.66561 m
.82032 1.63495 L
s
.6937 1.66561 m
.69564 1.75513 L
s
.41515 .81207 m .61322 .8247 L .41334 .89033 L .544 .324 .532 r
F
.41515 .81207 m .61235 .74577 L .61322 .8247 L F
0 g
.41515 .81207 m
.41691 .73588 L
s
.54225 .32469 m
.50706 .25856 L
s
.61151 .66894 m
.61235 .74577 L
s
.82402 1.72519 m
.82032 1.63495 L
s
.17268 .22482 m
.22575 .28742 L
s
.22575 .28742 m
.47063 .19008 L
s
.41148 .97072 m .64843 .96244 L .46069 1.02128 L .656 .751 .92 r
F
.46069 1.02128 m .64843 .96244 L .68155 1.01707 L F
0 g
.46069 1.02128 m
.50834 1.07023 L
s
.68155 1.01707 m
.71354 1.06983 L
s
.69564 1.75513 m
.82402 1.72519 L
s
.69564 1.75513 m
.65028 1.71661 L
s
.41334 .89033 m .61411 .90584 L .41148 .97072 L .544 .324 .532 r
F
.41334 .89033 m .61322 .8247 L .61411 .90584 L F
0 g
.41334 .89033 m
.41515 .81207 L
s
.50706 .25856 m
.47063 .19008 L
s
.61235 .74577 m
.61322 .8247 L
s
.79306 1.68261 m
.82402 1.72519 L
s
.43287 .11911 m
.17268 .22482 L
s
.11784 .16014 m
.17268 .22482 L
s
.41148 .97072 m .61503 .98928 L .40957 1.05334 L .544 .324 .532 r
F
.41148 .97072 m .61411 .90584 L .64843 .96244 L .656 .751 .92 r
F
.41148 .97072 m .61411 .90584 L .61503 .98928 L .544 .324 .532 r
F
0 g
.64843 .96244 m
.68155 1.01707 L
s
.36062 .91847 m .61411 .90584 L .41148 .97072 L .656 .751 .92 r
F
0 g
.41275 .91587 m
.41334 .89033 L
s
.65028 1.71661 m
.79306 1.68261 L
s
.65028 1.71661 m
.60341 1.6768 L
s
.47063 .19008 m
.43287 .11911 L
s
.40957 1.05334 m .61597 1.07511 L .4076 1.13828 L .544 .324 .532 r
F
.40957 1.05334 m .61503 .98928 L .61597 1.07511 L F
0 g
.40957 1.05334 m
.41148 .97072 L
s
.76098 1.63848 m
.79306 1.68261 L
s
.39371 .04552 m
.11784 .16014 L
s
.11176 .23273 m
.11784 .16014 L
s
.36062 .91847 m .57854 .84717 L .61411 .90584 L .656 .751 .92 r
F
0 g
.61322 .8247 m
.61411 .90584 L
s
.61411 .90584 m
.64843 .96244 L
s
.30804 .86445 m .57854 .84717 L .36062 .91847 L .656 .751 .92 r
F
0 g
.36062 .91847 m
.41148 .97072 L
s
.60341 1.6768 m
.76098 1.63848 L
s
.60341 1.6768 m
.55494 1.63564 L
s
.61411 .90584 m
.61503 .98928 L
s
.43287 .11911 m
.39371 .04552 L
s
.4076 1.13828 m .61694 1.16344 L .40558 1.22564 L .544 .324 .532 r
F
.4076 1.13828 m .61597 1.07511 L .61694 1.16344 L F
0 g
.4076 1.13828 m
.40957 1.05334 L
s
.1055 .3074 m
.11176 .23273 L
s
.11176 .23273 m
.39145 .11859 L
s
.72771 1.5927 m
.76098 1.63848 L
s
.55494 1.63564 m
.72771 1.5927 L
s
.30804 .86445 m .54163 .7863 L .57854 .84717 L .656 .751 .92 r
F
0 g
.57854 .84717 m
.61411 .90584 L
s
.25365 .80856 m .54163 .7863 L .30804 .86445 L .656 .751 .92 r
F
0 g
.30804 .86445 m
.36062 .91847 L
s
.55494 1.63564 m
.50481 1.59306 L
s
.61503 .98928 m
.61597 1.07511 L
s
.40558 1.22564 m .61794 1.25438 L .4035 1.31553 L .544 .324 .532 r
F
.40558 1.22564 m .61694 1.16344 L .61794 1.25438 L F
0 g
.40558 1.22564 m
.4076 1.13828 L
s
.09907 .38423 m
.1055 .3074 L
s
.1055 .3074 m
.38913 .19381 L
s
.39371 .04552 m
.39145 .11859 L
s
.61597 1.07511 m
.61694 1.16344 L
s
.25365 .80856 m .50332 .72311 L .54163 .7863 L .656 .751 .92 r
F
0 g
.54163 .7863 m
.57854 .84717 L
s
.19734 .75072 m .50332 .72311 L .25365 .80856 L .656 .751 .92 r
F
0 g
.25365 .80856 m
.30804 .86445 L
s
.50481 1.59306 m
.69317 1.5452 L
s
.50481 1.59306 m
.45291 1.54899 L
s
.69317 1.5452 m
.72771 1.5927 L
s
.4035 1.31553 m .61897 1.34805 L .40137 1.40806 L .544 .324 .532 r
F
.4035 1.31553 m .61794 1.25438 L .61897 1.34805 L F
0 g
.4035 1.31553 m
.40558 1.22564 L
s
.38674 .27128 m
.09907 .38423 L
s
.09244 .46332 m
.09907 .38423 L
s
.39145 .11859 m
.38913 .19381 L
s
.61694 1.16344 m
.61794 1.25438 L
s
.19734 .75072 m .46353 .65747 L .50332 .72311 L .656 .751 .92 r
F
0 g
.50332 .72311 m
.54163 .7863 L
s
.13902 .6908 m .46353 .65747 L .19734 .75072 L .656 .751 .92 r
F
0 g
.19734 .75072 m
.25365 .80856 L
s
.65731 1.49586 m
.69317 1.5452 L
s
.40137 1.40806 m .62003 1.44458 L .39916 1.50334 L .544 .324 .532 r
F
0 g
.45291 1.54899 m
.65731 1.49586 L
s
.39916 1.50334 m
.45291 1.54899 L
s
.40137 1.40806 m .61897 1.34805 L .62003 1.44458 L .544 .324 .532 r
F
0 g
.40137 1.40806 m
.4035 1.31553 L
s
.39916 1.50334 m
.40137 1.40806 L
s
.08562 .54478 m
.09244 .46332 L
s
.09244 .46332 m
.38427 .3511 L
s
.38913 .19381 m
.38674 .27128 L
s
.61794 1.25438 m
.61897 1.34805 L
s
.39916 1.50334 m
.62003 1.44458 L
s
.13902 .6908 m .42215 .58923 L .46353 .65747 L .656 .751 .92 r
F
0 g
.46353 .65747 m
.50332 .72311 L
s
.07859 .62871 m .42215 .58923 L .13902 .6908 L .656 .751 .92 r
F
0 g
.13902 .6908 m
.19734 .75072 L
s
.34346 1.45603 m
.39916 1.50334 L
s
.62003 1.44458 m
.65731 1.49586 L
s
.38674 .27128 m
.38427 .3511 L
s
.61897 1.34805 m
.62003 1.44458 L
s
.07859 .62871 m .37911 .51823 L .42215 .58923 L .656 .751 .92 r
F
0 g
.07859 .62871 m
.37911 .51823 L
s
.07134 .71522 m
.07859 .62871 L
s
.42215 .58923 m
.46353 .65747 L
s
.08562 .54478 m
.38173 .43338 L
s
.07859 .62871 m
.08562 .54478 L
s
.07859 .62871 m
.13902 .6908 L
s
.34346 1.45603 m
.58126 1.39124 L
s
.34346 1.45603 m
.28569 1.40697 L
s
.38427 .3511 m
.38173 .43338 L
s
.58126 1.39124 m
.62003 1.44458 L
s
.37911 .51823 m
.42215 .58923 L
s
.06386 .80444 m
.07134 .71522 L
s
.07134 .71522 m
.3764 .60578 L
s
.37911 .51823 m
.38173 .43338 L
s
.28569 1.40697 m
.5409 1.33572 L
s
.28569 1.40697 m
.22573 1.35605 L
s
.5409 1.33572 m
.58126 1.39124 L
s
.05615 .89649 m
.06386 .80444 L
s
.06386 .80444 m
.37361 .69616 L
s
.3764 .60578 m
.37911 .51823 L
s
.22573 1.35605 m
.49886 1.27788 L
s
.22573 1.35605 m
.16347 1.30318 L
s
.49886 1.27788 m
.5409 1.33572 L
s
.37072 .78951 m
.05615 .89649 L
s
.04819 .99151 m
.05615 .89649 L
s
.3764 .60578 m
.37361 .69616 L
s
.16347 1.30318 m
.45502 1.21757 L
s
.16347 1.30318 m
.09877 1.24822 L
s
.03997 1.08966 m
.04819 .99151 L
s
.04819 .99151 m
.36774 .88597 L
s
.37361 .69616 m
.37072 .78951 L
s
.45502 1.21757 m
.49886 1.27788 L
s
.09877 1.24822 m
.40927 1.15463 L
s
.09877 1.24822 m
.03147 1.19107 L
s
.36466 .9857 m
.03997 1.08966 L
s
.03147 1.19107 m
.03997 1.08966 L
s
.37072 .78951 m
.36774 .88597 L
s
.40927 1.15463 m
.45502 1.21757 L
s
.36147 1.08888 m
.03147 1.19107 L
s
.36774 .88597 m
.36466 .9857 L
s
.36147 1.08888 m
.40927 1.15463 L
s
.36466 .9857 m
.36147 1.08888 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{102.375, 183.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 101.375}, {182.812, 0}} -> {0.20358, -0.00218199, \
0.00532299, 0.00532299}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[WedgePrism[8, {{-25,-25},{0,25},{25,-25}}, \
3],PlotType->TopView];\
\>", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.00358 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0953063 2.50179 0.0953063 [
[ 0 0 0 0 ]
[ 1 5.00358 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 4.88445 m
.02381 4.48734 L
.36825 4.46801 L
.31299 4.86126 L
.02381 4.88445 L
s
.02381 4.48734 m
.02381 4.09023 L
.42352 4.07477 L
.36825 4.46801 L
.02381 4.48734 L
s
.02381 4.09023 m
.02381 3.69312 L
.47879 3.68152 L
.42352 4.07477 L
.02381 4.09023 L
s
.02381 3.69312 m
.02381 3.29601 L
.53405 3.28828 L
.47879 3.68152 L
.02381 3.69312 L
s
.02381 3.29601 m
.02381 2.8989 L
.58932 2.89503 L
.53405 3.28828 L
.02381 3.29601 L
s
.02381 2.8989 m
.02381 2.50179 L
.64459 2.50179 L
.58932 2.89503 L
.02381 2.8989 L
s
.02381 2.50179 m
.02381 2.10468 L
.69986 2.10854 L
.64459 2.50179 L
.02381 2.50179 L
s
.02381 2.10468 m
.02381 1.70757 L
.75512 1.7153 L
.69986 2.10854 L
.02381 2.10468 L
s
.02381 1.70757 m
.02381 1.31046 L
.81039 1.32205 L
.75512 1.7153 L
.02381 1.70757 L
s
.02381 1.31046 m
.02381 .91335 L
.86566 .92881 L
.81039 1.32205 L
.02381 1.31046 L
s
.02381 .91335 m
.02381 .51624 L
.92092 .53557 L
.86566 .92881 L
.02381 .91335 L
s
.02381 .51624 m
.02381 .11913 L
.97619 .14232 L
.92092 .53557 L
.02381 .51624 L
s
.02381 .11913 m
.02381 .31769 L
.94856 .33894 L
.97619 .14232 L
.02381 .11913 L
s
.02381 .31769 m
.02381 .51624 L
.92092 .53557 L
.94856 .33894 L
.02381 .31769 L
s
.02381 .51624 m
.02381 .7148 L
.89329 .73219 L
.92092 .53557 L
.02381 .51624 L
s
.02381 .7148 m
.02381 .91335 L
.86566 .92881 L
.89329 .73219 L
.02381 .7148 L
s
.02381 .91335 m
.02381 1.11191 L
.83802 1.12543 L
.86566 .92881 L
.02381 .91335 L
s
.02381 1.11191 m
.02381 1.31046 L
.81039 1.32205 L
.83802 1.12543 L
.02381 1.11191 L
s
.02381 1.31046 m
.02381 1.50902 L
.78276 1.51868 L
.81039 1.32205 L
.02381 1.31046 L
s
.02381 1.50902 m
.02381 1.70757 L
.75512 1.7153 L
.78276 1.51868 L
.02381 1.50902 L
s
.02381 1.70757 m
.02381 1.90613 L
.72749 1.91192 L
.75512 1.7153 L
.02381 1.70757 L
s
.02381 1.90613 m
.02381 2.10468 L
.69986 2.10854 L
.72749 1.91192 L
.02381 1.90613 L
s
.02381 2.10468 m
.02381 2.30323 L
.67222 2.30517 L
.69986 2.10854 L
.02381 2.10468 L
s
.02381 2.30323 m
.02381 2.50179 L
.64459 2.50179 L
.67222 2.30517 L
.02381 2.30323 L
s
.02381 2.50179 m
.02381 2.70034 L
.61696 2.69841 L
.64459 2.50179 L
.02381 2.50179 L
s
.02381 2.70034 m
.02381 2.8989 L
.58932 2.89503 L
.61696 2.69841 L
.02381 2.70034 L
s
.02381 2.8989 m
.02381 3.09745 L
.56169 3.09166 L
.58932 2.89503 L
.02381 2.8989 L
s
.02381 3.09745 m
.02381 3.29601 L
.53405 3.28828 L
.56169 3.09166 L
.02381 3.09745 L
s
.02381 3.29601 m
.02381 3.49456 L
.50642 3.4849 L
.53405 3.28828 L
.02381 3.29601 L
s
.02381 3.49456 m
.02381 3.69312 L
.47879 3.68152 L
.50642 3.4849 L
.02381 3.49456 L
s
.02381 3.69312 m
.02381 3.89167 L
.45115 3.87815 L
.47879 3.68152 L
.02381 3.69312 L
s
.02381 3.89167 m
.02381 4.09023 L
.42352 4.07477 L
.45115 3.87815 L
.02381 3.89167 L
s
.02381 4.09023 m
.02381 4.28878 L
.39589 4.27139 L
.42352 4.07477 L
.02381 4.09023 L
s
.02381 4.28878 m
.02381 4.48734 L
.36825 4.46801 L
.39589 4.27139 L
.02381 4.28878 L
s
.02381 4.48734 m
.02381 4.68589 L
.34062 4.66464 L
.36825 4.46801 L
.02381 4.48734 L
s
.02381 4.68589 m
.02381 4.88445 L
.31299 4.86126 L
.34062 4.66464 L
.02381 4.68589 L
s
0 0 m
1 0 L
1 5.00358 L
0 5.00358 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{29.875, 149.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 28.875}, {148.438, 0}} -> {-0.249873, -26.9696, \
0.36338, 0.36338}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.91661 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.434713 1.97183 -2.22045e-16 1.97183 [
[ 0 0 0 0 ]
[ 1 1.91661 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91661 L
0 1.91661 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.77506 .83586 m
.71725 .85848 L
s
.71725 .85848 m
.67512 .80814 L
s
.69805 .90736 m
.71725 .85848 L
s
.77506 .83586 m
.76294 .88297 L
s
.7456 .78148 m
.77506 .83586 L
s
.7456 .78148 m
.67512 .80814 L
s
.67512 .80814 m
.63178 .75637 L
s
.76294 .88297 m
.69805 .90736 L
s
.67811 .95814 m
.69805 .90736 L
s
.71524 .72543 m
.7456 .78148 L
s
.76294 .88297 m
.75033 .93197 L
s
.71524 .72543 m
.63178 .75637 L
s
.63178 .75637 m
.58719 .70308 L
s
.68392 .66762 m
.71524 .72543 L
s
.75033 .93197 m
.67811 .95814 L
s
.65739 1.01091 m
.67811 .95814 L
s
.68392 .66762 m
.58719 .70308 L
s
.58719 .70308 m
.54127 .64823 L
s
.75033 .93197 m
.73721 .98295 L
s
.6516 .60798 m
.68392 .66762 L
s
.73721 .98295 m
.65739 1.01091 L
s
.63583 1.06581 m
.65739 1.01091 L
s
.6516 .60798 m
.54127 .64823 L
s
.54127 .64823 m
.49398 .59173 L
s
.73721 .98295 m
.72354 1.03605 L
s
.61824 .54641 m
.6516 .60798 L
s
.61824 .54641 m
.49398 .59173 L
s
.49398 .59173 m
.44525 .53352 L
s
.72354 1.03605 m
.63583 1.06581 L
s
.61339 1.12295 m
.63583 1.06581 L
s
.58379 .48282 m
.61824 .54641 L
s
.72354 1.03605 m
.70929 1.0914 L
s
.44525 .53352 m
.58379 .48282 L
s
.44525 .53352 m
.39502 .4735 L
s
.70929 1.0914 m
.61339 1.12295 L
s
.59001 1.18248 m
.61339 1.12295 L
s
.54819 .4171 m
.58379 .48282 L
s
.54819 .4171 m
.39502 .4735 L
s
.39502 .4735 m
.34321 .41161 L
s
.70929 1.0914 m
.69443 1.14914 L
s
.51137 .34916 m
.54819 .4171 L
s
.69443 1.14914 m
.59001 1.18248 L
s
.56563 1.24455 m
.59001 1.18248 L
s
.51137 .34916 m
.34321 .41161 L
s
.34321 .41161 m
.28975 .34774 L
s
.69443 1.14914 m
.67891 1.20944 L
s
.47329 .27887 m
.51137 .34916 L
s
.47329 .27887 m
.28975 .34774 L
s
.28975 .34774 m
.23456 .2818 L
s
.67891 1.20944 m
.56563 1.24455 L
s
.54019 1.30934 m
.56563 1.24455 L
s
.43387 .20611 m
.23456 .2818 L
s
.23456 .2818 m
.17755 .21369 L
s
.67891 1.20944 m
.66269 1.27247 L
s
.43387 .20611 m
.47329 .27887 L
s
.66269 1.27247 m
.54019 1.30934 L
s
.51361 1.37701 m
.54019 1.30934 L
s
.17755 .21369 m
.39304 .13074 L
s
.17755 .21369 m
.11863 .14331 L
s
.39304 .13074 m
.43387 .20611 L
s
.66269 1.27247 m
.64571 1.33842 L
s
.64571 1.33842 m
.51361 1.37701 L
s
.48582 1.44777 m
.51361 1.37701 L
s
.11863 .14331 m
.35072 .05264 L
s
.11863 .14331 m
.14269 .25716 L
s
.35072 .05264 m
.39304 .13074 L
s
.36951 .1708 m
.14269 .25716 L
s
.14269 .25716 m
.16701 .37231 L
s
.38849 .29019 m
.16701 .37231 L
s
.16701 .37231 m
.19161 .48876 L
s
.64571 1.33842 m
.62794 1.4075 L
s
.40767 .41082 m
.19161 .48876 L
s
.19161 .48876 m
.21649 .60653 L
s
.36951 .1708 m
.35072 .05264 L
s
.42705 .53272 m
.21649 .60653 L
s
.21649 .60653 m
.24166 .72566 L
s
.62794 1.4075 m
.48582 1.44777 L
s
.45673 1.52184 m
.48582 1.44777 L
s
.38849 .29019 m
.36951 .1708 L
s
.44663 .65591 m
.24166 .72566 L
s
.24166 .72566 m
.26712 .84617 L
s
.40767 .41082 m
.38849 .29019 L
s
.26712 .84617 m
.46642 .7804 L
s
.26712 .84617 m
.29287 .96807 L
s
.62794 1.4075 m
.60929 1.47992 L
s
.42705 .53272 m
.40767 .41082 L
s
.48643 .90622 m
.29287 .96807 L
s
.29287 .96807 m
.31892 1.0914 L
s
.44663 .65591 m
.42705 .53272 L
s
.50664 1.03338 m
.31892 1.0914 L
s
.31892 1.0914 m
.34528 1.21617 L
s
.60929 1.47992 m
.45673 1.52184 L
s
.42625 1.59945 m
.45673 1.52184 L
s
.46642 .7804 m
.44663 .65591 L
s
.52708 1.16191 m
.34528 1.21617 L
s
.34528 1.21617 m
.37195 1.34242 L
s
.48643 .90622 m
.46642 .7804 L
s
.54773 1.29184 m
.37195 1.34242 L
s
.37195 1.34242 m
.39894 1.47017 L
s
.50664 1.03338 m
.48643 .90622 L
s
.60929 1.47992 m
.58972 1.55595 L
s
.52708 1.16191 m
.50664 1.03338 L
s
.56862 1.42318 m
.39894 1.47017 L
s
.39894 1.47017 m
.42625 1.59945 L
s
.54773 1.29184 m
.52708 1.16191 L
s
.42625 1.59945 m
.58972 1.55595 L
s
.56862 1.42318 m
.54773 1.29184 L
s
.58972 1.55595 m
.56862 1.42318 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{81.125, 155.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 80.125}, {154.438, 0}} -> {0.220459, -0.0027554, \
0.00632946, 0.00632946}},
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[
{Ray[],
Move[WedgePrism[20, 25, 3],30],
Boundary[100,GraphicDesign->Off]},
PlotType->TopView];\
\>", "Input",
  CellTags->"WedgePrism"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.125 0.00952381 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.30952 .00595 m
.42475 .00595 L
.41753 .02579 L
.30952 .02579 L
.30952 .00595 L
F
.30952 .02579 m
.41753 .02579 L
.41031 .04563 L
.30952 .04563 L
.30952 .02579 L
F
.30952 .04563 m
.41031 .04563 L
.40309 .06548 L
.30952 .06548 L
.30952 .04563 L
F
.30952 .06548 m
.40309 .06548 L
.39587 .08532 L
.30952 .08532 L
.30952 .06548 L
F
.30952 .08532 m
.39587 .08532 L
.38865 .10516 L
.30952 .10516 L
.30952 .08532 L
F
.30952 .10516 m
.38865 .10516 L
.38143 .125 L
.30952 .125 L
.30952 .10516 L
F
.30952 .125 m
.38143 .125 L
.3742 .14484 L
.30952 .14484 L
.30952 .125 L
F
.30952 .14484 m
.3742 .14484 L
.36698 .16468 L
.30952 .16468 L
.30952 .14484 L
F
.30952 .16468 m
.36698 .16468 L
.35976 .18452 L
.30952 .18452 L
.30952 .16468 L
F
.30952 .18452 m
.35976 .18452 L
.35254 .20437 L
.30952 .20437 L
.30952 .18452 L
F
.30952 .20437 m
.35254 .20437 L
.34532 .22421 L
.30952 .22421 L
.30952 .20437 L
F
.30952 .22421 m
.34532 .22421 L
.3381 .24405 L
.30952 .24405 L
.30952 .22421 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.30952 .00595 m
.30952 .02579 L
.30952 .04563 L
.30952 .06548 L
.30952 .08532 L
.30952 .10516 L
.30952 .125 L
.30952 .14484 L
.30952 .16468 L
.30952 .18452 L
.30952 .20437 L
.30952 .22421 L
.30952 .24405 L
.3381 .24405 L
.34532 .22421 L
.35254 .20437 L
.35976 .18452 L
.36698 .16468 L
.3742 .14484 L
.38143 .125 L
.38865 .10516 L
.39587 .08532 L
.40309 .06548 L
.41031 .04563 L
.41753 .02579 L
.42475 .00595 L
.30952 .00595 L
s
.5 g
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
.30952 .125 m
.38143 .125 L
.38143 .125 L
.30952 .125 L
.30952 .125 L
F
0 g
.30952 .125 m
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.30952 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.38143 .125 L
.30952 .125 L
s
.30952 .24405 m
.3381 .24405 L
.33847 .24303 L
.30952 .24303 L
.30952 .24405 L
s
.30952 .24303 m
.33847 .24303 L
.33957 .23999 L
.30952 .23999 L
.30952 .24303 L
s
.30952 .23999 m
.33957 .23999 L
.34139 .23499 L
.30952 .23499 L
.30952 .23999 L
s
.30952 .23499 m
.34139 .23499 L
.3439 .2281 L
.30952 .2281 L
.30952 .23499 L
s
.30952 .2281 m
.3439 .2281 L
.34705 .21945 L
.30952 .21945 L
.30952 .2281 L
s
.30952 .21945 m
.34705 .21945 L
.35079 .20918 L
.30952 .20918 L
.30952 .21945 L
s
.30952 .20918 m
.35079 .20918 L
.35505 .19747 L
.30952 .19747 L
.30952 .20918 L
s
.30952 .19747 m
.35505 .19747 L
.35976 .18452 L
.30952 .18452 L
.30952 .19747 L
s
.30952 .18452 m
.35976 .18452 L
.36484 .17056 L
.30952 .17056 L
.30952 .18452 L
s
.30952 .17056 m
.36484 .17056 L
.37021 .15581 L
.30952 .15581 L
.30952 .17056 L
s
.30952 .15581 m
.37021 .15581 L
.37577 .14054 L
.30952 .14054 L
.30952 .15581 L
s
.30952 .14054 m
.37577 .14054 L
.38143 .125 L
.30952 .125 L
.30952 .14054 L
s
.30952 .125 m
.38143 .125 L
.38708 .10946 L
.30952 .10946 L
.30952 .125 L
s
.30952 .10946 m
.38708 .10946 L
.39264 .09419 L
.30952 .09419 L
.30952 .10946 L
s
.30952 .09419 m
.39264 .09419 L
.39801 .07944 L
.30952 .07944 L
.30952 .09419 L
s
.30952 .07944 m
.39801 .07944 L
.40309 .06548 L
.30952 .06548 L
.30952 .07944 L
s
.30952 .06548 m
.40309 .06548 L
.4078 .05253 L
.30952 .05253 L
.30952 .06548 L
s
.30952 .05253 m
.4078 .05253 L
.41206 .04082 L
.30952 .04082 L
.30952 .05253 L
s
.30952 .04082 m
.41206 .04082 L
.4158 .03055 L
.30952 .03055 L
.30952 .04082 L
s
.30952 .03055 m
.4158 .03055 L
.41895 .0219 L
.30952 .0219 L
.30952 .03055 L
s
.30952 .0219 m
.41895 .0219 L
.42146 .01501 L
.30952 .01501 L
.30952 .0219 L
s
.30952 .01501 m
.42146 .01501 L
.42328 .01001 L
.30952 .01001 L
.30952 .01501 L
s
.30952 .01001 m
.42328 .01001 L
.42438 .00697 L
.30952 .00697 L
.30952 .01001 L
s
.30952 .00697 m
.42438 .00697 L
.42475 .00595 L
.30952 .00595 L
.30952 .00697 L
s
.30952 .00595 m
.42475 .00595 L
.42438 .00697 L
.30952 .00697 L
.30952 .00595 L
s
.30952 .00697 m
.42438 .00697 L
.42328 .01001 L
.30952 .01001 L
.30952 .00697 L
s
.30952 .01001 m
.42328 .01001 L
.42146 .01501 L
.30952 .01501 L
.30952 .01001 L
s
.30952 .01501 m
.42146 .01501 L
.41895 .0219 L
.30952 .0219 L
.30952 .01501 L
s
.30952 .0219 m
.41895 .0219 L
.4158 .03055 L
.30952 .03055 L
.30952 .0219 L
s
.30952 .03055 m
.4158 .03055 L
.41206 .04082 L
.30952 .04082 L
.30952 .03055 L
s
.30952 .04082 m
.41206 .04082 L
.4078 .05253 L
.30952 .05253 L
.30952 .04082 L
s
.30952 .05253 m
.4078 .05253 L
.40309 .06548 L
.30952 .06548 L
.30952 .05253 L
s
.30952 .06548 m
.40309 .06548 L
.39801 .07944 L
.30952 .07944 L
.30952 .06548 L
s
.30952 .07944 m
.39801 .07944 L
.39264 .09419 L
.30952 .09419 L
.30952 .07944 L
s
.30952 .09419 m
.39264 .09419 L
.38708 .10946 L
.30952 .10946 L
.30952 .09419 L
s
.30952 .10946 m
.38708 .10946 L
.38143 .125 L
.30952 .125 L
.30952 .10946 L
s
.30952 .125 m
.38143 .125 L
.37577 .14054 L
.30952 .14054 L
.30952 .125 L
s
.30952 .14054 m
.37577 .14054 L
.37021 .15581 L
.30952 .15581 L
.30952 .14054 L
s
.30952 .15581 m
.37021 .15581 L
.36484 .17056 L
.30952 .17056 L
.30952 .15581 L
s
.30952 .17056 m
.36484 .17056 L
.35976 .18452 L
.30952 .18452 L
.30952 .17056 L
s
.30952 .18452 m
.35976 .18452 L
.35505 .19747 L
.30952 .19747 L
.30952 .18452 L
s
.30952 .19747 m
.35505 .19747 L
.35079 .20918 L
.30952 .20918 L
.30952 .19747 L
s
.30952 .20918 m
.35079 .20918 L
.34705 .21945 L
.30952 .21945 L
.30952 .20918 L
s
.30952 .21945 m
.34705 .21945 L
.3439 .2281 L
.30952 .2281 L
.30952 .21945 L
s
.30952 .2281 m
.3439 .2281 L
.34139 .23499 L
.30952 .23499 L
.30952 .2281 L
s
.30952 .23499 m
.34139 .23499 L
.33957 .23999 L
.30952 .23999 L
.30952 .23499 L
s
.30952 .23999 m
.33957 .23999 L
.33847 .24303 L
.30952 .24303 L
.30952 .23999 L
s
.30952 .24303 m
.33847 .24303 L
.3381 .24405 L
.30952 .24405 L
.30952 .24303 L
s
.039 .916 .04 r
.02381 .125 m
.30952 .125 L
s
0 0 0 r
2 Mabswid
.30952 .125 Mdot
.039 .916 .04 r
.5 Mabswid
.30952 .125 m
.38143 .125 L
s
0 0 0 r
2 Mabswid
.38143 .125 Mdot
.039 .916 .04 r
.5 Mabswid
.38143 .125 m
.97619 .00603 L
s
0 0 0 r
2 Mabswid
.97619 .00603 Mdot
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{295.812, 73.8125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 294.812}, {72.8125, 0}} -> {-3.1427, -13.1251, \
0.360519, 0.360519}},
  CellTags->"WedgePrism"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{1180, 1038},
WindowMargins->{{83, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "HollowCornerCube"->{
    Cell[1916, 61, 89, 1, 36, "Subsection",
      CellTags->"HollowCornerCube"],
    Cell[2030, 66, 66, 1, 27, "Input",
      CellTags->"HollowCornerCube"],
    Cell[2099, 69, 836, 12, 232, "Print",
      CellTags->"HollowCornerCube"],
    Cell[2972, 86, 196, 5, 57, "Input",
      CellTags->"HollowCornerCube"],
    Cell[3171, 93, 13038, 286, 174, 2002, 144, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"HollowCornerCube"],
    Cell[16246, 384, 159, 4, 57, "Input",
      CellTags->"HollowCornerCube"],
    Cell[16408, 390, 33120, 969, 182, 9098, 666, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"HollowCornerCube"],
    Cell[49565, 1364, 96, 1, 27, "Input",
      CellTags->"HollowCornerCube"],
    Cell[49664, 1367, 44042, 2222, 178, 27003, 2006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"HollowCornerCube"],
    Cell[93743, 3594, 177, 5, 57, "Input",
      CellTags->"HollowCornerCube"],
    Cell[93923, 3601, 23443, 394, 204, 1706, 120, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"HollowCornerCube"],
    Cell[117403, 4000, 203, 7, 87, "Input",
      CellTags->"HollowCornerCube"],
    Cell[117609, 4009, 11735, 911, 198, 11496, 904, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"HollowCornerCube"],
    Cell[129381, 4925, 227, 7, 87, "Input",
      CellTags->"HollowCornerCube"],
    Cell[129611, 4934, 39029, 1341, 193, 13331, 1018, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"HollowCornerCube"]},
  "SolidCornerCube"->{
    Cell[168689, 6281, 95, 1, 36, "Subsection",
      CellTags->"SolidCornerCube"],
    Cell[168809, 6286, 64, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[168876, 6289, 1374, 19, 382, "Print",
      CellTags->"SolidCornerCube"],
    Cell[170287, 6313, 126, 4, 42, "Input",
      CellTags->"SolidCornerCube"],
    Cell[170416, 6319, 34017, 2196, 165, 33777, 2189, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[204470, 8520, 61, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[204534, 8523, 70327, 6169, 188, 70068, 6162, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[274864, 14694, 128, 3, 22, "Print",
      CellTags->"SolidCornerCube"],
    Cell[274995, 14699, 97, 2, 26, "Output",
      CellTags->"SolidCornerCube"],
    Cell[275129, 14706, 131, 4, 42, "Input",
      CellTags->"SolidCornerCube"],
    Cell[275263, 14712, 34562, 2252, 141, 34323, 2245, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[309862, 16969, 95, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[309960, 16972, 35098, 2255, 142, 34765, 2245, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[345095, 19232, 77, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[345175, 19235, 69339, 6169, 157, 69091, 6162, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[414551, 25409, 144, 4, 42, "Input",
      CellTags->"SolidCornerCube"],
    Cell[414698, 25415, 40508, 2712, 169, 40268, 2705, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[455243, 28132, 123, 4, 42, "Input",
      CellTags->"SolidCornerCube"],
    Cell[455369, 28138, 2040, 154, 137, 1793, 147, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[457446, 28297, 206, 7, 87, "Input",
      CellTags->"SolidCornerCube"],
    Cell[457655, 28306, 23952, 1718, 179, 23713, 1711, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[481644, 30029, 214, 7, 87, "Input",
      CellTags->"SolidCornerCube"],
    Cell[481861, 30038, 39413, 2587, 188, 39176, 2580, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[521311, 32630, 82, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[521396, 32633, 39317, 2587, 173, 39062, 2580, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[560750, 35225, 62, 1, 27, "Input",
      CellTags->"SolidCornerCube"],
    Cell[560815, 35228, 73420, 6536, 160, 73166, 6529, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"],
    Cell[634272, 41769, 214, 7, 87, "Input",
      CellTags->"SolidCornerCube"],
    Cell[634489, 41778, 8155, 601, 171, 7916, 594, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"SolidCornerCube"]},
  "AnamorphicPrisms"->{
    Cell[642693, 42385, 168, 4, 36, "Subsection",
      CellTags->"AnamorphicPrisms"],
    Cell[642886, 42393, 66, 1, 27, "Input",
      CellTags->"AnamorphicPrisms"],
    Cell[642955, 42396, 1237, 17, 337, "Print",
      CellTags->"AnamorphicPrisms"],
    Cell[644229, 42418, 140, 4, 42, "Input",
      CellTags->"AnamorphicPrisms"],
    Cell[644372, 42424, 14371, 1029, 163, 14131, 1022, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"AnamorphicPrisms"],
    Cell[658746, 43455, 947, 24, 52, "Print",
      CellTags->"AnamorphicPrisms"],
    Cell[659696, 43481, 98, 2, 26, "Output",
      CellTags->"AnamorphicPrisms"],
    Cell[659831, 43488, 63, 1, 27, "Input",
      CellTags->"AnamorphicPrisms"],
    Cell[659897, 43491, 19505, 1394, 179, 19258, 1387, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"AnamorphicPrisms"],
    Cell[679439, 44890, 229, 7, 102, "Input",
      CellTags->"AnamorphicPrisms"],
    Cell[679671, 44899, 13513, 1012, 145, 13259, 1005, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"AnamorphicPrisms"],
    Cell[693187, 45913, 1799, 41, 67, "Print",
      CellTags->"AnamorphicPrisms"],
    Cell[694989, 45956, 98, 2, 26, "Output",
      CellTags->"AnamorphicPrisms"],
    Cell[695102, 45961, 123, 4, 42, "Input",
      CellTags->"AnamorphicPrisms"]},
  "DirectVisionPrism"->{
    Cell[695262, 45970, 100, 1, 36, "Subsection",
      CellTags->"DirectVisionPrism"],
    Cell[695387, 45975, 68, 1, 39, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[695458, 45978, 685, 10, 243, "Print",
      CellTags->"DirectVisionPrism"],
    Cell[696180, 45993, 74, 1, 39, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[696257, 45996, 116, 3, 39, "Output",
      CellTags->"DirectVisionPrism"],
    Cell[696410, 46004, 140, 3, 55, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[696553, 46009, 7179, 179, 74, 1459, 103, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"DirectVisionPrism"],
    Cell[703769, 46193, 64, 1, 39, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[703836, 46196, 13461, 267, 127, 1463, 114, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"DirectVisionPrism"],
    Cell[717334, 46468, 245, 4, 103, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[717582, 46474, 12031, 341, 103, 3073, 225, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"DirectVisionPrism"],
    Cell[729616, 46817, 978, 24, 83, "Print",
      CellTags->"DirectVisionPrism"],
    Cell[730597, 46843, 99, 2, 39, "Output",
      CellTags->"DirectVisionPrism"],
    Cell[730733, 46850, 83, 1, 39, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[730819, 46853, 300, 5, 103, "Output",
      CellTags->"DirectVisionPrism"],
    Cell[731156, 46863, 284, 5, 119, "Input",
      CellTags->"DirectVisionPrism"],
    Cell[731443, 46870, 14486, 371, 110, 3067, 225, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"DirectVisionPrism"],
    Cell[745932, 47243, 1055, 26, 99, "Print",
      CellTags->"DirectVisionPrism"],
    Cell[746990, 47271, 99, 2, 39, "Output",
      CellTags->"DirectVisionPrism"]},
  "DovePrism"->{
    Cell[747138, 47279, 78, 1, 36, "Subsection",
      CellTags->"DovePrism"],
    Cell[747241, 47284, 52, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[747296, 47287, 781, 11, 217, "Print",
      CellTags->"DovePrism"],
    Cell[748114, 47303, 60, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[748177, 47306, 324, 5, 97, "Print",
      CellTags->"DovePrism"],
    Cell[748538, 47316, 58, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[748599, 47319, 100, 3, 26, "Output",
      CellTags->"DovePrism"],
    Cell[748736, 47327, 71, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[748810, 47330, 1273, 82, 131, 1027, 75, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"DovePrism"],
    Cell[750120, 47417, 73, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[750196, 47420, 125, 3, 26, "Output",
      CellTags->"DovePrism"],
    Cell[750358, 47428, 86, 1, 27, "Input",
      CellTags->"DovePrism"],
    Cell[750447, 47431, 1381, 85, 137, 1143, 78, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"DovePrism"],
    Cell[751865, 47521, 146, 7, 87, "Input",
      CellTags->"DovePrism"],
    Cell[752014, 47530, 4669, 364, 184, 4387, 356, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"DovePrism"]},
  "FresnelRhomb"->{
    Cell[756732, 47900, 85, 1, 36, "Subsection",
      CellTags->"FresnelRhomb"],
    Cell[756842, 47905, 58, 1, 27, "Input",
      CellTags->"FresnelRhomb"],
    Cell[756903, 47908, 1266, 18, 382, "Print",
      CellTags->"FresnelRhomb"],
    Cell[758206, 47931, 77, 1, 27, "Input",
      CellTags->"FresnelRhomb"],
    Cell[758286, 47934, 163, 4, 26, "Output",
      CellTags->"FresnelRhomb"],
    Cell[758486, 47943, 146, 3, 43, "Input",
      CellTags->"FresnelRhomb"],
    Cell[758635, 47948, 1614, 106, 120, 1362, 99, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"FresnelRhomb"],
    Cell[760252, 48056, 244, 5, 52, "Print",
      CellTags->"FresnelRhomb"],
    Cell[760499, 48063, 94, 2, 26, "Output",
      CellTags->"FresnelRhomb"],
    Cell[760630, 48070, 79, 2, 27, "Input",
      CellTags->"FresnelRhomb"],
    Cell[760712, 48074, 1544, 106, 125, 1296, 99, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"FresnelRhomb"],
    Cell[762293, 48185, 209, 7, 87, "Input",
      CellTags->"FresnelRhomb"],
    Cell[762505, 48194, 2862, 200, 198, 2610, 193, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"FresnelRhomb"],
    Cell[765404, 48399, 193, 7, 87, "Input",
      CellTags->"FresnelRhomb"],
    Cell[765600, 48408, 2284, 157, 204, 2032, 150, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"FresnelRhomb"]},
  "PechanPrism"->{
    Cell[767933, 48571, 88, 1, 36, "Subsection",
      CellTags->"PechanPrism"],
    Cell[768046, 48576, 56, 1, 27, "Input",
      CellTags->"PechanPrism"],
    Cell[768105, 48579, 885, 12, 247, "Print",
      CellTags->"PechanPrism"],
    Cell[769027, 48596, 67, 1, 27, "Input",
      CellTags->"PechanPrism"],
    Cell[769097, 48599, 100, 3, 26, "Output",
      CellTags->"PechanPrism"],
    Cell[769234, 48607, 90, 1, 27, "Input",
      CellTags->"PechanPrism"],
    Cell[769327, 48610, 2191, 142, 138, 1939, 135, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[771555, 48757, 58, 1, 27, "Input",
      CellTags->"PechanPrism"],
    Cell[771616, 48760, 2260, 154, 126, 2000, 147, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[773913, 48919, 183, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[774099, 48928, 8992, 704, 151, 8741, 697, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[783128, 49637, 174, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[783305, 49646, 9067, 704, 152, 8815, 697, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[792409, 50355, 202, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[792614, 50364, 8997, 704, 188, 8753, 697, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[801648, 51073, 199, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[801850, 51082, 9035, 704, 169, 8793, 697, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[810922, 51791, 177, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[811102, 51800, 8074, 632, 192, 7822, 625, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"],
    Cell[819213, 52437, 195, 7, 87, "Input",
      CellTags->"PechanPrism"],
    Cell[819411, 52446, 8058, 632, 199, 7822, 625, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PechanPrism"]},
  "PellinBrocaPrism"->{
    Cell[827518, 53084, 127, 4, 36, "Subsection",
      CellTags->"PellinBrocaPrism"],
    Cell[827670, 53092, 66, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[827739, 53095, 1396, 19, 397, "Print",
      CellTags->"PellinBrocaPrism"],
    Cell[829172, 53119, 127, 4, 42, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[829302, 53125, 1360, 82, 137, 1111, 75, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[830665, 53209, 694, 18, 37, "Print",
      CellTags->"PellinBrocaPrism"],
    Cell[831362, 53229, 98, 2, 26, "Output",
      CellTags->"PellinBrocaPrism"],
    Cell[831497, 53236, 63, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[831563, 53239, 1277, 82, 131, 1022, 75, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[832877, 53326, 243, 8, 132, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[833123, 53336, 2650, 180, 203, 2398, 173, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[835810, 53521, 161, 4, 59, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[835974, 53527, 86, 2, 26, "Output",
      CellTags->"PellinBrocaPrism"],
    Cell[836097, 53534, 68, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[836168, 53537, 108, 2, 26, "Output",
      CellTags->"PellinBrocaPrism"],
    Cell[836313, 53544, 238, 8, 132, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[836554, 53554, 1773, 113, 210, 1525, 106, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[838342, 53670, 96, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[838463, 53675, 248, 9, 147, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[838714, 53686, 6609, 443, 135, 6362, 436, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[845338, 54132, 96, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[845437, 54135, 96, 1, 27, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[845558, 54140, 237, 11, 147, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[845820, 54155, 6519, 421, 119, 6197, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[852342, 54578, 6527, 421, 119, 6212, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[858872, 55001, 6491, 421, 119, 6177, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[865366, 55424, 6457, 421, 119, 6142, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[871826, 55847, 6523, 421, 119, 6208, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[878352, 56270, 6506, 421, 119, 6185, 412, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[884861, 56693, 6618, 443, 119, 6362, 436, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[891528, 57142, 435, 11, 207, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[891966, 57155, 15495, 1141, 209, 15250, 1134, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[907498, 58301, 390, 9, 160, "Input",
      CellTags->"PellinBrocaPrism"],
    Cell[907891, 58312, 9553, 647, 387, 9305, 640, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PellinBrocaPrism"],
    Cell[917459, 58962, 1003, 14, 239, "Text",
      CellTags->"PellinBrocaPrism"]},
  "PentaPrism"->{
    Cell[918499, 58981, 99, 1, 36, "Subsection",
      CellTags->"PentaPrism"],
    Cell[918623, 58986, 54, 1, 27, "Input",
      CellTags->"PentaPrism"],
    Cell[918680, 58989, 537, 8, 172, "Print",
      CellTags->"PentaPrism"],
    Cell[919254, 59002, 91, 1, 27, "Input",
      CellTags->"PentaPrism"],
    Cell[919348, 59005, 1732, 114, 156, 1481, 107, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PentaPrism"],
    Cell[921117, 59124, 57, 1, 27, "Input",
      CellTags->"PentaPrism"],
    Cell[921177, 59127, 1594, 97, 177, 1341, 90, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PentaPrism"],
    Cell[922808, 59229, 159, 7, 87, "Input",
      CellTags->"PentaPrism"],
    Cell[922970, 59238, 3200, 228, 217, 2949, 221, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PentaPrism"],
    Cell[926207, 59471, 191, 7, 87, "Input",
      CellTags->"PentaPrism"],
    Cell[926401, 59480, 5033, 385, 172, 4783, 378, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PentaPrism"]},
  "PorroPrism"->{
    Cell[931483, 59871, 94, 1, 36, "Subsection",
      CellTags->"PorroPrism"],
    Cell[931602, 59876, 54, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[931659, 59879, 543, 8, 157, "Print",
      CellTags->"PorroPrism"],
    Cell[932239, 59892, 62, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[932304, 59895, 1601, 26, 311, "Output",
      CellTags->"PorroPrism"],
    Cell[933942, 59926, 61, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[934006, 59929, 102, 3, 26, "Output",
      CellTags->"PorroPrism"],
    Cell[934145, 59937, 74, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[934222, 59940, 6581, 556, 165, 6321, 549, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[940840, 60501, 75, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[940918, 60504, 5980, 374, 145, 5737, 367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[946935, 60883, 77, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[947015, 60886, 5852, 374, 78, 5611, 367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[952904, 61265, 76, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[952983, 61268, 5863, 374, 103, 5622, 367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[958883, 61647, 89, 1, 27, "Input",
      CellTags->"PorroPrism"],
    Cell[958975, 61650, 17403, 1471, 155, 17143, 1464, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[976415, 63126, 115, 4, 42, "Input",
      CellTags->"PorroPrism"],
    Cell[976533, 63132, 19593, 1544, 143, 19333, 1537, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"],
    Cell[996163, 64681, 182, 7, 102, "Input",
      CellTags->"PorroPrism"],
    Cell[996348, 64690, 9497, 656, 232, 9246, 649, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PorroPrism"]},
  "Prism"->{
    Cell[1005894, 65352, 87, 1, 36, "Subsection",
      CellTags->"Prism"],
    Cell[1006006, 65357, 44, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1006053, 65360, 918, 13, 277, "Print",
      CellTags->"Prism"],
    Cell[1007008, 65378, 52, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1007063, 65381, 1596, 26, 311, "Output",
      CellTags->"Prism"],
    Cell[1008696, 65412, 43, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1008742, 65415, 161, 3, 37, "Print",
      CellTags->"Prism"],
    Cell[1008940, 65423, 91, 1, 42, "Input",
      CellTags->"Prism"],
    Cell[1009034, 65426, 1221, 74, 113, 975, 67, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1010258, 65502, 150, 4, 22, "Print",
      CellTags->"Prism"],
    Cell[1010411, 65508, 75, 2, 26, "Output",
      CellTags->"Prism"],
    Cell[1010523, 65515, 52, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1010578, 65518, 1169, 73, 193, 917, 66, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1011784, 65596, 92, 1, 42, "Input",
      CellTags->"Prism"],
    Cell[1011879, 65599, 1217, 74, 113, 975, 67, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1013133, 65678, 52, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1013188, 65681, 1184, 73, 193, 930, 66, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1014409, 65759, 93, 1, 42, "Input",
      CellTags->"Prism"],
    Cell[1014505, 65762, 1240, 74, 144, 995, 67, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1015782, 65841, 52, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1015837, 65844, 1172, 73, 161, 919, 66, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1017046, 65922, 90, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1017139, 65925, 1296, 76, 176, 1042, 69, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1018472, 66006, 90, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1018565, 66009, 1297, 76, 213, 1044, 69, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1019899, 66090, 90, 1, 27, "Input",
      CellTags->"Prism"],
    Cell[1019992, 66093, 1257, 72, 169, 1004, 65, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1021286, 66170, 205, 7, 102, "Input",
      CellTags->"Prism"],
    Cell[1021494, 66179, 4079, 300, 171, 3835, 293, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1025610, 66484, 183, 7, 117, "Input",
      CellTags->"Prism"],
    Cell[1025796, 66493, 2433, 169, 150, 2189, 162, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"],
    Cell[1028266, 66667, 211, 8, 117, "Input",
      CellTags->"Prism"],
    Cell[1028480, 66677, 3653, 269, 110, 3416, 262, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"Prism"]},
  "ReversionPrism"->{
    Cell[1032182, 66952, 92, 1, 36, "Subsection",
      CellTags->"ReversionPrism"],
    Cell[1032299, 66957, 62, 1, 27, "Input",
      CellTags->"ReversionPrism"],
    Cell[1032364, 66960, 796, 11, 232, "Print",
      CellTags->"ReversionPrism"],
    Cell[1033197, 66976, 99, 1, 27, "Input",
      CellTags->"ReversionPrism"],
    Cell[1033299, 66979, 1934, 128, 116, 1679, 121, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"ReversionPrism"],
    Cell[1035270, 67112, 61, 1, 27, "Input",
      CellTags->"ReversionPrism"],
    Cell[1035334, 67115, 1954, 135, 135, 1701, 128, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"ReversionPrism"],
    Cell[1037325, 67255, 173, 7, 102, "Input",
      CellTags->"ReversionPrism"],
    Cell[1037501, 67264, 3776, 274, 117, 3524, 267, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"ReversionPrism"]},
  "RhomboidPrism"->{
    Cell[1041326, 67544, 95, 1, 36, "Subsection",
      CellTags->"RhomboidPrism"],
    Cell[1041446, 67549, 60, 1, 27, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1041509, 67552, 874, 12, 262, "Print",
      CellTags->"RhomboidPrism"],
    Cell[1042420, 67569, 124, 3, 43, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1042547, 67574, 1367, 82, 64, 1115, 75, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RhomboidPrism"],
    Cell[1043917, 67658, 214, 6, 22, "Print",
      CellTags->"RhomboidPrism"],
    Cell[1044134, 67666, 95, 2, 26, "Output",
      CellTags->"RhomboidPrism"],
    Cell[1044266, 67673, 77, 1, 27, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1044346, 67676, 390, 10, 41, "Output",
      CellTags->"RhomboidPrism"],
    Cell[1044773, 67691, 143, 3, 43, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1044919, 67696, 1353, 82, 71, 1108, 75, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RhomboidPrism"],
    Cell[1046309, 67783, 158, 4, 59, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1046470, 67789, 83, 2, 26, "Output",
      CellTags->"RhomboidPrism"],
    Cell[1046590, 67796, 221, 4, 91, "Input",
      CellTags->"RhomboidPrism"],
    Cell[1046814, 67802, 1724, 108, 104, 1481, 101, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RhomboidPrism"],
    Cell[1048541, 67912, 913, 22, 52, "Print",
      CellTags->"RhomboidPrism"],
    Cell[1049457, 67936, 94, 2, 26, "Output",
      CellTags->"RhomboidPrism"]},
  "RoofPrism"->{
    Cell[1049600, 67944, 71, 1, 36, "Subsection",
      CellTags->"RoofPrism"],
    Cell[1049696, 67949, 52, 1, 39, "Input",
      CellTags->"RoofPrism"],
    Cell[1049751, 67952, 605, 9, 184, "Print",
      CellTags->"RoofPrism"],
    Cell[1050393, 67966, 60, 1, 39, "Input",
      CellTags->"RoofPrism"],
    Cell[1050456, 67969, 1647, 29, 338, "Output",
      CellTags->"RoofPrism"],
    Cell[1052140, 68003, 60, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1052203, 68006, 1647, 29, 326, "Output",
      CellTags->"RoofPrism"],
    Cell[1053887, 68040, 173, 7, 87, "Input",
      CellTags->"RoofPrism"],
    Cell[1054063, 68049, 38032, 830, 227, 5367, 421, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1092132, 68884, 56, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1092191, 68887, 35754, 776, 192, 4800, 389, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1127982, 69668, 82, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1128067, 69671, 14475, 293, 181, 2094, 134, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1142545, 69966, 134, 3, 22, "Print",
      CellTags->"RoofPrism"],
    Cell[1142682, 69971, 79, 2, 26, "Output",
      CellTags->"RoofPrism"],
    Cell[1142798, 69978, 173, 7, 87, "Input",
      CellTags->"RoofPrism"],
    Cell[1142974, 69987, 34217, 783, 200, 5367, 421, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1177228, 70775, 56, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1177287, 70778, 36440, 758, 207, 4450, 358, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1213764, 71541, 74, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1213841, 71544, 20939, 596, 139, 5023, 394, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1234817, 72145, 97, 1, 42, "Input",
      CellTags->"RoofPrism"],
    Cell[1234917, 72148, 11605, 216, 170, 1438, 85, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"],
    Cell[1246525, 72366, 170, 4, 37, "Print",
      CellTags->"RoofPrism"],
    Cell[1246698, 72372, 91, 2, 26, "Output",
      CellTags->"RoofPrism"],
    Cell[1246826, 72379, 75, 1, 27, "Input",
      CellTags->"RoofPrism"],
    Cell[1246904, 72382, 14750, 287, 181, 1613, 119, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"RoofPrism"]},
  "WedgePrism"->{
    Cell[1261703, 72675, 104, 1, 36, "Subsection",
      CellTags->"WedgePrism"],
    Cell[1261832, 72680, 54, 1, 27, "Input",
      CellTags->"WedgePrism"],
    Cell[1261889, 72683, 546, 8, 87, "Print",
      CellTags->"WedgePrism"],
    Cell[1262472, 72696, 63, 1, 27, "Input",
      CellTags->"WedgePrism"],
    Cell[1262538, 72699, 104, 3, 27, "Output",
      CellTags->"WedgePrism"],
    Cell[1262679, 72707, 182, 4, 27, "Input",
      CellTags->"WedgePrism"],
    Cell[1262864, 72713, 31718, 1282, 171, 14718, 1067, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"WedgePrism"],
    Cell[1294585, 73997, 1881, 40, 55, "Print",
      CellTags->"WedgePrism"],
    Cell[1296469, 74039, 91, 2, 27, "Output",
      CellTags->"WedgePrism"],
    Cell[1296597, 74046, 94, 1, 27, "Input",
      CellTags->"WedgePrism"],
    Cell[1296694, 74049, 14802, 426, 214, 4232, 290, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"WedgePrism"],
    Cell[1311533, 74480, 57, 1, 39, "Input",
      CellTags->"WedgePrism"],
    Cell[1311593, 74483, 10609, 734, 178, 10355, 727, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"],
    Cell[1322239, 75222, 99, 1, 54, "Input",
      CellTags->"WedgePrism"],
    Cell[1322341, 75225, 7911, 537, 226, 7660, 530, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"],
    Cell[1330289, 75767, 57, 1, 27, "Input",
      CellTags->"WedgePrism"],
    Cell[1330349, 75770, 10629, 736, 204, 10373, 729, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"],
    Cell[1341015, 76511, 129, 4, 54, "Input",
      CellTags->"WedgePrism"],
    Cell[1341147, 76517, 3954, 262, 170, 3707, 255, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"],
    Cell[1345138, 76784, 57, 1, 39, "Input",
      CellTags->"WedgePrism"],
    Cell[1345198, 76787, 4605, 370, 176, 4351, 363, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"],
    Cell[1349840, 77162, 157, 7, 99, "Input",
      CellTags->"WedgePrism"],
    Cell[1350000, 77171, 7665, 560, 94, 7417, 553, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"WedgePrism"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"HollowCornerCube", 1358339, 77752},
  {"SolidCornerCube", 1359915, 77790},
  {"AnamorphicPrisms", 1363319, 77873},
  {"DirectVisionPrism", 1364764, 77908},
  {"DovePrism", 1366584, 77951},
  {"FresnelRhomb", 1367977, 77988},
  {"PechanPrism", 1369502, 78027},
  {"PellinBrocaPrism", 1371811, 78086},
  {"PentaPrism", 1375876, 78185},
  {"PorroPrism", 1377063, 78216},
  {"Prism", 1379264, 78273},
  {"ReversionPrism", 1382636, 78364},
  {"RhomboidPrism", 1383640, 78389},
  {"RoofPrism", 1385268, 78430},
  {"WedgePrism", 1388014, 78501}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 115, 4, 52, "Section"],

Cell[CellGroupData[{
Cell[1916, 61, 89, 1, 36, "Subsection",
  CellTags->"HollowCornerCube"],

Cell[CellGroupData[{
Cell[2030, 66, 66, 1, 27, "Input",
  CellTags->"HollowCornerCube"],
Cell[2099, 69, 836, 12, 232, "Print",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2972, 86, 196, 5, 57, "Input",
  CellTags->"HollowCornerCube"],
Cell[3171, 93, 13038, 286, 174, 2002, 144, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16246, 384, 159, 4, 57, "Input",
  CellTags->"HollowCornerCube"],
Cell[16408, 390, 33120, 969, 182, 9098, 666, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49565, 1364, 96, 1, 27, "Input",
  CellTags->"HollowCornerCube"],
Cell[49664, 1367, 44042, 2222, 178, 27003, 2006, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93743, 3594, 177, 5, 57, "Input",
  CellTags->"HollowCornerCube"],
Cell[93923, 3601, 23443, 394, 204, 1706, 120, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117403, 4000, 203, 7, 87, "Input",
  CellTags->"HollowCornerCube"],
Cell[117609, 4009, 11735, 911, 198, 11496, 904, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"HollowCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129381, 4925, 227, 7, 87, "Input",
  CellTags->"HollowCornerCube"],
Cell[129611, 4934, 39029, 1341, 193, 13331, 1018, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"HollowCornerCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[168689, 6281, 95, 1, 36, "Subsection",
  CellTags->"SolidCornerCube"],

Cell[CellGroupData[{
Cell[168809, 6286, 64, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[168876, 6289, 1374, 19, 382, "Print",
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170287, 6313, 126, 4, 42, "Input",
  CellTags->"SolidCornerCube"],
Cell[170416, 6319, 34017, 2196, 165, 33777, 2189, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204470, 8520, 61, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[204534, 8523, 70327, 6169, 188, 70068, 6162, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"],
Cell[274864, 14694, 128, 3, 22, "Print",
  CellTags->"SolidCornerCube"],
Cell[274995, 14699, 97, 2, 26, "Output",
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[275129, 14706, 131, 4, 42, "Input",
  CellTags->"SolidCornerCube"],
Cell[275263, 14712, 34562, 2252, 141, 34323, 2245, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[309862, 16969, 95, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[309960, 16972, 35098, 2255, 142, 34765, 2245, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345095, 19232, 77, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[345175, 19235, 69339, 6169, 157, 69091, 6162, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[414551, 25409, 144, 4, 42, "Input",
  CellTags->"SolidCornerCube"],
Cell[414698, 25415, 40508, 2712, 169, 40268, 2705, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455243, 28132, 123, 4, 42, "Input",
  CellTags->"SolidCornerCube"],
Cell[455369, 28138, 2040, 154, 137, 1793, 147, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457446, 28297, 206, 7, 87, "Input",
  CellTags->"SolidCornerCube"],
Cell[457655, 28306, 23952, 1718, 179, 23713, 1711, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[481644, 30029, 214, 7, 87, "Input",
  CellTags->"SolidCornerCube"],
Cell[481861, 30038, 39413, 2587, 188, 39176, 2580, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[521311, 32630, 82, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[521396, 32633, 39317, 2587, 173, 39062, 2580, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[560750, 35225, 62, 1, 27, "Input",
  CellTags->"SolidCornerCube"],
Cell[560815, 35228, 73420, 6536, 160, 73166, 6529, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]],

Cell[CellGroupData[{
Cell[634272, 41769, 214, 7, 87, "Input",
  CellTags->"SolidCornerCube"],
Cell[634489, 41778, 8155, 601, 171, 7916, 594, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"SolidCornerCube"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[642693, 42385, 168, 4, 36, "Subsection",
  CellTags->"AnamorphicPrisms"],

Cell[CellGroupData[{
Cell[642886, 42393, 66, 1, 27, "Input",
  CellTags->"AnamorphicPrisms"],
Cell[642955, 42396, 1237, 17, 337, "Print",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{
Cell[644229, 42418, 140, 4, 42, "Input",
  CellTags->"AnamorphicPrisms"],
Cell[644372, 42424, 14371, 1029, 163, 14131, 1022, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"AnamorphicPrisms"],
Cell[658746, 43455, 947, 24, 52, "Print",
  CellTags->"AnamorphicPrisms"],
Cell[659696, 43481, 98, 2, 26, "Output",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{
Cell[659831, 43488, 63, 1, 27, "Input",
  CellTags->"AnamorphicPrisms"],
Cell[659897, 43491, 19505, 1394, 179, 19258, 1387, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"AnamorphicPrisms"]
}, Open  ]],

Cell[CellGroupData[{
Cell[679439, 44890, 229, 7, 102, "Input",
  CellTags->"AnamorphicPrisms"],
Cell[679671, 44899, 13513, 1012, 145, 13259, 1005, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"AnamorphicPrisms"],
Cell[693187, 45913, 1799, 41, 67, "Print",
  CellTags->"AnamorphicPrisms"],
Cell[694989, 45956, 98, 2, 26, "Output",
  CellTags->"AnamorphicPrisms"]
}, Open  ]],
Cell[695102, 45961, 123, 4, 42, "Input",
  CellTags->"AnamorphicPrisms"]
}, Closed]],

Cell[CellGroupData[{
Cell[695262, 45970, 100, 1, 36, "Subsection",
  CellTags->"DirectVisionPrism"],

Cell[CellGroupData[{
Cell[695387, 45975, 68, 1, 39, "Input",
  CellTags->"DirectVisionPrism"],
Cell[695458, 45978, 685, 10, 243, "Print",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[696180, 45993, 74, 1, 39, "Input",
  CellTags->"DirectVisionPrism"],
Cell[696257, 45996, 116, 3, 39, "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[696410, 46004, 140, 3, 55, "Input",
  CellTags->"DirectVisionPrism"],
Cell[696553, 46009, 7179, 179, 74, 1459, 103, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[703769, 46193, 64, 1, 39, "Input",
  CellTags->"DirectVisionPrism"],
Cell[703836, 46196, 13461, 267, 127, 1463, 114, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[717334, 46468, 245, 4, 103, "Input",
  CellTags->"DirectVisionPrism"],
Cell[717582, 46474, 12031, 341, 103, 3073, 225, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"DirectVisionPrism"],
Cell[729616, 46817, 978, 24, 83, "Print",
  CellTags->"DirectVisionPrism"],
Cell[730597, 46843, 99, 2, 39, "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[730733, 46850, 83, 1, 39, "Input",
  CellTags->"DirectVisionPrism"],
Cell[730819, 46853, 300, 5, 103, "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[731156, 46863, 284, 5, 119, "Input",
  CellTags->"DirectVisionPrism"],
Cell[731443, 46870, 14486, 371, 110, 3067, 225, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"DirectVisionPrism"],
Cell[745932, 47243, 1055, 26, 99, "Print",
  CellTags->"DirectVisionPrism"],
Cell[746990, 47271, 99, 2, 39, "Output",
  CellTags->"DirectVisionPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[747138, 47279, 78, 1, 36, "Subsection",
  CellTags->"DovePrism"],

Cell[CellGroupData[{
Cell[747241, 47284, 52, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[747296, 47287, 781, 11, 217, "Print",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748114, 47303, 60, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[748177, 47306, 324, 5, 97, "Print",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748538, 47316, 58, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[748599, 47319, 100, 3, 26, "Output",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748736, 47327, 71, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[748810, 47330, 1273, 82, 131, 1027, 75, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[750120, 47417, 73, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[750196, 47420, 125, 3, 26, "Output",
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[750358, 47428, 86, 1, 27, "Input",
  CellTags->"DovePrism"],
Cell[750447, 47431, 1381, 85, 137, 1143, 78, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"DovePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[751865, 47521, 146, 7, 87, "Input",
  CellTags->"DovePrism"],
Cell[752014, 47530, 4669, 364, 184, 4387, 356, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"DovePrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[756732, 47900, 85, 1, 36, "Subsection",
  CellTags->"FresnelRhomb"],

Cell[CellGroupData[{
Cell[756842, 47905, 58, 1, 27, "Input",
  CellTags->"FresnelRhomb"],
Cell[756903, 47908, 1266, 18, 382, "Print",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[758206, 47931, 77, 1, 27, "Input",
  CellTags->"FresnelRhomb"],
Cell[758286, 47934, 163, 4, 26, "Output",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[758486, 47943, 146, 3, 43, "Input",
  CellTags->"FresnelRhomb"],
Cell[758635, 47948, 1614, 106, 120, 1362, 99, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"FresnelRhomb"],
Cell[760252, 48056, 244, 5, 52, "Print",
  CellTags->"FresnelRhomb"],
Cell[760499, 48063, 94, 2, 26, "Output",
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[760630, 48070, 79, 2, 27, "Input",
  CellTags->"FresnelRhomb"],
Cell[760712, 48074, 1544, 106, 125, 1296, 99, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[762293, 48185, 209, 7, 87, "Input",
  CellTags->"FresnelRhomb"],
Cell[762505, 48194, 2862, 200, 198, 2610, 193, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"FresnelRhomb"]
}, Open  ]],

Cell[CellGroupData[{
Cell[765404, 48399, 193, 7, 87, "Input",
  CellTags->"FresnelRhomb"],
Cell[765600, 48408, 2284, 157, 204, 2032, 150, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"FresnelRhomb"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[767933, 48571, 88, 1, 36, "Subsection",
  CellTags->"PechanPrism"],

Cell[CellGroupData[{
Cell[768046, 48576, 56, 1, 27, "Input",
  CellTags->"PechanPrism"],
Cell[768105, 48579, 885, 12, 247, "Print",
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[769027, 48596, 67, 1, 27, "Input",
  CellTags->"PechanPrism"],
Cell[769097, 48599, 100, 3, 26, "Output",
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[769234, 48607, 90, 1, 27, "Input",
  CellTags->"PechanPrism"],
Cell[769327, 48610, 2191, 142, 138, 1939, 135, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[771555, 48757, 58, 1, 27, "Input",
  CellTags->"PechanPrism"],
Cell[771616, 48760, 2260, 154, 126, 2000, 147, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[773913, 48919, 183, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[774099, 48928, 8992, 704, 151, 8741, 697, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[783128, 49637, 174, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[783305, 49646, 9067, 704, 152, 8815, 697, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[792409, 50355, 202, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[792614, 50364, 8997, 704, 188, 8753, 697, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[801648, 51073, 199, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[801850, 51082, 9035, 704, 169, 8793, 697, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[810922, 51791, 177, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[811102, 51800, 8074, 632, 192, 7822, 625, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[819213, 52437, 195, 7, 87, "Input",
  CellTags->"PechanPrism"],
Cell[819411, 52446, 8058, 632, 199, 7822, 625, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PechanPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[827518, 53084, 127, 4, 36, "Subsection",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{
Cell[827670, 53092, 66, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[827739, 53095, 1396, 19, 397, "Print",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[829172, 53119, 127, 4, 42, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[829302, 53125, 1360, 82, 137, 1111, 75, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[830665, 53209, 694, 18, 37, "Print",
  CellTags->"PellinBrocaPrism"],
Cell[831362, 53229, 98, 2, 26, "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[831497, 53236, 63, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[831563, 53239, 1277, 82, 131, 1022, 75, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[832877, 53326, 243, 8, 132, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[833123, 53336, 2650, 180, 203, 2398, 173, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[835810, 53521, 161, 4, 59, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[835974, 53527, 86, 2, 26, "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[836097, 53534, 68, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[836168, 53537, 108, 2, 26, "Output",
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[836313, 53544, 238, 8, 132, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[836554, 53554, 1773, 113, 210, 1525, 106, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],
Cell[838342, 53670, 96, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{
Cell[838463, 53675, 248, 9, 147, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[838714, 53686, 6609, 443, 135, 6362, 436, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],
Cell[845338, 54132, 96, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[845437, 54135, 96, 1, 27, "Input",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{
Cell[845558, 54140, 237, 11, 147, "Input",
  CellTags->"PellinBrocaPrism"],

Cell[CellGroupData[{
Cell[845820, 54155, 6519, 421, 119, 6197, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[852342, 54578, 6527, 421, 119, 6212, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[858872, 55001, 6491, 421, 119, 6177, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[865366, 55424, 6457, 421, 119, 6142, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[871826, 55847, 6523, 421, 119, 6208, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[878352, 56270, 6506, 421, 119, 6185, 412, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"],
Cell[884861, 56693, 6618, 443, 119, 6362, 436, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[891528, 57142, 435, 11, 207, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[891966, 57155, 15495, 1141, 209, 15250, 1134, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[907498, 58301, 390, 9, 160, "Input",
  CellTags->"PellinBrocaPrism"],
Cell[907891, 58312, 9553, 647, 387, 9305, 640, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PellinBrocaPrism"]
}, Open  ]],
Cell[917459, 58962, 1003, 14, 239, "Text",
  CellTags->"PellinBrocaPrism"]
}, Closed]],

Cell[CellGroupData[{
Cell[918499, 58981, 99, 1, 36, "Subsection",
  CellTags->"PentaPrism"],

Cell[CellGroupData[{
Cell[918623, 58986, 54, 1, 27, "Input",
  CellTags->"PentaPrism"],
Cell[918680, 58989, 537, 8, 172, "Print",
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[919254, 59002, 91, 1, 27, "Input",
  CellTags->"PentaPrism"],
Cell[919348, 59005, 1732, 114, 156, 1481, 107, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[921117, 59124, 57, 1, 27, "Input",
  CellTags->"PentaPrism"],
Cell[921177, 59127, 1594, 97, 177, 1341, 90, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[922808, 59229, 159, 7, 87, "Input",
  CellTags->"PentaPrism"],
Cell[922970, 59238, 3200, 228, 217, 2949, 221, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PentaPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[926207, 59471, 191, 7, 87, "Input",
  CellTags->"PentaPrism"],
Cell[926401, 59480, 5033, 385, 172, 4783, 378, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PentaPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[931483, 59871, 94, 1, 36, "Subsection",
  CellTags->"PorroPrism"],

Cell[CellGroupData[{
Cell[931602, 59876, 54, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[931659, 59879, 543, 8, 157, "Print",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[932239, 59892, 62, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[932304, 59895, 1601, 26, 311, "Output",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[933942, 59926, 61, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[934006, 59929, 102, 3, 26, "Output",
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[934145, 59937, 74, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[934222, 59940, 6581, 556, 165, 6321, 549, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[940840, 60501, 75, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[940918, 60504, 5980, 374, 145, 5737, 367, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[946935, 60883, 77, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[947015, 60886, 5852, 374, 78, 5611, 367, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[952904, 61265, 76, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[952983, 61268, 5863, 374, 103, 5622, 367, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[958883, 61647, 89, 1, 27, "Input",
  CellTags->"PorroPrism"],
Cell[958975, 61650, 17403, 1471, 155, 17143, 1464, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[976415, 63126, 115, 4, 42, "Input",
  CellTags->"PorroPrism"],
Cell[976533, 63132, 19593, 1544, 143, 19333, 1537, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[996163, 64681, 182, 7, 102, "Input",
  CellTags->"PorroPrism"],
Cell[996348, 64690, 9497, 656, 232, 9246, 649, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PorroPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1005894, 65352, 87, 1, 36, "Subsection",
  CellTags->"Prism"],

Cell[CellGroupData[{
Cell[1006006, 65357, 44, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1006053, 65360, 918, 13, 277, "Print",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1007008, 65378, 52, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1007063, 65381, 1596, 26, 311, "Output",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1008696, 65412, 43, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1008742, 65415, 161, 3, 37, "Print",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1008940, 65423, 91, 1, 42, "Input",
  CellTags->"Prism"],
Cell[1009034, 65426, 1221, 74, 113, 975, 67, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"],
Cell[1010258, 65502, 150, 4, 22, "Print",
  CellTags->"Prism"],
Cell[1010411, 65508, 75, 2, 26, "Output",
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1010523, 65515, 52, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1010578, 65518, 1169, 73, 193, 917, 66, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1011784, 65596, 92, 1, 42, "Input",
  CellTags->"Prism"],
Cell[1011879, 65599, 1217, 74, 113, 975, 67, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1013133, 65678, 52, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1013188, 65681, 1184, 73, 193, 930, 66, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1014409, 65759, 93, 1, 42, "Input",
  CellTags->"Prism"],
Cell[1014505, 65762, 1240, 74, 144, 995, 67, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1015782, 65841, 52, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1015837, 65844, 1172, 73, 161, 919, 66, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1017046, 65922, 90, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1017139, 65925, 1296, 76, 176, 1042, 69, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1018472, 66006, 90, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1018565, 66009, 1297, 76, 213, 1044, 69, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1019899, 66090, 90, 1, 27, "Input",
  CellTags->"Prism"],
Cell[1019992, 66093, 1257, 72, 169, 1004, 65, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1021286, 66170, 205, 7, 102, "Input",
  CellTags->"Prism"],
Cell[1021494, 66179, 4079, 300, 171, 3835, 293, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1025610, 66484, 183, 7, 117, "Input",
  CellTags->"Prism"],
Cell[1025796, 66493, 2433, 169, 150, 2189, 162, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1028266, 66667, 211, 8, 117, "Input",
  CellTags->"Prism"],
Cell[1028480, 66677, 3653, 269, 110, 3416, 262, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"Prism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1032182, 66952, 92, 1, 36, "Subsection",
  CellTags->"ReversionPrism"],

Cell[CellGroupData[{
Cell[1032299, 66957, 62, 1, 27, "Input",
  CellTags->"ReversionPrism"],
Cell[1032364, 66960, 796, 11, 232, "Print",
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1033197, 66976, 99, 1, 27, "Input",
  CellTags->"ReversionPrism"],
Cell[1033299, 66979, 1934, 128, 116, 1679, 121, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1035270, 67112, 61, 1, 27, "Input",
  CellTags->"ReversionPrism"],
Cell[1035334, 67115, 1954, 135, 135, 1701, 128, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"ReversionPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1037325, 67255, 173, 7, 102, "Input",
  CellTags->"ReversionPrism"],
Cell[1037501, 67264, 3776, 274, 117, 3524, 267, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"ReversionPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1041326, 67544, 95, 1, 36, "Subsection",
  CellTags->"RhomboidPrism"],

Cell[CellGroupData[{
Cell[1041446, 67549, 60, 1, 27, "Input",
  CellTags->"RhomboidPrism"],
Cell[1041509, 67552, 874, 12, 262, "Print",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1042420, 67569, 124, 3, 43, "Input",
  CellTags->"RhomboidPrism"],
Cell[1042547, 67574, 1367, 82, 64, 1115, 75, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"RhomboidPrism"],
Cell[1043917, 67658, 214, 6, 22, "Print",
  CellTags->"RhomboidPrism"],
Cell[1044134, 67666, 95, 2, 26, "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1044266, 67673, 77, 1, 27, "Input",
  CellTags->"RhomboidPrism"],
Cell[1044346, 67676, 390, 10, 41, "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1044773, 67691, 143, 3, 43, "Input",
  CellTags->"RhomboidPrism"],
Cell[1044919, 67696, 1353, 82, 71, 1108, 75, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1046309, 67783, 158, 4, 59, "Input",
  CellTags->"RhomboidPrism"],
Cell[1046470, 67789, 83, 2, 26, "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1046590, 67796, 221, 4, 91, "Input",
  CellTags->"RhomboidPrism"],
Cell[1046814, 67802, 1724, 108, 104, 1481, 101, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"RhomboidPrism"],
Cell[1048541, 67912, 913, 22, 52, "Print",
  CellTags->"RhomboidPrism"],
Cell[1049457, 67936, 94, 2, 26, "Output",
  CellTags->"RhomboidPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1049600, 67944, 71, 1, 36, "Subsection",
  CellTags->"RoofPrism"],

Cell[CellGroupData[{
Cell[1049696, 67949, 52, 1, 39, "Input",
  CellTags->"RoofPrism"],
Cell[1049751, 67952, 605, 9, 184, "Print",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1050393, 67966, 60, 1, 39, "Input",
  CellTags->"RoofPrism"],
Cell[1050456, 67969, 1647, 29, 338, "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1052140, 68003, 60, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1052203, 68006, 1647, 29, 326, "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1053887, 68040, 173, 7, 87, "Input",
  CellTags->"RoofPrism"],
Cell[1054063, 68049, 38032, 830, 227, 5367, 421, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1092132, 68884, 56, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1092191, 68887, 35754, 776, 192, 4800, 389, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127982, 69668, 82, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1128067, 69671, 14475, 293, 181, 2094, 134, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"],
Cell[1142545, 69966, 134, 3, 22, "Print",
  CellTags->"RoofPrism"],
Cell[1142682, 69971, 79, 2, 26, "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1142798, 69978, 173, 7, 87, "Input",
  CellTags->"RoofPrism"],
Cell[1142974, 69987, 34217, 783, 200, 5367, 421, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1177228, 70775, 56, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1177287, 70778, 36440, 758, 207, 4450, 358, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1213764, 71541, 74, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1213841, 71544, 20939, 596, 139, 5023, 394, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1234817, 72145, 97, 1, 42, "Input",
  CellTags->"RoofPrism"],
Cell[1234917, 72148, 11605, 216, 170, 1438, 85, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"],
Cell[1246525, 72366, 170, 4, 37, "Print",
  CellTags->"RoofPrism"],
Cell[1246698, 72372, 91, 2, 26, "Output",
  CellTags->"RoofPrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1246826, 72379, 75, 1, 27, "Input",
  CellTags->"RoofPrism"],
Cell[1246904, 72382, 14750, 287, 181, 1613, 119, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"RoofPrism"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1261703, 72675, 104, 1, 36, "Subsection",
  CellTags->"WedgePrism"],

Cell[CellGroupData[{
Cell[1261832, 72680, 54, 1, 27, "Input",
  CellTags->"WedgePrism"],
Cell[1261889, 72683, 546, 8, 87, "Print",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1262472, 72696, 63, 1, 27, "Input",
  CellTags->"WedgePrism"],
Cell[1262538, 72699, 104, 3, 27, "Output",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1262679, 72707, 182, 4, 27, "Input",
  CellTags->"WedgePrism"],
Cell[1262864, 72713, 31718, 1282, 171, 14718, 1067, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"WedgePrism"],
Cell[1294585, 73997, 1881, 40, 55, "Print",
  CellTags->"WedgePrism"],
Cell[1296469, 74039, 91, 2, 27, "Output",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1296597, 74046, 94, 1, 27, "Input",
  CellTags->"WedgePrism"],
Cell[1296694, 74049, 14802, 426, 214, 4232, 290, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1311533, 74480, 57, 1, 39, "Input",
  CellTags->"WedgePrism"],
Cell[1311593, 74483, 10609, 734, 178, 10355, 727, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1322239, 75222, 99, 1, 54, "Input",
  CellTags->"WedgePrism"],
Cell[1322341, 75225, 7911, 537, 226, 7660, 530, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1330289, 75767, 57, 1, 27, "Input",
  CellTags->"WedgePrism"],
Cell[1330349, 75770, 10629, 736, 204, 10373, 729, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1341015, 76511, 129, 4, 54, "Input",
  CellTags->"WedgePrism"],
Cell[1341147, 76517, 3954, 262, 170, 3707, 255, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1345138, 76784, 57, 1, 39, "Input",
  CellTags->"WedgePrism"],
Cell[1345198, 76787, 4605, 370, 176, 4351, 363, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1349840, 77162, 157, 7, 99, "Input",
  CellTags->"WedgePrism"],
Cell[1350000, 77171, 7665, 560, 94, 7417, 553, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"WedgePrism"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

