(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    724516,      27406]*)
(*NotebookOutlinePosition[    725174,      27429]*)
(*  CellTagsIndexPosition[    725130,      27425]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
componentfunctions = 
\tSelect[ReadData[RayicaFunction, All, Union->True, \
ReportedInterval->Infinity],
\t\tNot[MemberQ[{HerzbergerFunction,IndexFunction,IndexInterpolationFunction, \

\t\t\tModelRefractiveIndex, SellmeierFunction, {}},#]]&]\
\>", "Input"],

Cell[BoxData[
    \({AnamorphicPrisms, AsphericLens, BallLens, BeamSplitter, 
      BeamSplitterCube, BiConcaveLens, BiConvexLens, CompoundLens, 
      CustomMirror, CylindricalLens, DirectVisionPrism, DovePrism, 
      FresnelRhomb, HollowCornerCube, JonesMatrixOptic, LensDoublet, 
      LensTriplet, LinearPolarizer, Mirror, ParabolicMirror, PechanPrism, 
      PentaPrism, PlanoConcaveCylindricalLens, PlanoConcaveLens, 
      PlanoConvexCylindricalLens, PlanoConvexLens, 
      PolarizingBeamSplitterCube, PorroPrism, Prism, RetardationPlate, 
      ReversionPrism, RhomboidPrism, RoofPrism, SolidCornerCube, 
      SphericalLens, SphericalMirror, WedgeBeamSplitter, WedgePrism, 
      Window}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[componentfunctions]", "Input"],

Cell[BoxData[
    \(39\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[Partition[
\tJoin[MapIndexed[(Print[First[#2],\" = \",#];
\t\tShowSystem[DataToRayica[#], PlotLabel->#, OutputType->StandardGraphics, 
\t\t\tDisplayFunction->Identity])&
\t,
\t\tcomponentfunctions
\t],{Graphics3D[{}]}],8]
], DisplayFunction->$DisplayFunction];\
\>", "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]" = \
"\[InvisibleSpace]AnamorphicPrisms\),
      SequenceForm[ 1, " = ", AnamorphicPrisms],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]" = \
"\[InvisibleSpace]AsphericLens\),
      SequenceForm[ 2, " = ", AsphericLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]" = "\[InvisibleSpace]BallLens\),
      SequenceForm[ 3, " = ", BallLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]" = \
"\[InvisibleSpace]BeamSplitter\),
      SequenceForm[ 4, " = ", BeamSplitter],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]" = \
"\[InvisibleSpace]BeamSplitterCube\),
      SequenceForm[ 5, " = ", BeamSplitterCube],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]" = "\[InvisibleSpace]BiConcaveLens\
\),
      SequenceForm[ 6, " = ", BiConcaveLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]" = \
"\[InvisibleSpace]BiConvexLens\),
      SequenceForm[ 7, " = ", BiConvexLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]" = \
"\[InvisibleSpace]CompoundLens\),
      SequenceForm[ 8, " = ", CompoundLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9\[InvisibleSpace]" = \
"\[InvisibleSpace]CustomMirror\),
      SequenceForm[ 9, " = ", CustomMirror],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(Nickel\[InvisibleSpace]" is not currently defined in \
Rayica's database at this time."\),
      SequenceForm[ 
      Nickel, " is not currently defined in Rayica's database at this time."],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Substituting a constant refractive index of 1.5 in \
place of "\[InvisibleSpace]Nickel\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Substituting a constant refractive index of 1.5 in place of ", Nickel, 
        "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(10\[InvisibleSpace]" = \
"\[InvisibleSpace]CylindricalLens\),
      SequenceForm[ 10, " = ", CylindricalLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(11\[InvisibleSpace]" = \
"\[InvisibleSpace]DirectVisionPrism\),
      SequenceForm[ 11, " = ", DirectVisionPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(12\[InvisibleSpace]" = "\[InvisibleSpace]DovePrism\),
      SequenceForm[ 12, " = ", DovePrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(13\[InvisibleSpace]" = "\[InvisibleSpace]FresnelRhomb\
\),
      SequenceForm[ 13, " = ", FresnelRhomb],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(14\[InvisibleSpace]" = \
"\[InvisibleSpace]HollowCornerCube\),
      SequenceForm[ 14, " = ", HollowCornerCube],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(15\[InvisibleSpace]" = \
"\[InvisibleSpace]JonesMatrixOptic\),
      SequenceForm[ 15, " = ", JonesMatrixOptic],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]" = \
"\[InvisibleSpace]LensDoublet\),
      SequenceForm[ 16, " = ", LensDoublet],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(17\[InvisibleSpace]" = \
"\[InvisibleSpace]LensTriplet\),
      SequenceForm[ 17, " = ", LensTriplet],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(18\[InvisibleSpace]" = \
"\[InvisibleSpace]LinearPolarizer\),
      SequenceForm[ 18, " = ", LinearPolarizer],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(19\[InvisibleSpace]" = "\[InvisibleSpace]Mirror\),
      SequenceForm[ 19, " = ", Mirror],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(20\[InvisibleSpace]" = \
"\[InvisibleSpace]ParabolicMirror\),
      SequenceForm[ 20, " = ", ParabolicMirror],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(Nickel\[InvisibleSpace]" is not currently defined in \
Rayica's database at this time."\),
      SequenceForm[ 
      Nickel, " is not currently defined in Rayica's database at this time."],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Substituting a constant refractive index of 1.5 in \
place of "\[InvisibleSpace]Nickel\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Substituting a constant refractive index of 1.5 in place of ", Nickel, 
        "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(21\[InvisibleSpace]" = \
"\[InvisibleSpace]PechanPrism\),
      SequenceForm[ 21, " = ", PechanPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(22\[InvisibleSpace]" = "\[InvisibleSpace]PentaPrism\),
      
      SequenceForm[ 22, " = ", PentaPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(23\[InvisibleSpace]" = \
"\[InvisibleSpace]PlanoConcaveCylindricalLens\),
      SequenceForm[ 23, " = ", PlanoConcaveCylindricalLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(24\[InvisibleSpace]" = \
"\[InvisibleSpace]PlanoConcaveLens\),
      SequenceForm[ 24, " = ", PlanoConcaveLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(25\[InvisibleSpace]" = \
"\[InvisibleSpace]PlanoConvexCylindricalLens\),
      SequenceForm[ 25, " = ", PlanoConvexCylindricalLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(26\[InvisibleSpace]" = \
"\[InvisibleSpace]PlanoConvexLens\),
      SequenceForm[ 26, " = ", PlanoConvexLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(27\[InvisibleSpace]" = \
"\[InvisibleSpace]PolarizingBeamSplitterCube\),
      SequenceForm[ 27, " = ", PolarizingBeamSplitterCube],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(28\[InvisibleSpace]" = "\[InvisibleSpace]PorroPrism\),
      
      SequenceForm[ 28, " = ", PorroPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(29\[InvisibleSpace]" = "\[InvisibleSpace]Prism\),
      SequenceForm[ 29, " = ", Prism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(30\[InvisibleSpace]" = \
"\[InvisibleSpace]RetardationPlate\),
      SequenceForm[ 30, " = ", RetardationPlate],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(31\[InvisibleSpace]" = \
"\[InvisibleSpace]ReversionPrism\),
      SequenceForm[ 31, " = ", ReversionPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(32\[InvisibleSpace]" = \
"\[InvisibleSpace]RhomboidPrism\),
      SequenceForm[ 32, " = ", RhomboidPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(33\[InvisibleSpace]" = "\[InvisibleSpace]RoofPrism\),
      SequenceForm[ 33, " = ", RoofPrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(34\[InvisibleSpace]" = \
"\[InvisibleSpace]SolidCornerCube\),
      SequenceForm[ 34, " = ", SolidCornerCube],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(35\[InvisibleSpace]" = \
"\[InvisibleSpace]SphericalLens\),
      SequenceForm[ 35, " = ", SphericalLens],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(36\[InvisibleSpace]" = \
"\[InvisibleSpace]SphericalMirror\),
      SequenceForm[ 36, " = ", SphericalMirror],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(LEBG\[InvisibleSpace]" is not currently defined in \
Rayica's database at this time."\),
      SequenceForm[ 
      LEBG, " is not currently defined in Rayica's database at this time."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Substituting a constant refractive index of 1.5 in \
place of "\[InvisibleSpace]LEBG\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Substituting a constant refractive index of 1.5 in place of ", LEBG, 
        "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(37\[InvisibleSpace]" = \
"\[InvisibleSpace]WedgeBeamSplitter\),
      SequenceForm[ 37, " = ", WedgeBeamSplitter],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(38\[InvisibleSpace]" = "\[InvisibleSpace]WedgePrism\),
      
      SequenceForm[ 38, " = ", WedgePrism],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(39\[InvisibleSpace]" = "\[InvisibleSpace]Window\),
      SequenceForm[ 39, " = ", Window],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .54973 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0130888 0.119048 [
[ 0 0 0 0 ]
[ 1 .54973 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .54973 L
0 .54973 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0130888 0.133279 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0608473 1.14433 0 1.14433 [
[.5 1.10561 -23.5625 0 ]
[.5 1.10561 23.5625 12 ]
[ 0 0 0 0 ]
[ 1 1.09311 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.10561 -84.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RoofPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.09311 L
0 1.09311 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.24822 .21237 m
.49097 .48632 L
s
.49097 .48632 m
.75203 .39852 L
s
.49111 .48624 m
.35203 .65691 L
s
.24838 .21228 m
.49111 .48624 L
s
.35194 .65683 m
.49103 .48616 L
s
.49103 .48616 m
.7521 .39836 L
s
.35207 .65677 m
.08562 .40338 L
s
.34044 .91278 m
.35207 .65677 L
s
.35203 .65691 m
.08557 .40354 L
s
.3403 .91287 m
.35194 .65683 L
s
.75205 .39835 m
.34027 .91284 L
s
.86056 .27552 m
.75205 .39835 L
s
.75203 .39852 m
.86054 .27569 L
s
.7521 .39836 m
.3403 .91287 L
s
.26522 1.02025 m
.34044 .91278 L
s
.34027 .91284 m
.26504 1.02031 L
s
.86044 .27571 m
.76126 .11715 L
s
.82591 .33367 m
.86044 .27571 L
s
.82604 .33346 m
.86056 .27552 L
s
.86054 .27569 m
.76137 .11713 L
s
.24842 .21234 m
.08561 .40359 L
s
.53588 .097 m
.24842 .21234 L
s
.53568 .09703 m
.24822 .21237 L
s
.08557 .40354 m
.24838 .21228 L
s
.08561 .40359 m
.04966 .67836 L
s
.08562 .40338 m
.04967 .67814 L
s
.11286 .91048 m
.2652 1.02015 L
s
.2652 1.02015 m
.35428 .9242 L
s
.11287 .91059 m
.26522 1.02025 L
s
.26504 1.02031 m
.3541 .92437 L
s
.76144 .11703 m
.82609 .33354 L
s
.53576 .09692 m
.76144 .11703 L
s
.76126 .11715 m
.82591 .33367 L
s
.76137 .11713 m
.53568 .09703 L
s
.82609 .33354 m
.35418 .92443 L
s
.3541 .92437 m
.82604 .33346 L
s
.04955 .67827 m
.53576 .09692 L
s
.04966 .67836 m
.53588 .097 L
s
.35428 .9242 m
.11286 .91048 L
s
.35418 .92443 m
.11275 .91071 L
s
.11275 .91071 m
.04955 .67827 L
s
.04967 .67814 m
.11287 .91059 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0130888 0.253695 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.133831 1.3385 0 1.3385 [
[.5 1.27808 -36.875 0 ]
[.5 1.27808 36.875 12 ]
[ 0 0 0 0 ]
[ 1 1.26558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.27808 -97.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SolidCornerCube) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.26558 L
0 1.26558 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.44965 .69852 m
.45496 .7159 L
s
.44406 .6816 m
.44965 .69852 L
s
.43822 .66509 m
.44406 .6816 L
s
.45496 .7159 m
.45999 .7338 L
s
.43927 .66798 m
.46471 .75226 L
s
.40517 .58793 m
.43927 .66798 L
s
.43212 .64898 m
.43822 .66509 L
s
.45999 .7338 m
.46471 .75226 L
s
.43142 .64721 m
.43212 .64898 L
s
.43073 .64545 m
.43142 .64721 L
s
.43003 .64369 m
.43073 .64545 L
s
.42932 .64194 m
.43003 .64369 L
s
.46471 .75226 m
.49952 .74145 L
s
.46471 .75226 m
.46897 .77074 L
s
.46471 .75226 m
.4803 .83692 L
s
.42862 .64019 m
.42932 .64194 L
s
.42791 .63844 m
.42862 .64019 L
s
.4274 .6372 m
.42791 .63844 L
s
.42689 .63595 m
.4274 .6372 L
s
.42638 .63471 m
.42689 .63595 L
s
.42586 .63347 m
.42638 .63471 L
s
.42535 .63224 m
.42586 .63347 L
s
.42483 .63101 m
.42535 .63224 L
s
.42444 .63008 m
.42483 .63101 L
s
.42406 .62916 m
.42444 .63008 L
s
.42367 .62824 m
.42406 .62916 L
s
.42327 .62732 m
.42367 .62824 L
s
.42288 .6264 m
.42327 .62732 L
s
.42249 .62548 m
.42288 .6264 L
s
.42218 .62477 m
.42249 .62548 L
s
.46897 .77074 m
.47265 .78869 L
s
.42188 .62405 m
.42218 .62477 L
s
.42157 .62334 m
.42188 .62405 L
s
.42126 .62263 m
.42157 .62334 L
s
.42095 .62192 m
.42126 .62263 L
s
.42064 .62121 m
.42095 .62192 L
s
.41815 .61556 m
.42064 .62121 L
s
.41563 .60995 m
.41815 .61556 L
s
.41307 .60438 m
.41563 .60995 L
s
.47265 .78869 m
.47581 .80616 L
s
.41047 .59886 m
.41307 .60438 L
s
.40784 .59337 m
.41047 .59886 L
s
.40517 .58793 m
.40784 .59337 L
s
.47581 .80616 m
.47846 .82319 L
s
.39271 .56393 m
.40517 .58793 L
s
.36385 .51596 m
.40517 .58793 L
s
.49952 .74145 m
.53471 .73052 L
s
.47846 .82319 m
.48065 .83983 L
s
.4803 .83692 m
.48503 .91795 L
s
.37948 .54072 m
.39271 .56393 L
s
.48065 .83983 m
.48239 .8561 L
s
.53471 .73052 m
.57029 .71947 L
s
.48239 .8561 m
.48255 .85789 L
s
.48255 .85789 m
.48271 .85967 L
s
.48271 .85967 m
.48287 .86145 L
s
.48287 .86145 m
.48302 .86323 L
s
.48302 .86323 m
.48316 .865 L
s
.3654 .51829 m
.37948 .54072 L
s
.48316 .865 m
.4833 .86676 L
s
.4833 .86676 m
.4834 .86802 L
s
.4834 .86802 m
.48349 .86928 L
s
.47633 .57823 m
.47255 .57587 L
s
.4801 .58059 m
.47633 .57823 L
s
.47255 .57587 m
.46877 .57354 L
s
.46644 .57223 m
.48879 .58596 L
s
.44434 .55807 m
.46644 .57223 L
s
.48349 .86928 m
.48358 .87053 L
s
.48386 .58298 m
.4801 .58059 L
s
.46877 .57354 m
.46497 .57121 L
s
.48785 .5853 m
.48386 .58298 L
s
.46497 .57121 m
.46116 .56891 L
s
.46116 .56891 m
.45758 .56653 L
s
.49183 .58763 m
.48785 .5853 L
s
.48879 .58596 m
.51143 .59931 L
s
.45758 .56653 m
.45399 .56418 L
s
.4958 .58998 m
.49183 .58763 L
s
.48358 .87053 m
.48367 .87179 L
s
.45399 .56418 m
.45039 .56183 L
s
.49977 .59235 m
.4958 .58998 L
s
.45039 .56183 m
.44678 .5595 L
s
.50372 .59473 m
.49977 .59235 L
s
.48367 .87179 m
.48375 .87304 L
s
.44678 .5595 m
.44316 .55719 L
s
.50767 .59713 m
.50372 .59473 L
s
.4225 .54338 m
.44434 .55807 L
s
.44316 .55719 m
.43953 .55489 L
s
.51185 .59946 m
.50767 .59713 L
s
.48375 .87304 m
.48384 .87428 L
s
.43953 .55489 m
.43612 .55252 L
s
.51143 .59931 m
.53436 .61233 L
s
.51603 .60181 m
.51185 .59946 L
s
.43612 .55252 m
.4327 .55017 L
s
.48384 .87428 m
.4839 .87522 L
s
.52019 .60418 m
.51603 .60181 L
s
.4839 .87522 m
.48396 .87615 L
s
.4327 .55017 m
.42927 .54783 L
s
.52435 .60656 m
.52019 .60418 L
s
.48396 .87615 m
.48401 .87709 L
s
.42927 .54783 m
.42583 .5455 L
s
.52851 .60896 m
.52435 .60656 L
s
.48401 .87709 m
.48407 .87802 L
s
.42583 .5455 m
.42238 .54319 L
s
.53265 .61138 m
.52851 .60896 L
s
.48407 .87802 m
.48412 .87895 L
s
.4009 .52806 m
.4225 .54338 L
s
.42238 .54319 m
.41891 .5409 L
s
.48412 .87895 m
.48417 .87988 L
s
.53705 .61374 m
.53265 .61138 L
s
.53436 .61233 m
.5576 .62508 L
s
.48417 .87988 m
.48421 .8806 L
s
.41891 .5409 m
.41568 .53853 L
s
.48421 .8806 m
.48425 .88132 L
s
.54143 .61611 m
.53705 .61374 L
s
.48425 .88132 m
.48429 .88204 L
s
.41568 .53853 m
.41243 .53617 L
s
.48429 .88204 m
.48433 .88276 L
s
.60627 .70829 m
.57029 .71947 L
s
.54581 .6185 m
.54143 .61611 L
s
.48433 .88276 m
.48437 .88348 L
s
.41243 .53617 m
.40917 .53384 L
s
.48437 .88348 m
.4844 .8842 L
s
.55018 .62091 m
.54581 .6185 L
s
.4844 .8842 m
.48465 .88993 L
s
.40917 .53384 m
.4059 .53151 L
s
.55455 .62333 m
.55018 .62091 L
s
.4059 .53151 m
.40261 .5292 L
s
.55891 .62578 m
.55455 .62333 L
s
.40261 .5292 m
.39931 .5269 L
s
.5576 .62508 m
.58119 .63757 L
s
.56353 .62816 m
.55891 .62578 L
s
.37954 .51195 m
.4009 .52806 L
s
.39931 .5269 m
.39625 .52453 L
s
.48465 .88993 m
.48484 .89562 L
s
.56814 .63056 m
.56353 .62816 L
s
.35039 .49664 m
.3654 .51829 L
s
.39625 .52453 m
.39317 .52217 L
s
.57275 .63298 m
.56814 .63056 L
s
.31705 .45593 m
.36385 .51596 L
s
.39317 .52217 m
.39008 .51983 L
s
.57735 .63541 m
.57275 .63298 L
s
.48484 .89562 m
.48498 .90126 L
s
.39008 .51983 m
.38697 .5175 L
s
.58195 .63787 m
.57735 .63541 L
s
.38697 .5175 m
.38386 .51518 L
s
.58119 .63757 m
.60514 .64985 L
s
.58654 .64035 m
.58195 .63787 L
s
.38386 .51518 m
.38072 .51288 L
s
.59142 .64276 m
.58654 .64035 L
s
.48498 .90126 m
.48505 .90687 L
s
.38072 .51288 m
.37783 .5105 L
s
.35843 .49484 m
.37954 .51195 L
s
.59628 .64519 m
.59142 .64276 L
s
.37783 .5105 m
.37493 .50813 L
s
.60115 .64765 m
.59628 .64519 L
s
.48505 .90687 m
.48507 .91243 L
s
.37493 .50813 m
.37201 .50577 L
s
.64266 .69699 m
.60627 .70829 L
s
.60601 .65012 m
.60115 .64765 L
s
.37201 .50577 m
.36907 .50343 L
s
.60514 .64985 m
.62948 .66192 L
s
.61086 .65262 m
.60601 .65012 L
s
.36907 .50343 m
.36612 .50111 L
s
.48507 .91243 m
.48503 .91796 L
s
.61571 .65514 m
.61086 .65262 L
s
.36612 .50111 m
.36316 .4988 L
s
.62087 .65759 m
.61571 .65514 L
s
.36316 .4988 m
.36045 .4964 L
s
.33433 .47583 m
.35039 .49664 L
s
.48503 .91796 m
.48413 .94233 L
s
.48503 .91795 m
.47816 .99111 L
s
.62602 .66006 m
.62087 .65759 L
s
.36045 .4964 m
.35772 .49402 L
s
.33761 .47636 m
.35843 .49484 L
s
.63117 .66255 m
.62602 .66006 L
s
.35772 .49402 m
.35498 .49165 L
s
.62948 .66192 m
.65424 .67382 L
s
.63631 .66507 m
.63117 .66255 L
s
.35498 .49165 m
.35223 .48929 L
s
.64146 .66762 m
.63631 .66507 L
s
.35223 .48929 m
.34945 .48695 L
s
.6466 .67019 m
.64146 .66762 L
s
.34945 .48695 m
.34666 .48463 L
s
.67946 .68556 m
.64266 .69699 L
s
.65208 .67268 m
.6466 .67019 L
s
.60342 .80349 m
.60636 .79899 L
s
.60073 .80788 m
.60342 .80349 L
s
.6026 .80478 m
.58808 .8279 L
s
.61739 .78146 m
.6026 .80478 L
s
.60636 .79899 m
.60928 .79447 L
s
.60928 .79447 m
.61217 .78993 L
s
.59803 .81226 m
.60073 .80788 L
s
.34666 .48463 m
.34414 .48221 L
s
.61217 .78993 m
.61505 .78536 L
s
.61505 .78536 m
.61792 .78078 L
s
.59531 .81662 m
.59803 .81226 L
s
.63246 .7579 m
.61739 .78146 L
s
.61792 .78078 m
.62076 .77617 L
s
.59256 .82097 m
.59531 .81662 L
s
.62076 .77617 m
.62387 .77146 L
s
.5898 .82529 m
.59256 .82097 L
s
.62387 .77146 m
.62696 .76672 L
s
.58702 .82959 m
.5898 .82529 L
s
.58808 .8279 m
.57382 .85082 L
s
.58448 .8338 m
.58702 .82959 L
s
.62696 .76672 m
.63003 .76196 L
s
.58192 .838 m
.58448 .8338 L
s
.63003 .76196 m
.63308 .75718 L
s
.64781 .73408 m
.63246 .7579 L
s
.57934 .84217 m
.58192 .838 L
s
.65756 .6752 m
.65208 .67268 L
s
.63308 .75718 m
.63611 .75237 L
s
.34414 .48221 m
.34161 .47981 L
s
.57674 .84633 m
.57934 .84217 L
s
.63611 .75237 m
.63912 .74753 L
s
.65424 .67382 m
.67946 .68556 L
s
.57413 .85047 m
.57674 .84633 L
s
.63912 .74753 m
.64243 .74258 L
s
.57382 .85082 m
.55982 .87359 L
s
.57149 .85459 m
.57413 .85047 L
s
.64243 .74258 m
.64571 .7376 L
s
.56909 .85863 m
.57149 .85459 L
s
.66303 .67774 m
.65756 .6752 L
s
.64571 .7376 m
.64897 .73259 L
s
.34161 .47981 m
.33906 .47742 L
s
.56667 .86265 m
.56909 .85863 L
s
.66347 .70998 m
.64781 .73408 L
s
.64897 .73259 m
.65221 .72756 L
s
.56422 .86665 m
.56667 .86265 L
s
.65221 .72756 m
.65544 .72249 L
s
.56176 .87064 m
.56422 .86665 L
s
.65544 .72249 m
.65864 .7174 L
s
.66851 .68032 m
.66303 .67774 L
s
.33906 .47742 m
.33649 .47504 L
s
.55928 .87461 m
.56176 .87064 L
s
.48413 .94233 m
.48201 .96593 L
s
.65864 .7174 m
.66216 .71217 L
s
.55982 .87359 m
.54608 .89621 L
s
.55678 .87856 m
.55928 .87461 L
s
.31716 .4559 m
.33761 .47636 L
s
.31705 .45593 m
.33433 .47583 L
s
.66216 .71217 m
.66566 .70691 L
s
.55451 .88243 m
.55678 .87856 L
s
.67946 .68556 m
.66347 .70998 L
s
.67398 .68292 m
.66851 .68032 L
s
.33649 .47504 m
.3339 .47269 L
s
.55222 .88629 m
.55451 .88243 L
s
.66566 .70691 m
.66914 .70162 L
s
.5499 .89013 m
.55222 .88629 L
s
.66914 .70162 m
.6726 .6963 L
s
.54757 .89395 m
.5499 .89013 L
s
.3339 .47269 m
.33129 .47034 L
s
.67946 .68556 m
.67398 .68292 L
s
.6726 .6963 m
.67604 .69095 L
s
.54522 .89777 m
.54757 .89395 L
s
.67604 .69095 m
.67946 .68556 L
s
.54608 .89621 m
.5326 .9187 L
s
.54285 .90156 m
.54522 .89777 L
s
.33129 .47034 m
.32899 .46789 L
s
.67946 .68556 m
.79004 .58773 L
s
.54071 .90527 m
.54285 .90156 L
s
.53854 .90897 m
.54071 .90527 L
s
.32899 .46789 m
.32666 .46546 L
s
.53635 .91266 m
.53854 .90897 L
s
.53415 .91633 m
.53635 .91266 L
s
.32666 .46546 m
.32432 .46305 L
s
.53192 .91998 m
.53415 .91633 L
s
.5326 .9187 m
.5194 .94109 L
s
.52968 .92362 m
.53192 .91998 L
s
.32432 .46305 m
.32195 .46065 L
s
.52766 .92718 m
.52968 .92362 L
s
.52562 .93073 m
.52766 .92718 L
s
.32195 .46065 m
.31957 .45826 L
s
.52356 .93426 m
.52562 .93073 L
s
.52148 .93778 m
.52356 .93426 L
s
.48201 .96593 m
.47861 .98874 L
s
.31957 .45826 m
.31716 .4559 L
s
.51937 .94128 m
.52148 .93778 L
s
.5194 .94109 m
.5065 .96339 L
s
.51725 .94478 m
.51937 .94128 L
s
.31707 .45593 m
.31705 .45593 L
s
.29934 .43808 m
.31705 .45593 L
s
.2669 .41177 m
.31705 .45593 L
s
.31709 .45592 m
.31707 .45593 L
s
.3171 .45591 m
.31709 .45592 L
s
.31712 .45591 m
.3171 .45591 L
s
.31714 .4559 m
.31712 .45591 L
s
.31716 .4559 m
.31714 .4559 L
s
.30042 .4362 m
.31716 .4559 L
s
.31716 .4559 m
.31509 .45343 L
s
.51536 .94818 m
.51725 .94478 L
s
.31509 .45343 m
.31304 .45102 L
s
.51344 .95158 m
.51536 .94818 L
s
.51151 .95496 m
.51344 .95158 L
s
.31304 .45102 m
.31099 .44865 L
s
.50955 .95833 m
.51151 .95496 L
s
.50757 .96169 m
.50955 .95833 L
s
.31099 .44865 m
.30895 .44633 L
s
.50557 .96503 m
.50757 .96169 L
s
.5065 .96339 m
.49395 .98561 L
s
.30895 .44633 m
.30692 .44406 L
s
.5038 .96828 m
.50557 .96503 L
s
.50202 .97153 m
.5038 .96828 L
s
.30692 .44406 m
.30489 .44184 L
s
.50021 .97476 m
.50202 .97153 L
s
.47861 .98874 m
.4738 1.01073 L
s
.30489 .44184 m
.3032 .43953 L
s
.49838 .97798 m
.50021 .97476 L
s
.47816 .99111 m
.45928 1.05189 L
s
.49652 .98118 m
.49838 .97798 L
s
.3032 .43953 m
.30152 .43727 L
s
.49464 .98437 m
.49652 .98118 L
s
.28206 .42305 m
.29934 .43808 L
s
.30152 .43727 m
.29985 .43506 L
s
.49301 .98747 m
.49464 .98437 L
s
.49395 .98561 m
.48182 1.00777 L
s
.28895 .41966 m
.30042 .4362 L
s
.49136 .99056 m
.49301 .98747 L
s
.29985 .43506 m
.29818 .43288 L
s
.48968 .99364 m
.49136 .99056 L
s
.29818 .43288 m
.29653 .43075 L
s
.48798 .9967 m
.48968 .99364 L
s
.48626 .99975 m
.48798 .9967 L
s
.29653 .43075 m
.29487 .42866 L
s
.48451 1.00279 m
.48626 .99975 L
s
.29487 .42866 m
.29353 .4265 L
s
.48302 1.00573 m
.48451 1.00279 L
s
.4738 1.01073 m
.46744 1.03182 L
s
.29353 .4265 m
.2922 .42437 L
s
.48151 1.00866 m
.48302 1.00573 L
s
.48182 1.00777 m
.47022 1.02986 L
s
.47997 1.01157 m
.48151 1.00866 L
s
.2922 .42437 m
.29087 .42229 L
s
.47841 1.01447 m
.47997 1.01157 L
s
.29087 .42229 m
.28955 .42025 L
s
.26513 .41057 m
.28206 .42305 L
s
.47682 1.01735 m
.47841 1.01447 L
s
.28955 .42025 m
.28824 .41824 L
s
.28128 .40536 m
.28895 .41966 L
s
.4752 1.02022 m
.47682 1.01735 L
s
.28824 .41824 m
.28693 .41627 L
s
.47387 1.023 m
.4752 1.02022 L
s
.28693 .41627 m
.28592 .41424 L
s
.47251 1.02575 m
.47387 1.023 L
s
.47113 1.02849 m
.47251 1.02575 L
s
.28592 .41424 m
.28491 .41224 L
s
.46971 1.03122 m
.47113 1.02849 L
s
.28491 .41224 m
.28391 .41028 L
s
.47022 1.02986 m
.45939 1.05186 L
s
.46744 1.03182 m
.45928 1.05189 L
s
.46827 1.03392 m
.46971 1.03122 L
s
.28391 .41028 m
.28291 .40835 L
s
.21605 .38729 m
.2669 .41177 L
s
.4668 1.03662 m
.46827 1.03392 L
s
.28291 .40835 m
.28193 .40647 L
s
.2485 .40049 m
.26513 .41057 L
s
.46564 1.0392 m
.4668 1.03662 L
s
.28193 .40647 m
.28095 .40461 L
s
.46445 1.04177 m
.46564 1.0392 L
s
.27658 .39275 m
.28128 .40536 L
s
.28095 .40461 m
.28024 .4027 L
s
.46324 1.04432 m
.46445 1.04177 L
s
.28024 .4027 m
.27954 .40081 L
s
.46199 1.04685 m
.46324 1.04432 L
s
.46071 1.04936 m
.46199 1.04685 L
s
.27954 .40081 m
.27886 .39896 L
s
.45939 1.05186 m
.46071 1.04936 L
s
.27886 .39896 m
.27817 .39715 L
s
.45928 1.05189 m
.4593 1.05188 L
s
.45928 1.05189 m
.44959 1.06976 L
s
.45928 1.05189 m
.4285 1.09562 L
s
.4593 1.05188 m
.45932 1.05188 L
s
.45932 1.05188 m
.45934 1.05187 L
s
.45934 1.05187 m
.45935 1.05187 L
s
.45935 1.05187 m
.45937 1.05186 L
s
.45937 1.05186 m
.45939 1.05186 L
s
.45939 1.05186 m
.45128 1.07021 L
s
.45842 1.05422 m
.45939 1.05186 L
s
.27817 .39715 m
.2775 .39537 L
s
.45744 1.05653 m
.45842 1.05422 L
s
.23215 .39273 m
.2485 .40049 L
s
.2775 .39537 m
.27683 .39363 L
s
.45644 1.05879 m
.45744 1.05653 L
s
.27683 .39363 m
.27644 .39182 L
s
.27435 .38152 m
.27658 .39275 L
s
.45543 1.06099 m
.45644 1.05879 L
s
.27644 .39182 m
.27604 .39005 L
s
.4544 1.06315 m
.45543 1.06099 L
s
.27604 .39005 m
.27566 .38831 L
s
.45335 1.06526 m
.4544 1.06315 L
s
.27566 .38831 m
.27529 .3866 L
s
.45264 1.06723 m
.45335 1.06526 L
s
.27529 .3866 m
.27492 .38493 L
s
.45191 1.06916 m
.45264 1.06723 L
s
.27492 .38493 m
.27456 .38329 L
s
.44959 1.06976 m
.43888 1.08464 L
s
.45117 1.07103 m
.45191 1.06916 L
s
.21605 .38729 m
.23215 .39273 L
s
.45128 1.07021 m
.44652 1.08309 L
s
.27456 .38329 m
.27446 .38159 L
s
.45041 1.07286 m
.45117 1.07103 L
s
.27446 .38159 m
.27438 .37992 L
s
.27427 .37147 m
.27435 .38152 L
s
.44964 1.07465 m
.45041 1.07286 L
s
.27438 .37992 m
.2743 .37829 L
s
.44885 1.07639 m
.44964 1.07465 L
s
.2743 .37829 m
.27423 .37669 L
s
.44838 1.078 m
.44885 1.07639 L
s
.27423 .37669 m
.27417 .37512 L
s
.44789 1.07957 m
.44838 1.078 L
s
.27417 .37512 m
.27411 .37358 L
s
.44739 1.08109 m
.44789 1.07957 L
s
.2125 .38639 m
.21605 .38729 L
s
.16766 .38586 m
.21605 .38729 L
s
.27411 .37358 m
.27432 .37199 L
s
.44687 1.08257 m
.44739 1.08109 L
s
.43888 1.08464 m
.42722 1.09678 L
s
.44634 1.08401 m
.44687 1.08257 L
s
.27432 .37199 m
.27454 .37042 L
s
.44652 1.08309 m
.44419 1.09202 L
s
.27612 .36244 m
.27427 .37147 L
s
.20897 .38562 m
.2125 .38639 L
s
.4458 1.08541 m
.44634 1.08401 L
s
.27454 .37042 m
.27477 .36889 L
s
.20545 .38496 m
.20897 .38562 L
s
.44555 1.08668 m
.4458 1.08541 L
s
.27477 .36889 m
.27501 .36739 L
s
.44529 1.08791 m
.44555 1.08668 L
s
.27501 .36739 m
.27526 .36593 L
s
.20194 .38442 m
.20545 .38496 L
s
.44501 1.0891 m
.44529 1.08791 L
s
.27526 .36593 m
.27551 .36449 L
s
.19845 .38399 m
.20194 .38442 L
s
.44473 1.09025 m
.44501 1.0891 L
s
.27551 .36449 m
.27603 .363 L
s
.4285 1.09562 m
.3867 1.11781 L
s
.44443 1.09136 m
.44473 1.09025 L
s
.42722 1.09678 m
.41463 1.10632 L
s
.19497 .38369 m
.19845 .38399 L
s
.27603 .363 m
.27656 .36154 L
s
.27974 .35433 m
.27612 .36244 L
s
.44412 1.09243 m
.44443 1.09136 L
s
.44419 1.09202 m
.44379 1.09786 L
s
.27656 .36154 m
.27711 .36011 L
s
.44408 1.09338 m
.44412 1.09243 L
s
.19453 .38367 m
.19497 .38369 L
s
.1941 .38364 m
.19453 .38367 L
s
.19366 .38361 m
.1941 .38364 L
s
.19323 .38359 m
.19366 .38361 L
s
.27711 .36011 m
.27766 .35872 L
s
.1928 .38357 m
.19323 .38359 L
s
.19236 .38355 m
.1928 .38357 L
s
.44404 1.09429 m
.44408 1.09338 L
s
.1918 .38353 m
.19236 .38355 L
s
.19125 .38351 m
.1918 .38353 L
s
.19069 .38349 m
.19125 .38351 L
s
.27766 .35872 m
.27822 .35736 L
s
.19014 .38348 m
.19069 .38349 L
s
.44399 1.09516 m
.44404 1.09429 L
s
.18958 .38347 m
.19014 .38348 L
s
.18903 .38347 m
.18958 .38347 L
s
.18829 .38346 m
.18903 .38347 L
s
.18755 .38347 m
.18829 .38346 L
s
.27822 .35736 m
.2788 .35603 L
s
.44392 1.09598 m
.44399 1.09516 L
s
.18681 .38348 m
.18755 .38347 L
s
.18607 .38349 m
.18681 .38348 L
s
.18533 .38351 m
.18607 .38349 L
s
.2788 .35603 m
.27964 .35464 L
s
.44384 1.09677 m
.44392 1.09598 L
s
.18459 .38354 m
.18533 .38351 L
s
.18356 .38359 m
.18459 .38354 L
s
.18253 .38364 m
.18356 .38359 L
s
.44376 1.09752 m
.44384 1.09677 L
s
.41463 1.10632 m
.40112 1.11333 L
s
.27964 .35464 m
.2805 .35329 L
s
.28503 .34707 m
.27974 .35433 L
s
.18151 .38371 m
.18253 .38364 L
s
.18048 .3838 m
.18151 .38371 L
s
.44394 1.09816 m
.44376 1.09752 L
s
.2805 .35329 m
.28137 .35197 L
s
.17945 .38389 m
.18048 .3838 L
s
.44379 1.09786 m
.44501 1.1011 L
s
.17843 .384 m
.17945 .38389 L
s
.44411 1.09875 m
.44394 1.09816 L
s
.16927 .38549 m
.17843 .384 L
s
.28137 .35197 m
.28225 .35068 L
s
.44427 1.09931 m
.44411 1.09875 L
s
.28225 .35068 m
.28314 .34943 L
s
.44443 1.09982 m
.44427 1.09931 L
s
.28314 .34943 m
.28405 .34821 L
s
.44457 1.10029 m
.44443 1.09982 L
s
.28405 .34821 m
.28523 .34693 L
s
.4447 1.10073 m
.44457 1.10029 L
s
.16022 .38801 m
.16927 .38549 L
s
.29192 .34061 m
.28503 .34707 L
s
.40112 1.11333 m
.3867 1.11781 L
s
.28523 .34693 m
.28643 .34568 L
s
.12541 .4099 m
.16766 .38586 L
s
.4451 1.10105 m
.4447 1.10073 L
s
.28643 .34568 m
.28764 .34447 L
s
.44549 1.10133 m
.4451 1.10105 L
s
.44501 1.1011 m
.44765 1.10208 L
s
.28764 .34447 m
.28887 .3433 L
s
.44587 1.10157 m
.44549 1.10133 L
s
.44624 1.10177 m
.44587 1.10157 L
s
.28887 .3433 m
.29011 .34216 L
s
.15129 .39162 m
.16022 .38801 L
s
.4466 1.10193 m
.44624 1.10177 L
s
.29011 .34216 m
.29136 .34106 L
s
.44695 1.10205 m
.4466 1.10193 L
s
.29136 .34106 m
.29291 .33989 L
s
.30036 .33491 m
.29192 .34061 L
s
.44757 1.10206 m
.44695 1.10205 L
s
.3867 1.11781 m
.38337 1.11845 L
s
.3867 1.11781 m
.33583 1.11466 L
s
.29291 .33989 m
.29447 .33876 L
s
.44818 1.10202 m
.44757 1.10206 L
s
.1425 .3964 m
.15129 .39162 L
s
.44765 1.10208 m
.45157 1.10104 L
s
.38337 1.11845 m
.38 1.11897 L
s
.29447 .33876 m
.29605 .33767 L
s
.44878 1.10195 m
.44818 1.10202 L
s
.29605 .33767 m
.29764 .33661 L
s
.38 1.11897 m
.37658 1.11936 L
s
.44937 1.10183 m
.44878 1.10195 L
s
.29764 .33661 m
.29925 .33559 L
s
.44995 1.10167 m
.44937 1.10183 L
s
.37658 1.11936 m
.37311 1.11962 L
s
.29925 .33559 m
.30088 .33462 L
s
.45053 1.10147 m
.44995 1.10167 L
s
.13387 .40245 m
.1425 .3964 L
s
.37311 1.11962 m
.36959 1.11975 L
s
.31033 .32996 m
.30036 .33491 L
s
.45137 1.10115 m
.45053 1.10147 L
s
.30088 .33462 m
.30282 .33357 L
s
.36959 1.11975 m
.36602 1.11974 L
s
.4522 1.10079 m
.45137 1.10115 L
s
.30282 .33357 m
.30477 .33256 L
s
.45157 1.10104 m
.45667 1.09814 L
s
.45302 1.10039 m
.4522 1.10079 L
s
.36602 1.11974 m
.36558 1.11973 L
s
.30477 .33256 m
.30674 .33159 L
s
.36558 1.11973 m
.36513 1.11972 L
s
.36513 1.11972 m
.36468 1.1197 L
s
.36468 1.1197 m
.36422 1.11969 L
s
.36422 1.11969 m
.36377 1.11967 L
s
.45384 1.09995 m
.45302 1.10039 L
s
.36377 1.11967 m
.36332 1.11965 L
s
.12541 .4099 m
.13387 .40245 L
s
.36332 1.11965 m
.36274 1.11962 L
s
.36274 1.11962 m
.36215 1.11958 L
s
.30674 .33159 m
.30874 .33067 L
s
.36215 1.11958 m
.36157 1.11954 L
s
.36157 1.11954 m
.36098 1.1195 L
s
.45465 1.09946 m
.45384 1.09995 L
s
.36098 1.1195 m
.36039 1.11946 L
s
.36039 1.11946 m
.3598 1.11941 L
s
.3598 1.11941 m
.35901 1.11934 L
s
.30874 .33067 m
.31075 .32978 L
s
.35901 1.11934 m
.35822 1.11927 L
s
.45546 1.09893 m
.45465 1.09946 L
s
.35822 1.11927 m
.35743 1.11918 L
s
.35743 1.11918 m
.35664 1.11909 L
s
.35664 1.11909 m
.35584 1.119 L
s
.3218 .32573 m
.31033 .32996 L
s
.31075 .32978 m
.31278 .32894 L
s
.35584 1.119 m
.35504 1.1189 L
s
.45653 1.09828 m
.45546 1.09893 L
s
.35504 1.1189 m
.35392 1.11874 L
s
.35392 1.11874 m
.35279 1.11858 L
s
.31278 .32894 m
.31514 .32802 L
s
.35279 1.11858 m
.35166 1.1184 L
s
.4576 1.09759 m
.45653 1.09828 L
s
.16413 .39499 m
.12541 .4099 L
s
.11743 .4186 m
.12541 .4099 L
s
.09318 .46011 m
.12541 .4099 L
s
.45667 1.09814 m
.4629 1.09348 L
s
.35166 1.1184 m
.35052 1.11821 L
s
.35052 1.11821 m
.34938 1.118 L
s
.45866 1.09685 m
.4576 1.09759 L
s
.31514 .32802 m
.31753 .32715 L
s
.34938 1.118 m
.34824 1.11778 L
s
.34824 1.11778 m
.33772 1.11522 L
s
.45971 1.09607 m
.45866 1.09685 L
s
.31753 .32715 m
.31994 .32632 L
s
.46076 1.09524 m
.45971 1.09607 L
s
.31994 .32632 m
.32236 .32554 L
s
.20334 .37988 m
.16413 .39499 L
s
.11016 .42824 m
.11743 .4186 L
s
.4618 1.09436 m
.46076 1.09524 L
s
.3348 .32222 m
.3218 .32573 L
s
.32236 .32554 m
.32482 .3248 L
s
.33772 1.11522 m
.32683 1.11154 L
s
.46311 1.09337 m
.4618 1.09436 L
s
.33583 1.11466 m
.27902 1.0839 L
s
.32482 .3248 m
.32729 .32411 L
s
.4629 1.09348 m
.4702 1.08714 L
s
.46443 1.09233 m
.46311 1.09337 L
s
.32729 .32411 m
.33013 .32334 L
s
.46573 1.09123 m
.46443 1.09233 L
s
.24307 .36457 m
.20334 .37988 L
s
.10357 .43876 m
.11016 .42824 L
s
.46704 1.09009 m
.46573 1.09123 L
s
.33013 .32334 m
.333 .32261 L
s
.32683 1.11154 m
.31553 1.10666 L
s
.46833 1.08891 m
.46704 1.09009 L
s
.333 .32261 m
.33589 .32194 L
s
.46962 1.08767 m
.46833 1.08891 L
s
.34934 .31945 m
.3348 .32222 L
s
.33589 .32194 m
.3388 .32131 L
s
.28332 .34906 m
.24307 .36457 L
s
.4712 1.0863 m
.46962 1.08767 L
s
.09762 .45014 m
.10357 .43876 L
s
.4702 1.08714 m
.47853 1.07919 L
s
.3388 .32131 m
.34174 .32074 L
s
.31553 1.10666 m
.30381 1.1005 L
s
.47278 1.08489 m
.4712 1.0863 L
s
.34174 .32074 m
.34471 .32022 L
s
.47435 1.08342 m
.47278 1.08489 L
s
.34471 .32022 m
.34809 .31961 L
s
.47591 1.0819 m
.47435 1.08342 L
s
.09229 .46232 m
.09762 .45014 L
s
.32411 .33334 m
.28332 .34906 L
s
.30381 1.1005 m
.29165 1.09296 L
s
.47747 1.08032 m
.47591 1.0819 L
s
.34809 .31961 m
.3515 .31906 L
s
.36544 .31742 m
.34934 .31945 L
s
.47903 1.0787 m
.47747 1.08032 L
s
.3515 .31906 m
.35494 .31856 L
s
.47853 1.07919 m
.48789 1.06964 L
s
.07463 .53473 m
.09318 .46011 L
s
.48089 1.07693 m
.47903 1.0787 L
s
.08757 .4753 m
.09229 .46232 L
s
.35494 .31856 m
.35841 .31812 L
s
.79004 .58773 m
.36544 .31742 L
s
.53549 1.01567 m
.79004 .58773 L
s
.36544 .31742 m
.32411 .33334 L
s
.48275 1.07512 m
.48089 1.07693 L
s
.29165 1.09296 m
.27902 1.0839 L
s
.35841 .31812 m
.36191 .31774 L
s
.4846 1.07324 m
.48275 1.07512 L
s
.36191 .31774 m
.36544 .31742 L
s
.48645 1.07131 m
.4846 1.07324 L
s
.08708 .47679 m
.08757 .4753 L
s
.0866 .47829 m
.08708 .47679 L
s
.08612 .47979 m
.0866 .47829 L
s
.4883 1.06932 m
.48645 1.07131 L
s
.08566 .48131 m
.08612 .47979 L
s
.3361 .33424 m
.36544 .31742 L
s
.36544 .31742 m
.35902 .321 L
s
.32033 1.07291 m
.27902 1.0839 L
s
.27902 1.0839 m
.2663 1.07354 L
s
.27902 1.0839 m
.22061 1.0257 L
s
.0852 .48284 m
.08566 .48131 L
s
.35902 .321 m
.35263 .32463 L
s
.08475 .48437 m
.0852 .48284 L
s
.48789 1.06964 m
.49826 1.05852 L
s
.35263 .32463 m
.34626 .3283 L
s
.08443 .48548 m
.08475 .48437 L
s
.49013 1.06728 m
.4883 1.06932 L
s
.08412 .48659 m
.08443 .48548 L
s
.34626 .3283 m
.33992 .33202 L
s
.08381 .4877 m
.08412 .48659 L
s
.0835 .48882 m
.08381 .4877 L
s
.33992 .33202 m
.3336 .33578 L
s
.30783 .35198 m
.3361 .33424 L
s
.0832 .48994 m
.0835 .48882 L
s
.3336 .33578 m
.32731 .33958 L
s
.0829 .49106 m
.0832 .48994 L
s
.49231 1.06508 m
.49013 1.06728 L
s
.08268 .49191 m
.0829 .49106 L
s
.32731 .33958 m
.32143 .34328 L
s
.08246 .49276 m
.08268 .49191 L
s
.08224 .49362 m
.08246 .49276 L
s
.32143 .34328 m
.31558 .34702 L
s
.08203 .49447 m
.08224 .49362 L
s
.08181 .49533 m
.08203 .49447 L
s
.31558 .34702 m
.30974 .3508 L
s
.0816 .49619 m
.08181 .49533 L
s
.49447 1.06283 m
.49231 1.06508 L
s
.08144 .49687 m
.0816 .49619 L
s
.2663 1.07354 m
.25392 1.06223 L
s
.08128 .49754 m
.08144 .49687 L
s
.30974 .3508 m
.30394 .35462 L
s
.08112 .49821 m
.08128 .49754 L
s
.28068 .37064 m
.30783 .35198 L
s
.08096 .49889 m
.08112 .49821 L
s
.0808 .49957 m
.08096 .49889 L
s
.36219 1.06177 m
.32033 1.07291 L
s
.30394 .35462 m
.29815 .35848 L
s
.08064 .50025 m
.0808 .49957 L
s
.07944 .50574 m
.08064 .50025 L
s
.29815 .35848 m
.29239 .36238 L
s
.49664 1.06051 m
.49447 1.06283 L
s
.29239 .36238 m
.28701 .36618 L
s
.28701 .36618 m
.28165 .37002 L
s
.07831 .51134 m
.07944 .50574 L
s
.28165 .37002 m
.27631 .3739 L
s
.25468 .39027 m
.28068 .37064 L
s
.4988 1.05813 m
.49664 1.06051 L
s
.27631 .3739 m
.27099 .37782 L
s
.27099 .37782 m
.2657 .38177 L
s
.07727 .51704 m
.07831 .51134 L
s
.2657 .38177 m
.26043 .38577 L
s
.25392 1.06223 m
.24185 1.05004 L
s
.49826 1.05852 m
.50964 1.04583 L
s
.50095 1.05568 m
.4988 1.05813 L
s
.26043 .38577 m
.25551 .38967 L
s
.25551 .38967 m
.25061 .39361 L
s
.22989 .41088 m
.25468 .39027 L
s
.0763 .52283 m
.07727 .51704 L
s
.25061 .39361 m
.24573 .39758 L
s
.36219 1.06177 m
.40463 1.05048 L
s
.5031 1.05317 m
.50095 1.05568 L
s
.24573 .39758 m
.24088 .40159 L
s
.07542 .52873 m
.0763 .52283 L
s
.24088 .40159 m
.23605 .40563 L
s
.23605 .40563 m
.23124 .40971 L
s
.23124 .40971 m
.22676 .4137 L
s
.20638 .43254 m
.22989 .41088 L
s
.50562 1.0505 m
.5031 1.05317 L
s
.07463 .53473 m
.07542 .52873 L
s
.22676 .4137 m
.2223 .41773 L
s
.24185 1.05004 m
.23008 1.03702 L
s
.2223 .41773 m
.21787 .42179 L
s
.21787 .42179 m
.21346 .42589 L
s
.07207 .56295 m
.07463 .53473 L
s
.07249 .62898 m
.07463 .53473 L
s
.50813 1.04776 m
.50562 1.0505 L
s
.21346 .42589 m
.20907 .43002 L
s
.20907 .43002 m
.2047 .43418 L
s
.18424 .45529 m
.20638 .43254 L
s
.2047 .43418 m
.20065 .43826 L
s
.20065 .43826 m
.19662 .44237 L
s
.51064 1.04495 m
.50813 1.04776 L
s
.19662 .44237 m
.19261 .44652 L
s
.40463 1.05048 m
.44765 1.03903 L
s
.19261 .44652 m
.18863 .4507 L
s
.23008 1.03702 m
.21861 1.0232 L
s
.50964 1.04583 m
.52205 1.03155 L
s
.18863 .4507 m
.18467 .45491 L
s
.18467 .45491 m
.18073 .45915 L
s
.1636 .47921 m
.18424 .45529 L
s
.51314 1.04207 m
.51064 1.04495 L
s
.18073 .45915 m
.1771 .46332 L
s
.1771 .46332 m
.17349 .46752 L
s
.17349 .46752 m
.1699 .47175 L
s
.51564 1.03912 m
.51314 1.04207 L
s
.1699 .47175 m
.16634 .47601 L
s
.22061 1.0257 m
.16583 .94334 L
s
.16634 .47601 m
.1628 .4803 L
s
.07126 .59318 m
.07207 .56295 L
s
.14459 .50439 m
.1636 .47921 L
s
.1628 .4803 m
.15928 .48462 L
s
.21861 1.0232 m
.20744 1.00864 L
s
.15928 .48462 m
.15606 .48887 L
s
.51813 1.0361 m
.51564 1.03912 L
s
.15606 .48887 m
.15287 .49315 L
s
.15287 .49315 m
.1497 .49746 L
s
.44765 1.03903 m
.49127 1.02743 L
s
.1497 .49746 m
.14656 .5018 L
s
.14656 .5018 m
.14344 .50617 L
s
.12743 .53096 m
.14459 .50439 L
s
.52104 1.03289 m
.51813 1.0361 L
s
.14344 .50617 m
.14034 .51057 L
s
.14034 .51057 m
.13754 .5149 L
s
.20744 1.00864 m
.20622 1.00697 L
s
.13754 .5149 m
.13477 .51926 L
s
.20622 1.00697 m
.205 1.0053 L
s
.13477 .51926 m
.13202 .52365 L
s
.205 1.0053 m
.20379 1.00362 L
s
.13202 .52365 m
.1293 .52806 L
s
.52393 1.02961 m
.52104 1.03289 L
s
.20379 1.00362 m
.20258 1.00193 L
s
.1293 .52806 m
.1266 .53251 L
s
.20258 1.00193 m
.20137 1.00023 L
s
.11235 .55907 m
.12743 .53096 L
s
.07227 .62544 m
.07126 .59318 L
s
.52205 1.03155 m
.53549 1.01567 L
s
.1266 .53251 m
.12393 .53699 L
s
.20137 1.00023 m
.20017 .99852 L
s
.20017 .99852 m
.19931 .9973 L
s
.12393 .53699 m
.12156 .5414 L
s
.19931 .9973 m
.19845 .99607 L
s
.19845 .99607 m
.1976 .99483 L
s
.12156 .5414 m
.11921 .54583 L
s
.1976 .99483 m
.19675 .99359 L
s
.52683 1.02624 m
.52393 1.02961 L
s
.11921 .54583 m
.11689 .5503 L
s
.19675 .99359 m
.1959 .99235 L
s
.1959 .99235 m
.19505 .9911 L
s
.11689 .5503 m
.1146 .55479 L
s
.19505 .9911 m
.19442 .99016 L
s
.19442 .99016 m
.19378 .98922 L
s
.1146 .55479 m
.11233 .55932 L
s
.19378 .98922 m
.19315 .98828 L
s
.19315 .98828 m
.19252 .98733 L
s
.09971 .58894 m
.11235 .55907 L
s
.19252 .98733 m
.19189 .98638 L
s
.11233 .55932 m
.11008 .56388 L
s
.49127 1.02743 m
.53549 1.01567 L
s
.19189 .98638 m
.19126 .98543 L
s
.19126 .98543 m
.19077 .98469 L
s
.11008 .56388 m
.10815 .56836 L
s
.52972 1.0228 m
.52683 1.02624 L
s
.19077 .98469 m
.19028 .98395 L
s
.19028 .98395 m
.18979 .98321 L
s
.18979 .98321 m
.18931 .98246 L
s
.10815 .56836 m
.10624 .57287 L
s
.18931 .98246 m
.18882 .98171 L
s
.18882 .98171 m
.18834 .98096 L
s
.18834 .98096 m
.18448 .97492 L
s
.10624 .57287 m
.10436 .57741 L
s
.10436 .57741 m
.10251 .58199 L
s
.10251 .58199 m
.10069 .58659 L
s
.18448 .97492 m
.18066 .96879 L
s
.07526 .6598 m
.07227 .62544 L
s
.5326 1.01927 m
.52972 1.0228 L
s
.10069 .58659 m
.09889 .59123 L
s
.08999 .62088 m
.09971 .58894 L
s
.09889 .59123 m
.09741 .59578 L
s
.08795 .73515 m
.07249 .62898 L
s
.18066 .96879 m
.17689 .96256 L
s
.09741 .59578 m
.09596 .60037 L
s
.09596 .60037 m
.09454 .60499 L
s
.09454 .60499 m
.09315 .60964 L
s
.17689 .96256 m
.17316 .95624 L
s
.53549 1.01567 m
.5326 1.01927 L
s
.09315 .60964 m
.09178 .61433 L
s
.09178 .61433 m
.09045 .61904 L
s
.17316 .95624 m
.16947 .94983 L
s
.09045 .61904 m
.08945 .62367 L
s
.08391 .65532 m
.08999 .62088 L
s
.08945 .62367 m
.08848 .62834 L
s
.08848 .62834 m
.08754 .63304 L
s
.16947 .94983 m
.16583 .94334 L
s
.08754 .63304 m
.08663 .63777 L
s
.53549 1.01567 m
.4997 1.01162 L
s
.52769 1.01484 m
.53549 1.01567 L
s
.08663 .63777 m
.08576 .64253 L
s
.0804 .69632 m
.07526 .6598 L
s
.5199 1.01397 m
.52769 1.01484 L
s
.16583 .94334 m
.15003 .913 L
s
.16583 .94334 m
.12007 .84341 L
s
.08576 .64253 m
.08491 .64732 L
s
.51213 1.01306 m
.5199 1.01397 L
s
.08491 .64732 m
.08442 .65203 L
s
.50436 1.01211 m
.51213 1.01306 L
s
.08442 .65203 m
.08397 .65678 L
s
.49661 1.01113 m
.50436 1.01211 L
s
.0826 .69298 m
.08391 .65532 L
s
.08397 .65678 m
.08355 .66156 L
s
.4997 1.01162 m
.46458 1.00623 L
s
.48886 1.01011 m
.49661 1.01113 L
s
.08355 .66156 m
.08316 .66637 L
s
.48154 1.00895 m
.48886 1.01011 L
s
.08316 .66637 m
.0828 .67121 L
s
.47423 1.00775 m
.48154 1.00895 L
s
.0828 .67121 m
.08248 .67609 L
s
.46693 1.00651 m
.47423 1.00775 L
s
.08248 .67609 m
.08255 .68087 L
s
.45964 1.00524 m
.46693 1.00651 L
s
.46458 1.00623 m
.43015 .99948 L
s
.08255 .68087 m
.08265 .6857 L
s
.45236 1.00394 m
.45964 1.00524 L
s
.08265 .6857 m
.08279 .69056 L
s
.15003 .913 m
.1352 .88091 L
s
.44509 1.0026 m
.45236 1.00394 L
s
.08795 .73515 m
.0804 .69632 L
s
.08279 .69056 m
.08296 .69545 L
s
.08807 .73511 m
.0826 .69298 L
s
.43821 1.00113 m
.44509 1.0026 L
s
.08296 .69545 m
.08317 .70038 L
s
.43134 .99962 m
.43821 1.00113 L
s
.08317 .70038 m
.08342 .70534 L
s
.42448 .99809 m
.43134 .99962 L
s
.43015 .99948 m
.39645 .99134 L
s
.08342 .70534 m
.08409 .71021 L
s
.41763 .99652 m
.42448 .99809 L
s
.08409 .71021 m
.08481 .71511 L
s
.4108 .99492 m
.41763 .99652 L
s
.08481 .71511 m
.08556 .72006 L
s
.40397 .99329 m
.4108 .99492 L
s
.08556 .72006 m
.08636 .72504 L
s
.3975 .99154 m
.40397 .99329 L
s
.08636 .72504 m
.08719 .73006 L
s
.39105 .98975 m
.3975 .99154 L
s
.39645 .99134 m
.36353 .98174 L
s
.1352 .88091 m
.12145 .84709 L
s
.08719 .73006 m
.08807 .73511 L
s
.3846 .98794 m
.39105 .98975 L
s
.08797 .73515 m
.08795 .73515 L
s
.09766 .77426 m
.08795 .73515 L
s
.12007 .84341 m
.08795 .73515 L
s
.08799 .73514 m
.08797 .73515 L
s
.08801 .73513 m
.08799 .73514 L
s
.08803 .73513 m
.08801 .73513 L
s
.08805 .73512 m
.08803 .73513 L
s
.08807 .73511 m
.08805 .73512 L
s
.10097 .77589 m
.08807 .73511 L
s
.08807 .73511 m
.0894 .74003 L
s
.37817 .98609 m
.3846 .98794 L
s
.0894 .74003 m
.09076 .74493 L
s
.37175 .98422 m
.37817 .98609 L
s
.36534 .98232 m
.37175 .98422 L
s
.09076 .74493 m
.09215 .74979 L
s
.35927 .98029 m
.36534 .98232 L
s
.36353 .98174 m
.33144 .97064 L
s
.09215 .74979 m
.09356 .75462 L
s
.35321 .97824 m
.35927 .98029 L
s
.09356 .75462 m
.095 .75943 L
s
.34717 .97616 m
.35321 .97824 L
s
.12145 .84709 m
.10889 .81155 L
s
.095 .75943 m
.09646 .7642 L
s
.34113 .97406 m
.34717 .97616 L
s
.09646 .7642 m
.09834 .76882 L
s
.10889 .81155 m
.09766 .77426 L
s
.33511 .97192 m
.34113 .97406 L
s
.09834 .76882 m
.10024 .77342 L
s
.3291 .96976 m
.33511 .97192 L
s
.33144 .97064 m
.30025 .95795 L
s
.10024 .77342 m
.10217 .77798 L
s
.32342 .96748 m
.3291 .96976 L
s
.11831 .81016 m
.10097 .77589 L
s
.10217 .77798 m
.10412 .78252 L
s
.31775 .96518 m
.32342 .96748 L
s
.10412 .78252 m
.10609 .78703 L
s
.31209 .96285 m
.31775 .96518 L
s
.10609 .78703 m
.10809 .79152 L
s
.30644 .96049 m
.31209 .96285 L
s
.10809 .79152 m
.11046 .79586 L
s
.30081 .9581 m
.30644 .96049 L
s
.11046 .79586 m
.11286 .80018 L
s
.30025 .95795 m
.27004 .94357 L
s
.29519 .95569 m
.30081 .9581 L
s
.28988 .95317 m
.29519 .95569 L
s
.11286 .80018 m
.11529 .80447 L
s
.28459 .95062 m
.28988 .95317 L
s
.11529 .80447 m
.11773 .80873 L
s
.27931 .94805 m
.28459 .95062 L
s
.11773 .80873 m
.12019 .81297 L
s
.1388 .83976 m
.11831 .81016 L
s
.27404 .94545 m
.27931 .94805 L
s
.12019 .81297 m
.12268 .81718 L
s
.12268 .81718 m
.12552 .82126 L
s
.26879 .94282 m
.27404 .94545 L
s
.27004 .94357 m
.24093 .92736 L
s
.26355 .94017 m
.26879 .94282 L
s
.12552 .82126 m
.12838 .82532 L
s
.25862 .93741 m
.26355 .94017 L
s
.12838 .82532 m
.13126 .82935 L
s
.25371 .93462 m
.25862 .93741 L
s
.13126 .82935 m
.13416 .83335 L
s
.2488 .93181 m
.25371 .93462 L
s
.13416 .83335 m
.13708 .83734 L
s
.24392 .92897 m
.2488 .93181 L
s
.13708 .83734 m
.14002 .84129 L
s
.1617 .86572 m
.1388 .83976 L
s
.23904 .92611 m
.24392 .92897 L
s
.14002 .84129 m
.14329 .84512 L
s
.24093 .92736 m
.21304 .90915 L
s
.23419 .92322 m
.23904 .92611 L
s
.14329 .84512 m
.14658 .84893 L
s
.22963 .92022 m
.23419 .92322 L
s
.14658 .84893 m
.1499 .85271 L
s
.2251 .9172 m
.22963 .92022 L
s
.1499 .85271 m
.15323 .85647 L
s
.22057 .91415 m
.2251 .9172 L
s
.15323 .85647 m
.15657 .8602 L
s
.21607 .91108 m
.22057 .91415 L
s
.15657 .8602 m
.15994 .86391 L
s
.15994 .86391 m
.16363 .8675 L
s
.21304 .90915 m
.18656 .8887 L
s
.21158 .90798 m
.21607 .91108 L
s
.18656 .8887 m
.1617 .86572 L
s
.2071 .90486 m
.21158 .90798 L
s
.20293 .90163 m
.2071 .90486 L
s
.16363 .8675 m
.16734 .87107 L
s
.19878 .89837 m
.20293 .90163 L
s
.16734 .87107 m
.17106 .87461 L
s
.17106 .87461 m
.1748 .87813 L
s
.19464 .89509 m
.19878 .89837 L
s
.18233 .88509 m
.18642 .88845 L
s
.17856 .88162 m
.18233 .88509 L
s
.1748 .87813 m
.17856 .88162 L
s
.19052 .89178 m
.19464 .89509 L
s
.18642 .88845 m
.19052 .89178 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0130888 0.374111 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.30061 1.69366 0 1.69366 [
[.5 1.64431 -30.5 0 ]
[.5 1.64431 30.5 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.63181 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.64431 -91.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SphericalLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.63181 L
0 1.63181 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.79515 .85377 m
.75822 .73296 L
s
.75822 .73296 m
.86612 .69786 L
s
.75822 .73296 m
.71159 .61732 L
s
.82067 .97433 m
.79515 .85377 L
s
.79515 .85377 m
.90363 .82008 L
s
.71159 .61732 m
.81966 .5806 L
s
.71159 .61732 m
.6572 .51228 L
s
.82067 .97433 m
.93045 .94177 L
s
.86612 .69786 m
.90363 .82008 L
s
.81966 .5806 m
.86612 .69786 L
s
.90363 .82008 m
.93045 .94177 L
s
.76618 .47375 m
.81966 .5806 L
s
.6572 .51228 m
.76618 .47375 L
s
.62919 1.04663 m .94506 1.0573 L .83329 1.089 L .656 .751 .92 r
F
0 g
.83173 1.19182 m
.83329 1.089 L
s
.82067 .97433 m
.82937 1.05339 L
s
.62919 1.04663 m .82866 .98783 L .94506 1.0573 L .656 .751 .92 r
F
0 g
.94506 1.0573 m
.94613 1.16066 L
s
.93045 .94177 m
.94506 1.0573 L
s
.83329 1.089 m
.94506 1.0573 L
s
.59736 .42338 m .66594 .52784 L .46799 .59741 L .544 .324 .532 r
F
.59736 .42338 m .70795 .38291 L .66594 .52784 L F
0 g
.59736 .42338 m
.70795 .38291 L
s
.70795 .38291 m
.76618 .47375 L
s
.53484 .35631 m
.59736 .42338 L
s
.48452 .98252 m .82866 .98783 L .62919 1.04663 L .656 .751 .92 r
F
0 g
.62919 1.04663 m
.83329 1.089 L
s
.81509 1.27642 m
.83173 1.19182 L
s
.83173 1.19182 m
.94613 1.16066 L
s
.46799 .59741 m .64166 .67255 L .40161 .75326 L .544 .324 .532 r
F
.46799 .59741 m .66594 .52784 L .64166 .67255 L F
0 g
.46799 .59741 m
.59736 .42338 L
s
.66594 .52784 m
.70795 .38291 L
s
.6477 .31386 m
.70795 .38291 L
s
.94613 1.16066 m
.93262 1.24545 L
s
.48452 .98252 m .72554 .90854 L .82866 .98783 L .656 .751 .92 r
F
0 g
.82866 .98783 m
.94506 1.0573 L
s
.37747 .90086 m .72554 .90854 L .48452 .98252 L .656 .751 .92 r
F
0 g
.48452 .98252 m
.62919 1.04663 L
s
.53484 .35631 m
.6477 .31386 L
s
.53484 .35631 m
.47303 .31673 L
s
.40161 .75326 m .63505 .81839 L .37747 .90086 L .544 .324 .532 r
F
.40161 .75326 m .64166 .67255 L .63505 .81839 L F
0 g
.40161 .75326 m
.46799 .59741 L
s
.64166 .67255 m
.66594 .52784 L
s
.78302 1.33622 m
.81509 1.27642 L
s
.81509 1.27642 m
.93262 1.24545 L
s
.58871 .27239 m
.6477 .31386 L
s
.93262 1.24545 m
.90405 1.30501 L
s
.37747 .90086 m .63505 .81839 L .72554 .90854 L .656 .751 .92 r
F
0 g
.72554 .90854 m
.82866 .98783 L
s
.37747 .90086 m .64716 .96653 L .39351 1.04343 L .544 .324 .532 r
F
.37747 .90086 m .63505 .81839 L .64716 .96653 L F
.30494 .8003 m .63505 .81839 L .37747 .90086 L .656 .751 .92 r
F
0 g
.39313 .80513 m
.40161 .75326 L
s
.47303 .31673 m
.58871 .27239 L
s
.47303 .31673 m
.41591 .30981 L
s
.73611 1.36478 m
.78302 1.33622 L
s
.78302 1.33622 m
.90405 1.30501 L
s
.53486 .26382 m
.58871 .27239 L
s
.90405 1.30501 m
.86076 1.33286 L
s
.30494 .8003 m .55747 .71581 L .63505 .81839 L .656 .751 .92 r
F
0 g
.63505 .81839 m
.64166 .67255 L
s
.63505 .81839 m
.72554 .90854 L
s
.39351 1.04343 m .68022 1.11805 L .4589 1.18116 L .544 .324 .532 r
F
.39351 1.04343 m .64716 .96653 L .68022 1.11805 L F
0 g
.37747 .90086 m
.39351 1.04343 L
s
.63505 .81839 m
.64716 .96653 L
s
.27484 .6754 m .55747 .71581 L .30494 .8003 L .656 .751 .92 r
F
0 g
.30494 .8003 m
.37747 .90086 L
s
.41591 .30981 m
.36801 .33946 L
s
.53486 .26382 m
.41591 .30981 L
s
.67618 1.35674 m
.73611 1.36478 L
s
.73611 1.36478 m
.86076 1.33286 L
s
.49049 .29227 m
.53486 .26382 L
s
.86076 1.33286 m
.80434 1.32359 L
s
.27484 .6754 m .49412 .59859 L .55747 .71581 L .656 .751 .92 r
F
0 g
.55747 .71581 m
.63505 .81839 L
s
.4589 1.18116 m .73793 1.274 L .6067 1.30891 L .544 .324 .532 r
F
.4589 1.18116 m .68022 1.11805 L .73793 1.274 L F
0 g
.39351 1.04343 m
.4589 1.18116 L
s
.4589 1.18116 m
.6067 1.30891 L
s
.64716 .96653 m
.68022 1.11805 L
s
.36801 .33946 m
.49049 .29227 L
s
.36801 .33946 m
.33404 .40724 L
s
.31826 .51114 m .49412 .59859 L .27484 .6754 L .656 .751 .92 r
F
0 g
.27484 .6754 m
.30494 .8003 L
s
.6067 1.30891 m
.67618 1.35674 L
s
.67618 1.35674 m
.80434 1.32359 L
s
.46009 .35947 m
.49049 .29227 L
s
.68022 1.11805 m
.73793 1.274 L
s
.73793 1.274 m
.80434 1.32359 L
s
.31826 .51114 m .44763 .46358 L .49412 .59859 L .656 .751 .92 r
F
0 g
.44763 .46358 m
.49412 .59859 L
s
.49412 .59859 m
.55747 .71581 L
s
.27484 .6754 m
.31826 .51114 L
s
.31826 .51114 m
.33404 .40724 L
s
.46009 .35947 m
.33404 .40724 L
s
.6067 1.30891 m
.73793 1.274 L
s
.53278 1.22169 m
.6067 1.30891 L
s
.44763 .46358 m
.46009 .35947 L
s
.66635 1.18454 m
.73793 1.274 L
s
.31826 .51114 m
.44763 .46358 L
s
.31826 .51114 m
.32361 .64474 L
s
.46093 1.1001 m
.53278 1.22169 L
s
.53278 1.22169 m
.66635 1.18454 L
s
.44763 .46358 m
.45579 .59823 L
s
.32361 .64474 m
.45579 .59823 L
s
.32361 .64474 m
.35089 .79711 L
s
.66635 1.18454 m
.59584 1.06039 L
s
.39817 .954 m
.46093 1.1001 L
s
.46093 1.1001 m
.59584 1.06039 L
s
.35089 .79711 m
.48505 .75241 L
s
.35089 .79711 m
.39817 .954 L
s
.39817 .954 m
.53329 .91167 L
s
.48505 .75241 m
.45579 .59823 L
s
.59584 1.06039 m
.53329 .91167 L
s
.53329 .91167 m
.48505 .75241 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0130888 0.494527 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.287282 1.66576 1.11022e-16 1.66576 [
[.5 1.61567 -34.125 0 ]
[.5 1.61567 34.125 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.60317 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.61567 -95.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SphericalMirror) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.60317 L
0 1.60317 L
closepath
clip
newpath
.49439 .81882 m .54682 .78852 L .58187 .90406 L .959 .688 .479 r
F
.46241 .74286 m .54682 .78852 L .49439 .81882 L .959 .687 .478 r
F
.46241 .74286 m .50092 .67846 L .54682 .78852 L F
0 g
.5 Mabswid
[ ] 0 setdash
.54682 .78852 m
.86737 .68427 L
s
.51862 .89886 m .58187 .90406 L .60442 1.01982 L .959 .689 .48 r
F
.49439 .81882 m .58187 .90406 L .51862 .89886 L .959 .688 .479 r
F
0 g
.54682 .78852 m
.58187 .90406 L
s
.42429 .67508 m .50092 .67846 L .46241 .74286 L .958 .686 .477 r
F
.42429 .67508 m .44607 .5791 L .50092 .67846 L F
0 g
.50092 .67846 m
.54682 .78852 L
s
.5338 .97877 m .60442 1.01982 L .61307 1.13035 L .959 .69 .482 r
F
.51862 .89886 m .60442 1.01982 L .5338 .97877 L .959 .689 .48 r
F
0 g
.58187 .90406 m
.60442 1.01982 L
s
.58187 .90406 m
.90412 .80397 L
s
.38193 .61945 m .44607 .5791 L .42429 .67508 L .957 .685 .477 r
F
.38193 .61945 m .3846 .49576 L .44607 .5791 L F
0 g
.44607 .5791 m
.50092 .67846 L
s
.5338 .97877 m .61307 1.13035 L .53897 1.05427 L .959 .69 .482 r
F
0 g
.60442 1.01982 m
.93047 .92314 L
s
.53897 1.05427 m .61307 1.13035 L .60673 1.22988 L .959 .691 .484 r
F
.53897 1.05427 m .94493 1.03626 L .61307 1.13035 L .656 .751 .92 r
F
0 g
.60442 1.01982 m
.60688 1.05126 L
s
.86737 .68427 m
.90412 .80397 L
s
.82192 .5694 m
.86737 .68427 L
s
.90412 .80397 m
.93047 .92314 L
s
.43708 .85178 m .49439 .81882 L .51862 .89886 L .958 .688 .481 r
F
.42034 .81241 m .49439 .81882 L .43708 .85178 L .958 .687 .481 r
F
.42034 .81241 m .46241 .74286 L .49439 .81882 L F
.44966 .89342 m .51862 .89886 L .5338 .97877 L .958 .689 .482 r
F
.43708 .85178 m .51862 .89886 L .44966 .89342 L .958 .688 .481 r
F
.3846 .49576 m .7173 .50157 L .38193 .61945 L .544 .324 .532 r
F
0 g
.50092 .67846 m
.82192 .5694 L
s
.3846 .49576 m .71282 .37565 L .7173 .50157 L .544 .324 .532 r
F
0 g
.71665 .48344 m
.76966 .46469 L
s
.33761 .57968 m .3846 .49576 L .38193 .61945 L .957 .684 .478 r
F
.33761 .57968 m .31933 .43383 L .3846 .49576 L F
0 g
.3846 .49576 m
.71282 .37565 L
s
.40043 .77773 m .46241 .74286 L .42034 .81241 L .957 .687 .481 r
F
.40043 .77773 m .42429 .67508 L .46241 .74286 L F
0 g
.76966 .46469 m
.82192 .5694 L
s
.45731 .93485 m .5338 .97877 L .53897 1.05427 L .958 .689 .483 r
F
.44966 .89342 m .5338 .97877 L .45731 .93485 L .958 .689 .482 r
F
.53349 1.121 m .60673 1.22988 L .5847 1.31227 L .959 .692 .486 r
F
.53897 1.05427 m .60673 1.22988 L .53349 1.121 L .959 .691 .484 r
F
0 g
.60673 1.22988 m
.61307 1.13035 L
s
.60673 1.22988 m
.94619 1.13744 L
s
.37852 .74993 m .42429 .67508 L .40043 .77773 L .957 .686 .481 r
F
.37852 .74993 m .38193 .61945 L .42429 .67508 L F
.45731 .93485 m .53897 1.05427 L .45954 .97354 L .958 .689 .483 r
F
.45954 .97354 m .53897 1.05427 L .53349 1.121 L .958 .69 .484 r
F
.53897 1.05427 m .87691 .95465 L .94493 1.03626 L .656 .751 .92 r
F
0 g
.93047 .92314 m
.94493 1.03626 L
s
.45954 .97354 m .87691 .95465 L .53897 1.05427 L .656 .751 .92 r
F
0 g
.61307 1.13035 m
.94493 1.03626 L
s
.53897 1.05427 m
.61307 1.13035 L
s
.71282 .37565 m
.76966 .46469 L
s
.94493 1.03626 m
.94619 1.13744 L
s
.38193 .61945 m .72203 .63442 L .37852 .74993 L .544 .324 .532 r
F
.38193 .61945 m .7173 .50157 L .72203 .63442 L F
.35593 .73089 m .38193 .61945 L .37852 .74993 L .957 .686 .481 r
F
.35593 .73089 m .33761 .57968 L .38193 .61945 L F
0 g
.38193 .61945 m
.3846 .49576 L
s
.29393 .55907 m .31933 .43383 L .33761 .57968 L .956 .684 .479 r
F
.29393 .55907 m .25371 .3986 L .31933 .43383 L F
0 g
.31933 .43383 m
.3846 .49576 L
s
.31933 .43383 m
.65405 .30793 L
s
.53349 1.121 m .5847 1.31227 L .51719 1.17464 L .959 .692 .486 r
F
.4561 1.00706 m .53349 1.121 L .51719 1.17464 L .958 .69 .486 r
F
.45954 .97354 m .53349 1.121 L .4561 1.00706 L .958 .69 .484 r
F
.51719 1.17464 m .5847 1.31227 L .54696 1.37115 L .958 .692 .488 r
F
0 g
.5847 1.31227 m
.93323 1.22042 L
s
.5847 1.31227 m
.60673 1.22988 L
s
.37429 .88773 m .43708 .85178 L .44966 .89342 L .957 .688 .484 r
F
.37429 .88773 m .42034 .81241 L .43708 .85178 L F
.37429 .88773 m .44966 .89342 L .45731 .93485 L F
0 g
.65405 .30793 m
.71282 .37565 L
s
.71282 .37565 m
.7173 .50157 L
s
.37429 .88773 m .40043 .77773 L .42034 .81241 L .957 .687 .484 r
F
.37429 .88773 m .45731 .93485 L .45954 .97354 L .957 .688 .485 r
F
.33413 .7221 m .33761 .57968 L .35593 .73089 L .956 .685 .482 r
F
.33413 .7221 m .29393 .55907 L .33761 .57968 L F
.37429 .88773 m .37852 .74993 L .40043 .77773 L .957 .687 .484 r
F
0 g
.94619 1.13744 m
.93323 1.22042 L
s
.37429 .88773 m .45954 .97354 L .4561 1.00706 L .957 .688 .485 r
F
.45954 .97354 m .80443 .86768 L .87691 .95465 L .656 .751 .92 r
F
0 g
.87691 .95465 m
.94493 1.03626 L
s
.37429 .88773 m .80443 .86768 L .45954 .97354 L .656 .751 .92 r
F
0 g
.45954 .97354 m
.53897 1.05427 L
s
.51719 1.17464 m .54696 1.37115 L .49048 1.2111 L .958 .692 .488 r
F
.44709 1.03317 m .51719 1.17464 L .49048 1.2111 L .958 .69 .487 r
F
.4561 1.00706 m .51719 1.17464 L .44709 1.03317 L .958 .69 .486 r
F
.37852 .74993 m .72702 .7748 L .37429 .88773 L .544 .324 .532 r
F
.37852 .74993 m .72203 .63442 L .72702 .7748 L F
.37429 .88773 m .35593 .73089 L .37852 .74993 L .957 .687 .484 r
F
0 g
.37852 .74993 m
.38193 .61945 L
s
.37429 .88773 m .4561 1.00706 L .44709 1.03317 L .957 .689 .486 r
F
.25378 .56015 m .25371 .3986 L .29393 .55907 L .955 .683 .481 r
F
.25378 .56015 m .1919 .39485 L .25371 .3986 L F
0 g
.25371 .3986 m
.31933 .43383 L
s
.37429 .88773 m .33413 .7221 L .35593 .73089 L .956 .687 .484 r
F
.44709 1.03317 m .49048 1.2111 L .43293 1.04995 L .958 .69 .487 r
F
.37429 .88773 m .44709 1.03317 L .43293 1.04995 L .957 .689 .486 r
F
.31457 .72445 m .29393 .55907 L .33413 .7221 L .956 .685 .483 r
F
.31457 .72445 m .25378 .56015 L .29393 .55907 L F
0 g
.7173 .50157 m
.72203 .63442 L
s
.59657 .26719 m
.65405 .30793 L
s
.49048 1.2111 m .54696 1.37115 L .49447 1.40037 L .958 .692 .489 r
F
0 g
.54696 1.37115 m
.90556 1.27867 L
s
.54696 1.37115 m
.5847 1.31227 L
s
.49048 1.2111 m .49447 1.40037 L .45447 1.22684 L .958 .692 .489 r
F
.43293 1.04995 m .49048 1.2111 L .45447 1.22684 L .957 .69 .488 r
F
.37429 .88773 m .31457 .72445 L .33413 .7221 L .956 .687 .485 r
F
0 g
.93323 1.22042 m
.90556 1.27867 L
s
.43293 1.04995 m .45447 1.22684 L .41441 1.05597 L .957 .69 .488 r
F
.37429 .88773 m .43293 1.04995 L .41441 1.05597 L .957 .689 .486 r
F
.37429 .88773 m .39267 1.05045 L .36918 1.03343 L .956 .688 .487 r
F
.37429 .88773 m .41441 1.05597 L .39267 1.05045 L .957 .689 .487 r
F
.37429 .88773 m .73231 .92335 L .36918 1.03343 L .544 .324 .532 r
F
.37429 .88773 m .72702 .7748 L .80443 .86768 L .656 .751 .92 r
F
.37429 .88773 m .72702 .7748 L .73231 .92335 L .544 .324 .532 r
F
.37429 .88773 m .29869 .73816 L .31457 .72445 L .956 .687 .485 r
F
.37429 .88773 m .28773 .76261 L .29869 .73816 L F
.37429 .88773 m .28265 .79633 L .28773 .76261 L .956 .687 .486 r
F
.37429 .88773 m .28396 .83704 L .28265 .79633 L F
.37429 .88773 m .29169 .88174 L .28396 .83704 L .956 .687 .487 r
F
.37429 .88773 m .3053 .92706 L .29169 .88174 L .956 .688 .487 r
F
.37429 .88773 m .32376 .9695 L .3053 .92706 L F
.37429 .88773 m .34562 1.00583 L .32376 .9695 L F
.37429 .88773 m .36918 1.03343 L .34562 1.00583 L F
0 g
.80443 .86768 m
.87691 .95465 L
s
.28265 .79633 m .72702 .7748 L .37429 .88773 L .656 .751 .92 r
F
0 g
.37723 .79175 m
.37852 .74993 L
s
.29869 .73816 m .25378 .56015 L .31457 .72445 L .955 .685 .484 r
F
.41441 1.05597 m .41108 1.21936 L .39267 1.05045 L .957 .69 .489 r
F
.41441 1.05597 m .45447 1.22684 L .41108 1.21936 L F
.22018 .58431 m .1919 .39485 L .25378 .56015 L .955 .683 .483 r
F
0 g
.25402 .39849 m
.59657 .26719 L
s
.25371 .3986 m
.25402 .39849 L
s
.29869 .73816 m .22018 .58431 L .25378 .56015 L .955 .685 .484 r
F
.22018 .58431 m .13865 .42603 L .1919 .39485 L .955 .683 .483 r
F
0 g
.1919 .39485 m
.54414 .25867 L
s
.1919 .39485 m
.25371 .3986 L
s
.45447 1.22684 m .42952 1.39475 L .41108 1.21936 L .957 .692 .491 r
F
.45447 1.22684 m .49447 1.40037 L .42952 1.39475 L F
0 g
.49447 1.40037 m
.54696 1.37115 L
s
.28773 .76261 m .22018 .58431 L .29869 .73816 L .955 .685 .485 r
F
.39267 1.05045 m .36312 1.18769 L .36918 1.03343 L .956 .69 .49 r
F
.39267 1.05045 m .41108 1.21936 L .36312 1.18769 L F
0 g
.54414 .25867 m
.59657 .26719 L
s
.28265 .79633 m .19609 .63129 L .28773 .76261 L .955 .686 .486 r
F
.28773 .76261 m .19609 .63129 L .22018 .58431 L .955 .685 .485 r
F
.36918 1.03343 m .73791 1.08082 L .36312 1.18769 L .544 .324 .532 r
F
.36918 1.03343 m .73231 .92335 L .73791 1.08082 L F
.36918 1.03343 m .31415 1.13293 L .34562 1.00583 L .956 .689 .49 r
F
.36918 1.03343 m .36312 1.18769 L .31415 1.13293 L F
0 g
.36918 1.03343 m
.37429 .88773 L
s
.90556 1.27867 m
.8635 1.30587 L
s
.19609 .63129 m .13865 .42603 L .22018 .58431 L .954 .684 .485 r
F
.28265 .79633 m .18396 .6988 L .19609 .63129 L .955 .686 .486 r
F
.28396 .83704 m .18396 .6988 L .28265 .79633 L .955 .686 .487 r
F
.28265 .79633 m .64417 .67539 L .72702 .7748 L .656 .751 .92 r
F
0 g
.72203 .63442 m
.72702 .7748 L
s
.72702 .7748 m
.80443 .86768 L
s
.18396 .6988 m .64417 .67539 L .28265 .79633 L .656 .751 .92 r
F
0 g
.28265 .79633 m
.37429 .88773 L
s
.34562 1.00583 m .26819 1.05854 L .32376 .9695 L .956 .689 .49 r
F
.34562 1.00583 m .31415 1.13293 L .26819 1.05854 L F
.41108 1.21936 m .35603 1.35121 L .36312 1.18769 L .956 .691 .492 r
F
.41108 1.21936 m .42952 1.39475 L .35603 1.35121 L F
0 g
.42952 1.39475 m
.49447 1.40037 L
s
.28396 .83704 m .18543 .78234 L .18396 .6988 L .955 .686 .487 r
F
.29169 .88174 m .18543 .78234 L .28396 .83704 L .955 .687 .488 r
F
.32376 .9695 m .22928 .97023 L .3053 .92706 L .955 .688 .49 r
F
.32376 .9695 m .26819 1.05854 L .22928 .97023 L F
0 g
.72702 .7748 m
.73231 .92335 L
s
.29169 .88174 m .20088 .87544 L .18543 .78234 L .955 .687 .488 r
F
.3053 .92706 m .20088 .87544 L .29169 .88174 L .955 .688 .489 r
F
.3053 .92706 m .22928 .97023 L .20088 .87544 L F
.19609 .63129 m .09897 .49332 L .13865 .42603 L .954 .684 .485 r
F
0 g
.13865 .42603 m
.50102 .28641 L
s
.13865 .42603 m
.1919 .39485 L
s
.18396 .6988 m .09897 .49332 L .19609 .63129 L .954 .684 .487 r
F
0 g
.50102 .28641 m
.54414 .25867 L
s
.36312 1.18769 m .74386 1.24803 L .35603 1.35121 L .544 .324 .532 r
F
0 g
.42952 1.39475 m
.80859 1.2967 L
s
.49447 1.40037 m
.8635 1.30587 L
s
.36312 1.18769 m .73791 1.08082 L .74386 1.24803 L .544 .324 .532 r
F
.36312 1.18769 m .27957 1.27003 L .31415 1.13293 L .956 .691 .493 r
F
.36312 1.18769 m .35603 1.35121 L .27957 1.27003 L F
0 g
.36312 1.18769 m
.36918 1.03343 L
s
.35603 1.35121 m
.36312 1.18769 L
s
.35603 1.35121 m
.42952 1.39475 L
s
.8635 1.30587 m
.80859 1.2967 L
s
.18396 .6988 m .07751 .59449 L .09897 .49332 L .954 .684 .487 r
F
0 g
.09897 .49332 m
.13865 .42603 L
s
.18543 .78234 m .07751 .59449 L .18396 .6988 L .954 .685 .489 r
F
.18396 .6988 m .55527 .56873 L .64417 .67539 L .656 .751 .92 r
F
0 g
.64417 .67539 m
.72702 .7748 L
s
.07751 .59449 m .55527 .56873 L .18396 .6988 L .656 .751 .92 r
F
0 g
.18396 .6988 m
.28265 .79633 L
s
.73231 .92335 m
.73791 1.08082 L
s
.31415 1.13293 m .20692 1.15583 L .26819 1.05854 L .955 .69 .493 r
F
.31415 1.13293 m .27957 1.27003 L .20692 1.15583 L F
.18543 .78234 m .07767 .72314 L .07751 .59449 L .954 .685 .489 r
F
.20088 .87544 m .07767 .72314 L .18543 .78234 L .954 .686 .49 r
F
.26819 1.05854 m .14522 1.01779 L .22928 .97023 L .955 .688 .492 r
F
.26819 1.05854 m .20692 1.15583 L .14522 1.01779 L F
0 g
.35603 1.35121 m
.74386 1.24803 L
s
.27957 1.27003 m
.35603 1.35121 L
s
.20088 .87544 m .10073 .86876 L .07767 .72314 L .954 .686 .49 r
F
.22928 .97023 m .10073 .86876 L .20088 .87544 L .954 .687 .492 r
F
0 g
.47157 .35212 m
.50102 .28641 L
s
.22928 .97023 m .14522 1.01779 L .10073 .86876 L .954 .687 .492 r
F
0 g
.74386 1.24803 m
.80859 1.2967 L
s
.73791 1.08082 m
.74386 1.24803 L
s
.07751 .59449 m .45966 .454 L .55527 .56873 L .656 .751 .92 r
F
0 g
.07751 .59449 m
.45966 .454 L
s
.07751 .59449 m
.18396 .6988 L
s
.07751 .59449 m
.09897 .49332 L
s
.09897 .49332 m
.47157 .35212 L
s
.55527 .56873 m
.64417 .67539 L
s
.07751 .59449 m
.07767 .72314 L
s
.20692 1.15583 m
.27957 1.27003 L
s
.27957 1.27003 m
.67401 1.16031 L
s
.45966 .454 m
.55527 .56873 L
s
.45966 .454 m
.47157 .35212 L
s
.07767 .72314 m
.46787 .58584 L
s
.07767 .72314 m
.10073 .86876 L
s
.14522 1.01779 m
.20692 1.15583 L
s
.20692 1.15583 m
.60513 1.03862 L
s
.67401 1.16031 m
.74386 1.24803 L
s
.10073 .86876 m
.49666 .73685 L
s
.10073 .86876 m
.14522 1.01779 L
s
.14522 1.01779 m
.54394 .89288 L
s
.45966 .454 m
.46787 .58584 L
s
.67401 1.16031 m
.60513 1.03862 L
s
.49666 .73685 m
.46787 .58584 L
s
.60513 1.03862 m
.54394 .89288 L
s
.54394 .89288 m
.49666 .73685 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0130888 0.614943 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.118582 1.30505 -1.11022e-16 1.30505 [
[.5 1.24332 -42.4375 0 ]
[.5 1.24332 42.4375 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.23082 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.24332 -103.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WedgeBeamSplitter) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.23082 L
0 1.23082 L
closepath
clip
newpath
.38608 .67852 m .42794 .65563 L .45239 .73669 L .945 .686 .513 r
F
.36319 .62547 m .42794 .65563 L .38608 .67852 L F
.36319 .62547 m .39507 .57869 L .42794 .65563 L F
.40297 .73463 m .45239 .73669 L .46726 .81814 L F
.38608 .67852 m .45239 .73669 L .40297 .73463 L F
0 g
.5 Mabswid
[ ] 0 setdash
.42794 .65563 m
.45239 .73669 L
s
.33543 .57834 m .39507 .57869 L .36319 .62547 L .945 .686 .513 r
F
.33543 .57834 m .35515 .50954 L .39507 .57869 L F
0 g
.39507 .57869 m
.42794 .65563 L
s
.41294 .79083 m .46726 .81814 L .4716 .89613 L .945 .686 .513 r
F
.40297 .73463 m .46726 .81814 L .41294 .79083 L F
0 g
.45239 .73669 m
.46726 .81814 L
s
.3042 .53992 m .35515 .50954 L .33543 .57834 L .945 .686 .513 r
F
.3042 .53992 m .30987 .45192 L .35515 .50954 L F
0 g
.35515 .50954 m
.39507 .57869 L
s
.41294 .79083 m .4716 .89613 L .41532 .84408 L .945 .686 .513 r
F
.41532 .84408 m .4716 .89613 L .46469 .96656 L F
.41532 .84408 m .93658 .76428 L .4716 .89613 L .656 .751 .92 r
F
0 g
.46726 .81814 m
.46826 .83598 L
s
.3409 .70324 m .38608 .67852 L .40297 .73463 L .945 .686 .513 r
F
.32892 .67577 m .38608 .67852 L .3409 .70324 L F
.32892 .67577 m .36319 .62547 L .38608 .67852 L F
.34965 .7324 m .40297 .73463 L .41294 .79083 L F
.3409 .70324 m .40297 .73463 L .34965 .7324 L F
.30987 .45192 m .77918 .37298 L .3042 .53992 L .544 .324 .532 r
F
.30987 .45192 m .77266 .28256 L .77918 .37298 L F
0 g
.77824 .35995 m
.81066 .34849 L
s
.27118 .51279 m .30987 .45192 L .3042 .53992 L .945 .686 .513 r
F
.27118 .51279 m .2613 .40959 L .30987 .45192 L F
.31441 .65168 m .36319 .62547 L .32892 .67577 L F
.31441 .65168 m .33543 .57834 L .36319 .62547 L F
.35465 .76152 m .41294 .79083 L .41532 .84408 L F
.34965 .7324 m .41294 .79083 L .35465 .76152 L F
.40975 .89131 m .46469 .96656 L .44614 1.0251 L F
.41532 .84408 m .46469 .96656 L .40975 .89131 L F
0 g
.46469 .96656 m
.4716 .89613 L
s
.29824 .63249 m .33543 .57834 L .31441 .65168 L .945 .686 .513 r
F
.29824 .63249 m .3042 .53992 L .33543 .57834 L F
.35465 .76152 m .41532 .84408 L .35555 .7888 L F
.35555 .7888 m .41532 .84408 L .40975 .89131 L F
.41532 .84408 m .89194 .70358 L .93658 .76428 L .656 .751 .92 r
F
.35555 .7888 m .89194 .70358 L .41532 .84408 L F
0 g
.8094 .71669 m
.92419 .68265 L
s
.46469 .96656 m
.94043 .837 L
s
.41532 .84408 m
.4716 .89613 L
s
.3042 .53992 m .78606 .46847 L .29824 .63249 L .544 .324 .532 r
F
0 g
.45239 .73669 m
.90427 .59633 L
s
.3042 .53992 m .77918 .37298 L .78606 .46847 L .544 .324 .532 r
F
0 g
.42794 .65563 m
.87789 .5093 L
s
.78447 .44638 m
.84624 .42539 L
s
.30987 .45192 m
.77266 .28256 L
s
.28139 .61953 m .3042 .53992 L .29824 .63249 L .945 .686 .513 r
F
.28139 .61953 m .27118 .51279 L .3042 .53992 L F
0 g
.3042 .53992 m
.30987 .45192 L
s
.23827 .4992 m .2613 .40959 L .27118 .51279 L .945 .686 .513 r
F
.23827 .4992 m .21198 .3862 L .2613 .40959 L F
0 g
.2613 .40959 m
.30987 .45192 L
s
.2613 .40959 m
.73404 .23177 L
s
.40975 .89131 m .44614 1.0251 L .39619 .92948 L .945 .686 .513 r
F
.35224 .81254 m .40975 .89131 L .39619 .92948 L F
.35555 .7888 m .40975 .89131 L .35224 .81254 L F
0 g
.87789 .5093 m
.90427 .59633 L
s
.84624 .42539 m
.87789 .5093 L
s
.90427 .59633 m
.92419 .68265 L
s
.39619 .92948 m .44614 1.0251 L .41609 1.06727 L .945 .686 .513 r
F
0 g
.44614 1.0251 m
.46469 .96656 L
s
.29196 .73 m .3409 .70324 L .34965 .7324 L .945 .686 .513 r
F
.29196 .73 m .32892 .67577 L .3409 .70324 L F
.29196 .73 m .34965 .7324 L .35465 .76152 L F
0 g
.81066 .34849 m
.84624 .42539 L
s
.29196 .73 m .31441 .65168 L .32892 .67577 L .945 .686 .513 r
F
.29196 .73 m .35465 .76152 L .35555 .7888 L F
0 g
.92419 .68265 m
.93658 .76428 L
s
.26493 .61379 m .27118 .51279 L .28139 .61953 L .945 .686 .513 r
F
.26493 .61379 m .23827 .4992 L .27118 .51279 L F
.29196 .73 m .29824 .63249 L .31441 .65168 L F
.29196 .73 m .35555 .7888 L .35224 .81254 L F
.35555 .7888 m .8443 .63878 L .89194 .70358 L .656 .751 .92 r
F
.29196 .73 m .8443 .63878 L .35555 .7888 L F
0 g
.4716 .89613 m
.93658 .76428 L
s
.35555 .7888 m
.41532 .84408 L
s
.39619 .92948 m .41609 1.06727 L .37503 .95568 L .945 .686 .513 r
F
.34481 .83115 m .39619 .92948 L .37503 .95568 L F
.35224 .81254 m .39619 .92948 L .34481 .83115 L F
.29824 .63249 m .79335 .56948 L .29196 .73 L .544 .324 .532 r
F
.29824 .63249 m .78606 .46847 L .79335 .56948 L F
.29196 .73 m .28139 .61953 L .29824 .63249 L .945 .686 .513 r
F
0 g
.29824 .63249 m
.3042 .53992 L
s
.77266 .28256 m
.81066 .34849 L
s
.29196 .73 m .35224 .81254 L .34481 .83115 L .945 .686 .513 r
F
.20764 .50088 m .21198 .3862 L .23827 .4992 L F
.20764 .50088 m .165 .38501 L .21198 .3862 L F
0 g
.21198 .3862 m
.2613 .40959 L
s
.21198 .3862 m
.69697 .20031 L
s
.93658 .76428 m
.94043 .837 L
s
.89194 .70358 m
.93658 .76428 L
s
.29196 .73 m .26493 .61379 L .28139 .61953 L .945 .686 .513 r
F
.34481 .83115 m .37503 .95568 L .33365 .84326 L F
.29196 .73 m .34481 .83115 L .33365 .84326 L F
.24996 .61587 m .23827 .4992 L .26493 .61379 L F
.24996 .61587 m .20764 .50088 L .23827 .4992 L F
.37503 .95568 m .41609 1.06727 L .37543 1.08872 L F
0 g
.41609 1.06727 m
.44614 1.0251 L
s
.37503 .95568 m .37543 1.08872 L .34721 .96743 L .945 .686 .513 r
F
.33365 .84326 m .37503 .95568 L .34721 .96743 L F
.29196 .73 m .24996 .61587 L .26493 .61379 L F
.33365 .84326 m .34721 .96743 L .31939 .84786 L F
.29196 .73 m .33365 .84326 L .31939 .84786 L F
0 g
.77266 .28256 m
.77918 .37298 L
s
.73404 .23177 m
.77266 .28256 L
s
.29196 .73 m .30291 .84439 L .28534 .83284 L .945 .686 .513 r
F
.29196 .73 m .31939 .84786 L .30291 .84439 L F
.29196 .73 m .80106 .67649 L .28534 .83284 L .544 .324 .532 r
F
.29196 .73 m .79335 .56948 L .8443 .63878 L .656 .751 .92 r
F
.29196 .73 m .79335 .56948 L .80106 .67649 L .544 .324 .532 r
F
.29196 .73 m .23758 .62589 L .24996 .61587 L .945 .686 .513 r
F
.29196 .73 m .22873 .64339 L .23758 .62589 L F
.29196 .73 m .22418 .6673 L .22873 .64339 L F
.29196 .73 m .22436 .696 L .22418 .6673 L F
.29196 .73 m .22934 .72738 L .22436 .696 L F
.29196 .73 m .2388 .75907 L .22934 .72738 L F
.29196 .73 m .25201 .78863 L .2388 .75907 L F
.29196 .73 m .26794 .81383 L .25201 .78863 L F
.29196 .73 m .28534 .83284 L .26794 .81383 L F
.22418 .6673 m .79335 .56948 L .29196 .73 L .656 .751 .92 r
F
0 g
.29681 .65482 m
.29824 .63249 L
s
.23758 .62589 m .20764 .50088 L .24996 .61587 L .945 .686 .513 r
F
0 g
.93492 .89629 m
.94043 .837 L
s
.31939 .84786 m .31426 .96292 L .30291 .84439 L .945 .686 .513 r
F
.31939 .84786 m .34721 .96743 L .31426 .96292 L F
.18158 .51871 m .165 .38501 L .20764 .50088 L F
.23758 .62589 m .18158 .51871 L .20764 .50088 L F
.18158 .51871 m .1239 .40831 L .165 .38501 L F
0 g
.165 .38501 m
.66395 .19211 L
s
.165 .38501 m
.21198 .3862 L
s
.8443 .63878 m
.89194 .70358 L
s
.34721 .96743 m .32602 1.08582 L .31426 .96292 L .945 .686 .513 r
F
.34721 .96743 m .37543 1.08872 L .32602 1.08582 L F
0 g
.37543 1.08872 m
.41609 1.06727 L
s
.22873 .64339 m .18158 .51871 L .23758 .62589 L .945 .686 .513 r
F
.30291 .84439 m .27835 .94146 L .28534 .83284 L F
.30291 .84439 m .31426 .96292 L .27835 .94146 L F
.22418 .6673 m .16231 .55242 L .22873 .64339 L F
.22873 .64339 m .16231 .55242 L .18158 .51871 L F
0 g
.77918 .37298 m
.78606 .46847 L
s
.69697 .20031 m
.73404 .23177 L
s
.28534 .83284 m .80925 .79008 L .27835 .94146 L .544 .324 .532 r
F
0 g
.44614 1.0251 m
.93492 .89629 L
s
.28534 .83284 m .80106 .67649 L .80925 .79008 L .544 .324 .532 r
F
.28534 .83284 m .24216 .90378 L .26794 .81383 L .945 .686 .513 r
F
.28534 .83284 m .27835 .94146 L .24216 .90378 L F
0 g
.28534 .83284 m
.29196 .73 L
s
.16231 .55242 m .1239 .40831 L .18158 .51871 L .945 .686 .513 r
F
.22418 .6673 m .15176 .60033 L .16231 .55242 L F
.22436 .696 m .15176 .60033 L .22418 .6673 L F
.22418 .6673 m .73871 .49517 L .79335 .56948 L .656 .751 .92 r
F
.15176 .60033 m .73871 .49517 L .22418 .6673 L F
0 g
.22418 .6673 m
.29196 .73 L
s
.26794 .81383 m .20867 .85223 L .25201 .78863 L .945 .686 .513 r
F
.26794 .81383 m .24216 .90378 L .20867 .85223 L F
0 g
.93492 .89629 m
.91952 .93745 L
s
.31426 .96292 m .27095 1.05638 L .27835 .94146 L .945 .686 .513 r
F
.31426 .96292 m .32602 1.08582 L .27095 1.05638 L F
0 g
.32602 1.08582 m
.37543 1.08872 L
s
.22436 .696 m .15122 .65922 L .15176 .60033 L .945 .686 .513 r
F
.22934 .72738 m .15122 .65922 L .22436 .696 L F
.25201 .78863 m .18083 .79077 L .2388 .75907 L F
.25201 .78863 m .20867 .85223 L .18083 .79077 L F
.22934 .72738 m .16113 .72453 L .15122 .65922 L F
.2388 .75907 m .16113 .72453 L .22934 .72738 L F
.2388 .75907 m .18083 .79077 L .16113 .72453 L F
.16231 .55242 m .09246 .45675 L .1239 .40831 L F
0 g
.1239 .40831 m
.165 .38501 L
s
.79335 .56948 m
.8443 .63878 L
s
.15176 .60033 m .09246 .45675 L .16231 .55242 L .945 .686 .513 r
F
0 g
.78606 .46847 m
.79335 .56948 L
s
.27835 .94146 m .81796 .91084 L .27095 1.05638 L .544 .324 .532 r
F
0 g
.32602 1.08582 m
.85977 .94776 L
s
.37543 1.08872 m
.89422 .95588 L
s
.27835 .94146 m .80925 .79008 L .81796 .91084 L .544 .324 .532 r
F
0 g
.41609 1.06727 m
.91952 .93745 L
s
.27835 .94146 m .21442 1.00054 L .24216 .90378 L .945 .686 .513 r
F
.27835 .94146 m .27095 1.05638 L .21442 1.00054 L F
0 g
.27835 .94146 m
.28534 .83284 L
s
.27095 1.05638 m
.32602 1.08582 L
s
.27095 1.05638 m
.27835 .94146 L
s
.66395 .19211 m
.69697 .20031 L
s
.15176 .60033 m .07422 .52862 L .09246 .45675 L .945 .686 .513 r
F
.15122 .65922 m .07422 .52862 L .15176 .60033 L F
.15176 .60033 m .67998 .41529 L .73871 .49517 L .656 .751 .92 r
F
.07422 .52862 m .67998 .41529 L .15176 .60033 L F
0 g
.15176 .60033 m
.22418 .6673 L
s
.09246 .45675 m
.1239 .40831 L
s
.91952 .93745 m
.89422 .95588 L
s
.24216 .90378 m .1615 .92146 L .20867 .85223 L .945 .686 .513 r
F
.24216 .90378 m .21442 1.00054 L .1615 .92146 L F
.15122 .65922 m .07186 .61932 L .07422 .52862 L F
.16113 .72453 m .07186 .61932 L .15122 .65922 L F
0 g
.73871 .49517 m
.79335 .56948 L
s
.79335 .56948 m
.80106 .67649 L
s
.20867 .85223 m .11738 .82547 L .18083 .79077 L .945 .686 .513 r
F
.20867 .85223 m .1615 .92146 L .11738 .82547 L F
0 g
.27095 1.05638 m
.81796 .91084 L
s
.21442 1.00054 m
.27095 1.05638 L
s
.16113 .72453 m .08654 .72142 L .07186 .61932 L .945 .686 .513 r
F
.18083 .79077 m .08654 .72142 L .16113 .72453 L F
.18083 .79077 m .11738 .82547 L .08654 .72142 L F
0 g
.63776 .21031 m
.66395 .19211 L
s
.07422 .52862 m .61668 .3292 L .67998 .41529 L .656 .751 .92 r
F
0 g
.07422 .52862 m
.61668 .3292 L
s
.07422 .52862 m
.15176 .60033 L
s
.07422 .52862 m
.09246 .45675 L
s
.09246 .45675 m
.6212 .25637 L
s
.1239 .40831 m
.63776 .21031 L
s
.07186 .61932 m
.07422 .52862 L
s
.89422 .95588 m
.85977 .94776 L
s
.1615 .92146 m
.21442 1.00054 L
s
.21442 1.00054 m
.77172 .84552 L
s
.80106 .67649 m
.80925 .79008 L
s
.67998 .41529 m
.73871 .49517 L
s
.07186 .61932 m
.62567 .42444 L
s
.07186 .61932 m
.08654 .72142 L
s
.11738 .82547 m
.1615 .92146 L
s
.1615 .92146 m
.72502 .7556 L
s
.6212 .25637 m
.63776 .21031 L
s
.08654 .72142 m
.64815 .53432 L
s
.08654 .72142 m
.11738 .82547 L
s
.11738 .82547 m
.68238 .64847 L
s
.81796 .91084 m
.85977 .94776 L
s
.80925 .79008 m
.81796 .91084 L
s
.61668 .3292 m
.67998 .41529 L
s
.61668 .3292 m
.6212 .25637 L
s
.77172 .84552 m
.81796 .91084 L
s
.61668 .3292 m
.62567 .42444 L
s
.77172 .84552 m
.72502 .7556 L
s
.64815 .53432 m
.62567 .42444 L
s
.72502 .7556 m
.68238 .64847 L
s
.68238 .64847 m
.64815 .53432 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0130888 0.735359 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.11737 1.30238 0 1.30238 [
[.5 1.24054 -27.75 0 ]
[.5 1.24054 27.75 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.22804 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.24054 -88.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WedgePrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.22804 L
0 1.22804 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.45139 .73545 m
.42702 .65465 L
s
.42702 .65465 m
.39425 .57795 L
s
.46621 .81664 m
.45139 .73545 L
s
.39425 .57795 m
.35444 .50903 L
s
.41438 .84251 m .93657 .76223 L .47052 .89438 L .656 .751 .92 r
F
0 g
.4636 .96459 m
.47052 .89438 L
s
.46621 .81664 m
.46719 .83439 L
s
.30929 .4516 m .77967 .372 L .30361 .53933 L .544 .324 .532 r
F
.30929 .4516 m .77313 .28185 L .77967 .372 L F
0 g
.77872 .35901 m
.81099 .3476 L
s
.44508 1.02295 m
.4636 .96459 L
s
.41438 .84251 m .8921 .70168 L .93657 .76223 L .656 .751 .92 r
F
.35477 .78742 m .8921 .70168 L .41438 .84251 L F
0 g
.41438 .84251 m
.47052 .89438 L
s
.80937 .71488 m
.9242 .68083 L
s
.4636 .96459 m
.94044 .83474 L
s
.30361 .53933 m .78657 .46721 L .29764 .63162 L .544 .324 .532 r
F
0 g
.45139 .73545 m
.90431 .59476 L
s
.30361 .53933 m .77967 .372 L .78657 .46721 L .544 .324 .532 r
F
0 g
.42702 .65465 m
.878 .50797 L
s
.78497 .44519 m
.84646 .4243 L
s
.30361 .53933 m
.30929 .4516 L
s
.26084 .40942 m
.30929 .4516 L
s
.30929 .4516 m
.77313 .28185 L
s
.26084 .40942 m
.73466 .23119 L
s
.26084 .40942 m
.21165 .38613 L
s
.878 .50797 m
.90431 .59476 L
s
.84646 .4243 m
.878 .50797 L
s
.90431 .59476 m
.9242 .68083 L
s
.41509 1.06499 m
.44508 1.02295 L
s
.81099 .3476 m
.84646 .4243 L
s
.9242 .68083 m
.93657 .76223 L
s
.35477 .78742 m .84464 .63706 L .8921 .70168 L .656 .751 .92 r
F
.29135 .72881 m .84464 .63706 L .35477 .78742 L F
0 g
.47052 .89438 m
.93657 .76223 L
s
.35477 .78742 m
.41438 .84251 L
s
.29764 .63162 m .79387 .56793 L .29135 .72881 L .544 .324 .532 r
F
.29764 .63162 m .78657 .46721 L .79387 .56793 L F
0 g
.29764 .63162 m
.30361 .53933 L
s
.77313 .28185 m
.81099 .3476 L
s
.21165 .38613 m
.69774 .1998 L
s
.21165 .38613 m
.16478 .38495 L
s
.93657 .76223 m
.94044 .83474 L
s
.8921 .70168 m
.93657 .76223 L
s
.37451 1.08639 m
.41509 1.06499 L
s
.77313 .28185 m
.77967 .372 L
s
.73466 .23119 m
.77313 .28185 L
s
.29135 .72881 m .80161 .67464 L .28471 .83133 L .544 .324 .532 r
F
.29135 .72881 m .79387 .56793 L .84464 .63706 L .656 .751 .92 r
F
.29135 .72881 m .79387 .56793 L .80161 .67464 L .544 .324 .532 r
F
.22374 .66634 m .79387 .56793 L .29135 .72881 L .656 .751 .92 r
F
0 g
.2962 .65383 m
.29764 .63162 L
s
.93498 .89385 m
.94044 .83474 L
s
.16478 .38495 m
.12378 .40819 L
s
.16478 .38495 m
.66486 .19161 L
s
.84464 .63706 m
.8921 .70168 L
s
.32523 1.08351 m
.37451 1.08639 L
s
.77967 .372 m
.78657 .46721 L
s
.69774 .1998 m
.73466 .23119 L
s
.28471 .83133 m .80983 .78789 L .27771 .93962 L .544 .324 .532 r
F
0 g
.44508 1.02295 m
.93498 .89385 L
s
.28471 .83133 m .80161 .67464 L .80983 .78789 L .544 .324 .532 r
F
0 g
.28471 .83133 m
.29135 .72881 L
s
.22374 .66634 m .73944 .49381 L .79387 .56793 L .656 .751 .92 r
F
.15151 .5996 m .73944 .49381 L .22374 .66634 L F
0 g
.22374 .66634 m
.29135 .72881 L
s
.93498 .89385 m
.91968 .93488 L
s
.79387 .56793 m
.84464 .63706 L
s
.78657 .46721 m
.79387 .56793 L
s
.27771 .93962 m .81856 .90831 L .27029 1.05417 L .544 .324 .532 r
F
0 g
.32523 1.08351 m
.8602 .94514 L
s
.27029 1.05417 m
.32523 1.08351 L
s
.37451 1.08639 m
.8945 .95325 L
s
.27771 .93962 m .80983 .78789 L .81856 .90831 L .544 .324 .532 r
F
0 g
.41509 1.06499 m
.91968 .93488 L
s
.27771 .93962 m
.28471 .83133 L
s
.27029 1.05417 m
.27771 .93962 L
s
.66486 .19161 m
.69774 .1998 L
s
.15151 .5996 m .68093 .41414 L .73944 .49381 L .656 .751 .92 r
F
.07418 .52814 m .68093 .41414 L .15151 .5996 L F
0 g
.15151 .5996 m
.22374 .66634 L
s
.0924 .45649 m
.12378 .40819 L
s
.91968 .93488 m
.8945 .95325 L
s
.73944 .49381 m
.79387 .56793 L
s
.79387 .56793 m
.80161 .67464 L
s
.27029 1.05417 m
.81856 .90831 L
s
.21392 .99852 m
.27029 1.05417 L
s
.63879 .20974 m
.66486 .19161 L
s
.07418 .52814 m .61787 .32827 L .68093 .41414 L .656 .751 .92 r
F
0 g
.07418 .52814 m
.61787 .32827 L
s
.0924 .45649 m
.62233 .25565 L
s
.07418 .52814 m
.0924 .45649 L
s
.07418 .52814 m
.15151 .5996 L
s
.12378 .40819 m
.63879 .20974 L
s
.07181 .61855 m
.07418 .52814 L
s
.8945 .95325 m
.8602 .94514 L
s
.16115 .91971 m
.21392 .99852 L
s
.21392 .99852 m
.77249 .84316 L
s
.80161 .67464 m
.80983 .78789 L
s
.68093 .41414 m
.73944 .49381 L
s
.07181 .61855 m
.62686 .42324 L
s
.07181 .61855 m
.08642 .72032 L
s
.11716 .82403 m
.16115 .91971 L
s
.16115 .91971 m
.72594 .75348 L
s
.62233 .25565 m
.63879 .20974 L
s
.08642 .72032 m
.6493 .53281 L
s
.08642 .72032 m
.11716 .82403 L
s
.11716 .82403 m
.68344 .64664 L
s
.81856 .90831 m
.8602 .94514 L
s
.80983 .78789 m
.81856 .90831 L
s
.61787 .32827 m
.68093 .41414 L
s
.61787 .32827 m
.62233 .25565 L
s
.77249 .84316 m
.81856 .90831 L
s
.61787 .32827 m
.62686 .42324 L
s
.77249 .84316 m
.72594 .75348 L
s
.6493 .53281 m
.62686 .42324 L
s
.72594 .75348 m
.68344 .64664 L
s
.68344 .64664 m
.6493 .53281 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0130888 0.855774 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.218821 1.52137 0 1.52137 [
[.5 1.46717 -19.1875 0 ]
[.5 1.46717 19.1875 12 ]
[ 0 0 0 0 ]
[ 1 1.45467 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.46717 -80.1875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Window) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.45467 L
0 1.45467 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.53078 .83718 m
.49996 .73537 L
s
.49996 .73537 m
.87372 .61381 L
s
.49996 .73537 m
.45923 .6385 L
s
.55026 .93927 m
.53078 .83718 L
s
.53078 .83718 m
.90653 .72046 L
s
.45923 .6385 m
.41032 .55118 L
s
.48925 .97061 m .94414 .92712 L .55719 1.03685 L .656 .751 .92 r
F
0 g
.55059 1.12479 m
.55719 1.03685 L
s
.55026 .93927 m
.55206 .9646 L
s
.35528 .47809 m .74329 .44983 L .3505 .58789 L .544 .324 .532 r
F
0 g
.45923 .6385 m
.83353 .51133 L
s
.35528 .47809 m .738 .33804 L .74329 .44983 L .544 .324 .532 r
F
0 g
.74253 .43373 m
.78764 .41778 L
s
.87372 .61381 m
.90653 .72046 L
s
.83353 .51133 m
.87372 .61381 L
s
.52992 1.19768 m
.55059 1.12479 L
s
.55059 1.12479 m
.94642 1.01699 L
s
.90653 .72046 m
.93045 .82654 L
s
.78764 .41778 m
.83353 .51133 L
s
.48925 .97061 m .88506 .85393 L .94414 .92712 L .656 .751 .92 r
F
.41705 .90021 m .88506 .85393 L .48925 .97061 L F
0 g
.48925 .97061 m
.55719 1.03685 L
s
.55719 1.03685 m
.94414 .92712 L
s
.81457 .8609 m
.93045 .82654 L
s
.93045 .82654 m
.94414 .92712 L
s
.3505 .58789 m .74887 .56782 L .34547 .70345 L .544 .324 .532 r
F
.3505 .58789 m .74329 .44983 L .74887 .56782 L F
0 g
.3505 .58789 m
.35528 .47809 L
s
.29664 .42398 m
.35528 .47809 L
s
.35528 .47809 m
.738 .33804 L
s
.29664 .42398 m
.68694 .27717 L
s
.29664 .42398 m
.23748 .39348 L
s
.738 .33804 m
.78764 .41778 L
s
.94414 .92712 m
.94642 1.01699 L
s
.49521 1.24992 m
.52992 1.19768 L
s
.52992 1.19768 m
.93633 1.09058 L
s
.41705 .90021 m .82207 .7759 L .88506 .85393 L .656 .751 .92 r
F
0 g
.88506 .85393 m
.94414 .92712 L
s
.34017 .82526 m .82207 .7759 L .41705 .90021 L .656 .751 .92 r
F
0 g
.41705 .90021 m
.48925 .97061 L
s
.738 .33804 m
.74329 .44983 L
s
.68694 .27717 m
.738 .33804 L
s
.34547 .70345 m .75477 .69253 L .34017 .82526 L .544 .324 .532 r
F
.34547 .70345 m .74887 .56782 L .75477 .69253 L F
0 g
.34547 .70345 m
.3505 .58789 L
s
.23748 .39348 m
.63728 .24024 L
s
.23748 .39348 m
.18154 .39076 L
s
.94642 1.01699 m
.93633 1.09058 L
s
.44739 1.27605 m
.49521 1.24992 L
s
.49521 1.24992 m
.91337 1.14208 L
s
.74329 .44983 m
.74887 .56782 L
s
.63728 .24024 m
.68694 .27717 L
s
.34017 .82526 m .76101 .82455 L .33458 .95383 L .544 .324 .532 r
F
.34017 .82526 m .75477 .69253 L .82207 .7759 L .656 .751 .92 r
F
.34017 .82526 m .75477 .69253 L .76101 .82455 L .544 .324 .532 r
F
0 g
.82207 .7759 m
.88506 .85393 L
s
.25815 .74529 m .75477 .69253 L .34017 .82526 L .656 .751 .92 r
F
0 g
.34405 .73616 m
.34547 .70345 L
s
.93633 1.09058 m
.91337 1.14208 L
s
.18154 .39076 m
.13309 .41882 L
s
.59229 .23197 m
.18154 .39076 L
s
.38859 1.27153 m
.44739 1.27605 L
s
.33458 .95383 m .76763 .96456 L .32866 1.08973 L .544 .324 .532 r
F
.33458 .95383 m .76101 .82455 L .76763 .96456 L F
0 g
.33458 .95383 m
.34017 .82526 L
s
.59229 .23197 m
.63728 .24024 L
s
.25815 .74529 m .6827 .60325 L .75477 .69253 L .656 .751 .92 r
F
0 g
.74887 .56782 m
.75477 .69253 L
s
.75477 .69253 m
.82207 .7759 L
s
.17044 .65977 m .6827 .60325 L .25815 .74529 L .656 .751 .92 r
F
0 g
.25815 .74529 m
.34017 .82526 L
s
.91337 1.14208 m
.87773 1.16586 L
s
.13309 .41882 m
.55566 .256 L
s
.13309 .41882 m
.09665 .47862 L
s
.75477 .69253 m
.76101 .82455 L
s
.32866 1.08973 m .77467 1.11329 L .3224 1.23362 L .544 .324 .532 r
F
0 g
.38859 1.27153 m
.83064 1.15718 L
s
.3224 1.23362 m
.38859 1.27153 L
s
.44739 1.27605 m
.87773 1.16586 L
s
.32866 1.08973 m .76763 .96456 L .77467 1.11329 L .544 .324 .532 r
F
0 g
.32866 1.08973 m
.33458 .95383 L
s
.3224 1.23362 m
.32866 1.08973 L
s
.55566 .256 m
.59229 .23197 L
s
.17044 .65977 m .60535 .50742 L .6827 .60325 L .656 .751 .92 r
F
0 g
.6827 .60325 m
.75477 .69253 L
s
.07644 .56812 m .60535 .50742 L .17044 .65977 L .656 .751 .92 r
F
0 g
.17044 .65977 m
.25815 .74529 L
s
.87773 1.16586 m
.83064 1.15718 L
s
.76101 .82455 m
.76763 .96456 L
s
.3224 1.23362 m
.77467 1.11329 L
s
.25384 1.16254 m
.3224 1.23362 L
s
.53116 .31395 m
.55566 .256 L
s
.07644 .56812 m .5221 .40429 L .60535 .50742 L .656 .751 .92 r
F
0 g
.07644 .56812 m
.5221 .40429 L
s
.60535 .50742 m
.6827 .60325 L
s
.09665 .47862 m
.53116 .31395 L
s
.07644 .56812 m
.09665 .47862 L
s
.07644 .56812 m
.17044 .65977 L
s
.07557 .68166 m
.07644 .56812 L
s
.18903 1.06234 m
.25384 1.16254 L
s
.25384 1.16254 m
.71384 1.03458 L
s
.77467 1.11329 m
.83064 1.15718 L
s
.76763 .96456 m
.77467 1.11329 L
s
.07557 .68166 m
.53062 .52154 L
s
.07557 .68166 m
.09527 .80995 L
s
.5221 .40429 m
.60535 .50742 L
s
.13432 .94106 m
.18903 1.06234 L
s
.18903 1.06234 m
.65343 .92565 L
s
.09527 .80995 m
.55702 .65612 L
s
.09527 .80995 m
.13432 .94106 L
s
.5221 .40429 m
.53116 .31395 L
s
.13432 .94106 m
.59932 .79539 L
s
.71384 1.03458 m
.77467 1.11329 L
s
.5221 .40429 m
.53062 .52154 L
s
.71384 1.03458 m
.65343 .92565 L
s
.55702 .65612 m
.53062 .52154 L
s
.65343 .92565 m
.59932 .79539 L
s
.59932 .79539 m
.55702 .65612 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0130888 0.97619 0.110043 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-16 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.119739 0.133279 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.477262 2.00826 -0.0107291 2.00826 [
[.5 2.01003 -60.9688 0 ]
[.5 2.01003 60.9688 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.99753 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 2.01003 -121.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PlanoConvexCylindricalLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.99753 L
0 1.99753 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5354 .62729 m
.6669 .68531 L
s
.6669 .68531 m
.9104 .60239 L
s
.6669 .68531 m
.67036 .86536 L
s
.42944 .55734 m
.5354 .62729 L
s
.5354 .62729 m
.84744 .51851 L
s
.9104 .60239 m
.84744 .51851 L
s
.92005 .78383 m
.9104 .60239 L
s
.67036 .86536 m
.92005 .78383 L
s
.67036 .86536 m
.67399 1.05452 L
s
.84744 .51851 m
.78208 .43143 L
s
.93019 .97465 m
.92005 .78383 L
s
.34491 .47608 m .71916 .52631 L .3402 .65951 L .544 .324 .532 r
F
.34491 .47608 m .71416 .34095 L .71916 .52631 L F
0 g
.71723 .45458 m
.78208 .43143 L
s
.2812 .38286 m
.34491 .47608 L
s
.34491 .47608 m
.71416 .34095 L
s
.67399 1.05452 m
.93019 .97465 L
s
.71416 .34095 m
.78208 .43143 L
s
.24054 .27589 m
.2812 .38286 L
s
.2812 .38286 m
.64355 .24688 L
s
.3402 .65951 m .72443 .72183 L .33524 .85269 L .544 .324 .532 r
F
.3402 .65951 m .71916 .52631 L .72443 .72183 L F
0 g
.3402 .65951 m
.34491 .47608 L
s
.53608 1.199 m .94088 1.17557 L .67781 1.2535 L .656 .751 .92 r
F
0 g
.67781 1.2535 m
.68183 1.46309 L
s
.67399 1.05452 m
.6766 1.19087 L
s
.64355 .24688 m
.71416 .34095 L
s
.71416 .34095 m
.71916 .52631 L
s
.22914 .15162 m
.24054 .27589 L
s
.24054 .27589 m
.57008 .149 L
s
.53608 1.199 m .87343 1.09651 L .94088 1.17557 L .656 .751 .92 r
F
0 g
.93019 .97465 m
.94088 1.17557 L
s
.42162 1.13314 m .87343 1.09651 L .53608 1.199 L .656 .751 .92 r
F
0 g
.53608 1.199 m
.67781 1.2535 L
s
.67781 1.2535 m
.94088 1.17557 L
s
.64355 .24688 m
.57008 .149 L
s
.94088 1.17557 m
.95214 1.38742 L
s
.33524 .85269 m .72999 .92837 L .33001 1.05642 L .544 .324 .532 r
F
.33524 .85269 m .72443 .72183 L .72999 .92837 L F
0 g
.33524 .85269 m
.3402 .65951 L
s
.68183 1.46309 m
.95214 1.38742 L
s
.68183 1.46309 m
.68607 1.68415 L
s
.71916 .52631 m
.72443 .72183 L
s
.42162 1.13314 m .80319 1.01418 L .87343 1.09651 L .656 .751 .92 r
F
0 g
.87343 1.09651 m
.94088 1.17557 L
s
.33001 1.05642 m .80319 1.01418 L .42162 1.13314 L .656 .751 .92 r
F
0 g
.42162 1.13314 m
.53608 1.199 L
s
.49357 .04706 m
.22914 .15162 L
s
.22087 .33934 m
.22914 .15162 L
s
.57008 .149 m
.49357 .04706 L
s
.96404 1.61113 m
.95214 1.38742 L
s
.33001 1.05642 m .73588 1.14687 L .32449 1.27159 L .544 .324 .532 r
F
.33001 1.05642 m .72999 .92837 L .80319 1.01418 L .656 .751 .92 r
F
.33001 1.05642 m .72999 .92837 L .73588 1.14687 L .544 .324 .532 r
F
0 g
.80319 1.01418 m
.87343 1.09651 L
s
.26064 .96815 m .72999 .92837 L .33001 1.05642 L .656 .751 .92 r
F
0 g
.33244 .96206 m
.33524 .85269 L
s
.68607 1.68415 m
.96404 1.61113 L
s
.68607 1.68415 m
.69055 1.91766 L
s
.49357 .04706 m
.49262 .23592 L
s
.21214 .53779 m
.22087 .33934 L
s
.22087 .33934 m
.49262 .23592 L
s
.26064 .96815 m .65363 .83885 L .72999 .92837 L .656 .751 .92 r
F
0 g
.72999 .92837 m
.80319 1.01418 L
s
.72443 .72183 m
.72999 .92837 L
s
.21598 .86649 m .65363 .83885 L .26064 .96815 L .656 .751 .92 r
F
0 g
.26064 .96815 m
.33001 1.05642 L
s
.97662 1.84771 m
.96404 1.61113 L
s
.32449 1.27159 m .74212 1.37843 L .31864 1.49918 L .544 .324 .532 r
F
.32449 1.27159 m .73588 1.14687 L .74212 1.37843 L F
0 g
.32449 1.27159 m
.33001 1.05642 L
s
.69055 1.91766 m
.97662 1.84771 L
s
.69055 1.91766 m
.53687 1.86877 L
s
.72999 .92837 m
.73588 1.14687 L
s
.49262 .23592 m
.49163 .43581 L
s
.49163 .43581 m
.21214 .53779 L
s
.21598 .86649 m .57389 .74539 L .65363 .83885 L .656 .751 .92 r
F
0 g
.65363 .83885 m
.72999 .92837 L
s
.20289 .7479 m .57389 .74539 L .21598 .86649 L .656 .751 .92 r
F
0 g
.21598 .86649 m
.26064 .96815 L
s
.53687 1.86877 m
.90401 1.7765 L
s
.53687 1.86877 m
.41242 1.80953 L
s
.90401 1.7765 m
.97662 1.84771 L
s
.31864 1.49918 m .74874 1.62422 L .31245 1.7403 L .544 .324 .532 r
F
.31864 1.49918 m .74212 1.37843 L .74874 1.62422 L F
0 g
.31864 1.49918 m
.32449 1.27159 L
s
.31245 1.7403 m
.31864 1.49918 L
s
.73588 1.14687 m
.74212 1.37843 L
s
.41242 1.80953 m
.82813 1.70208 L
s
.31245 1.7403 m
.41242 1.80953 L
s
.20289 .7479 m .49057 .64771 L .57389 .74539 L .656 .751 .92 r
F
0 g
.20289 .7479 m
.49057 .64771 L
s
.19307 .97074 m
.20289 .7479 L
s
.49057 .64771 m
.49163 .43581 L
s
.57389 .74539 m
.65363 .83885 L
s
.20289 .7479 m
.21214 .53779 L
s
.20289 .7479 m
.21598 .86649 L
s
.49057 .64771 m
.57389 .74539 L
s
.82813 1.70208 m
.90401 1.7765 L
s
.31245 1.7403 m
.74874 1.62422 L
s
.23633 1.66035 m
.31245 1.7403 L
s
.74212 1.37843 m
.74874 1.62422 L
s
.48944 .87276 m
.49057 .64771 L
s
.74874 1.62422 m
.82813 1.70208 L
s
.18265 1.20749 m
.19307 .97074 L
s
.19307 .97074 m
.48944 .87276 L
s
.23633 1.66035 m
.6656 1.54269 L
s
.23633 1.66035 m
.18682 1.5679 L
s
.6656 1.54269 m
.74874 1.62422 L
s
.48944 .87276 m
.48824 1.11221 L
s
.17155 1.45951 m
.18265 1.20749 L
s
.18265 1.20749 m
.48824 1.11221 L
s
.18682 1.5679 m
.57845 1.45721 L
s
.18682 1.5679 m
.17155 1.45951 L
s
.57845 1.45721 m
.6656 1.54269 L
s
.48824 1.11221 m
.48697 1.36749 L
s
.48697 1.36749 m
.17155 1.45951 L
s
.48697 1.36749 m
.57845 1.45721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.119739 0.253695 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.371077 1.84033 1.11022e-16 1.84033 [
[.5 1.79462 -38.5625 0 ]
[.5 1.79462 38.5625 12 ]
[ 0 0 0 0 ]
[ 1 1.78212 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.79462 -99.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PlanoConvexLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.78212 L
0 1.78212 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.78441 .94084 m
.74354 .80694 L
s
.74354 .80694 m
.85947 .76923 L
s
.74354 .80694 m
.69158 .67888 L
s
.81231 1.07454 m
.78441 .94084 L
s
.78441 .94084 m
.90096 .90463 L
s
.69158 .67888 m
.80769 .63943 L
s
.69158 .67888 m
.63072 .56269 L
s
.81231 1.07454 m
.93025 1.03957 L
s
.85947 .76923 m
.90096 .90463 L
s
.80769 .63943 m
.85947 .76923 L
s
.90096 .90463 m
.93025 1.03957 L
s
.74779 .5213 m
.80769 .63943 L
s
.63072 .56269 m
.74779 .5213 L
s
.65752 1.13775 m .94566 1.16777 L .82559 1.20181 L .656 .751 .92 r
F
0 g
.82287 1.31601 m
.82559 1.20181 L
s
.81231 1.07454 m
.82068 1.15475 L
s
.65752 1.13775 m .86694 1.07601 L .94566 1.16777 L .656 .751 .92 r
F
0 g
.94566 1.16777 m
.94573 1.28256 L
s
.93025 1.03957 m
.94566 1.16777 L
s
.82559 1.20181 m
.94566 1.16777 L
s
.56353 .46451 m .68585 .56396 L .47802 .63701 L .544 .324 .532 r
F
.56353 .46451 m .6823 .42104 L .68585 .56396 L F
0 g
.6823 .42104 m
.74779 .5213 L
s
.56353 .46451 m
.6823 .42104 L
s
.49312 .39063 m
.56353 .46451 L
s
.52033 1.05891 m .86694 1.07601 L .65752 1.13775 L .656 .751 .92 r
F
0 g
.65752 1.13775 m
.82559 1.20181 L
s
.80317 1.41009 m
.82287 1.31601 L
s
.82287 1.31601 m
.94573 1.28256 L
s
.61429 .34505 m
.6823 .42104 L
s
.47802 .63701 m .68959 .7147 L .4279 .80269 L .544 .324 .532 r
F
.47802 .63701 m .68585 .56396 L .68959 .7147 L F
0 g
.47802 .63701 m
.56353 .46451 L
s
.6823 .42104 m
.68585 .56396 L
s
.94573 1.28256 m
.92936 1.37683 L
s
.49312 .39063 m
.61429 .34505 L
s
.49312 .39063 m
.42327 .3473 L
s
.52033 1.05891 m .78307 .97827 L .86694 1.07601 L .656 .751 .92 r
F
0 g
.86694 1.07601 m
.94566 1.16777 L
s
.40876 .9651 m .78307 .97827 L .52033 1.05891 L .656 .751 .92 r
F
0 g
.52033 1.05891 m
.65752 1.13775 L
s
.76618 1.47671 m
.80317 1.41009 L
s
.80317 1.41009 m
.92936 1.37683 L
s
.4279 .80269 m .69355 .87392 L .40876 .9651 L .544 .324 .532 r
F
.4279 .80269 m .68959 .7147 L .69355 .87392 L F
0 g
.4279 .80269 m
.47802 .63701 L
s
.68585 .56396 m
.68959 .7147 L
s
.54745 .2997 m
.61429 .34505 L
s
.92936 1.37683 m
.89608 1.44321 L
s
.42327 .3473 m
.54745 .2997 L
s
.42327 .3473 m
.35848 .34022 L
s
.40876 .9651 m .69355 .87392 L .78307 .97827 L .656 .751 .92 r
F
0 g
.78307 .97827 m
.86694 1.07601 L
s
.40876 .9651 m .69773 1.04236 L .42108 1.12622 L .544 .324 .532 r
F
.40876 .9651 m .69355 .87392 L .69773 1.04236 L F
.32234 .85442 m .69355 .87392 L .40876 .9651 L .656 .751 .92 r
F
0 g
.42119 .85962 m
.4279 .80269 L
s
.71261 1.50876 m
.76618 1.47671 L
s
.76618 1.47671 m
.89608 1.44321 L
s
.48612 .29088 m
.54745 .2997 L
s
.89608 1.44321 m
.84636 1.47451 L
s
.35848 .34022 m
.30386 .37367 L
s
.48612 .29088 m
.35848 .34022 L
s
.32234 .85442 m .59776 .76228 L .69355 .87392 L .656 .751 .92 r
F
0 g
.68959 .7147 m
.69355 .87392 L
s
.69355 .87392 m
.78307 .97827 L
s
.42108 1.12622 m .70216 1.22084 L .46975 1.28711 L .544 .324 .532 r
F
.42108 1.12622 m .69773 1.04236 L .70216 1.22084 L F
0 g
.40876 .9651 m
.42108 1.12622 L
s
.69355 .87392 m
.69773 1.04236 L
s
.26477 .72322 m .59776 .76228 L .32234 .85442 L .656 .751 .92 r
F
0 g
.32234 .85442 m
.40876 .9651 L
s
.64462 1.50027 m
.71261 1.50876 L
s
.71261 1.50876 m
.84636 1.47451 L
s
.43525 .32305 m
.48612 .29088 L
s
.84636 1.47451 m
.78208 1.46472 L
s
.30386 .37367 m
.43525 .32305 L
s
.30386 .37367 m
.26473 .4493 L
s
.26477 .72322 m .49505 .64256 L .59776 .76228 L .656 .751 .92 r
F
0 g
.59776 .76228 m
.69355 .87392 L
s
.46975 1.28711 m .70686 1.41028 L .56615 1.44772 L .544 .324 .532 r
F
.46975 1.28711 m .70216 1.22084 L .70686 1.41028 L F
0 g
.42108 1.12622 m
.46975 1.28711 L
s
.69773 1.04236 m
.70216 1.22084 L
s
.46975 1.28711 m
.56615 1.44772 L
s
.56615 1.44772 m
.64462 1.50027 L
s
.64462 1.50027 m
.78208 1.46472 L
s
.24592 .56483 m .49505 .64256 L .26477 .72322 L .656 .751 .92 r
F
0 g
.26477 .72322 m
.32234 .85442 L
s
.39989 .39807 m
.43525 .32305 L
s
.70686 1.41028 m
.78208 1.46472 L
s
.70216 1.22084 m
.70686 1.41028 L
s
.39989 .39807 m
.26473 .4493 L
s
.24592 .56483 m .38461 .51384 L .49505 .64256 L .656 .751 .92 r
F
0 g
.38461 .51384 m
.49505 .64256 L
s
.24592 .56483 m
.26473 .4493 L
s
.49505 .64256 m
.59776 .76228 L
s
.24592 .56483 m
.26477 .72322 L
s
.56615 1.44772 m
.70686 1.41028 L
s
.48304 1.35151 m
.56615 1.44772 L
s
.38461 .51384 m
.39989 .39807 L
s
.62621 1.31169 m
.70686 1.41028 L
s
.24592 .56483 m
.38461 .51384 L
s
.24592 .56483 m
.25083 .71308 L
s
.40259 1.21718 m
.48304 1.35151 L
s
.48304 1.35151 m
.62621 1.31169 L
s
.38461 .51384 m
.39249 .66323 L
s
.25083 .71308 m
.39249 .66323 L
s
.25083 .71308 m
.28043 .88193 L
s
.62621 1.31169 m
.54717 1.17462 L
s
.33268 1.05561 m
.40259 1.21718 L
s
.40259 1.21718 m
.54717 1.17462 L
s
.28043 .88193 m
.4242 .83403 L
s
.28043 .88193 m
.33268 1.05561 L
s
.33268 1.05561 m
.47747 1.01025 L
s
.4242 .83403 m
.39249 .66323 L
s
.54717 1.17462 m
.47747 1.01025 L
s
.47747 1.01025 m
.4242 .83403 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.119739 0.374111 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.5 1.098 -59.25 0 ]
[.5 1.098 59.25 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -120.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PolarizingBeamSplitterCube) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.66497 .02988 m .42216 .58164 L .40598 1.06315 L 0 0 .346 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.536 .54442 m
.91022 .42206 L
s
.97657 .93008 m
.91022 .42206 L
s
.66497 .02988 m .40598 1.06315 L .6952 .58531 L 0 0 .346 r
F
0 g
.40598 1.06315 m
.6952 .58531 L
s
.66497 .02988 m
.91022 .42206 L
s
.10855 .26104 m
.42216 .58164 L
s
.40598 1.06315 m
.42216 .58164 L
s
.42216 .58164 m
.66497 .02988 L
s
.02877 .79167 m
.40598 1.06315 L
s
.40598 1.06315 m
.97657 .93008 L
s
.10855 .26104 m
.66497 .02988 L
s
.02877 .79167 m
.10855 .26104 L
s
.6952 .58531 m
.97657 .93008 L
s
.66497 .02988 m
.6952 .58531 L
s
.02877 .79167 m
.6952 .58531 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.119739 0.494527 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0539155 1.18619 0 1.18619 [
[.5 1.09884 -24.6562 0 ]
[.5 1.09884 24.6562 12 ]
[ 0 0 0 0 ]
[ 1 1.08634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.09884 -85.6562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PorroPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.08634 L
0 1.08634 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.51679 .72602 m
.52903 .76464 L
s
.56015 .65764 m .55032 .75877 L .54791 .79672 L 0 0 .208 r
F
.56015 .65764 m .55275 .72844 L .55032 .75877 L F
.56015 .65764 m .55032 .75877 L .55275 .72844 L .796 .544 .556 r
F
.56015 .65764 m .54791 .79672 L .55032 .75877 L F
.56015 .65764 m .54791 .79672 L .54555 .87192 L 0 0 .208 r
F
.56015 .65764 m .54555 .87192 L .54791 .79672 L .796 .544 .556 r
F
.56015 .65764 m .55519 .70227 L .55275 .72844 L 0 0 .208 r
F
.56015 .65764 m .55275 .72844 L .55519 .70227 L .796 .544 .556 r
F
.56015 .65764 m .55766 .6789 L .55519 .70227 L 0 0 .208 r
F
.56015 .65764 m .55519 .70227 L .55766 .6789 L .796 .544 .556 r
F
.56015 .65764 m .52909 .76511 L .54555 .87192 L F
0 g
.52903 .76464 m
.52908 .76487 L
s
.52908 .76487 m
.52911 .76503 L
s
.56015 .65764 m .5127 .71526 L .52909 .76511 L .796 .544 .556 r
F
.56015 .65764 m .49619 .67754 L .5127 .71526 L F
0 g
.50803 .70452 m
.51409 .7194 L
s
.5127 .71526 m
.52909 .76511 L
s
.56015 .65764 m .47949 .64704 L .49619 .67754 L .796 .544 .556 r
F
0 g
.49027 .66667 m
.49855 .68286 L
s
.49619 .67754 m
.5127 .71526 L
s
.56015 .65764 m .57472 .75148 L .57106 .72291 L 0 0 .208 r
F
.56015 .65764 m .57844 .78774 L .57472 .75148 L F
.56015 .65764 m .57472 .75148 L .57844 .78774 L .969 .732 .3 r
F
.56015 .65764 m .57106 .72291 L .57472 .75148 L F
.56015 .65764 m .56742 .69854 L .57106 .72291 L F
.56015 .65764 m .57106 .72291 L .56742 .69854 L 0 0 .208 r
F
0 g
.57106 .72291 m
.57472 .75148 L
s
.54556 .87648 m
.54569 .87893 L
s
.56015 .65764 m .57844 .78774 L .5825 .86141 L .969 .732 .3 r
F
.56015 .65764 m .5825 .86141 L .57844 .78774 L 0 0 .208 r
F
0 g
.57472 .75148 m
.57844 .78774 L
s
.56015 .65764 m .56378 .67701 L .56742 .69854 L .969 .732 .3 r
F
.56015 .65764 m .56742 .69854 L .56378 .67701 L 0 0 .208 r
F
0 g
.56742 .69854 m
.57106 .72291 L
s
.56015 .65764 m .46255 .62195 L .47949 .64704 L .796 .544 .556 r
F
0 g
.47153 .6352 m
.48178 .65116 L
s
.47949 .64704 m
.49619 .67754 L
s
.56015 .65764 m .5962 .74507 L .61051 .68537 L .969 .732 .3 r
F
.56015 .65764 m .5825 .86141 L .5962 .74507 L F
0 g
.5964 .74452 m
.59844 .73569 L
s
.59624 .74545 m
.59631 .74504 L
s
.59597 .74699 m
.59624 .74545 L
s
.59631 .74504 m
.5964 .74452 L
s
.56015 .65764 m .59627 .61017 L .5781 .63325 L .969 .732 .3 r
F
.56015 .65764 m .61467 .58825 L .59627 .61017 L F
.56015 .65764 m .63332 .56737 L .61467 .58825 L F
.56015 .65764 m .65225 .54746 L .63332 .56737 L F
.54756 .40731 m .67146 .52862 L .44532 .60164 L .665 .739 .905 r
F
.54756 .40731 m .76925 .34791 L .67146 .52862 L F
.76925 .34791 m .76937 .34788 L .76931 .34798 L F
.76925 .34791 m .76931 .34798 L .67146 .52862 L F
.74916 .32109 m .76925 .34782 L .76926 .34791 L .976 .68 .389 r
F
.74916 .32109 m .76926 .34791 L .74917 .32119 L F
.76925 .34791 m .74927 .32114 L .76937 .34788 L .665 .739 .905 r
F
.54756 .40731 m .74917 .32119 L .76925 .34791 L F
.74917 .32119 m .74927 .32114 L .76925 .34791 L F
.74916 .32109 m .74917 .32119 L .74916 .32118 L .976 .68 .389 r
F
.54756 .40731 m .44628 .26127 L .74927 .32114 L .665 .739 .905 r
F
.56015 .65764 m .57632 .86317 L .5825 .86141 L 0 0 .208 r
F
.56015 .65764 m .57015 .86492 L .57632 .86317 L F
.56015 .65764 m .56398 .86668 L .57015 .86492 L F
.56015 .65764 m .55783 .86843 L .56398 .86668 L F
.56015 .65764 m .55168 .87017 L .55783 .86843 L F
.56015 .65764 m .54555 .87192 L .55168 .87017 L F
.56154 .97324 m .5796 .93214 L .58262 .87531 L .969 .732 .3 r
F
.56154 .97324 m .58262 .87531 L .5796 .93214 L 0 0 .208 r
F
.56154 .97324 m .57619 .95125 L .5796 .93214 L .969 .732 .3 r
F
.56154 .97324 m .5796 .93214 L .57619 .95125 L 0 0 .208 r
F
.56154 .97324 m .57619 .95125 L .57264 .96236 L F
.56154 .97324 m .57264 .96236 L .57619 .95125 L .969 .732 .3 r
F
.56154 .97324 m .56901 .96894 L .57264 .96236 L F
.56154 .97324 m .57264 .96236 L .56901 .96894 L 0 0 .208 r
F
.56154 .97324 m .58262 .87531 L .59855 .94514 L .969 .732 .3 r
F
.56154 .97324 m .56901 .96894 L .56531 .97233 L 0 0 .208 r
F
.56154 .97324 m .56531 .97233 L .56901 .96894 L .969 .732 .3 r
F
.56154 .97324 m .59855 .94514 L .61456 .95658 L F
.56154 .97324 m .68213 .90128 L .64038 .9128 L .295 .146 .503 r
F
.56154 .97324 m .66474 .92561 L .68213 .90128 L .969 .732 .3 r
F
.56154 .97324 m .66126 .91756 L .68213 .90128 L .295 .146 .503 r
F
.56154 .97324 m .68213 .90128 L .66126 .91756 L .969 .732 .3 r
F
.54827 .78881 m .78922 .73336 L .68213 .90138 L .643 .765 .937 r
F
.78922 .73336 m .78935 .73333 L .78928 .73343 L F
.78922 .73336 m .78928 .73343 L .68213 .90138 L F
.74916 .32118 m .78922 .73336 L .76758 .70835 L .976 .68 .389 r
F
.74917 .32119 m .78922 .73336 L .74916 .32118 L F
.74917 .32119 m .76926 .34791 L .78923 .73347 L F
.78922 .73336 m .7677 .70831 L .78935 .73333 L .643 .765 .937 r
F
.54827 .78881 m .76759 .70835 L .78922 .73336 L F
.76759 .70835 m .7677 .70831 L .78922 .73336 L F
.56015 .65764 m .61051 .68537 L .62516 .63742 L .969 .732 .3 r
F
.31923 .46965 m .34217 .49362 L .34217 .4937 L .952 .687 .497 r
F
.20463 .34998 m .44532 .60164 L .20446 .34995 L .665 .739 .905 r
F
.44537 .60155 m .44532 .60164 L .20463 .34998 L F
.18249 .61869 m .17562 .73534 L .15251 .71166 L .728 .633 .071 r
F
.18249 .61869 m .17643 .72034 L .17562 .73534 L F
.18249 .61869 m .17562 .73534 L .17643 .72034 L .698 .437 .526 r
F
.18249 .61869 m .21813 .72188 L .17562 .73534 L F
.17562 .7353 m .43798 .96875 L .17543 .73527 L .643 .765 .937 r
F
.31923 .46974 m .34217 .4937 L .32605 .86907 L .952 .687 .497 r
F
.31923 .46974 m .32605 .86907 L .32604 .86907 L F
.56154 .97324 m .55609 .97244 L .55342 .96759 L 0 0 .208 r
F
.56154 .97324 m .55342 .96759 L .55609 .97244 L .796 .544 .556 r
F
.56154 .97324 m .5588 .9741 L .55609 .97244 L 0 0 .208 r
F
.56154 .97324 m .55609 .97244 L .5588 .9741 L .796 .544 .556 r
F
.56154 .97324 m .51121 .98462 L .52868 .96424 L F
.56154 .97324 m .43797 .96865 L .45668 .9825 L F
.56154 .97324 m .43797 .96865 L .45885 .97314 L .295 .146 .503 r
F
.56154 .97324 m .47763 .95771 L .43797 .96865 L F
.56154 .97324 m .45885 .97314 L .43797 .96865 L .796 .544 .556 r
F
.43804 .96866 m .43798 .96875 L .17562 .7353 L .643 .765 .937 r
F
.31923 .46965 m .32604 .86917 L .30105 .84695 L .952 .687 .497 r
F
.54827 .78881 m .43804 .96866 L .17562 .7353 L .643 .765 .937 r
F
.32604 .86907 m .32605 .86907 L .32604 .86917 L .952 .687 .497 r
F
.31923 .46965 m .34217 .4937 L .31923 .46974 L F
.54756 .40731 m .44537 .60155 L .20463 .34998 L .665 .739 .905 r
F
.18249 .61869 m .43813 .6522 L .39311 .66646 L .698 .437 .526 r
F
.18249 .61869 m .43813 .6522 L .39526 .6506 L .885 .611 .516 r
F
.18249 .61869 m .37866 .6391 L .43813 .6522 L F
.18249 .61869 m .39526 .6506 L .43813 .6522 L .698 .437 .526 r
F
.54827 .78881 m .43794 .65212 L .7677 .70831 L .643 .765 .937 r
F
.76758 .70835 m .78923 .73347 L .76759 .70845 L .976 .68 .389 r
F
.78922 .73336 m .78923 .73347 L .76758 .70835 L F
.56015 .65764 m .67146 .5285 L .65225 .54746 L .969 .732 .3 r
F
.56015 .65764 m .6556 .56025 L .67146 .5285 L F
.56015 .65764 m .64018 .59631 L .6556 .56025 L F
.56015 .65764 m .62516 .63742 L .64018 .59631 L F
0 g
.5825 .86141 m
.58719 .82154 L
s
.54525 .87061 m
.54556 .87648 L
s
.54519 .86941 m
.54525 .87061 L
s
.52909 .76511 m
.53239 .78653 L
s
.53586 .80906 m
.54555 .87192 L
s
.56015 .65764 m .44531 .60153 L .46255 .62195 L .796 .544 .556 r
F
.56015 .65764 m .46464 .60775 L .44531 .60153 L F
.56015 .65764 m .48387 .61513 L .46464 .60775 L F
.56015 .65764 m .50302 .62372 L .48387 .61513 L F
.56015 .65764 m .52211 .63358 L .50302 .62372 L F
.56015 .65764 m .54114 .64483 L .52211 .63358 L F
.56015 .65764 m .52211 .63358 L .54114 .64483 L .295 .146 .503 r
F
.56015 .65764 m .50302 .62372 L .52211 .63358 L F
.56015 .65764 m .48387 .61513 L .50302 .62372 L F
.56015 .65764 m .46464 .60775 L .48387 .61513 L F
.56015 .65764 m .44531 .60153 L .46464 .60775 L F
.56015 .65764 m .48211 .58965 L .44531 .60153 L F
0 g
.46255 .62195 m
.47949 .64704 L
s
.56015 .65764 m .51926 .57765 L .48211 .58965 L .295 .146 .503 r
F
.56015 .65764 m .55676 .56554 L .51926 .57765 L F
.56015 .65764 m .59463 .55332 L .55676 .56554 L F
.56015 .65764 m .63286 .54097 L .59463 .55332 L F
.56015 .65764 m .65225 .54746 L .67146 .5285 L F
.56015 .65764 m .63332 .56737 L .65225 .54746 L F
.56015 .65764 m .61467 .58825 L .63332 .56737 L F
.56015 .65764 m .59627 .61017 L .61467 .58825 L F
.56015 .65764 m .5781 .63325 L .59627 .61017 L F
.56015 .65764 m .67146 .5285 L .63286 .54097 L F
0 g
.54555 .87192 m
.55168 .87017 L
s
.54555 .87192 m
.54555 .87192 L
s
.61187 .68176 m
.61475 .67174 L
s
.61475 .67174 m
.61592 .66765 L
s
.58263 .86846 m
.583 .85808 L
s
.583 .85808 m
.58305 .85674 L
s
.55168 .87017 m
.55783 .86843 L
s
.44919 .60608 m
.46382 .62379 L
s
.61162 .68172 m
.62516 .63742 L
s
.55783 .86843 m
.56398 .86668 L
s
.44531 .60153 m
.46255 .62195 L
s
.56398 .86668 m
.57015 .86492 L
s
.56154 .97324 m .54557 .88578 L .55172 .88404 L 0 0 .208 r
F
.56154 .97324 m .54817 .9408 L .54557 .88578 L F
0 g
.54557 .88114 m
.54569 .87893 L
s
.56154 .97324 m .54557 .88578 L .54817 .9408 L .796 .544 .556 r
F
.56154 .97324 m .55078 .9582 L .54817 .9408 L 0 0 .208 r
F
.56154 .97324 m .54817 .9408 L .55078 .9582 L .796 .544 .556 r
F
.56154 .97324 m .55342 .96759 L .55078 .9582 L 0 0 .208 r
F
.56154 .97324 m .55078 .9582 L .55342 .96759 L .796 .544 .556 r
F
.56154 .97324 m .52868 .96424 L .54557 .88578 L F
0 g
.54527 .88644 m
.54557 .88114 L
s
.54557 .88578 m
.54557 .88578 L
s
.52868 .96424 m
.54557 .88578 L
s
.54521 .88752 m
.54527 .88644 L
s
.57015 .86492 m
.57632 .86317 L
s
.56154 .97324 m .55172 .88404 L .55788 .8823 L 0 0 .208 r
F
0 g
.54557 .88578 m
.55172 .88404 L
s
.57632 .86317 m
.5825 .86141 L
s
.56154 .97324 m .55788 .8823 L .56405 .88056 L 0 0 .208 r
F
0 g
.55172 .88404 m
.55788 .8823 L
s
.5825 .86141 m
.5825 .86141 L
s
.56154 .97324 m .56405 .88056 L .57023 .87881 L 0 0 .208 r
F
0 g
.55788 .8823 m
.56405 .88056 L
s
.62315 .6442 m
.62671 .63389 L
s
.62671 .63389 m
.63054 .62281 L
s
.63054 .62281 m
.63132 .62055 L
s
.62264 .64567 m
.62315 .6442 L
s
.56154 .97324 m .57023 .87881 L .57642 .87706 L 0 0 .208 r
F
0 g
.56405 .88056 m
.57023 .87881 L
s
.58263 .86846 m
.58317 .87729 L
s
.58317 .87729 m
.58321 .87787 L
s
.56154 .97324 m .57642 .87706 L .58262 .87531 L 0 0 .208 r
F
0 g
.57642 .87706 m
.58262 .87531 L
s
.57023 .87881 m
.57642 .87706 L
s
.58262 .87531 m
.5985 .9449 L
s
.58262 .87531 m
.58262 .87531 L
s
.62516 .63742 m
.64018 .59631 L
s
.34216 .49384 m
.44519 .6015 L
s
.44519 .6015 m
.44524 .60156 L
s
.44524 .60156 m
.44532 .60164 L
s
.44532 .60164 m
.44535 .60163 L
s
.44535 .60163 m
.44539 .60162 L
s
.67144 .52863 m
.67146 .52862 L
s
.67139 .52864 m
.67144 .52863 L
s
.44531 .60153 m
.44531 .60153 L
s
.44531 .60153 m
.48211 .58965 L
s
.48211 .58965 m
.51926 .57765 L
s
.63817 .60189 m
.6475 .57921 L
s
.6379 .60254 m
.63817 .60189 L
s
.6475 .57921 m
.64781 .57845 L
s
.64018 .59631 m
.6556 .56025 L
s
.51926 .57765 m
.55676 .56554 L
s
.55676 .56554 m
.59463 .55332 L
s
.65445 .56294 m
.66795 .53549 L
s
.65444 .56295 m
.65445 .56294 L
s
.59844 .94463 m
.59855 .94487 L
s
.6556 .56025 m
.67146 .5285 L
s
.59463 .55332 m
.63286 .54097 L
s
.52652 .96676 m
.52868 .96424 L
s
.63286 .54097 m
.67146 .5285 L
s
.76931 .34798 m
.76937 .34788 L
s
.67146 .52862 m
.75196 .38001 L
s
.75444 .37544 m
.75444 .37544 L
s
.76927 .34806 m
.76931 .34798 L
s
.76928 .34776 m
.76933 .34768 L
s
.67146 .5285 m
.67146 .5285 L
s
.56154 .97324 m .49335 .99172 L .51121 .98462 L .796 .544 .556 r
F
0 g
.5062 .98661 m
.51272 .98288 L
s
.49944 .99048 m
.50082 .9897 L
s
.51121 .98462 m
.51764 .97712 L
s
.32604 .86917 m
.32605 .86907 L
s
.33083 .75758 m
.33531 .65335 L
s
.33611 .63467 m
.34217 .4937 L
s
.32595 .86909 m
.32595 .86899 L
s
.33074 .75757 m
.33522 .65333 L
s
.33602 .63466 m
.34208 .49362 L
s
.49747 .9906 m
.49944 .99048 L
s
.61314 .95557 m
.61326 .95558 L
s
.56154 .97324 m .47516 .99043 L .49335 .99172 L .796 .544 .556 r
F
0 g
.48066 .99164 m
.48694 .99125 L
s
.55867 .97402 m
.5588 .9741 L
s
.56154 .97324 m .61456 .95658 L .63092 .95444 L .969 .732 .3 r
F
0 g
.61326 .95558 m
.61925 .95595 L
s
.61925 .95595 m
.61932 .95596 L
s
.56531 .97233 m
.56548 .97217 L
s
.60792 .95183 m
.61456 .95658 L
s
.30114 .84703 m
.30114 .84693 L
s
.30562 .75396 m
.30582 .74991 L
s
.30582 .74991 m
.31074 .64778 L
s
.31149 .63211 m
.31931 .46982 L
s
.30105 .84695 m
.30105 .84684 L
s
.30553 .75395 m
.30573 .74985 L
s
.30573 .74985 m
.31065 .64775 L
s
.3114 .6321 m
.31923 .46973 L
s
.47767 .9906 m
.48066 .99164 L
s
.56154 .97324 m .45668 .9825 L .47516 .99043 L .796 .544 .556 r
F
.56154 .97324 m .52086 .97801 L .54128 .97652 L .295 .146 .503 r
F
.56154 .97324 m .50031 .97787 L .52086 .97801 L F
.56154 .97324 m .47963 .97623 L .50031 .97787 L F
.56154 .97324 m .45885 .97314 L .47963 .97623 L F
.56154 .97324 m .51769 .94665 L .47763 .95771 L F
.56154 .97324 m .55816 .93549 L .51769 .94665 L F
.56154 .97324 m .59906 .9242 L .55816 .93549 L F
.56154 .97324 m .64038 .9128 L .59906 .9242 L F
.56154 .97324 m .64069 .93218 L .66126 .91756 L F
.56154 .97324 m .62042 .94514 L .64069 .93218 L F
.56154 .97324 m .64766 .94354 L .66474 .92561 L .969 .732 .3 r
F
.56154 .97324 m .60047 .95637 L .62042 .94514 L .295 .146 .503 r
F
.56154 .97324 m .58084 .96579 L .60047 .95637 L F
.56154 .97324 m .60047 .95637 L .58084 .96579 L .969 .732 .3 r
F
.56154 .97324 m .62042 .94514 L .60047 .95637 L F
.56154 .97324 m .64069 .93218 L .62042 .94514 L F
.56154 .97324 m .66126 .91756 L .64069 .93218 L F
.56154 .97324 m .63092 .95444 L .64766 .94354 L F
0 g
.62419 .95626 m
.62544 .95634 L
s
.45991 .98438 m
.4665 .98669 L
s
.47516 .99043 m
.49335 .99172 L
s
.56154 .97324 m .47963 .97623 L .45885 .97314 L .796 .544 .556 r
F
.56154 .97324 m .50031 .97787 L .47963 .97623 L F
.56154 .97324 m .52086 .97801 L .50031 .97787 L F
.56154 .97324 m .54128 .97652 L .52086 .97801 L F
0 g
.56154 .97324 m
.58084 .96579 L
s
.54128 .97652 m
.56154 .97324 L
s
.56154 .97324 m
.56531 .97233 L
s
.5588 .9741 m
.56154 .97324 L
s
.45668 .9825 m
.47516 .99043 L
s
.63689 .95057 m
.64267 .94766 L
s
.63676 .95064 m
.63689 .95057 L
s
.62544 .95634 m
.62725 .95543 L
s
.52086 .97801 m
.54128 .97652 L
s
.50031 .97787 m
.52086 .97801 L
s
.58084 .96579 m
.60047 .95637 L
s
.43803 .96876 m
.44218 .97172 L
s
.45808 .98308 m
.45991 .98438 L
s
.47963 .97623 m
.50031 .97787 L
s
.45885 .97314 m
.47963 .97623 L
s
.54756 .40731 m .20446 .34995 L .44628 .26127 L .665 .739 .905 r
F
0 g
.43784 .96861 m
.4379 .96867 L
s
.54827 .78881 m .68213 .90138 L .43798 .96875 L .643 .765 .937 r
F
0 g
.6821 .90139 m
.68213 .90138 L
s
.68194 .90144 m
.6821 .90139 L
s
.43798 .96875 m
.43801 .96874 L
s
.43801 .96874 m
.43817 .9687 L
s
.61906 .91879 m
.68194 .90144 L
s
.43817 .9687 m
.61906 .91879 L
s
.4379 .96867 m
.43798 .96875 L
s
.65559 .93522 m
.65575 .93506 L
s
.6454 .94502 m
.64545 .94498 L
s
.64267 .94766 m
.6454 .94502 L
s
.65575 .93506 m
.66178 .92925 L
s
.60047 .95637 m
.62042 .94514 L
s
.43818 .96869 m
.45885 .97314 L
s
.43807 .96872 m
.45668 .9825 L
s
.43801 .96874 m
.43803 .96876 L
s
.63092 .95444 m
.64766 .94354 L
s
.43779 .96855 m
.43801 .96874 L
s
.32595 .86909 m
.43779 .96855 L
s
.64766 .94354 m
.66474 .92561 L
s
.62042 .94514 m
.64069 .93218 L
s
.64069 .93218 m
.65445 .9224 L
s
.65445 .9224 m
.66126 .91756 L
s
.68207 .90143 m
.68209 .9014 L
s
.68156 .90213 m
.68207 .90143 L
s
.67827 .90663 m
.68156 .90213 L
s
.66178 .92925 m
.66346 .92695 L
s
.66346 .92695 m
.66346 .92695 L
s
.66474 .92561 m
.68204 .90141 L
s
.20813 .27996 m .20463 .35002 L .20545 .33537 L .698 .437 .526 r
F
.20813 .27996 m .20545 .33537 L .20463 .35002 L .728 .633 .071 r
F
.20813 .27996 m .20618 .32181 L .20545 .33537 L F
.20813 .27996 m .20545 .33537 L .20618 .32181 L .698 .437 .526 r
F
.20813 .27996 m .20618 .32181 L .20682 .30937 L F
.20813 .27996 m .20682 .30937 L .20618 .32181 L .728 .633 .071 r
F
.20813 .27996 m .20737 .29816 L .20682 .30937 L F
.20813 .27996 m .20682 .30937 L .20737 .29816 L .698 .437 .526 r
F
.20813 .27996 m .20737 .29816 L .20781 .28829 L F
.20813 .27996 m .20781 .28829 L .20737 .29816 L .728 .633 .071 r
F
.20813 .27996 m .24388 .33563 L .20463 .35002 L .698 .437 .526 r
F
0 g
.20455 .35005 m
.31922 .46987 L
s
.20813 .27996 m .20463 .35002 L .1832 .33032 L .728 .633 .071 r
F
0 g
.20446 .34995 m
.20455 .35005 L
s
.20463 .35002 m
.20463 .35002 L
s
.20446 .34995 m
.20448 .34994 L
s
.20448 .34994 m
.20452 .34993 L
s
.78923 .73337 m
.78923 .73347 L
s
.76926 .34791 m
.78922 .73318 L
s
.74916 .32109 m
.74918 .32113 L
s
.74927 .32114 m
.76937 .34788 L
s
.78931 .73323 m
.78931 .73333 L
s
.76933 .34777 m
.78931 .73323 L
s
.76933 .34768 m
.76933 .34777 L
s
.66126 .91756 m
.68192 .90144 L
s
.20813 .27996 m .28355 .32109 L .24388 .33563 L .698 .437 .526 r
F
0 g
.20463 .35002 m
.24388 .33563 L
s
.20813 .27996 m .1832 .33032 L .16095 .31549 L .728 .633 .071 r
F
0 g
.18162 .32923 m
.19994 .34568 L
s
.1832 .33032 m
.20463 .35002 L
s
.76782 .70839 m
.76783 .7085 L
s
.74938 .32123 m
.76782 .70839 L
s
.74938 .32114 m
.74938 .32123 L
s
.74916 .3211 m
.74938 .32114 L
s
.76758 .70835 m
.76759 .70845 L
s
.74916 .32118 m
.76758 .70829 L
s
.74916 .32109 m
.74916 .32112 L
s
.20813 .27996 m .32363 .30639 L .28355 .32109 L .698 .437 .526 r
F
0 g
.24388 .33563 m
.28355 .32109 L
s
.78928 .73343 m
.78935 .73333 L
s
.68213 .90138 m
.78928 .73343 L
s
.78923 .73346 m
.78931 .73333 L
s
.68209 .9014 m
.78923 .73346 L
s
.20813 .27996 m .36414 .29153 L .32363 .30639 L .698 .437 .526 r
F
0 g
.28355 .32109 m
.32363 .30639 L
s
.20813 .27996 m .16095 .31549 L .13771 .30643 L .728 .633 .071 r
F
0 g
.15788 .31427 m
.17156 .32253 L
s
.16095 .31549 m
.1832 .33032 L
s
.20813 .27996 m .40508 .27652 L .36414 .29153 L .698 .437 .526 r
F
0 g
.32363 .30639 m
.36414 .29153 L
s
.30105 .84695 m
.32604 .86917 L
s
.20813 .27996 m .44645 .26135 L .40508 .27652 L .698 .437 .526 r
F
0 g
.36414 .29153 m
.40508 .27652 L
s
.44653 .26132 m
.74927 .32114 L
s
.44703 .26139 m
.74916 .3211 L
s
.44641 .26127 m
.44703 .26139 L
s
.20813 .27996 m .13771 .30643 L .11315 .30516 L .728 .633 .071 r
F
0 g
.13432 .30624 m
.1461 .30967 L
s
.13771 .30643 m
.16095 .31549 L
s
.20813 .27996 m .44645 .26135 L .40708 .26105 L .885 .611 .516 r
F
0 g
.44634 .26126 m
.44641 .26127 L
s
.20813 .27996 m .40708 .26105 L .44645 .26135 L .698 .437 .526 r
F
.20813 .27996 m .40708 .26105 L .36763 .26201 L .885 .611 .516 r
F
.20813 .27996 m .36763 .26201 L .40708 .26105 L .698 .437 .526 r
F
.20813 .27996 m .32805 .26428 L .36763 .26201 L F
.20813 .27996 m .36763 .26201 L .32805 .26428 L .885 .611 .516 r
F
.20813 .27996 m .32805 .26428 L .2883 .26793 L F
.20813 .27996 m .2883 .26793 L .32805 .26428 L .698 .437 .526 r
F
.20813 .27996 m .39175 .25308 L .44645 .26135 L .885 .611 .516 r
F
0 g
.44645 .26135 m
.44645 .26135 L
s
.44475 .26103 m
.44634 .26126 L
s
.44628 .26127 m
.44653 .26132 L
s
.44625 .26128 m
.44628 .26127 L
s
.44618 .26131 m
.44625 .26128 L
s
.40508 .27652 m
.44645 .26135 L
s
.43729 .25996 m
.44475 .26103 L
s
.20813 .27996 m .2883 .26793 L .24835 .2731 L .885 .611 .516 r
F
.20813 .27996 m .24835 .2731 L .2883 .26793 L .698 .437 .526 r
F
0 g
.2883 .26793 m
.2936 .26745 L
s
.20813 .27996 m .33632 .25 L .39175 .25308 L .885 .611 .516 r
F
0 g
.38768 .25285 m
.43454 .25957 L
s
.38229 .25208 m
.38768 .25285 L
s
.39175 .25308 m
.44645 .26135 L
s
.36281 .25146 m
.38229 .25208 L
s
.20813 .27996 m .27991 .25298 L .33632 .25 L .885 .611 .516 r
F
0 g
.32879 .25039 m
.36281 .25146 L
s
.31964 .2501 m
.32879 .25039 L
s
.33632 .25 m
.39175 .25308 L
s
.20813 .27996 m .2221 .26406 L .27991 .25298 L .885 .611 .516 r
F
.20813 .27996 m .11315 .30516 L .08656 .3172 L .728 .633 .071 r
F
.20813 .27996 m .13581 .29541 L .11043 .3082 L .807 .535 .528 r
F
.20813 .27996 m .16043 .28733 L .13581 .29541 L F
.20813 .27996 m .1845 .28243 L .16043 .28733 L F
.20813 .27996 m .16043 .28733 L .1845 .28243 L .728 .633 .071 r
F
.20813 .27996 m .13581 .29541 L .16043 .28733 L F
.20813 .27996 m .11043 .3082 L .13581 .29541 L F
.20813 .27996 m .15631 .28768 L .1379 .29785 L .885 .611 .516 r
F
.20813 .27996 m .17405 .28219 L .15631 .28768 L F
.20813 .27996 m .19129 .27988 L .17405 .28219 L F
.20813 .27996 m .17405 .28219 L .19129 .27988 L .807 .535 .528 r
F
.20813 .27996 m .15631 .28768 L .17405 .28219 L F
.20813 .27996 m .1379 .29785 L .15631 .28768 L F
.20813 .27996 m .1621 .28873 L .2221 .26406 L .885 .611 .516 r
F
.20813 .27996 m .08736 .3791 L .09441 .3765 L .807 .535 .528 r
F
.20813 .27996 m .08032 .38169 L .08736 .3791 L F
.20813 .27996 m .0733 .38428 L .08032 .38169 L F
.20813 .27996 m .06629 .38686 L .0733 .38428 L F
.20813 .27996 m .05929 .38944 L .06629 .38686 L F
.20813 .27996 m .0523 .39202 L .05929 .38944 L F
.20813 .27996 m .08656 .3172 L .0523 .39202 L .728 .633 .071 r
F
.20813 .27996 m .08383 .32953 L .0523 .39202 L .807 .535 .528 r
F
.20813 .27996 m .0523 .39202 L .08383 .32953 L .728 .633 .071 r
F
.20813 .27996 m .11839 .31656 L .09441 .3765 L .885 .611 .516 r
F
.20813 .27996 m .11043 .3082 L .08383 .32953 L .807 .535 .528 r
F
.20813 .27996 m .08383 .32953 L .11043 .3082 L .728 .633 .071 r
F
.20813 .27996 m .1379 .29785 L .11839 .31656 L .885 .611 .516 r
F
.20813 .27996 m .11839 .31656 L .1379 .29785 L .807 .535 .528 r
F
.20813 .27996 m .09441 .3765 L .11839 .31656 L F
.20813 .27996 m .09441 .3765 L .1621 .28873 L .885 .611 .516 r
F
0 g
.10686 .30642 m
.11101 .30614 L
s
.27991 .25298 m
.33632 .25 L
s
.08656 .3172 m
.11315 .30516 L
s
.27189 .25451 m
.30019 .25189 L
s
.26069 .25554 m
.27189 .25451 L
s
.30019 .25189 m
.31964 .2501 L
s
.17405 .28219 m
.17992 .2814 L
s
.08678 .31694 m
.10686 .30642 L
s
.2221 .26406 m
.27991 .25298 L
s
.13581 .29541 m
.15184 .29015 L
s
.15631 .28768 m
.17405 .28219 L
s
.21713 .26609 m
.23877 .26085 L
s
.20765 .26838 m
.21713 .26609 L
s
.23877 .26085 m
.26069 .25554 L
s
.11043 .3082 m
.13581 .29541 L
s
.1621 .28873 m
.2221 .26406 L
s
.1379 .29785 m
.15631 .28768 L
s
.08654 .31722 m
.08668 .31706 L
s
.08668 .31706 m
.08678 .31694 L
s
.07031 .33636 m
.08654 .31722 L
s
.0523 .39202 m
.08656 .3172 L
s
.16262 .28835 m
.20765 .26838 L
s
.18249 .61869 m .26112 .70826 L .21813 .72188 L .698 .437 .526 r
F
.18249 .61869 m .30461 .69449 L .26112 .70826 L F
.18249 .61869 m .34861 .68055 L .30461 .69449 L F
.18249 .61869 m .39311 .66646 L .34861 .68055 L F
.54827 .78881 m .17543 .73527 L .43794 .65212 L .643 .765 .937 r
F
0 g
.17564 .73543 m
.30114 .84703 L
s
.17543 .73527 m
.17561 .73543 L
s
.17561 .73543 m
.43784 .96861 L
s
.08383 .32953 m
.11043 .3082 L
s
.11839 .31656 m
.1379 .29785 L
s
.16189 .2889 m
.16221 .28866 L
s
.12754 .31489 m
.16189 .2889 L
s
.16221 .28866 m
.16262 .28835 L
s
.09441 .3765 m
.1621 .28873 L
s
.05828 .36417 m
.07031 .33636 L
s
.0523 .39202 m
.08383 .32953 L
s
.09441 .3765 m
.11839 .31656 L
s
.10406 .34714 m
.12754 .31489 L
s
.05317 .39025 m
.05828 .36417 L
s
.05136 .39946 m
.05183 .39708 L
s
.05183 .39708 m
.05286 .39181 L
s
.17562 .7353 m
.17562 .7353 L
s
.17561 .7354 m
.17564 .73543 L
s
.17494 .7347 m
.17561 .7354 L
s
.17056 .7301 m
.17494 .7347 L
s
.43773 .65219 m
.43791 .65214 L
s
.43791 .65214 m
.43794 .65212 L
s
.17546 .73526 m
.17562 .73521 L
s
.17543 .73527 m
.17546 .73526 L
s
.7677 .70831 m
.78935 .73333 L
s
.76759 .70845 m
.78923 .73347 L
s
.09588 .37557 m
.09638 .37381 L
s
.09638 .37381 m
.10406 .34714 L
s
.09346 .38398 m
.09588 .37557 L
s
.18249 .61869 m .17738 .70368 L .17643 .72034 L .728 .633 .071 r
F
.18249 .61869 m .17643 .72034 L .17738 .70368 L .698 .437 .526 r
F
0 g
.17562 .73521 m
.17643 .72034 L
s
.0523 .39202 m
.05929 .38944 L
s
.0523 .39202 m
.0523 .39202 L
s
.05929 .38944 m
.06629 .38686 L
s
.18249 .61869 m .15251 .71166 L .12955 .68144 L .728 .633 .071 r
F
0 g
.17643 .72034 m
.17674 .71487 L
s
.24 .71482 m
.43773 .65219 L
s
.17562 .73521 m
.24 .71482 L
s
.14858 .70703 m
.15088 .70944 L
s
.15251 .71166 m
.17552 .73524 L
s
.06629 .38686 m
.0733 .38428 L
s
.14049 .69577 m
.14858 .70703 L
s
.0733 .38428 m
.08032 .38169 L
s
.18249 .61869 m .05065 .40724 L .05766 .40467 L .807 .535 .528 r
F
0 g
.05111 .40707 m
.05136 .39946 L
s
.18249 .61869 m .06429 .53421 L .05065 .40724 L .728 .633 .071 r
F
.18249 .61869 m .0676 .48712 L .05065 .40724 L .807 .535 .528 r
F
.18249 .61869 m .05065 .40724 L .0676 .48712 L .728 .633 .071 r
F
0 g
.05065 .40724 m
.05065 .40724 L
s
.05001 .44086 m
.05101 .41012 L
s
.08032 .38169 m
.08736 .3791 L
s
.43808 .65232 m
.43875 .65243 L
s
.76759 .70846 m
.76783 .7085 L
s
.43875 .65243 m
.76759 .70846 L
s
.43794 .65212 m
.43822 .65217 L
s
.43822 .65217 m
.7677 .70831 L
s
.18249 .61869 m .05766 .40467 L .06468 .4021 L .807 .535 .528 r
F
0 g
.05065 .40724 m
.05766 .40467 L
s
.18249 .61869 m .17844 .6853 L .17738 .70368 L .728 .633 .071 r
F
.18249 .61869 m .17738 .70368 L .17844 .6853 L .698 .437 .526 r
F
0 g
.17674 .71487 m
.17738 .70368 L
s
.08736 .3791 m
.09441 .3765 L
s
.18249 .61869 m .06468 .4021 L .07171 .39952 L .807 .535 .528 r
F
0 g
.05766 .40467 m
.06468 .4021 L
s
.09441 .3765 m
.09441 .3765 L
s
.18249 .61869 m .07171 .39952 L .07876 .39694 L .807 .535 .528 r
F
0 g
.06468 .4021 m
.07171 .39952 L
s
.18249 .61869 m .07876 .39694 L .08582 .39435 L .807 .535 .528 r
F
0 g
.07171 .39952 m
.07876 .39694 L
s
.18249 .61869 m .12955 .68144 L .10692 .64377 L .728 .633 .071 r
F
0 g
.12278 .67112 m
.12655 .67637 L
s
.12955 .68144 m
.15251 .71166 L
s
.18249 .61869 m .08582 .39435 L .09289 .39175 L .807 .535 .528 r
F
0 g
.07876 .39694 m
.08582 .39435 L
s
.18249 .61869 m .09289 .39175 L .14335 .50664 L .885 .611 .516 r
F
.18249 .61869 m .10332 .47444 L .09289 .39175 L F
.18249 .61869 m .09289 .39175 L .10332 .47444 L .807 .535 .528 r
F
0 g
.09289 .39175 m
.09289 .39175 L
s
.09429 .39489 m
.09652 .42402 L
s
.09415 .393 m
.09429 .39489 L
s
.09346 .38398 m
.09415 .393 L
s
.08582 .39435 m
.09289 .39175 L
s
.05001 .44086 m
.0544 .48664 L
s
.18249 .61869 m .17964 .66512 L .17844 .6853 L .728 .633 .071 r
F
.18249 .61869 m .17844 .6853 L .17964 .66512 L .698 .437 .526 r
F
0 g
.17738 .70368 m
.17844 .6853 L
s
.11507 .65726 m
.12278 .67112 L
s
.18249 .61869 m .10692 .64377 L .08492 .59655 L .728 .633 .071 r
F
0 g
.09944 .62917 m
.10387 .63712 L
s
.10692 .64377 m
.12955 .68144 L
s
.18249 .61869 m .18099 .64298 L .17964 .66512 L .728 .633 .071 r
F
.18249 .61869 m .17964 .66512 L .18099 .64298 L .698 .437 .526 r
F
0 g
.17844 .6853 m
.17964 .66512 L
s
.17964 .66512 m
.18099 .64298 L
s
.09125 .61003 m
.09944 .62917 L
s
.09652 .42402 m
.11346 .46564 L
s
.18249 .61869 m .08926 .5255 L .0676 .48712 L .807 .535 .528 r
F
.18249 .61869 m .0676 .48712 L .08926 .5255 L .728 .633 .071 r
F
0 g
.05065 .40724 m
.0676 .48712 L
s
.18249 .61869 m .08492 .59655 L .06429 .53421 L .728 .633 .071 r
F
0 g
.06429 .53421 m
.08492 .59655 L
s
.07968 .58302 m
.08325 .59135 L
s
.08492 .59655 m
.10692 .64377 L
s
.06437 .53448 m
.06443 .53476 L
s
.06429 .53406 m
.06437 .53448 L
s
.0544 .48664 m
.06429 .53406 L
s
.05065 .40724 m
.06429 .53421 L
s
.06443 .53476 m
.07968 .58302 L
s
.18249 .61869 m .11194 .55502 L .08926 .5255 L .807 .535 .528 r
F
.18249 .61869 m .08926 .5255 L .11194 .55502 L .728 .633 .071 r
F
0 g
.0676 .48712 m
.08926 .5255 L
s
.18249 .61869 m .11801 .51548 L .10332 .47444 L .885 .611 .516 r
F
.18249 .61869 m .10332 .47444 L .11801 .51548 L .807 .535 .528 r
F
0 g
.09289 .39175 m
.10332 .47444 L
s
.11346 .46564 m
.14318 .50621 L
s
.18249 .61869 m .13516 .5795 L .11194 .55502 L .807 .535 .528 r
F
.18249 .61869 m .11194 .55502 L .13516 .5795 L .728 .633 .071 r
F
0 g
.08926 .5255 m
.11194 .55502 L
s
.18249 .61869 m .26709 .63662 L .22467 .62862 L .885 .611 .516 r
F
.18249 .61869 m .3097 .64287 L .26709 .63662 L F
.18249 .61869 m .35244 .64751 L .3097 .64287 L F
.18249 .61869 m .39526 .6506 L .35244 .64751 L F
.18249 .61869 m .31905 .61969 L .37866 .6391 L F
.18249 .61869 m .25962 .59308 L .31905 .61969 L F
.18249 .61869 m .20077 .55724 L .25962 .59308 L F
.18249 .61869 m .14335 .50664 L .20077 .55724 L F
0 g
.14346 .50659 m
.14382 .50708 L
s
.14318 .50621 m
.14346 .50659 L
s
.09289 .39175 m
.14335 .50664 L
s
.18249 .61869 m .1336 .54758 L .11801 .51548 L .885 .611 .516 r
F
.18249 .61869 m .14964 .57459 L .1336 .54758 L F
.18249 .61869 m .16598 .59803 L .14964 .57459 L F
.18249 .61869 m .14964 .57459 L .16598 .59803 L .807 .535 .528 r
F
.18249 .61869 m .1336 .54758 L .14964 .57459 L F
.18249 .61869 m .11801 .51548 L .1336 .54758 L F
0 g
.10332 .47444 m
.11801 .51548 L
s
.18249 .61869 m .15872 .60046 L .13516 .5795 L .807 .535 .528 r
F
.18249 .61869 m .13516 .5795 L .15872 .60046 L .728 .633 .071 r
F
0 g
.11194 .55502 m
.13516 .5795 L
s
.18249 .61869 m .35244 .64751 L .39526 .6506 L .698 .437 .526 r
F
.18249 .61869 m .3097 .64287 L .35244 .64751 L F
.18249 .61869 m .26709 .63662 L .3097 .64287 L F
.18249 .61869 m .22467 .62862 L .26709 .63662 L F
0 g
.18099 .64298 m
.18249 .61869 L
s
.18249 .61869 m
.22467 .62862 L
s
.16598 .59803 m
.18249 .61869 L
s
.15872 .60046 m
.18249 .61869 L
s
.13516 .5795 m
.15872 .60046 L
s
.11801 .51548 m
.1336 .54758 L
s
.14964 .57459 m
.16598 .59803 L
s
.22467 .62862 m
.26709 .63662 L
s
.1336 .54758 m
.14964 .57459 L
s
.26709 .63662 m
.3097 .64287 L
s
.3097 .64287 m
.35244 .64751 L
s
.37866 .6391 m
.43788 .65214 L
s
.39526 .6506 m
.43775 .65219 L
s
.43627 .6519 m
.438 .6523 L
s
.42517 .64935 m
.43627 .6519 L
s
.36841 .63632 m
.37426 .63766 L
s
.37426 .63766 m
.42419 .64913 L
s
.438 .6523 m
.43808 .65232 L
s
.35244 .64751 m
.39526 .6506 L
s
.14335 .50664 m
.20077 .55724 L
s
.14382 .50708 m
.18651 .54655 L
s
.31905 .61969 m
.37866 .6391 L
s
.34749 .62894 m
.36841 .63632 L
s
.30132 .61264 m
.31107 .61608 L
s
.31107 .61608 m
.34749 .62894 L
s
.21762 .56741 m
.23977 .58227 L
s
.18651 .54655 m
.19594 .55287 L
s
.19594 .55287 m
.21762 .56741 L
s
.20077 .55724 m
.25962 .59308 L
s
.25962 .59308 m
.31905 .61969 L
s
.2809 .60256 m
.30132 .61264 L
s
.23977 .58227 m
.25139 .588 L
s
.25139 .588 m
.2809 .60256 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.119739 0.614943 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567085 1.16605 0 1.16605 [
[.5 1.09796 -13.5938 0 ]
[.5 1.09796 13.5938 12 ]
[ 0 0 0 0 ]
[ 1 1.08546 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.09796 -74.5938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.08546 L
0 1.08546 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.42214 .58162 m
.40595 1.0631 L
s
.66492 .0299 m
.42214 .58162 L
s
.42225 .58158 m
.40608 1.06307 L
s
.10867 .26099 m
.42225 .58158 L
s
.42219 .58173 m
.665 .03003 L
s
.1086 .26117 m
.42219 .58173 L
s
.40602 1.06297 m
.69522 .58513 L
s
.02888 .79149 m
.40602 1.06297 L
s
.40595 1.0631 m
.69513 .58528 L
s
.40608 1.06307 m
.02892 .79159 L
s
.02889 .79172 m
.10864 .26114 L
s
.10864 .26114 m
.66499 .03002 L
s
.02892 .79159 m
.10867 .26099 L
s
.665 .03003 m
.1086 .26117 L
s
.66499 .03002 m
.69522 .58539 L
s
.69513 .58528 m
.66492 .0299 L
s
.69522 .58539 m
.02889 .79172 L
s
.69522 .58513 m
.02888 .79149 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.119739 0.735359 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.434567 1.97153 0 1.97153 [
[.5 1.9288 -35.1875 0 ]
[.5 1.9288 35.1875 12 ]
[ 0 0 0 0 ]
[ 1 1.9163 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.9288 -96.1875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RetardationPlate) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.9163 L
0 1.9163 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.68821 1.04544 m
.64427 .90099 L
s
.64427 .90099 m
.74784 .8673 L
s
.58745 .76314 m
.64427 .90099 L
s
.71723 1.18996 m
.68821 1.04544 L
s
.68821 1.04544 m
.79232 1.0131 L
s
.58745 .76314 m
.69117 .72791 L
s
.58745 .76314 m
.52015 .63843 L
s
.79232 1.0131 m
.74784 .8673 L
s
.74784 .8673 m
.85341 .83296 L
s
.69117 .72791 m
.74784 .8673 L
s
.71723 1.18996 m
.82257 1.15873 L
s
.82257 1.15873 m
.79232 1.0131 L
s
.79232 1.0131 m
.89846 .98013 L
s
.69117 .72791 m
.7969 .69198 L
s
.69117 .72791 m
.62468 .60147 L
s
.85341 .83296 m
.89846 .98013 L
s
.7969 .69198 m
.85341 .83296 L
s
.82257 1.15873 m
.92996 1.12688 L
s
.89846 .98013 m
.92996 1.12688 L
s
.52015 .63843 m
.62468 .60147 L
s
.73128 .56378 m
.7969 .69198 L
s
.63791 1.2323 m .83677 1.29737 L .72957 1.32777 L .656 .751 .92 r
F
0 g
.72381 1.45167 m
.72957 1.32777 L
s
.71723 1.18996 m
.72353 1.26032 L
s
.62468 .60147 m
.73128 .56378 L
s
.74752 1.19998 m .9461 1.26638 L .83677 1.29737 L .656 .751 .92 r
F
0 g
.82257 1.15873 m
.8296 1.22743 L
s
.63791 1.2323 m .74752 1.19998 L .83677 1.29737 L .656 .751 .92 r
F
0 g
.72957 1.32777 m
.83677 1.29737 L
s
.83344 1.42182 m
.83677 1.29737 L
s
.44519 .53348 m .5512 .64978 L .44244 .68801 L .544 .324 .532 r
F
.44519 .53348 m .5512 .49469 L .5512 .64978 L F
0 g
.36603 .45506 m
.44519 .53348 L
s
.74752 1.19998 m .85937 1.16701 L .9461 1.26638 L .656 .751 .92 r
F
0 g
.94529 1.39136 m
.9461 1.26638 L
s
.83677 1.29737 m
.9461 1.26638 L
s
.92996 1.12688 m
.9461 1.26638 L
s
.699 1.55402 m
.72381 1.45167 L
s
.72381 1.45167 m
.83344 1.42182 L
s
.5512 .49469 m .66221 .61076 L .5512 .64978 L .544 .324 .532 r
F
.5512 .49469 m .65934 .45511 L .66221 .61076 L F
0 g
.65934 .45511 m
.73128 .56378 L
s
.44519 .53348 m
.5512 .49469 L
s
.5512 .49469 m
.65934 .45511 L
s
.47411 .41441 m
.5512 .49469 L
s
.5404 1.13074 m .74752 1.19998 L .63791 1.2323 L .656 .751 .92 r
F
0 g
.63791 1.2323 m
.72957 1.32777 L
s
.81152 1.52437 m
.83344 1.42182 L
s
.83344 1.42182 m
.94529 1.39136 L
s
.58442 .37292 m
.65934 .45511 L
s
.65252 1.09632 m .85937 1.16701 L .74752 1.19998 L .656 .751 .92 r
F
.5404 1.13074 m .65252 1.09632 L .74752 1.19998 L F
0 g
.74752 1.19998 m
.83677 1.29737 L
s
.44244 .68801 m .5512 .81324 L .43953 .85078 L .544 .324 .532 r
F
.44244 .68801 m .5512 .64978 L .5512 .81324 L F
0 g
.44244 .68801 m
.44519 .53348 L
s
.36603 .45506 m
.47411 .41441 L
s
.36603 .45506 m
.2869 .40985 L
s
.94529 1.39136 m
.92639 1.49409 L
s
.65252 1.09632 m .76701 1.06118 L .85937 1.16701 L .656 .751 .92 r
F
0 g
.85937 1.16701 m
.9461 1.26638 L
s
.65497 1.62688 m
.699 1.55402 L
s
.699 1.55402 m
.81152 1.52437 L
s
.5512 .64978 m .66523 .77489 L .5512 .81324 L .544 .324 .532 r
F
.5512 .64978 m .66221 .61076 L .66523 .77489 L F
0 g
.5512 .49469 m
.5512 .64978 L
s
.65934 .45511 m
.66221 .61076 L
s
.47411 .41441 m
.58442 .37292 L
s
.47411 .41441 m
.39756 .36743 L
s
.7707 1.59703 m
.81152 1.52437 L
s
.81152 1.52437 m
.92639 1.49409 L
s
.43647 1.02249 m .65252 1.09632 L .5404 1.13074 L .656 .751 .92 r
F
0 g
.5404 1.13074 m
.63791 1.2323 L
s
.51058 .32411 m
.58442 .37292 L
s
.43953 .85078 m .5512 .98576 L .43647 1.02249 L .544 .324 .532 r
F
.43953 .85078 m .5512 .81324 L .5512 .98576 L F
0 g
.43953 .85078 m
.44244 .68801 L
s
.92639 1.49409 m
.88893 1.56654 L
s
.5512 .98576 m .76701 1.06118 L .65252 1.09632 L .656 .751 .92 r
F
.43647 1.02249 m .5512 .98576 L .65252 1.09632 L F
0 g
.65252 1.09632 m
.74752 1.19998 L
s
.2869 .40985 m
.39756 .36743 L
s
.2869 .40985 m
.21282 .40388 L
s
.5512 .81324 m .66843 .94823 L .5512 .98576 L .544 .324 .532 r
F
.5512 .81324 m .66523 .77489 L .66843 .94823 L F
0 g
.5512 .64978 m
.5512 .81324 L
s
.66221 .61076 m
.66523 .77489 L
s
.59274 1.66256 m
.65497 1.62688 L
s
.65497 1.62688 m
.7707 1.59703 L
s
.5512 .98576 m .66843 .94823 L .76701 1.06118 L .656 .751 .92 r
F
0 g
.76701 1.06118 m
.85937 1.16701 L
s
.39756 .36743 m
.51058 .32411 L
s
.39756 .36743 m
.32647 .35994 L
s
.71179 1.63208 m
.7707 1.59703 L
s
.7707 1.59703 m
.88893 1.56654 L
s
.44263 .31503 m
.51058 .32411 L
s
.43647 1.02249 m .5512 1.16813 L .43323 1.20389 L .544 .324 .532 r
F
.43647 1.02249 m .5512 .98576 L .5512 1.16813 L F
.32547 .90688 m .5512 .98576 L .43647 1.02249 L .656 .751 .92 r
F
0 g
.43783 .94615 m
.43953 .85078 L
s
.88893 1.56654 m
.8335 1.60091 L
s
.5512 .98576 m .67181 1.13156 L .5512 1.16813 L .544 .324 .532 r
F
.5512 .98576 m .66843 .94823 L .67181 1.13156 L F
.4429 .86759 m .66843 .94823 L .5512 .98576 L .656 .751 .92 r
F
0 g
.5512 .81324 m
.5512 .90631 L
s
.32547 .90688 m .4429 .86759 L .5512 .98576 L .656 .751 .92 r
F
0 g
.21282 .40388 m
.14956 .44161 L
s
.32647 .35994 m
.21282 .40388 L
s
.4429 .86759 m .56299 .82742 L .66843 .94823 L .656 .751 .92 r
F
0 g
.66843 .94823 m
.76701 1.06118 L
s
.66523 .77489 m
.66843 .94823 L
s
.51493 1.65461 m
.59274 1.66256 L
s
.59274 1.66256 m
.71179 1.63208 L
s
.32647 .35994 m
.26642 .39658 L
s
.44263 .31503 m
.32647 .35994 L
s
.43323 1.20389 m .5512 1.3612 L .42981 1.39581 L .544 .324 .532 r
F
.43323 1.20389 m .5512 1.16813 L .5512 1.3612 L F
0 g
.43323 1.20389 m
.43647 1.02249 L
s
.63717 1.623 m
.71179 1.63208 L
s
.71179 1.63208 m
.8335 1.60091 L
s
.20664 .78312 m .4429 .86759 L .32547 .90688 L .656 .751 .92 r
F
0 g
.32547 .90688 m
.43647 1.02249 L
s
.38597 .35051 m
.44263 .31503 L
s
.5512 1.16813 m .67539 1.32578 L .5512 1.3612 L .544 .324 .532 r
F
.5512 1.16813 m .67181 1.13156 L .67539 1.32578 L F
0 g
.5512 .98576 m
.5512 1.16813 L
s
.66843 .94823 m
.67181 1.13156 L
s
.8335 1.60091 m
.76224 1.59065 L
s
.32688 .741 m .56299 .82742 L .4429 .86759 L .656 .751 .92 r
F
.20664 .78312 m .32688 .741 L .4429 .86759 L F
0 g
.4429 .86759 m
.5512 .98576 L
s
.14956 .44161 m
.26642 .39658 L
s
.14956 .44161 m
.10315 .52464 L
s
.51493 1.65461 m
.63717 1.623 L
s
.32688 .741 m .44995 .69789 L .56299 .82742 L .656 .751 .92 r
F
0 g
.56299 .82742 m
.66843 .94823 L
s
.42981 1.39581 m .5512 1.56594 L .42618 1.5992 L .544 .324 .532 r
F
0 g
.42618 1.5992 m
.51493 1.65461 L
s
.42981 1.39581 m .5512 1.3612 L .5512 1.56594 L .544 .324 .532 r
F
0 g
.42981 1.39581 m
.43323 1.20389 L
s
.42618 1.5992 m
.42981 1.39581 L
s
.26642 .39658 m
.38597 .35051 L
s
.26642 .39658 m
.22326 .47911 L
s
.63717 1.623 m
.76224 1.59065 L
s
.5512 1.3612 m .67919 1.53189 L .5512 1.56594 L .544 .324 .532 r
F
0 g
.5512 1.56594 m
.63717 1.623 L
s
.5512 1.3612 m .67539 1.32578 L .67919 1.53189 L .544 .324 .532 r
F
0 g
.5512 1.16813 m
.5512 1.3612 L
s
.67181 1.13156 m
.67539 1.32578 L
s
.5512 1.3612 m
.5512 1.56594 L
s
.34622 .43252 m
.38597 .35051 L
s
.07914 .65032 m .32688 .741 L .20664 .78312 L .656 .751 .92 r
F
0 g
.20664 .78312 m
.32547 .90688 L
s
.22326 .47911 m
.10315 .52464 L
s
.67919 1.53189 m
.76224 1.59065 L
s
.67539 1.32578 m
.67919 1.53189 L
s
.20229 .60505 m .44995 .69789 L .32688 .741 L .656 .751 .92 r
F
.07914 .65032 m .20229 .60505 L .32688 .741 L F
0 g
.32688 .741 m
.4429 .86759 L
s
.07914 .65032 m
.10315 .52464 L
s
.42618 1.5992 m
.5512 1.56594 L
s
.33315 1.49671 m
.42618 1.5992 L
s
.34622 .43252 m
.22326 .47911 L
s
.20229 .60505 m .32844 .55867 L .44995 .69789 L .656 .751 .92 r
F
0 g
.32844 .55867 m
.44995 .69789 L
s
.20229 .60505 m
.22326 .47911 L
s
.20229 .60505 m
.32688 .741 L
s
.07914 .65032 m
.20664 .78312 L
s
.44995 .69789 m
.56299 .82742 L
s
.5512 1.56594 m
.67919 1.53189 L
s
.46025 1.46136 m
.5512 1.56594 L
s
.32844 .55867 m
.34622 .43252 L
s
.07914 .65032 m
.20229 .60505 L
s
.07914 .65032 m
.08154 .81078 L
s
.59047 1.42513 m
.67919 1.53189 L
s
.24406 1.353 m
.33315 1.49671 L
s
.33315 1.49671 m
.46025 1.46136 L
s
.20229 .60505 m
.32844 .55867 L
s
.20229 .60505 m
.20726 .76654 L
s
.37235 1.31524 m
.46025 1.46136 L
s
.46025 1.46136 m
.59047 1.42513 L
s
.08154 .81078 m
.20726 .76654 L
s
.08154 .81078 m
.11172 .99289 L
s
.32844 .55867 m
.33609 .72121 L
s
.16766 1.17967 m
.24406 1.353 L
s
.24406 1.353 m
.37235 1.31524 L
s
.59047 1.42513 m
.50384 1.27654 L
s
.11172 .99289 m
.23926 .9504 L
s
.11172 .99289 m
.16766 1.17967 L
s
.20726 .76654 m
.33609 .72121 L
s
.20726 .76654 m
.23926 .9504 L
s
.16766 1.17967 m
.2961 1.13944 L
s
.2961 1.13944 m
.37235 1.31524 L
s
.37235 1.31524 m
.50384 1.27654 L
s
.23926 .9504 m
.37001 .90684 L
s
.2961 1.13944 m
.23926 .9504 L
s
.37001 .90684 m
.33609 .72121 L
s
.2961 1.13944 m
.42777 1.09819 L
s
.50384 1.27654 m
.42777 1.09819 L
s
.42777 1.09819 m
.37001 .90684 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.119739 0.855774 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.00385 -0.118963 1.00385 [
[.5 .71462 -33.8125 0 ]
[.5 .71462 33.8125 12 ]
[ 0 0 0 0 ]
[ 1 .70212 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .71462 -94.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ReversionPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .70212 L
0 .70212 L
closepath
clip
newpath
.74697 .35909 m .4668 .44654 L .46512 .63528 L .562 .35 .551 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.1747 .39697 m
.46678 .44659 L
s
.46678 .44659 m
.4668 .44659 L
s
.17476 .39689 m
.46686 .44651 L
s
.17487 .39693 m
.15887 .58809 L
s
.04829 .27974 m
.17487 .39693 L
s
.04811 .27978 m
.1747 .39697 L
s
.15876 .58806 m
.17476 .39689 L
s
.74697 .35909 m .46512 .63528 L .75918 .55202 L .562 .35 .551 r
F
0 g
.74697 .35909 m
.75918 .55202 L
s
.7469 .35912 m
.78794 .29218 L
s
.7591 .55205 m
.7591 .55206 L
s
.46527 .63527 m
.46527 .63524 L
s
.74698 .35919 m
.74705 .35916 L
s
.46512 .63528 m
.4668 .44654 L
s
.4668 .44654 m
.74697 .35909 L
s
.74709 .3591 m
.78811 .29221 L
s
.74705 .35916 m
.74709 .3591 L
s
.75918 .55202 m
.75926 .552 L
s
.15871 .58804 m
.4651 .63523 L
s
.4651 .63523 m
.46512 .63524 L
s
.46512 .63528 m
.75918 .55202 L
s
.15876 .58806 m
.46519 .63526 L
s
.46519 .63526 m
.46527 .63527 L
s
.02461 .47611 m
.15871 .58804 L
s
.15887 .58809 m
.02479 .47617 L
s
.78791 .29222 m
.80264 .48813 L
s
.86552 .16565 m
.78791 .29222 L
s
.78796 .29229 m
.86558 .16572 L
s
.50186 .28748 m
.78796 .29229 L
s
.80267 .48808 m
.78794 .29218 L
s
.78811 .29221 m
.04811 .27978 L
s
.5019 .48355 m
.5019 .28745 L
s
.76765 .02003 m
.5019 .28745 L
s
.7676 .02006 m
.50186 .28748 L
s
.50208 .28739 m
.50208 .4835 L
s
.04821 .27977 m
.50208 .28739 L
s
.02471 .4762 m
.04821 .27977 L
s
.02479 .47617 m
.04829 .27974 L
s
.75926 .552 m
.80284 .48801 L
s
.75911 .55204 m
.80267 .48808 L
s
.7591 .55206 m
.75911 .55204 L
s
.80269 .48809 m
.88544 .36658 L
s
.50185 .48349 m
.80269 .48809 L
s
.80264 .48813 m
.88539 .36662 L
s
.80284 .48801 m
.02461 .47611 L
s
.78308 .22585 m
.50185 .48349 L
s
.5019 .48355 m
.78314 .22592 L
s
.50208 .4835 m
.02471 .4762 L
s
.86552 .16572 m
.88539 .36668 L
s
.76754 .02006 m
.86552 .16572 L
s
.88539 .36662 m
.86552 .16565 L
s
.86558 .16572 m
.7676 .02006 L
s
.88539 .36668 m
.78303 .22596 L
s
.88544 .36658 m
.78308 .22585 L
s
.78303 .22596 m
.76754 .02006 L
s
.78314 .22592 m
.76765 .02003 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.119739 0.97619 0.216693 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.0046 -0.0385242 1.0046 [
[.5 .88184 -34.6562 0 ]
[.5 .88184 34.6562 12 ]
[ 0 0 0 0 ]
[ 1 .86934 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .88184 -95.6562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RhomboidPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .86934 L
0 .86934 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.3 .50216 m
.28154 .85117 L
s
.45012 .13714 m
.3 .50216 L
s
.29993 .50226 m
.54826 .42169 L
s
.45005 .13725 m
.29993 .50226 L
s
.29997 .5021 m
.28151 .85112 L
s
.5483 .42153 m
.29997 .5021 L
s
.54819 .42163 m
.55256 .7784 L
s
.75312 .02362 m
.54819 .42163 L
s
.54826 .42169 m
.75321 .02368 L
s
.55268 .77831 m
.5483 .42153 L
s
.28148 .85109 m
.55263 .77829 L
s
.44432 .51687 m
.28148 .85109 L
s
.28154 .85117 m
.4444 .51695 L
s
.28151 .85112 m
.55268 .77831 L
s
.55263 .77829 m
.78221 .41055 L
s
.55256 .7784 m
.78213 .41069 L
s
.45001 .13728 m
.44427 .51708 L
s
.75314 .02371 m
.45001 .13728 L
s
.4444 .51695 m
.45012 .13714 L
s
.75321 .02368 m
.45005 .13725 L
s
.78215 .41077 m
.75314 .02371 L
s
.78213 .41069 m
.75312 .02362 L
s
.44427 .51708 m
.78215 .41077 L
s
.78221 .41055 m
.44432 .51687 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.226388 0.133279 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.079586 1.21818 -1.11022e-16 1.21818 [
[.5 1.15267 -25.2188 0 ]
[.5 1.15267 25.2188 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.14017 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.15267 -86.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(LensTriplet) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.14017 L
0 1.14017 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47599 .67877 m
.45383 .60541 L
s
.45383 .60541 m
.60249 .55706 L
s
.45383 .60541 m
.42421 .53572 L
s
.48963 .75244 m
.47599 .67877 L
s
.47599 .67877 m
.62542 .63236 L
s
.42421 .53572 m
.57304 .48515 L
s
.42421 .53572 m
.38835 .47304 L
s
.48963 .75244 m
.64078 .70762 L
s
.41002 .78553 m .64762 .77935 L .49388 .82294 L .656 .751 .92 r
F
0 g
.48808 .88657 m
.49388 .82294 L
s
.48963 .75244 m
.49149 .78341 L
s
.62542 .63236 m
.60249 .55706 L
s
.60249 .55706 m
.66093 .53806 L
s
.60249 .55706 m
.57304 .48515 L
s
.64078 .70762 m
.62542 .63236 L
s
.62542 .63236 m
.68417 .61411 L
s
.57304 .48515 m
.63156 .46527 L
s
.57304 .48515 m
.5383 .42002 L
s
.64078 .70762 m
.70022 .69 L
s
.68417 .61411 m
.66093 .53806 L
s
.66093 .53806 m
.63156 .46527 L
s
.70022 .69 m
.68417 .61411 L
s
.34777 .42073 m .3999 .48027 L .30991 .5119 L .544 .324 .532 r
F
.34777 .42073 m .49975 .36511 L .3999 .48027 L F
0 g
.41405 .46395 m
.5383 .42002 L
s
.30433 .38221 m
.34777 .42073 L
s
.63156 .46527 m
.59729 .39916 L
s
.5383 .42002 m
.59729 .39916 L
s
.47187 .93941 m
.48808 .88657 L
s
.48808 .88657 m
.64521 .84378 L
s
.41002 .78553 m .50076 .75878 L .64762 .77935 L .656 .751 .92 r
F
.33639 .74188 m .50076 .75878 L .41002 .78553 L F
0 g
.41002 .78553 m
.49388 .82294 L
s
.50076 .75878 m .70812 .76219 L .64762 .77935 L .656 .751 .92 r
F
0 g
.64521 .84378 m
.64762 .77935 L
s
.49388 .82294 m
.64762 .77935 L
s
.64078 .70762 m
.64589 .76117 L
s
.30991 .5119 m .35197 .57925 L .28485 .60181 L .544 .324 .532 r
F
.30991 .5119 m .3999 .48027 L .35197 .57925 L F
0 g
.30991 .5119 m
.34777 .42073 L
s
.76834 .6799 m .94081 .69621 L .70812 .76219 L .656 .751 .92 r
F
.50076 .75878 m .76834 .6799 L .70812 .76219 L F
0 g
.64762 .77935 m
.70812 .76219 L
s
.70022 .69 m
.70128 .69967 L
s
.70709 .82693 m
.70812 .76219 L
s
.40381 .72119 m .76834 .6799 L .50076 .75878 L .656 .751 .92 r
F
0 g
.71322 .68614 m
.92865 .62226 L
s
.33639 .74188 m .40381 .72119 L .50076 .75878 L .656 .751 .92 r
F
0 g
.50076 .75878 m
.64762 .77935 L
s
.30433 .38221 m
.26031 .3608 L
s
.49975 .36511 m .66544 .38694 L .3999 .48027 L .544 .324 .532 r
F
0 g
.30433 .38221 m
.45915 .32397 L
s
.66093 .53806 m
.88539 .46505 L
s
.49975 .36511 m .55958 .34322 L .66544 .38694 L .544 .324 .532 r
F
0 g
.34777 .42073 m
.49975 .36511 L
s
.45915 .32397 m
.49975 .36511 L
s
.44534 .97742 m
.47187 .93941 L
s
.47187 .93941 m
.63302 .89695 L
s
.88539 .46505 m
.90984 .54401 L
s
.85642 .38887 m
.88539 .46505 L
s
.63302 .89695 m
.64521 .84378 L
s
.64521 .84378 m
.70709 .82693 L
s
.3999 .48027 m .71914 .45579 L .35197 .57925 L .544 .324 .532 r
F
0 g
.68417 .61411 m
.90984 .54401 L
s
.3999 .48027 m .66544 .38694 L .71914 .45579 L .544 .324 .532 r
F
0 g
.70664 .43976 m
.85642 .38887 L
s
.3999 .48027 m
.49975 .36511 L
s
.27192 .69156 m .40381 .72119 L .33639 .74188 L .656 .751 .92 r
F
0 g
.33639 .74188 m
.41002 .78553 L
s
.90984 .54401 m
.92865 .62226 L
s
.55958 .34322 m .79744 .34054 L .66544 .38694 L .544 .324 .532 r
F
.55958 .34322 m .7899 .25894 L .79744 .34054 L F
0 g
.79635 .32878 m
.82412 .31896 L
s
.49975 .36511 m
.55958 .34322 L
s
.55958 .34322 m
.7899 .25894 L
s
.52017 .30102 m
.55958 .34322 L
s
.28485 .60181 m .33353 .67183 L .27192 .69156 L .544 .324 .532 r
F
.28485 .60181 m .35197 .57925 L .33353 .67183 L F
0 g
.28485 .60181 m
.30991 .5119 L
s
.82412 .31896 m
.85642 .38887 L
s
.69655 .8802 m
.70709 .82693 L
s
.70709 .82693 m
.94539 .76203 L
s
.40381 .72119 m .77245 .60804 L .76834 .6799 L .656 .751 .92 r
F
.33353 .67183 m .77245 .60804 L .40381 .72119 L F
.27192 .69156 m .33353 .67183 L .40381 .72119 L F
0 g
.40381 .72119 m
.50076 .75878 L
s
.35197 .57925 m .74033 .54159 L .33353 .67183 L .544 .324 .532 r
F
.35197 .57925 m .71914 .45579 L .74033 .54159 L F
0 g
.35197 .57925 m
.3999 .48027 L
s
.45915 .32397 m
.52017 .30102 L
s
.45915 .32397 m
.41869 .30009 L
s
.26031 .3608 m
.41869 .30009 L
s
.26031 .3608 m
.21847 .35945 L
s
.7899 .25894 m
.82412 .31896 L
s
.76834 .6799 m .90126 .64072 L .94081 .69621 L .656 .751 .92 r
F
0 g
.94081 .69621 m
.94539 .76203 L
s
.70812 .76219 m
.94081 .69621 L
s
.92865 .62226 m
.94081 .69621 L
s
.61093 .93471 m
.63302 .89695 L
s
.63302 .89695 m
.69655 .8802 L
s
.52017 .30102 m
.75539 .21255 L
s
.52017 .30102 m
.48119 .27613 L
s
.27192 .69156 m .34218 .76052 L .27154 .78193 L .544 .324 .532 r
F
.27192 .69156 m .33353 .67183 L .34218 .76052 L F
.21655 .63366 m .33353 .67183 L .27192 .69156 L .656 .751 .92 r
F
0 g
.2774 .65352 m
.28485 .60181 L
s
.40925 .99665 m
.44534 .97742 L
s
.44534 .97742 m
.61093 .93471 L
s
.77245 .60804 m .90126 .64072 L .76834 .6799 L .656 .751 .92 r
F
0 g
.70812 .76219 m
.76834 .6799 L
s
.6763 .91786 m
.69655 .8802 L
s
.69655 .8802 m
.94159 .81563 L
s
.33353 .67183 m .73034 .64285 L .34218 .76052 L .544 .324 .532 r
F
.33353 .67183 m .74033 .54159 L .77245 .60804 L .656 .751 .92 r
F
.33353 .67183 m .74033 .54159 L .73034 .64285 L .544 .324 .532 r
F
.28684 .61014 m .74033 .54159 L .33353 .67183 L .656 .751 .92 r
F
0 g
.34764 .60095 m
.35197 .57925 L
s
.21655 .63366 m .28684 .61014 L .33353 .67183 L .656 .751 .92 r
F
0 g
.75539 .21255 m
.7899 .25894 L
s
.66544 .38694 m .80525 .42683 L .71914 .45579 L .544 .324 .532 r
F
.66544 .38694 m .79744 .34054 L .80525 .42683 L F
0 g
.55958 .34322 m
.66544 .38694 L
s
.7899 .25894 m
.79744 .34054 L
s
.41869 .30009 m
.48119 .27613 L
s
.41869 .30009 m
.38095 .29663 L
s
.94539 .76203 m
.94159 .81563 L
s
.21847 .35945 m
.18197 .38027 L
s
.38095 .29663 m
.21847 .35945 L
s
.27154 .78193 m .38508 .84512 L .28526 .87358 L .544 .324 .532 r
F
.27154 .78193 m .34218 .76052 L .38508 .84512 L F
0 g
.27154 .78193 m
.27192 .69156 L
s
.77245 .60804 m .85887 .58151 L .90126 .64072 L .656 .751 .92 r
F
0 g
.90126 .64072 m
.94081 .69621 L
s
.57941 .95308 m
.61093 .93471 L
s
.61093 .93471 m
.6763 .91786 L
s
.48119 .27613 m
.72252 .18363 L
s
.48119 .27613 m
.44516 .27181 L
s
.36526 .99384 m
.40925 .99665 L
s
.17124 .56678 m .28684 .61014 L .21655 .63366 L .656 .751 .92 r
F
0 g
.21655 .63366 m
.27192 .69156 L
s
.34218 .76052 m .68184 .7605 L .38508 .84512 L .544 .324 .532 r
F
.34218 .76052 m .73034 .64285 L .68184 .7605 L F
0 g
.33353 .67183 m
.34218 .76052 L
s
.72252 .18363 m
.75539 .21255 L
s
.64669 .93586 m
.6763 .91786 L
s
.28684 .61014 m .67329 .48085 L .74033 .54159 L .656 .751 .92 r
F
.27005 .53217 m .67329 .48085 L .28684 .61014 L F
.17124 .56678 m .27005 .53217 L .28684 .61014 L F
0 g
.28684 .61014 m
.33353 .67183 L
s
.74033 .54159 m .85887 .58151 L .77245 .60804 L .656 .751 .92 r
F
0 g
.76834 .6799 m
.77245 .60804 L
s
.94159 .81563 m
.92885 .85273 L
s
.38095 .29663 m
.34888 .31596 L
s
.44516 .27181 m
.38095 .29663 L
s
.71914 .45579 m .81336 .51821 L .74033 .54159 L .544 .324 .532 r
F
.71914 .45579 m .80525 .42683 L .81336 .51821 L F
0 g
.66544 .38694 m
.71914 .45579 L
s
.79744 .34054 m
.80525 .42683 L
s
.18197 .38027 m
.34888 .31596 L
s
.18197 .38027 m
.15418 .42388 L
s
.28526 .87358 m .49438 .91954 L .31607 .96698 L .544 .324 .532 r
F
0 g
.40925 .99665 m
.57941 .95308 L
s
.28526 .87358 m .38508 .84512 L .49438 .91954 L .544 .324 .532 r
F
0 g
.27154 .78193 m
.28526 .87358 L
s
.28526 .87358 m
.31607 .96698 L
s
.74033 .54159 m .81336 .51821 L .85887 .58151 L .656 .751 .92 r
F
0 g
.85887 .58151 m
.90126 .64072 L
s
.53979 .94869 m
.57941 .95308 L
s
.57941 .95308 m
.64669 .93586 L
s
.44516 .27181 m
.41494 .2905 L
s
.69356 .17577 m
.44516 .27181 L
s
.31607 .96698 m
.36526 .99384 L
s
.36526 .99384 m
.53979 .94869 L
s
.13826 .48876 m .27005 .53217 L .17124 .56678 L .656 .751 .92 r
F
0 g
.17124 .56678 m
.21655 .63366 L
s
.69356 .17577 m
.72252 .18363 L
s
.60889 .93082 m
.64669 .93586 L
s
.38508 .84512 m .56507 .90073 L .49438 .91954 L .544 .324 .532 r
F
.38508 .84512 m .68184 .7605 L .56507 .90073 L F
0 g
.34218 .76052 m
.38508 .84512 L
s
.64669 .93586 m
.90709 .86918 L
s
.6763 .91786 m
.92885 .85273 L
s
.38508 .84512 m
.49438 .91954 L
s
.74033 .54159 m .8218 .61512 L .73034 .64285 L .544 .324 .532 r
F
.74033 .54159 m .81336 .51821 L .8218 .61512 L F
.67329 .48085 m .81336 .51821 L .74033 .54159 L .656 .751 .92 r
F
0 g
.71914 .45579 m
.729 .49571 L
s
.92885 .85273 m
.90709 .86918 L
s
.32556 .35893 m
.15418 .42388 L
s
.34888 .31596 m
.41494 .2905 L
s
.34888 .31596 m
.32556 .35893 L
s
.27005 .53217 m .56405 .42918 L .67329 .48085 L .656 .751 .92 r
F
.31382 .42422 m .56405 .42918 L .27005 .53217 L F
.13826 .48876 m .31382 .42422 L .27005 .53217 L F
0 g
.27005 .53217 m
.28684 .61014 L
s
.13826 .48876 m
.15418 .42388 L
s
.13826 .48876 m
.17124 .56678 L
s
.31607 .96698 m
.49438 .91954 L
s
.26544 .91624 m
.31607 .96698 L
s
.67329 .48085 m .76439 .45037 L .81336 .51821 L .656 .751 .92 r
F
0 g
.81336 .51821 m
.85887 .58151 L
s
.80525 .42683 m
.81336 .51821 L
s
.49438 .91954 m
.53979 .94869 L
s
.53979 .94869 m
.60889 .93082 L
s
.41494 .2905 m
.67098 .19184 L
s
.41494 .2905 m
.39348 .33319 L
s
.67098 .19184 m
.69356 .17577 L
s
.73034 .64285 m .8306 .71808 L .68184 .7605 L .544 .324 .532 r
F
.73034 .64285 m .8218 .61512 L .8306 .71808 L F
0 g
.73034 .64285 m
.74033 .54159 L
s
.81336 .51821 m
.8218 .61512 L
s
.13659 .57076 m
.13826 .48876 L
s
.56405 .42918 m .76439 .45037 L .67329 .48085 L .656 .751 .92 r
F
0 g
.67329 .48085 m
.74033 .54159 L
s
.39348 .33319 m
.32556 .35893 L
s
.21791 .84448 m
.26544 .91624 L
s
.26544 .91624 m
.44659 .86585 L
s
.90709 .86918 m
.8769 .86149 L
s
.44659 .86585 m
.49438 .91954 L
s
.68184 .7605 m .83978 .82765 L .56507 .90073 L .544 .324 .532 r
F
0 g
.49438 .91954 m
.56507 .90073 L
s
.60889 .93082 m
.8769 .86149 L
s
.56507 .90073 m
.60889 .93082 L
s
.68184 .7605 m .8306 .71808 L .83978 .82765 L .544 .324 .532 r
F
0 g
.68184 .7605 m
.73034 .64285 L
s
.56507 .90073 m
.68184 .7605 L
s
.8218 .61512 m
.8306 .71808 L
s
.13659 .57076 m
.31567 .50775 L
s
.13659 .57076 m
.15015 .66318 L
s
.56405 .42918 m .71158 .3775 L .76439 .45037 L .656 .751 .92 r
F
0 g
.76439 .45037 m
.81336 .51821 L
s
.17814 .75745 m
.21791 .84448 L
s
.21791 .84448 m
.40063 .7907 L
s
.51849 .84585 m
.56507 .90073 L
s
.56507 .90073 m
.83978 .82765 L
s
.15015 .66318 m
.33177 .60268 L
s
.15015 .66318 m
.17814 .75745 L
s
.38348 .39862 m .71158 .3775 L .56405 .42918 L .656 .751 .92 r
F
.31382 .42422 m .38348 .39862 L .56405 .42918 L F
0 g
.56405 .42918 m
.67329 .48085 L
s
.31382 .42422 m
.32556 .35893 L
s
.13826 .48876 m
.31382 .42422 L
s
.27005 .53217 m
.31382 .42422 L
s
.17814 .75745 m
.36102 .70015 L
s
.65725 .23323 m
.67098 .19184 L
s
.31382 .42422 m
.31567 .50775 L
s
.40063 .7907 m
.44659 .86585 L
s
.44659 .86585 m
.51849 .84585 L
s
.83978 .82765 m
.8769 .86149 L
s
.8306 .71808 m
.83978 .82765 L
s
.38348 .39862 m .65447 .299 L .71158 .3775 L .656 .751 .92 r
F
0 g
.38348 .39862 m
.3868 .48272 L
s
.38348 .39862 m
.65447 .299 L
s
.31382 .42422 m
.38348 .39862 L
s
.38348 .39862 m
.56405 .42918 L
s
.38348 .39862 m
.39348 .33319 L
s
.71158 .3775 m
.76439 .45037 L
s
.39348 .33319 m
.65725 .23323 L
s
.47322 .76933 m
.51849 .84585 L
s
.51849 .84585 m
.79832 .76801 L
s
.31567 .50775 m
.3868 .48272 L
s
.31567 .50775 m
.33177 .60268 L
s
.65447 .299 m
.71158 .3775 L
s
.36102 .70015 m
.40063 .7907 L
s
.40063 .7907 m
.47322 .76933 L
s
.33177 .60268 m
.40394 .57863 L
s
.33177 .60268 m
.36102 .70015 L
s
.65447 .299 m
.65725 .23323 L
s
.36102 .70015 m
.43369 .67739 L
s
.3868 .48272 m
.66385 .38523 L
s
.3868 .48272 m
.40394 .57863 L
s
.43369 .67739 m
.47322 .76933 L
s
.47322 .76933 m
.75604 .68608 L
s
.79832 .76801 m
.83978 .82765 L
s
.40394 .57863 m
.68527 .48491 L
s
.40394 .57863 m
.43369 .67739 L
s
.43369 .67739 m
.71704 .58862 L
s
.65447 .299 m
.66385 .38523 L
s
.79832 .76801 m
.75604 .68608 L
s
.68527 .48491 m
.66385 .38523 L
s
.75604 .68608 m
.71704 .58862 L
s
.71704 .58862 m
.68527 .48491 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.226388 0.253695 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.645931 2.40421 -2.22045e-16 2.40421 [
[.5 2.37017 -33 0 ]
[.5 2.37017 33 12 ]
[ 0 0 0 0 ]
[ 1 2.35767 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 2.37017 -94 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(LinearPolarizer) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2.35767 L
0 2.35767 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.80636 1.05138 m
.86296 1.23689 L
s
.73426 .87403 m
.80636 1.05138 L
s
.86296 1.23689 m
.90144 1.42217 L
s
.64967 .71316 m
.73426 .87403 L
s
.90144 1.42217 m
.91951 1.59857 L
s
.55617 .5773 m
.64967 .71316 L
s
.91951 1.59857 m
.91527 1.7569 L
s
.91951 1.59857 m
.80596 1.47466 L
s
.91951 1.59857 m
.91951 1.59857 L
s
.55617 .5773 m
.55617 .5773 L
s
.55617 .5773 m
.55617 .77463 L
s
.45809 .47516 m
.55617 .5773 L
s
.91527 1.7569 m
.88739 1.88738 L
s
.80596 1.47466 m
.68509 1.34277 L
s
.55617 .77463 m
.55617 .9826 L
s
.36069 .41539 m
.45809 .47516 L
s
.88739 1.88738 m
.83545 1.97983 L
s
.68509 1.34277 m
.55617 1.2021 L
s
.55617 .9826 m
.55617 1.2021 L
s
.27024 .40586 m
.36069 .41539 L
s
.83545 1.97983 m
.7605 2.02442 L
s
.55617 1.2021 m
.41839 1.05175 L
s
.55617 1.2021 m
.55617 1.43413 L
s
.19385 .45247 m
.27024 .40586 L
s
.7605 2.02442 m
.66556 2.01287 L
s
.55617 1.43413 m
.55617 1.67977 L
s
.41839 1.05175 m
.27078 .89069 L
s
.13894 .55749 m
.19385 .45247 L
s
.66556 2.01287 m
.55617 1.94028 L
s
.55617 1.67977 m
.55617 1.94028 L
s
.27078 .89069 m
.11226 .71771 L
s
.11226 .71771 m
.13894 .55749 L
s
.55617 1.94028 m
.44046 1.80721 L
s
.55617 1.94028 m
.55617 1.94028 L
s
.11226 .71771 m
.11226 .71771 L
s
.11857 .92319 m
.11226 .71771 L
s
.44046 1.80721 m
.32862 1.6213 L
s
.15929 1.15711 m
.11857 .92319 L
s
.32862 1.6213 m
.23161 1.39763 L
s
.23161 1.39763 m
.15929 1.15711 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.226388 0.374111 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.119931 1.30802 -2.22045e-16 1.30802 [
[.5 1.2464 -15.3125 0 ]
[.5 1.2464 15.3125 12 ]
[ 0 0 0 0 ]
[ 1 1.2339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.2464 -76.3125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Mirror) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.2339 L
0 1.2339 L
closepath
clip
newpath
.38699 .67969 m .42895 .65673 L .45349 .73808 L .945 .686 .513 r
F
.36402 .62644 m .42895 .65673 L .38699 .67969 L F
.36402 .62644 m .39597 .57951 L .42895 .65673 L F
.40394 .73599 m .45349 .73808 L .46842 .81981 L F
.38699 .67969 m .45349 .73808 L .40394 .73599 L F
0 g
.5 Mabswid
[ ] 0 setdash
.42895 .65673 m
.45349 .73808 L
s
.33618 .57914 m .39597 .57951 L .36402 .62644 L .945 .686 .513 r
F
.33618 .57914 m .35593 .51011 L .39597 .57951 L F
0 g
.39597 .57951 m
.42895 .65673 L
s
.41395 .79238 m .46842 .81981 L .4728 .89807 L .945 .686 .513 r
F
.40394 .73599 m .46842 .81981 L .41395 .79238 L F
0 g
.45349 .73808 m
.46842 .81981 L
s
.30486 .54058 m .35593 .51011 L .33618 .57914 L .945 .686 .513 r
F
.30486 .54058 m .31051 .45227 L .35593 .51011 L F
0 g
.35593 .51011 m
.39597 .57951 L
s
.41395 .79238 m .4728 .89807 L .41636 .84582 L .945 .686 .513 r
F
.41636 .84582 m .4728 .89807 L .46589 .96874 L F
.41636 .84582 m .94247 .76489 L .4728 .89807 L .656 .751 .92 r
F
0 g
.46842 .81981 m
.46942 .83766 L
s
.34169 .70447 m .38699 .67969 L .40394 .73599 L .945 .686 .513 r
F
.32967 .6769 m .38699 .67969 L .34169 .70447 L F
.32967 .6769 m .36402 .62644 L .38699 .67969 L F
.35048 .73374 m .40394 .73599 L .41395 .79238 L F
.34169 .70447 m .40394 .73599 L .35048 .73374 L F
.31051 .45227 m .78163 .373 L .30486 .54058 L .544 .324 .532 r
F
.31051 .45227 m .77504 .28228 L .78163 .373 L F
0 g
.78068 .35993 m
.81389 .34819 L
s
.27173 .51334 m .31051 .45227 L .30486 .54058 L .945 .686 .513 r
F
.27173 .51334 m .2618 .40978 L .31051 .45227 L F
.31512 .65272 m .36402 .62644 L .32967 .6769 L F
.31512 .65272 m .33618 .57914 L .36402 .62644 L F
.3555 .76296 m .41395 .79238 L .41636 .84582 L F
.35048 .73374 m .41395 .79238 L .3555 .76296 L F
.41078 .89322 m .46589 .96874 L .44731 1.02748 L F
.41636 .84582 m .46589 .96874 L .41078 .89322 L F
0 g
.46589 .96874 m
.4728 .89807 L
s
.29891 .63347 m .33618 .57914 L .31512 .65272 L .945 .686 .513 r
F
.29891 .63347 m .30486 .54058 L .33618 .57914 L F
.3555 .76296 m .41636 .84582 L .35642 .79034 L F
.35642 .79034 m .41636 .84582 L .41078 .89322 L F
.41636 .84582 m .89679 .7042 L .94247 .76489 L .656 .751 .92 r
F
.35642 .79034 m .89679 .7042 L .41636 .84582 L F
0 g
.81361 .71746 m
.92986 .68298 L
s
.46589 .96874 m
.94634 .8379 L
s
.41636 .84582 m
.4728 .89807 L
s
.30486 .54058 m .78858 .46882 L .29891 .63347 L .544 .324 .532 r
F
0 g
.45349 .73808 m
.90953 .59642 L
s
.30486 .54058 m .78163 .373 L .78858 .46882 L .544 .324 .532 r
F
0 g
.42895 .65673 m
.88259 .50919 L
s
.78697 .44666 m
.85026 .42515 L
s
.31051 .45227 m
.77504 .28228 L
s
.28201 .62045 m .30486 .54058 L .29891 .63347 L .945 .686 .513 r
F
.28201 .62045 m .27173 .51334 L .30486 .54058 L F
0 g
.30486 .54058 m
.31051 .45227 L
s
.23874 .49969 m .2618 .40978 L .27173 .51334 L .945 .686 .513 r
F
.23874 .49969 m .21234 .3863 L .2618 .40978 L F
0 g
.2618 .40978 m
.31051 .45227 L
s
.2618 .40978 m
.73557 .23158 L
s
.41078 .89322 m .44731 1.02748 L .3972 .93151 L .945 .686 .513 r
F
.3531 .81416 m .41078 .89322 L .3972 .93151 L F
.35642 .79034 m .41078 .89322 L .3531 .81416 L F
0 g
.88259 .50919 m
.90953 .59642 L
s
.85026 .42515 m
.88259 .50919 L
s
.90953 .59642 m
.92986 .68298 L
s
.3972 .93151 m .44731 1.02748 L .4172 1.06979 L .945 .686 .513 r
F
0 g
.44731 1.02748 m
.46589 .96874 L
s
.29264 .73131 m .34169 .70447 L .35048 .73374 L .945 .686 .513 r
F
.29264 .73131 m .32967 .6769 L .34169 .70447 L F
.29264 .73131 m .35048 .73374 L .3555 .76296 L F
0 g
.81389 .34819 m
.85026 .42515 L
s
.29264 .73131 m .31512 .65272 L .32967 .6769 L .945 .686 .513 r
F
.29264 .73131 m .3555 .76296 L .35642 .79034 L F
0 g
.92986 .68298 m
.94247 .76489 L
s
.2655 .61469 m .27173 .51334 L .28201 .62045 L .945 .686 .513 r
F
.2655 .61469 m .23874 .49969 L .27173 .51334 L F
.29264 .73131 m .29891 .63347 L .31512 .65272 L F
.29264 .73131 m .35642 .79034 L .3531 .81416 L F
.35642 .79034 m .84805 .63943 L .89679 .7042 L .656 .751 .92 r
F
.29264 .73131 m .84805 .63943 L .35642 .79034 L F
0 g
.4728 .89807 m
.94247 .76489 L
s
.35642 .79034 m
.41636 .84582 L
s
.3972 .93151 m .4172 1.06979 L .37599 .9578 L .945 .686 .513 r
F
.34566 .83283 m .3972 .93151 L .37599 .9578 L F
.3531 .81416 m .3972 .93151 L .34566 .83283 L F
.29891 .63347 m .79593 .57018 L .29264 .73131 L .544 .324 .532 r
F
.29891 .63347 m .78858 .46882 L .79593 .57018 L F
.29264 .73131 m .28201 .62045 L .29891 .63347 L .945 .686 .513 r
F
0 g
.29891 .63347 m
.30486 .54058 L
s
.77504 .28228 m
.81389 .34819 L
s
.29264 .73131 m .3531 .81416 L .34566 .83283 L .945 .686 .513 r
F
.20803 .50137 m .21234 .3863 L .23874 .49969 L F
.20803 .50137 m .16524 .38509 L .21234 .3863 L F
0 g
.21234 .3863 m
.2618 .40978 L
s
.21234 .3863 m
.69765 .20028 L
s
.94247 .76489 m
.94634 .8379 L
s
.89679 .7042 m
.94247 .76489 L
s
.29264 .73131 m .2655 .61469 L .28201 .62045 L .945 .686 .513 r
F
.34566 .83283 m .37599 .9578 L .33447 .84498 L F
.29264 .73131 m .34566 .83283 L .33447 .84498 L F
.25049 .61677 m .23874 .49969 L .2655 .61469 L F
.25049 .61677 m .20803 .50137 L .23874 .49969 L F
.37599 .9578 m .4172 1.06979 L .37643 1.09131 L F
0 g
.4172 1.06979 m
.44731 1.02748 L
s
.37599 .9578 m .37643 1.09131 L .3481 .96958 L .945 .686 .513 r
F
.33447 .84498 m .37599 .9578 L .3481 .96958 L F
.29264 .73131 m .25049 .61677 L .2655 .61469 L F
.33447 .84498 m .3481 .96958 L .32017 .84959 L F
.29264 .73131 m .33447 .84498 L .32017 .84959 L F
0 g
.73557 .23158 m
.77504 .28228 L
s
.77504 .28228 m
.78163 .373 L
s
.29264 .73131 m .30365 .8461 L .28603 .8345 L .945 .686 .513 r
F
.29264 .73131 m .32017 .84959 L .30365 .8461 L F
.29264 .73131 m .80373 .67756 L .28603 .8345 L .544 .324 .532 r
F
.29264 .73131 m .79593 .57018 L .84805 .63943 L .656 .751 .92 r
F
.29264 .73131 m .79593 .57018 L .80373 .67756 L .544 .324 .532 r
F
.29264 .73131 m .23808 .62683 L .25049 .61677 L .945 .686 .513 r
F
.29264 .73131 m .22921 .64438 L .23808 .62683 L F
.29264 .73131 m .22465 .66838 L .22921 .64438 L F
.29264 .73131 m .22484 .69717 L .22465 .66838 L F
.29264 .73131 m .22985 .72866 L .22484 .69717 L F
.29264 .73131 m .23935 .76047 L .22985 .72866 L F
.29264 .73131 m .2526 .79013 L .23935 .76047 L F
.29264 .73131 m .26858 .81542 L .2526 .79013 L F
.29264 .73131 m .28603 .8345 L .26858 .81542 L F
.22465 .66838 m .79593 .57018 L .29264 .73131 L .656 .751 .92 r
F
0 g
.29747 .65586 m
.29891 .63347 L
s
.23808 .62683 m .20803 .50137 L .25049 .61677 L .945 .686 .513 r
F
0 g
.94062 .89748 m
.94634 .8379 L
s
.32017 .84959 m .31506 .96505 L .30365 .8461 L .945 .686 .513 r
F
.32017 .84959 m .3481 .96958 L .31506 .96505 L F
.1819 .51925 m .16524 .38509 L .20803 .50137 L F
.23808 .62683 m .1819 .51925 L .20803 .50137 L F
.1819 .51925 m .12404 .40845 L .16524 .38509 L F
0 g
.16524 .38509 m
.66387 .19231 L
s
.16524 .38509 m
.21234 .3863 L
s
.84805 .63943 m
.89679 .7042 L
s
.3481 .96958 m .3269 1.08838 L .31506 .96505 L .945 .686 .513 r
F
.3481 .96958 m .37643 1.09131 L .3269 1.08838 L F
0 g
.37643 1.09131 m
.4172 1.06979 L
s
.22921 .64438 m .1819 .51925 L .23808 .62683 L .945 .686 .513 r
F
.30365 .8461 m .27905 .94351 L .28603 .8345 L F
.30365 .8461 m .31506 .96505 L .27905 .94351 L F
.22465 .66838 m .16259 .55308 L .22921 .64438 L F
.22921 .64438 m .16259 .55308 L .1819 .51925 L F
0 g
.78163 .373 m
.78858 .46882 L
s
.69765 .20028 m
.73557 .23158 L
s
.28603 .8345 m .812 .79154 L .27905 .94351 L .544 .324 .532 r
F
0 g
.44731 1.02748 m
.94062 .89748 L
s
.28603 .8345 m .80373 .67756 L .812 .79154 L .544 .324 .532 r
F
.28603 .8345 m .24275 .90568 L .26858 .81542 L .945 .686 .513 r
F
.28603 .8345 m .27905 .94351 L .24275 .90568 L F
0 g
.28603 .8345 m
.29264 .73131 L
s
.16259 .55308 m .12404 .40845 L .1819 .51925 L .945 .686 .513 r
F
.22465 .66838 m .15202 .60115 L .16259 .55308 L F
.22484 .69717 m .15202 .60115 L .22465 .66838 L F
.22465 .66838 m .74007 .49594 L .79593 .57018 L .656 .751 .92 r
F
.15202 .60115 m .74007 .49594 L .22465 .66838 L F
0 g
.22465 .66838 m
.29264 .73131 L
s
.26858 .81542 m .20916 .85395 L .2526 .79013 L .945 .686 .513 r
F
.26858 .81542 m .24275 .90568 L .20916 .85395 L F
0 g
.94062 .89748 m
.9248 .93889 L
s
.31506 .96505 m .27167 1.05883 L .27905 .94351 L .945 .686 .513 r
F
.31506 .96505 m .3269 1.08838 L .27167 1.05883 L F
0 g
.3269 1.08838 m
.37643 1.09131 L
s
.22484 .69717 m .15151 .66025 L .15202 .60115 L .945 .686 .513 r
F
.22985 .72866 m .15151 .66025 L .22484 .69717 L F
.2526 .79013 m .18123 .79226 L .23935 .76047 L F
.2526 .79013 m .20916 .85395 L .18123 .79226 L F
.22985 .72866 m .16146 .72579 L .15151 .66025 L F
.23935 .76047 m .16146 .72579 L .22985 .72866 L F
.23935 .76047 m .18123 .79226 L .16146 .72579 L F
.16259 .55308 m .09252 .45705 L .12404 .40845 L F
0 g
.12404 .40845 m
.16524 .38509 L
s
.79593 .57018 m
.84805 .63943 L
s
.15202 .60115 m .09252 .45705 L .16259 .55308 L .945 .686 .513 r
F
0 g
.78858 .46882 m
.79593 .57018 L
s
.27905 .94351 m .82079 .91273 L .27167 1.05883 L .544 .324 .532 r
F
0 g
.3269 1.08838 m
.86358 .94956 L
s
.37643 1.09131 m
.89886 .95754 L
s
.27905 .94351 m .812 .79154 L .82079 .91273 L .544 .324 .532 r
F
0 g
.4172 1.06979 m
.9248 .93889 L
s
.27905 .94351 m .21497 1.00278 L .24275 .90568 L .945 .686 .513 r
F
.27905 .94351 m .27167 1.05883 L .21497 1.00278 L F
0 g
.27905 .94351 m
.28603 .8345 L
s
.27167 1.05883 m
.3269 1.08838 L
s
.27167 1.05883 m
.27905 .94351 L
s
.66387 .19231 m
.69765 .20028 L
s
.15202 .60115 m .07425 .52916 L .09252 .45705 L .945 .686 .513 r
F
.15151 .66025 m .07425 .52916 L .15202 .60115 L F
.15202 .60115 m .68005 .41618 L .74007 .49594 L .656 .751 .92 r
F
.07425 .52916 m .68005 .41618 L .15202 .60115 L F
0 g
.15202 .60115 m
.22465 .66838 L
s
.09252 .45705 m
.12404 .40845 L
s
.9248 .93889 m
.89886 .95754 L
s
.24275 .90568 m .16189 .92341 L .20916 .85395 L .945 .686 .513 r
F
.24275 .90568 m .21497 1.00278 L .16189 .92341 L F
.15151 .66025 m .07192 .62017 L .07425 .52916 L F
.16146 .72579 m .07192 .62017 L .15151 .66025 L F
0 g
.74007 .49594 m
.79593 .57018 L
s
.79593 .57018 m
.80373 .67756 L
s
.20916 .85395 m .11762 .82707 L .18123 .79226 L .945 .686 .513 r
F
.20916 .85395 m .16189 .92341 L .11762 .82707 L F
0 g
.27167 1.05883 m
.82079 .91273 L
s
.21497 1.00278 m
.27167 1.05883 L
s
.16146 .72579 m .08666 .72264 L .07192 .62017 L .945 .686 .513 r
F
.18123 .79226 m .08666 .72264 L .16146 .72579 L F
.18123 .79226 m .11762 .82707 L .08666 .72264 L F
0 g
.63705 .21077 m
.66387 .19231 L
s
.07425 .52916 m .61537 .33024 L .68005 .41618 L .656 .751 .92 r
F
0 g
.07425 .52916 m
.61537 .33024 L
s
.07425 .52916 m
.15202 .60115 L
s
.07425 .52916 m
.09252 .45705 L
s
.09252 .45705 m
.62007 .25712 L
s
.12404 .40845 m
.63705 .21077 L
s
.07192 .62017 m
.07425 .52916 L
s
.89886 .95754 m
.86358 .94956 L
s
.16189 .92341 m
.21497 1.00278 L
s
.21497 1.00278 m
.77351 .84741 L
s
.80373 .67756 m
.812 .79154 L
s
.68005 .41618 m
.74007 .49594 L
s
.07192 .62017 m
.62447 .42574 L
s
.07192 .62017 m
.08666 .72264 L
s
.11762 .82707 m
.16189 .92341 L
s
.16189 .92341 m
.72579 .75743 L
s
.62007 .25712 m
.63705 .21077 L
s
.08666 .72264 m
.64736 .53585 L
s
.08666 .72264 m
.11762 .82707 L
s
.11762 .82707 m
.68226 .65018 L
s
.82079 .91273 m
.86358 .94956 L
s
.812 .79154 m
.82079 .91273 L
s
.61537 .33024 m
.68005 .41618 L
s
.61537 .33024 m
.62007 .25712 L
s
.77351 .84741 m
.82079 .91273 L
s
.61537 .33024 m
.62447 .42574 L
s
.77351 .84741 m
.72579 .75743 L
s
.64736 .53585 m
.62447 .42574 L
s
.72579 .75743 m
.68226 .65018 L
s
.68226 .65018 m
.64736 .53585 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.226388 0.494527 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.212733 1.50843 0 1.50843 [
[.5 1.45383 -34.125 0 ]
[.5 1.45383 34.125 12 ]
[ 0 0 0 0 ]
[ 1 1.44133 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.45383 -95.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ParabolicMirror) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.44133 L
0 1.44133 L
closepath
clip
newpath
.6334 .69458 m .49572 .73061 L .52616 .83118 L .471 .43 .73 r
F
.60237 .61896 m .49572 .73061 L .6334 .69458 L .485 .492 .789 r
F
.60237 .61896 m .45546 .63492 L .49572 .73061 L F
.65756 .77393 m .52616 .83118 L .54537 .93204 L .441 .355 .663 r
F
.6334 .69458 m .52616 .83118 L .65756 .77393 L .471 .43 .73 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.49572 .73061 m
.52616 .83118 L
s
.56595 .55099 m .45546 .63492 L .60237 .61896 L .484 .549 .847 r
F
.56595 .55099 m .40708 .54868 L .45546 .63492 L F
0 g
.45546 .63492 m
.49572 .73061 L
s
.6736 .85299 m .54537 .93204 L .55214 1.02845 L .387 .255 .577 r
F
.65756 .77393 m .54537 .93204 L .6736 .85299 L .441 .355 .663 r
F
0 g
.52616 .83118 m
.54537 .93204 L
s
.5259 .49455 m .40708 .54868 L .56595 .55099 L .459 .605 .908 r
F
.5259 .49455 m .35262 .47652 L .40708 .54868 L F
0 g
.40708 .54868 m
.45546 .63492 L
s
.6736 .85299 m .55214 1.02845 L .68053 .92769 L .387 .255 .577 r
F
.62119 .9774 m .5571 1.02704 L .55214 1.02845 L .656 .751 .92 r
F
.62119 .9774 m .62632 .97593 L .5571 1.02704 L F
.68053 .92769 m .62632 .97593 L .62119 .9774 L F
.68053 .92769 m .68582 .92615 L .62632 .97593 L F
.68053 .92769 m .55214 1.02845 L .54552 1.11535 L .29 .104 .448 r
F
0 g
.54537 .93204 m
.55214 1.02845 L
s
.35262 .47652 m .44875 .48125 L .44368 .48308 L .544 .324 .532 r
F
.35262 .47652 m .35753 .47472 L .44875 .48125 L F
.44368 .48308 m .53113 .49269 L .5259 .49455 L F
.44368 .48308 m .44875 .48125 L .53113 .49269 L F
.4843 .45336 m .35262 .47652 L .5259 .49455 L .382 .653 .964 r
F
.4843 .45336 m .29457 .4231 L .35262 .47652 L F
0 g
.35262 .47652 m
.40708 .54868 L
s
.67763 .99381 m .54552 1.11535 L .52498 1.18739 L .095 0 .213 r
F
0 g
.55086 1.11044 m
.55107 1.10765 L
s
.68053 .92769 m .54552 1.11535 L .67763 .99381 L .29 .104 .448 r
F
0 g
.54552 1.11535 m
.55214 1.02845 L
s
.71074 .61925 m .6334 .69458 L .73204 .6721 L .398 .44 .788 r
F
.71074 .61925 m .60237 .61896 L .6334 .69458 L F
.73204 .6721 m .6334 .69458 L .65756 .77393 L .385 .375 .725 r
F
.74898 .72752 m .65756 .77393 L .6736 .85299 L .347 .292 .652 r
F
.73204 .6721 m .65756 .77393 L .74898 .72752 L .385 .375 .725 r
F
.68623 .57199 m .60237 .61896 L .71074 .61925 L .385 .494 .847 r
F
.68623 .57199 m .56595 .55099 L .60237 .61896 L F
.76061 .78241 m .6736 .85299 L .68053 .92769 L .276 .175 .555 r
F
.74898 .72752 m .6736 .85299 L .76061 .78241 L .347 .292 .652 r
F
.44355 .43084 m .29457 .4231 L .4843 .45336 L .173 .636 .935 r
F
.44355 .43084 m .236 .39303 L .29457 .4231 L F
0 g
.29457 .4231 m
.35262 .47652 L
s
.65987 .53317 m .56595 .55099 L .68623 .57199 L .335 .538 .903 r
F
.65987 .53317 m .5259 .49455 L .56595 .55099 L F
.76061 .78241 m .68053 .92769 L .76619 .83367 L .276 .175 .555 r
F
.72918 .87966 m .68582 .92615 L .68053 .92769 L .656 .751 .92 r
F
.72918 .87966 m .73462 .87805 L .68582 .92615 L F
.76619 .83367 m .73462 .87805 L .72918 .87966 L F
.76619 .83367 m .77175 .832 L .73462 .87805 L F
.76619 .83367 m .68053 .92769 L .67763 .99381 L .141 0 .401 r
F
.66455 1.04711 m .52498 1.18739 L .49054 1.23903 L 0 0 0 r
F
0 g
.53239 1.17819 m
.53248 1.17787 L
s
.5317 1.18063 m
.53239 1.17819 L
s
.67763 .99381 m .52498 1.18739 L .66455 1.04711 L .095 0 .213 r
F
0 g
.52498 1.18739 m
.54552 1.11535 L
s
.5259 .49455 m .60368 .50929 L .59828 .51117 L .544 .324 .532 r
F
.5259 .49455 m .53113 .49269 L .60368 .50929 L F
.59828 .51117 m .6654 .53126 L .65987 .53317 L F
.59828 .51117 m .60368 .50929 L .6654 .53126 L F
.63316 .50539 m .5259 .49455 L .65987 .53317 L .205 .552 .932 r
F
.63316 .50539 m .4843 .45336 L .5259 .49455 L F
.76523 .8782 m .67763 .99381 L .66455 1.04711 L 0 0 .121 r
F
.76619 .83367 m .67763 .99381 L .76523 .8782 L .141 0 .401 r
F
.40636 .42979 m .236 .39303 L .44355 .43084 L .239 0 0 r
F
0 g
.24748 .39436 m
.24977 .39554 L
s
.40636 .42979 m .18059 .39041 L .236 .39303 L .239 0 0 r
F
0 g
.25677 .4037 m
.29457 .4231 L
s
.24111 .39107 m
.24748 .39436 L
s
.236 .39303 m
.24111 .39107 L
s
.77261 .63817 m .73204 .6721 L .7836 .66569 L .146 .279 .744 r
F
.77261 .63817 m .71074 .61925 L .73204 .6721 L F
.7836 .66569 m .73204 .6721 L .74898 .72752 L .138 .212 .679 r
F
.79245 .69458 m .74898 .72752 L .76061 .78241 L .084 .111 .591 r
F
.7836 .66569 m .74898 .72752 L .79245 .69458 L .138 .212 .679 r
F
.76014 .61372 m .71074 .61925 L .77261 .63817 L .103 .317 .791 r
F
.76014 .61372 m .68623 .57199 L .71074 .61925 L F
.60777 .49086 m .4843 .45336 L .63316 .50539 L 0 .451 .809 r
F
.60777 .49086 m .44355 .43084 L .4843 .45336 L F
.79861 .72305 m .76061 .78241 L .76619 .83367 L 0 0 .462 r
F
.79245 .69458 m .76061 .78241 L .79861 .72305 L .084 .111 .591 r
F
.66455 1.04711 m .49054 1.23903 L .64142 1.08348 L 0 0 0 r
F
.64142 1.08348 m .49054 1.23903 L .44314 1.26489 L .718 .976 .752 r
F
0 g
.49054 1.23903 m
.49588 1.23765 L
s
.49588 1.23765 m
.49962 1.23202 L
s
.49962 1.23202 m
.50458 1.22455 L
s
.52049 1.19412 m
.52498 1.18739 L
s
.49101 1.24031 m
.49588 1.23765 L
s
.74696 .59393 m .68623 .57199 L .76014 .61372 L 0 .315 .805 r
F
.74696 .59393 m .65987 .53317 L .68623 .57199 L F
.75756 .91305 m .66455 1.04711 L .64142 1.08348 L 0 0 0 r
F
.76523 .8782 m .66455 1.04711 L .75756 .91305 L 0 0 .121 r
F
.79861 .72305 m .76619 .83367 L .80167 .74933 L 0 0 .462 r
F
.79063 .7901 m .77175 .832 L .76619 .83367 L .656 .751 .92 r
F
.79063 .7901 m .79632 .78837 L .77175 .832 L F
.80167 .74933 m .76619 .83367 L .76523 .8782 L 0 0 .254 r
F
.65987 .53317 m .71538 .55879 L .70972 .56071 L .544 .324 .532 r
F
.65987 .53317 m .6654 .53126 L .71538 .55879 L F
.70972 .56071 m .75274 .59201 L .74696 .59393 L F
.73391 .58014 m .65987 .53317 L .74696 .59393 L 0 .238 .726 r
F
.73391 .58014 m .63316 .50539 L .65987 .53317 L F
.80167 .74933 m .79632 .78837 L .79063 .7901 L .656 .751 .92 r
F
.80167 .74933 m .80746 .74754 L .79632 .78837 L F
.8014 .77173 m .76523 .8782 L .75756 .91305 L 0 0 0 r
F
0 g
.7849 .80865 m
.78605 .8066 L
s
.80167 .74933 m .76523 .8782 L .8014 .77173 L 0 0 .254 r
F
0 g
.79615 .78867 m
.79632 .78837 L
s
.58544 .49119 m .44355 .43084 L .60777 .49086 L .457 0 0 r
F
.58544 .49119 m .40636 .42979 L .44355 .43084 L F
.3756 .45194 m .18059 .39041 L .40636 .42979 L .533 .023 0 r
F
0 g
.18583 .38838 m
.19186 .38867 L
s
.19186 .38867 m
.24111 .39107 L
s
.3756 .45194 m .13258 .41818 L .18059 .39041 L .533 .023 0 r
F
0 g
.18059 .39041 m
.236 .39303 L
s
.18059 .39041 m
.18583 .38838 L
s
.1809 .39123 m
.18583 .38838 L
s
.13795 .41611 m
.1809 .39123 L
s
.8073 .74814 m
.80746 .74754 L
s
.79632 .78837 m
.79689 .78629 L
s
.80143 .76965 m
.8073 .74814 L
s
.72184 .57337 m .63316 .50539 L .73391 .58014 L .512 0 0 r
F
0 g
.67562 .53689 m
.69451 .5473 L
s
.72184 .57337 m .60777 .49086 L .63316 .50539 L .512 0 0 r
F
.64142 1.08348 m .44314 1.26489 L .60904 1.09926 L .718 .976 .752 r
F
.75756 .91305 m .64142 1.08348 L .74337 .93557 L 0 0 0 r
F
.74337 .93557 m .64142 1.08348 L .60904 1.09926 L .842 .994 .748 r
F
.70972 .56071 m .71538 .55879 L .75274 .59201 L .544 .324 .532 r
F
0 g
.69451 .5473 m
.71538 .55879 L
s
.70191 .55639 m
.70972 .56071 L
s
.70972 .56071 m
.71958 .56951 L
s
.75219 .59153 m
.75274 .59201 L
s
.8014 .77173 m .75756 .91305 L .79776 .78874 L 0 0 0 r
F
.79776 .78874 m .75756 .91305 L .74337 .93557 L .844 .886 .456 r
F
.60904 1.09926 m .44314 1.26489 L .38489 1.26046 L .83 .959 .895 r
F
0 g
.44314 1.26489 m
.44862 1.26348 L
s
.44314 1.26489 m
.49054 1.23903 L
s
.44862 1.26348 m
.45378 1.26066 L
s
.45378 1.26066 m
.49101 1.24031 L
s
.7836 .66569 m
.79245 .69458 L
s
.7836 .66569 m
.78934 .66385 L
s
.77261 .63817 m
.7836 .66569 L
s
.79245 .69458 m
.79861 .72305 L
s
.79245 .69458 m
.7982 .69276 L
s
.44264 1.26302 m
.44862 1.26348 L
s
.78934 .66385 m
.7982 .69276 L
s
.77835 .6363 m
.78934 .66385 L
s
.7982 .69276 m
.80438 .72125 L
s
.77261 .63817 m
.77835 .6363 L
s
.76014 .61372 m
.77261 .63817 L
s
.76589 .61183 m
.77835 .6363 L
s
.79861 .72305 m
.80167 .74933 L
s
.79861 .72305 m
.80438 .72125 L
s
.80438 .72125 m
.80746 .74754 L
s
.76014 .61372 m
.76589 .61183 L
s
.74696 .59393 m
.76014 .61372 L
s
.75274 .59201 m
.76589 .61183 L
s
.80167 .74933 m
.80746 .74754 L
s
.8014 .77173 m
.80167 .74933 L
s
.80723 .76994 m
.80746 .74754 L
s
.71157 .57426 m .60777 .49086 L .72184 .57337 L .704 .17 0 r
F
0 g
.71538 .55879 m
.75219 .59153 L
s
.71157 .57426 m .58544 .49119 L .60777 .49086 L .704 .17 0 r
F
0 g
.74696 .59393 m
.75274 .59201 L
s
.73391 .58014 m
.74696 .59393 L
s
.56786 .50712 m .40636 .42979 L .58544 .49119 L .641 .154 .078 r
F
.56786 .50712 m .3756 .45194 L .40636 .42979 L F
0 g
.73972 .57819 m
.75274 .59201 L
s
.8014 .77173 m
.80723 .76994 L
s
.80723 .76994 m
.80363 .78695 L
s
.74337 .93557 m .60904 1.09926 L .72327 .94365 L .842 .994 .748 r
F
.7909 .79911 m .74337 .93557 L .72327 .94365 L .951 .954 .683 r
F
.79776 .78874 m .74337 .93557 L .7909 .79911 L .844 .886 .456 r
F
0 g
.79776 .78874 m
.8014 .77173 L
s
.73391 .58014 m
.73972 .57819 L
s
.72184 .57337 m
.73391 .58014 L
s
.72768 .57141 m
.73972 .57819 L
s
.60904 1.09926 m .38489 1.26046 L .56901 1.09171 L .83 .959 .895 r
F
.72327 .94365 m .60904 1.09926 L .56901 1.09171 L .883 .944 .848 r
F
0 g
.79776 .78874 m
.80363 .78695 L
s
.79681 .79731 m
.80363 .78695 L
s
.35409 .49741 m .13258 .41818 L .3756 .45194 L .634 .25 .299 r
F
.35409 .49741 m .09643 .4773 L .13258 .41818 L F
0 g
.13258 .41818 m
.18059 .39041 L
s
.13258 .41818 m
.13795 .41611 L
s
.13424 .4222 m
.13795 .41611 L
s
.10195 .47521 m
.13424 .4222 L
s
.72184 .57337 m
.72768 .57141 L
s
.70387 .58294 m .58544 .49119 L .71157 .57426 L .772 .324 .187 r
F
0 g
.71157 .57426 m
.72184 .57337 L
s
.70387 .58294 m .56786 .50712 L .58544 .49119 L .772 .324 .187 r
F
0 g
.71746 .57228 m
.72768 .57141 L
s
.7909 .79911 m .72327 .94365 L .78121 .80197 L .951 .954 .683 r
F
0 g
.7909 .79911 m
.79681 .79731 L
s
.7909 .79911 m
.79776 .78874 L
s
.78717 .80016 m
.79681 .79731 L
s
.56901 1.09171 m .38489 1.26046 L .31936 1.22305 L .815 .855 .878 r
F
0 g
.38489 1.26046 m
.39052 1.259 L
s
.38489 1.26046 m
.44314 1.26489 L
s
.39052 1.259 m
.39686 1.25949 L
s
.39686 1.25949 m
.44264 1.26302 L
s
.72327 .94365 m .56901 1.09171 L .69839 .93596 L .883 .944 .848 r
F
.78121 .80197 m .72327 .94365 L .69839 .93596 L .942 .906 .757 r
F
0 g
.38377 1.25513 m
.39052 1.259 L
s
.71157 .57426 m
.71746 .57228 L
s
.70981 .58095 m
.71746 .57228 L
s
.55658 .53829 m .3756 .45194 L .56786 .50712 L .698 .32 .329 r
F
.55658 .53829 m .35409 .49741 L .3756 .45194 L F
.78121 .80197 m .69839 .93596 L .7693 .79694 L .942 .906 .757 r
F
0 g
.78121 .80197 m
.78717 .80016 L
s
.78121 .80197 m
.7909 .79911 L
s
.7753 .79511 m
.78717 .80016 L
s
.69935 .59899 m .56786 .50712 L .70387 .58294 L .788 .42 .361 r
F
0 g
.70387 .58294 m
.70981 .58095 L
s
.70387 .58294 m
.71157 .57426 L
s
.69935 .59899 m .55658 .53829 L .56786 .50712 L .788 .42 .361 r
F
.56901 1.09171 m .31936 1.22305 L .52383 1.05966 L .815 .855 .878 r
F
.69839 .93596 m .56901 1.09171 L .52383 1.05966 L .853 .85 .839 r
F
0 g
.70532 .597 m
.70981 .58095 L
s
.7693 .79694 m .67032 .91228 L .75594 .78418 L .906 .836 .766 r
F
.7693 .79694 m .69839 .93596 L .67032 .91228 L F
0 g
.7693 .79694 m
.78121 .80197 L
s
.7693 .79694 m
.7753 .79511 L
s
.69839 .93596 m .52383 1.05966 L .67032 .91228 L .853 .85 .839 r
F
.69839 .62143 m .55658 .53829 L .69935 .59899 L .791 .486 .473 r
F
0 g
.69935 .59899 m
.70532 .597 L
s
.69935 .59899 m
.70387 .58294 L
s
.34419 .56419 m .09643 .4773 L .35409 .49741 L .672 .376 .464 r
F
.34419 .56419 m .07633 .56576 L .09643 .4773 L F
0 g
.09643 .4773 m
.13258 .41818 L
s
.09643 .4773 m
.10195 .47521 L
s
.75594 .78418 m .64107 .87371 L .74208 .76444 L .872 .773 .75 r
F
.75594 .78418 m .67032 .91228 L .64107 .87371 L F
.75594 .78418 m .72685 .84383 L .72081 .84565 L .544 .324 .532 r
F
.75594 .78418 m .76197 .78233 L .72685 .84383 L F
0 g
.75916 .78726 m
.7693 .79694 L
s
.75594 .78418 m
.76197 .78233 L
s
.76197 .78233 m
.7753 .79511 L
s
.09988 .48437 m
.10195 .47521 L
s
.74814 .76255 m
.76197 .78233 L
s
.69839 .62143 m .55273 .58304 L .55658 .53829 L .791 .486 .473 r
F
.70115 .64874 m .55273 .58304 L .69839 .62143 L .794 .538 .55 r
F
.63352 .59988 m .70441 .61944 L .69839 .62143 L .656 .751 .92 r
F
0 g
.69854 .61782 m
.69935 .59899 L
s
.63352 .59988 m .63954 .59786 L .70441 .61944 L .656 .751 .92 r
F
0 g
.70348 .61913 m
.70441 .61944 L
s
.70441 .61944 m
.70532 .597 L
s
.69839 .62143 m
.70441 .61944 L
s
.55273 .58304 m .35409 .49741 L .55658 .53829 L .719 .42 .471 r
F
.74208 .76444 m .61294 .82278 L .72873 .73904 L .845 .719 .724 r
F
0 g
.76147 .78321 m
.76197 .78233 L
s
.74208 .76444 m .64107 .87371 L .61294 .82278 L .845 .719 .724 r
F
0 g
.74208 .76444 m
.75594 .78418 L
s
.74208 .76444 m
.74814 .76255 L
s
.72081 .84565 m .67635 .91051 L .67032 .91228 L .544 .324 .532 r
F
.72081 .84565 m .72685 .84383 L .67635 .91051 L F
0 g
.72081 .84565 m
.75594 .78418 L
s
.72685 .84383 m
.76147 .78321 L
s
.55273 .58304 m .34419 .56419 L .35409 .49741 L .719 .42 .471 r
F
0 g
.7348 .73713 m
.74814 .76255 L
s
.70602 .87134 m
.72685 .84383 L
s
.52383 1.05966 m .31936 1.22305 L .25152 1.15289 L .787 .766 .834 r
F
0 g
.33223 1.22561 m
.38377 1.25513 L
s
.42855 1.13959 m .3251 1.22152 L .31936 1.22305 L .544 .324 .532 r
F
0 g
.31936 1.22305 m
.38489 1.26046 L
s
.42855 1.13959 m .4344 1.13799 L .3251 1.22152 L .544 .324 .532 r
F
0 g
.31808 1.21424 m
.3251 1.22152 L
s
.31936 1.22305 m
.3251 1.22152 L
s
.3251 1.22152 m
.33223 1.22561 L
s
.70115 .64874 m .55693 .63838 L .55273 .58304 L .794 .538 .55 r
F
.70746 .67895 m .55693 .63838 L .70115 .64874 L .8 .583 .608 r
F
0 g
.69839 .62143 m
.70115 .64874 L
s
.70115 .64874 m
.70719 .64676 L
s
.70444 .61973 m
.70719 .64676 L
s
.70441 .61944 m
.70444 .61973 L
s
.72873 .73904 m .58825 .76332 L .71689 .70982 L .825 .67 .692 r
F
.72873 .73904 m .61294 .82278 L .58825 .76332 L F
0 g
.72873 .73904 m
.74208 .76444 L
s
.72873 .73904 m
.7348 .73713 L
s
.67032 .91228 m .47683 1.00404 L .64107 .87371 L .82 .77 .806 r
F
.67032 .91228 m .52383 1.05966 L .47683 1.00404 L F
.67032 .91228 m .61056 .98202 L .60457 .98374 L .544 .324 .532 r
F
.67032 .91228 m .67635 .91051 L .61056 .98202 L F
0 g
.67032 .91228 m
.72081 .84565 L
s
.67635 .91051 m
.70602 .87134 L
s
.72297 .70789 m
.7348 .73713 L
s
.65863 .92976 m
.67635 .91051 L
s
.52383 1.05966 m .4344 1.13799 L .42855 1.13959 L .544 .324 .532 r
F
0 g
.31936 1.22305 m
.42855 1.13959 L
s
.70746 .67895 m .56905 .70013 L .55693 .63838 L .8 .583 .608 r
F
0 g
.70719 .64676 m
.71353 .67699 L
s
.71689 .70982 m .56905 .70013 L .70746 .67895 L .81 .626 .654 r
F
0 g
.70115 .64874 m
.70746 .67895 L
s
.70746 .67895 m
.71353 .67699 L
s
.71689 .70982 m .58825 .76332 L .56905 .70013 L .81 .626 .654 r
F
0 g
.71689 .70982 m
.72297 .70789 L
s
.71689 .70982 m
.72873 .73904 L
s
.70746 .67895 m
.71689 .70982 L
s
.52383 1.05966 m .52976 1.05799 L .4344 1.13799 L .544 .324 .532 r
F
0 g
.3251 1.22152 m
.4344 1.13799 L
s
.71353 .67699 m
.72297 .70789 L
s
.60457 .98374 m .52976 1.05799 L .52383 1.05966 L .544 .324 .532 r
F
.60457 .98374 m .61056 .98202 L .52976 1.05799 L F
0 g
.60457 .98374 m
.67032 .91228 L
s
.61056 .98202 m
.65863 .92976 L
s
.55273 .58304 m .63954 .59786 L .63352 .59988 L .656 .751 .92 r
F
0 g
.63352 .59988 m
.69839 .62143 L
s
.52383 1.05966 m .25152 1.15289 L .47683 1.00404 L .787 .766 .834 r
F
0 g
.52383 1.05966 m
.60457 .98374 L
s
.50401 1.0796 m
.52976 1.05799 L
s
.42855 1.13959 m
.52383 1.05966 L
s
.4344 1.13799 m
.50401 1.0796 L
s
.52976 1.05799 m
.61056 .98202 L
s
.55273 .58304 m .55872 .58099 L .63954 .59786 L .656 .751 .92 r
F
0 g
.63954 .59786 m
.70348 .61913 L
s
.55693 .63838 m .34419 .56419 L .55273 .58304 L .731 .49 .562 r
F
.45617 .5711 m .55872 .58099 L .55273 .58304 L .656 .751 .92 r
F
0 g
.55273 .58304 m
.63352 .59988 L
s
.45617 .5711 m .46211 .56903 L .55872 .58099 L .656 .751 .92 r
F
0 g
.55872 .58099 m
.63954 .59786 L
s
.64107 .87371 m .43193 .9283 L .61294 .82278 L .793 .704 .767 r
F
.64107 .87371 m .47683 1.00404 L .43193 .9283 L F
.34419 .56419 m .46211 .56903 L .45617 .5711 L .656 .751 .92 r
F
0 g
.45617 .5711 m
.55273 .58304 L
s
.34419 .56419 m .35006 .56211 L .46211 .56903 L .656 .751 .92 r
F
0 g
.46211 .56903 m
.55872 .58099 L
s
.07633 .56576 m .22311 .56032 L .21734 .56241 L .656 .751 .92 r
F
.07633 .56576 m .08198 .56368 L .22311 .56032 L F
0 g
.08198 .56368 m
.09988 .48437 L
s
.34746 .64794 m .07633 .56576 L .34419 .56419 L .693 .459 .565 r
F
.34746 .64794 m .07537 .67794 L .07633 .56576 L F
0 g
.07633 .56576 m
.09643 .4773 L
s
.07633 .56576 m
.08198 .56368 L
s
.21734 .56241 m .35006 .56211 L .34419 .56419 L .656 .751 .92 r
F
.55693 .63838 m .34746 .64794 L .34419 .56419 L .731 .49 .562 r
F
0 g
.34419 .56419 m
.45617 .5711 L
s
.38035 .56398 m
.46211 .56903 L
s
.21734 .56241 m .22311 .56032 L .35006 .56211 L .656 .751 .92 r
F
0 g
.08198 .56368 m
.22311 .56032 L
s
.21734 .56241 m
.34419 .56419 L
s
.35006 .56211 m
.38035 .56398 L
s
.07633 .56576 m
.21734 .56241 L
s
.22311 .56032 m
.35006 .56211 L
s
.56905 .70013 m .34746 .64794 L .55693 .63838 L .742 .546 .628 r
F
.61294 .82278 m .39319 .83838 L .58825 .76332 L .772 .649 .726 r
F
.61294 .82278 m .43193 .9283 L .39319 .83838 L F
.47683 1.00404 m .18741 1.05394 L .43193 .9283 L .761 .695 .788 r
F
.47683 1.00404 m .25152 1.15289 L .18741 1.05394 L F
0 g
.25152 1.15289 m
.31936 1.22305 L
s
.25735 1.15126 m
.26469 1.15888 L
s
.26469 1.15888 m
.31808 1.21424 L
s
.25152 1.15289 m
.25735 1.15126 L
s
.56905 .70013 m .36418 .74205 L .34746 .64794 L .742 .546 .628 r
F
.58825 .76332 m .36418 .74205 L .56905 .70013 L .756 .597 .681 r
F
.58825 .76332 m .39319 .83838 L .36418 .74205 L F
.36418 .74205 m .07537 .67794 L .34746 .64794 L .708 .523 .636 r
F
0 g
.08113 .67591 m
.08122 .6638 L
s
.08122 .6638 m
.08198 .56368 L
s
.43193 .9283 m .13333 .93417 L .39319 .83838 L .741 .635 .742 r
F
.43193 .9283 m .18741 1.05394 L .13333 .93417 L F
0 g
.19329 1.05221 m
.20019 1.06288 L
s
.20019 1.06288 m
.25735 1.15126 L
s
.18741 1.05394 m
.25152 1.15289 L
s
.36418 .74205 m .09477 .80467 L .07537 .67794 L .708 .523 .636 r
F
0 g
.07537 .67794 m
.08113 .67591 L
s
.07537 .67794 m
.07633 .56576 L
s
.39319 .83838 m .09477 .80467 L .36418 .74205 L .724 .58 .693 r
F
0 g
.09853 .78914 m
.10062 .80272 L
s
.08113 .67591 m
.09853 .78914 L
s
.18741 1.05394 m
.19329 1.05221 L
s
.39319 .83838 m .13333 .93417 L .09477 .80467 L .724 .58 .693 r
F
0 g
.13333 .93417 m
.18741 1.05394 L
s
.07537 .67794 m
.09477 .80467 L
s
.13922 .93233 m
.14499 .94513 L
s
.14499 .94513 m
.19329 1.05221 L
s
.09477 .80467 m
.13333 .93417 L
s
.09477 .80467 m
.10062 .80272 L
s
.13512 .91857 m
.13922 .93233 L
s
.10062 .80272 m
.13512 .91857 L
s
.13333 .93417 m
.13922 .93233 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.226388 0.614943 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0323494 1.13541 0 1.13541 [
[.5 1.04986 -28 0 ]
[.5 1.04986 28 12 ]
[ 0 0 0 0 ]
[ 1 1.03736 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.04986 -89 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PechanPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03736 L
0 1.03736 L
closepath
clip
newpath
.86172 .55114 m .41514 .57857 L .40467 .94 L .671 .439 .561 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.4151 .57871 m
.41513 .57866 L
s
.4151 .57871 m
.41513 .57871 L
s
.86155 .55129 m
.86169 .55128 L
s
.86172 .55114 m .40467 .94 L .89052 .91502 L .671 .439 .561 r
F
0 g
.86172 .55114 m
.89052 .91502 L
s
.86173 .55126 m
.86189 .55121 L
s
.86189 .55121 m
.94191 .52656 L
s
.86161 .55115 m
.94182 .52644 L
s
.89037 .91503 m
.89037 .91503 L
s
.40462 .93985 m
.41509 .57841 L
s
.40452 .93989 m
.41499 .57845 L
s
.40474 .94008 m
.40474 .94 L
s
.40467 .94 m
.41514 .57857 L
s
.41514 .57857 m
.86172 .55114 L
s
.97815 .89257 m
.94186 .52653 L
s
.94186 .52653 m
.63241 .09691 L
s
.97811 .89248 m
.94182 .52644 L
s
.94191 .52656 m
.63246 .09692 L
s
.40464 .93995 m
.40467 .93995 L
s
.40464 .93995 m
.40466 .9399 L
s
.40474 .94008 m
.40479 .93999 L
s
.40467 .94 m
.89052 .91502 L
s
.89069 .91491 m
.97819 .89242 L
s
.89051 .91496 m
.89069 .91491 L
s
.89039 .91503 m
.97811 .89248 L
s
.89037 .91503 m
.89039 .91503 L
s
.49139 .06639 m .18566 .34329 L .15167 .72401 L .256 .075 .434 r
F
0 g
.15161 .72389 m
.15165 .72393 L
s
.15165 .72393 m
.15167 .72395 L
s
.15169 .72396 m
.40455 .93983 L
s
.18559 .34336 m
.18563 .34339 L
s
.18563 .34339 m
.18565 .34342 L
s
.29197 .45242 m
.41502 .57859 L
s
.18567 .34316 m
.18573 .34322 L
s
.29206 .45225 m
.41509 .57841 L
s
.6429 .49347 m
.97815 .89257 L
s
.97819 .89242 m
.64294 .49329 L
s
.49139 .06639 m .15167 .72401 L .48658 .4646 L .256 .075 .434 r
F
0 g
.15167 .72401 m
.48658 .4646 L
s
.15161 .72389 m
.48651 .46447 L
s
.15167 .72389 m
.18567 .34316 L
s
.18559 .34336 m
.49133 .06646 L
s
.41499 .57845 m
.45548 .48869 L
s
.48714 .4185 m
.63234 .09657 L
s
.41502 .57859 m
.45562 .48858 L
s
.48714 .41871 m
.63237 .09673 L
s
.41524 .57857 m
.45597 .48831 L
s
.48713 .41924 m
.63257 .09689 L
s
.41513 .57866 m
.45584 .48841 L
s
.48713 .41905 m
.63246 .09692 L
s
.40466 .9399 m
.64294 .49329 L
s
.40479 .93999 m
.64307 .49345 L
s
.40455 .93983 m
.64285 .49311 L
s
.40452 .93989 m
.64282 .49316 L
s
.15174 .72395 m
.40462 .93985 L
s
.15167 .72389 m
.15174 .72395 L
s
.15167 .72401 m
.18566 .34329 L
s
.18566 .34329 m
.49139 .06639 L
s
.63241 .09691 m
.6429 .49347 L
s
.64307 .49345 m
.63257 .09689 L
s
.64276 .49331 m
.63229 .09673 L
s
.63229 .09673 m
.58409 .02981 L
s
.63237 .09673 m
.58417 .0298 L
s
.64282 .49316 m
.63234 .09657 L
s
.48646 .46468 m
.49128 .06648 L
s
.49128 .06648 m
.49131 .06647 L
s
.49139 .06643 m
.58412 .02982 L
s
.48658 .4646 m
.49139 .06639 L
s
.49133 .06646 m
.49147 .0664 L
s
.49147 .0664 m
.58417 .0298 L
s
.58954 .42991 m
.58412 .02982 L
s
.58409 .02981 m
.5895 .4299 L
s
.5895 .4299 m
.64276 .49331 L
s
.64285 .49311 m
.58959 .4297 L
s
.48646 .46468 m
.48649 .46467 L
s
.48649 .46467 m
.58954 .42991 L
s
.48651 .46447 m
.48667 .46442 L
s
.48667 .46442 m
.58959 .4297 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.226388 0.735359 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.000317684 1.05183 5.55112e-17 1.05183 [
[.5 .96887 -24.6562 0 ]
[.5 .96887 24.6562 12 ]
[ 0 0 0 0 ]
[ 1 .95637 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .96887 -85.6562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PentaPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .95637 L
0 .95637 L
closepath
clip
newpath
.7967 .83992 m .76862 .4775 L .79669 .84006 L .132 .046 .484 r
F
.76864 .47746 m .76862 .4775 L .7967 .83992 L F
.7967 .83992 m .76876 .47745 L .79684 .84002 L .671 .44 .562 r
F
.33134 .50489 m .76864 .47746 L .7967 .83992 L F
.76864 .47746 m .76876 .47745 L .7967 .83992 L F
.90655 .70431 m .86381 .32593 L .90666 .70446 L .878 .579 .477 r
F
.86373 .32596 m .7967 .83992 L .90656 .70442 L .132 .046 .484 r
F
.86372 .32588 m .86381 .32593 L .90655 .70431 L .878 .579 .477 r
F
.86375 .32584 m .76864 .47746 L .7967 .83992 L .132 .046 .484 r
F
.48617 .10247 m .86372 .32588 L .90655 .70431 L .878 .579 .477 r
F
.48617 .10247 m .90655 .70431 L .48051 .49952 L F
.90655 .70431 m .90666 .70446 L .90656 .70442 L F
.7967 .83992 m .90656 .70442 L .90656 .70442 L .132 .046 .484 r
F
.90655 .70431 m .90656 .70442 L .48051 .49952 L .878 .579 .477 r
F
.7967 .83992 m .79671 .84002 L .90656 .70442 L .132 .046 .484 r
F
.90656 .70442 m .90656 .70442 L .90659 .70438 L F
.86375 .32584 m .86373 .32596 L .90659 .70438 L F
.86373 .32596 m .90656 .70442 L .90659 .70438 L F
.7967 .83992 m .79669 .84006 L .79671 .84002 L F
.33134 .50489 m .7967 .83992 L .30929 .86427 L .671 .44 .562 r
F
.7967 .83992 m .79684 .84002 L .79671 .84002 L F
.7967 .83992 m .79671 .84002 L .30929 .86427 L F
0 g
.5 Mabswid
[ ] 0 setdash
.33134 .50489 m
.48057 .49553 L
s
.30929 .86427 m
.33134 .50489 L
s
.08572 .26363 m
.33129 .50497 L
s
.33129 .50497 m
.33133 .50501 L
s
.08589 .26352 m
.33144 .50488 L
s
.30947 .86432 m
.30947 .86427 L
s
.79669 .84003 m
.79669 .84006 L
s
.86372 .32588 m
.86375 .32584 L
s
.86386 .32603 m
.86391 .32595 L
s
.86383 .32609 m
.86386 .32603 L
s
.79683 .83988 m
.79684 .84002 L
s
.86381 .32593 m
.90666 .70446 L
s
.48617 .10247 m
.86372 .32588 L
s
.86376 .3259 m
.86381 .32593 L
s
.86375 .32584 m
.90659 .70438 L
s
.48626 .10249 m
.86379 .32588 L
s
.86379 .32588 m
.86391 .32595 L
s
.79683 .83998 m
.79684 .83998 L
s
.02797 .64775 m
.30925 .86418 L
s
.30925 .86418 m
.30929 .86421 L
s
.02812 .64784 m
.30941 .86427 L
s
.30941 .86427 m
.30947 .86432 L
s
.30929 .86427 m
.79671 .84002 L
s
.79671 .84002 m
.79684 .84002 L
s
.90669 .70438 m
.90675 .7043 L
s
.79684 .83998 m
.90663 .70445 L
s
.90665 .70442 m
.90669 .70438 L
s
.79671 .84002 m
.90656 .70442 L
s
.79669 .84006 m
.79671 .84002 L
s
.0281 .64793 m
.08586 .26363 L
s
.48628 .10254 m
.48639 .10249 L
s
.08586 .26363 m
.48617 .10258 L
s
.02812 .64784 m
.08589 .26352 L
s
.48613 .10254 m
.48626 .10249 L
s
.08572 .26363 m
.48613 .10254 L
s
.48076 .49954 m
.48639 .10249 L
s
.48051 .49952 m
.48617 .10247 L
s
.48051 .49952 m
.90656 .70442 L
s
.90656 .70442 m
.90666 .70446 L
s
.48062 .49934 m
.90661 .70423 L
s
.90661 .70423 m
.90675 .7043 L
s
.48063 .49958 m
.48076 .49954 L
s
.0281 .64793 m
.48063 .49958 L
s
.48047 .49938 m
.48062 .49934 L
s
.02797 .64775 m
.48047 .49938 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.226388 0.855774 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.202949 1.48759 0 1.48759 [
[.5 1.43234 -62.9062 0 ]
[.5 1.43234 62.9062 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.41984 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.43234 -123.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PlanoConcaveCylindricalLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.41984 L
0 1.41984 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61858 .89635 m
.68488 .76989 L
s
.68488 .76989 m
.90705 .70088 L
s
.68488 .76989 m
.72939 .64471 L
s
.74717 .87151 m .94393 .90152 L .54399 1.01493 L .656 .751 .92 r
F
0 g
.54399 1.01493 m
.62165 1.07719 L
s
.61858 .89635 m
.93041 .80388 L
s
.54399 1.01493 m
.61858 .89635 L
s
.72939 .64471 m
.87518 .59729 L
s
.72939 .64471 m
.74906 .52733 L
s
.74906 .52733 m
.83622 .49772 L
s
.74906 .52733 m
.74171 .4245 L
s
.87518 .59729 m
.90705 .70088 L
s
.83622 .49772 m
.87518 .59729 L
s
.90705 .70088 m
.93041 .80388 L
s
.79183 .40678 m
.83622 .49772 L
s
.69631 1.12356 m
.62165 1.07719 L
s
.62165 1.07719 m
.94644 .98874 L
s
.74171 .4245 m
.79183 .40678 L
s
.74717 .87151 m .88694 .8303 L .94393 .90152 L .656 .751 .92 r
F
0 g
.94393 .90152 m
.94644 .98874 L
s
.93041 .80388 m
.94393 .90152 L
s
.54399 1.01493 m
.94393 .90152 L
s
.70618 .34303 m .74937 .4377 L .71062 .45132 L .544 .324 .532 r
F
.70618 .34303 m .74388 .32923 L .74937 .4377 L F
0 g
.74388 .32923 m
.79183 .40678 L
s
.70618 .34303 m
.74388 .32923 L
s
.64268 .28951 m
.70618 .34303 L
s
.76277 .77383 m .88694 .8303 L .74717 .87151 L .656 .751 .92 r
F
0 g
.54399 1.01493 m
.74717 .87151 L
s
.69464 .26996 m
.74388 .32923 L
s
.75148 1.15225 m
.69631 1.12356 L
s
.69631 1.12356 m
.93703 1.06012 L
s
.94644 .98874 m
.93703 1.06012 L
s
.76277 .77383 m .82619 .75436 L .88694 .8303 L .656 .751 .92 r
F
0 g
.88694 .8303 m
.94393 .90152 L
s
.64268 .28951 m
.69464 .26996 L
s
.64268 .28951 m
.55335 .26975 L
s
.71062 .45132 m .75515 .55219 L .7153 .56559 L .544 .324 .532 r
F
.71062 .45132 m .74937 .4377 L .75515 .55219 L F
0 g
.70618 .34303 m
.71062 .45132 L
s
.74388 .32923 m
.74937 .4377 L
s
.64682 .23393 m
.69464 .26996 L
s
.93703 1.06012 m
.91519 1.11003 L
s
.72026 .68635 m .82619 .75436 L .76277 .77383 L .656 .751 .92 r
F
0 g
.74717 .87151 m
.76277 .77383 L
s
.55335 .26975 m
.64682 .23393 L
s
.55335 .26975 m
.44264 .28793 L
s
.72026 .68635 m .76127 .67322 L .82619 .75436 L .656 .751 .92 r
F
0 g
.82619 .75436 m
.88694 .8303 L
s
.7153 .56559 m .76127 .67322 L .72026 .68635 L .544 .324 .532 r
F
.7153 .56559 m .75515 .55219 L .76127 .67322 L F
0 g
.71062 .45132 m
.7153 .56559 L
s
.74937 .4377 m
.75515 .55219 L
s
.78025 1.15882 m
.75148 1.15225 L
s
.75148 1.15225 m
.91519 1.11003 L
s
.60358 .2257 m
.64682 .23393 L
s
.91519 1.11003 m
.88106 1.13301 L
s
.44264 .28793 m
.31763 .34552 L
s
.60358 .2257 m
.44264 .28793 L
s
.72026 .68635 m .76775 .80137 L .7255 .81417 L .544 .324 .532 r
F
.72026 .68635 m .76127 .67322 L .76775 .80137 L F
.62505 .60864 m .76127 .67322 L .72026 .68635 L .656 .751 .92 r
F
0 g
.7153 .56559 m
.7189 .65313 L
s
.62505 .60864 m .69175 .58632 L .76127 .67322 L .656 .751 .92 r
F
0 g
.76127 .67322 m
.82619 .75436 L
s
.75515 .55219 m
.76127 .67322 L
s
.77665 1.13975 m
.78025 1.15882 L
s
.78025 1.15882 m
.88106 1.13301 L
s
.56849 .24886 m
.60358 .2257 L
s
.31763 .34552 m
.56849 .24886 L
s
.31763 .34552 m
.18798 .44035 L
s
.88106 1.13301 m
.83582 1.12444 L
s
.7255 .81417 m .77462 .93727 L .73106 .94969 L .544 .324 .532 r
F
.7255 .81417 m .76775 .80137 L .77462 .93727 L F
0 g
.72026 .68635 m
.7255 .81417 L
s
.76127 .67322 m
.76775 .80137 L
s
.46274 .54711 m .69175 .58632 L .62505 .60864 L .656 .751 .92 r
F
0 g
.62505 .60864 m
.72026 .68635 L
s
.46274 .54711 m .61711 .49303 L .69175 .58632 L .656 .751 .92 r
F
0 g
.69175 .58632 m
.76127 .67322 L
s
.07615 .56195 m .61711 .49303 L .46274 .54711 L .656 .751 .92 r
F
.07615 .56195 m .53677 .39262 L .61711 .49303 L F
0 g
.07615 .56195 m
.18798 .44035 L
s
.61711 .49303 m
.69175 .58632 L
s
.46274 .54711 m
.62505 .60864 L
s
.07615 .56195 m
.53677 .39262 L
s
.07615 .56195 m
.46274 .54711 L
s
.18798 .44035 m
.54516 .30499 L
s
.07615 .56195 m
.17107 .63815 L
s
.54516 .30499 m
.56849 .24886 L
s
.77665 1.13975 m
.83582 1.12444 L
s
.73106 .94969 m .78192 1.08166 L .73697 1.09362 L .544 .324 .532 r
F
0 g
.73697 1.09362 m
.77665 1.13975 L
s
.73106 .94969 m .77462 .93727 L .78192 1.08166 L .544 .324 .532 r
F
0 g
.7255 .81417 m
.73106 .94969 L
s
.76775 .80137 m
.77462 .93727 L
s
.73106 .94969 m
.73697 1.09362 L
s
.78192 1.08166 m
.83582 1.12444 L
s
.77462 .93727 m
.78192 1.08166 L
s
.53677 .39262 m
.61711 .49303 L
s
.17107 .63815 m
.54538 .50644 L
s
.17107 .63815 m
.29642 .72871 L
s
.53677 .39262 m
.54516 .30499 L
s
.73697 1.09362 m
.78192 1.08166 L
s
.66145 1.02226 m
.73697 1.09362 L
s
.72321 1.00507 m
.78192 1.08166 L
s
.29642 .72871 m
.42925 .82986 L
s
.57122 .63716 m
.29642 .72871 L
s
.55544 .93132 m
.66145 1.02226 L
s
.66145 1.02226 m
.72321 1.00507 L
s
.53677 .39262 m
.54538 .50644 L
s
.72321 1.00507 m
.66479 .89913 L
s
.42925 .82986 m
.61235 .7725 L
s
.42925 .82986 m
.55544 .93132 L
s
.55544 .93132 m
.66479 .89913 L
s
.57122 .63716 m
.54538 .50644 L
s
.66479 .89913 m
.61235 .7725 L
s
.61235 .7725 m
.57122 .63716 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.226388 0.97619 0.323343 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.362303 1.82214 2.22045e-16 1.82214 [
[.5 1.776 -40.5 0 ]
[.5 1.776 40.5 12 ]
[ 0 0 0 0 ]
[ 1 1.7635 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.776 -101.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PlanoConcaveLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.7635 L
0 1.7635 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6365 .97641 m
.5969 .84605 L
s
.5969 .84605 m
.8603 .76039 L
s
.5969 .84605 m
.54541 .72176 L
s
.66236 1.1069 m
.6365 .97641 L
s
.6365 .97641 m
.90129 .89416 L
s
.54541 .72176 m
.80918 .63214 L
s
.54541 .72176 m
.48418 .60942 L
s
.66236 1.1069 m
.93028 1.02745 L
s
.69298 1.11497 m .94559 1.15408 L .6729 1.2314 L .656 .751 .92 r
F
0 g
.66685 1.34341 m
.6729 1.2314 L
s
.66236 1.1069 m
.6729 1.2314 L
s
.8603 .76039 m
.90129 .89416 L
s
.80918 .63214 m
.8603 .76039 L
s
.90129 .89416 m
.93028 1.02745 L
s
.75007 .51541 m
.80918 .63214 L
s
.41579 .51501 m .68913 .55747 L .51544 .61851 L .544 .324 .532 r
F
0 g
.48418 .60942 m
.50097 .60348 L
s
.41579 .51501 m .68549 .41632 L .68913 .55747 L .544 .324 .532 r
F
0 g
.68861 .53714 m
.75007 .51541 L
s
.41579 .51501 m
.48418 .60942 L
s
.41579 .51501 m
.68549 .41632 L
s
.3434 .44464 m
.41579 .51501 L
s
.68549 .41632 m
.75007 .51541 L
s
.64339 1.43603 m
.66685 1.34341 L
s
.66685 1.34341 m
.94578 1.26745 L
s
.69298 1.11497 m .86798 1.06338 L .94559 1.15408 L .656 .751 .92 r
F
0 g
.94559 1.15408 m
.94578 1.26745 L
s
.93028 1.02745 m
.94559 1.15408 L
s
.6729 1.2314 m
.94559 1.15408 L
s
.66392 1.00401 m .86798 1.06338 L .69298 1.11497 L .656 .751 .92 r
F
0 g
.6729 1.2314 m
.69298 1.11497 L
s
.3434 .44464 m
.61844 .34119 L
s
.3434 .44464 m
.27084 .4043 L
s
.61844 .34119 m
.68549 .41632 L
s
.60242 1.50207 m
.64339 1.43603 L
s
.64339 1.43603 m
.92977 1.36055 L
s
.94578 1.26745 m
.92977 1.36055 L
s
.51544 .61851 m .69297 .70634 L .57206 .747 L .544 .324 .532 r
F
.51544 .61851 m .68913 .55747 L .69297 .70634 L F
0 g
.41579 .51501 m
.51544 .61851 L
s
.68549 .41632 m
.68913 .55747 L
s
.66392 1.00401 m .7853 .96676 L .86798 1.06338 L .656 .751 .92 r
F
0 g
.86798 1.06338 m
.94559 1.15408 L
s
.55256 .29632 m
.61844 .34119 L
s
.27084 .4043 m
.55256 .29632 L
s
.27084 .4043 m
.20274 .39942 L
s
.59162 .89735 m .7853 .96676 L .66392 1.00401 L .656 .751 .92 r
F
0 g
.66392 1.00401 m
.69298 1.11497 L
s
.92977 1.36055 m
.89707 1.42608 L
s
.54492 1.5346 m
.60242 1.50207 L
s
.60242 1.50207 m
.89707 1.42608 L
s
.57206 .747 m .69703 .8636 L .59162 .89735 L .544 .324 .532 r
F
.57206 .747 m .69297 .70634 L .69703 .8636 L F
0 g
.51544 .61851 m
.57206 .747 L
s
.68913 .55747 m
.69297 .70634 L
s
.59162 .89735 m .69703 .8636 L .7853 .96676 L .656 .751 .92 r
F
0 g
.7853 .96676 m
.86798 1.06338 L
s
.49216 .28752 m
.55256 .29632 L
s
.20274 .39942 m
.14435 .43396 L
s
.49216 .28752 m
.20274 .39942 L
s
.89707 1.42608 m
.84814 1.45696 L
s
.59162 .89735 m .70133 1.02997 L .5734 1.06875 L .544 .324 .532 r
F
.59162 .89735 m .69703 .8636 L .70133 1.02997 L F
.47521 .79585 m .69703 .8636 L .59162 .89735 L .656 .751 .92 r
F
0 g
.57206 .747 m
.58269 .82868 L
s
.47337 1.5278 m
.54492 1.5346 L
s
.54492 1.5346 m
.84814 1.45696 L
s
.47521 .79585 m .60259 .75324 L .69703 .8636 L .656 .751 .92 r
F
0 g
.69703 .8636 m
.7853 .96676 L
s
.69297 .70634 m
.69703 .8636 L
s
.44209 .31923 m
.49216 .28752 L
s
.14435 .43396 m
.44209 .31923 L
s
.14435 .43396 m
.10121 .50931 L
s
.5734 1.06875 m .70588 1.20627 L .51155 1.26168 L .544 .324 .532 r
F
.5734 1.06875 m .70133 1.02997 L .70588 1.20627 L F
0 g
.5734 1.06875 m
.59162 .89735 L
s
.69703 .8636 m
.70133 1.02997 L
s
.30876 .70233 m .60259 .75324 L .47521 .79585 L .656 .751 .92 r
F
0 g
.47521 .79585 m
.59162 .89735 L
s
.84814 1.45696 m
.78484 1.44723 L
s
.30876 .70233 m .50131 .63487 L .60259 .75324 L .656 .751 .92 r
F
0 g
.60259 .75324 m
.69703 .8636 L
s
.51155 1.26168 m .71071 1.3934 L .39205 1.47818 L .544 .324 .532 r
F
0 g
.47337 1.5278 m
.78484 1.44723 L
s
.39205 1.47818 m
.47337 1.5278 L
s
.51155 1.26168 m .70588 1.20627 L .71071 1.3934 L .544 .324 .532 r
F
0 g
.51155 1.26168 m
.5734 1.06875 L
s
.70133 1.02997 m
.70588 1.20627 L
s
.39205 1.47818 m
.51155 1.26168 L
s
.40735 .39329 m
.44209 .31923 L
s
.07843 .62304 m .50131 .63487 L .30876 .70233 L .656 .751 .92 r
F
0 g
.30876 .70233 m
.47521 .79585 L
s
.39205 1.47818 m
.71071 1.3934 L
s
.30709 1.38609 m
.39205 1.47818 L
s
.71071 1.3934 m
.78484 1.44723 L
s
.70588 1.20627 m
.71071 1.3934 L
s
.07843 .62304 m .39242 .50761 L .50131 .63487 L .656 .751 .92 r
F
0 g
.39242 .50761 m
.50131 .63487 L
s
.50131 .63487 m
.60259 .75324 L
s
.07843 .62304 m
.10121 .50931 L
s
.07843 .62304 m
.30876 .70233 L
s
.10121 .50931 m
.40735 .39329 L
s
.07843 .62304 m
.39242 .50761 L
s
.07843 .62304 m
.07973 .76799 L
s
.39242 .50761 m
.40735 .39329 L
s
.22601 1.25677 m
.30709 1.38609 L
s
.30709 1.38609 m
.63118 1.29594 L
s
.63118 1.29594 m
.71071 1.3934 L
s
.07973 .76799 m
.40032 .65518 L
s
.07973 .76799 m
.10642 .93229 L
s
.15678 1.10067 m
.22601 1.25677 L
s
.22601 1.25677 m
.55319 1.16047 L
s
.10642 .93229 m
.43174 .82392 L
s
.10642 .93229 m
.15678 1.10067 L
s
.15678 1.10067 m
.48438 .99804 L
s
.39242 .50761 m
.40032 .65518 L
s
.63118 1.29594 m
.55319 1.16047 L
s
.43174 .82392 m
.40032 .65518 L
s
.55319 1.16047 m
.48438 .99804 L
s
.48438 .99804 m
.43174 .82392 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.333038 0.133279 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.113308 1.29342 0 1.29342 [
[.5 1.23121 -30.8125 0 ]
[.5 1.23121 30.8125 12 ]
[ 0 0 0 0 ]
[ 1 1.21871 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.23121 -91.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(CustomMirror) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.21871 L
0 1.21871 L
closepath
clip
newpath
.69079 .57239 m .42398 .65134 L .44809 .73128 L .558 .483 .727 r
F
.66662 .51236 m .42398 .65134 L .69079 .57239 L .573 .541 .781 r
F
.66662 .51236 m .39153 .57547 L .42398 .65134 L F
.71 .63523 m .44809 .73128 L .46271 .81161 L .535 .419 .668 r
F
.69079 .57239 m .44809 .73128 L .71 .63523 L .558 .483 .727 r
F
0 g
.5 Mabswid
[ ] 0 setdash
.42398 .65134 m
.44809 .73128 L
s
.63868 .45826 m .39153 .57547 L .66662 .51236 L .581 .598 .835 r
F
.63868 .45826 m .35211 .50731 L .39153 .57547 L F
0 g
.39153 .57547 m
.42398 .65134 L
s
.72328 .69767 m .46271 .81161 L .46691 .88853 L .498 .337 .593 r
F
.71 .63523 m .46271 .81161 L .72328 .69767 L .535 .419 .668 r
F
0 g
.44809 .73128 m
.46271 .81161 L
s
.60834 .41317 m .35211 .50731 L .63868 .45826 L .578 .66 .894 r
F
.60834 .41317 m .30736 .45052 L .35211 .50731 L F
0 g
.35211 .50731 m
.39153 .57547 L
s
.72328 .69767 m .46691 .88853 L .72981 .75647 L .498 .337 .593 r
F
.72981 .75647 m .46691 .88853 L .45999 .95802 L .437 .221 .487 r
F
0 g
.46271 .81161 m
.46691 .88853 L
s
.57719 .38006 m .30736 .45052 L .60834 .41317 L .552 .731 .958 r
F
.57719 .38006 m .25933 .40883 L .30736 .45052 L F
0 g
.30736 .45052 m
.35211 .50731 L
s
.72898 .8083 m .45999 .95802 L .44156 1.01578 L .319 .029 .304 r
F
.72981 .75647 m .45999 .95802 L .72898 .8083 L .437 .221 .487 r
F
0 g
.45999 .95802 m
.46691 .88853 L
s
.54705 .36166 m .25933 .40883 L .57719 .38006 L .456 .793 .999 r
F
.54705 .36166 m .21055 .38583 L .25933 .40883 L F
0 g
.25933 .40883 m
.30736 .45052 L
s
.72047 .84982 m .44156 1.01578 L .41176 1.0574 L .055 0 0 r
F
0 g
.44882 1.01146 m
.4492 1.01026 L
s
.72898 .8083 m .44156 1.01578 L .72047 .84982 L .319 .029 .304 r
F
0 g
.44156 1.01578 m
.45999 .95802 L
s
.77861 .55249 m .69079 .57239 L .71 .63523 L .382 .373 .725 r
F
.76305 .51306 m .69079 .57239 L .77861 .55249 L .394 .437 .786 r
F
.76305 .51306 m .66662 .51236 L .69079 .57239 L F
.79128 .59374 m .71 .63523 L .72328 .69767 L .345 .291 .654 r
F
.77861 .55249 m .71 .63523 L .79128 .59374 L .382 .373 .725 r
F
.74548 .47772 m .66662 .51236 L .76305 .51306 L .382 .489 .844 r
F
.74548 .47772 m .63868 .45826 L .66662 .51236 L F
.80034 .63446 m .72328 .69767 L .72981 .75647 L .275 .177 .559 r
F
.79128 .59374 m .72328 .69767 L .80034 .63446 L .345 .291 .654 r
F
.72687 .44862 m .63868 .45826 L .74548 .47772 L .332 .532 .899 r
F
.72687 .44862 m .60834 .41317 L .63868 .45826 L F
.51996 .36021 m .21055 .38583 L .54705 .36166 L .139 .684 .801 r
F
.51996 .36021 m .16406 .38472 L .21055 .38583 L F
0 g
.21055 .38583 m
.25933 .40883 L
s
.80034 .63446 m .72981 .75647 L .80522 .6723 L .275 .177 .559 r
F
.80522 .6723 m .72981 .75647 L .72898 .8083 L .144 0 .411 r
F
.72047 .84982 m .41176 1.0574 L .7043 .87781 L .055 0 0 r
F
.7043 .87781 m .41176 1.0574 L .37149 1.0786 L .43 .844 .673 r
F
0 g
.41176 1.0574 m
.41837 1.0557 L
s
.41837 1.0557 m
.42097 1.05204 L
s
.42097 1.05204 m
.42134 1.05152 L
s
.41567 1.05195 m
.44156 1.01578 L
s
.41504 1.05745 m
.41837 1.0557 L
s
.70832 .42773 m .60834 .41317 L .72687 .44862 L .207 .545 .929 r
F
.70832 .42773 m .57719 .38006 L .60834 .41317 L F
.80554 .70496 m .72898 .8083 L .72047 .84982 L 0 0 .143 r
F
.80522 .6723 m .72898 .8083 L .80554 .70496 L .144 0 .411 r
F
.49804 .37707 m .16406 .38472 L .51996 .36021 L .309 0 0 r
F
0 g
.17461 .38232 m
.19228 .38278 L
s
.49804 .37707 m .12336 .40776 L .16406 .38472 L .309 0 0 r
F
0 g
.17053 .38222 m
.17461 .38232 L
s
.16406 .38472 m
.17053 .38222 L
s
.16717 .38412 m
.17053 .38222 L
s
.69101 .41668 m .57719 .38006 L .70832 .42773 L 0 .452 .82 r
F
.69101 .41668 m .54705 .36166 L .57719 .38006 L F
.80804 .55227 m .77861 .55249 L .79128 .59374 L 0 .067 .605 r
F
.80164 .53595 m .77861 .55249 L .80804 .55227 L 0 .129 .665 r
F
.80164 .53595 m .76305 .51306 L .77861 .55249 L F
.8133 .56936 m .79128 .59374 L .80034 .63446 L 0 0 .513 r
F
.80804 .55227 m .79128 .59374 L .8133 .56936 L 0 .067 .605 r
F
.79451 .52145 m .76305 .51306 L .80164 .53595 L 0 .149 .691 r
F
.79451 .52145 m .74548 .47772 L .76305 .51306 L F
.81708 .58615 m .80034 .63446 L .80522 .6723 L 0 0 .373 r
F
.8133 .56936 m .80034 .63446 L .81708 .58615 L 0 0 .513 r
F
.80111 .73026 m .72047 .84982 L .7043 .87781 L 0 0 0 r
F
.80554 .70496 m .72047 .84982 L .80111 .73026 L 0 0 .143 r
F
.68099 .88943 m .37149 1.0786 L .3226 1.07578 L .707 .957 .948 r
F
0 g
.3818 1.075 m
.41504 1.05745 L
s
.7043 .87781 m .37149 1.0786 L .68099 .88943 L .43 .844 .673 r
F
0 g
.37149 1.0786 m
.41176 1.0574 L
s
.37826 1.07686 m
.3818 1.075 L
s
.37149 1.0786 m
.37826 1.07686 L
s
.37422 1.07663 m
.37826 1.07686 L
s
.78709 .50972 m .74548 .47772 L .79451 .52145 L 0 .119 .665 r
F
.78709 .50972 m .72687 .44862 L .74548 .47772 L F
.81708 .58615 m .80522 .6723 L .81915 .60156 L 0 0 .373 r
F
.81915 .60156 m .80522 .6723 L .80554 .70496 L 0 0 .158 r
F
0 g
.80958 .67426 m
.81254 .67009 L
s
.77987 .50155 m .72687 .44862 L .78709 .50972 L 0 .021 .539 r
F
.77987 .50155 m .70832 .42773 L .72687 .44862 L F
0 g
.72047 .44026 m
.73415 .44613 L
s
.67613 .41663 m .54705 .36166 L .69101 .41668 L .447 0 0 r
F
.67613 .41663 m .51996 .36021 L .54705 .36166 L F
.81915 .60156 m .80554 .70496 L .81934 .61459 L 0 0 .158 r
F
.81934 .61459 m .80554 .70496 L .80111 .73026 L .72 .68 .135 r
F
0 g
.81254 .67009 m
.82614 .63324 L
s
.81507 .64536 m
.81866 .63554 L
s
.81433 .64739 m
.81507 .64536 L
s
.48333 .41238 m .12336 .40776 L .49804 .37707 L .514 .123 .237 r
F
0 g
.13001 .4052 m
.13357 .40318 L
s
.13357 .40318 m
.16717 .38412 L
s
.48333 .41238 m .0922 .45558 L .12336 .40776 L .514 .123 .237 r
F
0 g
.12336 .40776 m
.16406 .38472 L
s
.12336 .40776 m
.13001 .4052 L
s
.12743 .40917 m
.13001 .4052 L
s
.80111 .73026 m .7043 .87781 L .79204 .74627 L 0 0 0 r
F
.79204 .74627 m .7043 .87781 L .68099 .88943 L .838 .989 .724 r
F
0 g
.82614 .63324 m
.82675 .59918 L
s
.77333 .49754 m .70832 .42773 L .77987 .50155 L .663 .135 0 r
F
0 g
.73357 .45378 m
.75342 .46904 L
s
.77333 .49754 m .69101 .41668 L .70832 .42773 L .663 .135 0 r
F
0 g
.75342 .46904 m
.76309 .47648 L
s
.73415 .44613 m
.77053 .47398 L
s
.77438 .49212 m
.78709 .50972 L
s
.76309 .47648 m
.77438 .49212 L
s
.81762 .62434 m .80111 .73026 L .79204 .74627 L .913 .863 .424 r
F
.81934 .61459 m .80111 .73026 L .81762 .62434 L .72 .68 .135 r
F
0 g
.81889 .61957 m
.81892 .61732 L
s
.81866 .63554 m
.81889 .61957 L
s
.65166 .88261 m .3226 1.07578 L .26813 1.0468 L .743 .854 .932 r
F
0 g
.33383 1.07424 m
.37422 1.07663 L
s
.68099 .88943 m .3226 1.07578 L .65166 .88261 L .707 .957 .948 r
F
0 g
.3226 1.07578 m
.37149 1.0786 L
s
.32954 1.07399 m
.33383 1.07424 L
s
.3226 1.07578 m
.32954 1.07399 L
s
.32502 1.07157 m
.32954 1.07399 L
s
.80804 .55227 m
.8133 .56936 L
s
.80804 .55227 m
.81559 .54984 L
s
.80164 .53595 m
.80804 .55227 L
s
.8133 .56936 m
.81708 .58615 L
s
.8133 .56936 m
.82085 .56696 L
s
.81559 .54984 m
.82085 .56696 L
s
.80919 .5335 m
.81559 .54984 L
s
.80164 .53595 m
.80919 .5335 L
s
.79451 .52145 m
.80164 .53595 L
s
.82085 .56696 m
.82466 .58376 L
s
.81708 .58615 m
.81915 .60156 L
s
.81708 .58615 m
.82466 .58376 L
s
.80207 .51898 m
.80919 .5335 L
s
.82466 .58376 m
.82675 .59918 L
s
.66483 .42812 m .51996 .36021 L .67613 .41663 L .643 .147 .056 r
F
.66483 .42812 m .49804 .37707 L .51996 .36021 L F
0 g
.79451 .52145 m
.80207 .51898 L
s
.78709 .50972 m
.79451 .52145 L
s
.76792 .49804 m .69101 .41668 L .77333 .49754 L .786 .287 0 r
F
0 g
.77053 .47398 m
.79468 .50722 L
s
.76792 .49804 m .67613 .41663 L .69101 .41668 L .786 .287 0 r
F
0 g
.81915 .60156 m
.82675 .59918 L
s
.81915 .60156 m
.81934 .61459 L
s
.79468 .50722 m
.80207 .51898 L
s
.82675 .59918 m
.82698 .61221 L
s
.78709 .50972 m
.79468 .50722 L
s
.77987 .50155 m
.78709 .50972 L
s
.79204 .74627 m .68099 .88943 L .77871 .75151 L .838 .989 .724 r
F
.81408 .63012 m .79204 .74627 L .77871 .75151 L .98 .912 .607 r
F
.81762 .62434 m .79204 .74627 L .81408 .63012 L .913 .863 .424 r
F
0 g
.78749 .49903 m
.79468 .50722 L
s
.81762 .62434 m
.81934 .61459 L
s
.81934 .61459 m
.82698 .61221 L
s
.82698 .61221 m
.8253 .62196 L
s
.77871 .75151 m .68099 .88943 L .65166 .88261 L .889 .95 .84 r
F
0 g
.77987 .50155 m
.78749 .49903 L
s
.77333 .49754 m
.77987 .50155 L
s
.78099 .495 m
.78749 .49903 L
s
.81762 .62434 m
.8253 .62196 L
s
.47751 .46459 m .0922 .45558 L .48333 .41238 L .592 .302 .445 r
F
0 g
.09901 .453 m
.10173 .4488 L
s
.10173 .4488 m
.12743 .40917 L
s
.47751 .46459 m .07407 .52649 L .0922 .45558 L .592 .302 .445 r
F
0 g
.0922 .45558 m
.12336 .40776 L
s
.0922 .45558 m
.09901 .453 L
s
.8253 .62196 m
.8218 .62774 L
s
.09751 .45892 m
.09901 .453 L
s
.77333 .49754 m
.78099 .495 L
s
.76402 .50309 m .67613 .41663 L .76792 .49804 L .829 .395 .205 r
F
0 g
.76792 .49804 m
.77333 .49754 L
s
.76402 .50309 m .66483 .42812 L .67613 .41663 L .829 .395 .205 r
F
0 g
.77562 .49548 m
.78099 .495 L
s
.81408 .63012 m .77871 .75151 L .80892 .63146 L .98 .912 .607 r
F
0 g
.81408 .63012 m
.8218 .62774 L
s
.81408 .63012 m
.81762 .62434 L
s
.8218 .62774 m
.81668 .62906 L
s
.65166 .88261 m .26813 1.0468 L .61811 .85648 L .743 .854 .932 r
F
.61811 .85648 m .26813 1.0468 L .21226 .99179 L .729 .755 .873 r
F
0 g
.26813 1.0468 m
.3226 1.07578 L
s
.27521 1.04492 m
.27998 1.04747 L
s
.27998 1.04747 m
.32502 1.07157 L
s
.26813 1.0468 m
.27521 1.04492 L
s
.77871 .75151 m .65166 .88261 L .76185 .74509 L .889 .95 .84 r
F
.80892 .63146 m .77871 .75151 L .76185 .74509 L .971 .883 .686 r
F
0 g
.27055 1.04031 m
.27521 1.04492 L
s
.76792 .49804 m
.77562 .49548 L
s
.77177 .50052 m
.77562 .49548 L
s
.80892 .63146 m .76185 .74509 L .80246 .62819 L .971 .883 .686 r
F
0 g
.80892 .63146 m
.81668 .62906 L
s
.80892 .63146 m
.81408 .63012 L
s
.6581 .45085 m .49804 .37707 L .66483 .42812 L .703 .318 .316 r
F
.6581 .45085 m .48333 .41238 L .49804 .37707 L F
0 g
.81668 .62906 m
.81026 .62578 L
s
.76195 .51243 m .66483 .42812 L .76402 .50309 L .837 .468 .354 r
F
0 g
.76402 .50309 m
.77177 .50052 L
s
.76402 .50309 m
.76792 .49804 L
s
.76974 .50986 m
.77177 .50052 L
s
.80246 .62819 m .74255 .72693 L .79513 .62046 L .94 .831 .709 r
F
.80246 .62819 m .76185 .74509 L .74255 .72693 L F
0 g
.80246 .62819 m
.80892 .63146 L
s
.80246 .62819 m
.81026 .62578 L
s
.81026 .62578 m
.80297 .61802 L
s
.76195 .51243 m .6581 .45085 L .66483 .42812 L .837 .468 .354 r
F
.76185 .74509 m .65166 .88261 L .61811 .85648 L .861 .857 .836 r
F
.76188 .52546 m .6581 .45085 L .76195 .51243 L .837 .522 .456 r
F
0 g
.76195 .51243 m
.76974 .50986 L
s
.76195 .51243 m
.76402 .50309 L
s
.7697 .5229 m
.76974 .50986 L
s
.79513 .62046 m .72217 .69795 L .78745 .60874 L .909 .778 .705 r
F
.79513 .62046 m .74255 .72693 L .72217 .69795 L F
0 g
.79513 .62046 m
.80246 .62819 L
s
.79513 .62046 m
.80297 .61802 L
s
.76185 .74509 m .61811 .85648 L .74255 .72693 L .861 .857 .836 r
F
0 g
.80297 .61802 m
.79532 .60627 L
s
.4816 .5303 m .07407 .52649 L .47751 .46459 L .63 .409 .564 r
F
0 g
.08104 .52393 m
.08261 .51772 L
s
.08261 .51772 m
.09751 .45892 L
s
.4816 .5303 m .07163 .61595 L .07407 .52649 L .63 .409 .564 r
F
0 g
.07407 .52649 m
.0922 .45558 L
s
.07407 .52649 m
.08104 .52393 L
s
.07407 .52649 m
.33922 .47207 L
s
.76188 .52546 m .65664 .4836 L .6581 .45085 L .837 .522 .456 r
F
.76384 .5413 m .65664 .4836 L .76188 .52546 L .837 .566 .529 r
F
0 g
.76188 .52546 m
.76195 .51243 L
s
.76188 .52546 m
.7697 .5229 L
s
.08104 .52393 m
.34671 .46937 L
s
.08084 .53145 m
.08104 .52393 L
s
.78745 .60874 m .70229 .66005 L .77996 .59382 L .883 .73 .687 r
F
.78745 .60874 m .72217 .69795 L .70229 .66005 L F
0 g
.78745 .60874 m
.79513 .62046 L
s
.78512 .64702 m
.79513 .62046 L
s
.78389 .66878 m
.80297 .61802 L
s
.78745 .60874 m
.79532 .60627 L
s
.77169 .53875 m
.7697 .5229 L
s
.79532 .60627 m
.78784 .59133 L
s
.76384 .5413 m .66076 .52417 L .65664 .4836 L .837 .566 .529 r
F
0 g
.72458 .4998 m
.7697 .5229 L
s
.71673 .50242 m
.73827 .51341 L
s
.76771 .55883 m .66076 .52417 L .76384 .5413 L .841 .607 .583 r
F
0 g
.76188 .52546 m
.76384 .5413 L
s
.76384 .5413 m
.77169 .53875 L
s
.77996 .59382 m .6845 .61608 L .77322 .57677 L .863 .686 .66 r
F
.77996 .59382 m .70229 .66005 L .6845 .61608 L F
0 g
.77996 .59382 m
.78745 .60874 L
s
.77996 .59382 m
.78784 .59133 L
s
.776 .67118 m
.78512 .64702 L
s
.77558 .55629 m
.77169 .53875 L
s
.76771 .55883 m .67028 .56953 L .66076 .52417 L .841 .607 .583 r
F
0 g
.73827 .51341 m
.76188 .52546 L
s
.77322 .57677 m .67028 .56953 L .76771 .55883 L .85 .646 .626 r
F
0 g
.76384 .5413 m
.76771 .55883 L
s
.76771 .55883 m
.77558 .55629 L
s
.76723 .68581 m
.776 .67118 L
s
.78784 .59133 m
.7811 .57426 L
s
.77322 .57677 m .6845 .61608 L .67028 .56953 L .85 .646 .626 r
F
0 g
.77322 .57677 m
.7811 .57426 L
s
.77322 .57677 m
.77996 .59382 L
s
.76771 .55883 m
.77322 .57677 L
s
.5828 .81188 m .21226 .99179 L .15998 .91385 L .71 .678 .816 r
F
0 g
.22432 .9946 m
.27055 1.04031 L
s
.61811 .85648 m .21226 .99179 L .5828 .81188 L .729 .755 .873 r
F
0 g
.21226 .99179 m
.26813 1.0468 L
s
.26813 1.0468 m
.50741 .93482 L
s
.21945 .98979 m
.22432 .9946 L
s
.27521 1.04492 m
.515 .93274 L
s
.21226 .99179 m
.21945 .98979 L
s
.7811 .57426 m
.77558 .55629 L
s
.75044 .72459 m
.78389 .66878 L
s
.21505 .98322 m
.21945 .98979 L
s
.65664 .4836 m .48333 .41238 L .6581 .45085 L .724 .42 .464 r
F
.65664 .4836 m .47751 .46459 L .48333 .41238 L F
0 g
.515 .93274 m
.6082 .8668 L
s
.74255 .72693 m .5828 .81188 L .72217 .69795 L .827 .775 .803 r
F
.74255 .72693 m .61811 .85648 L .5828 .81188 L F
0 g
.74255 .72693 m
.76723 .68581 L
s
.6082 .8668 m
.62588 .85429 L
s
.50741 .93482 m
.61811 .85648 L
s
.69182 .78829 m
.74255 .72693 L
s
.66449 .48093 m
.72458 .4998 L
s
.73371 .74484 m
.75044 .72459 L
s
.69968 .78601 m
.73371 .74484 L
s
.61811 .85648 m
.69182 .78829 L
s
.62588 .85429 m
.69968 .78601 L
s
.49565 .60437 m .07163 .61595 L .4816 .5303 L .654 .486 .644 r
F
0 g
.07894 .60567 m
.08084 .53145 L
s
.49565 .60437 m .08604 .71664 L .07163 .61595 L .654 .486 .644 r
F
0 g
.07163 .61595 m
.07407 .52649 L
s
.07874 .61346 m
.07894 .60567 L
s
.07163 .61595 m
.07874 .61346 L
s
.66076 .52417 m .47751 .46459 L .65664 .4836 L .737 .491 .557 r
F
0 g
.65664 .4836 m
.71673 .50242 L
s
.57875 .47023 m
.65664 .4836 L
s
.07874 .61346 m
.07996 .62198 L
s
.58655 .46753 m
.66449 .48093 L
s
.72217 .69795 m .54864 .75162 L .70229 .66005 L .799 .709 .765 r
F
.72217 .69795 m .5828 .81188 L .54864 .75162 L F
.54864 .75162 m .15998 .91385 L .11644 .81923 L .692 .612 .762 r
F
0 g
.17176 .9185 m
.21505 .98322 L
s
.5828 .81188 m .15998 .91385 L .54864 .75162 L .71 .678 .816 r
F
0 g
.15998 .91385 m
.21226 .99179 L
s
.16723 .91172 m
.17176 .9185 L
s
.15998 .91385 m
.16723 .91172 L
s
.16354 .90368 m
.16723 .91172 L
s
.46316 .46306 m
.4852 .46187 L
s
.34671 .46937 m
.46316 .46306 L
s
.66076 .52417 m .4816 .5303 L .47751 .46459 L .737 .491 .557 r
F
0 g
.4852 .46187 m
.58655 .46753 L
s
.47751 .46459 m
.57875 .47023 L
s
.33922 .47207 m
.47751 .46459 L
s
.67028 .56953 m .4816 .5303 L .66076 .52417 L .748 .548 .625 r
F
.51868 .68039 m .08604 .71664 L .49565 .60437 L .674 .551 .707 r
F
.51868 .68039 m .11644 .81923 L .08604 .71664 L F
0 g
.07163 .61595 m
.08604 .71664 L
s
.07996 .62198 m
.09199 .70554 L
s
.09199 .70554 m
.09324 .71424 L
s
.08604 .71664 m
.09324 .71424 L
s
.12744 .82511 m
.16354 .90368 L
s
.70229 .66005 m .51868 .68039 L .6845 .61608 L .778 .652 .724 r
F
.70229 .66005 m .54864 .75162 L .51868 .68039 L F
0 g
.09324 .71424 m
.09584 .72301 L
s
.54864 .75162 m .11644 .81923 L .51868 .68039 L .692 .612 .762 r
F
0 g
.11644 .81923 m
.12369 .81696 L
s
.09584 .72301 m
.12108 .80816 L
s
.12108 .80816 m
.12369 .81696 L
s
.11644 .81923 m
.15998 .91385 L
s
.12369 .81696 m
.12744 .82511 L
s
.08604 .71664 m
.11644 .81923 L
s
.67028 .56953 m .49565 .60437 L .4816 .5303 L .748 .548 .625 r
F
.6845 .61608 m .49565 .60437 L .67028 .56953 L .761 .6 .678 r
F
.6845 .61608 m .51868 .68039 L .49565 .60437 L F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.333038 0.253695 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.218821 1.52137 -2.22045e-16 1.52137 [
[.5 1.46717 -34.0938 0 ]
[.5 1.46717 34.0938 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.45467 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.46717 -95.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(CylindricalLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.45467 L
0 1.45467 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59986 .70288 m
.50511 .62292 L
s
.50511 .62292 m
.42208 .54703 L
s
.70021 .78455 m
.59986 .70288 L
s
.59986 .70288 m
.87372 .61381 L
s
.79384 .86705 m
.70021 .78455 L
s
.70021 .78455 m
.90653 .72046 L
s
.35528 .47809 m .74329 .44983 L .3505 .58789 L .544 .324 .532 r
F
0 g
.50511 .62292 m
.83353 .51133 L
s
.35528 .47809 m .738 .33804 L .74329 .44983 L .544 .324 .532 r
F
0 g
.74253 .43373 m
.78764 .41778 L
s
.79384 .86705 m
.93045 .82654 L
s
.87372 .61381 m
.90653 .72046 L
s
.83353 .51133 m
.87372 .61381 L
s
.90653 .72046 m
.93045 .82654 L
s
.78764 .41778 m
.83353 .51133 L
s
.58112 .94353 m .94414 .92712 L .84379 .95558 L .656 .751 .92 r
F
0 g
.79384 .86705 m
.83063 .93225 L
s
.80401 1.05578 m
.84379 .95558 L
s
.3505 .58789 m .74887 .56782 L .34547 .70345 L .544 .324 .532 r
F
.3505 .58789 m .74329 .44983 L .74887 .56782 L F
0 g
.3505 .58789 m
.35528 .47809 L
s
.30877 .41941 m
.35528 .47809 L
s
.35528 .47809 m
.738 .33804 L
s
.58112 .94353 m .88506 .85393 L .94414 .92712 L .656 .751 .92 r
F
0 g
.93045 .82654 m
.94414 .92712 L
s
.43816 .89373 m .88506 .85393 L .58112 .94353 L .656 .751 .92 r
F
0 g
.58112 .94353 m
.84379 .95558 L
s
.84379 .95558 m
.94414 .92712 L
s
.30877 .41941 m
.68694 .27717 L
s
.30877 .41941 m
.28628 .37478 L
s
.738 .33804 m
.78764 .41778 L
s
.94414 .92712 m
.94642 1.01699 L
s
.71279 1.14949 m
.80401 1.05578 L
s
.80401 1.05578 m
.94642 1.01699 L
s
.43816 .89373 m .82207 .7759 L .88506 .85393 L .656 .751 .92 r
F
0 g
.88506 .85393 m
.94414 .92712 L
s
.34017 .82526 m .82207 .7759 L .43816 .89373 L .656 .751 .92 r
F
0 g
.43816 .89373 m
.58112 .94353 L
s
.738 .33804 m
.74329 .44983 L
s
.68694 .27717 m
.738 .33804 L
s
.34547 .70345 m .75477 .69253 L .34017 .82526 L .544 .324 .532 r
F
.34547 .70345 m .74887 .56782 L .75477 .69253 L F
0 g
.34547 .70345 m
.3505 .58789 L
s
.94642 1.01699 m
.93633 1.09058 L
s
.60652 1.22121 m
.71279 1.14949 L
s
.71279 1.14949 m
.93633 1.09058 L
s
.28628 .37478 m
.63728 .24024 L
s
.28628 .37478 m
.29078 .34853 L
s
.74329 .44983 m
.74887 .56782 L
s
.63728 .24024 m
.68694 .27717 L
s
.34017 .82526 m .76101 .82455 L .33458 .95383 L .544 .324 .532 r
F
.34017 .82526 m .75477 .69253 L .82207 .7759 L .656 .751 .92 r
F
.34017 .82526 m .75477 .69253 L .76101 .82455 L .544 .324 .532 r
F
0 g
.82207 .7759 m
.88506 .85393 L
s
.2802 .73791 m .75477 .69253 L .34017 .82526 L .656 .751 .92 r
F
0 g
.34424 .73178 m
.34547 .70345 L
s
.4998 1.26263 m
.60652 1.22121 L
s
.60652 1.22121 m
.91337 1.14208 L
s
.93633 1.09058 m
.91337 1.14208 L
s
.29078 .34853 m
.32273 .34575 L
s
.59229 .23197 m
.29078 .34853 L
s
.33458 .95383 m .76763 .96456 L .32866 1.08973 L .544 .324 .532 r
F
.33458 .95383 m .76101 .82455 L .76763 .96456 L F
0 g
.33458 .95383 m
.34017 .82526 L
s
.40225 1.26799 m
.4998 1.26263 L
s
.59229 .23197 m
.63728 .24024 L
s
.2802 .73791 m .6827 .60325 L .75477 .69253 L .656 .751 .92 r
F
0 g
.74887 .56782 m
.75477 .69253 L
s
.75477 .69253 m
.82207 .7759 L
s
.27083 .62461 m .6827 .60325 L .2802 .73791 L .656 .751 .92 r
F
0 g
.2802 .73791 m
.34017 .82526 L
s
.91337 1.14208 m
.87773 1.16586 L
s
.75477 .69253 m
.76101 .82455 L
s
.32866 1.08973 m .77467 1.11329 L .3224 1.23362 L .544 .324 .532 r
F
0 g
.4998 1.26263 m
.87773 1.16586 L
s
.32866 1.08973 m .76763 .96456 L .77467 1.11329 L .544 .324 .532 r
F
0 g
.32866 1.08973 m
.33458 .95383 L
s
.3224 1.23362 m
.32866 1.08973 L
s
.3224 1.23362 m
.40225 1.26799 L
s
.40225 1.26799 m
.83064 1.15718 L
s
.55566 .256 m
.59229 .23197 L
s
.32273 .34575 m
.55566 .256 L
s
.32273 .34575 m
.37402 .3735 L
s
.87773 1.16586 m
.83064 1.15718 L
s
.27083 .62461 m .60535 .50742 L .6827 .60325 L .656 .751 .92 r
F
0 g
.6827 .60325 m
.75477 .69253 L
s
.40559 .44712 m .60535 .50742 L .27083 .62461 L .656 .751 .92 r
F
0 g
.27083 .62461 m
.2802 .73791 L
s
.76101 .82455 m
.76763 .96456 L
s
.3224 1.23362 m
.77467 1.11329 L
s
.26801 1.1586 m
.3224 1.23362 L
s
.53116 .31395 m
.55566 .256 L
s
.24528 1.04578 m
.26801 1.1586 L
s
.26801 1.1586 m
.71384 1.03458 L
s
.77467 1.11329 m
.83064 1.15718 L
s
.76763 .96456 m
.77467 1.11329 L
s
.53116 .31395 m
.37402 .3735 L
s
.40559 .44712 m .5221 .40429 L .60535 .50742 L .656 .751 .92 r
F
0 g
.5221 .40429 m
.60535 .50742 L
s
.37402 .3735 m
.40559 .44712 L
s
.60535 .50742 m
.6827 .60325 L
s
.27083 .62461 m
.40559 .44712 L
s
.25732 .90253 m
.24528 1.04578 L
s
.24528 1.04578 m
.65343 .92565 L
s
.5221 .40429 m
.53116 .31395 L
s
.71384 1.03458 m
.77467 1.11329 L
s
.40559 .44712 m
.5221 .40429 L
s
.36575 .57955 m
.40559 .44712 L
s
.30187 .74112 m
.25732 .90253 L
s
.25732 .90253 m
.59932 .79539 L
s
.36575 .57955 m
.30187 .74112 L
s
.30187 .74112 m
.55702 .65612 L
s
.36575 .57955 m
.53062 .52154 L
s
.5221 .40429 m
.53062 .52154 L
s
.71384 1.03458 m
.65343 .92565 L
s
.55702 .65612 m
.53062 .52154 L
s
.65343 .92565 m
.59932 .79539 L
s
.59932 .79539 m
.55702 .65612 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.333038 0.374111 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.027933 1.02793 -0.178239 1.02793 [
[.5 .64494 -39.3125 0 ]
[.5 .64494 39.3125 12 ]
[ 0 0 0 0 ]
[ 1 .63244 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .64494 -100.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(DirectVisionPrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .63244 L
0 .63244 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.27772 .38651 m
.26837 .58824 L
s
.42437 .1638 m
.27772 .38651 L
s
.27766 .38658 m
.83169 .208 L
s
.09354 .34152 m
.27766 .38658 L
s
.27763 .3865 m
.26827 .58823 L
s
.83165 .20791 m
.27763 .3865 L
s
.2778 .38647 m
.26845 .5882 L
s
.09368 .34141 m
.2778 .38647 L
s
.04376 .29558 m
.09354 .34152 L
s
.09374 .34143 m
.07577 .54517 L
s
.04396 .29549 m
.09374 .34143 L
s
.07571 .54515 m
.09368 .34141 L
s
.84857 .01704 m
.04376 .29558 L
s
.0233 .5012 m
.04396 .29549 L
s
.26831 .58821 m
.84845 .41714 L
s
.07557 .54516 m
.26831 .58821 L
s
.26837 .58824 m
.42133 .37473 L
s
.26827 .58823 m
.84842 .41716 L
s
.26845 .5882 m
.07571 .54515 L
s
.0231 .50119 m
.07557 .54516 L
s
.07577 .54517 m
.0233 .5012 L
s
.83149 .20799 m
.84825 .41724 L
s
.88678 .07401 m
.83149 .20799 L
s
.83161 .20797 m
.84837 .41722 L
s
.42423 .16385 m
.83161 .20797 L
s
.83169 .208 m
.88699 .07402 L
s
.84842 .41716 m
.83165 .20791 L
s
.86755 .23292 m
.0231 .50119 L
s
.42423 .16389 m
.42118 .37482 L
s
.84848 .01706 m
.42423 .16389 L
s
.42118 .37477 m
.42423 .16385 L
s
.42133 .37473 m
.42437 .1638 L
s
.84825 .41724 m
.90731 .28813 L
s
.84845 .41714 m
.90752 .28803 L
s
.84837 .41722 m
.42118 .37477 L
s
.88678 .07406 m
.90731 .28818 L
s
.84836 .01709 m
.88678 .07406 L
s
.90731 .28813 m
.88678 .07401 L
s
.88699 .07402 m
.84857 .01704 L
s
.42118 .37482 m
.86747 .23305 L
s
.86734 .23307 m
.84836 .01709 L
s
.86747 .23305 m
.84848 .01706 L
s
.90731 .28818 m
.86734 .23307 L
s
.90752 .28803 m
.86755 .23292 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.333038 0.494527 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0326551 1.03266 -0.20378 1.03266 [
[.5 .60171 -24.4062 0 ]
[.5 .60171 24.4062 12 ]
[ 0 0 0 0 ]
[ 1 .58921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .60171 -85.4062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(DovePrism) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .58921 L
0 .58921 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.15556 .40403 m
.04005 .29819 L
s
.95461 .14672 m
.15556 .40403 L
s
.32406 .52272 m
.15554 .40396 L
s
.15554 .40396 m
.95459 .14665 L
s
.32423 .5227 m
.1557 .40394 L
s
.1557 .40394 m
.0402 .2981 L
s
.20907 .41566 m
.04008 .29818 L
s
.04008 .29818 m
.86591 .01583 L
s
.04005 .29819 m
.86589 .01584 L
s
.0402 .2981 m
.20919 .41558 L
s
.32409 .5227 m
.20904 .41558 L
s
.76106 .3921 m
.32409 .5227 L
s
.76104 .39211 m
.32406 .52272 L
s
.20919 .41558 m
.32423 .5227 L
s
.95444 .14673 m
.76089 .39219 L
s
.86571 .01586 m
.95444 .14673 L
s
.86589 .01584 m
.95461 .14672 L
s
.95459 .14665 m
.76104 .39211 L
s
.6612 .27184 m
.20907 .41566 L
s
.20904 .41558 m
.66118 .27176 L
s
.76089 .39219 m
.661 .27186 L
s
.66118 .27176 m
.76106 .3921 L
s
.661 .27186 m
.86571 .01586 L
s
.86591 .01583 m
.6612 .27184 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.333038 0.614943 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0 1.00673 -0.144739 1.00673 [
[.5 .66355 -31.3438 0 ]
[.5 .66355 31.3438 12 ]
[ 0 0 0 0 ]
[ 1 .65105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .66355 -92.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(FresnelRhomb) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .65105 L
0 .65105 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61034 .41201 m
.85424 .14942 L
s
.52006 .31033 m
.61034 .41201 L
s
.61034 .41201 m
.15593 .38284 L
s
.61395 .54477 m
.61034 .41201 L
s
.15593 .38284 m
.04121 .27814 L
s
.14404 .51657 m
.15593 .38284 L
s
.61395 .54477 m
.86766 .28995 L
s
.52065 .44636 m
.61395 .54477 L
s
.61395 .54477 m
.14404 .51657 L
s
.14404 .51657 m
.02456 .41514 L
s
.04121 .27814 m
.52006 .31033 L
s
.52065 .44636 m
.52006 .31033 L
s
.7655 .01891 m
.52006 .31033 L
s
.04121 .27814 m
.02456 .41514 L
s
.02456 .41514 m
.52065 .44636 L
s
.77612 .16247 m
.52065 .44636 L
s
.85424 .14942 m
.7655 .01891 L
s
.86766 .28995 m
.85424 .14942 L
s
.77612 .16247 m
.86766 .28995 L
s
.7655 .01891 m
.77612 .16247 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.333038 0.735359 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.13389 1.33863 -1.11022e-16 1.33863 [
[.5 1.27821 -41.3125 0 ]
[.5 1.27821 41.3125 12 ]
[ 0 0 0 0 ]
[ 1 1.26571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.27821 -102.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(HollowCornerCube) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.26571 L
0 1.26571 L
closepath
clip
newpath
.43374 .67109 m .43931 .66802 L .46476 .75232 L .947 .687 .51 r
F
.40097 .59426 m .43931 .66802 L .43374 .67109 L F
.40097 .59426 m .40521 .58797 L .43931 .66802 L F
.45816 .75202 m .46476 .75232 L .48035 .837 L F
.43374 .67109 m .46476 .75232 L .45816 .75202 L F
0 g
.5 Mabswid
[ ] 0 setdash
.43931 .66802 m
.46476 .75232 L
s
.4281 .67418 m .43374 .67109 L .45816 .75202 L .947 .687 .51 r
F
.39669 .60062 m .43374 .67109 L .4281 .67418 L F
.39669 .60062 m .40097 .59426 L .43374 .67109 L F
.45816 .75202 m .48035 .837 L .47307 .83328 L F
.45149 .75172 m .45816 .75202 L .47307 .83328 L F
.4281 .67418 m .45816 .75202 L .45149 .75172 L F
.36127 .52529 m .40521 .58797 L .40097 .59426 L F
.36127 .52529 m .36389 .51598 L .40521 .58797 L F
0 g
.40521 .58797 m
.43931 .66802 L
s
.47307 .83328 m .48035 .837 L .48509 .91804 L .947 .687 .51 r
F
0 g
.46476 .75232 m
.48035 .837 L
s
.42242 .67731 m .4281 .67418 L .45149 .75172 L .947 .687 .51 r
F
.39237 .60704 m .4281 .67418 L .42242 .67731 L F
.39237 .60704 m .39669 .60062 L .4281 .67418 L F
.45149 .75172 m .47307 .83328 L .46572 .82954 L F
.44476 .75141 m .45149 .75172 L .46572 .82954 L F
.42242 .67731 m .45149 .75172 L .44476 .75141 L F
.35863 .53468 m .40097 .59426 L .39669 .60062 L F
.35863 .53468 m .36127 .52529 L .40097 .59426 L F
.47307 .83328 m .48509 .91804 L .4775 .91095 L F
.46572 .82954 m .47307 .83328 L .4775 .91095 L F
.35597 .54415 m .39669 .60062 L .39237 .60704 L F
0 g
.39237 .60704 m
.42242 .67731 L
s
.35597 .54415 m .35863 .53468 L .39669 .60062 L .947 .687 .51 r
F
.44476 .75141 m .46572 .82954 L .4583 .82575 L F
0 g
.42242 .67731 m
.44476 .75141 L
s
.46572 .82954 m .4775 .91095 L .46985 .90381 L .947 .687 .51 r
F
.4583 .82575 m .46572 .82954 L .46985 .90381 L F
.31635 .46793 m .36389 .51598 L .36127 .52529 L F
.31635 .46793 m .31708 .45595 L .36389 .51598 L F
0 g
.36389 .51598 m
.40521 .58797 L
s
.4583 .82575 m .46985 .90381 L .46214 .89662 L .947 .687 .51 r
F
0 g
.44476 .75141 m
.4583 .82575 L
s
.31562 .48 m .36127 .52529 L .35863 .53468 L .947 .687 .51 r
F
.31562 .48 m .31635 .46793 L .36127 .52529 L F
.4775 .91095 m .48509 .91804 L .47822 .99121 L F
0 g
.48035 .837 m
.48509 .91804 L
s
.31489 .49214 m .35863 .53468 L .35597 .54415 L .947 .687 .51 r
F
0 g
.35597 .54415 m
.39237 .60704 L
s
.31489 .49214 m .31562 .48 L .35863 .53468 L .947 .687 .51 r
F
.4775 .91095 m .47822 .99121 L .47075 .98091 L F
.46985 .90381 m .4775 .91095 L .47075 .98091 L F
.46985 .90381 m .47075 .98091 L .46325 .97056 L F
.46214 .89662 m .46985 .90381 L .46325 .97056 L F
.31708 .45595 m .79001 .58781 L .67943 .68564 L .278 .555 .928 r
F
0 g
.31708 .45595 m
.36389 .51598 L
s
.31708 .45595 m
.31708 .45595 L
s
.45933 1.05199 m .67943 .68564 L .79001 .58781 L 0 0 0 r
F
.46214 .89662 m .46325 .97056 L .45569 .96014 L .947 .687 .51 r
F
0 g
.4583 .82575 m
.46214 .89662 L
s
.31708 .45595 m .36536 .31746 L .79001 .58781 L .278 .555 .928 r
F
0 g
.31708 .45595 m
.67943 .68564 L
s
.26831 .42594 m .31708 .45595 L .31635 .46793 L .947 .687 .51 r
F
.26831 .42594 m .26693 .41178 L .31708 .45595 L F
0 g
.31708 .45595 m
.31708 .45595 L
s
.26971 .44017 m .31635 .46793 L .31562 .48 L .947 .687 .51 r
F
.26971 .44017 m .26831 .42594 L .31635 .46793 L F
.27111 .45446 m .31562 .48 L .31489 .49214 L F
0 g
.31489 .49214 m
.35597 .54415 L
s
.27111 .45446 m .26971 .44017 L .31562 .48 L .947 .687 .51 r
F
.47075 .98091 m .47822 .99121 L .45933 1.05199 L F
0 g
.47822 .99121 m
.48509 .91804 L
s
.47075 .98091 m .45933 1.05199 L .45248 1.03882 L .947 .687 .51 r
F
.46325 .97056 m .47075 .98091 L .45248 1.03882 L F
.46325 .97056 m .45248 1.03882 L .4456 1.02559 L F
.45569 .96014 m .46325 .97056 L .4456 1.02559 L F
.45569 .96014 m .4456 1.02559 L .4387 1.01232 L F
0 g
.45569 .96014 m
.46214 .89662 L
s
.21972 .40294 m .26693 .41178 L .26831 .42594 L .947 .687 .51 r
F
.21972 .40294 m .21606 .38729 L .26693 .41178 L F
0 g
.26693 .41178 m
.31708 .45595 L
s
.22338 .41862 m .26831 .42594 L .26971 .44017 L .947 .687 .51 r
F
.22338 .41862 m .21972 .40294 L .26831 .42594 L F
.22705 .43432 m .26971 .44017 L .27111 .45446 L F
0 g
.27111 .45446 m
.31489 .49214 L
s
.22705 .43432 m .22338 .41862 L .26971 .44017 L .947 .687 .51 r
F
.45933 1.05199 m .79001 .58781 L .53543 1.0158 L 0 0 0 r
F
0 g
.45933 1.05199 m
.67943 .68564 L
s
.45248 1.03882 m .45933 1.05199 L .42854 1.09573 L .947 .687 .51 r
F
0 g
.45933 1.05199 m
.47822 .99121 L
s
.45248 1.03882 m .42854 1.09573 L .42285 1.08023 L .947 .687 .51 r
F
.4456 1.02559 m .45248 1.03882 L .42285 1.08023 L F
.4456 1.02559 m .42285 1.08023 L .41714 1.06471 L F
.4387 1.01232 m .4456 1.02559 L .41714 1.06471 L F
.4387 1.01232 m .41714 1.06471 L .41143 1.04917 L F
0 g
.4387 1.01232 m
.45569 .96014 L
s
.17363 .40207 m .21606 .38729 L .21972 .40294 L .947 .687 .51 r
F
.17363 .40207 m .16767 .38587 L .21606 .38729 L F
0 g
.21606 .38729 m
.26693 .41178 L
s
.17958 .41826 m .21972 .40294 L .22338 .41862 L .947 .687 .51 r
F
.17958 .41826 m .17363 .40207 L .21972 .40294 L F
.18552 .43443 m .22338 .41862 L .22705 .43432 L F
0 g
.22705 .43432 m
.27111 .45446 L
s
.18552 .43443 m .17958 .41826 L .22338 .41862 L .947 .687 .51 r
F
.42285 1.08023 m .42854 1.09573 L .38675 1.11792 L F
0 g
.42854 1.09573 m
.45933 1.05199 L
s
.42285 1.08023 m .38675 1.11792 L .38277 1.10091 L .947 .687 .51 r
F
.41714 1.06471 m .42285 1.08023 L .38277 1.10091 L F
.41714 1.06471 m .38277 1.10091 L .37881 1.08394 L F
.41143 1.04917 m .41714 1.06471 L .37881 1.08394 L F
.41143 1.04917 m .37881 1.08394 L .37485 1.06699 L F
0 g
.41143 1.04917 m
.4387 1.01232 L
s
.14966 .45652 m .17958 .41826 L .18552 .43443 L .947 .687 .51 r
F
0 g
.18552 .43443 m
.22705 .43432 L
s
.14161 .44105 m .17363 .40207 L .17958 .41826 L .947 .687 .51 r
F
.14966 .45652 m .14161 .44105 L .17958 .41826 L F
.13353 .42551 m .16767 .38587 L .17363 .40207 L F
.14161 .44105 m .13353 .42551 L .17363 .40207 L F
.13353 .42551 m .12542 .40991 L .16767 .38587 L F
0 g
.16767 .38587 m
.21606 .38729 L
s
.37485 1.06699 m .33246 1.08007 L .33078 1.06284 L .947 .687 .51 r
F
.37485 1.06699 m .37881 1.08394 L .33246 1.08007 L F
0 g
.37485 1.06699 m
.41143 1.04917 L
s
.37881 1.08394 m .33416 1.09737 L .33246 1.08007 L .947 .687 .51 r
F
.37881 1.08394 m .38277 1.10091 L .33416 1.09737 L F
.38277 1.10091 m .33587 1.11477 L .33416 1.09737 L F
.38277 1.10091 m .38675 1.11792 L .33587 1.11477 L F
0 g
.38675 1.11792 m
.42854 1.09573 L
s
.12268 .50081 m .14161 .44105 L .14966 .45652 L .947 .687 .51 r
F
0 g
.14966 .45652 m
.18552 .43443 L
s
.11292 .48734 m .13353 .42551 L .14161 .44105 L .947 .687 .51 r
F
.12268 .50081 m .11292 .48734 L .14161 .44105 L F
.10309 .47378 m .12542 .40991 L .13353 .42551 L F
.11292 .48734 m .10309 .47378 L .13353 .42551 L F
.10309 .47378 m .09319 .46013 L .12542 .40991 L F
0 g
.12542 .40991 m
.16767 .38587 L
s
.33078 1.06284 m .28103 1.05133 L .282 1.03518 L .947 .687 .51 r
F
.33078 1.06284 m .33246 1.08007 L .28103 1.05133 L F
0 g
.33078 1.06284 m
.37485 1.06699 L
s
.33246 1.08007 m .28004 1.0676 L .28103 1.05133 L .947 .687 .51 r
F
.33246 1.08007 m .33416 1.09737 L .28004 1.0676 L F
.33416 1.09737 m .27905 1.08401 L .28004 1.0676 L F
.33416 1.09737 m .33587 1.11477 L .27905 1.08401 L F
0 g
.33587 1.11477 m
.38675 1.11792 L
s
.1075 .56545 m .11292 .48734 L .12268 .50081 L .947 .687 .51 r
F
0 g
.12268 .50081 m
.14966 .45652 L
s
.09665 .55531 m .10309 .47378 L .11292 .48734 L .947 .687 .51 r
F
.1075 .56545 m .09665 .55531 L .11292 .48734 L F
.08569 .54508 m .09319 .46013 L .10309 .47378 L F
.09665 .55531 m .08569 .54508 L .10309 .47378 L F
.282 1.03518 m .22841 .99812 L .23224 .98449 L F
.282 1.03518 m .28103 1.05133 L .22841 .99812 L F
0 g
.282 1.03518 m
.33078 1.06284 L
s
.08569 .54508 m .07463 .53475 L .09319 .46013 L .947 .687 .51 r
F
0 g
.09319 .46013 m
.12542 .40991 L
s
.28103 1.05133 m .22454 1.01189 L .22841 .99812 L .947 .687 .51 r
F
.28103 1.05133 m .28004 1.0676 L .22454 1.01189 L F
.11969 .73665 m .09512 .64055 L .10624 .64622 L F
.10924 .73617 m .08387 .63482 L .09512 .64055 L F
.11969 .73665 m .10924 .73617 L .09512 .64055 L F
.09866 .73569 m .0725 .62902 L .08387 .63482 L F
.10924 .73617 m .09866 .73569 L .08387 .63482 L F
.09866 .73569 m .08795 .73521 L .0725 .62902 L F
.12918 .83848 m .08795 .73521 L .09866 .73569 L F
.12918 .83848 m .12008 .84348 L .08795 .73521 L F
.08795 .73521 m .79001 .58781 L .36536 .31746 L .744 .57 .658 r
F
.14704 .82866 m .10924 .73617 L .11969 .73665 L .947 .687 .51 r
F
.14704 .82866 m .13816 .83354 L .10924 .73617 L F
.13816 .83354 m .09866 .73569 L .10924 .73617 L F
.13816 .83354 m .12918 .83848 L .09866 .73569 L F
.08795 .73521 m .53543 1.0158 L .79001 .58781 L .744 .57 .658 r
F
0 g
.53543 1.0158 m
.79001 .58781 L
s
.36536 .31746 m
.79001 .58781 L
s
.45933 1.05199 m
.53543 1.0158 L
s
.28004 1.0676 m .22064 1.02579 L .22454 1.01189 L .947 .687 .51 r
F
.28004 1.0676 m .27905 1.08401 L .22064 1.02579 L F
0 g
.27905 1.08401 m
.33587 1.11477 L
s
.10624 .64622 m .09665 .55531 L .1075 .56545 L .947 .687 .51 r
F
0 g
.1075 .56545 m
.12268 .50081 L
s
.09512 .64055 m .08569 .54508 L .09665 .55531 L .947 .687 .51 r
F
.10624 .64622 m .09512 .64055 L .09665 .55531 L F
0 g
.10624 .64622 m
.1075 .56545 L
s
.23224 .98449 m .17923 .92356 L .1858 .9138 L .947 .687 .51 r
F
.23224 .98449 m .22841 .99812 L .17923 .92356 L F
0 g
.23224 .98449 m
.282 1.03518 L
s
.08387 .63482 m .07463 .53475 L .08569 .54508 L .947 .687 .51 r
F
.09512 .64055 m .08387 .63482 L .08569 .54508 L F
0 g
.08795 .73521 m
.36536 .31746 L
s
.22841 .99812 m .17258 .93343 L .17923 .92356 L .947 .687 .51 r
F
.22841 .99812 m .22454 1.01189 L .17258 .93343 L F
.08387 .63482 m .0725 .62902 L .07463 .53475 L F
0 g
.0725 .62902 m
.07463 .53475 L
s
.07463 .53475 m
.09319 .46013 L
s
.22454 1.01189 m .16585 .94342 L .17258 .93343 L .947 .687 .51 r
F
.22454 1.01189 m .22064 1.02579 L .16585 .94342 L F
0 g
.22064 1.02579 m
.27905 1.08401 L
s
.10624 .64622 m
.11371 .69642 L
s
.1858 .9138 m .13816 .83354 L .14704 .82866 L .947 .687 .51 r
F
.1858 .9138 m .17923 .92356 L .13816 .83354 L F
0 g
.1858 .9138 m
.23224 .98449 L
s
.12644 .75934 m
.14704 .82866 L
s
.17923 .92356 m .12918 .83848 L .13816 .83354 L .947 .687 .51 r
F
.17923 .92356 m .17258 .93343 L .12918 .83848 L F
0 g
.14704 .82866 m
.1858 .9138 L
s
.17258 .93343 m .12008 .84348 L .12918 .83848 L .947 .687 .51 r
F
.17258 .93343 m .16585 .94342 L .12008 .84348 L F
0 g
.16585 .94342 m
.22064 1.02579 L
s
.0725 .62902 m
.08795 .73521 L
s
.08795 .73521 m
.53543 1.0158 L
s
.12008 .84348 m
.16585 .94342 L
s
.08795 .73521 m
.12008 .84348 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.333038 0.855774 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.577662 2.26497 2.22045e-16 2.26497 [
[.5 2.22829 -37.7188 0 ]
[.5 2.22829 37.7188 12.1875 ]
[ 0 0 0 0 ]
[ 1 2.21579 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 2.22829 -98.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(JonesMatrixOptic) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2.21579 L
0 2.21579 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.78883 1.18093 m
.7364 1.00885 L
s
.7364 1.00885 m
.78781 .99213 L
s
.7364 1.00885 m
.66918 .84447 L
s
.82405 1.35293 m
.78883 1.18093 L
s
.78883 1.18093 m
.84052 1.16488 L
s
.84052 1.16488 m
.78781 .99213 L
s
.78781 .99213 m
.83964 .97527 L
s
.72067 .82697 m
.78781 .99213 L
s
.87635 1.33742 m
.84052 1.16488 L
s
.84052 1.16488 m
.89262 1.14869 L
s
.66918 .84447 m
.72067 .82697 L
s
.66918 .84447 m
.59 .69552 L
s
.83964 .97527 m
.89262 1.14869 L
s
.77257 .80934 m
.83964 .97527 L
s
.89262 1.14869 m
.92907 1.32179 L
s
.82405 1.35293 m
.87635 1.33742 L
s
.72067 .82697 m
.77257 .80934 L
s
.72067 .82697 m
.64189 .67717 L
s
.87635 1.33742 m
.92907 1.32179 L
s
.69422 .65867 m
.77257 .80934 L
s
.59 .69552 m
.64189 .67717 L
s
.64189 .67717 m
.69422 .65867 L
s
.733 1.40235 m .89318 1.50169 L .83996 1.51678 L .656 .751 .92 r
F
0 g
.83479 1.66396 m
.83996 1.51678 L
s
.82405 1.35293 m
.83499 1.4656 L
s
.733 1.40235 m .78743 1.3863 L .89318 1.50169 L .656 .751 .92 r
F
.78743 1.3863 m .94684 1.48648 L .89318 1.50169 L F
0 g
.83996 1.51678 m
.89318 1.50169 L
s
.87635 1.33742 m
.88782 1.44939 L
s
.88923 1.64913 m
.89318 1.50169 L
s
.78743 1.3863 m .84232 1.37012 L .94684 1.48648 L .656 .751 .92 r
F
0 g
.94412 1.63418 m
.94684 1.48648 L
s
.92907 1.32179 m
.94684 1.48648 L
s
.89318 1.50169 m
.94684 1.48648 L
s
.50219 .56991 m .55482 .73441 L .50081 .75339 L .544 .324 .532 r
F
.50219 .56991 m .55482 .55065 L .55482 .73441 L F
0 g
.55482 .64521 m
.59 .69552 L
s
.40982 .47572 m
.50219 .56991 L
s
.55482 .55065 m .6093 .71526 L .55482 .73441 L .544 .324 .532 r
F
.55482 .55065 m .6079 .53123 L .6093 .71526 L F
0 g
.6079 .53123 m
.69422 .65867 L
s
.60864 .62885 m
.64189 .67717 L
s
.50219 .56991 m
.55482 .55065 L
s
.55482 .55065 m
.6079 .53123 L
s
.46349 .45553 m
.55482 .55065 L
s
.80738 1.78536 m
.83479 1.66396 L
s
.83479 1.66396 m
.88923 1.64913 L
s
.51762 .43517 m
.6079 .53123 L
s
.86326 1.77064 m
.88923 1.64913 L
s
.88923 1.64913 m
.94412 1.63418 L
s
.61919 1.28057 m .78743 1.3863 L .733 1.40235 L .656 .751 .92 r
F
0 g
.733 1.40235 m
.83996 1.51678 L
s
.94412 1.63418 m
.91963 1.75578 L
s
.67487 1.26348 m .84232 1.37012 L .78743 1.3863 L .656 .751 .92 r
F
.61919 1.28057 m .67487 1.26348 L .78743 1.3863 L F
0 g
.78743 1.3863 m
.89318 1.50169 L
s
.67487 1.26348 m .73105 1.24624 L .84232 1.37012 L .656 .751 .92 r
F
0 g
.84232 1.37012 m
.94684 1.48648 L
s
.50081 .75339 m .55482 .92808 L .49936 .94673 L .544 .324 .532 r
F
.50081 .75339 m .55482 .73441 L .55482 .92808 L F
0 g
.50081 .75339 m
.50219 .56991 L
s
.40982 .47572 m
.46349 .45553 L
s
.40982 .47572 m
.31782 .42094 L
s
.55482 .73441 m .61078 .90926 L .55482 .92808 L .544 .324 .532 r
F
.55482 .73441 m .6093 .71526 L .61078 .90926 L F
0 g
.55482 .55065 m
.55482 .73441 L
s
.6079 .53123 m
.6093 .71526 L
s
.46349 .45553 m
.51762 .43517 L
s
.46349 .45553 m
.37279 .39987 L
s
.42824 .37862 m
.51762 .43517 L
s
.75741 1.87156 m
.80738 1.78536 L
s
.80738 1.78536 m
.86326 1.77064 L
s
.8149 1.85673 m
.86326 1.77064 L
s
.86326 1.77064 m
.91963 1.75578 L
s
.91963 1.75578 m
.8729 1.84178 L
s
.49783 1.15073 m .67487 1.26348 L .61919 1.28057 L .656 .751 .92 r
F
0 g
.61919 1.28057 m
.733 1.40235 L
s
.55482 1.13249 m .73105 1.24624 L .67487 1.26348 L .656 .751 .92 r
F
.49783 1.15073 m .55482 1.13249 L .67487 1.26348 L F
0 g
.67487 1.26348 m
.78743 1.3863 L
s
.49936 .94673 m .55482 1.13249 L .49783 1.15073 L .544 .324 .532 r
F
.49936 .94673 m .55482 .92808 L .55482 1.13249 L F
0 g
.49936 .94673 m
.50081 .75339 L
s
.55482 1.13249 m .61233 1.11407 L .73105 1.24624 L .656 .751 .92 r
F
0 g
.73105 1.24624 m
.84232 1.37012 L
s
.55482 .92808 m .61233 1.11407 L .55482 1.13249 L .544 .324 .532 r
F
.55482 .92808 m .61078 .90926 L .61233 1.11407 L F
0 g
.55482 .73441 m
.55482 .92808 L
s
.6093 .71526 m
.61078 .90926 L
s
.31782 .42094 m
.37279 .39987 L
s
.31782 .42094 m
.2321 .41283 L
s
.37279 .39987 m
.42824 .37862 L
s
.37279 .39987 m
.28856 .391 L
s
.34554 .36897 m
.42824 .37862 L
s
.68595 1.9134 m
.75741 1.87156 L
s
.75741 1.87156 m
.8149 1.85673 L
s
.7451 1.89826 m
.8149 1.85673 L
s
.8149 1.85673 m
.8729 1.84178 L
s
.8729 1.84178 m
.8048 1.88297 L
s
.49783 1.15073 m .55482 1.34855 L .49621 1.36632 L .544 .324 .532 r
F
.49783 1.15073 m .55482 1.13249 L .55482 1.34855 L F
0 g
.55482 1.21171 m
.61919 1.28057 L
s
.36816 1.012 m .55482 1.13249 L .49783 1.15073 L .656 .751 .92 r
F
0 g
.49824 1.09596 m
.49936 .94673 L
s
.55482 1.13249 m .61398 1.33062 L .55482 1.34855 L .544 .324 .532 r
F
.55482 1.13249 m .61233 1.11407 L .61398 1.33062 L F
0 g
.61296 1.19592 m
.67487 1.26348 L
s
.42651 .99248 m .61233 1.11407 L .55482 1.13249 L .656 .751 .92 r
F
0 g
.55482 .92808 m
.55482 1.07644 L
s
.36816 1.012 m .42651 .99248 L .55482 1.13249 L .656 .751 .92 r
F
.42651 .99248 m .48541 .97277 L .61233 1.11407 L F
0 g
.61233 1.11407 m
.73105 1.24624 L
s
.61078 .90926 m
.61233 1.11407 L
s
.2321 .41283 m
.15935 .45678 L
s
.28856 .391 m
.2321 .41283 L
s
.28856 .391 m
.21742 .43441 L
s
.34554 .36897 m
.28856 .391 L
s
.27604 .41182 m
.34554 .36897 L
s
.59594 1.90321 m
.68595 1.9134 L
s
.68595 1.9134 m
.7451 1.89826 L
s
.65669 1.88749 m
.7451 1.89826 L
s
.7451 1.89826 m
.8048 1.88297 L
s
.49621 1.36632 m .55482 1.57731 L .4945 1.59451 L .544 .324 .532 r
F
.49621 1.36632 m .55482 1.34855 L .55482 1.57731 L F
0 g
.49621 1.36632 m
.49783 1.15073 L
s
.8048 1.88297 m
.71802 1.87163 L
s
.55482 1.34855 m .61573 1.55994 L .55482 1.57731 L .544 .324 .532 r
F
.55482 1.34855 m .61398 1.33062 L .61573 1.55994 L F
0 g
.55482 1.13249 m
.55482 1.34855 L
s
.61233 1.11407 m
.61398 1.33062 L
s
.2293 .86342 m .42651 .99248 L .36816 1.012 L .656 .751 .92 r
F
0 g
.36816 1.012 m
.49783 1.15073 L
s
.28906 .84249 m .48541 .97277 L .42651 .99248 L .656 .751 .92 r
F
.2293 .86342 m .28906 .84249 L .42651 .99248 L F
0 g
.42651 .99248 m
.55482 1.13249 L
s
.28906 .84249 m .3494 .82135 L .48541 .97277 L .656 .751 .92 r
F
0 g
.48541 .97277 m
.61233 1.11407 L
s
.15935 .45678 m
.21742 .43441 L
s
.15935 .45678 m
.10658 .55482 L
s
.21742 .43441 m
.27604 .41182 L
s
.21742 .43441 m
.16628 .5322 L
s
.22657 .50935 m
.27604 .41182 L
s
.59594 1.90321 m
.65669 1.88749 L
s
.4945 1.59451 m .55482 1.8199 L .49269 1.83643 L .544 .324 .532 r
F
0 g
.49269 1.83643 m
.59594 1.90321 L
s
.4945 1.59451 m .55482 1.57731 L .55482 1.8199 L .544 .324 .532 r
F
0 g
.4945 1.59451 m
.49621 1.36632 L
s
.49269 1.83643 m
.4945 1.59451 L
s
.65669 1.88749 m
.71802 1.87163 L
s
.55482 1.57731 m .61758 1.8032 L .55482 1.8199 L .544 .324 .532 r
F
0 g
.55482 1.8199 m
.65669 1.88749 L
s
.55482 1.57731 m .61573 1.55994 L .61758 1.8032 L .544 .324 .532 r
F
0 g
.55482 1.34855 m
.55482 1.57731 L
s
.61398 1.33062 m
.61573 1.55994 L
s
.55482 1.57731 m
.55482 1.8199 L
s
.61758 1.8032 m
.71802 1.87163 L
s
.61573 1.55994 m
.61758 1.8032 L
s
.08021 .70391 m .28906 .84249 L .2293 .86342 L .656 .751 .92 r
F
0 g
.2293 .86342 m
.36816 1.012 L
s
.14144 .68141 m .3494 .82135 L .28906 .84249 L .656 .751 .92 r
F
.08021 .70391 m .14144 .68141 L .28906 .84249 L F
0 g
.28906 .84249 m
.42651 .99248 L
s
.08021 .70391 m
.10658 .55482 L
s
.16628 .5322 m
.10658 .55482 L
s
.14144 .68141 m .20328 .65867 L .3494 .82135 L .656 .751 .92 r
F
0 g
.20328 .65867 m
.3494 .82135 L
s
.14144 .68141 m
.28906 .84249 L
s
.08021 .70391 m
.2293 .86342 L
s
.3494 .82135 m
.48541 .97277 L
s
.14144 .68141 m
.16628 .5322 L
s
.22657 .50935 m
.16628 .5322 L
s
.49269 1.83643 m
.55482 1.8199 L
s
.38388 1.71356 m
.49269 1.83643 L
s
.20328 .65867 m
.22657 .50935 L
s
.55482 1.8199 m
.61758 1.8032 L
s
.44707 1.69598 m
.55482 1.8199 L
s
.5109 1.67822 m
.61758 1.8032 L
s
.08021 .70391 m
.14144 .68141 L
s
.08021 .70391 m
.08481 .89474 L
s
.14144 .68141 m
.20328 .65867 L
s
.14144 .68141 m
.14732 .87275 L
s
.27914 1.54163 m
.38388 1.71356 L
s
.38388 1.71356 m
.44707 1.69598 L
s
.20328 .65867 m
.21046 .85053 L
s
.34292 1.52286 m
.44707 1.69598 L
s
.44707 1.69598 m
.5109 1.67822 L
s
.5109 1.67822 m
.40737 1.50389 L
s
.08481 .89474 m
.14732 .87275 L
s
.08481 .89474 m
.12182 1.11171 L
s
.18872 1.33457 m
.27914 1.54163 L
s
.27914 1.54163 m
.34292 1.52286 L
s
.14732 .87275 m
.21046 .85053 L
s
.14732 .87275 m
.18524 1.09058 L
s
.25258 1.31456 m
.34292 1.52286 L
s
.34292 1.52286 m
.40737 1.50389 L
s
.24931 1.06924 m
.21046 .85053 L
s
.12182 1.11171 m
.18524 1.09058 L
s
.18872 1.33457 m
.12182 1.11171 L
s
.18872 1.33457 m
.25258 1.31456 L
s
.40737 1.50389 m
.31711 1.29435 L
s
.18524 1.09058 m
.24931 1.06924 L
s
.18524 1.09058 m
.25258 1.31456 L
s
.25258 1.31456 m
.31711 1.29435 L
s
.31711 1.29435 m
.24931 1.06924 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.333038 0.97619 0.429993 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.291201 1.67397 0 1.67397 [
[.5 1.6241 -27.75 0 ]
[.5 1.6241 27.75 12 ]
[ 0 0 0 0 ]
[ 1 1.6116 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.6241 -88.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(LensDoublet) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.6116 L
0 1.6116 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.65547 .8859 m
.61982 .76867 L
s
.61982 .76867 m
.69042 .7457 L
s
.61982 .76867 m
.5737 .6568 L
s
.67901 1.00319 m
.65547 .8859 L
s
.65547 .8859 m
.72645 .86385 L
s
.5737 .6568 m
.6444 .63278 L
s
.5737 .6568 m
.51906 .5556 L
s
.72645 .86385 m
.69042 .7457 L
s
.69042 .7457 m
.828 .70096 L
s
.69042 .7457 m
.6444 .63278 L
s
.75082 .98189 m
.72645 .86385 L
s
.72645 .86385 m
.86476 .82089 L
s
.67901 1.00319 m
.75082 .98189 L
s
.6444 .63278 m
.78219 .58597 L
s
.6444 .63278 m
.59032 .53041 L
s
.75082 .98189 m
.89078 .94039 L
s
.51906 .5556 m
.59032 .53041 L
s
.828 .70096 m
.86476 .82089 L
s
.78219 .58597 m
.828 .70096 L
s
.86476 .82089 m
.89078 .94039 L
s
.57256 1.04994 m .76208 1.09431 L .68901 1.11503 L .656 .751 .92 r
F
0 g
.6843 1.21559 m
.68901 1.11503 L
s
.67901 1.00319 m
.68555 1.07639 L
s
.72924 .48129 m
.78219 .58597 L
s
.57256 1.04994 m .75416 .99641 L .76208 1.09431 L .656 .751 .92 r
F
0 g
.75082 .98189 m
.75233 .99695 L
s
.75416 .99641 m .90456 1.05391 L .76208 1.09431 L .656 .751 .92 r
F
0 g
.68901 1.11503 m
.76208 1.09431 L
s
.75902 1.19524 m
.76208 1.09431 L
s
.4582 .47044 m .59444 .54717 L .41425 .61051 L .544 .324 .532 r
F
.4582 .47044 m .53045 .444 L .59444 .54717 L F
0 g
.59032 .53041 m
.72924 .48129 L
s
.39392 .40682 m
.4582 .47044 L
s
.66411 1.29866 m
.6843 1.21559 L
s
.6843 1.21559 m
.75902 1.19524 L
s
.53045 .444 m .6976 .51091 L .59444 .54717 L .544 .324 .532 r
F
.53045 .444 m .6714 .39242 L .6976 .51091 L F
0 g
.4582 .47044 m
.53045 .444 L
s
.6714 .39242 m
.72924 .48129 L
s
.53045 .444 m
.6714 .39242 L
s
.46758 .37911 m
.53045 .444 L
s
.75416 .99641 m .85809 .96577 L .90456 1.05391 L .656 .751 .92 r
F
0 g
.90456 1.05391 m
.9048 1.15554 L
s
.89078 .94039 m
.90456 1.05391 L
s
.76208 1.09431 m
.90456 1.05391 L
s
.46753 .97599 m .75416 .99641 L .57256 1.04994 L .656 .751 .92 r
F
0 g
.57256 1.04994 m
.68901 1.11503 L
s
.74081 1.27845 m
.75902 1.19524 L
s
.75902 1.19524 m
.9048 1.15554 L
s
.41425 .61051 m .6337 .66739 L .38595 .75069 L .544 .324 .532 r
F
.41425 .61051 m .59444 .54717 L .6337 .66739 L F
0 g
.41425 .61051 m
.4582 .47044 L
s
.61137 .32503 m
.6714 .39242 L
s
.39392 .40682 m
.46758 .37911 L
s
.39392 .40682 m
.32965 .37014 L
s
.71629 .89963 m .85809 .96577 L .75416 .99641 L .656 .751 .92 r
F
.46753 .97599 m .71629 .89963 L .75416 .99641 L F
0 g
.75416 .99641 m
.76208 1.09431 L
s
.9048 1.15554 m
.89054 1.23899 L
s
.46758 .37911 m
.61137 .32503 L
s
.46758 .37911 m
.40507 .34123 L
s
.62833 1.3578 m
.66411 1.29866 L
s
.66411 1.29866 m
.74081 1.27845 L
s
.37325 .89222 m .71629 .89963 L .46753 .97599 L .656 .751 .92 r
F
0 g
.46753 .97599 m
.57256 1.04994 L
s
.59444 .54717 m .71582 .63978 L .6337 .66739 L .544 .324 .532 r
F
.59444 .54717 m .6976 .51091 L .71582 .63978 L F
0 g
.53045 .444 m
.59444 .54717 L
s
.6714 .39242 m
.6976 .51091 L
s
.71629 .89963 m .79873 .87433 L .85809 .96577 L .656 .751 .92 r
F
0 g
.85809 .96577 m
.90456 1.05391 L
s
.38595 .75069 m .6489 .80397 L .37325 .89222 L .544 .324 .532 r
F
.38595 .75069 m .6337 .66739 L .6489 .80397 L F
0 g
.38595 .75069 m
.41425 .61051 L
s
.70721 1.33746 m
.74081 1.27845 L
s
.74081 1.27845 m
.89054 1.23899 L
s
.5524 .28476 m
.61137 .32503 L
s
.32965 .37014 m
.40507 .34123 L
s
.32965 .37014 m
.26948 .36532 L
s
.89054 1.23899 m
.86132 1.29772 L
s
.40507 .34123 m
.5524 .28476 L
s
.40507 .34123 m
.34693 .33538 L
s
.37325 .89222 m .6489 .80397 L .71629 .89963 L .656 .751 .92 r
F
.6489 .80397 m .79873 .87433 L .71629 .89963 L F
0 g
.71629 .89963 m
.75416 .99641 L
s
.57777 1.38677 m
.62833 1.3578 L
s
.62833 1.3578 m
.70721 1.33746 L
s
.37325 .89222 m .63876 .95682 L .37701 1.03617 L .544 .324 .532 r
F
.37325 .89222 m .6489 .80397 L .63876 .95682 L F
.28987 .79728 m .6489 .80397 L .37325 .89222 L .656 .751 .92 r
F
0 g
.38161 .79899 m
.38595 .75069 L
s
.6337 .66739 m .72544 .77947 L .6489 .80397 L .544 .324 .532 r
F
.6337 .66739 m .71582 .63978 L .72544 .77947 L F
0 g
.59444 .54717 m
.6337 .66739 L
s
.6976 .51091 m
.71582 .63978 L
s
.6589 1.366 m
.70721 1.33746 L
s
.70721 1.33746 m
.86132 1.29772 L
s
.6489 .80397 m .72544 .77947 L .79873 .87433 L .656 .751 .92 r
F
0 g
.79873 .87433 m
.85809 .96577 L
s
.49836 .27683 m
.5524 .28476 L
s
.26948 .36532 m
.21808 .39596 L
s
.34693 .33538 m
.26948 .36532 L
s
.86132 1.29772 m
.81758 1.32537 L
s
.37701 1.03617 m .60019 1.1262 L .39906 1.18355 L .544 .324 .532 r
F
.37701 1.03617 m .63876 .95682 L .60019 1.1262 L F
0 g
.37325 .89222 m
.37701 1.03617 L
s
.34693 .33538 m
.29772 .36527 L
s
.49836 .27683 m
.34693 .33538 L
s
.51457 1.38034 m
.57777 1.38677 L
s
.57777 1.38677 m
.6589 1.366 L
s
.6489 .80397 m .72572 .93046 L .63876 .95682 L .544 .324 .532 r
F
.6489 .80397 m .72544 .77947 L .72572 .93046 L F
.55046 .7101 m .72544 .77947 L .6489 .80397 L .656 .751 .92 r
F
0 g
.6337 .66739 m
.64251 .74659 L
s
.28987 .79728 m .55046 .7101 L .6489 .80397 L .656 .751 .92 r
F
.21839 .68922 m .55046 .7101 L .28987 .79728 L F
0 g
.28987 .79728 m
.37325 .89222 L
s
.59787 1.35879 m
.6589 1.366 L
s
.6589 1.366 m
.81758 1.32537 L
s
.55046 .7101 m .63704 .68113 L .72544 .77947 L .656 .751 .92 r
F
0 g
.72544 .77947 m
.79873 .87433 L
s
.71582 .63978 m
.72544 .77947 L
s
.45358 .30522 m
.49836 .27683 L
s
.21808 .39596 m
.29772 .36527 L
s
.21808 .39596 m
.18036 .46336 L
s
.81758 1.32537 m
.76093 1.31661 L
s
.63876 .95682 m .71577 1.09324 L .60019 1.1262 L .544 .324 .532 r
F
.63876 .95682 m .72572 .93046 L .71577 1.09324 L F
0 g
.63876 .95682 m
.6489 .80397 L
s
.72544 .77947 m
.72572 .93046 L
s
.39906 1.18355 m .52768 1.31272 L .44249 1.33539 L .544 .324 .532 r
F
.39906 1.18355 m .60019 1.1262 L .52768 1.31272 L F
0 g
.37701 1.03617 m
.39906 1.18355 L
s
.39906 1.18355 m
.44249 1.33539 L
s
.29772 .36527 m
.45358 .30522 L
s
.29772 .36527 m
.26221 .43234 L
s
.44249 1.33539 m
.51457 1.38034 L
s
.51457 1.38034 m
.59787 1.35879 L
s
.41762 .61943 m .63704 .68113 L .55046 .7101 L .656 .751 .92 r
F
.21839 .68922 m .41762 .61943 L .55046 .7101 L F
0 g
.55046 .7101 m
.6489 .80397 L
s
.16083 .56537 m .41762 .61943 L .21839 .68922 L .656 .751 .92 r
F
0 g
.21839 .68922 m
.28987 .79728 L
s
.59787 1.35879 m
.76093 1.31661 L
s
.41762 .61943 m .53216 .57931 L .63704 .68113 L .656 .751 .92 r
F
0 g
.63704 .68113 m
.72544 .77947 L
s
.42254 .37158 m
.45358 .30522 L
s
.60019 1.1262 m .69458 1.26832 L .52768 1.31272 L .544 .324 .532 r
F
0 g
.52768 1.31272 m
.59787 1.35879 L
s
.60019 1.1262 m .71577 1.09324 L .69458 1.26832 L .544 .324 .532 r
F
0 g
.60019 1.1262 m
.63876 .95682 L
s
.52768 1.31272 m
.60019 1.1262 L
s
.71577 1.09324 m
.72572 .93046 L
s
.18036 .46336 m
.26221 .43234 L
s
.69458 1.26832 m
.76093 1.31661 L
s
.44249 1.33539 m
.52768 1.31272 L
s
.36695 1.25223 m
.44249 1.33539 L
s
.24475 .53452 m .53216 .57931 L .41762 .61943 L .656 .751 .92 r
F
.16083 .56537 m .24475 .53452 L .41762 .61943 L F
0 g
.41762 .61943 m
.55046 .7101 L
s
.16083 .56537 m
.18036 .46336 L
s
.16083 .56537 m
.21839 .68922 L
s
.42254 .37158 m
.26221 .43234 L
s
.69458 1.26832 m
.71577 1.09324 L
s
.52768 1.31272 m
.69458 1.26832 L
s
.45355 1.22814 m
.52768 1.31272 L
s
.24475 .53452 m .40925 .47405 L .53216 .57931 L .656 .751 .92 r
F
0 g
.40925 .47405 m
.53216 .57931 L
s
.24475 .53452 m
.26221 .43234 L
s
.24475 .53452 m
.41762 .61943 L
s
.53216 .57931 m
.63704 .68113 L
s
.16083 .56537 m
.24475 .53452 L
s
.16083 .56537 m
.16275 .6956 L
s
.40925 .47405 m
.42254 .37158 L
s
.29462 1.13561 m
.36695 1.25223 L
s
.36695 1.25223 m
.45355 1.22814 L
s
.24475 .53452 m
.40925 .47405 L
s
.24475 .53452 m
.2484 .66546 L
s
.62336 1.1809 m
.69458 1.26832 L
s
.38203 1.10989 m
.45355 1.22814 L
s
.45355 1.22814 m
.62336 1.1809 L
s
.16275 .6956 m
.2484 .66546 L
s
.16275 .6956 m
.18721 .84338 L
s
.23261 .99496 m
.29462 1.13561 L
s
.29462 1.13561 m
.38203 1.10989 L
s
.40925 .47405 m
.41642 .60634 L
s
.2484 .66546 m
.41642 .60634 L
s
.2484 .66546 m
.27411 .81444 L
s
.18721 .84338 m
.27411 .81444 L
s
.18721 .84338 m
.23261 .99496 L
s
.23261 .99496 m
.32012 .96755 L
s
.32012 .96755 m
.38203 1.10989 L
s
.38203 1.10989 m
.55351 1.05941 L
s
.62336 1.1809 m
.55351 1.05941 L
s
.27411 .81444 m
.44462 .75763 L
s
.27411 .81444 m
.32012 .96755 L
s
.32012 .96755 m
.49184 .91375 L
s
.44462 .75763 m
.41642 .60634 L
s
.55351 1.05941 m
.49184 .91375 L
s
.49184 .91375 m
.44462 .75763 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.439688 0.133279 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.02475 -0.0315924 1.02475 [
[.5 .89818 -40.4688 0 ]
[.5 .89818 40.4688 12.1875 ]
[ 0 0 0 0 ]
[ 1 .88568 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .89818 -101.469 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AnamorphicPrisms) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .88568 L
0 .88568 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.64272 .45218 m
.64464 .50358 L
s
.66923 .43432 m
.64272 .45218 L
s
.57158 .44389 m
.64272 .45218 L
s
.62195 .40893 m
.57158 .44389 L
s
.49981 .43552 m
.57158 .44389 L
s
.67156 .48595 m
.66923 .43432 L
s
.66923 .43432 m
.62195 .40893 L
s
.52374 .40863 m .42742 .42709 L .52356 .3561 L .375 .197 .508 r
F
.52374 .40863 m .42615 .4788 L .42742 .42709 L F
0 g
.48822 .43417 m
.49981 .43552 L
s
.3544 .41858 m
.42742 .42709 L
s
.64464 .50358 m
.64662 .55653 L
s
.67156 .48595 m
.64464 .50358 L
s
.28073 .40999 m
.3544 .41858 L
s
.41973 .30034 m
.28073 .40999 L
s
.20641 .40133 m
.28073 .40999 L
s
.62195 .40893 m
.57341 .38286 L
s
.67396 .53913 m
.67156 .48595 L
s
.20641 .40133 m
.36563 .27129 L
s
.20179 .45335 m
.20641 .40133 L
s
.52391 .46282 m .42615 .4788 L .52374 .40863 L .375 .197 .508 r
F
0 g
.3544 .41858 m
.47236 .3286 L
s
.42742 .42709 m
.52356 .3561 L
s
.52377 .41838 m
.57341 .38286 L
s
.52391 .46282 m .42485 .53208 L .42615 .4788 L .375 .197 .508 r
F
0 g
.42615 .4788 m
.42742 .42709 L
s
.67396 .53913 m
.64662 .55653 L
s
.65458 .3858 m
.65675 .438 L
s
.88803 .28935 m
.65458 .3858 L
s
.65129 .33816 m
.65458 .3858 L
s
.52356 .3561 m
.57341 .38286 L
s
.19702 .50697 m
.20179 .45335 L
s
.5241 .51873 m .42485 .53208 L .52391 .46282 L .375 .197 .508 r
F
.5241 .51873 m .4235 .587 L .42485 .53208 L F
0 g
.42485 .53208 m
.42615 .4788 L
s
.62705 .56956 m .64866 .61107 L .67644 .59394 L .656 .751 .92 r
F
0 g
.67396 .53913 m
.67644 .59394 L
s
.64662 .55653 m
.64748 .57965 L
s
.62705 .56956 m .57428 .60312 L .64866 .61107 L .656 .751 .92 r
F
0 g
.64866 .61107 m
.67644 .59394 L
s
.64866 .61107 m
.65076 .66731 L
s
.47236 .3286 m
.52356 .3561 L
s
.52356 .3561 m
.52374 .40863 L
s
.57629 .5445 m .57428 .60312 L .62705 .56956 L .656 .751 .92 r
F
.57629 .5445 m .49924 .5951 L .57428 .60312 L F
0 g
.57428 .60312 m
.64866 .61107 L
s
.65675 .438 m
.65898 .49181 L
s
.89404 .34259 m
.65675 .438 L
s
.5241 .51873 m .49924 .5951 L .57629 .5445 L .656 .751 .92 r
F
.5241 .51873 m .4235 .587 L .49924 .5951 L F
0 g
.49924 .5951 m
.57428 .60312 L
s
.67644 .59394 m
.67899 .65046 L
s
.62705 .56956 m
.67644 .59394 L
s
.85525 .25181 m
.65129 .33816 L
s
.64784 .28817 m
.65129 .33816 L
s
.47041 .49223 m .4235 .587 L .5241 .51873 L .656 .751 .92 r
F
.47041 .49223 m .34708 .57883 L .4235 .587 L F
.52429 .57646 m .4235 .587 L .5241 .51873 L .375 .197 .508 r
F
.52429 .57646 m .42211 .64364 L .4235 .587 L F
0 g
.4964 .5948 m
.49924 .5951 L
s
.65076 .66731 m
.65292 .72529 L
s
.67899 .65046 m
.65076 .66731 L
s
.47236 .3286 m
.41973 .30034 L
s
.41516 .46495 m .34708 .57883 L .47041 .49223 L .656 .751 .92 r
F
.41516 .46495 m .26995 .57058 L .34708 .57883 L F
0 g
.34708 .57883 m
.4235 .587 L
s
.52374 .40863 m
.52391 .46282 L
s
.35829 .43687 m .26995 .57058 L .41516 .46495 L .656 .751 .92 r
F
.35829 .43687 m .1921 .56226 L .26995 .57058 L F
0 g
.20179 .45335 m
.36326 .3247 L
s
.19702 .50697 m
.36082 .37987 L
s
.26995 .57058 m
.34708 .57883 L
s
.1921 .56226 m
.19702 .50697 L
s
.1921 .56226 m
.26995 .57058 L
s
.57629 .5445 m
.62705 .56956 L
s
.68162 .70877 m
.67899 .65046 L
s
.1921 .56226 m
.35829 .43687 L
s
.18703 .6193 m
.1921 .56226 L
s
.52448 .6361 m .42211 .64364 L .52429 .57646 L .375 .197 .508 r
F
.52448 .6361 m .42068 .70207 L .42211 .64364 L F
0 g
.42211 .64364 m
.4235 .587 L
s
.65292 .72529 m
.65516 .78513 L
s
.68162 .70877 m
.65292 .72529 L
s
.41973 .30034 m
.36563 .27129 L
s
.52391 .46282 m
.5241 .51873 L
s
.90665 .45433 m .66129 .54732 L .65801 .50144 L .656 .751 .92 r
F
0 g
.66129 .54732 m
.66367 .6046 L
s
.65898 .49181 m
.65937 .50118 L
s
.89404 .34259 m
.88803 .28935 L
s
.88803 .28935 m
.85525 .25181 L
s
.5241 .51873 m
.57629 .5445 L
s
.68434 .76895 m
.68162 .70877 L
s
.18703 .6193 m
.35568 .49581 L
s
.18179 .67818 m
.18703 .6193 L
s
.52469 .69773 m .42068 .70207 L .52448 .6361 L .375 .197 .508 r
F
.52469 .69773 m .4192 .76239 L .42068 .70207 L F
0 g
.42068 .70207 m
.42211 .64364 L
s
.4192 .76239 m
.42068 .70207 L
s
.36563 .27129 m
.36326 .3247 L
s
.65516 .78513 m
.68434 .76895 L
s
.65516 .78513 m
.57725 .77762 L
s
.5241 .51873 m
.52429 .57646 L
s
.47041 .49223 m
.5241 .51873 L
s
.57725 .77762 m
.4986 .77004 L
s
.63266 .74589 m
.57725 .77762 L
s
.66367 .6046 m
.66612 .66374 L
s
.66367 .6046 m
.91328 .51302 L
s
.90024 .39755 m
.89404 .34259 L
s
.85525 .25181 m
.82127 .21289 L
s
.4192 .76239 m
.4986 .77004 L
s
.4986 .77004 m
.57946 .72217 L
s
.63266 .74589 m
.68434 .76895 L
s
.18179 .67818 m
.35297 .55678 L
s
.17638 .73898 m
.18179 .67818 L
s
.87257 .41802 m .65801 .50144 L .65456 .45319 L .656 .751 .92 r
F
.90665 .45433 m .65801 .50144 L .87257 .41802 L F
0 g
.65801 .50144 m
.66129 .54732 L
s
.66129 .54732 m
.90665 .45433 L
s
.83046 .42482 m
.90024 .39755 L
s
.33904 .75466 m
.4192 .76239 L
s
.4192 .76239 m
.52469 .69773 L
s
.36326 .3247 m
.36082 .37987 L
s
.78602 .17251 m .64421 .23567 L .64637 .28942 L .499 .287 .522 r
F
0 g
.64039 .18045 m
.64421 .23567 L
s
.64789 .28815 m
.82127 .21289 L
s
.41516 .46495 m
.47041 .49223 L
s
.33904 .75466 m
.2581 .74686 L
s
.33904 .75466 m
.46827 .67257 L
s
.52429 .57646 m
.52448 .6361 L
s
.66612 .66374 m
.66866 .72484 L
s
.92013 .57372 m
.66612 .66374 L
s
.90024 .39755 m
.90665 .45433 L
s
.2581 .74686 m
.17638 .73898 L
s
.41012 .64663 m
.2581 .74686 L
s
.57946 .72217 m
.63266 .74589 L
s
.35018 .61989 m
.17638 .73898 L
s
.35829 .43687 m
.36082 .37987 L
s
.79065 .22681 m .64637 .28942 L .64861 .34496 L .499 .287 .522 r
F
.78602 .17251 m .64637 .28942 L .79065 .22681 L F
0 g
.64421 .23567 m
.64637 .28942 L
s
.64421 .23567 m
.78602 .17251 L
s
.78602 .17251 m
.82127 .21289 L
s
.35829 .43687 m
.41516 .46495 L
s
.52448 .6361 m
.52469 .69773 L
s
.66866 .72484 m
.92722 .63653 L
s
.66866 .72484 m
.66541 .68132 L
s
.90665 .45433 m
.91328 .51302 L
s
.52469 .69773 m
.57946 .72217 L
s
.83718 .38031 m .65456 .45319 L .65092 .40239 L .656 .751 .92 r
F
.87257 .41802 m .65456 .45319 L .83718 .38031 L F
0 g
.65456 .45319 m
.65801 .50144 L
s
.87257 .41802 m
.90665 .45433 L
s
.64039 .18045 m
.74942 .1306 L
s
.63638 .12229 m
.64039 .18045 L
s
.74942 .1306 m
.78602 .17251 L
s
.35568 .49581 m
.35829 .43687 L
s
.79543 .28298 m .64861 .34496 L .65092 .40239 L .499 .287 .522 r
F
.79065 .22681 m .64861 .34496 L .79543 .28298 L F
0 g
.64637 .28942 m
.64861 .34496 L
s
.78602 .17251 m
.79065 .22681 L
s
.46827 .67257 m
.52469 .69773 L
s
.92013 .57372 m
.91328 .51302 L
s
.66541 .68132 m
.66198 .63544 L
s
.89174 .60192 m
.66541 .68132 L
s
.74942 .1306 m
.7114 .08705 L
s
.35568 .49581 m
.35297 .55678 L
s
.79543 .28298 m .65092 .40239 L .80039 .34111 L .499 .287 .522 r
F
0 g
.79065 .22681 m
.79543 .28298 L
s
.83718 .38031 m .65092 .40239 L .80039 .34111 L .656 .751 .92 r
F
0 g
.83718 .38031 m
.87257 .41802 L
s
.80039 .34111 m .65092 .40239 L .65331 .4618 L .499 .287 .522 r
F
.80039 .34111 m .65092 .40239 L .64709 .34882 L .656 .751 .92 r
F
0 g
.64861 .34496 m
.64876 .34873 L
s
.7114 .08705 m
.63638 .12229 L
s
.63214 .06097 m
.63638 .12229 L
s
.41012 .64663 m
.46827 .67257 L
s
.92722 .63653 m
.92013 .57372 L
s
.35297 .55678 m
.35018 .61989 L
s
.80552 .40131 m .65331 .4618 L .65579 .5233 L .499 .287 .522 r
F
.80039 .34111 m .65331 .4618 L .80552 .40131 L F
0 g
.65092 .40239 m
.65331 .4618 L
s
.7114 .08705 m
.67187 .04177 L
s
.35018 .61989 m
.41012 .64663 L
s
.89174 .60192 m
.92722 .63653 L
s
.76212 .30033 m .64709 .34882 L .64304 .29225 L .656 .751 .92 r
F
.80039 .34111 m .64709 .34882 L .76212 .30033 L F
0 g
.64709 .34882 m
.65092 .40239 L
s
.80039 .34111 m
.83718 .38031 L
s
.79543 .28298 m
.80039 .34111 L
s
.67187 .04177 m
.63214 .06097 L
s
.63427 .11609 m
.63214 .06097 L
s
.81083 .4637 m .65579 .5233 L .65835 .587 L .499 .287 .522 r
F
.80552 .40131 m .65579 .5233 L .81083 .4637 L F
0 g
.65331 .4618 m
.65579 .5233 L
s
.80039 .34111 m
.80552 .40131 L
s
.67187 .04177 m
.67474 .09702 L
s
.85481 .5659 m
.89174 .60192 L
s
.67474 .09702 m
.63427 .11609 L
s
.63648 .1732 m
.63427 .11609 L
s
.76212 .30033 m .64304 .29225 L .72228 .25789 L .656 .751 .92 r
F
0 g
.76212 .30033 m
.80039 .34111 L
s
.81083 .4637 m .65835 .587 L .81635 .52839 L .499 .287 .522 r
F
0 g
.65835 .587 m
.81635 .52839 L
s
.65453 .53577 m
.65835 .587 L
s
.80552 .40131 m
.81083 .4637 L
s
.65579 .5233 m
.65835 .587 L
s
.65835 .587 m
.66198 .63544 L
s
.66198 .63544 m
.85481 .5659 L
s
.72228 .25789 m .64304 .29225 L .63876 .23242 L .656 .751 .92 r
F
0 g
.64304 .29225 m
.64709 .34882 L
s
.67474 .09702 m
.6777 .15427 L
s
.81635 .52839 m
.85481 .5659 L
s
.6777 .15427 m
.63648 .1732 L
s
.81083 .4637 m
.81635 .52839 L
s
.72228 .25789 m .63876 .23242 L .68077 .21366 L .656 .751 .92 r
F
0 g
.68077 .21366 m
.72228 .25789 L
s
.63648 .1732 m
.63876 .23242 L
s
.63876 .23242 m
.64304 .29225 L
s
.72228 .25789 m
.76212 .30033 L
s
.6777 .15427 m
.68077 .21366 L
s
.65453 .53577 m
.65047 .48152 L
s
.65453 .53577 m
.77625 .48929 L
s
.63876 .23242 m
.68077 .21366 L
s
.63876 .23242 m
.64114 .29387 L
s
.77625 .48929 m
.81635 .52839 L
s
.68077 .21366 m
.68397 .2753 L
s
.68397 .2753 m
.64114 .29387 L
s
.6436 .35767 m
.64114 .29387 L
s
.73442 .44848 m
.77625 .48929 L
s
.65047 .48152 m
.64617 .42396 L
s
.73442 .44848 m
.65047 .48152 L
s
.68397 .2753 m
.68728 .33933 L
s
.68728 .33933 m
.6436 .35767 L
s
.64617 .42396 m
.6436 .35767 L
s
.69073 .40587 m
.73442 .44848 L
s
.68728 .33933 m
.69073 .40587 L
s
.64617 .42396 m
.69073 .40587 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.439688 0.253695 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.10848 1.28275 2.22045e-16 1.28275 [
[.5 1.22009 -29.6875 0 ]
[.5 1.22009 29.6875 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.20759 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.22009 -90.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AsphericLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.20759 L
0 1.20759 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.48693 .71301 m
.46292 .63355 L
s
.46292 .63355 m
.63525 .5775 L
s
.46292 .63355 m
.43091 .55804 L
s
.40745 .66428 m
.46292 .63355 L
s
.50181 .79277 m
.48693 .71301 L
s
.48693 .71301 m
.66017 .6592 L
s
.42111 .70963 m
.48693 .71301 L
s
.43091 .55804 m
.60345 .49942 L
s
.43091 .55804 m
.39223 .49008 L
s
.38903 .62142 m
.43091 .55804 L
s
.45245 .81774 m .68487 .81853 L .5066 .86908 L .656 .751 .92 r
F
0 g
.50181 .79277 m
.50339 .81791 L
s
.37484 .77552 m .5066 .86908 L .43129 .79767 L .656 .751 .92 r
F
.37484 .77552 m .45245 .81774 L .5066 .86908 L F
0 g
.50181 .79277 m
.67704 .74081 L
s
.5006 .93793 m
.5066 .86908 L
s
.66017 .6592 m
.63525 .5775 L
s
.63525 .5775 m
.57979 .61077 L
s
.63525 .5775 m
.60345 .49942 L
s
.67704 .74081 m
.66017 .6592 L
s
.66017 .6592 m
.59224 .65171 L
s
.60345 .49942 m
.56372 .57188 L
s
.60345 .49942 m
.56609 .42861 L
s
.34852 .43334 m .52453 .45582 L .34383 .51933 L .544 .324 .532 r
F
0 g
.36682 .58346 m
.38855 .50361 L
s
.34852 .43334 m .52474 .36885 L .52453 .45582 L .544 .324 .532 r
F
0 g
.52456 .4433 m
.56609 .42861 L
s
.30178 .39149 m
.34852 .43334 L
s
.48339 .99508 m
.5006 .93793 L
s
.5006 .93793 m
.68281 .88831 L
s
.42699 .83526 m
.5006 .93793 L
s
.42111 .70963 m
.40745 .66428 L
s
.40745 .66428 m
.57979 .61077 L
s
.40745 .66428 m
.38903 .62142 L
s
.45245 .81774 m .63461 .76404 L .68487 .81853 L .656 .751 .92 r
F
0 g
.68281 .88831 m
.68487 .81853 L
s
.67704 .74081 m
.68487 .81853 L
s
.5066 .86908 m
.68487 .81853 L
s
.39492 .7632 m .63461 .76404 L .45245 .81774 L .656 .751 .92 r
F
.32627 .7499 m .45245 .81774 L .37484 .77552 L F
.32627 .7499 m .39492 .7632 L .45245 .81774 L F
0 g
.42111 .70963 m
.42924 .75495 L
s
.42924 .75495 m
.44541 .76337 L
s
.45245 .81774 m
.5066 .86908 L
s
.43129 .79767 m
.5066 .86908 L
s
.38903 .62142 m
.36682 .58346 L
s
.42924 .75495 m
.42964 .76332 L
s
.31442 .61049 m .34383 .51933 L .3389 .60981 L .544 .324 .532 r
F
.34201 .55271 m .34383 .51933 L .31442 .61049 L F
.34383 .51933 m .5243 .54747 L .3389 .60981 L F
.34383 .51933 m .52453 .45582 L .5243 .54747 L F
0 g
.34383 .51933 m
.34852 .43334 L
s
.34201 .55271 m
.34852 .43334 L
s
.30178 .39149 m
.48133 .32395 L
s
.30178 .39149 m
.25447 .36815 L
s
.30178 .39149 m
.316 .53126 L
s
.42699 .83526 m
.43129 .79767 L
s
.37484 .77552 m
.43129 .79767 L
s
.52474 .36885 m .54022 .54763 L .52453 .45582 L .544 .324 .532 r
F
.52474 .36885 m .5244 .50907 L .54022 .54763 L F
0 g
.34852 .43334 m
.52474 .36885 L
s
.52474 .36885 m
.56609 .42861 L
s
.48133 .32395 m
.52474 .36885 L
s
.316 .53126 m
.34201 .55271 L
s
.45505 1.03614 m
.48339 .99508 L
s
.48339 .99508 m
.67029 .94582 L
s
.41635 .86524 m
.48339 .99508 L
s
.67029 .94582 m
.68281 .88831 L
s
.41635 .86524 m
.42699 .83526 L
s
.31442 .61049 m .3389 .60981 L .29557 .66636 L .544 .324 .532 r
F
0 g
.31442 .61049 m
.34201 .55271 L
s
.63461 .76404 m .59388 .69763 L .60359 .73041 L .656 .751 .92 r
F
.58111 .70605 m .59388 .69763 L .63461 .76404 L F
.39492 .7632 m .58111 .70605 L .63461 .76404 L F
0 g
.42699 .83526 m
.60166 .76353 L
s
.60166 .76353 m
.68281 .88831 L
s
.63461 .76404 m
.68487 .81853 L
s
.60359 .73041 m
.68487 .81853 L
s
.60035 .69237 m
.67704 .74081 L
s
.3337 .70515 m .58111 .70605 L .39492 .7632 L .656 .751 .92 r
F
0 g
.56314 .70598 m
.60035 .69237 L
s
.43129 .79767 m
.60359 .73041 L
s
.28687 .72014 m .39492 .7632 L .32627 .7499 L .656 .751 .92 r
F
.28687 .72014 m .3337 .70515 L .39492 .7632 L F
0 g
.39492 .7632 m
.45245 .81774 L
s
.32627 .7499 m
.37484 .77552 L
s
.316 .53126 m
.50338 .48918 L
s
.29036 .52084 m
.316 .53126 L
s
.57979 .61077 m
.59224 .65171 L
s
.56372 .57188 m
.57979 .61077 L
s
.3389 .60981 m .52407 .6442 L .3337 .70515 L .544 .324 .532 r
F
0 g
.43329 .70551 m
.59224 .65171 L
s
.3389 .60981 m .5243 .54747 L .52407 .6442 L .544 .324 .532 r
F
0 g
.52422 .58308 m
.56372 .57188 L
s
.29557 .66636 m .3389 .60981 L .3337 .70515 L .544 .324 .532 r
F
0 g
.3389 .60981 m
.34383 .51933 L
s
.59224 .65171 m
.60035 .69237 L
s
.39977 .88536 m
.41635 .86524 L
s
.60035 .69237 m
.60191 .71072 L
s
.52453 .45582 m .55126 .58912 L .5243 .54747 L .544 .324 .532 r
F
0 g
.34201 .55271 m
.5244 .50907 L
s
.52453 .45582 m .54022 .54763 L .55126 .58912 L .544 .324 .532 r
F
0 g
.54491 .53727 m
.56609 .42861 L
s
.54106 .53827 m
.54491 .53727 L
s
.5244 .50907 m
.52474 .36885 L
s
.52453 .45582 m
.52474 .36885 L
s
.54491 .53727 m
.56372 .57188 L
s
.29557 .66636 m .3337 .70515 L .28687 .72014 L .544 .324 .532 r
F
0 g
.29557 .66636 m
.31442 .61049 L
s
.25447 .36815 m
.43819 .29773 L
s
.25447 .36815 m
.20955 .36653 L
s
.29036 .52084 m
.25447 .36815 L
s
.48133 .32395 m
.50338 .48918 L
s
.48133 .32395 m
.43819 .29773 L
s
.53932 .52959 m
.54491 .53727 L
s
.60166 .76353 m
.60359 .73041 L
s
.64714 .98661 m
.67029 .94582 L
s
.67029 .94582 m
.59451 .78951 L
s
.29036 .52084 m
.48316 .47918 L
s
.29036 .52084 m
.2668 .52269 L
s
.41639 1.05687 m
.45505 1.03614 L
s
.45505 1.03614 m
.64714 .98661 L
s
.39977 .88536 m
.45505 1.03614 L
s
.28687 .72014 m .32821 .80573 L .28863 .77206 L .544 .324 .532 r
F
.28687 .72014 m .3337 .70515 L .32821 .80573 L F
.25683 .68589 m .3337 .70515 L .28687 .72014 L .656 .751 .92 r
F
0 g
.29102 .69446 m
.29557 .66636 L
s
.50338 .48918 m
.5244 .50907 L
s
.37804 .89378 m
.39977 .88536 L
s
.39977 .88536 m
.58237 .80641 L
s
.59451 .78951 m
.60166 .76353 L
s
.58111 .70605 m .57852 .66531 L .59388 .69763 L .656 .751 .92 r
F
0 g
.59388 .69763 m
.60359 .73041 L
s
.52407 .6442 m .57852 .66531 L .58111 .70605 L .656 .751 .92 r
F
.3337 .70515 m .52407 .6442 L .58111 .70605 L F
0 g
.58111 .70605 m
.63461 .76404 L
s
.3337 .70515 m .52382 .74643 L .32821 .80573 L .544 .324 .532 r
F
0 g
.41635 .86524 m
.59451 .78951 L
s
.3337 .70515 m .52407 .6442 L .52382 .74643 L .544 .324 .532 r
F
.2684 .64324 m .52407 .6442 L .3337 .70515 L .656 .751 .92 r
F
0 g
.33706 .6435 m
.3389 .60981 L
s
.25683 .68589 m .2684 .64324 L .3337 .70515 L .656 .751 .92 r
F
0 g
.77246 .59488 m
.75954 .55276 L
s
.75954 .55276 m
.84241 .52602 L
s
.75954 .55276 m
.7436 .51251 L
s
.78165 .63649 m
.77246 .59488 L
s
.77246 .59488 m
.85556 .56868 L
s
.5243 .54747 m .55568 .63408 L .52407 .6442 L .544 .324 .532 r
F
.5243 .54747 m .55126 .58912 L .55568 .63408 L F
0 g
.5243 .54747 m
.52453 .45582 L
s
.5244 .50907 m
.54022 .54763 L
s
.7436 .51251 m
.82655 .48514 L
s
.7436 .51251 m
.72553 .47644 L
s
.2668 .52269 m
.24706 .53735 L
s
.46511 .48018 m
.2668 .52269 L
s
.20955 .36653 m
.2668 .52269 L
s
.48316 .47918 m
.50338 .48918 L
s
.28863 .77206 m .32241 .91202 L .30141 .82231 L .544 .324 .532 r
F
.28863 .77206 m .32821 .80573 L .32241 .91202 L F
0 g
.28687 .72014 m
.28863 .77206 L
s
.78165 .63649 m
.86526 .61072 L
s
.54022 .54763 m
.55126 .58912 L
s
.23657 .64669 m .2684 .64324 L .25683 .68589 L .656 .751 .92 r
F
0 g
.25683 .68589 m
.28687 .72014 L
s
.43819 .29773 m
.48316 .47918 L
s
.43819 .29773 m
.39807 .29365 L
s
.59451 .78951 m
.58237 .80641 L
s
.20955 .36653 m
.17043 .38893 L
s
.39807 .29365 m
.20955 .36653 L
s
.37804 .89378 m
.41639 1.05687 L
s
.84241 .52602 m
.85556 .56868 L
s
.82655 .48514 m
.84241 .52602 L
s
.76288 .64563 m .8709 .64974 L .78651 .67521 L .656 .751 .92 r
F
0 g
.78651 .67521 m
.78666 .70868 L
s
.78165 .63649 m
.78289 .64639 L
s
.85556 .56868 m
.86526 .61072 L
s
.80885 .44838 m
.82655 .48514 L
s
.61383 1.00632 m
.64714 .98661 L
s
.64714 .98661 m
.58237 .80641 L
s
.52407 .6442 m .55568 .63408 L .57852 .66531 L .656 .751 .92 r
F
0 g
.57852 .66531 m
.59388 .69763 L
s
.36916 1.0537 m
.41639 1.05687 L
s
.41639 1.05687 m
.61383 1.00632 L
s
.46511 .48018 m
.48316 .47918 L
s
.70634 .44673 m .79372 .46262 L .70861 .49116 L .544 .324 .532 r
F
.70634 .44673 m .7903 .41797 L .79372 .46262 L F
0 g
.79304 .45371 m
.80885 .44838 L
s
.70634 .44673 m
.7903 .41797 L
s
.68714 .42539 m
.70634 .44673 L
s
.24706 .53735 m
.23279 .56441 L
s
.24706 .53735 m
.17043 .38893 L
s
.30141 .82231 m .31627 1.0245 L .32462 .87146 L .544 .324 .532 r
F
.30141 .82231 m .32241 .91202 L .31627 1.0245 L F
0 g
.28863 .77206 m
.30141 .82231 L
s
.7903 .41797 m
.80885 .44838 L
s
.58237 .80641 m
.56583 .81268 L
s
.32821 .80573 m .52355 .85466 L .32241 .91202 L .544 .324 .532 r
F
0 g
.30141 .82231 m
.32462 .87146 L
s
.32821 .80573 m .52382 .74643 L .52355 .85466 L .544 .324 .532 r
F
0 g
.32821 .80573 m
.3337 .70515 L
s
.52361 .83092 m
.56583 .81268 L
s
.78192 .73468 m
.78666 .70868 L
s
.78666 .70868 m
.87205 .68337 L
s
.52364 .81677 m
.54584 .80737 L
s
.35383 .90306 m
.36916 1.0537 L
s
.76288 .64563 m .84828 .61935 L .8709 .64974 L .656 .751 .92 r
F
0 g
.8709 .64974 m
.87205 .68337 L
s
.86526 .61072 m
.8709 .64974 L
s
.78651 .67521 m
.8709 .64974 L
s
.23657 .64669 m .19861 .57707 L .2684 .64324 L .656 .751 .92 r
F
.22533 .60241 m .19861 .57707 L .23657 .64669 L F
0 g
.23657 .64669 m
.25683 .68589 L
s
.7385 .61511 m .84828 .61935 L .76288 .64563 L .656 .751 .92 r
F
0 g
.76288 .64563 m
.78651 .67521 L
s
.52407 .6442 m .55174 .68294 L .52382 .74643 L .544 .324 .532 r
F
.52407 .6442 m .55568 .63408 L .55174 .68294 L F
0 g
.55239 .67491 m
.58111 .70605 L
s
.4631 .5781 m .55568 .63408 L .52407 .6442 L .656 .751 .92 r
F
0 g
.52414 .615 m
.5243 .54747 L
s
.2684 .64324 m .4631 .5781 L .52407 .6442 L .656 .751 .92 r
F
.19861 .57707 m .4631 .5781 L .2684 .64324 L F
0 g
.2684 .64324 m
.3337 .70515 L
s
.22533 .60241 m
.23657 .64669 L
s
.70861 .49116 m .79723 .50848 L .71094 .53677 L .544 .324 .532 r
F
.70861 .49116 m .79372 .46262 L .79723 .50848 L F
0 g
.70634 .44673 m
.70861 .49116 L
s
.68714 .42539 m
.77199 .39593 L
s
.68714 .42539 m
.66915 .41409 L
s
.7903 .41797 m
.79372 .46262 L
s
.77199 .39593 m
.7903 .41797 L
s
.4631 .5781 m .52361 .60457 L .55568 .63408 L .656 .751 .92 r
F
0 g
.55126 .58912 m
.55568 .63408 L
s
.55568 .63408 m
.57852 .66531 L
s
.46511 .48018 m
.39807 .29365 L
s
.45059 .49263 m
.46511 .48018 L
s
.23028 .57719 m
.23279 .56441 L
s
.87205 .68337 m
.86848 .70936 L
s
.77239 .75124 m
.78192 .73468 L
s
.78192 .73468 m
.86848 .70936 L
s
.56583 .81268 m
.54584 .80737 L
s
.61383 1.00632 m
.56583 .81268 L
s
.39807 .29365 m
.36413 .31429 L
s
.17043 .38893 m
.36413 .31429 L
s
.17043 .38893 m
.14073 .43603 L
s
.7385 .61511 m .82494 .58798 L .84828 .61935 L .656 .751 .92 r
F
0 g
.84828 .61935 m
.8709 .64974 L
s
.71334 .5836 m .82494 .58798 L .7385 .61511 L .656 .751 .92 r
F
0 g
.7385 .61511 m
.76288 .64563 L
s
.71094 .53677 m .80083 .55559 L .71334 .5836 L .544 .324 .532 r
F
.71094 .53677 m .79723 .50848 L .80083 .55559 L F
0 g
.70861 .49116 m
.71094 .53677 L
s
.52382 .74643 m .55174 .68294 L .54062 .73521 L .544 .324 .532 r
F
0 g
.55174 .68294 m
.55568 .63408 L
s
.79372 .46262 m
.79723 .50848 L
s
.75508 .38401 m
.77199 .39593 L
s
.66915 .41409 m
.75508 .38401 L
s
.66915 .41409 m
.6536 .41404 L
s
.39779 .5073 m .52361 .60457 L .4631 .5781 L .656 .751 .92 r
F
.39779 .5073 m .48349 .5765 L .52361 .60457 L F
0 g
.24706 .53735 m
.45059 .49263 L
s
.52361 .60457 m
.55568 .63408 L
s
.23279 .56441 m
.41211 .52282 L
s
.22533 .60241 m
.22557 .64879 L
s
.57172 1.00131 m
.61383 1.00632 L
s
.32241 .91202 m .52327 .96943 L .31627 1.0245 L .544 .324 .532 r
F
0 g
.36916 1.0537 m
.57172 1.00131 L
s
.31627 1.0245 m
.36916 1.0537 L
s
.32241 .91202 m .52355 .85466 L .52327 .96943 L .544 .324 .532 r
F
0 g
.32241 .91202 m
.32821 .80573 L
s
.31627 1.0245 m
.32462 .87146 L
s
.29667 .84116 m
.32462 .87146 L
s
.31627 1.0245 m
.32241 .91202 L
s
.86848 .70936 m
.86021 .72574 L
s
.27082 .8003 m
.29667 .84116 L
s
.29667 .84116 m
.50104 .76236 L
s
.29667 .84116 m
.26177 .96942 L
s
.75848 .75679 m
.77239 .75124 L
s
.77239 .75124 m
.86021 .72574 L
s
.57172 1.00131 m
.54584 .80737 L
s
.52382 .74643 m .54062 .73521 L .52355 .85466 L .544 .324 .532 r
F
0 g
.52382 .74643 m
.52407 .6442 L
s
.71334 .5836 m .80083 .55559 L .82494 .58798 L .656 .751 .92 r
F
0 g
.82494 .58798 m
.84828 .61935 L
s
.52355 .85466 m .54062 .73521 L .52371 .79032 L .544 .324 .532 r
F
0 g
.52371 .79032 m
.54062 .73521 L
s
.52355 .85466 m
.52382 .74643 L
s
.54062 .73521 m
.55174 .68294 L
s
.32462 .87146 m
.52371 .79032 L
s
.53185 .79659 m
.54584 .80737 L
s
.71334 .5836 m .80453 .604 L .71579 .63171 L .544 .324 .532 r
F
.71334 .5836 m .80083 .55559 L .80453 .604 L F
.68734 .55106 m .80083 .55559 L .71334 .5836 L .656 .751 .92 r
F
0 g
.71094 .53677 m
.71172 .55204 L
s
.22557 .64879 m
.43883 .59037 L
s
.22557 .64879 m
.23371 .70002 L
s
.12231 .59496 m
.22557 .64879 L
s
.19861 .57707 m .39779 .5073 L .4631 .5781 L .656 .751 .92 r
F
0 g
.4631 .5781 m
.52407 .6442 L
s
.24922 .75195 m
.27082 .8003 L
s
.27082 .8003 m
.47959 .72532 L
s
.27082 .8003 m
.2105 .89158 L
s
.74076 .38346 m
.75508 .38401 L
s
.12385 .50619 m .39779 .5073 L .19861 .57707 L .656 .751 .92 r
F
0 g
.19861 .57707 m
.2684 .64324 L
s
.14073 .43603 m
.19124 .50647 L
s
.32766 .43127 m .48349 .5765 L .39779 .5073 L .656 .751 .92 r
F
.32766 .43127 m .43671 .54949 L .48349 .5765 L F
0 g
.48349 .5765 m
.52361 .60457 L
s
.36413 .31429 m
.45059 .49263 L
s
.44081 .51616 m
.45059 .49263 L
s
.42314 .52026 m
.44081 .51616 L
s
.22533 .60241 m
.43671 .54949 L
s
.43671 .54949 m
.48349 .5765 L
s
.43854 .53461 m
.44081 .51616 L
s
.6536 .41404 m
.6417 .4258 L
s
.74076 .38346 m
.6536 .41404 L
s
.23371 .70002 m
.44716 .63572 L
s
.23371 .70002 m
.24922 .75195 L
s
.23371 .70002 m
.13716 .69506 L
s
.24922 .75195 m
.46112 .68196 L
s
.24922 .75195 m
.16751 .79722 L
s
.86021 .72574 m
.84758 .73095 L
s
.52327 .96943 m
.52371 .79032 L
s
.50104 .76236 m
.52371 .79032 L
s
.74095 .75041 m
.75848 .75679 L
s
.75848 .75679 m
.84758 .73095 L
s
.71579 .63171 m .80834 .65377 L .71832 .68115 L .544 .324 .532 r
F
.71579 .63171 m .80453 .604 L .80834 .65377 L F
0 g
.71334 .5836 m
.71579 .63171 L
s
.68734 .55106 m .77592 .52212 L .80083 .55559 L .656 .751 .92 r
F
0 g
.80083 .55559 m
.80453 .604 L
s
.79723 .50848 m
.80083 .55559 L
s
.80083 .55559 m
.82494 .58798 L
s
.36413 .31429 m
.33967 .36063 L
s
.66049 .51744 m .77592 .52212 L .68734 .55106 L .656 .751 .92 r
F
0 g
.68734 .55106 m
.71334 .5836 L
s
.43671 .54949 m
.43883 .59037 L
s
.73013 .39488 m
.74076 .38346 L
s
.47959 .72532 m
.50104 .76236 L
s
.47208 .91092 m
.50104 .76236 L
s
.31627 1.0245 m
.52327 .96943 L
s
.26177 .96942 m
.31627 1.0245 L
s
.6417 .4258 m
.73013 .39488 L
s
.6417 .4258 m
.63448 .4491 L
s
.52327 .96943 m
.57172 1.00131 L
s
.84758 .73095 m
.83126 .72404 L
s
.52327 .96943 m
.52355 .85466 L
s
.33025 .52179 m
.43883 .59037 L
s
.43883 .59037 m
.44716 .63572 L
s
.71832 .68115 m .81226 .70496 L .72092 .73198 L .544 .324 .532 r
F
0 g
.74095 .75041 m
.83126 .72404 L
s
.72092 .73198 m
.74095 .75041 L
s
.71832 .68115 m .80834 .65377 L .81226 .70496 L .544 .324 .532 r
F
0 g
.71579 .63171 m
.71832 .68115 L
s
.71832 .68115 m
.72092 .73198 L
s
.80453 .604 m
.80834 .65377 L
s
.47959 .72532 m
.46112 .68196 L
s
.42267 .82913 m
.47959 .72532 L
s
.66049 .51744 m .75017 .48752 L .77592 .52212 L .656 .751 .92 r
F
0 g
.77592 .52212 m
.80083 .55559 L
s
.34806 .6248 m
.44716 .63572 L
s
.46112 .68196 m
.44716 .63572 L
s
.37988 .73069 m
.46112 .68196 L
s
.63272 .48268 m .75017 .48752 L .66049 .51744 L .656 .751 .92 r
F
0 g
.66049 .51744 m
.68734 .55106 L
s
.72417 .41804 m
.73013 .39488 L
s
.72417 .41804 m
.63448 .4491 L
s
.12385 .50619 m .32766 .43127 L .39779 .5073 L .656 .751 .92 r
F
0 g
.32766 .43127 m
.39779 .5073 L
s
.32766 .43127 m
.43671 .54949 L
s
.14073 .43603 m
.33967 .36063 L
s
.12385 .50619 m
.14073 .43603 L
s
.33967 .36063 m
.44081 .51616 L
s
.39779 .5073 m
.4631 .5781 L
s
.12385 .50619 m
.22533 .60241 L
s
.12385 .50619 m
.19861 .57707 L
s
.12385 .50619 m
.32766 .43127 L
s
.12231 .59496 m
.12385 .50619 L
s
.72092 .73198 m
.81226 .70496 L
s
.69981 .7024 m
.72092 .73198 L
s
.81226 .70496 m
.83126 .72404 L
s
.80834 .65377 m
.81226 .70496 L
s
.2105 .89158 m
.26177 .96942 L
s
.26177 .96942 m
.47208 .91092 L
s
.32766 .43127 m
.33967 .36063 L
s
.63272 .48268 m .72353 .45172 L .75017 .48752 L .656 .751 .92 r
F
0 g
.72353 .45172 m
.75017 .48752 L
s
.63272 .48268 m
.63448 .4491 L
s
.75017 .48752 m
.77592 .52212 L
s
.63272 .48268 m
.66049 .51744 L
s
.63272 .48268 m
.72353 .45172 L
s
.63272 .48268 m
.63673 .5243 L
s
.72353 .45172 m
.72417 .41804 L
s
.67927 .66363 m
.69981 .7024 L
s
.69981 .7024 m
.79193 .67462 L
s
.47208 .91092 m
.52327 .96943 L
s
.79193 .67462 m
.81226 .70496 L
s
.12231 .59496 m
.33025 .52179 L
s
.12231 .59496 m
.13716 .69506 L
s
.63673 .5243 m
.72847 .49367 L
s
.63673 .5243 m
.64638 .57083 L
s
.66095 .61857 m
.67927 .66363 L
s
.67927 .66363 m
.77183 .63503 L
s
.16751 .79722 m
.2105 .89158 L
s
.2105 .89158 m
.42267 .82913 L
s
.64638 .57083 m
.73874 .54075 L
s
.64638 .57083 m
.66095 .61857 L
s
.72353 .45172 m
.72847 .49367 L
s
.66095 .61857 m
.7536 .58918 L
s
.79193 .67462 m
.77183 .63503 L
s
.13716 .69506 m
.34806 .6248 L
s
.13716 .69506 m
.16751 .79722 L
s
.16751 .79722 m
.37988 .73069 L
s
.73874 .54075 m
.72847 .49367 L
s
.32766 .43127 m
.33025 .52179 L
s
.77183 .63503 m
.7536 .58918 L
s
.7536 .58918 m
.73874 .54075 L
s
.42267 .82913 m
.47208 .91092 L
s
.33025 .52179 m
.34806 .6248 L
s
.37988 .73069 m
.42267 .82913 L
s
.34806 .6248 m
.37988 .73069 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.439688 0.374111 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567238 1.16608 0 1.16608 [
[.5 1.098 -19.9688 0 ]
[.5 1.098 19.9688 12 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -80.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BallLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.64395 .59288 m .64503 .59611 L .64399 .59274 L .67 .55 .71 r
F
.64268 .59504 m .64503 .59611 L .62147 .52538 L F
.64309 .59638 m .64564 .599 L .64503 .59611 L .662 .503 .659 r
F
.64058 .5938 m .64159 .59717 L .64309 .59638 L .579 .496 .725 r
F
.52195 .54022 m .52097 .61381 L .64309 .59638 L .67 .55 .71 r
F
.64268 .59504 m .64309 .59638 L .64503 .59611 L F
.64058 .5938 m .64309 .59638 L .64208 .59307 L .579 .496 .725 r
F
.52195 .54022 m .64309 .59638 L .64268 .59504 L .67 .55 .71 r
F
.62147 .52538 m .64395 .59288 L .62305 .52515 L F
.64395 .59288 m .64399 .59274 L .62305 .52515 L F
.64208 .59307 m .64309 .59638 L .74157 .54442 L .579 .496 .725 r
F
.64309 .59638 m .76954 .61111 L .74157 .54442 L .548 .428 .669 r
F
.64159 .59717 m .64286 .59731 L .64309 .59638 L F
.64286 .59731 m .64329 .59736 L .64309 .59638 L F
.64368 .59924 m .64564 .599 L .64309 .59638 L .662 .503 .659 r
F
.66442 .73378 m .66277 .73565 L .66455 .73479 L .509 .347 .597 r
F
.66269 .73374 m .66433 .73382 L .66445 .73377 L .454 .241 .5 r
F
.66269 .73374 m .66445 .73377 L .66447 .73288 L F
.66391 .73295 m .66445 .73377 L .66447 .73288 L .629 .382 .524 r
F
.65605 .66816 m .66441 .73372 L .65785 .6683 L .509 .347 .597 r
F
.66442 .73378 m .66455 .73479 L .66445 .73377 L F
.6646 .73375 m .66445 .73377 L .66685 .73449 L .649 .449 .6 r
F
.66445 .73377 m .66399 .73487 L .66685 .73449 L F
.6581 .6708 m .66618 .72963 L .66029 .67055 L F
.66447 .73288 m .6649 .73371 L .66677 .73258 L .629 .382 .524 r
F
.6649 .73371 m .66674 .73347 L .66677 .73258 L F
.66618 .72963 m .66685 .73449 L .66632 .72931 L .649 .449 .6 r
F
.66618 .72963 m .66632 .72931 L .66029 .67055 L F
.66444 .7337 m .66447 .73371 L .6581 .6708 L F
.6646 .73375 m .66685 .73449 L .66671 .73347 L F
.66269 .73374 m .66267 .73462 L .66433 .73382 L .454 .241 .5 r
F
.66225 .73046 m .66277 .73565 L .66441 .73372 L .509 .347 .597 r
F
.52 .75263 m .52 .75366 L .52053 .75358 L .649 .449 .6 r
F
.66433 .73382 m .66442 .73383 L .66445 .73377 L .454 .241 .5 r
F
.66433 .73382 m .66432 .73407 L .66442 .73383 L F
.66432 .73383 m .66277 .73565 L .66442 .73378 L .509 .347 .597 r
F
.66267 .73462 m .66128 .79114 L .66433 .73382 L .454 .241 .5 r
F
.66128 .79114 m .6612 .79445 L .66136 .79126 L F
.66128 .79114 m .66136 .79126 L .66433 .73382 L F
.6317 .87886 m .63118 .87981 L .63253 .87921 L .174 0 .026 r
F
.65147 .84533 m .63476 .87809 L .65353 .8451 L .504 .092 .192 r
F
.63476 .87809 m .6343 .879 L .63483 .87806 L F
.63476 .87809 m .63483 .87806 L .65353 .8451 L F
.63163 .87975 m .60546 .89594 L .63336 .87955 L .247 0 0 r
F
.60546 .89594 m .60514 .89614 L .60549 .89594 L F
.60546 .89594 m .60549 .89594 L .63336 .87955 L F
.60419 .8961 m .60514 .89614 L .63163 .87975 L F
.63253 .87921 m .63336 .87955 L .6343 .879 L F
.63163 .87966 m .60322 .89652 L .60386 .89629 L 0 0 0 r
F
.63163 .87975 m .63336 .87955 L .63253 .87921 L .247 0 0 r
F
.63279 .87875 m .6343 .879 L .65147 .84533 L .504 .092 .192 r
F
.65074 .84445 m .6317 .87886 L .63253 .87921 L .174 0 .026 r
F
.65074 .84445 m .63253 .87921 L .652 .84437 L F
.52055 .8597 m .52145 .89236 L .6343 .879 L .504 .092 .192 r
F
.63163 .87966 m .60386 .89629 L .63193 .87957 L 0 0 0 r
F
.63027 .88035 m .60288 .89672 L .63163 .87966 L F
.52145 .89236 m .52275 .9058 L .60386 .89629 L .247 0 0 r
F
.60466 .89612 m .60386 .89629 L .60514 .89614 L F
.52145 .89236 m .60386 .89629 L .60466 .89612 L F
.63118 .87981 m .63027 .88035 L .63163 .87966 L 0 0 0 r
F
.63118 .87981 m .63193 .87957 L .63253 .87921 L F
.52145 .89236 m .63163 .87975 L .63253 .87921 L .247 0 0 r
F
.52145 .89236 m .60419 .8961 L .63163 .87975 L F
.60282 .89616 m .56753 .89176 L .60076 .877 L .542 .913 .949 r
F
.60418 .8961 m .60386 .89629 L .60434 .89608 L 0 0 0 r
F
.60418 .8961 m .60434 .89608 L .66776 .86834 L F
.63193 .87957 m .60418 .8961 L .66776 .86834 L F
.63253 .87921 m .66776 .86834 L .72156 .84015 L F
.63193 .87957 m .66776 .86834 L .63253 .87921 L F
.65237 .84372 m .65353 .8451 L .65446 .84347 L .504 .092 .192 r
F
.65119 .84233 m .65074 .84445 L .65237 .84372 L .361 .075 .336 r
F
.65074 .84445 m .652 .84437 L .65237 .84372 L .174 0 .026 r
F
.52055 .8597 m .65147 .84533 L .65237 .84372 L .504 .092 .192 r
F
.65147 .84533 m .65353 .8451 L .65237 .84372 L F
.66238 .79636 m .65446 .84347 L .66463 .79612 L .591 .278 .407 r
F
.65252 .84301 m .65446 .84347 L .66238 .79636 L F
.6612 .79445 m .65119 .84233 L .65237 .84372 L .361 .075 .336 r
F
.6612 .79445 m .65237 .84372 L .66278 .79447 L F
.52007 .81156 m .52055 .8597 L .65446 .84347 L .591 .278 .407 r
F
.65237 .84372 m .72156 .84015 L .75925 .79591 L .174 0 .026 r
F
.652 .84437 m .72156 .84015 L .65237 .84372 L F
.652 .84437 m .63253 .87921 L .72156 .84015 L F
.52055 .8597 m .63279 .87875 L .65147 .84533 L .504 .092 .192 r
F
.60386 .89629 m .60076 .877 L .66776 .86834 L .542 .913 .949 r
F
.52275 .9058 m .56783 .8918 L .60324 .89621 L .292 .782 .894 r
F
.52275 .9058 m .60324 .89621 L .60386 .89629 L F
.60286 .89651 m .60282 .89616 L .60386 .89629 L .542 .913 .949 r
F
.60282 .89616 m .60076 .877 L .60386 .89629 L F
.60324 .89621 m .6045 .89606 L .60386 .89629 L .292 .782 .894 r
F
.60324 .89621 m .5682 .89168 L .6045 .89606 L F
.56783 .8918 m .5682 .89168 L .60324 .89621 L F
.52275 .9058 m .52441 .89685 L .56753 .89176 L F
.56813 .8917 m .56753 .89176 L .5682 .89168 L F
.52275 .9058 m .56753 .89176 L .56813 .8917 L F
.38779 .84054 m .52145 .89236 L .52055 .8597 L .675 .229 .186 r
F
.38779 .84054 m .40963 .8766 L .52145 .89236 L F
.40963 .8766 m .52275 .9058 L .52145 .89236 L .439 0 0 r
F
.37612 .79006 m .38779 .84054 L .52055 .8597 L .736 .395 .405 r
F
.52607 .86432 m .52631 .86418 L .52441 .89685 L .547 .793 .99 r
F
.52797 .86528 m .52631 .86418 L .60076 .877 L .624 .836 .981 r
F
.60076 .877 m .52631 .86418 L .52809 .86484 L .663 .832 .964 r
F
.52007 .81156 m .65252 .84301 L .66238 .79636 L .591 .278 .407 r
F
.66442 .73383 m .6612 .79445 L .66296 .79363 L .454 .241 .5 r
F
.66432 .73407 m .6612 .79445 L .66442 .73383 L F
.6612 .79445 m .66278 .79447 L .66296 .79363 L .361 .075 .336 r
F
.52007 .81156 m .66238 .79636 L .66296 .79363 L .591 .278 .407 r
F
.66238 .79636 m .66463 .79612 L .66296 .79363 L F
.66296 .79363 m .66463 .79612 L .66523 .79335 L F
.55021 .7495 m .52 .75366 L .55063 .74966 L .649 .449 .6 r
F
.55021 .7495 m .55063 .74966 L .66399 .73487 L F
.66433 .73382 m .66445 .73377 L .66445 .73377 L .454 .241 .5 r
F
.66445 .73377 m .55021 .7495 L .66399 .73487 L .649 .449 .6 r
F
.52 .75263 m .52053 .75358 L .66445 .73377 L F
.52 .75263 m .66445 .73377 L .66445 .73377 L F
.66442 .73383 m .66296 .79363 L .66445 .73383 L .454 .241 .5 r
F
.54862 .74889 m .66523 .79335 L .66665 .73708 L .629 .382 .524 r
F
.5221 .75236 m .66523 .79335 L .54862 .74889 L F
.52043 .75188 m .52007 .81156 L .66523 .79335 L F
.52 .75176 m .52 .75263 L .52043 .75188 L F
.52 .75263 m .52007 .81156 L .52043 .75188 L F
.25969 .66745 m .26005 .66783 L .26013 .66768 L .877 .587 .493 r
F
.37289 .72915 m .25997 .66963 L .37437 .73103 L .866 .642 .596 r
F
.25997 .66963 m .25953 .6694 L .25997 .66964 L F
.25997 .66963 m .25997 .66964 L .37437 .73103 L F
.25973 .66838 m .25953 .6694 L .37289 .72915 L F
.20597 .57675 m .20664 .57879 L .25973 .66838 L .981 .697 .327 r
F
.20576 .57639 m .20594 .57688 L .20597 .57675 L F
.20594 .57688 m .20664 .57879 L .20597 .57675 L F
.20576 .57639 m .25973 .66838 L .2595 .66713 L F
.22289 .51277 m .259 .66714 L .2732 .6025 L .987 .793 .556 r
F
.25963 .45446 m .22289 .51277 L .2732 .6025 L .947 .822 .689 r
F
.259 .66714 m .20576 .57875 L .25953 .6694 L .987 .793 .556 r
F
.20576 .57875 m .20576 .57875 L .25953 .6694 L F
.20576 .57639 m .20581 .5774 L .20664 .57879 L .981 .697 .327 r
F
.22289 .51277 m .20581 .5774 L .259 .66714 L .987 .793 .556 r
F
.20581 .5774 m .20555 .5784 L .259 .66714 L F
.20664 .57879 m .20962 .64523 L .26273 .73154 L .981 .697 .327 r
F
.20581 .5774 m .20962 .64523 L .20664 .57879 L F
.28847 .36568 m .22289 .51277 L .25963 .45446 L .869 .948 .591 r
F
.28847 .36568 m .25385 .41436 L .22289 .51277 L F
.25385 .41436 m .20625 .57603 L .22289 .51277 L 0 0 0 r
F
.259 .66714 m .25942 .66894 L .25959 .66813 L .987 .793 .556 r
F
.25942 .66894 m .25953 .6694 L .25973 .66838 L F
.2595 .66713 m .25973 .66838 L .25969 .66745 L .981 .697 .327 r
F
.25969 .66745 m .25973 .66838 L .26146 .66931 L .877 .587 .493 r
F
.25942 .66894 m .25973 .66838 L .2732 .6025 L .987 .793 .556 r
F
.20664 .57879 m .26273 .73154 L .25973 .66838 L .981 .697 .327 r
F
.23711 .47854 m .20962 .64523 L .20581 .5774 L 0 0 .319 r
F
.20625 .57603 m .20569 .57792 L .2059 .57712 L 0 0 0 r
F
.20625 .57603 m .2059 .57712 L .22289 .51277 L F
.20569 .57792 m .20581 .5774 L .22289 .51277 L F
.23711 .47854 m .24123 .55013 L .20962 .64523 L 0 0 .319 r
F
.23759 .47701 m .24123 .55013 L .23711 .47854 L F
.20625 .57603 m .23734 .47798 L .20555 .5784 L 0 0 0 r
F
.25385 .41436 m .23759 .47701 L .20625 .57603 L F
.23759 .47701 m .23734 .47798 L .20625 .57603 L F
.23754 .47592 m .23759 .47701 L .23711 .47854 L 0 0 .319 r
F
.23754 .47592 m .23711 .47854 L .20581 .5774 L F
.20587 .57604 m .20581 .5774 L .20576 .57639 L F
.23754 .47592 m .20581 .5774 L .20587 .57604 L F
.20576 .57875 m .20555 .5784 L .20576 .57875 L .987 .793 .556 r
F
.20569 .57792 m .20555 .5784 L .20581 .5774 L 0 0 0 r
F
.259 .66714 m .25959 .66813 L .2732 .6025 L .987 .793 .556 r
F
.26146 .66931 m .26273 .73154 L .37612 .79006 L .877 .587 .493 r
F
.25973 .66838 m .26273 .73154 L .26146 .66931 L F
.26013 .66768 m .26146 .66931 L .37446 .72912 L F
.26005 .66783 m .26146 .66931 L .26013 .66768 L F
.26146 .66931 m .37448 .73001 L .37446 .72912 L F
.2732 .6025 m .25973 .66838 L .37289 .72915 L .866 .642 .596 r
F
.37289 .72915 m .37407 .73065 L .37416 .72984 L F
.37407 .73065 m .37437 .73103 L .37448 .73001 L F
.37446 .72912 m .3749 .72937 L .375 .7292 L .753 .483 .524 r
F
.37446 .72912 m .52 .75263 L .51947 .75168 L F
.51793 .75231 m .37437 .73103 L .52 .75366 L .757 .538 .6 r
F
.37448 .73001 m .37437 .73103 L .51793 .75231 L F
.37662 .73034 m .37612 .79006 L .52007 .81156 L .753 .483 .524 r
F
.37446 .72912 m .37448 .73001 L .37662 .73034 L F
.37448 .73001 m .37612 .79006 L .37662 .73034 L F
.375 .7292 m .37662 .73034 L .52 .75263 L F
.3749 .72937 m .37662 .73034 L .375 .7292 L F
.38187 .66357 m .37448 .73001 L .51793 .75231 L .757 .538 .6 r
F
.37407 .73065 m .37448 .73001 L .38187 .66357 L .866 .642 .596 r
F
.26146 .66931 m .37612 .79006 L .37448 .73001 L .877 .587 .493 r
F
.2732 .6025 m .37289 .72915 L .38187 .66357 L .866 .642 .596 r
F
.37289 .72915 m .37416 .72984 L .38187 .66357 L F
.51793 .75231 m .51958 .75338 L .51959 .75257 L .757 .538 .6 r
F
.51958 .75338 m .52 .75366 L .52 .75263 L F
.51947 .75168 m .52 .75263 L .52 .75176 L .753 .483 .524 r
F
.52 .75176 m .66436 .73731 L .66391 .73295 L .629 .382 .524 r
F
.52 .75176 m .5221 .75236 L .54862 .74889 L F
.51958 .75338 m .52 .75263 L .52031 .68605 L .757 .538 .6 r
F
.37662 .73034 m .52007 .81156 L .52 .75263 L .753 .483 .524 r
F
.38187 .66357 m .51793 .75231 L .52031 .68605 L .757 .538 .6 r
F
.51793 .75231 m .51959 .75257 L .52031 .68605 L F
.66296 .79363 m .75925 .79591 L .77955 .7398 L .361 .075 .336 r
F
.66278 .79447 m .75925 .79591 L .66296 .79363 L F
.52558 .86334 m .52631 .86418 L .44934 .83045 L .618 .728 .924 r
F
.52628 .86483 m .5263 .86436 L .53717 .87144 L .58 .821 .99 r
F
.37612 .79006 m .52055 .8597 L .52007 .81156 L .736 .395 .405 r
F
.48275 .81432 m .52558 .86334 L .44934 .83045 L .618 .728 .924 r
F
.48275 .81432 m .52631 .86418 L .4823 .81471 L .648 .738 .915 r
F
.66445 .73377 m .6649 .73371 L .66447 .73288 L .629 .382 .524 r
F
.66441 .73372 m .66442 .73378 L .66445 .73377 L .509 .347 .597 r
F
.66441 .73372 m .66445 .73377 L .65785 .6683 L F
.66445 .73377 m .66445 .73377 L .6646 .73375 L .649 .449 .6 r
F
.66445 .73377 m .66665 .73708 L .6649 .73371 L .629 .382 .524 r
F
.6649 .73371 m .66665 .73708 L .66674 .73347 L F
.66447 .73371 m .66445 .73377 L .6646 .73375 L .649 .449 .6 r
F
.66441 .73372 m .66432 .73383 L .66442 .73378 L .509 .347 .597 r
F
.664 .73383 m .66445 .73377 L .66391 .73295 L .629 .382 .524 r
F
.66442 .73383 m .66445 .73383 L .66445 .73377 L .454 .241 .5 r
F
.7822 .67807 m .78215 .67833 L .78261 .67811 L .509 .347 .597 r
F
.66447 .73371 m .6646 .73375 L .66618 .72963 L .649 .449 .6 r
F
.6646 .73375 m .66671 .73347 L .66618 .72963 L F
.66445 .73377 m .78241 .67709 L .66445 .73377 L .454 .241 .5 r
F
.782 .67638 m .78241 .67709 L .78245 .67616 L F
.66445 .73377 m .78241 .67709 L .782 .67638 L F
.84371 .58999 m .78241 .67709 L .84467 .58998 L .214 .152 .567 r
F
.84467 .58971 m .84467 .58998 L .84492 .58964 L F
.84371 .58999 m .84467 .58998 L .84467 .58971 L F
.78262 .6761 m .78258 .67684 L .78326 .67588 L .021 0 .366 r
F
.78245 .67616 m .78241 .67709 L .78262 .6761 L F
.78241 .67709 m .78261 .67811 L .78283 .6778 L .214 .152 .567 r
F
.78241 .67709 m .78283 .6778 L .84492 .58964 L F
.66491 .73267 m .66445 .73377 L .78245 .67616 L .454 .241 .5 r
F
.65775 .66731 m .66029 .67055 L .65993 .66701 L .649 .449 .6 r
F
.65605 .66816 m .65785 .6683 L .65775 .66731 L .509 .347 .597 r
F
.65605 .66816 m .66225 .73046 L .66441 .73372 L F
.65522 .66409 m .65605 .66816 L .65775 .66731 L .548 .428 .669 r
F
.52031 .68605 m .6581 .6708 L .65775 .66731 L .649 .449 .6 r
F
.6581 .6708 m .66029 .67055 L .65775 .66731 L F
.64368 .59924 m .65993 .66701 L .64564 .599 L .662 .503 .659 r
F
.65749 .66607 m .65993 .66701 L .64368 .59924 L F
.64159 .59717 m .65522 .66409 L .65775 .66731 L .548 .428 .669 r
F
.64159 .59717 m .65775 .66731 L .64329 .59736 L F
.52097 .61381 m .52031 .68605 L .65993 .66701 L .662 .503 .659 r
F
.65775 .66731 m .7822 .67807 L .76954 .61111 L .509 .347 .597 r
F
.65785 .6683 m .7822 .67807 L .65775 .66731 L F
.7822 .67807 m .78261 .67811 L .78241 .67709 L F
.7822 .67807 m .78241 .67709 L .76954 .61111 L F
.78241 .67709 m .77955 .7398 L .78262 .6761 L .021 0 .366 r
F
.84447 .58799 m .84447 .58799 L .84471 .58764 L F
.78326 .67588 m .84466 .58864 L .84471 .58764 L F
.82781 .52383 m .84466 .58864 L .82368 .48948 L 0 0 .22 r
F
.78245 .67616 m .78326 .67588 L .84447 .58799 L .021 0 .366 r
F
.78245 .67616 m .84447 .58799 L .84447 .58799 L F
.84371 .58999 m .84492 .58964 L .84466 .58864 L .214 .152 .567 r
F
.78326 .67588 m .8409 .65589 L .84466 .58864 L .021 0 .366 r
F
.76954 .61111 m .84371 .58999 L .82781 .52383 L .214 .152 .567 r
F
.84371 .58999 m .84466 .58864 L .82781 .52383 L F
.82725 .59468 m .83042 .60887 L .84371 .58999 L F
.76954 .61111 m .83042 .60887 L .82725 .59468 L F
.76954 .61111 m .78241 .67709 L .83042 .60887 L F
.84437 .58727 m .8409 .65589 L .81963 .56048 L .929 .738 .255 r
F
.84464 .58757 m .8446 .58836 L .84437 .58727 L F
.8446 .58836 m .8409 .65589 L .84437 .58727 L F
.84466 .58864 m .8409 .65589 L .84464 .58757 L F
.74157 .54442 m .82781 .52383 L .7915 .46452 L .345 .32 .687 r
F
.74157 .54442 m .76954 .61111 L .82781 .52383 L F
.7915 .46452 m .82781 .52383 L .80673 .42505 L 0 .065 .626 r
F
.84471 .58764 m .84437 .58727 L .82341 .48686 L .929 .738 .255 r
F
.82781 .52383 m .82368 .48948 L .80673 .42505 L 0 0 .22 r
F
.82368 .48948 m .82335 .48794 L .80673 .42505 L F
.84437 .58727 m .81963 .56048 L .82335 .48794 L .929 .738 .255 r
F
.64926 .42536 m .73926 .41494 L .67479 .37749 L .515 .536 .815 r
F
.64926 .42536 m .7007 .48147 L .73926 .41494 L F
.7007 .48147 m .7915 .46452 L .73926 .41494 L .44 .44 .763 r
F
.7007 .48147 m .74157 .54442 L .7915 .46452 L F
.67479 .37749 m .73926 .41494 L .72109 .342 L .387 .535 .882 r
F
.73926 .41494 m .77127 .37526 L .72109 .342 L .17 .365 .814 r
F
.73926 .41494 m .7915 .46452 L .77127 .37526 L F
.7915 .46452 m .80673 .42505 L .77127 .37526 L 0 .065 .626 r
F
.80673 .42505 m .82335 .48794 L .71241 .40581 L .914 .547 .32 r
F
.8218 .48679 m .70829 .48158 L .7107 .40455 L .917 .653 .522 r
F
.67479 .37749 m .72109 .342 L .66051 .32621 L .387 .535 .882 r
F
.80673 .42505 m .71118 .40557 L .69992 .34373 L .914 .547 .32 r
F
.71118 .40557 m .71087 .4055 L .7107 .40455 L F
.71118 .40557 m .7107 .40455 L .69992 .34373 L F
.59423 .45674 m .5939 .45753 L .59501 .45736 L .679 .642 .806 r
F
.59363 .45816 m .5942 .45828 L .5939 .45753 L .607 .558 .774 r
F
.59421 .4583 m .62211 .52297 L .59533 .45814 L .676 .595 .757 r
F
.62211 .52297 m .62305 .52515 L .62212 .52291 L F
.62211 .52297 m .62212 .52291 L .59533 .45814 L F
.62087 .52391 m .62305 .52515 L .59421 .4583 L F
.59304 .45803 m .62026 .52605 L .62147 .52538 L .607 .558 .774 r
F
.52321 .46852 m .52195 .54022 L .62147 .52538 L .676 .595 .757 r
F
.62087 .52391 m .62147 .52538 L .62305 .52515 L F
.59304 .45803 m .62147 .52538 L .5942 .45828 L .607 .558 .774 r
F
.52321 .46852 m .62147 .52538 L .62087 .52391 L .676 .595 .757 r
F
.59248 .45694 m .59304 .45803 L .5939 .45753 L .633 .621 .821 r
F
.59304 .45803 m .59363 .45816 L .5939 .45753 L .607 .558 .774 r
F
.52321 .46852 m .59533 .45814 L .5939 .45753 L .676 .595 .757 r
F
.5942 .45828 m .62147 .52538 L .7007 .48147 L .607 .558 .774 r
F
.62147 .52538 m .74157 .54442 L .7007 .48147 L .579 .496 .725 r
F
.62026 .52605 m .62125 .5262 L .62147 .52538 L F
.62125 .5262 m .74157 .54442 L .62147 .52538 L F
.5939 .45753 m .59533 .45814 L .59501 .45736 L .676 .595 .757 r
F
.5942 .45828 m .7007 .48147 L .5939 .45753 L .607 .558 .774 r
F
.52321 .46852 m .62087 .52391 L .59421 .4583 L .676 .595 .757 r
F
.56109 .39633 m .59248 .45694 L .5939 .45753 L .633 .621 .821 r
F
.59295 .45574 m .5939 .45753 L .59423 .45674 L .679 .642 .806 r
F
.56109 .39633 m .5939 .45753 L .5618 .39656 L .633 .621 .821 r
F
.56153 .39606 m .59501 .45736 L .56211 .39597 L .679 .642 .806 r
F
.56109 .39633 m .5618 .39656 L .56153 .39606 L .633 .621 .821 r
F
.52629 .34546 m .52631 .34518 L .52729 .34536 L .685 .769 .915 r
F
.52729 .34536 m .52645 .34541 L .52687 .34523 L .702 .764 .9 r
F
.52645 .34541 m .52631 .34506 L .52746 .34497 L F
.52688 .34524 m .52674 .34511 L .52695 .34513 L .709 .749 .883 r
F
.52674 .34511 m .52631 .34506 L .52732 .34458 L F
.52577 .34427 m .52631 .34506 L .52534 .34454 L .659 .69 .868 r
F
.52534 .34454 m .52633 .34466 L .52517 .34492 L .642 .692 .881 r
F
.52746 .34497 m .52631 .34506 L .52709 .34515 L .709 .749 .883 r
F
.52618 .34533 m .52622 .34525 L .52687 .34562 L .663 .763 .924 r
F
.52685 .34563 m .52661 .34537 L .52637 .34548 L .685 .769 .915 r
F
.52595 .34515 m .52631 .34506 L .52572 .34561 L .63 .723 .914 r
F
.52685 .34581 m .48767 .39489 L .52469 .402 L .694 .711 .862 r
F
.52583 .345 m .52631 .34506 L .52531 .34532 L .632 .704 .898 r
F
.52602 .34544 m .52631 .34506 L .52597 .34539 L .663 .763 .924 r
F
.52609 .34544 m .5263 .34543 L .52629 .34572 L .642 .745 .924 r
F
.52629 .34572 m .52631 .34506 L .52602 .34544 L .663 .763 .924 r
F
.52616 .34457 m .52621 .34471 L .52579 .3443 L .677 .697 .861 r
F
.52579 .34478 m .52631 .34506 L .52517 .34492 L .642 .692 .881 r
F
.52664 .34497 m .52631 .34506 L .52691 .34428 L .705 .729 .869 r
F
.52691 .34428 m .52631 .34506 L .5269 .34461 L .694 .711 .862 r
F
.52632 .34469 m .52621 .34471 L .52616 .34457 L .677 .697 .861 r
F
.52632 .34478 m .52621 .34471 L .52632 .34469 L F
.52613 .34445 m .52631 .34506 L .52633 .34456 L .659 .69 .868 r
F
.52578 .34426 m .52633 .34456 L .52631 .34506 L F
.52632 .34483 m .52631 .34506 L .52576 .34427 L .677 .697 .861 r
F
.52686 .34563 m .52666 .34542 L .52729 .34536 L .685 .769 .915 r
F
.52684 .34561 m .52631 .34506 L .52687 .34562 L .663 .763 .924 r
F
.52659 .3451 m .52631 .34506 L .52664 .34497 L .705 .729 .869 r
F
.52603 .345 m .52631 .34506 L .52595 .34515 L .63 .723 .914 r
F
.5261 .34484 m .52631 .34506 L .52583 .345 L .632 .704 .898 r
F
.52652 .3451 m .52631 .34506 L .52634 .34417 L .694 .711 .862 r
F
.52649 .34499 m .52631 .34506 L .52632 .34483 L .677 .697 .861 r
F
.52578 .34426 m .52631 .34506 L .52613 .34445 L .659 .69 .868 r
F
.52633 .34466 m .52631 .34506 L .526 .34473 L .642 .692 .881 r
F
.52631 .34506 m .52668 .34489 L .5269 .34461 L .694 .711 .862 r
F
.52689 .34478 m .52631 .34506 L .52688 .34514 L .705 .729 .869 r
F
.52682 .34505 m .52646 .34479 L .52634 .34417 L .694 .711 .862 r
F
.52695 .34513 m .52674 .34511 L .52732 .34458 L .709 .749 .883 r
F
.52732 .34458 m .5271 .34486 L .52691 .34428 L .705 .729 .869 r
F
.5271 .34486 m .5268 .34524 L .52684 .34493 L F
.5271 .34486 m .52684 .34493 L .52691 .34428 L F
.52424 .34557 m .46096 .32498 L .45044 .35079 L .702 .764 .9 r
F
.52589 .34516 m .52595 .34515 L .52572 .34561 L .63 .723 .914 r
F
.52688 .34524 m .52667 .34517 L .52674 .34511 L .709 .749 .883 r
F
.5268 .34524 m .52664 .34518 L .52691 .34428 L .705 .729 .869 r
F
.52688 .34517 m .5265 .34482 L .52682 .34505 L .694 .711 .862 r
F
.5265 .34482 m .52646 .34479 L .5265 .34482 L F
.5265 .34482 m .5265 .34482 L .52682 .34505 L F
.52688 .34517 m .52652 .3451 L .52646 .34479 L F
.52708 .34525 m .52632 .34478 L .52632 .34469 L .677 .697 .861 r
F
.52631 .34506 m .5266 .345 L .52668 .34489 L .694 .711 .862 r
F
.52634 .34417 m .52631 .34506 L .52689 .34496 L .677 .697 .861 r
F
.52633 .34456 m .52648 .34464 L .52631 .34506 L .659 .69 .868 r
F
.52634 .34417 m .52708 .34525 L .52579 .3443 L .677 .697 .861 r
F
.52648 .34464 m .52652 .34467 L .52647 .34468 L .659 .69 .868 r
F
.52646 .34521 m .52631 .34506 L .52729 .34536 L .685 .769 .915 r
F
.52531 .34532 m .52631 .34506 L .52566 .345 L .63 .723 .914 r
F
.52729 .34536 m .52631 .34506 L .52663 .3454 L .702 .764 .9 r
F
.52709 .34515 m .5266 .34509 L .52646 .34544 L .709 .749 .883 r
F
.52572 .34561 m .52631 .34506 L .52575 .34494 L .642 .745 .924 r
F
.52583 .34477 m .52631 .34506 L .52579 .34478 L .642 .692 .881 r
F
.52517 .34492 m .52631 .34506 L .52591 .34474 L .632 .704 .898 r
F
.52613 .34457 m .52595 .34515 L .52589 .34516 L .63 .723 .914 r
F
.52575 .34494 m .52631 .34506 L .52585 .34509 L .642 .745 .924 r
F
.5263 .3453 m .52631 .34506 L .52684 .34561 L .663 .763 .924 r
F
.52575 .34497 m .52631 .34506 L .5263 .3453 L F
.52663 .3454 m .52631 .34506 L .5265 .34541 L .702 .764 .9 r
F
.52609 .34514 m .52631 .34506 L .52646 .34521 L .685 .769 .915 r
F
.5269 .34461 m .52662 .34509 L .52687 .3453 L .694 .711 .862 r
F
.52691 .34428 m .52688 .34517 L .52661 .34467 L F
.52652 .34467 m .52743 .34516 L .52647 .34468 L .659 .69 .868 r
F
.52661 .34527 m .52655 .34522 L .52691 .34428 L .705 .729 .869 r
F
.5269 .34461 m .52683 .3447 L .52685 .34469 L .694 .711 .862 r
F
.52683 .3447 m .52653 .34508 L .52685 .34469 L F
.52685 .34469 m .52653 .34508 L .52657 .34517 L F
.52647 .34468 m .52662 .34475 L .52642 .3448 L .659 .69 .868 r
F
.52708 .34525 m .52663 .34514 L .52632 .34483 L .677 .697 .861 r
F
.52732 .34458 m .52689 .34478 L .52688 .34514 L .705 .729 .869 r
F
.52688 .34524 m .52629 .34552 L .52667 .34517 L .709 .749 .883 r
F
.5265 .34562 m .52655 .34522 L .52661 .34527 L .705 .729 .869 r
F
.52534 .34454 m .52631 .34506 L .52575 .34459 L .642 .692 .881 r
F
.52631 .34506 m .52608 .34489 L .52599 .34491 L .63 .723 .914 r
F
.52631 .34506 m .52599 .34491 L .52566 .345 L F
.52691 .34386 m .59388 .32768 L .56677 .30772 L F
.5265 .34541 m .52631 .34506 L .5263 .34543 L .702 .764 .9 r
F
.52554 .34483 m .52593 .34494 L .52531 .34532 L .632 .704 .898 r
F
.52566 .345 m .52599 .34491 L .52583 .34484 L .63 .723 .914 r
F
.52629 .34572 m .52574 .34515 L .52687 .34562 L .663 .763 .924 r
F
.52667 .34517 m .52631 .34506 L .52674 .34511 L .709 .749 .883 r
F
.52629 .34552 m .52631 .34506 L .52667 .34517 L F
.52688 .34514 m .52631 .34506 L .52628 .3459 L .705 .729 .869 r
F
.52662 .34509 m .52657 .34517 L .52681 .34527 L .694 .711 .862 r
F
.52662 .34509 m .52681 .34527 L .52687 .3453 L F
.52685 .34563 m .52666 .34542 L .52686 .34563 L .685 .769 .915 r
F
.52687 .3453 m .52657 .34517 L .52685 .34581 L .694 .711 .862 r
F
.5268 .34524 m .5265 .34562 L .52664 .34518 L .705 .729 .869 r
F
.52645 .34541 m .5263 .34543 L .52631 .34506 L .702 .764 .9 r
F
.52597 .34539 m .52631 .34506 L .52589 .3453 L .663 .763 .924 r
F
.5263 .34546 m .52631 .34506 L .52614 .34541 L .685 .769 .915 r
F
.52574 .34515 m .52622 .34525 L .52618 .34533 L .663 .763 .924 r
F
.52574 .34515 m .52599 .34511 L .52622 .34525 L F
.52517 .34492 m .52554 .34483 L .52531 .34532 L .632 .704 .898 r
F
.52575 .34459 m .52631 .34506 L .52618 .34464 L .642 .692 .881 r
F
.52618 .34464 m .52633 .34472 L .52633 .34466 L F
.52628 .3459 m .52631 .34506 L .52659 .3451 L .705 .729 .869 r
F
.52654 .34524 m .52631 .34506 L .52652 .3451 L .694 .711 .862 r
F
.52685 .34563 m .52629 .34546 L .52666 .34542 L .685 .769 .915 r
F
.5265 .34562 m .52645 .34547 L .52655 .34522 L .705 .729 .869 r
F
.52682 .34668 m .52631 .34506 L .52654 .34524 L .694 .711 .862 r
F
.52631 .34506 m .5263 .34537 L .5266 .345 L F
.52653 .34508 m .52643 .34522 L .52656 .34539 L F
.52653 .34508 m .52656 .34539 L .52685 .34581 L F
.52567 .34498 m .52595 .34501 L .52572 .34561 L .63 .723 .914 r
F
.52531 .34532 m .52567 .34498 L .52572 .34561 L F
.52572 .34561 m .52575 .34494 L .52602 .34533 L .642 .745 .924 r
F
.52574 .34515 m .52535 .34474 L .52599 .34511 L .663 .763 .924 r
F
.52614 .34541 m .52631 .34506 L .52428 .34482 L .685 .769 .915 r
F
.52629 .34546 m .52428 .34482 L .52631 .34518 L F
.5263 .34543 m .52533 .34549 L .52631 .34506 L .702 .764 .9 r
F
.52689 .34496 m .52631 .34506 L .52782 .34632 L .677 .697 .861 r
F
.52708 .34525 m .52632 .34483 L .52632 .34478 L F
.52633 .34472 m .52631 .34506 L .52708 .34513 L .659 .69 .868 r
F
.52633 .34472 m .52708 .34513 L .52743 .34516 L F
.52633 .34456 m .52633 .34472 L .52743 .34516 L F
.52782 .34632 m .52631 .34506 L .52649 .34499 L .677 .697 .861 r
F
.52708 .34525 m .52782 .34632 L .52663 .34514 L F
.52729 .34536 m .52687 .34523 L .52746 .34497 L .702 .764 .9 r
F
.52688 .34517 m .52682 .34668 L .52652 .3451 L .694 .711 .862 r
F
.52743 .34516 m .52631 .34506 L .58984 .37887 L .659 .69 .868 r
F
.52692 .3449 m .52743 .34516 L .52631 .34506 L F
.52632 .34478 m .52632 .34483 L .52621 .34471 L .677 .697 .861 r
F
.52743 .34516 m .52835 .34565 L .52631 .34506 L .659 .69 .868 r
F
.52835 .34565 m .58984 .37887 L .52631 .34506 L F
.52746 .34497 m .52688 .34524 L .52732 .34458 L .709 .749 .883 r
F
.52631 .34506 m .58984 .37887 L .52618 .34464 L .642 .692 .881 r
F
.52581 .34476 m .52655 .34458 L .52603 .34489 L .632 .704 .898 r
F
.52581 .34476 m .52603 .34489 L .52593 .34494 L F
.52554 .34483 m .52581 .34476 L .52593 .34494 L F
.52567 .34498 m .52613 .34457 L .52595 .34501 L .63 .723 .914 r
F
.52633 .34466 m .52668 .3447 L .52631 .34506 L .642 .692 .881 r
F
.52633 .34466 m .58984 .37887 L .60207 .35382 L F
.52633 .34472 m .58984 .37887 L .52633 .34466 L F
.52591 .34474 m .52631 .34506 L .5269 .34449 L .632 .704 .898 r
F
.52655 .34458 m .52631 .34506 L .5261 .34484 L F
.52599 .34491 m .52644 .3448 L .52583 .34484 L .63 .723 .914 r
F
.52668 .3447 m .60207 .35382 L .52631 .34506 L .642 .692 .881 r
F
.5269 .34449 m .52631 .34506 L .59388 .32768 L .632 .704 .898 r
F
.52655 .34458 m .59388 .32768 L .52631 .34506 L F
.52691 .34428 m .52661 .34467 L .52634 .34417 L .694 .711 .862 r
F
.52644 .3448 m .59388 .32768 L .52651 .34467 L .63 .723 .914 r
F
.52644 .3448 m .52651 .34467 L .52583 .34484 L F
.52583 .34484 m .52651 .34467 L .52691 .34386 L F
.52651 .34467 m .59388 .32768 L .52691 .34386 L F
.52578 .34426 m .52631 .34506 L .52577 .34427 L .659 .69 .868 r
F
.52631 .34506 m .59388 .32768 L .52608 .34489 L .63 .723 .914 r
F
.52613 .34457 m .52618 .3447 L .52595 .34515 L F
.52635 .34437 m .52631 .34506 L .52603 .34499 L F
.52613 .34457 m .52635 .34437 L .52618 .3447 L F
.52635 .34437 m .56677 .30772 L .52631 .34506 L F
.52631 .34506 m .56677 .30772 L .52583 .34487 L .642 .745 .924 r
F
.52603 .34499 m .52631 .34506 L .52603 .345 L .63 .723 .914 r
F
.52631 .34506 m .52583 .34487 L .52575 .34494 L .642 .745 .924 r
F
.52634 .34417 m .52579 .3443 L .52577 .34427 L .677 .697 .861 r
F
.52575 .34494 m .56677 .30772 L .52803 .29986 L .642 .745 .924 r
F
.52575 .34494 m .52803 .29986 L .52631 .34506 L F
.52589 .3453 m .52631 .34506 L .52481 .34417 L .663 .763 .924 r
F
.52599 .34513 m .52631 .34506 L .52609 .34514 L .685 .769 .915 r
F
.5263 .34543 m .52631 .34506 L .52424 .34557 L .702 .764 .9 r
F
.5263 .34551 m .52631 .34506 L .52629 .34552 L .709 .749 .883 r
F
.52629 .34552 m .52631 .34506 L .52608 .34561 L F
.52572 .34561 m .52602 .34533 L .52629 .34572 L .642 .745 .924 r
F
.52629 .34552 m .46046 .37631 L .52631 .34506 L .709 .749 .883 r
F
.52628 .3459 m .52631 .34506 L .52572 .34662 L .705 .729 .869 r
F
.52608 .34561 m .52553 .34565 L .52477 .34623 L .709 .749 .883 r
F
.52535 .34474 m .52631 .34506 L .52575 .34497 L .663 .763 .924 r
F
.52428 .34482 m .52631 .34506 L .52599 .34513 L .685 .769 .915 r
F
.52428 .34482 m .52631 .34506 L .46096 .32498 L F
.52428 .34482 m .46096 .32498 L .52631 .34506 L F
.52631 .34506 m .46096 .32498 L .52424 .34557 L .702 .764 .9 r
F
.52533 .34549 m .52424 .34557 L .52631 .34506 L F
.52424 .34557 m .45044 .35079 L .52631 .34506 L F
.52631 .34506 m .45044 .35079 L .52608 .34561 L .709 .749 .883 r
F
.52572 .34662 m .52631 .34506 L .48767 .39489 L .705 .729 .869 r
F
.5265 .34562 m .52628 .3459 L .52645 .34547 L F
.52628 .3459 m .48767 .39489 L .52631 .34506 L F
.52643 .34522 m .48767 .39489 L .52685 .34581 L .694 .711 .862 r
F
.52782 .34632 m .52631 .34506 L .56211 .39597 L .677 .697 .861 r
F
.52631 .34506 m .48767 .39489 L .5263 .34537 L .694 .711 .862 r
F
.48901 .30677 m .48901 .30677 L .48879 .30653 L .663 .763 .924 r
F
.52631 .34506 m .48939 .30643 L .48879 .30653 L F
.52535 .34474 m .48879 .30653 L .52631 .34506 L F
.48984 .30614 m .4897 .30616 L .48939 .30643 L .706 .869 .959 r
F
.45166 .28413 m .45095 .28372 L .45165 .28414 L .603 .842 .989 r
F
.4533 .28421 m .45095 .28372 L .48939 .30643 L F
.48984 .30614 m .45374 .28334 L .45216 .28351 L .706 .869 .959 r
F
.45374 .28334 m .45306 .28291 L .45216 .28351 L F
.45306 .28291 m .45242 .2832 L .45216 .28351 L .677 .961 .941 r
F
.45242 .2832 m .4518 .28347 L .45216 .28351 L F
.45216 .28351 m .45057 .28368 L .45095 .28372 L .352 .82 .907 r
F
.52977 .27012 m .45179 .28347 L .45216 .28351 L F
.45179 .28347 m .45057 .28368 L .45216 .28351 L F
.45306 .28291 m .42006 .27916 L .4176 .2799 L .677 .961 .941 r
F
.45179 .28347 m .41704 .28032 L .45057 .28368 L .352 .82 .907 r
F
.41704 .28032 m .41583 .28021 L .41703 .28033 L F
.41704 .28032 m .41703 .28033 L .45057 .28368 L F
.41837 .27998 m .41737 .28007 L .45179 .28347 L F
.41737 .28007 m .41583 .28021 L .41704 .28032 L F
.41737 .28007 m .41704 .28032 L .45179 .28347 L F
.41688 .28034 m .38619 .29827 L .41509 .28066 L .189 0 0 r
F
.41724 .28012 m .38843 .29788 L .28847 .36568 L .425 .828 .623 r
F
.45306 .28291 m .4176 .2799 L .4518 .28347 L .677 .961 .941 r
F
.52977 .27012 m .53139 .26017 L .41583 .28021 L .352 .82 .907 r
F
.4176 .2799 m .28847 .36568 L .33739 .33425 L .425 .828 .623 r
F
.4176 .2799 m .41509 .28066 L .41583 .28021 L .189 0 0 r
F
.41688 .28034 m .41509 .28066 L .4176 .2799 L F
.41778 .27976 m .41724 .28012 L .4176 .2799 L .425 .828 .623 r
F
.41724 .28012 m .28847 .36568 L .4176 .2799 L F
.4533 .28421 m .45216 .28351 L .45095 .28372 L .603 .842 .989 r
F
.4518 .28347 m .4176 .2799 L .33739 .33425 L .677 .961 .941 r
F
.52977 .27012 m .41837 .27998 L .45179 .28347 L .352 .82 .907 r
F
.53139 .26017 m .41688 .28034 L .4176 .2799 L .189 0 0 r
F
.53139 .26017 m .389 .29753 L .41688 .28034 L F
.4518 .28347 m .33739 .33425 L .45216 .28351 L .677 .961 .941 r
F
.45216 .28351 m .33739 .33425 L .39632 .32084 L F
.33739 .33425 m .25963 .45446 L .31241 .40665 L .892 .979 .816 r
F
.39632 .32084 m .33739 .33425 L .31241 .40665 L .835 .917 .891 r
F
.33739 .33425 m .28847 .36568 L .25963 .45446 L .892 .979 .816 r
F
.38843 .29788 m .25385 .41436 L .28847 .36568 L .013 0 0 r
F
.389 .29753 m .3882 .29774 L .41688 .28034 L .189 0 0 r
F
.3882 .29774 m .38767 .2974 L .41688 .28034 L F
.52803 .29986 m .52977 .27012 L .45216 .28351 L .603 .842 .989 r
F
.48984 .30614 m .45216 .28351 L .4891 .30625 L .706 .869 .959 r
F
.52803 .29986 m .45216 .28351 L .4533 .28421 L .603 .842 .989 r
F
.48939 .30643 m .45166 .28413 L .48879 .30653 L F
.45166 .28413 m .45165 .28414 L .48879 .30653 L F
.4891 .30625 m .45216 .28351 L .39632 .32084 L .706 .869 .959 r
F
.4897 .30616 m .4891 .30625 L .48939 .30643 L F
.52481 .34417 m .52631 .34506 L .48901 .30677 L .663 .763 .924 r
F
.52481 .34417 m .48901 .30677 L .48901 .30677 L F
.52631 .34506 m .48984 .30614 L .46096 .32498 L .685 .769 .915 r
F
.52803 .29986 m .4533 .28421 L .48939 .30643 L .603 .842 .989 r
F
.56677 .30772 m .52977 .27012 L .52803 .29986 L .515 .767 .988 r
F
.56677 .30772 m .60751 .28612 L .52977 .27012 L F
.60751 .28612 m .53139 .26017 L .52977 .27012 L .15 .65 .91 r
F
.53139 .26017 m .53277 .27301 L .38843 .29788 L .189 0 0 r
F
.3882 .29774 m .38843 .29788 L .38619 .29827 L F
.53139 .26017 m .38843 .29788 L .3882 .29774 L F
.38815 .29843 m .36752 .33831 L .25385 .41436 L .013 0 0 r
F
.4891 .30625 m .39632 .32084 L .48939 .30643 L .706 .869 .959 r
F
.48939 .30643 m .39632 .32084 L .46096 .32498 L F
.39632 .32084 m .31241 .40665 L .37737 .3716 L .835 .917 .891 r
F
.46096 .32498 m .39632 .32084 L .37737 .3716 L .767 .84 .907 r
F
.53277 .27301 m .36789 .33759 L .38843 .29788 L .482 .08 .201 r
F
.38863 .29801 m .25385 .41436 L .38843 .29788 L .013 0 0 r
F
.38843 .29788 m .36495 .33874 L .38619 .29827 L .482 .08 .201 r
F
.36789 .33759 m .36495 .33874 L .38843 .29788 L F
.52577 .34427 m .52579 .3443 L .52576 .34427 L .677 .697 .861 r
F
.52631 .34506 m .52803 .29986 L .48939 .30643 L .663 .763 .924 r
F
.53277 .27301 m .53377 .31021 L .36752 .33831 L .482 .08 .201 r
F
.36721 .33786 m .36752 .33831 L .36495 .33874 L F
.53277 .27301 m .36752 .33831 L .36721 .33786 L F
.36752 .33831 m .23926 .47593 L .25385 .41436 L .275 .027 .344 r
F
.23926 .47593 m .23759 .47701 L .25385 .41436 L F
.31241 .40665 m .30245 .5365 L .34511 .47482 L .894 .822 .769 r
F
.37737 .3716 m .31241 .40665 L .34511 .47482 L .837 .807 .821 r
F
.25963 .45446 m .2732 .6025 L .30245 .5365 L .947 .822 .689 r
F
.31241 .40665 m .25963 .45446 L .30245 .5365 L .894 .822 .769 r
F
.35763 .39898 m .24123 .55013 L .23759 .47701 L .401 .229 .529 r
F
.52477 .34623 m .45044 .35079 L .46046 .37631 L .709 .749 .883 r
F
.52553 .34565 m .45044 .35079 L .52477 .34623 L F
.37737 .3716 m .34511 .47482 L .39871 .42053 L .837 .807 .821 r
F
.45044 .35079 m .39871 .42053 L .46046 .37631 L .777 .783 .858 r
F
.45044 .35079 m .37737 .3716 L .39871 .42053 L F
.53377 .31021 m .36081 .39846 L .35763 .39898 L .582 .287 .433 r
F
.53377 .31021 m .35763 .39898 L .35764 .39891 L F
.52631 .34506 m .46046 .37631 L .48767 .39489 L .705 .729 .869 r
F
.52682 .34668 m .52469 .402 L .52631 .34506 L .694 .711 .862 r
F
.52631 .34506 m .56109 .39633 L .56153 .39606 L .659 .69 .868 r
F
.52631 .34506 m .52469 .402 L .56153 .39606 L .677 .697 .861 r
F
.48767 .39489 m .52321 .46852 L .52469 .402 L .721 .678 .807 r
F
.48767 .39489 m .45213 .45536 L .52321 .46852 L F
.39871 .42053 m .4218 .52244 L .45213 .45536 L .793 .715 .778 r
F
.39871 .42053 m .34511 .47482 L .4218 .52244 L F
.46046 .37631 m .45213 .45536 L .48767 .39489 L .756 .725 .824 r
F
.46046 .37631 m .39871 .42053 L .45213 .45536 L F
.53161 .37048 m .35982 .47511 L .35777 .40358 L .623 .399 .557 r
F
.34511 .47482 m .39801 .59292 L .4218 .52244 L .823 .699 .728 r
F
.34511 .47482 m .30245 .5365 L .39801 .59292 L F
.35764 .39906 m .35985 .47631 L .24123 .55013 L .401 .229 .529 r
F
.53161 .37048 m .35777 .40358 L .35763 .39898 L .623 .399 .557 r
F
.35764 .39906 m .24123 .55013 L .35763 .39898 L .401 .229 .529 r
F
.35777 .40358 m .35504 .4041 L .35763 .39898 L .623 .399 .557 r
F
.35766 .39902 m .35764 .39906 L .35763 .39898 L .401 .229 .529 r
F
.52631 .34506 m .60207 .35382 L .59388 .32768 L .632 .704 .898 r
F
.52782 .34632 m .56211 .39597 L .52631 .34506 L .677 .697 .861 r
F
.52631 .34506 m .56153 .39606 L .56211 .39597 L F
.52631 .34506 m .56153 .39606 L .58984 .37887 L .659 .69 .868 r
F
.52469 .402 m .59295 .45574 L .56153 .39606 L .679 .642 .806 r
F
.52469 .402 m .5939 .45753 L .59295 .45574 L F
.52469 .402 m .52321 .46852 L .5939 .45753 L F
.45213 .45536 m .52195 .54022 L .52321 .46852 L .738 .646 .758 r
F
.45213 .45536 m .4218 .52244 L .52195 .54022 L F
.30245 .5365 m .38187 .66357 L .39801 .59292 L .847 .676 .67 r
F
.30245 .5365 m .2732 .6025 L .38187 .66357 L F
.35985 .47631 m .2667 .62961 L .24123 .55013 L .476 .362 .644 r
F
.53161 .37048 m .53413 .44896 L .35985 .47631 L .623 .399 .557 r
F
.53161 .37048 m .35985 .47631 L .35923 .47547 L F
.36011 .47783 m .2667 .62961 L .35985 .47631 L .476 .362 .644 r
F
.4218 .52244 m .52097 .61381 L .52195 .54022 L .748 .615 .71 r
F
.4218 .52244 m .39801 .59292 L .52097 .61381 L F
.53413 .44896 m .37509 .56452 L .35985 .47631 L .645 .478 .642 r
F
.36179 .4751 m .37644 .561 L .2667 .62961 L .476 .362 .644 r
F
.62026 .52605 m .64058 .5938 L .64208 .59307 L .579 .496 .725 r
F
.62026 .52605 m .64208 .59307 L .62174 .52628 L F
.52195 .54022 m .64268 .59504 L .62147 .52538 L .67 .55 .71 r
F
.53413 .44896 m .5334 .54226 L .37531 .56578 L .645 .478 .642 r
F
.37467 .56211 m .37531 .56578 L .2667 .62961 L .476 .362 .644 r
F
.37509 .56452 m .37531 .56578 L .37286 .56614 L .645 .478 .642 r
F
.53413 .44896 m .37531 .56578 L .37509 .56452 L F
.37644 .561 m .37531 .56578 L .37467 .56211 L .476 .362 .644 r
F
.37644 .561 m .37708 .56474 L .37531 .56578 L F
.39801 .59292 m .52031 .68605 L .52097 .61381 L .755 .58 .66 r
F
.39801 .59292 m .38187 .66357 L .52031 .68605 L F
.37531 .56578 m .31267 .70747 L .2667 .62961 L .525 .461 .726 r
F
.37583 .56751 m .31267 .70747 L .37531 .56578 L F
.5334 .54226 m .37659 .57006 L .37531 .56578 L .658 .541 .71 r
F
.37583 .56751 m .40291 .65781 L .31267 .70747 L .525 .461 .726 r
F
.37659 .57006 m .37419 .57049 L .37531 .56578 L .658 .541 .71 r
F
.5334 .54226 m .40256 .65665 L .37659 .57006 L F
.52097 .61381 m .65749 .66607 L .64368 .59924 L .662 .503 .659 r
F
.52097 .61381 m .64368 .59924 L .64309 .59638 L F
.5334 .54226 m .53209 .63968 L .40291 .65781 L .658 .541 .71 r
F
.40201 .65712 m .40291 .65781 L .40091 .65809 L F
.5334 .54226 m .40291 .65781 L .40201 .65712 L F
.40291 .65781 m .37545 .77653 L .31267 .70747 L .563 .547 .795 r
F
.40372 .65969 m .37545 .77653 L .40291 .65781 L F
.53209 .63968 m .43959 .74242 L .40291 .65781 L .665 .6 .773 r
F
.66447 .73288 m .66445 .73377 L .66491 .73267 L .454 .241 .5 r
F
.66445 .73377 m .66445 .73377 L .66447 .73288 L F
.52031 .68605 m .66445 .73377 L .66447 .73371 L .649 .449 .6 r
F
.52031 .68605 m .52 .75263 L .66445 .73377 L F
.52031 .68605 m .66444 .7337 L .6581 .6708 L F
.53209 .63968 m .53034 .73139 L .43999 .74335 L .665 .6 .773 r
F
.53209 .63968 m .43999 .74335 L .43959 .74242 L F
.44061 .74185 m .43999 .74335 L .37545 .77653 L .563 .547 .795 r
F
.43959 .74242 m .43999 .74335 L .43858 .74354 L .665 .6 .773 r
F
.40437 .65701 m .44061 .74185 L .43958 .7424 L .563 .547 .795 r
F
.40372 .65969 m .43958 .7424 L .37545 .77653 L F
.40437 .65701 m .43958 .7424 L .40372 .65969 L F
.44061 .74185 m .44103 .74282 L .43999 .74335 L F
.44128 .74549 m .48267 .81418 L .44934 .83045 L .594 .632 .859 r
F
.53034 .73139 m .48241 .81376 L .43999 .74335 L .664 .663 .839 r
F
.43999 .74335 m .44934 .83045 L .37545 .77653 L .594 .632 .859 r
F
.44103 .74282 m .44128 .74549 L .43999 .74335 L F
.44128 .74549 m .44934 .83045 L .43999 .74335 L F
.43999 .74335 m .48204 .81441 L .43938 .74483 L .664 .663 .839 r
F
.43999 .74335 m .43938 .74483 L .43858 .74354 L F
.40291 .65781 m .43858 .74354 L .40091 .65809 L .665 .6 .773 r
F
.43959 .74242 m .43858 .74354 L .40291 .65781 L F
.40398 .65863 m .40372 .65969 L .40291 .65781 L .563 .547 .795 r
F
.40437 .65701 m .40398 .65863 L .40291 .65781 L F
.37708 .56474 m .40437 .65701 L .40291 .65781 L .525 .461 .726 r
F
.37708 .56474 m .40291 .65781 L .37583 .56751 L F
.37708 .56474 m .37583 .56751 L .37531 .56578 L F
.37659 .57006 m .40091 .65809 L .37419 .57049 L .658 .541 .71 r
F
.40256 .65665 m .40091 .65809 L .37659 .57006 L F
.37531 .56578 m .37419 .57049 L .37286 .56614 L F
.35985 .47631 m .37286 .56614 L .35716 .47673 L .645 .478 .642 r
F
.37509 .56452 m .37286 .56614 L .35985 .47631 L F
.3605 .4772 m .36011 .47783 L .35985 .47631 L .476 .362 .644 r
F
.36179 .4751 m .3605 .4772 L .35985 .47631 L F
.35923 .47547 m .35985 .47631 L .35716 .47673 L .623 .399 .557 r
F
.53377 .31021 m .53424 .37005 L .36081 .39846 L .582 .287 .433 r
F
.58984 .37887 m .67479 .37749 L .60207 .35382 L .581 .617 .853 r
F
.60207 .35382 m .66051 .32621 L .59388 .32768 L .53 .637 .901 r
F
.60207 .35382 m .67479 .37749 L .66051 .32621 L F
.59388 .32768 m .60751 .28612 L .56677 .30772 L .496 .689 .954 r
F
.59388 .32768 m .66051 .32621 L .60751 .28612 L F
.69992 .34373 m .53684 .37055 L .53377 .31021 L .759 .431 .431 r
F
.53684 .37055 m .53476 .37015 L .53377 .31021 L F
.59295 .45574 m .59501 .45736 L .56153 .39606 L .679 .642 .806 r
F
.56153 .39606 m .64926 .42536 L .58984 .37887 L .633 .621 .821 r
F
.5618 .39656 m .64926 .42536 L .56153 .39606 L F
.5618 .39656 m .5939 .45753 L .64926 .42536 L F
.58984 .37887 m .64926 .42536 L .67479 .37749 L .581 .617 .853 r
F
.70757 .40394 m .53413 .44896 L .53424 .37005 L .77 .52 .556 r
F
.53477 .37089 m .53424 .37005 L .53377 .31021 L .759 .431 .431 r
F
.7082 .40406 m .53413 .44896 L .70757 .40394 L .77 .52 .556 r
F
.69992 .34373 m .7107 .40455 L .53684 .37055 L .759 .431 .431 r
F
.5939 .45753 m .7007 .48147 L .64926 .42536 L .607 .558 .774 r
F
.71074 .40341 m .70829 .48158 L .53413 .44896 L .77 .52 .556 r
F
.53684 .37055 m .71087 .4055 L .53425 .37098 L .759 .431 .431 r
F
.7107 .40455 m .71087 .4055 L .53684 .37055 L F
.71022 .40354 m .7082 .40406 L .7101 .40328 L .77 .52 .556 r
F
.7082 .40406 m .70757 .40394 L .7101 .40328 L F
.7101 .40328 m .70757 .40394 L .53424 .37005 L F
.53684 .37055 m .53477 .37089 L .53476 .37015 L .759 .431 .431 r
F
.53477 .37089 m .53425 .37098 L .53424 .37005 L F
.53371 .3692 m .53424 .37005 L .53161 .37048 L .623 .399 .557 r
F
.53424 .36887 m .53424 .37005 L .53371 .3692 L F
.53424 .37005 m .53413 .44896 L .53161 .37048 L F
.36081 .39846 m .53424 .37005 L .35815 .39981 L .582 .287 .433 r
F
.53424 .37005 m .53425 .37098 L .53358 .37109 L F
.53424 .37005 m .53358 .37109 L .35815 .39981 L F
.53491 .369 m .53424 .37005 L .53424 .36887 L .77 .52 .556 r
F
.7101 .40328 m .53424 .37005 L .53491 .369 L F
.36738 .33921 m .35763 .39898 L .23734 .47798 L .275 .027 .344 r
F
.46096 .32498 m .37737 .3716 L .45044 .35079 L .767 .84 .907 r
F
.53377 .31021 m .35764 .39891 L .36752 .33831 L .582 .287 .433 r
F
.36782 .33874 m .36738 .33921 L .36752 .33831 L .275 .027 .344 r
F
.36738 .33921 m .23734 .47798 L .36752 .33831 L F
.36752 .33831 m .35761 .39893 L .36495 .33874 L .582 .287 .433 r
F
.35764 .39891 m .35761 .39893 L .36752 .33831 L F
.35763 .39898 m .357 .40024 L .23734 .47798 L .275 .027 .344 r
F
.35761 .39893 m .35554 .39559 L .36495 .33874 L .582 .287 .433 r
F
.53424 .36887 m .53161 .37048 L .35826 .39774 L .623 .399 .557 r
F
.53424 .36887 m .35826 .39774 L .35827 .39772 L F
.35764 .39891 m .35763 .39898 L .35761 .39893 L .582 .287 .433 r
F
.3576 .39783 m .35763 .39898 L .23754 .47592 L .401 .229 .529 r
F
.35761 .39893 m .35746 .39901 L .35554 .39559 L .582 .287 .433 r
F
.35746 .39901 m .35491 .39942 L .35554 .39559 L F
.3576 .39785 m .35491 .39942 L .35487 .39828 L .623 .399 .557 r
F
.36938 .33707 m .36022 .39386 L .35767 .3989 L .275 .027 .344 r
F
.36938 .33707 m .35767 .3989 L .36738 .33921 L F
.53161 .37048 m .35763 .39898 L .35826 .39774 L .623 .399 .557 r
F
.35763 .39898 m .23759 .47701 L .23754 .47592 L .401 .229 .529 r
F
.35763 .39898 m .23759 .47701 L .35763 .39898 L F
.35763 .39898 m .35504 .4041 L .35491 .39942 L .623 .399 .557 r
F
.35766 .39902 m .35985 .47631 L .35764 .39906 L .401 .229 .529 r
F
.35959 .40215 m .35985 .47631 L .35766 .39902 L F
.35763 .39898 m .35748 .39992 L .357 .40024 L .275 .027 .344 r
F
.35761 .39893 m .35815 .39981 L .35475 .40037 L .582 .287 .433 r
F
.35767 .3989 m .35748 .39992 L .35763 .39898 L .275 .027 .344 r
F
.35767 .3989 m .35763 .39898 L .36738 .33921 L F
.35826 .39774 m .35763 .39898 L .3576 .39785 L .623 .399 .557 r
F
.35763 .39898 m .35491 .39942 L .3576 .39785 L F
.36081 .39846 m .35815 .39981 L .35763 .39898 L .582 .287 .433 r
F
.35776 .39889 m .35959 .40215 L .35766 .39902 L .401 .229 .529 r
F
.35957 .39772 m .35959 .40215 L .35776 .39889 L F
.35776 .39889 m .35766 .39902 L .35763 .39898 L F
.35766 .39896 m .35945 .39864 L .35748 .39992 L .275 .027 .344 r
F
.35767 .3989 m .35778 .39888 L .35766 .39896 L F
.35778 .39888 m .35945 .39864 L .35766 .39896 L F
.36022 .39386 m .3596 .3977 L .35767 .3989 L F
.35957 .39655 m .35957 .39772 L .35784 .3988 L .401 .229 .529 r
F
.3596 .3977 m .35778 .39888 L .35767 .3989 L .275 .027 .344 r
F
.35957 .39772 m .35957 .39772 L .35784 .3988 L .401 .229 .529 r
F
.35784 .3988 m .35957 .39772 L .35776 .39889 L F
.35776 .39889 m .35763 .39898 L .35763 .39898 L F
.35746 .39901 m .35475 .40037 L .35491 .39942 L .582 .287 .433 r
F
.35957 .39655 m .35776 .39889 L .35763 .39898 L .401 .229 .529 r
F
.35957 .39655 m .35763 .39898 L .3576 .39783 L F
.3596 .3977 m .35945 .39864 L .35778 .39888 L .275 .027 .344 r
F
.35957 .39772 m .36179 .4751 L .35985 .47631 L .401 .229 .529 r
F
.35957 .39655 m .3596 .3977 L .35957 .39772 L F
.3596 .3977 m .36179 .4751 L .35957 .39772 L F
.35777 .40358 m .35716 .47673 L .35504 .4041 L .623 .399 .557 r
F
.35982 .47511 m .35716 .47673 L .35777 .40358 L F
.35827 .39772 m .35826 .39774 L .35487 .39828 L F
.23926 .47593 m .23734 .47798 L .23759 .47701 L .275 .027 .344 r
F
.36938 .33707 m .36782 .33874 L .36752 .33831 L F
.38863 .29801 m .36938 .33707 L .36752 .33831 L .013 0 0 r
F
.38863 .29801 m .36752 .33831 L .38815 .29843 L F
.41778 .27976 m .39006 .29678 L .38998 .29693 L .425 .828 .623 r
F
.38965 .29713 m .39006 .29678 L .38843 .29788 L F
.41778 .27976 m .38843 .29788 L .41724 .28012 L F
.39006 .29678 m .38923 .29839 L .38863 .29801 L .013 0 0 r
F
.38923 .29839 m .36938 .33707 L .38863 .29801 L F
.39006 .29678 m .38863 .29801 L .38843 .29788 L F
.3882 .29774 m .38619 .29827 L .38767 .2974 L .189 0 0 r
F
.41889 .27903 m .41817 .27947 L .41778 .27976 L .425 .828 .623 r
F
.41817 .27947 m .39006 .29678 L .41778 .27976 L F
.41889 .27903 m .41778 .27976 L .4176 .2799 L F
.42006 .27916 m .41889 .27903 L .4176 .2799 L .677 .961 .941 r
F
.71074 .40341 m .71022 .40354 L .7101 .40328 L .77 .52 .556 r
F
.82341 .48686 m .8218 .48679 L .71074 .40341 L .917 .653 .522 r
F
.8218 .48679 m .7107 .40455 L .71074 .40341 L F
.82341 .48686 m .81963 .56048 L .70829 .48158 L F
.71241 .40581 m .82335 .48794 L .71087 .4055 L .914 .547 .32 r
F
.84437 .58727 m .82335 .48794 L .82349 .48726 L .929 .738 .255 r
F
.82368 .48948 m .82361 .48892 L .82335 .48794 L 0 0 .22 r
F
.82335 .48794 m .82361 .48892 L .82321 .48862 L .914 .547 .32 r
F
.82335 .48794 m .82321 .48862 L .71087 .4055 L F
.82349 .48726 m .82335 .48794 L .82341 .48686 L .929 .738 .255 r
F
.82368 .48948 m .84466 .58864 L .82361 .48892 L 0 0 .22 r
F
.84466 .58864 m .84492 .58964 L .84484 .58929 L F
.84471 .58764 m .84466 .58864 L .84464 .58757 L .929 .738 .255 r
F
.84466 .58864 m .84484 .58929 L .82361 .48892 L 0 0 .22 r
F
.78326 .67588 m .77955 .7398 L .8409 .65589 L .021 0 .366 r
F
.78258 .67684 m .77955 .7398 L .78326 .67588 L F
.78062 .67795 m .66455 .73479 L .78215 .67833 L .509 .347 .597 r
F
.78062 .67795 m .78215 .67833 L .7822 .67807 L F
.66447 .73371 m .66618 .72963 L .6581 .6708 L .649 .449 .6 r
F
.65785 .6683 m .66445 .73377 L .78062 .67795 L .509 .347 .597 r
F
.66445 .73377 m .66455 .73479 L .78062 .67795 L F
.66436 .73731 m .66665 .73708 L .66445 .73377 L .629 .382 .524 r
F
.66445 .73383 m .77955 .7398 L .66445 .73377 L .454 .241 .5 r
F
.66436 .73731 m .66445 .73377 L .664 .73383 L .629 .382 .524 r
F
.53034 .73139 m .52834 .80859 L .48275 .81432 L .664 .663 .839 r
F
.48241 .81376 m .48275 .81432 L .48204 .81441 L F
.53034 .73139 m .48275 .81432 L .48241 .81376 L F
.48267 .81418 m .48275 .81432 L .44934 .83045 L .594 .632 .859 r
F
.4832 .81392 m .48275 .81432 L .48267 .81418 L F
.44103 .74282 m .4832 .81392 L .48267 .81418 L F
.44103 .74282 m .48267 .81418 L .44128 .74549 L F
.48241 .81376 m .48204 .81441 L .43999 .74335 L .664 .663 .839 r
F
.48275 .81432 m .4823 .81471 L .48204 .81441 L .648 .738 .915 r
F
.4832 .81392 m .48328 .81406 L .48275 .81432 L .594 .632 .859 r
F
.52834 .80859 m .52631 .86418 L .48275 .81432 L .648 .738 .915 r
F
.52608 .86402 m .52631 .86418 L .52607 .86415 L .586 .728 .941 r
F
.52608 .86402 m .52607 .86415 L .43716 .8528 L F
.52566 .86375 m .52608 .86402 L .43716 .8528 L F
.52606 .86355 m .52631 .86418 L .52558 .86334 L .618 .728 .924 r
F
.56753 .89176 m .52797 .86528 L .60076 .877 L .624 .836 .981 r
F
.53717 .87144 m .52631 .86418 L .5682 .89168 L .58 .821 .99 r
F
.52622 .8643 m .52631 .86418 L .53717 .87144 L F
.52565 .86427 m .52631 .86418 L .48109 .89076 L .541 .764 .98 r
F
.52583 .86399 m .52607 .86408 L .44912 .8748 L .557 .741 .962 r
F
.52789 .86355 m .52674 .86401 L .57404 .81544 L .685 .785 .926 r
F
.52583 .86412 m .52631 .86418 L .44912 .8748 L .557 .741 .962 r
F
.5272 .86451 m .52631 .86418 L .6153 .85543 L .663 .832 .964 r
F
.52593 .8641 m .52631 .86418 L .52565 .86427 L .541 .764 .98 r
F
.52552 .86464 m .52607 .86432 L .52441 .89685 L .547 .793 .99 r
F
.52656 .86392 m .52631 .86418 L .52834 .80859 L .672 .758 .916 r
F
.52834 .80859 m .52657 .86365 L .52631 .86418 L .648 .738 .915 r
F
.52575 .86412 m .52587 .86413 L .48109 .89076 L .541 .764 .98 r
F
.53711 .87155 m .53516 .87023 L .53717 .87144 L .58 .821 .99 r
F
.52441 .89685 m .53516 .87023 L .53711 .87155 L F
.44934 .83045 m .52631 .86418 L .52568 .86349 L .586 .728 .941 r
F
.52711 .86337 m .52656 .86392 L .52834 .80859 L .672 .758 .916 r
F
.52441 .89685 m .52628 .86483 L .53516 .87023 L .58 .821 .99 r
F
.52441 .89685 m .53717 .87144 L .56753 .89176 L F
.56701 .89199 m .52631 .86418 L .52691 .86515 L .624 .836 .981 r
F
.52689 .86511 m .52631 .86418 L .52797 .86528 L F
.52638 .8643 m .52631 .86418 L .5265 .86425 L .663 .832 .964 r
F
.52702 .86274 m .527 .86347 L .52631 .86418 L .648 .738 .915 r
F
.52674 .86401 m .52631 .86418 L .57404 .81544 L .685 .785 .926 r
F
.5268 .86413 m .52631 .86418 L .60587 .83279 L .684 .812 .944 r
F
.52656 .86404 m .52631 .86418 L .52656 .86392 L .672 .758 .916 r
F
.5266 .86416 m .52631 .86418 L .52674 .86401 L .685 .785 .926 r
F
.48328 .81406 m .52631 .86418 L .52634 .8634 L .618 .728 .924 r
F
.52568 .86349 m .52631 .86418 L .52633 .86377 L .586 .728 .941 r
F
.5271 .8637 m .527 .86376 L .527 .86374 L .672 .758 .916 r
F
.527 .86376 m .52656 .86403 L .527 .86374 L F
.527 .86374 m .52656 .86403 L .52656 .86392 L F
.5271 .8637 m .52656 .86392 L .52711 .86337 L F
.52633 .86383 m .52631 .86418 L .52566 .86375 L .586 .728 .941 r
F
.43716 .8528 m .52631 .86418 L .52599 .86382 L .557 .741 .962 r
F
.5262 .86406 m .52631 .86418 L .52583 .86412 L F
.52609 .86384 m .52609 .8639 L .44912 .8748 L F
.52809 .86484 m .52631 .86418 L .52629 .86453 L .663 .832 .964 r
F
.6153 .85543 m .52631 .86418 L .52697 .86446 L .684 .812 .944 r
F
.52574 .86395 m .52583 .86399 L .44912 .8748 L .557 .741 .962 r
F
.44912 .8748 m .52631 .86418 L .52514 .86403 L .541 .764 .98 r
F
.52387 .86421 m .52565 .86419 L .48109 .89076 L F
.52449 .86477 m .52631 .86418 L .52563 .86409 L .547 .793 .99 r
F
.52554 .86425 m .52607 .86432 L .52552 .86464 L F
.52563 .8644 m .52631 .86418 L .52564 .86433 L .58 .821 .99 r
F
.48109 .89076 m .52631 .86418 L .52449 .86477 L .547 .793 .99 r
F
.52607 .86426 m .52631 .86418 L .52607 .86432 L F
.52441 .89685 m .52631 .86418 L .52563 .8644 L .58 .821 .99 r
F
.52579 .8644 m .52622 .8643 L .52603 .86456 L F
.52579 .8644 m .52603 .86456 L .52596 .86464 L F
.52563 .86444 m .52579 .8644 L .52596 .86464 L F
.52607 .86421 m .52631 .86418 L .52622 .8643 L F
.52596 .86464 m .52622 .8643 L .5263 .86436 L F
.52596 .86464 m .5263 .86436 L .52628 .86483 L F
.52563 .86444 m .52613 .86425 L .52622 .8643 L F
.52691 .86515 m .52631 .86418 L .52564 .8643 L .624 .836 .981 r
F
.52689 .86511 m .52628 .86471 L .52631 .86418 L F
.52629 .86453 m .52631 .86418 L .52629 .86453 L .663 .832 .964 r
F
.52441 .89685 m .52563 .86444 L .52628 .86483 L .58 .821 .99 r
F
.52653 .86457 m .52638 .8643 L .5272 .86451 L .663 .832 .964 r
F
.52633 .86387 m .52608 .86393 L .52613 .8639 L .557 .741 .962 r
F
.52608 .86393 m .52583 .86399 L .52613 .8639 L F
.52613 .8639 m .52583 .86399 L .52574 .86395 L F
.52387 .86421 m .52615 .86388 L .52565 .86419 L .541 .764 .98 r
F
.48109 .89076 m .52554 .86415 L .52552 .86464 L .547 .793 .99 r
F
.48109 .89076 m .52552 .86464 L .52441 .89685 L F
.52552 .86461 m .52553 .86449 L .52512 .86465 L .684 .812 .944 r
F
.52628 .86471 m .52605 .86456 L .52631 .86418 L .624 .836 .981 r
F
.52629 .86453 m .52614 .86446 L .52611 .8645 L .663 .832 .964 r
F
.52565 .86418 m .52607 .86432 L .52554 .86425 L .547 .793 .99 r
F
.52565 .86418 m .52607 .86417 L .52607 .86432 L F
.52631 .86418 m .52573 .86425 L .52564 .86433 L .58 .821 .99 r
F
.52554 .86415 m .52565 .86418 L .52554 .86425 L .547 .793 .99 r
F
.52554 .86415 m .5257 .86415 L .52565 .86418 L F
.5257 .86415 m .52607 .86417 L .52565 .86418 L F
.52514 .86403 m .52631 .86418 L .52599 .86391 L .541 .764 .98 r
F
.52615 .86388 m .52587 .86413 L .52575 .86412 L F
.52563 .86409 m .52631 .86418 L .52574 .86403 L .547 .793 .99 r
F
.52563 .86444 m .52565 .86393 L .52613 .86425 L .58 .821 .99 r
F
.52605 .86456 m .52541 .86414 L .52631 .86418 L .624 .836 .981 r
F
.57404 .81544 m .52631 .86418 L .52814 .86307 L .672 .758 .916 r
F
.52834 .80859 m .52631 .86418 L .527 .86376 L .648 .738 .915 r
F
.52634 .8634 m .52631 .86418 L .52659 .86368 L .618 .728 .924 r
F
.52672 .86383 m .52631 .86418 L .52606 .86355 L F
.52633 .86377 m .52631 .86418 L .52634 .86377 L .586 .728 .941 r
F
.52633 .86387 m .52633 .86392 L .52583 .86399 L .557 .741 .962 r
F
.52599 .86382 m .52631 .86418 L .52615 .86385 L F
.52652 .86389 m .52607 .86408 L .52583 .86399 L F
.52615 .86388 m .52619 .86395 L .52587 .86413 L .541 .764 .98 r
F
.52554 .86415 m .52609 .86382 L .52607 .86417 L .547 .793 .99 r
F
.52541 .86414 m .52516 .86398 L .52631 .86418 L .624 .836 .981 r
F
.52574 .86403 m .52631 .86418 L .52583 .86397 L .547 .793 .99 r
F
.52651 .86385 m .52631 .86418 L .52633 .86383 L .586 .728 .941 r
F
.52633 .86367 m .52631 .86418 L .52634 .86366 L .547 .793 .99 r
F
.52631 .86418 m .52569 .86424 L .52629 .86453 L .663 .832 .964 r
F
.56677 .89183 m .52564 .8643 L .56753 .89176 L .624 .836 .981 r
F
.52564 .8643 m .52564 .8643 L .56753 .89176 L F
.52653 .86457 m .52496 .86431 L .52631 .86418 L .663 .832 .964 r
F
.52614 .86446 m .52516 .86398 L .52611 .8645 L F
.52645 .86442 m .52582 .86437 L .52567 .86443 L .684 .812 .944 r
F
.52564 .8643 m .52516 .86398 L .52564 .8643 L .624 .836 .981 r
F
.52611 .8645 m .52516 .86398 L .52496 .86431 L .663 .832 .964 r
F
.52645 .86442 m .52567 .86443 L .52553 .86449 L .684 .812 .944 r
F
.52697 .86446 m .52645 .86442 L .52553 .86449 L F
.52631 .86418 m .52496 .86431 L .52582 .86437 L F
.52638 .8643 m .5265 .86425 L .5272 .86451 L .663 .832 .964 r
F
.52631 .86418 m .52582 .86437 L .52697 .86446 L .684 .812 .944 r
F
.52697 .86446 m .52591 .86457 L .52659 .8643 L F
.52657 .86443 m .52657 .86443 L .52686 .8644 L .685 .785 .926 r
F
.5263 .86446 m .52657 .86443 L .52657 .86443 L F
.5263 .86446 m .5263 .86446 L .52657 .86443 L F
.52689 .86436 m .5263 .86446 L .52686 .8644 L F
.52621 .86436 m .52631 .86418 L .52643 .86428 L .684 .812 .944 r
F
.52562 .8646 m .52631 .86418 L .52621 .86436 L F
.52641 .86437 m .52637 .8643 L .52664 .86419 L F
.5263 .86441 m .52631 .86433 L .52637 .8643 L F
.5263 .86441 m .52637 .8643 L .52641 .86437 L F
.52591 .86457 m .52606 .86442 L .52631 .86433 L F
.52591 .86457 m .52631 .86433 L .5263 .86441 L F
.52591 .86457 m .52562 .8646 L .52606 .86442 L F
.52562 .8646 m .52512 .86465 L .52631 .86418 L F
.52631 .86418 m .52512 .86465 L .52697 .86435 L .685 .785 .926 r
F
.52643 .86428 m .52631 .86418 L .5268 .86413 L .684 .812 .944 r
F
.52645 .86431 m .52631 .86418 L .5266 .86416 L .685 .785 .926 r
F
.52683 .8642 m .52664 .86419 L .60587 .83279 L .684 .812 .944 r
F
.52641 .86437 m .52664 .86419 L .52683 .8642 L F
.52697 .86446 m .52659 .8643 L .60587 .83279 L F
.52722 .86425 m .52656 .8642 L .52674 .86401 L .685 .785 .926 r
F
.52722 .86425 m .52605 .86472 L .52656 .8642 L F
.60076 .877 m .52653 .86457 L .6153 .85543 L .663 .832 .964 r
F
.52723 .86402 m .52631 .86418 L .52628 .865 L .672 .758 .916 r
F
.60587 .83279 m .52631 .86418 L .52697 .86435 L .685 .785 .926 r
F
.52722 .86425 m .52674 .86401 L .52789 .86355 L F
.52814 .86307 m .52631 .86418 L .52723 .86402 L .672 .758 .916 r
F
.52656 .86413 m .52631 .86418 L .52656 .86408 L F
.52656 .86408 m .52631 .86418 L .52656 .86404 L F
.52709 .8639 m .52656 .86403 L .5271 .8637 L F
.527 .86376 m .52631 .86418 L .527 .8638 L .648 .738 .915 r
F
.52709 .8639 m .52656 .86409 L .52656 .86403 L .672 .758 .916 r
F
.52709 .86416 m .52656 .86409 L .52709 .8639 L F
.527 .86351 m .52699 .8641 L .52631 .86418 L .648 .738 .915 r
F
.52709 .86416 m .52655 .86417 L .52656 .86409 L .672 .758 .916 r
F
.527 .8638 m .52631 .86418 L .52698 .86431 L .648 .738 .915 r
F
.52659 .86368 m .52631 .86418 L .52709 .86425 L .618 .728 .924 r
F
.6153 .85543 m .52697 .86446 L .60587 .83279 L .684 .812 .944 r
F
.60587 .83279 m .52722 .86425 L .57404 .81544 L .685 .785 .926 r
F
.57404 .81544 m .52709 .86416 L .52834 .80859 L .672 .758 .916 r
F
.52615 .86385 m .52767 .86435 L .52751 .86401 L .557 .741 .962 r
F
.52697 .86435 m .52689 .86436 L .52686 .8644 L .685 .785 .926 r
F
.52655 .86443 m .52631 .86418 L .52656 .86413 L .672 .758 .916 r
F
.52709 .86416 m .52654 .86473 L .52655 .86417 L F
.52699 .8641 m .52697 .86491 L .52631 .86418 L .648 .738 .915 r
F
.52698 .86431 m .52631 .86418 L .52698 .86462 L F
.52672 .86383 m .52747 .86468 L .52631 .86418 L .618 .728 .924 r
F
.52634 .86377 m .52631 .86418 L .52767 .86435 L .586 .728 .941 r
F
.52651 .86385 m .52767 .86435 L .52631 .86418 L F
.52701 .86395 m .52631 .86418 L .5262 .86406 L .557 .741 .962 r
F
.52652 .86389 m .52701 .86395 L .52641 .86403 L F
.52701 .86395 m .52751 .86401 L .52631 .86418 L F
.52631 .86418 m .52751 .86401 L .52649 .86394 L .541 .764 .98 r
F
.52631 .86418 m .52767 .86435 L .52615 .86385 L .557 .741 .962 r
F
.52652 .86389 m .52641 .86403 L .52607 .86408 L F
.52631 .86418 m .52649 .86394 L .52599 .86391 L .541 .764 .98 r
F
.52609 .86384 m .52633 .86387 L .52609 .8639 L .557 .741 .962 r
F
.52634 .86386 m .52631 .86418 L .52593 .8641 L .541 .764 .98 r
F
.52615 .86388 m .52634 .86386 L .52619 .86395 L F
.52583 .86397 m .52631 .86418 L .52633 .86367 L .547 .793 .99 r
F
.52633 .86387 m .52652 .86389 L .52633 .86392 L .557 .741 .962 r
F
.52599 .86391 m .52751 .86401 L .52702 .86376 L .541 .764 .98 r
F
.52609 .86382 m .52634 .86366 L .52631 .86418 L .547 .793 .99 r
F
.52631 .86418 m .52633 .86368 L .52601 .86398 L .58 .821 .99 r
F
.52631 .86418 m .52634 .86366 L .52633 .86368 L F
.52609 .86382 m .52631 .86418 L .52607 .86426 L .547 .793 .99 r
F
.52631 .86418 m .52601 .86398 L .52573 .86425 L .58 .821 .99 r
F
.52564 .8643 m .52631 .86418 L .5254 .86414 L .624 .836 .981 r
F
.52631 .86418 m .5255 .86414 L .52569 .86424 L .663 .832 .964 r
F
.43716 .8528 m .52609 .86384 L .44912 .8748 L .557 .741 .962 r
F
.52564 .86433 m .52601 .86398 L .52566 .86375 L .58 .821 .99 r
F
.52631 .86418 m .52568 .86374 L .52567 .86375 L .624 .836 .981 r
F
.52601 .86398 m .52634 .86366 L .52567 .86375 L .58 .821 .99 r
F
.52601 .86398 m .52567 .86375 L .52566 .86375 L F
.52565 .86393 m .52631 .86418 L .52607 .86421 L F
.52565 .86393 m .52566 .86375 L .52631 .86418 L F
.52631 .86418 m .52567 .86375 L .5254 .86414 L .624 .836 .981 r
F
.52631 .86418 m .52516 .86398 L .5255 .86414 L .663 .832 .964 r
F
.52697 .86446 m .52553 .86449 L .52552 .86461 L .684 .812 .944 r
F
.52582 .86437 m .52496 .86431 L .52512 .86465 L F
.5263 .86446 m .5263 .86446 L .5263 .86446 L .685 .785 .926 r
F
.52686 .8644 m .5263 .86446 L .52561 .8649 L F
.5263 .86446 m .52566 .86456 L .52562 .86483 L F
.5263 .86446 m .52562 .86483 L .52561 .8649 L F
.52605 .86472 m .52631 .86418 L .52645 .86431 L F
.52605 .86472 m .52561 .8649 L .52631 .86418 L F
.52631 .86418 m .52561 .8649 L .52628 .865 L .672 .758 .916 r
F
.52566 .86456 m .52512 .86465 L .52533 .86476 L .685 .785 .926 r
F
.52566 .86456 m .52533 .86476 L .52561 .8649 L F
.527 .86347 m .527 .86351 L .52631 .86418 L .648 .738 .915 r
F
.52634 .86386 m .52702 .86376 L .52631 .86418 L .541 .764 .98 r
F
.52631 .86418 m .52702 .86376 L .52634 .86366 L .547 .793 .99 r
F
.52709 .86425 m .52695 .86492 L .52747 .86468 L .618 .728 .924 r
F
.52631 .86418 m .52695 .86492 L .52709 .86425 L F
.44912 .8748 m .52387 .86421 L .48109 .89076 L .541 .764 .98 r
F
.52654 .86473 m .52631 .86418 L .52655 .86443 L .672 .758 .916 r
F
.5254 .86414 m .52568 .86374 L .52516 .86398 L .624 .836 .981 r
F
.52631 .86418 m .52747 .86468 L .52767 .86435 L .586 .728 .941 r
F
.52834 .80859 m .52702 .86274 L .52657 .86365 L .648 .738 .915 r
F
.56753 .89176 m .52689 .86511 L .52797 .86528 L .624 .836 .981 r
F
.48328 .81406 m .52572 .86268 L .52558 .86334 L .618 .728 .924 r
F
.52572 .86268 m .52672 .86383 L .52606 .86355 L F
.52572 .86268 m .52606 .86355 L .52558 .86334 L F
.48328 .81406 m .52558 .86334 L .48275 .81432 L F
.52654 .86473 m .52628 .865 L .52631 .86418 L .672 .758 .916 r
F
.56753 .89176 m .53717 .87144 L .5682 .89168 L .58 .821 .99 r
F
.52698 .86462 m .52628 .865 L .52697 .86491 L .648 .738 .915 r
F
.52631 .86418 m .52628 .865 L .52698 .86462 L F
.44934 .83045 m .52453 .86299 L .43716 .8528 L .586 .728 .941 r
F
.52453 .86299 m .52651 .86385 L .52566 .86375 L F
.52453 .86299 m .52566 .86375 L .43716 .8528 L F
.56701 .89199 m .56677 .89183 L .56753 .89176 L .624 .836 .981 r
F
.60286 .89651 m .56701 .89199 L .56753 .89176 L .542 .913 .949 r
F
.60286 .89651 m .56753 .89176 L .60282 .89616 L F
.60288 .89672 m .60226 .89664 L .60286 .89651 L F
.60226 .89664 m .56701 .89199 L .60286 .89651 L F
.60386 .89629 m .6045 .89606 L .60514 .89614 L .292 .782 .894 r
F
.60322 .89652 m .60288 .89672 L .60386 .89629 L 0 0 0 r
F
.60288 .89672 m .60286 .89651 L .60386 .89629 L .542 .913 .949 r
F
.66278 .79447 m .65237 .84372 L .75925 .79591 L .361 .075 .336 r
F
.66445 .73377 m .77955 .7398 L .78241 .67709 L .454 .241 .5 r
F
.66445 .73383 m .66296 .79363 L .77955 .7398 L F
.64329 .59736 m .65775 .66731 L .76954 .61111 L .548 .428 .669 r
F
.64329 .59736 m .76954 .61111 L .64309 .59638 L F
.62174 .52628 m .64208 .59307 L .74157 .54442 L .579 .496 .725 r
F
.26273 .73154 m .38779 .84054 L .37612 .79006 L .865 .483 .319 r
F
.66051 .32621 m .64528 .28373 L .60751 .28612 L .222 .569 .939 r
F
.66051 .32621 m .72109 .342 L .64528 .28373 L F
.28397 .7886 m .40963 .8766 L .38779 .84054 L .763 .255 0 r
F
.26273 .73154 m .28397 .7886 L .38779 .84054 L .865 .483 .319 r
F
.77955 .7398 m .8144 .72193 L .8409 .65589 L 0 0 0 r
F
.77955 .7398 m .75925 .79591 L .8144 .72193 L F
.20962 .64523 m .28397 .7886 L .26273 .73154 L .819 .433 0 r
F
.60751 .28612 m .64528 .28373 L .53139 .26017 L .15 .65 .91 r
F
.72109 .342 m .67712 .30269 L .64528 .28373 L 0 .209 .666 r
F
.72109 .342 m .77127 .37526 L .67712 .30269 L F
.75925 .79591 m .7658 .78052 L .8144 .72193 L .617 .863 .508 r
F
.75925 .79591 m .72156 .84015 L .7658 .78052 L F
.40963 .8766 m .44117 .89441 L .52275 .9058 L .439 0 0 r
F
.32335 .83421 m .44117 .89441 L .40963 .8766 L .368 0 0 r
F
.28397 .7886 m .32335 .83421 L .40963 .8766 L .763 .255 0 r
F
.20962 .64523 m .23647 .71258 L .28397 .7886 L .819 .433 0 r
F
.23647 .71258 m .32335 .83421 L .28397 .7886 L 0 .016 .571 r
F
.77127 .37526 m .69992 .34373 L .67712 .30269 L .785 .287 0 r
F
.77127 .37526 m .80673 .42505 L .69992 .34373 L F
.64528 .28373 m .53277 .27301 L .53139 .26017 L .452 0 0 r
F
.64528 .28373 m .67712 .30269 L .53277 .27301 L F
.44117 .89441 m .52441 .89685 L .52275 .9058 L .159 .671 .898 r
F
.72156 .84015 m .69782 .8265 L .7658 .78052 L .756 .995 .846 r
F
.72156 .84015 m .66776 .86834 L .69782 .8265 L F
.8409 .65589 m .79357 .6386 L .81963 .56048 L .991 .887 .581 r
F
.8409 .65589 m .8144 .72193 L .79357 .6386 L F
.32335 .83421 m .37944 .86413 L .44117 .89441 L .368 0 0 r
F
.2856 .77305 m .37944 .86413 L .32335 .83421 L .062 .403 .857 r
F
.23647 .71258 m .2856 .77305 L .32335 .83421 L 0 .016 .571 r
F
.44117 .89441 m .48109 .89076 L .52441 .89685 L .159 .671 .898 r
F
.37944 .86413 m .48109 .89076 L .44117 .89441 L .216 .634 .954 r
F
.24123 .55013 m .23647 .71258 L .20962 .64523 L .065 .112 .601 r
F
.8144 .72193 m .74647 .71452 L .79357 .6386 L .946 .914 .753 r
F
.8144 .72193 m .7658 .78052 L .74647 .71452 L F
.66776 .86834 m .6153 .85543 L .69782 .8265 L .733 .935 .954 r
F
.66776 .86834 m .60076 .877 L .6153 .85543 L F
.67712 .30269 m .53377 .31021 L .53277 .27301 L .702 .257 .193 r
F
.67712 .30269 m .69992 .34373 L .53377 .31021 L F
.2667 .62961 m .2856 .77305 L .23647 .71258 L .261 .337 .753 r
F
.24123 .55013 m .2667 .62961 L .23647 .71258 L .065 .112 .601 r
F
.37944 .86413 m .44912 .8748 L .48109 .89076 L .216 .634 .954 r
F
.35418 .82132 m .44912 .8748 L .37944 .86413 L .367 .621 .95 r
F
.2856 .77305 m .35418 .82132 L .37944 .86413 L .062 .403 .857 r
F
.7658 .78052 m .68198 .78129 L .74647 .71452 L .872 .898 .848 r
F
.7658 .78052 m .69782 .8265 L .68198 .78129 L F
.31267 .70747 m .35418 .82132 L .2856 .77305 L .396 .494 .842 r
F
.2667 .62961 m .31267 .70747 L .2856 .77305 L .261 .337 .753 r
F
.35418 .82132 m .43716 .8528 L .44912 .8748 L .367 .621 .95 r
F
.69782 .8265 m .60587 .83279 L .68198 .78129 L .786 .863 .906 r
F
.69782 .8265 m .6153 .85543 L .60587 .83279 L F
.81963 .56048 m .69143 .57032 L .70829 .48158 L .893 .708 .644 r
F
.81963 .56048 m .79357 .6386 L .69143 .57032 L F
.37545 .77653 m .43716 .8528 L .35418 .82132 L .499 .618 .901 r
F
.31267 .70747 m .37545 .77653 L .35418 .82132 L .396 .494 .842 r
F
.37545 .77653 m .44934 .83045 L .43716 .8528 L .499 .618 .901 r
F
.79357 .6386 m .66132 .66132 L .69143 .57032 L .861 .741 .729 r
F
.79357 .6386 m .74647 .71452 L .66132 .66132 L F
.68198 .78129 m .60587 .83279 L .57404 .81544 L .767 .779 .863 r
F
.74647 .71452 m .62082 .74567 L .66132 .66132 L .82 .763 .799 r
F
.74647 .71452 m .68198 .78129 L .62082 .74567 L F
.68198 .78129 m .57404 .81544 L .62082 .74567 L .767 .779 .863 r
F
.62082 .74567 m .57404 .81544 L .52834 .80859 L .722 .712 .84 r
F
.62082 .74567 m .52834 .80859 L .53034 .73139 L F
.70829 .48158 m .5334 .54226 L .53413 .44896 L .769 .58 .642 r
F
.70829 .48158 m .69143 .57032 L .5334 .54226 L F
.66132 .66132 m .62082 .74567 L .53034 .73139 L .747 .669 .774 r
F
.69143 .57032 m .53209 .63968 L .5334 .54226 L .761 .626 .711 r
F
.69143 .57032 m .66132 .66132 L .53209 .63968 L F
.66132 .66132 m .53034 .73139 L .53209 .63968 L .747 .669 .774 r
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.439688 0.494527 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.718515 2.55185 -2.22045e-16 2.55185 [
[.5 2.52052 -28.2812 0 ]
[.5 2.52052 28.2812 12.1875 ]
[ 0 0 0 0 ]
[ 1 2.50802 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 2.52052 -89.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BeamSplitter) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2.50802 L
0 2.50802 L
closepath
clip
newpath
.74331 1.16389 m .82569 1.11427 L .88641 1.31329 L .966 .687 .452 r
F
.68943 1.0325 m .82569 1.11427 L .74331 1.16389 L F
.68943 1.0325 m .74833 .924 L .82569 1.11427 L F
0 g
.5 Mabswid
[ ] 0 setdash
.82569 1.11427 m
.82597 1.11418 L
s
.74861 .9239 m
.82597 1.11418 L
s
.78532 1.30183 m .88641 1.31329 L .92769 1.51207 L .966 .687 .452 r
F
.74331 1.16389 m .88641 1.31329 L .78532 1.30183 L F
0 g
.82569 1.11427 m
.88641 1.31329 L
s
.82597 1.11418 m
.88669 1.3132 L
s
.88641 1.31329 m
.88669 1.3132 L
s
.62635 .91471 m .74833 .924 L .68943 1.0325 L .966 .687 .452 r
F
.62635 .91471 m .65758 .75142 L .74833 .924 L F
0 g
.74833 .924 m
.82569 1.11427 L
s
.74833 .924 m
.74861 .9239 L
s
.65786 .75132 m
.74861 .9239 L
s
.81321 1.43911 m .92769 1.51207 L .94707 1.70132 L .966 .687 .452 r
F
.78532 1.30183 m .92769 1.51207 L .81321 1.43911 L F
0 g
.88641 1.31329 m
.92769 1.51207 L
s
.88669 1.3132 m
.92797 1.51198 L
s
.92769 1.51207 m
.92797 1.51198 L
s
.55726 .81736 m .65758 .75142 L .62635 .91471 L .966 .687 .452 r
F
.55726 .81736 m .55727 .60566 L .65758 .75142 L F
0 g
.65758 .75142 m
.74833 .924 L
s
.65758 .75142 m
.65786 .75132 L
s
.81321 1.43911 m .94707 1.70132 L .82524 1.56838 L .966 .687 .452 r
F
.82524 1.56838 m .94707 1.70132 L .94252 1.87118 L F
.82524 1.56838 m .94736 1.70123 L .94707 1.70132 L .656 .751 .92 r
F
0 g
.92769 1.51207 m
.94703 1.70087 L
s
.82524 1.56838 m .82554 1.56829 L .94736 1.70123 L .656 .751 .92 r
F
0 g
.94282 1.8711 m
.94736 1.70123 L
s
.92797 1.51198 m
.94736 1.70123 L
s
.94707 1.70132 m
.94736 1.70123 L
s
.65413 1.21762 m .74331 1.16389 L .78532 1.30183 L .966 .687 .452 r
F
.62592 1.14948 m .74331 1.16389 L .65413 1.21762 L F
.62592 1.14948 m .68943 1.0325 L .74331 1.16389 L F
.67595 1.28943 m .78532 1.30183 L .81321 1.43911 L F
.65413 1.21762 m .78532 1.30183 L .67595 1.28943 L F
.55727 .60566 m .55756 .81726 L .55726 .81736 L .544 .324 .532 r
F
.55727 .60566 m .55755 .60556 L .55756 .81726 L F
0 g
.55755 .60608 m
.65758 .75142 L
s
.55755 .60556 m
.65786 .75132 L
s
.48588 .74693 m .55727 .60566 L .55726 .81736 L .966 .687 .452 r
F
.48588 .74693 m .45204 .49608 L .55727 .60566 L F
0 g
.55727 .60566 m
.55755 .60556 L
s
.59298 1.08917 m .68943 1.0325 L .62592 1.14948 L .966 .687 .452 r
F
.59298 1.08917 m .62635 .91471 L .68943 1.0325 L F
.69007 1.36063 m .81321 1.43911 L .82524 1.56838 L F
.67595 1.28943 m .81321 1.43911 L .69007 1.36063 L F
.8202 1.68221 m .94252 1.87118 L .9126 2.01116 L F
.82524 1.56838 m .94252 1.87118 L .8202 1.68221 L F
0 g
.94252 1.87118 m
.94707 1.70132 L
s
.94252 1.87118 m
.94282 1.8711 L
s
.9129 2.01108 m
.94282 1.8711 L
s
.55726 1.04048 m .62635 .91471 L .59298 1.08917 L .966 .687 .452 r
F
.55726 1.04048 m .55726 .81736 L .62635 .91471 L F
.69007 1.36063 m .82524 1.56838 L .69556 1.42689 L F
.69556 1.42689 m .82524 1.56838 L .8202 1.68221 L F
.69556 1.42689 m .82554 1.56829 L .82524 1.56838 L .656 .751 .92 r
F
0 g
.82524 1.56838 m
.94707 1.70132 L
s
.69556 1.42689 m .69587 1.42679 L .82554 1.56829 L .656 .751 .92 r
F
0 g
.82554 1.56829 m
.94736 1.70123 L
s
.55726 .81736 m .55756 1.04038 L .55726 1.04048 L .544 .324 .532 r
F
.55726 .81736 m .55756 .81726 L .55756 1.04038 L F
0 g
.55755 .60556 m
.55756 .81726 L
s
.52093 1.00673 m .55726 .81736 L .55726 1.04048 L .966 .687 .452 r
F
.52093 1.00673 m .48588 .74693 L .55726 .81736 L F
0 g
.55726 .81736 m
.55727 .60566 L
s
.41643 .70921 m .45204 .49608 L .48588 .74693 L .966 .687 .452 r
F
0 g
.45233 .49597 m
.55755 .60556 L
s
.41643 .70921 m .34754 .43196 L .45204 .49608 L .966 .687 .452 r
F
0 g
.45204 .49608 m
.55727 .60566 L
s
.45204 .49608 m
.45233 .49597 L
s
.8202 1.68221 m .9126 2.01116 L .79759 1.77321 L .966 .687 .452 r
F
.69193 1.48404 m .8202 1.68221 L .79759 1.77321 L F
.69556 1.42689 m .8202 1.68221 L .69193 1.48404 L F
.79759 1.77321 m .9126 2.01116 L .85688 2.11035 L F
0 g
.9126 2.01116 m
.9129 2.01108 L
s
.9126 2.01116 m
.94252 1.87118 L
s
.85719 2.11027 m
.9129 2.01108 L
s
.55725 1.27598 m .65413 1.21762 L .67595 1.28943 L .966 .687 .452 r
F
.55725 1.27598 m .62592 1.14948 L .65413 1.21762 L F
.55725 1.27598 m .67595 1.28943 L .69007 1.36063 L F
.55725 1.27598 m .59298 1.08917 L .62592 1.14948 L F
.55725 1.27598 m .69007 1.36063 L .69556 1.42689 L F
.48633 .99052 m .48588 .74693 L .52093 1.00673 L F
.48633 .99052 m .41643 .70921 L .48588 .74693 L F
.55725 1.27598 m .55726 1.04048 L .59298 1.08917 L F
.55725 1.27598 m .69556 1.42689 L .69193 1.48404 L F
.55725 1.27598 m .69587 1.42679 L .69556 1.42689 L .656 .751 .92 r
F
0 g
.69556 1.42689 m
.82524 1.56838 L
s
.55725 1.27598 m .55757 1.27588 L .69587 1.42679 L .656 .751 .92 r
F
0 g
.69587 1.42679 m
.82554 1.56829 L
s
.79759 1.77321 m .85688 2.11035 L .75778 1.83439 L .966 .687 .452 r
F
.67919 1.52826 m .79759 1.77321 L .75778 1.83439 L F
.69193 1.48404 m .79759 1.77321 L .67919 1.52826 L F
.55726 1.04048 m .55757 1.27588 L .55725 1.27598 L .544 .324 .532 r
F
.55726 1.04048 m .55756 1.04038 L .55757 1.27588 L F
0 g
.55756 .81726 m
.55756 1.04038 L
s
.55725 1.27598 m .52093 1.00673 L .55726 1.04048 L .966 .687 .452 r
F
0 g
.55726 1.04048 m
.55726 .81736 L
s
.55725 1.27598 m .69193 1.48404 L .67919 1.52826 L .966 .687 .452 r
F
.35356 .70873 m .34754 .43196 L .41643 .70921 L F
.35356 .70873 m .2505 .42174 L .34754 .43196 L F
0 g
.34754 .43196 m
.45204 .49608 L
s
.34784 .43184 m
.45233 .49597 L
s
.34754 .43196 m
.34784 .43184 L
s
.55725 1.27598 m .48633 .99052 L .52093 1.00673 L .966 .687 .452 r
F
.67919 1.52826 m .75778 1.83439 L .65791 1.55627 L F
.55725 1.27598 m .67919 1.52826 L .65791 1.55627 L F
.45581 .99347 m .41643 .70921 L .48633 .99052 L F
.45581 .99347 m .35356 .70873 L .41643 .70921 L F
.75778 1.83439 m .85688 2.11035 L .77646 2.15819 L F
0 g
.85688 2.11035 m
.85719 2.11027 L
s
.85688 2.11035 m
.9126 2.01116 L
s
.77678 2.15811 m
.85719 2.11027 L
s
.75778 1.83439 m .77646 2.15819 L .7023 1.85971 L .966 .687 .452 r
F
.65791 1.55627 m .75778 1.83439 L .7023 1.85971 L F
.55725 1.27598 m .45581 .99347 L .48633 .99052 L F
.65791 1.55627 m .7023 1.85971 L .62924 1.56568 L F
.55725 1.27598 m .65791 1.55627 L .62924 1.56568 L F
.55725 1.27598 m .59492 1.55518 L .55725 1.5249 L F
.55725 1.27598 m .55757 1.5248 L .55725 1.5249 L .544 .324 .532 r
F
.55725 1.27598 m .62924 1.56568 L .59492 1.55518 L .966 .687 .452 r
F
.55725 1.27598 m .55757 1.27588 L .55757 1.5248 L .544 .324 .532 r
F
0 g
.55757 1.27632 m
.69556 1.42689 L
s
.55725 1.27598 m .43162 1.01604 L .45581 .99347 L .966 .687 .452 r
F
.55725 1.27598 m .41568 1.05726 L .43162 1.01604 L F
.55725 1.27598 m .40943 1.11468 L .41568 1.05726 L F
.55725 1.27598 m .41356 1.1844 L .40943 1.11468 L F
.55725 1.27598 m .42797 1.26132 L .41356 1.1844 L F
.55725 1.27598 m .45164 1.3396 L .42797 1.26132 L F
.55725 1.27598 m .48277 1.41318 L .45164 1.3396 L F
.55725 1.27598 m .51891 1.47649 L .48277 1.41318 L F
.55725 1.27598 m .55725 1.5249 L .51891 1.47649 L F
.40943 1.11468 m .55757 1.27588 L .55725 1.27598 L .656 .751 .92 r
F
0 g
.55725 1.27554 m
.55726 1.04048 L
s
.40943 1.11468 m .40975 1.11457 L .55757 1.27588 L .656 .751 .92 r
F
0 g
.55757 1.27588 m
.69587 1.42679 L
s
.55756 1.04038 m
.55757 1.27588 L
s
.43162 1.01604 m .35356 .70873 L .45581 .99347 L .966 .687 .452 r
F
.62924 1.56568 m .63401 1.84492 L .59492 1.55518 L F
.62924 1.56568 m .7023 1.85971 L .63401 1.84492 L F
.3021 .74809 m .2505 .42174 L .35356 .70873 L F
.43162 1.01604 m .3021 .74809 L .35356 .70873 L F
.3021 .74809 m .16854 .47175 L .2505 .42174 L F
0 g
.2505 .42174 m
.25081 .42162 L
s
.2505 .42174 m
.34754 .43196 L
s
.25081 .42162 m
.34784 .43184 L
s
.16886 .47163 m
.25081 .42162 L
s
.7023 1.85971 m .6746 2.14579 L .63401 1.84492 L .966 .687 .452 r
F
.7023 1.85971 m .77646 2.15819 L .6746 2.14579 L F
0 g
.77646 2.15819 m
.85688 2.11035 L
s
.41568 1.05726 m .3021 .74809 L .43162 1.01604 L .966 .687 .452 r
F
.59492 1.55518 m .55725 1.78844 L .55725 1.5249 L F
.59492 1.55518 m .63401 1.84492 L .55725 1.78844 L F
0 g
.77646 2.15819 m
.77678 2.15811 L
s
.67493 2.14571 m
.77678 2.15811 L
s
.40943 1.11468 m .26667 .82705 L .41568 1.05726 L .966 .687 .452 r
F
.41568 1.05726 m .26667 .82705 L .3021 .74809 L F
.55725 1.5249 m .55758 1.78834 L .55725 1.78844 L .544 .324 .532 r
F
.55725 1.5249 m .55757 1.5248 L .55758 1.78834 L F
0 g
.55757 1.27588 m
.55757 1.5248 L
s
.55725 1.5249 m .47764 1.69228 L .51891 1.47649 L .966 .687 .452 r
F
.55725 1.5249 m .55725 1.78844 L .47764 1.69228 L F
0 g
.55725 1.5249 m
.55725 1.27598 L
s
.26667 .82705 m .16854 .47175 L .3021 .74809 L .966 .687 .452 r
F
.40943 1.11468 m .25106 .94188 L .26667 .82705 L F
.41356 1.1844 m .25106 .94188 L .40943 1.11468 L F
.25106 .94188 m .40975 1.11457 L .40943 1.11468 L .656 .751 .92 r
F
0 g
.40943 1.11468 m
.55725 1.27598 L
s
.25106 .94188 m .25139 .94177 L .40975 1.11457 L .656 .751 .92 r
F
0 g
.40975 1.11457 m
.55757 1.27588 L
s
.51891 1.47649 m .40169 1.56254 L .48277 1.41318 L .966 .687 .452 r
F
.51891 1.47649 m .47764 1.69228 L .40169 1.56254 L F
.63401 1.84492 m .55724 2.06792 L .55725 1.78844 L F
.63401 1.84492 m .6746 2.14579 L .55724 2.06792 L F
0 g
.6746 2.14579 m
.77646 2.15819 L
s
.41356 1.1844 m .25761 1.085 L .25106 .94188 L .966 .687 .452 r
F
.42797 1.26132 m .25761 1.085 L .41356 1.1844 L F
.48277 1.41318 m .33606 1.40922 L .45164 1.3396 L F
.48277 1.41318 m .40169 1.56254 L .33606 1.40922 L F
.42797 1.26132 m .28663 1.2453 L .25761 1.085 L F
.45164 1.3396 m .28663 1.2453 L .42797 1.26132 L F
.45164 1.3396 m .33606 1.40922 L .28663 1.2453 L F
.26667 .82705 m .10962 .58441 L .16854 .47175 L F
0 g
.16854 .47175 m
.16886 .47163 L
s
.16854 .47175 m
.2505 .42174 L
s
.10995 .58429 m
.16886 .47163 L
s
.25106 .94188 m .10962 .58441 L .26667 .82705 L .966 .687 .452 r
F
0 g
.6746 2.14579 m
.67493 2.14571 L
s
.55725 1.78844 m .55758 2.06783 L .55724 2.06792 L .544 .324 .532 r
F
.55725 1.78844 m .55758 1.78834 L .55758 2.06783 L F
0 g
.55758 2.06783 m
.67493 2.14571 L
s
.55757 1.5248 m
.55758 1.78834 L
s
.55725 1.78844 m .4331 1.92516 L .47764 1.69228 L .966 .687 .452 r
F
.55725 1.78844 m .55724 2.06792 L .4331 1.92516 L F
0 g
.55725 1.78844 m
.55725 1.5249 L
s
.55724 2.06792 m
.6746 2.14579 L
s
.55724 2.06792 m
.55725 1.78844 L
s
.55758 1.78834 m
.55758 2.06783 L
s
.25106 .94188 m .08099 .75631 L .10962 .58441 L .966 .687 .452 r
F
0 g
.10962 .58441 m
.16854 .47175 L
s
.25761 1.085 m .08099 .75631 L .25106 .94188 L .966 .687 .452 r
F
.08099 .75631 m .25139 .94177 L .25106 .94188 L .656 .751 .92 r
F
0 g
.25106 .94188 m
.40943 1.11468 L
s
.08099 .75631 m .08133 .75619 L .25139 .94177 L .656 .751 .92 r
F
0 g
.25139 .94177 m
.40975 1.11457 L
s
.47764 1.69228 m .31311 1.72571 L .40169 1.56254 L .966 .687 .452 r
F
.47764 1.69228 m .4331 1.92516 L .31311 1.72571 L F
0 g
.10962 .58441 m
.10995 .58429 L
s
.08133 .75619 m
.10995 .58429 L
s
.25761 1.085 m .08776 .97675 L .08099 .75631 L .966 .687 .452 r
F
0 g
.08099 .75631 m
.10962 .58441 L
s
.08099 .75631 m
.25106 .94188 L
s
.08133 .75619 m
.25139 .94177 L
s
.28663 1.2453 m .08776 .97675 L .25761 1.085 L .966 .687 .452 r
F
.40169 1.56254 m .20903 1.48575 L .33606 1.40922 L F
.40169 1.56254 m .31311 1.72571 L .20903 1.48575 L F
0 g
.55724 2.06792 m
.55758 2.06783 L
s
.4331 1.92516 m
.55724 2.06792 L
s
.43344 1.92506 m
.55758 2.06783 L
s
.28663 1.2453 m .13144 1.22771 L .08776 .97675 L .966 .687 .452 r
F
.33606 1.40922 m .13144 1.22771 L .28663 1.2453 L F
.33606 1.40922 m .20903 1.48575 L .13144 1.22771 L F
0 g
.08099 .75631 m
.08133 .75619 L
s
.08099 .75631 m
.08776 .97675 L
s
.08133 .75619 m
.0881 .97663 L
s
.31311 1.72571 m
.4331 1.92516 L
s
.4331 1.92516 m
.43344 1.92506 L
s
.31346 1.72561 m
.43344 1.92506 L
s
.08776 .97675 m
.0881 .97663 L
s
.08776 .97675 m
.13144 1.22771 L
s
.0881 .97663 m
.13179 1.22759 L
s
.20903 1.48575 m
.31311 1.72571 L
s
.31311 1.72571 m
.31346 1.72561 L
s
.20938 1.48564 m
.31346 1.72561 L
s
.13144 1.22771 m
.13179 1.22759 L
s
.13144 1.22771 m
.20903 1.48575 L
s
.13179 1.22759 m
.20938 1.48564 L
s
.20903 1.48575 m
.20938 1.48564 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.439688 0.614943 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-16 1.16608 [
[.5 1.098 -38.7812 0 ]
[.5 1.098 38.7812 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -99.7812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BeamSplitterCube) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.42216 .58164 m
.40598 1.06315 L
s
.66497 .02988 m
.42216 .58164 L
s
.42216 .58164 m
.91022 .42206 L
s
.10855 .26104 m
.42216 .58164 L
s
.91022 .42206 m
.66497 .02988 L
s
.97657 .93008 m
.91022 .42206 L
s
.40598 1.06315 m
.6952 .58531 L
s
.40598 1.06315 m
.02877 .79167 L
s
.97657 .93008 m
.40598 1.06315 L
s
.66497 .02988 m
.10855 .26104 L
s
.02877 .79167 m
.10855 .26104 L
s
.6952 .58531 m
.97657 .93008 L
s
.6952 .58531 m
.66497 .02988 L
s
.02877 .79167 m
.6952 .58531 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.439688 0.735359 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.320254 1.73469 -2.22045e-16 1.73469 [
[.5 1.68639 -33.8438 0 ]
[.5 1.68639 33.8438 12 ]
[ 0 0 0 0 ]
[ 1 1.67389 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.68639 -94.8438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BiConcaveLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.67389 L
0 1.67389 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60603 .93596 m
.56897 .81388 L
s
.56897 .81388 m
.86428 .71784 L
s
.56897 .81388 m
.5206 .69754 L
s
.63003 1.05822 m
.60603 .93596 L
s
.60603 .93596 m
.90289 .84375 L
s
.5206 .69754 m
.81632 .59707 L
s
.5206 .69754 m
.46293 .59246 L
s
.63003 1.05822 m
.93041 .96915 L
s
.61532 1.07857 m .94524 1.08823 L .63952 1.17491 L .656 .751 .92 r
F
0 g
.6333 1.27995 m
.63952 1.17491 L
s
.63003 1.05822 m
.63173 1.07905 L
s
.86428 .71784 m
.90289 .84375 L
s
.81632 .59707 m
.86428 .71784 L
s
.90289 .84375 m
.93041 .96915 L
s
.76104 .48706 m
.81632 .59707 L
s
.39841 .50423 m .64716 .54651 L .44917 .6161 L .544 .324 .532 r
F
.39841 .50423 m .70078 .39358 L .64716 .54651 L F
0 g
.65484 .52461 m
.76104 .48706 L
s
.39841 .50423 m
.70078 .39358 L
s
.32999 .43858 m
.39841 .50423 L
s
.61064 1.36685 m
.6333 1.27995 L
s
.6333 1.27995 m
.94603 1.19479 L
s
.70078 .39358 m
.76104 .48706 L
s
.61532 1.07857 m .81483 1.01975 L .94524 1.08823 L .656 .751 .92 r
F
0 g
.94524 1.08823 m
.94603 1.19479 L
s
.93041 .96915 m
.94524 1.08823 L
s
.63952 1.17491 m
.94524 1.08823 L
s
.56504 .98227 m .81483 1.01975 L .61532 1.07857 L .656 .751 .92 r
F
0 g
.61532 1.07857 m
.63952 1.17491 L
s
.32999 .43858 m
.63835 .32259 L
s
.32999 .43858 m
.26131 .4011 L
s
.44917 .6161 m .61603 .69748 L .47917 .7435 L .544 .324 .532 r
F
.44917 .6161 m .64716 .54651 L .61603 .69748 L F
0 g
.39841 .50423 m
.44917 .6161 L
s
.64716 .54651 m
.70078 .39358 L
s
.63835 .32259 m
.70078 .39358 L
s
.57147 1.42889 m
.61064 1.36685 L
s
.61064 1.36685 m
.93171 1.28223 L
s
.94603 1.19479 m
.93171 1.28223 L
s
.56504 .98227 m .70245 .94009 L .81483 1.01975 L .656 .751 .92 r
F
0 g
.81483 1.01975 m
.94524 1.08823 L
s
.48831 .88616 m .70245 .94009 L .56504 .98227 L .656 .751 .92 r
F
0 g
.56504 .98227 m
.61532 1.07857 L
s
.26131 .4011 m
.57716 .28003 L
s
.26131 .4011 m
.19672 .39685 L
s
.57716 .28003 m
.63835 .32259 L
s
.47917 .7435 m .60663 .84828 L .48831 .88616 L .544 .324 .532 r
F
.47917 .7435 m .61603 .69748 L .60663 .84828 L F
0 g
.44917 .6161 m
.47917 .7435 L
s
.61603 .69748 m
.64716 .54651 L
s
.51676 1.45957 m
.57147 1.42889 L
s
.57147 1.42889 m
.90182 1.3437 L
s
.93171 1.28223 m
.90182 1.3437 L
s
.48831 .88616 m .60663 .84828 L .70245 .94009 L .656 .751 .92 r
F
0 g
.70245 .94009 m
.81483 1.01975 L
s
.48831 .88616 m .62 1.00029 L .47533 1.04414 L .544 .324 .532 r
F
.48831 .88616 m .60663 .84828 L .62 1.00029 L F
.38357 .79077 m .60663 .84828 L .48831 .88616 L .656 .751 .92 r
F
0 g
.47917 .7435 m
.48386 .81663 L
s
.19672 .39685 m
.1412 .42952 L
s
.52121 .2714 m
.19672 .39685 L
s
.52121 .2714 m
.57716 .28003 L
s
.4489 1.45343 m
.51676 1.45957 L
s
.51676 1.45957 m
.85673 1.37252 L
s
.90182 1.3437 m
.85673 1.37252 L
s
.38357 .79077 m .52761 .74259 L .60663 .84828 L .656 .751 .92 r
F
0 g
.60663 .84828 m
.70245 .94009 L
s
.60663 .84828 m
.61603 .69748 L
s
.47533 1.04414 m .65905 1.15461 L .43781 1.2177 L .544 .324 .532 r
F
.47533 1.04414 m .62 1.00029 L .65905 1.15461 L F
0 g
.47533 1.04414 m
.48831 .88616 L
s
.60663 .84828 m
.62 1.00029 L
s
.24813 .69716 m .52761 .74259 L .38357 .79077 L .656 .751 .92 r
F
0 g
.38357 .79077 m
.48831 .88616 L
s
.1412 .42952 m
.47502 .30089 L
s
.1412 .42952 m
.09999 .50036 L
s
.47502 .30089 m
.52121 .2714 L
s
.85673 1.37252 m
.79811 1.3631 L
s
.24813 .69716 m .46732 .62038 L .52761 .74259 L .656 .751 .92 r
F
0 g
.52761 .74259 m
.60663 .84828 L
s
.43781 1.2177 m .72922 1.31216 L .37195 1.40721 L .544 .324 .532 r
F
0 g
.4489 1.45343 m
.79811 1.3631 L
s
.37195 1.40721 m
.4489 1.45343 L
s
.43781 1.2177 m .65905 1.15461 L .72922 1.31216 L .544 .324 .532 r
F
0 g
.43781 1.2177 m
.47533 1.04414 L
s
.37195 1.40721 m
.43781 1.2177 L
s
.62 1.00029 m
.65905 1.15461 L
s
.07794 .60707 m .46732 .62038 L .24813 .69716 L .656 .751 .92 r
F
0 g
.24813 .69716 m
.38357 .79077 L
s
.44323 .37028 m
.47502 .30089 L
s
.37195 1.40721 m
.72922 1.31216 L
s
.29173 1.32122 m
.37195 1.40721 L
s
.65905 1.15461 m
.72922 1.31216 L
s
.72922 1.31216 m
.79811 1.3631 L
s
.07794 .60707 m .42998 .47766 L .46732 .62038 L .656 .751 .92 r
F
0 g
.42998 .47766 m
.46732 .62038 L
s
.09999 .50036 m
.44323 .37028 L
s
.07794 .60707 m
.09999 .50036 L
s
.46732 .62038 m
.52761 .74259 L
s
.07794 .60707 m
.24813 .69716 L
s
.07794 .60707 m
.42998 .47766 L
s
.07794 .60707 m
.0786 .74291 L
s
.21536 1.20035 m
.29173 1.32122 L
s
.29173 1.32122 m
.6551 1.22014 L
s
.42998 .47766 m
.44323 .37028 L
s
.0786 .74291 m
.43805 .61643 L
s
.0786 .74291 m
.10326 .89678 L
s
.6551 1.22014 m
.72922 1.31216 L
s
.15034 1.05435 m
.21536 1.20035 L
s
.21536 1.20035 m
.5822 1.09238 L
s
.10326 .89678 m
.468 .77527 L
s
.10326 .89678 m
.15034 1.05435 L
s
.15034 1.05435 m
.51764 .93928 L
s
.42998 .47766 m
.43805 .61643 L
s
.6551 1.22014 m
.5822 1.09238 L
s
.468 .77527 m
.43805 .61643 L
s
.5822 1.09238 m
.51764 .93928 L
s
.51764 .93928 m
.468 .77527 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.439688 0.855774 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.245842 1.5786 -2.22045e-16 1.5786 [
[.5 1.5261 -31.9062 0 ]
[.5 1.5261 31.9062 12 ]
[ 0 0 0 0 ]
[ 1 1.5136 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.5261 -92.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BiConvexLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5136 L
0 1.5136 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.69495 .81902 m
.6617 .70991 L
s
.6617 .70991 m
.72079 .69069 L
s
.6617 .70991 m
.6191 .60566 L
s
.71732 .92808 m
.69495 .81902 L
s
.69495 .81902 m
.75436 .80057 L
s
.6191 .60566 m
.67827 .58556 L
s
.6191 .60566 m
.56893 .5112 L
s
.72079 .69069 m
.75436 .80057 L
s
.67827 .58556 m
.72079 .69069 L
s
.75436 .80057 m
.77742 .91026 L
s
.71732 .92808 m
.77742 .91026 L
s
.62858 .49011 m
.67827 .58556 L
s
.56893 .5112 m
.62858 .49011 L
s
.56989 .98585 m .78863 1.01462 L .72745 1.03196 L .656 .751 .92 r
F
0 g
.72425 1.12527 m
.72745 1.03196 L
s
.71732 .92808 m
.72494 1.00624 L
s
.56989 .98585 m .81558 .91343 L .78863 1.01462 L .656 .751 .92 r
F
0 g
.78683 1.10823 m
.78863 1.01462 L
s
.77742 .91026 m
.77892 .92423 L
s
.72745 1.03196 m
.78863 1.01462 L
s
.51332 .43153 m .66721 .49348 L .4234 .57917 L .544 .324 .532 r
F
.51332 .43153 m .57382 .40939 L .66721 .49348 L F
0 g
.51332 .43153 m
.57382 .40939 L
s
.45483 .37177 m
.51332 .43153 L
s
.448 .92499 m .81558 .91343 L .56989 .98585 L .656 .751 .92 r
F
0 g
.56989 .98585 m
.72745 1.03196 L
s
.51653 .34856 m
.57382 .40939 L
s
.70697 1.20223 m
.72425 1.12527 L
s
.72425 1.12527 m
.78683 1.10823 L
s
.4234 .57917 m .72187 .59974 L .37261 .71718 L .544 .324 .532 r
F
.4234 .57917 m .66721 .49348 L .72187 .59974 L F
0 g
.4234 .57917 m
.51332 .43153 L
s
.57382 .40939 m
.66721 .49348 L
s
.78683 1.10823 m
.77121 1.1853 L
s
.45483 .37177 m
.51653 .34856 L
s
.45483 .37177 m
.3966 .33699 L
s
.448 .92499 m .79866 .81735 L .81558 .91343 L .656 .751 .92 r
F
.35264 .85039 m .79866 .81735 L .448 .92499 L F
0 g
.448 .92499 m
.56989 .98585 L
s
.78863 1.01462 m
.81558 .91343 L
s
.4598 .31277 m
.51653 .34856 L
s
.37261 .71718 m .74376 .72517 L .35264 .85039 L .544 .324 .532 r
F
.37261 .71718 m .72187 .59974 L .74376 .72517 L F
0 g
.37261 .71718 m
.4234 .57917 L
s
.67539 1.25686 m
.70697 1.20223 L
s
.70697 1.20223 m
.77121 1.1853 L
s
.77121 1.1853 m
.74149 1.23981 L
s
.66721 .49348 m
.72187 .59974 L
s
.3966 .33699 m
.4598 .31277 L
s
.3966 .33699 m
.34235 .3318 L
s
.35264 .85039 m .73229 .86901 L .36309 .98094 L .544 .324 .532 r
F
.35264 .85039 m .74376 .72517 L .79866 .81735 L .656 .751 .92 r
F
.35264 .85039 m .74376 .72517 L .73229 .86901 L .544 .324 .532 r
F
0 g
.79866 .81735 m
.81558 .91343 L
s
.28258 .76062 m .74376 .72517 L .35264 .85039 L .656 .751 .92 r
F
0 g
.36707 .75413 m
.37261 .71718 L
s
.40728 .3067 m
.4598 .31277 L
s
.63019 1.28336 m
.67539 1.25686 L
s
.67539 1.25686 m
.74149 1.23981 L
s
.74149 1.23981 m
.69822 1.26594 L
s
.36309 .98094 m .68199 1.03175 L .40953 1.10944 L .544 .324 .532 r
F
.36309 .98094 m .73229 .86901 L .68199 1.03175 L F
0 g
.35264 .85039 m
.36309 .98094 L
s
.34235 .3318 m
.29634 .35963 L
s
.40728 .3067 m
.34235 .3318 L
s
.28258 .76062 m .65015 .63765 L .74376 .72517 L .656 .751 .92 r
F
0 g
.72187 .59974 m
.74376 .72517 L
s
.74376 .72517 m
.79866 .81735 L
s
.24234 .65195 m .65015 .63765 L .28258 .76062 L .656 .751 .92 r
F
0 g
.28258 .76062 m
.35264 .85039 L
s
.36313 .33389 m
.40728 .3067 L
s
.57324 1.27687 m
.63019 1.28336 L
s
.63019 1.28336 m
.69822 1.26594 L
s
.73229 .86901 m
.74376 .72517 L
s
.69822 1.26594 m
.64311 1.25879 L
s
.40953 1.10944 m .57936 1.21547 L .50788 1.23449 L .544 .324 .532 r
F
.40953 1.10944 m .68199 1.03175 L .57936 1.21547 L F
0 g
.36309 .98094 m
.40953 1.10944 L
s
.40953 1.10944 m
.50788 1.23449 L
s
.29634 .35963 m
.36313 .33389 L
s
.29634 .35963 m
.26299 .42176 L
s
.33167 .39573 m
.36313 .33389 L
s
.68199 1.03175 m
.73229 .86901 L
s
.50788 1.23449 m
.57324 1.27687 L
s
.57324 1.27687 m
.64311 1.25879 L
s
.24234 .65195 m .51227 .55739 L .65015 .63765 L .656 .751 .92 r
F
0 g
.65015 .63765 m
.74376 .72517 L
s
.24637 .51627 m .51227 .55739 L .24234 .65195 L .656 .751 .92 r
F
0 g
.24234 .65195 m
.28258 .76062 L
s
.57936 1.21547 m
.64311 1.25879 L
s
.33167 .39573 m
.26299 .42176 L
s
.57936 1.21547 m
.68199 1.03175 L
s
.50788 1.23449 m
.57936 1.21547 L
s
.43897 1.15654 m
.50788 1.23449 L
s
.24637 .51627 m .3168 .49038 L .51227 .55739 L .656 .751 .92 r
F
0 g
.3168 .49038 m
.51227 .55739 L
s
.3168 .49038 m
.33167 .39573 L
s
.24637 .51627 m
.26299 .42176 L
s
.51227 .55739 m
.65015 .63765 L
s
.24234 .65195 m
.24637 .51627 L
s
.51167 1.13632 m
.57936 1.21547 L
s
.24637 .51627 m
.3168 .49038 L
s
.24637 .51627 m
.24936 .63726 L
s
.37262 1.04749 m
.43897 1.15654 L
s
.43897 1.15654 m
.51167 1.13632 L
s
.3168 .49038 m
.32128 .61195 L
s
.51167 1.13632 m
.44601 1.02589 L
s
.24936 .63726 m
.32128 .61195 L
s
.24936 .63726 m
.27288 .77484 L
s
.31531 .91617 m
.37262 1.04749 L
s
.37262 1.04749 m
.44601 1.02589 L
s
.34585 .75053 m
.32128 .61195 L
s
.27288 .77484 m
.34585 .75053 L
s
.27288 .77484 m
.31531 .91617 L
s
.31531 .91617 m
.38879 .89315 L
s
.44601 1.02589 m
.38879 .89315 L
s
.38879 .89315 m
.34585 .75053 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.439688 0.97619 0.536642 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.34076 1.77739 2.22045e-16 1.77739 [
[.5 1.73016 -33.875 0 ]
[.5 1.73016 33.875 12.1875 ]
[ 0 0 0 0 ]
[ 1 1.71766 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.73016 -94.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(CompoundLens) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.71766 L
0 1.71766 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63823 .95034 m
.59984 .824 L
s
.59984 .824 m
.71188 .78756 L
s
.59984 .824 m
.54996 .70352 L
s
.66334 1.07681 m
.63823 .95034 L
s
.63823 .95034 m
.75086 .91535 L
s
.54996 .70352 m
.66215 .6654 L
s
.54996 .70352 m
.49069 .5946 L
s
.66334 1.07681 m
.77729 1.04302 L
s
.71188 .78756 m
.75086 .91535 L
s
.66215 .6654 m
.71188 .78756 L
s
.75195 .91502 m
.71296 .78721 L
s
.71296 .78721 m
.85498 .74102 L
s
.71296 .78721 m
.66323 .66503 L
s
.75086 .91535 m
.77729 1.04302 L
s
.77839 1.04269 m
.75195 .91502 L
s
.75195 .91502 m
.89472 .87067 L
s
.60376 .55462 m
.66215 .6654 L
s
.66323 .66503 m
.80547 .6167 L
s
.66323 .66503 m
.60485 .55424 L
s
.49069 .5946 m
.60376 .55462 L
s
.77839 1.04269 m
.92287 .99985 L
s
.58243 1.11723 m .7896 1.16458 L .67365 1.19746 L .656 .751 .92 r
F
0 g
.6679 1.30599 m
.67365 1.19746 L
s
.66334 1.07681 m
.66847 1.1369 L
s
.85498 .74102 m
.89472 .87067 L
s
.80547 .6167 m
.85498 .74102 L
s
.89472 .87067 m
.92287 .99985 L
s
.60485 .55424 m
.74825 .50353 L
s
.74825 .50353 m
.80547 .6167 L
s
.58243 1.11723 m .72609 1.07488 L .7896 1.16458 L .656 .751 .92 r
F
0 g
.78647 1.2737 m
.7896 1.16458 L
s
.77729 1.04302 m
.7896 1.16458 L
s
.67365 1.19746 m
.7896 1.16458 L
s
.72731 1.07452 m .9378 1.12256 L .79071 1.16426 L .656 .751 .92 r
F
0 g
.78761 1.27339 m
.79071 1.16426 L
s
.77839 1.04269 m
.7829 1.08721 L
s
.42451 .50305 m .55382 .59188 L .41127 .64198 L .544 .324 .532 r
F
.42451 .50305 m .53917 .46109 L .55382 .59188 L F
0 g
.53917 .46109 m
.60376 .55462 L
s
.42451 .50305 m
.53917 .46109 L
s
.35449 .43479 m
.42451 .50305 L
s
.64532 1.39572 m
.6679 1.30599 L
s
.6679 1.30599 m
.78647 1.2737 L
s
.47137 .39082 m
.53917 .46109 L
s
.72731 1.07452 m .86708 1.03332 L .9378 1.12256 L .656 .751 .92 r
F
0 g
.9378 1.12256 m
.93811 1.23241 L
s
.92287 .99985 m
.9378 1.12256 L
s
.79071 1.16426 m
.9378 1.12256 L
s
.54027 .46069 m .69375 .54269 L .55502 .59145 L .544 .324 .532 r
F
.54027 .46069 m .68577 .40745 L .69375 .54269 L F
0 g
.68577 .40745 m
.74825 .50353 L
s
.54027 .46069 m
.68577 .40745 L
s
.47249 .3904 m
.54027 .46069 L
s
.48976 1.03083 m .72609 1.07488 L .58243 1.11723 L .656 .751 .92 r
F
0 g
.58243 1.11723 m
.67365 1.19746 L
s
.78647 1.2737 m
.767 1.36365 L
s
.76817 1.36334 m
.78761 1.27339 L
s
.78761 1.27339 m
.93811 1.23241 L
s
.41127 .64198 m .56315 .73223 L .40148 .78659 L .544 .324 .532 r
F
.41127 .64198 m .55382 .59188 L .56315 .73223 L F
0 g
.41127 .64198 m
.42451 .50305 L
s
.53917 .46109 m
.55382 .59188 L
s
.35449 .43479 m
.47137 .39082 L
s
.35449 .43479 m
.28433 .39562 L
s
.62093 .33457 m
.68577 .40745 L
s
.48976 1.03083 m .65209 .981 L .72609 1.07488 L .656 .751 .92 r
F
0 g
.72609 1.07488 m
.7896 1.16458 L
s
.65338 .9806 m .86708 1.03332 L .72731 1.07452 L .656 .751 .92 r
F
0 g
.72731 1.07452 m
.79071 1.16426 L
s
.60579 1.45969 m
.64532 1.39572 L
s
.64532 1.39572 m
.767 1.36365 L
s
.93811 1.23241 m
.92275 1.32261 L
s
.404 .34976 m
.47137 .39082 L
s
.47249 .3904 m
.62093 .33457 L
s
.47249 .3904 m
.40515 .34932 L
s
.55502 .59145 m .7004 .68608 L .56443 .7318 L .544 .324 .532 r
F
.55502 .59145 m .69375 .54269 L .7004 .68608 L F
0 g
.54027 .46069 m
.55502 .59145 L
s
.68577 .40745 m
.69375 .54269 L
s
.65338 .9806 m .78989 .9387 L .86708 1.03332 L .656 .751 .92 r
F
0 g
.86708 1.03332 m
.9378 1.12256 L
s
.39538 .93754 m .65209 .981 L .48976 1.03083 L .656 .751 .92 r
F
0 g
.48976 1.03083 m
.58243 1.11723 L
s
.767 1.36365 m
.73092 1.42742 L
s
.73213 1.42711 m
.76817 1.36334 L
s
.76817 1.36334 m
.92275 1.32261 L
s
.40148 .78659 m .56671 .88268 L .39538 .93754 L .544 .324 .532 r
F
.40148 .78659 m .56315 .73223 L .56671 .88268 L F
0 g
.40148 .78659 m
.41127 .64198 L
s
.55382 .59188 m
.56315 .73223 L
s
.55725 .29101 m
.62093 .33457 L
s
.28433 .39562 m
.404 .34976 L
s
.28433 .39562 m
.21851 .39082 L
s
.39538 .93754 m .56671 .88268 L .65209 .981 L .656 .751 .92 r
F
0 g
.65209 .981 m
.72609 1.07488 L
s
.56804 .88226 m .78989 .9387 L .65338 .9806 L .656 .751 .92 r
F
0 g
.65338 .9806 m
.72731 1.07452 L
s
.92275 1.32261 m
.89124 1.38608 L
s
.55026 1.49117 m
.60579 1.45969 L
s
.60579 1.45969 m
.73092 1.42742 L
s
.56443 .7318 m .70561 .83822 L .56804 .88226 L .544 .324 .532 r
F
.56443 .7318 m .7004 .68608 L .70561 .83822 L F
0 g
.55502 .59145 m
.56443 .7318 L
s
.69375 .54269 m
.7004 .68608 L
s
.34138 .34331 m
.404 .34976 L
s
.40515 .34932 m
.55725 .29101 L
s
.40515 .34932 m
.34256 .34286 L
s
.56804 .88226 m .70561 .83822 L .78989 .9387 L .656 .751 .92 r
F
0 g
.78989 .9387 m
.86708 1.03332 L
s
.39538 .93754 m .56401 1.0438 L .39326 1.09557 L .544 .324 .532 r
F
.39538 .93754 m .56671 .88268 L .56401 1.0438 L F
.29895 .83654 m .56671 .88268 L .39538 .93754 L .656 .751 .92 r
F
0 g
.39876 .85374 m
.40148 .78659 L
s
.73092 1.42742 m
.67896 1.45822 L
s
.6802 1.4579 m
.73213 1.42711 L
s
.73213 1.42711 m
.89124 1.38608 L
s
.4989 .28241 m
.55725 .29101 L
s
.21851 .39082 m
.1621 .42422 L
s
.34138 .34331 m
.21851 .39082 L
s
.29895 .83654 m .46894 .77967 L .56671 .88268 L .656 .751 .92 r
F
0 g
.56671 .88268 m
.65209 .981 L
s
.56315 .73223 m
.56671 .88268 L
s
.56804 .88226 m .70924 .99978 L .56537 1.04339 L .544 .324 .532 r
F
.56804 .88226 m .70561 .83822 L .70924 .99978 L F
.47029 .77922 m .70561 .83822 L .56804 .88226 L .656 .751 .92 r
F
0 g
.56443 .7318 m
.56615 .80325 L
s
.89124 1.38608 m
.84403 1.41595 L
s
.4811 1.48452 m
.55026 1.49117 L
s
.55026 1.49117 m
.67896 1.45822 L
s
.28844 .37554 m
.34138 .34331 L
s
.34256 .34286 m
.28965 .37508 L
s
.4989 .28241 m
.34256 .34286 L
s
.39326 1.09557 m .55451 1.21618 L .39549 1.26152 L .544 .324 .532 r
F
.39326 1.09557 m .56401 1.0438 L .55451 1.21618 L F
0 g
.39326 1.09557 m
.39538 .93754 L
s
.56401 1.0438 m
.56671 .88268 L
s
.47029 .77922 m .61354 .73129 L .70561 .83822 L .656 .751 .92 r
F
0 g
.70561 .83822 m
.78989 .9387 L
s
.7004 .68608 m
.70561 .83822 L
s
.20015 .72687 m .46894 .77967 L .29895 .83654 L .656 .751 .92 r
F
0 g
.29895 .83654 m
.39538 .93754 L
s
.67896 1.45822 m
.61324 1.45034 L
s
.61451 1.45001 m
.6802 1.4579 L
s
.6802 1.4579 m
.84403 1.41595 L
s
.45057 .31307 m
.4989 .28241 L
s
.56537 1.04339 m .71117 1.17151 L .55586 1.21579 L .544 .324 .532 r
F
.56537 1.04339 m .70924 .99978 L .71117 1.17151 L F
0 g
.56537 1.04339 m
.56804 .88226 L
s
.70561 .83822 m
.70924 .99978 L
s
.1621 .42422 m
.28844 .37554 L
s
.1621 .42422 m
.12047 .4972 L
s
.20015 .72687 m .35767 .67169 L .46894 .77967 L .656 .751 .92 r
F
0 g
.46894 .77967 m
.56671 .88268 L
s
.359 .67122 m .61354 .73129 L .47029 .77922 L .656 .751 .92 r
F
0 g
.47029 .77922 m
.56804 .88226 L
s
.84403 1.41595 m
.78287 1.40646 L
s
.39549 1.26152 m .53758 1.40043 L .40247 1.43638 L .544 .324 .532 r
F
.39549 1.26152 m .55451 1.21618 L .53758 1.40043 L F
0 g
.39326 1.09557 m
.39549 1.26152 L
s
.55451 1.21618 m
.56401 1.0438 L
s
.39549 1.26152 m
.40247 1.43638 L
s
.40247 1.43638 m
.4811 1.48452 L
s
.4811 1.48452 m
.61324 1.45034 L
s
.2503 .448 m
.28844 .37554 L
s
.28965 .37508 m
.45057 .31307 L
s
.28965 .37508 m
.25155 .44752 L
s
.359 .67122 m .5129 .61731 L .61354 .73129 L .656 .751 .92 r
F
0 g
.61354 .73129 m
.70561 .83822 L
s
.09855 .60738 m .35767 .67169 L .20015 .72687 L .656 .751 .92 r
F
0 g
.20015 .72687 m
.29895 .83654 L
s
.53758 1.40043 m
.61324 1.45034 L
s
.61451 1.45001 m
.78287 1.40646 L
s
.55586 1.21579 m .71121 1.35423 L .53888 1.40008 L .544 .324 .532 r
F
0 g
.53758 1.40043 m
.55451 1.21618 L
s
.53888 1.40008 m
.61451 1.45001 L
s
.55586 1.21579 m .71117 1.17151 L .71121 1.35423 L .544 .324 .532 r
F
0 g
.55586 1.21579 m
.56537 1.04339 L
s
.70924 .99978 m
.71117 1.17151 L
s
.53888 1.40008 m
.55586 1.21579 L
s
.2503 .448 m
.12047 .4972 L
s
.41709 .38478 m
.45057 .31307 L
s
.09855 .60738 m .23165 .55845 L .35767 .67169 L .656 .751 .92 r
F
0 g
.09855 .60738 m
.12047 .4972 L
s
.35767 .67169 m
.46894 .77967 L
s
.09855 .60738 m
.20015 .72687 L
s
.23293 .55798 m .5129 .61731 L .359 .67122 L .656 .751 .92 r
F
0 g
.359 .67122 m
.47029 .77922 L
s
.40247 1.43638 m
.53758 1.40043 L
s
.32026 1.34706 m
.40247 1.43638 L
s
.71121 1.35423 m
.78287 1.40646 L
s
.71117 1.17151 m
.71121 1.35423 L
s
.41709 .38478 m
.25155 .44752 L
s
.45762 1.30885 m
.53758 1.40043 L
s
.53888 1.40008 m
.71121 1.35423 L
s
.45894 1.30848 m
.53888 1.40008 L
s
.23293 .55798 m .40279 .49554 L .5129 .61731 L .656 .751 .92 r
F
0 g
.40279 .49554 m
.5129 .61731 L
s
.23293 .55798 m
.25155 .44752 L
s
.23165 .55845 m
.2503 .448 L
s
.5129 .61731 m
.61354 .73129 L
s
.23165 .55845 m
.35767 .67169 L
s
.23293 .55798 m
.359 .67122 L
s
.09855 .60738 m
.23165 .55845 L
s
.09855 .60738 m
.09994 .74785 L
s
.40279 .49554 m
.41709 .38478 L
s
.24178 1.22167 m
.32026 1.34706 L
s
.32026 1.34706 m
.45762 1.30885 L
s
.23165 .55845 m
.23579 .70004 L
s
.63428 1.25971 m
.71121 1.35423 L
s
.23293 .55798 m
.40279 .49554 L
s
.23293 .55798 m
.2371 .69958 L
s
.09994 .74785 m
.23579 .70004 L
s
.09994 .74785 m
.1259 .9071 L
s
.45762 1.30885 m
.38041 1.18087 L
s
.38174 1.18047 m
.45894 1.30848 L
s
.45894 1.30848 m
.63428 1.25971 L
s
.17472 1.07032 m
.24178 1.22167 L
s
.24178 1.22167 m
.38041 1.18087 L
s
.1259 .9071 m
.26371 .86119 L
s
.1259 .9071 m
.17472 1.07032 L
s
.17472 1.07032 m
.3135 1.02684 L
s
.40279 .49554 m
.41059 .63854 L
s
.26371 .86119 m
.23579 .70004 L
s
.2371 .69958 m
.41059 .63854 L
s
.2371 .69958 m
.26504 .86075 L
s
.38041 1.18087 m
.3135 1.02684 L
s
.31484 1.02643 m
.38174 1.18047 L
s
.38174 1.18047 m
.55881 1.12835 L
s
.63428 1.25971 m
.55881 1.12835 L
s
.3135 1.02684 m
.26371 .86119 L
s
.26504 .86075 m
.44111 .80209 L
s
.26504 .86075 m
.31484 1.02643 L
s
.31484 1.02643 m
.49216 .97088 L
s
.44111 .80209 m
.41059 .63854 L
s
.55881 1.12835 m
.49216 .97088 L
s
.49216 .97088 m
.44111 .80209 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{932, 512.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>T000202000`400?l00000o`00003ooooooooo
ooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00
ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonW
ooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooo
oooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooo
oooooooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooofWooooo
0_l0000looooo`00ooooooooooooooooooooI_ooool3o`000003ooooool0003ooooo03_ooooo003o
oooooooooooooooooomTooooo`;o00001?ooool2o`0003_ooooo003ooooooooooooooooooomRoooo
o`;o00001_ooool00ol0003oooooo`00000jooooo`00ooooooooooooooooooooGoooool3o`0000So
oooo00?o0000ooooool00000>_ooool00?oooooooooooooooooooegooooo0_l0000;ooooo`04o`00
0?ooooooooooo`0003Wooooo001;ooooo`Ko0000oooooooooooooooooooo2Oooool3o`0000gooooo
00Co0000oooooooooooo0000>Oooool004Sooooo0ol000000ooooooo0000ooooo`03ooooo`So0000
ooooooooooooookooooo0_l0000@ooooo`05o`000?ooooooooooooooool00000>?ooool004Kooooo
0_l00003ooooo`03o`000?oooooooooo00_ooooo1?l0003ooooooooooooon?ooool2o`0001;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`00A?ooool2o`0000Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3oooooooooooooloooool3o`0001Gooooo00Go
0000ooooooooooooooooo`00000gooooo`00@Oooool3o`0000Gooooo00?o0000ooooooooool04?oo
ool2o`000?ooooooooooooobooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Cooooo000oooooo`;o00001oooool00ol0003oooooooooo`0Booooo`;o0000oooooooo
ooooonkooooo0ol0000Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool0
03gooooo0_l00008ooooo`03o`000?oooooooooo01?ooooo0_l0003;ooooo`Go0000Joooool5o`00
07?ooooo1Ol0001[ooooo`Go0000I_ooool5o`0005Oooooo0_l0000Mooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0<oooool003[ooooo0ol0000:ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooool00000aoooool5o`0000?ooooo00?o0000ooooooooool0IOooool6o`0000;o
oooo00?o0000ooooooooool0KOooool5o`0000?ooooo00?o0000ooooooooool0IOooool5o`0000?o
oooo00?o0000ooooooooool0H?ooool5o`0000?ooooo00?o0000ooooooooool0D_ooool2o`0001oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`00>?ooool2o`0000cooooo
00?o0000ooooooooool05?ooool01?l0003oooooooooool00034ooooo`?o000000?oooooo`000?oo
ool01?ooool2o`0006Cooooo1Ol00005ooooo`;o0000K?ooool4o`000003ooooool0003ooooo00?o
oooo0_l0001Tooooo`Co000000?oooooo`000?ooool00oooool2o`0005kooooo1_l00005ooooo`;o
0000D?ooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`00
=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool00000
`oooool2o`0000;ooooo0ol000001_oooooo0000o`000?l0003oooooo`00067ooooo1_l000000ooo
oooo0000ooooo`02ooooo`;o000000?oooooo`000?ooool0J?ooool5o`0000;ooooo00?o0000oooo
ooooool00ol000000ooooooo0000ooooo`1Pooooo`Go00000_ooool00ol0003oooooooooo`03o`00
0003ooooool0003ooooo05[ooooo1_l000000ooooooo0000ooooo`02ooooo`?o000000?oooooo`00
0?ooool0COooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0aoooo
o`00=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooo
oooo0000`Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0G?ooool5o`0000?ooooo00?o0000ooooool000000_l00004ooooo`03o`000?oooooo
oooo06?ooooo1Ol00004ooooo`Co00001Oooool00ol0003oooooooooo`1Kooooo`Go00001?ooool4
o`0000Gooooo00?o0000ooooooooool0E_ooool6o`0000;ooooo1Ol00005ooooo`03o`000?oooooo
oooo04Sooooo0ol0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool0
03Kooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`000<7ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0FOooool2o`000003ooooool0003o000000Cooooo0ol00008ooooo`03o`000?oooooo
oooo063ooooo1Ol00003ooooo`Go00001oooool2o`0005[ooooo1Ol00003ooooo`Go00001oooool2
o`0005Cooooo1_l00002ooooo`Go00002Oooool00ol0003oooooooooo`15ooooo`;o0000:Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo000eooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`000;oooooo1?l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Gooooo`Ko00000ooo
ool5o`0000Sooooo0ol0001Nooooo`Go00000oooool4o`0000?ooooo00?o0000ooooooooool00_oo
ool3o`000003oh]BR?l0003ooooo05Kooooo1Ol00003ooooo`Co00000oooool00ol0003ooooooooo
o`02ooooo`?o000000?oRe:8o`000?ooool0D?ooool4o`000004ooooool0003o0000ooooo`Ko0000
00?oooooo`000?ooool02?ooool2o`0004Cooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0;oooool003Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00001:ooooo`Go0000
K_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`000003oh]B
R?l0003ooooo05Cooooo1_l00002ooooo`Go00000_ooool00ol0003oooooooooo`03ooooo`?o0000
0_n;DXP00ol0003oooooooooo`1Jooooo`Go00000_ooool5o`0000Cooooo00?o0000ooooooooool0
0ol00004oh]BR0;o0000E?ooool5o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo00?o0000
1?n;DXP2o`0004gooooo2?l000001?oooooo0000o`000?ooool2o`0000?ooooo00?o0000oooooooo
ool01Oooool3o`000003oh]BR?l0003ooooo043ooooo0ol0000]ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0;oooool003?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000018ooooo`Go
00000_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oRe:8oh]BR002oh]BR0;o0000Doooool00ol0003om:ikooB^N`02ooB^N`03
ooB_N_l0003o000000?o00001?ooool01?l0003oooooooooooooool3o`0000GoRe:80_l0001Hoooo
o`Go00000_ooool5o`0000Kooooo1?l00007oh]BR0;o0000DOooool5o`0000;ooooo1Ol00006oooo
o`Co00001on;DXP2o`0004_ooooo1?l000001?oooooo0000o`000?ooool6o`0000Gooooo00?o0000
ooooooooool00_ooool3o`0000CoRe:80_l0000oooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`00<_ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000007_ooool01?l0003oooooooooool00018ooooo`Co00001Ooo
ool2o`0006_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?n;
DXSoRe:8oh]BR?l000000_ooool00ol0003oooooooooo`1@ooooo`03o`000?od[W_om:ik00?o0000
0_od[gX2o`0000Cooooo1Ol00008oh]BR003o`000?oooooo000005Cooooo1_l000000ooooooo0000
o`000003o`0000Kooooo0ol000000onW`>_o0000oh]BR008oh]BR0?o0000COooool6o`000003oooo
ool0003o000000?o00001_ooool3o`000003ojO0jol0003oRe:800SoRe:80ol00019ooooo`?o0000
0_ooool7o`0000Oooooo0_l000001?oooooo0000o`000?l00007oh]BR0;o0000?oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool0037ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`00000Pooooo`;o0000A_ooool5o`0000Wooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oRe:8
oh]BR002oh]BR003o`000?oooooooooo00;o0000D?ooool4o`0000?om:ik1?od[gX4o`000003ojO0
jol0003oRe:800[oRe:800Co0000ooooool0003o0000DOooool5o`0000;ooooo1Ol00005ooooo`?o
00001?nW`>/2o`0000SoRe:800?o0000ooooool00000Boooool5o`0000;ooooo1Ol00005ooooo`?o
00001?nW`>/2o`0000SoRe:800?o0000ooooool00000B?ooool00ol0003oooooooooo`02ooooo`;o
00000_ooool00ol0003oooooooooo`05ooooo`?o000000?oYl3[o`000?l000002_n;DXP3o`0003ko
oooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool0037ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo047ooooo
2?l0000;ooooo`;o0000Ioooool00ol0003oooooo`000002o`0000;oYl3[00?o0000ooooooooool0
0_ooool00ol0003oRe:8oh]BR003oh]BR0?o000000?oooooo`000?ooool0C_ooool2o`000003ooB_
O?od[W_om:ik00?om:ik0ood[gX2o`0000CoYl3[0_l0000:oh]BR0;o000000?oooooo`000?ooool0
COooool6o`000003ooooool0003o000000?o00001_ooool2o`0000OoYl3[00?o0000ojO0jol00000
1on;DXP01?l0003oooooooooool00017ooooo`Ko000000?oooooo`000?l000000ol00006ooooo`;o
00001onW`>/00ol0003oYl3[o`000007oh]BR004o`000?ooooooooooo`0004Oooooo00?o0000oooo
ool000000_l00005ooooo`04o`000?ooooooooooooooo`?o00001?nW`>/2o`0000[oRe:800?o0000
ooooool00000?_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0;?ooool0033ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000Ooooo
o`;o0000@_ooool3o`0000?ooooo1?l0000<ooooo`03o`000?oooooooooo06Cooooo0_l00005ojO0
j`;o00000_ooool00ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0C?ooool00ol0003om:mlooB_O005ooB^N`?o00001_nW`>/00ol0003oYl3[o`000009oh]B
R005o`000?ooooooooooooooool00000B_ooool<o`0000Kooooo0ol0000:ojO0j`;o00001on;DXP0
1Ol0003ooooooooooooooooo000004?ooooo3?l00006ooooo`?o00002_nW`>/2o`0000OoRe:800Go
0000ooooooooooooooooo`000015ooooo`?o00002Oooool3o`0000OoYl3[00?o0000ojO0jol00000
2On;DXP01?l0003oooooooooool0000looooo`05o`000?ooooooooooooooool00000;Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo000_ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00007Oooool2o`0004;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0006Cooooo00?o0000ojO0jonW`>/01?nW`>/2o`0000;ooooo00?o0000oh]B
R?n;DXP00on;DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00Go0000ooB_
O?od[gcom:mlooB^N`03o`0000WoYl3[00Co0000ojO0jonW`>_o00002?n;DXP00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04Kooooo0_l00003oo6_P`?o000000?olJn3o`000?ooool01_oo
ool2o`0000goYl3[00?o0000ojO0jol000001_n;DXP01Ol0003ooooooooooooooooo000004;ooooo
0_l00003ooooo`?o000000?oooooo`000?ooool01_ooool2o`0000goYl3[00?o0000ojO0jol00000
1_n;DXP01Ol0003ooooooooooooooooo000004Cooooo00?o0000ooooooooool02?ooool3o`0000[o
Yl3[0_l00009oh]BR005o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[oooo
o`00;_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000007?ooool2o`00
04;ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo00?o0000ooooooooool0HOooool00ol0
003oYl3[ojO0j`04ojO0j`;o000000?oooooo`000?n;DXP01On;DXP00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04_ooooo00Co0000ooB_O?od[gcom:ml0_l0000<ojO0j`05o`000?nW`>_o
Yl3[ojO0jol000001on;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00?o
0000oo6_Pol000000_l00005oo6_P`04o`000?ooooooooooooooo`?o00003_nW`>/2o`0000;oYl3[
00?o0000oh]BR?n;DXP00on;DXP01?l0003oooooooooooooool2o`00047ooooo00?o0000ooooool0
00000_l00005ooooo`04o`000?ooooooooooooooo`?o00003_nW`>/2o`0000;oYl3[00?o0000oh]B
R?n;DXP00on;DXP01?l0003oooooooooooooool2o`0004?ooooo00?o0000ooooooooool01Oooool3
o`0000goYl3[00?o0000ojO0jol000002?n;DXP01Ol0003ooooooooooooooooo000003_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0:_ooool002gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Sooooo0_l00012ooooo`;o00001?ooool2o`0000Gooooo0_l0000>
ooooo`;o0000H?ooool2o`0000KoYl3[00?o0000ojO0jol000001on;DXP2o`0000Cooooo0_l0001<
ooooo`Co00003_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800CoRe:800Co0000
oooooooooooooooo0ol00016ooooo`?o00002Ooa[h<3o`0000koYl3[0ol000001OnW`>_o0000ojO0
jonW`>_o000000KoRe:80ol000000ooooooo0000ooooo`0oooooo`?o00002Oooool3o`0000koYl3[
0ol000001OnW`>_o0000ojO0jonW`>_o000000KoRe:80ol000000ooooooo0000ooooo`12ooooo`03
o`000?oooooooooo00?ooooo0_l0000?ojO0j`;o00000_nW`>/00ol0003oRe:8oh]BR005oh]BR004
o`000?ooooooooooooooo`;o0000>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`00;?ooool2o`0000co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`Co0000@oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool2o`0000oooooo0_l0001Nooooo`03o`000?nW`>_o000000Co
Yl3[0_l000000onW`>_o0000oh]BR006oh]BR0;o000000Koooooo`000?l0003o0000ooooool0001<
ooooo`03o`000?nW`>_oYl3[00koYl3[0_l00004ojO0j`03o`000?n;DXSoRe:800GoRe:80ol00002
ooooo`03o`000?oooooooooo04?ooooo00?o0000oo6_Pooa[h<02?oa[h<2o`0000koYl3[0ol00004
ojO0j`05o`000?nW`>_oYl3[ojO0jol000001On;DXP00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool02?ooool2o`0000koYl3[0ol00004ojO0j`05o`000?nW
`>_oYl3[ojO0jol000001On;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo
00Co0000oooooooooooooooo0ol0000>ojO0j`?o000000?oYl3[o`000?nW`>/00_nW`>/00ol0003o
Re:8oh]BR004oh]BR0Co000000?oooooo`000?ooool0>Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`00
;?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4?ooool3o`0000;ooooo0_l00013ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`00013o
oooo00?o0000ooooooooool0Foooool01?l0003oYl3[o`000?nW`>/3o`000004ojO0jol0003oYl3[
o`0000KoRe:800Co0000oooooooooooo00001Oooool00ol0003oooooooooo`19ooooo`;o00003?nW
`>/3o`000003ojO0jol0003oYl3[00CoYl3[00?o0000oh]BR?n;DXP01?n;DXP00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04;ooooo00?o0000oo6_Pooa[h<01Ooa[h<3o`0000goYl3[0ol0
0007ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01Oooool3o`0000goYl3[0ol0
0007ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03oooooo1?l0000>ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0
j`02ojO0j`03o`000?n;DXSoRe:800?oRe:800?o0000ooooooooool00oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Sooooo000/ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`?o00001?ooool2o`0004?ooooo0_l0
0002ooooo`;o00002oooool2o`00013ooooo0_l0001Kooooo`04o`000?nW`>_o0000o`0000CoYl3[
00Co0000ojO0jonW`>_o00001On;DXP01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooB_OOl000002?nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?nW`>/00ol0
003oRe:8oh]BR003oh]BR003o`000?oooooooooo00?ooooo00?o0000ooooooooool0@_ooool00ol0
003olJn3oo6_P`03oo6_P`;o00003OnW`>/3o`0000_oYl3[00?o0000ojO0jonW`>/00_nW`>/01Ol0
003oRe:8oh]BR?n;DXSo000000Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`03
ooooo`;o00003OnW`>/3o`0000_oYl3[00?o0000ojO0jonW`>/00_nW`>/01Ol0003oRe:8oh]BR?n;
DXSo000000Cooooo00?o0000ooooooooool0?oooool00ol0003oYl3[ojO0j`0<ojO0j`?o00001onW
`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?n;DXSoRe:800;oRe:800?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo000/ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0ol0
0006ooooo`;o0000A?ooool01Ol0003ooooooooooooooooo000000gooooo0_l0000Aooooo`03o`00
0?oooooooooo05Oooooo00Co0000ojO0jonW`>_o00001OnW`>/01?l0003oYl3[ojO0jol00005oh]B
R005o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`19ooooo`04o`000?od[ggo
m:mmo`0000CoYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00CoYl3[00?o0000oh]BR?n;DXP00_n;
DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00Co0000oo6_Pooa[h?olJn3
0ol0000<ojO0j`?o00003_nW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?n;DXSoRe:8o`0000Go
oooo00?o0000ooooooooool0>_ooool01?l0003oooooooooooooool3o`0000coYl3[0ol0000>ojO0
j`03o`000?nW`>_oYl3[00?oYl3[00Co0000oh]BR?n;DXSo00001?ooool2o`00043ooooo0_l0000:
ojO0j`?o00002_nW`>/00ol0003oYl3[ojO0j`04ojO0j`05o`000?n;DXSoRe:8oh]BR?l000001Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo000[ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo0ol00008ooooo`;o0000AOooool00ol0003oooooooooo`02o`0000gooooo00Co0000
ooooool0003o00004?ooool2o`0005Oooooo00Co0000ojO0jonW`>_o00001_nW`>/01?l0003oYl3[
ojO0jol00004oh]BR005o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`18oooo
o`04o`000?od[ggom:mmooB_O@Co00002onW`>/00ol0003oYl3[ojO0j`05ojO0j`05o`000?n;DXSo
Re:8oh]BR?l000001_ooool00ol0003oooooooooo`10ooooo`Co00003?nW`>/3o`00017oYl3[00?o
0000ojO0jonW`>/00onW`>/01?l0003oRe:8oh]BR?l00003ooooo`?o0000??ooool4o`0000coYl3[
0ol0000AojO0j`03o`000?nW`>_oYl3[00?oYl3[00Go0000oh]BR?n;DXSo0000ooooo`03o`000003
ooooool0003ooooo03oooooo00?o0000ooooool000001onW`>/2o`0000koYl3[00?o0000ojO0jonW
`>/01?nW`>/01?l0003oRe:8oh]BR?l00005ooooo`;o0000=oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Woooo
o`00:oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooooooo`03o`0000[ooooo00?o0000ooooool00000AOooool01?l0003oooooooooool0000?
ooooo`04o`000?oooooo0000o`00017ooooo00?o0000ooooooooool0E?ooool01?l0003oYl3[ojO0
jol00006ojO0j`04o`000?nW`>_oYl3[o`0000CoRe:800Go0000ooooooooooooooooo`000003oooo
o`?o0000B_ooool00ol0003om:mmo`000003o`0000goYl3[00?o0000ojO0jonW`>/01OnW`>/01Ol0
003oRe:8oh]BR?n;DXSo000000Cooooo0ol00012ooooo`;o00002onW`>/3o`0001?oYl3[0_l00006
ojO0j`03o`000?n;DXSo000000?o00000_ooool00ol0003oooooooooo`0jooooo`;o00002onW`>/3
o`0001?oYl3[0_l00006ojO0j`04o`000?n;DXSo0000o`0000Cooooo00?o0000ooooooooool0?_oo
ool01?l0003oooooooooool00003ojO0j`?o00004?nW`>/00ol0003oYl3[ojO0j`04ojO0j`04o`00
0?n;DXSoRe:8o`0000;ooooo0ol000000ooooooo0000ooooo`0fooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Ko
oooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000004_ooool2o`0000gooooo
0_l00016ooooo`03o`000?oooooo0000013ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o
0000EOooool01?l0003oYl3[ojO0jol00005ojO0j`05o`000?nW`>_oYl3[ojO0jol000000on;DXP0
0ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003oooooooooo`18ooooo`;o00000ood[gd0
0ood[gco0000ojO0j`0<ojO0j`03o`000?nW`>_oYl3[00GoYl3[00Go0000oh]BR?n;DXSo0000oooo
o`03o`0000;ooooo00?o0000ooooooooool0@?ooool00ol0003olJn3o`000007ojO0j`?o00004onW
`>/3o`000003ojO0jol0003oYl3[00KoYl3[0_l00005ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooool000001onW`>/3o`0001?oYl3[0ol000000onW`>_o0000ojO0j`06ojO0j`;o00001Ooo
ool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooooooo`?o00004onW`>/00ol0003oYl3[
ojO0j`05ojO0j`03o`000?n;DXSo000000;o00001Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`;o0000
9oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00_ooooo0_l00017ooooo`03o`000?oooooo0000013ooooo0_l00003ooooo`?o00004?oo
ool00ol0003oooooooooo`1Booooo`04o`000?nW`>_oYl3[o`0000CoYl3[0_l00003ojO0j`04o`00
0?n;DXSoRe:8o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03
o`000?od[ggom:mm00;om:mm0_od[g`00ol0003oYl3[ojO0j`09ojO0j`;o00002?nW`>/01?l0003o
Re:8o`000?l00006ooooo`03o`000?oooooooooo03oooooo00Co0000oo6_Pooa[h?o00000onW`>/3
o`0001?oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0000?oYl3[0ol0000CojO0j`?o00001?nW
`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Ooo
ool4o`000003ooooool0003o0000017oYl3[0ol00008ojO0j`;o00001oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0<ooooo`?o000000?oooooo`000?ooool09_ooool002_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`00000Aooooo`03o`000?oooooooooo00_ooooo0_l00018ooooo`?o00004Oooool2
o`0000Cooooo0_l0000?ooooo`;o0000Doooool01Ol0003oYl3[ojO0jol0003oYl3[00?o000000?o
Yl3[o`000?nW`>/00onW`>/00ol0003oRe:8o`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Aoooool00ol0003om:mmooB_O@02ooB_O@?om:ml00?o0000ojO0jonW`>/01OnW
`>/3o`000003ojO0jol0003oYl3[00SoYl3[0_l00007ooooo`03o`000?oooooooooo03oooooo00Co
0000oo6_Pooa[h?olJn30ol0000CojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`03ojO0j`;oRe:8
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooooooo`?o
00004onW`>/3o`0000SoYl3[00?o0000ojO0jonW`>/00onW`>/2oh]BR003o`000?oooooooooo00Co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?nW`>_oYl3[00_o
Yl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`09ooooo`?o00001?ooool00ol0003oooooooooo`0Uooooo`00:oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool02oooool2o`0004Wo
oooo0ol0000Aooooo`?o00001?ooool3o`0000cooooo00?o0000ooooool00000E?ooool01?l0003o
Yl3[o`000?l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool00ol0003om:mmooB_O@02ooB_O@Com:ml00Co0000ojO0
jonW`>_oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00SoYl3[00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0oooooo`Co000000?olJn3o`000?l000004?nW`>/3o`0000_oYl3[00?o0000
ojO0jonW`>/01On;DXP2o`0000?ooooo0ol0000kooooo`Co000000?oooooo`000?l000004?nW`>/3
o`0000_oYl3[00?o0000ojO0jonW`>/01On;DXP2o`0000?ooooo0ol0000oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ojO0jonW`>/01onW`>/3o`0000GoYl3[00?o0000ojO0jonW`>/01_nW`>/0
0on;DXSo0000ooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0ol00007ooooo`03o`000?oooooo
oooo02Gooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000BOooool2o`00
01?ooooo0_l00006ooooo`?o00002Oooool00ol0003oooooo`00001Eooooo`03o`000?nW`>_o0000
00KoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0_l00018ooooo`03o`000?od[ggom:mm00;om:mm1Ood[g`3o`0000SoYl3[00?o0000ojO0
jonW`>/01OnW`>/2oh]BR0;o00001Oooool3o`00043ooooo00?o0000oo6_Pooa[h<01?oa[h<00ol0
003oYl3[ojO0j`0:ojO0j`?o00003_nW`>/00ol0003oRe:8oh]BR005oh]BR003o`000?nW`>_o0000
00;o00000_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000ojO0
jonW`>/02_nW`>/3o`0000koYl3[00?o0000oh]BR?n;DXP01On;DXP00ol0003oYl3[o`000002o`00
00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?nW`>_oYl3[
00?oYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?n;DXP2o`0000Gooooo0ol0000doooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`?o00002_ooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`;o
0000B_ooool2o`0001?ooooo0_l00008ooooo`?o00001_ooool00ol0003oooooo`00001Fooooo`03
o`000?nW`>_o000000KoYl3[00?o0000ojO0jonW`>/00_nW`>/00on;DXSo0000o`000006ooooo`Co
000000?oooooo`000?ooool0B?ooool01?l0003om:mmooB_OOod[gd3ooB_O0;o000000?om:mlo`00
0?nW`>/02?nW`>/00ol0003oYl3[ojO0j`02ojO0j`GoRe:800Co0000ojO0jol0003ooooo0ol00002
ooooo`03o`000?oooooooooo03kooooo00?o0000oo6_Pooa[h<01Ooa[h<00ol0003oYl3[ojO0j`06
ojO0j`?o00003_nW`>/4oh]BR003o`000?n;DXSoRe:800GoRe:800?o0000ojO0jol000001?ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ojO0jonW`>/01_nW`>/3
o`0000koYl3[1?n;DXP00ol0003oRe:8oh]BR005oh]BR003o`000?nW`>_o000000Cooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?nW`>_o000000?o00002onW`>/0
0ol0003oYl3[oh]BR006oh]BR004o`000?nW`>_o0000ooooo`?o00000_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`03o`0000kooooo00?o0000ooooooooool09?ooool002[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool2
o`0004_ooooo0_l0000Dooooo`03o`000?oooooooooo00Sooooo0ol00003ooooo`04o`000?oooooo
ooooo`0005Oooooo00?o0000ojO0jol000001_nW`>/00ol0003oRe:8oh]BR002oh]BR003o`000?nW
`>_o000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`04o`000?od
[ggom:mmooB_O@?o00001?od[g`00ol0003oYl3[ojO0j`06ojO0j`03o`000?n;DXSoRe:800OoRe:8
00Co0000ojO0jonW`>_o00001Oooool00ol0003oooooooooo`0nooooo`03o`000?oa[h?olJn300Ko
lJn300?o0000ojO0jonW`>/00_nW`>/3o`0000koYl3[1On;DXP3o`0000OoRe:800Co0000ojO0jonW
`>_o00000oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ojO0
jonW`>/00_nW`>/3o`0000koYl3[1On;DXP3o`0000OoRe:800Co0000ojO0jonW`>_o00000oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo0ol0000>ojO0j`03oh]BR?l0003o
Re:800OoRe:800Co0000ojO0jonW`>_o00001Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool07?ooool3o`00017ooooo00?o0000ooooooooool09?oo
ool002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool2o`0004cooooo0_l0000Dooooo`;o00002oooool4
o`0000;ooooo00?o0000ooooooooool0Eoooool2o`0000CoYl3[0_n;DXP00ol0003oRe:8oh]BR002
oh]BR004o`000?nW`>_oYl3[o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`17ooooo`Co000000?om:mmooB_O?od[g`01Ood[g`00ol0003oYl3[ojO0j`03ojO0j`;oRe:800?o
0000oh]BR?n;DXP01on;DXP01Ol0003oYl3[ojO0jonW`>_o000000Cooooo00?o0000ooooooooool0
?_ooool00ol0003olJn3oo6_P`07oo6_P`Go00003OnW`>/5oh]BR0?o00000_n;DXP00ol0003oRe:8
oh]BR005oh]BR004o`000?nW`>_oYl3[o`0000?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`07ooooo`Go00003OnW`>/5oh]BR0?o00000_n;DXP00ol0003oRe:8oh]BR005oh]BR004
o`000?nW`>_oYl3[o`0000?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02oooo
o`?o00000_ooool00ol0003oYl3[ojO0j`0:ojO0j`CoRe:800?o0000oh]BR?n;DXP01_n;DXP01?l0
003oYl3[ojO0jol00004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Hooooo`?o000000?oooooo`000?ooool04Oooool00ol0003oooooooooo`0T
ooooo`00:_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`;o0000COooool2o`0001Gooooo00?o0000ooooooooool02?ooool4
o`0000?ooooo00?o0000ooooooooool0F?ooool00ol0003oYl3[oh]BR004oh]BR003o`000?n;DXSo
Re:800?oRe:800Co0000ojO0jonW`>_o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooB_OOod[gd00_od[gd8ooB_O003o`000?nW`>_oRe:800GoRe:800?o
0000oh]BR?n;DXP01_n;DXP01Ol0003oYl3[ojO0jonW`>_o000000Gooooo00?o0000ooooooooool0
?_ooool00ol0003olJn3oo6_P`04oo6_P`Co00003OnW`>/5oh]BR0?o00001_n;DXP00ol0003oRe:8
oh]BR004oh]BR005o`000?nW`>_oYl3[ojO0jol000000_ooool2o`0003[ooooo00?o0000oooooooo
ool01?ooool4o`0000goYl3[1On;DXP3o`0000KoRe:800?o0000oh]BR?n;DXP01?n;DXP01Ol0003o
Yl3[ojO0jonW`>_o000000;ooooo0_l0000nooooo`03o`000?oooooo000000;o00001_ooool00ol0
003oYl3[ojO0j`06ojO0j`GoRe:80ol00008oh]BR004o`000?nW`>_oYl3[o`0000Gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo0ol00004
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09?ooool002[ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooo`00001=ooooo`;o00005Oooool00ol0003oooooooooo`06ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000005_ooooo00?o0000oh]BR?n;DXP00on;DXP3o`0000CoRe:800Co
0000ojO0jonW`>_oYl3[0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooB_OOod[gd00_od[gd4ooB`O@Com;1l00?o0000oh]BR?n;DXP00on;DXP3o`0000SoRe:8
00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo
00Co0000oo6_Pooa[h?olJn30ol00004oo6_P`03o`000?nW`>_oYl3[00OoYl3[1On;DXP3o`0000Wo
Re:800?o0000oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`02ojO0j`;o000000?oooooo`000?oo
ool0>Oooool01?l0003oooooooooooooool3o`0000Cooooo00?o0000ojO0jonW`>/01onW`>/5oh]B
R0?o00002On;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?nW`>_oYl3[00;oYl3[0_l000000ooo
oooo0000ooooo`0mooooo`;o00002_ooool00ol0003oYl3[ojO0j`02ojO0j`GoRe:80ol00002oh]B
R003o`000?n;DXSoRe:800KoRe:800Go0000ojO0jonW`>_oYl3[o`000004ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`?o00001oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo000Zooooo`04o`000?oooooooooo
o`0000oooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000Coooool00ol0003ooooooooo
o`0Cooooo`;o00000_ooool5o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo05[ooooo0_l0
00001?n;DXSo0000o`000?l00002oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000ojO0jonW`>/0
0onW`>/3o`0000?ooooo0_l00018ooooo`03o`000?od[ggom:mm00;om:mm1Ood/7d3ooB`O003o`00
0?n;DXSoRe:800?o00000_n;DXP00ol0003oRe:8oh]BR006oh]BR003o`000?nW`>_oYl3[00?oYl3[
00?o0000ooooool000000_l00010ooooo`Co00002?oa[h<00ol0003oYl3[ojO0j`03ojO0j`GoRe:8
0ol0000=oh]BR003o`000?n;DXSoRe:800?oRe:800?o0000ojO0jonW`>/00onW`>/00ol0003ooooo
o`00000jooooo`Co00002?ooool00ol0003oYl3[ojO0j`03ojO0j`GoRe:80ol0000=oh]BR003o`00
0?n;DXSoRe:800?oRe:800?o0000ojO0jonW`>/00onW`>/00ol0003oooooo`00000nooooo`03o`00
0?oooooooooo00[ooooo00?o0000oh]BR?n;DXP00on;DXP3o`0000KoRe:800?o0000oh]BR?n;DXP0
1On;DXP00ol0003oYl3[ojO0j`02ojO0j`Go0000<_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00cooooo0ol0000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
9?ooool002[ooooo00?o0000ooooool000004Oooool00ol0003oooooo`00000=ooooo`;o0000D?oo
ool00ol0003oooooooooo`0Dooooo`?o00002?ooool01Ol0003ooooooooooooooooo000005cooooo
0ol00006oh]BR005o`000?n;DXSoRe:8oh]BR?l000001onW`>/4o`000003ooooool0003ooooo04So
oooo00?o0000ooB_OOod[gd00_od[gd4ooB`O@?om;1l0ol00006oh]BR003o`000?n;DXSoRe:800Go
Re:800?o0000ojO0jonW`>/00onW`>/2o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003o
lJn3oo6_P`0:oo6_P`03o`000?nW`>_oRe:800?oRe:81?l0000@oh]BR003o`000?n;DXSoRe:800?o
Re:800?o0000ojO0jonW`>/00onW`>/00ol0003oooooo`00000jooooo`03o`000?oooooooooo00[o
oooo00?o0000ojO0jon;DXP00on;DXP4o`00013oRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003o
Yl3[ojO0j`03ojO0j`03o`000?oooooo000003kooooo00?o0000ooooooooool02_ooool00ol0003o
Re:8oh]BR003o`0000WoRe:800?o0000oh]BR?n;DXP01On;DXP00ol0003oYl3[ojO0j`03ojO0j`04
o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08oooo
o`?o00003Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo000Yooooo`03
o`000?oooooo000001?ooooo00?o0000ooooooooool02oooool2o`00057ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000G_ooool00ol0
003oRe:8oh]BR005oh]BR005o`000?n;DXSoRe:8oh]BR?l000002?nW`>/2o`0000;ooooo00?o0000
ooooooooool0Aoooool00ol0003om:mmooB_O@02ooB_O@Com;1m1?l00008oh]BR003o`000?n;DXSo
Re:800GoRe:800?o0000ojO0jonW`>/01?nW`>/01?l0003oooooooooool00010ooooo`03o`000?oa
[h?olJn300[olJn300?o0000oh]BR?n;DXP00ol0000Doh]BR003o`000?n;DXSoRe:800?oRe:800?o
0000ojO0jonW`>/01?nW`>/2o`0003[ooooo00?o0000ooooooooool02_ooool00ol0003oRe:8oh]B
R003o`0001CoRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003oYl3[ojO0j`04ojO0j`;o0000?ooo
ool00ol0003oooooooooo`09ooooo`?o00003On;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?nW
`>_oYl3[00CoYl3[00?o0000ooooool00000<_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo0ol0000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08ooo
ool002Wooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000DOooool2
o`0001Gooooo00?o0000ooooooooool01_ooool2o`0000?ooooo00?o0000ooooooooool0G?ooool2
o`0000OoRe:800Co0000oh]BR?n;DXSo00002_nW`>/00ol0003oooooo`000019ooooo`04o`000?od
[ggom:mmooB_O@;om;1m0ol000001?od/7gom;1looB`O?l00009oh]BR003o`000?n;DXSoRe:800Co
Re:800?o0000ojO0jonW`>/01?nW`>/01?l0003oooooooooool00011ooooo`03o`000?oa[h?olJn3
00WolJn30ol0000Foh]BR0?o00001?n;DXP00ol0003oYl3[ojO0j`04ojO0j`;o0000>oooool00ol0
003oooooooooo`09ooooo`?o00005_n;DXP3o`0000CoRe:800?o0000ojO0jonW`>/00onW`>/3o`00
03oooooo00?o0000ooooooooool01_ooool4o`0000ooRe:800?o0000oh]BR?n;DXP01?n;DXP00ol0
003oYl3[ojO0j`05ojO0j`03o`000?oooooo0000033ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`03o`0001?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Soooo
o`00:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool0
0000D_ooool2o`0001Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
05oooooo0_l00007oh]BR005o`000?n;DXSoRe:8oh]BR?l000002_nW`>/00ol0003oooooo`000019
ooooo`03o`000?od[ggo000000;o00001Ood/7d00ood/7co0000oh]BR008oh]BR003o`000?n;DXSo
Re:800CoRe:800?o0000ojO0jonW`>/01OnW`>/00ol0003oooooo`000011ooooo`03o`000?oa[h?o
lJn300KolJn31?l0000Eoh]BR0?o00000_n;DXP00ol0003oRe:8oh]BR002oh]BR003o`000?nW`>_o
Yl3[00?oYl3[0ol0000kooooo`03o`000?oooooooooo00Kooooo1?l0000Eoh]BR0?o00000_n;DXP0
0ol0003oRe:8oh]BR002oh]BR003o`000?nW`>_oYl3[00?o00000_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?n;DXSoRe:800goRe:800?o0000
oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`06ojO0j`;o0000<?ooool00ol0003oooooooooo`0M
ooooo`;o00005?ooool3o`0001?ooooo00?o0000ooooooooool08oooool002Wooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000005Cooooo0_l0000Eoooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00001Pooooo`03o`000?n;DXSo
000000KoRe:800Co0000oh]BR?n;DXSoRe:80_l0000:ojO0j`;o0000BOooool2o`0000Wom;1m00?o
0000oh]BR?n;DXP01on;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?nW`>_oYl3[00KoYl3[0_l0
0011ooooo`03o`000?oa[h?olJn300?olJn30ol00002oo6_P`03o`000?n;DXSoRe:8013oRe:81?l0
0006oh]BR005o`000?n;DXSoRe:8oh]BR?l000000_nW`>/3o`0000;ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool00ol0003oRe:8oh]BR00@oh]BR0Co0000
1_n;DXP01?l0003oRe:8oh]BR?n;DXP3o`0000Gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooo`000002o`0000Kooooo00?o0000oh]BR?n;DXP03?n;DXP3o`0000GoRe:800?o0000ojO0jonW
`>/01OnW`>/3o`00033ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`?o
00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02?ooool2o`0005Gooooo0ol0000Dooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo05kooooo00?o0000oh]BR?l00000
1On;DXP3o`0000;oRe:800?o0000ooooool000001?l00004ojO0j`?o0000BOooool00ol0003om;1m
ooB`O@08ooB`O@03o`000?n;DXSoRe:800KoRe:80ol00005oh]BR003o`000?nW`>_oYl3[00GoYl3[
0ol00012ooooo`03o`000?oa[h?o000000;o00001Ooa[h<00ol0003oRe:8oh]BR00=oh]BR0?o0000
2_n;DXP01?l0003oRe:8oh]BR?n;DXP3o`0000Gooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooo`000002o`0000Gooooo00?o0000oh]BR?n;DXP03On;DXP3o`0000[oRe:800Go0000oh]BR?n;
DXSoRe:8o`000008ooooo`03o`000?oooooooooo03gooooo0_l00009ooooo`03o`000?n;DXSoRe:8
00WoRe:80ol00002oh]BR003o`000?n;DXSoRe:800?oRe:800?o0000ojO0jonW`>/00_nW`>/3o`00
00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00gooooo0ol00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool002[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`;o0000Eoooool2o`0001Co
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000006;ooooo0_l00002oh]B
R0?o00000_n;DXP01?l0003oRe:8oh]BR?l00006ooooo`Co00000_ooool00ol0003oooooooooo`18
ooooo`03o`000?od/7gom;1m00Oom;1m00?o0000oh]BR?n;DXP00_n;DXP4o`0000;oRe:800?o0000
oh]BR?n;DXP00on;DXP01?l0003oYl3[ojO0jonW`>/4o`0000;ooooo00?o0000ooooooooool0@?oo
ool2o`0000SolJn300?o0000oh]BR?n;DXP02On;DXP4o`0000koRe:800Co0000oh]BR?n;DXSo0000
2?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool00ol0003oRe:8oh]BR009oh]BR0Co0000
3_n;DXP01?l0003oRe:8oh]BR?l00008ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02?ooool00ol0003oRe:8oh]BR005oh]BR0Co00001_n;DXP00ol0003oRe:8oh]BR002oh]BR0Go
00001Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02_ooool3o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`00
:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
Eoooool3o`0001?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool0
HOooool01?l0003oRe:8o`000?l00006oh]BR004o`000?n;DXSoRe:8o`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?od/7gom;1m00Oom;1m1Ol00007oh]B
R003o`000?n;DXSoRe:800;oRe:81?l00006ooooo`03o`000?oooooooooo043ooooo00?o0000oo6_
Pooa[h<01ooa[h<00ol0003oRe:8oh]BR006oh]BR0?o00004_n;DXP01?l0003oRe:8oh]BR?l00006
ooooo`?o0000>oooool00ol0003oooooooooo`07ooooo`03o`000?n;DXSoRe:800KoRe:80ol0000B
oh]BR004o`000?n;DXSoRe:8o`0000Kooooo0ol00010ooooo`03o`000?oooooooooo00Oooooo00Co
0000oh]BR?n;DXSoRe:81?l0000:oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000ooooooooool0
1oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool4o`0000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`00:_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000FOoo
ool3o`0001;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000006Cooooo
0_l00007oh]BR004o`000?n;DXSoRe:8o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`19ooooo`05o`000?od/7gom;1mooB`OOod/7h00_od/7d3o`0000_oRe:800?o0000oh]B
R?n;DXP00_n;DXP00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo00?o0000oo6_
Pooa[h<01_oa[h<00ol0003oRe:8oh]BR002oh]BR0Co00005?n;DXP3o`000004oh]BR?l0003ooooo
ooooo`Co00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000
oh]BR?n;DXP00_n;DXP4o`0001CoRe:80ol000001?n;DXSo0000ooooooooool4o`0000;ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`Co00003on;DXP01Ol0003oRe:8oh]B
R?n;DXSo000000Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00?ooooo0ol0000Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool002_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000005[ooooo00?o0000ooooooooool00_l0000@ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`1Sooooo`03o`000?n;DXSo000000OoRe:800?o0000oh]BR?l00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Wooooo00?o0000ooB`OOod/7d0
1?l000000ood/7go0000oh]BR00<oh]BR005o`000?n;DXSoRe:8oh]BR?l000002?ooool3o`0004;o
oooo00?o0000oo6_Pooa[h<01_oa[h<00ol0003oRe:8o`000002o`0001CoRe:81?l00002oh]BR003
o`000?n;DXSoRe:800;o00001_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Ko
oooo00?o0000oh]BR?l000000_l0000Doh]BR0Co00000_n;DXP00ol0003oRe:8oh]BR002o`0000Ko
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`Co00004_n;DXP01Ol0003o
Re:8oh]BR?n;DXSo000000Oooooo0ol0000_ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00ol0000Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool002_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`;o0000G?ooool00ol0003o
ooooooooo`02o`0000oooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo06?o
oooo00Co0000oh]BR?n;DXSo00001_n;DXP00ol0003oRe:8o`000006ooooo`03o`000?oooooooooo
00?o0000C?ooool2o`0000?om;1n0_od/7d00ol0003oRe:8oh]BR00;oh]BR005o`000?n;DXSoRe:8
oh]BR?l000001Oooool3o`0000;ooooo00?o0000ooooooooool0@Oooool00ol0003olJn3oo6_P`03
oo6_P`Co00004on;DXP4o`0000OoRe:800?o0000oh]BR?l000001_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00?ooooo1?l0000Coh]BR0Co00001on;DXP00ol0003oRe:8o`000006
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00ol00003ooooo`03o`000?n;DXSo
Re:800ooRe:80ol00002oh]BR003o`000?oooooooooo00;ooooo0ol00002ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool07Oooool4o`0001[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Rooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo0_l0001Mooooo`04o`000?ooooooooooooooo`?o00003Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo06Gooooo0ol00006oh]BR0;o000000?oRe:8o`000?ooool01?oo
ool3o`0000;ooooo00?o0000ooooooooool0B_ooool00ol0003om;1nooB`OP03ooB`OP03ooB`OOl0
003oRe:800_oRe:80ol00002oh]BR003o`000?oooooo000000?o00001Oooool00ol0003ooooooooo
o`11ooooo`03o`000?oa[h?olJn300?o00000_oa[h<00ol0003oRe:8oh]BR00>oh]BR0Co00003?n;
DXP2o`0000Cooooo0ol0000nooooo`03o`000?oooooooooo00?o00000_ooool00ol0003oRe:8oh]B
R00>oh]BR0Co00003?n;DXP2o`0000Cooooo0ol00013ooooo`;o00001_ooool00ol0003oRe:8oh]B
R00<oh]BR0?o00000on;DXP00ol0003oRe:8oh]BR004o`0000Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Jooooo`?o000000?oooooo`000?ooool07?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02;ooooo000/ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00ol0003oooooo`00001Nooooo`03o`000?oooooooooo00;ooooo0ol0000;
ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool0J?ooool2o`0000;oRe:80ol0
00001?n;DXSo0000oh]BR?l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Boooool00ol0003om;1nooB`OP03ooB`OP03o`000?n;DXSoRe:800KoRe:81?l00003oh]BR004o`00
0?n;DXSoRe:8o`0000Sooooo00?o0000ooooooooool0@oooool2o`0000GolJn300?o0000oh]BR?n;
DXP02_n;DXP4o`0000ooRe:81ol00002ooooo`03o`000?oooooooooo03gooooo0_l00005ooooo`03
o`000?n;DXSoRe:800[oRe:81?l0000?oh]BR0Oo00000_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo00Gooooo00?o0000oh]BR?n;DXP02?n;DXP4o`0000OoRe:800?o0000oh]BR?l0
00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo0ol00004ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`00
;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
Goooool00ol0003oooooooooo`04ooooo`?o00002Oooool3o`0000?ooooo00?o0000ooooooooool0
JOooool3o`0000GoRe:80_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Boooool00ol0003om;1nooB`OP03ooB`OP03o`000?n;DXSoRe:800;oRe:81?l00008oh]BR003o`00
0?n;DXSo000000Kooooo0ol00015ooooo`03o`000?oa[h?olJn300ColJn300?o0000oh]BR?n;DXP0
1on;DXP3o`0000ooRe:81ol000000ooooooo0000ooooo`03o`00043ooooo00?o0000ooooooooool0
1?ooool00ol0003oRe:8oh]BR007oh]BR0?o00003on;DXP7o`000003ooooool0003ooooo00?o0000
AOooool00ol0003oooooooooo`04ooooo`03o`000?n;DXSoRe:800GoRe:80ol0000<oh]BR0;o0000
1Oooool3o`0002oooooo00?o0000ooooooooool05Oooool3o`0000Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo000/ooooo`03o`000?oo
oooooooo00oooooo00Oo0000ooooooooooooooooo`000?oooooo0000067ooooo00?o0000oooooooo
ool01Oooool3o`0000Oooooo0_l00003ooooo`03o`000?oooooooooo06_ooooo00?o0000oh]BR?n;
DXP01On;DXP2o`0000?ooooo00?o0000ooooooooool01?l0001>ooooo`03o`000?od/7kom;1n00;o
m;1n00?o0000oh]BR?l000000_l0000=oh]BR0;o00000oooool3o`0000;ooooo00?o0000oooooooo
ool0A?ooool00ol0003olJn3oo6_P`03oo6_P`03o`000?n;DXSoRe:800?oRe:81?l0000?oh]BR0Oo
00000oooool4o`000003ooooool0003ooooo043ooooo00?o0000ooooooooool00oooool00ol0003o
Re:8oh]BR003oh]BR0Co00003_n;DXP7o`0000Cooooo1Ol00017ooooo`03o`000?oooooooooo00?o
oooo00?o0000oh]BR?n;DXP00_n;DXP3o`0000koRe:82?l00002ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool04Oooool4o`0000[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo000]ooooo`03o`000?oooooooooo00kooooo
00Co0000oooooooooooooooo0_l0001Rooooo`;o00002?ooool5o`0000?ooooo0_l00003ooooo`03
o`000?oooooooooo06cooooo00?o0000oh]BR?n;DXP01?n;DXP3o`0000;ooooo0ol00002ooooo`03
o`000?oooooooooo04gooooo00?o0000ooB`O_od/7h01?l0000?oh]BR0Ko00001?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oa[h?olJn300;olJn300?o0000oh]BR?l000000ol0000?oh]BR0Oo
00000oooool4o`0000;ooooo0ol00013ooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?l0
00000ol0000>oh]BR0Oo00001?ooool6o`0004[ooooo00?o0000ooooooooool00oooool5o`0000go
Re:82?l00003ooooo`?o0000<?ooool00ol0003oooooooooo`0>ooooo`?o00003_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool002gooooo
00?o0000ooooooooool03_ooool01_l0003oooooooooool0003oooooo`0006?ooooo00?o0000oooo
ooooool02_ooool7o`000003ooooool0003ooooo06oooooo00?o0000oh]BR?n;DXP00ol00003oooo
o`03o`000?oooooo000000;ooooo0_l0001Aooooo`;o00000_od/7h00ol0003oRe:8oh]BR00:oh]B
R0Ko00000_ooool01?l0003oooooooooooooool3o`0004Sooooo00?o0000oo6_Pooa[h<01?l0000?
oh]BR0Oo00001?ooool3o`0000;ooooo1?l00016ooooo`03o`000?oooooooooo00Co00003_n;DXP8
o`0000Cooooo1Ol0001?ooooo`03o`000?oooooooooo00?o00003On;DXP7o`0000?ooooo1Ol00000
0ooooooo0000ooooo`0`ooooo`03o`000?oooooooooo00_ooooo0ol0000Aooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`00;Oooool00ol0
003oooooooooo`0>ooooo`05o`000?oooooo0000ooooool00000IOooool00ol0003oooooooooo`0<
ooooo`Go0000L_ooool2o`0000Kooooo1_l0001Cooooo`04o`000?od/7kom;1no`0000SoRe:81ol0
0004ooooo`Go000000?oooooo`000?ooool0BOooool2o`0000;olJn300?o0000oh]BR?n;DXP02_n;
DXP7o`0000Cooooo1?l000000ooooooo0000o`000002o`0004_ooooo0_l00002ooooo`03o`000?n;
DXSoRe:800[oRe:81ol00004ooooo`Ko0000Doooool2o`000003ooooool0003oRe:800SoRe:82?l0
0003ooooo`Go00000_ooool3o`0003;ooooo00?o0000ooooooooool01oooool4o`0001Cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo000^
ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000ooooo`1Vooooo`03o`000?oooooo
oooo00Wooooo0ol00002ooooo`;o0000M?ooool00ol0003oooooooooo`08o`0005Gooooo00?o0000
ooB`O_l000001On;DXP3o`0000;omK5l0_l00004ooooo`Go000000Coooooo`000?l0003o0000C?oo
ool01?l0003olJn3oo6_Pol00008oh]BR0So00000oooool4o`000003ooooool0003o000000;o0000
Coooool01?l0003oooooooooool00009oh]BR0Oo00001?ooool6o`0005Sooooo00?o0000ooooool0
00001On;DXP4o`000003ooooool0003o000000Cooooo1_l000000ooooooo0000o`000002o`0003Go
oooo00?o0000ooooooooool01?ooool3o`0001Sooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo000^ooooo`[o00001_ooool00ol0003ooooo
o`00001Xooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`;o0000M_ooool6o`0005[o
oooo0_l000000on;DXSo0000o`000002o`0000;omK5m0ooe/G`00ol0003oooooo`000009o`00053o
oooo00?o0000oo6_Pol000001On;DXP3o`0000;olJn30_l00003ooooo`Wo0000E?ooool00ol0003o
ooooo`000005oh]BR0Co000000?oooooo`000?l000001?ooool6o`0005gooooo0_l000000on;DXSo
0000o`000002o`0000Gooooo00?o0000ooooooooool01Ol000000ooooooo0000o`000002o`0003So
oooo00?o0000ooooooooool00_ooool3o`0001_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo000`ooooo`03o`000?oooooooooo00Gooooo
2?l0001Zooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co0000f?ooool2o`0000;om;1m
0_od/Gd3ooFaO@Wo0000E_ooool2o`000003oh]BR?l0003o000000;o00001Ooa[h<9o`0005[ooooo
0_l000000on;DXSo0000o`000002o`0000Gooooo00?o0000ooooool000001_l0001Qooooo`;o0000
2?ooool5o`0000;ooooo0ol0000looooo`03o`000?oooooo000000;o00007_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool0037ooooo00?o
0000ooooooooool02Oooool00ol0003oooooo`00001/ooooo`;o00001oooool4o`000=_ooooo0_l0
0002ooBaO@So0000Foooool2o`0000OolJn31ol0001Oooooo`;o00002?ooool6o`0006Oooooo0_l0
0002ooooo`Ko000000?oooooo`000?l000000_l0000oooooo`;o00008Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool003;ooooo0_l00008
ooooo`03o`000?oooooo000006kooooo0_l00005ooooo`Co0000g_ooool5o`0006;ooooo00?o0000
oo6_Pooa[h<01ol0001Uooooo`;o00000_ooool6o`0006gooooo0ol000000ooooooo0000o`000003
o`0004Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08Oooool003Cooooo00?o0000ooooooooool01Oooool2o`00
073ooooo1_l0003ooooood_ooooo1Ol0001[ooooo`Go0000Loooool2o`0004[ooooo0_l0000Noooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Poooo
o`00=Oooool2o`0000Cooooo0_l0003ooooooooooooonOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`00
=oooool01Ol0003ooooooooooooooooo00000?oooooooooooookooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023o
oooo000hooooo`03o`000?oooooo00000?ooooooooooooomooooo`;o00006Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool003Wooooo00?o
0000ooooooooool0ooooooooooooookooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Yooooo`05o`000?ooooooooooooooool000008_ooool00?oooooooooooooooooooccooooo0_l0
000Fooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00008_ooool00?oooooooooo
ooooooooockooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Zooooo`04o`000?oo
ooooooooo`0002;ooooo003oooooooooooooooooooloooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:oooool01?l0003oooooooooool0000Qooooo`00oooooooooooooooooooo@?oo
ool2o`0001;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00000Qooooo`00oooooooo
oooooooooooo@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo0_l0000Q
ooooo`00oooooooooooooooooooo@oooool2o`0000oooooo00?o0000ooooooooool0;?ooool3o`00
027ooooo003ooooooooooooooooooom5ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0:?ooool4o`0002Cooooo003ooooooaCooooo0ol0001Yooooo`?o0000LOooool4o`00027ooooo
0ol0001Fooooo`Co0000c_ooool2o`0000cooooo00?o0000ooooooooool09?ooool4o`0002Sooooo
003ooooooaGooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1`ooooo`05o`000?oo
ooooooooooooool000008Oooool00ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool0
0000coooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo1?l0000/ooooo`00
=?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l0
00001?l00004ooooo`So00000_ooool01?l0003oooooo`000?ooool2o`0003Sooooo0ol00003oooo
o`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000;ooooo0ol00003oooo
o`?o00000_ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol00004ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0003?ooooo0ol00003
ooooo`?o00000_ooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool5o`000003ooooool0
003o000000;ooooo3?l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000Co0000=_oo
ool3o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l00002ooooo`Go0000
00?oooooo`000?l000000_ooool9o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000;?ooool01?l0003oooooooooool00003
ooooo`;o00000_ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1Ol0
0003ooooo`;o00000_ooool3o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000
o`000?l00003ooooo`?o000000?oooooo`000?l000001?l00002ooooo`05o`000?ooooooooooo`00
0?ooool00_l00002ooooo`;o0000<_ooool01?l0003oooooooooool00003ooooo`;o00000_ooool4
o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`So00000_oo
ool01?l0003oooooo`000?ooool2o`0004[ooooo00Co0000oooooooooooo00000_ooool3o`000003
ooooool0003ooooo00;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003oooo
o`03o`000?oooooo000004kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`Co0000<?ooool003Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool2
o`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo000003Wooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00Co0000oooooooooooo00000oooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_l0000eooooo`04o`000?oooooo
ooooo`0000;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00001?ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;o
oooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooo000000Cooooo00?o0000oooo
ooooool0<oooool01?l0003oooooooooool00002ooooo`0:o`000?ooooooooooo`000?oooooo0000
ooooool0003oooooo`0000Cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000;Ooo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo037ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001?ooool01ol0003oooooo`000?oooooo0000ooooool00000Boooool01?l0003oooooooooool0
0003ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooo0000
00?ooooo00Oo0000ooooool0003oooooo`000?oooooo000004kooooo0_l00008ooooo`03o`000?oo
oooooooo01Sooooo1?l0000dooooo`00=Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooooooo`;o00000oooool00ol0003oooooo`000002ooooo`?o00000oooool01?l0003ooooo
ooooool00002ooooo`;o00000_ooool01Ol0003oooooo`000?oooooo000003cooooo00?o0000oooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000001_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooo`00
0?ooool4o`000004ooooool0003oooooo`0000Oooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`05o`0003Gooooo00Co0000oooooooooooo00000_ooool01_l0003oooooo`000?oooooo
0000ooooo`Co000000Ooooooo`000?ooooooooooo`000?oooooo000000Cooooo0_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo1?l000001?oooooo0000ooooool00002ooooo`;o0000>Oooool0
1?l0003oooooooooool00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000001ooooooo
0000oooooooooooo0000ooooool000001?ooool2o`0000;ooooo00[o0000oooooooooooo0000oooo
ool0003oooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooool00000;?ooool01ol0003oooooo`000?l0003oooooo`000?ooool0
1Ol00002ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000000_l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooo000000?o000000?oooooo`000?l000000_ooool01Ol0003ooooo
o`000?oooooo000000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`0a
ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`05o`0000;ooooo00?o0000ooooooooool0
0ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000?ooooo00Co0000oooooooo
oooo00000_ooool2o`0000;ooooo00Go0000ooooool0003oooooo`00001:ooooo`06o`000?oooooo
0000o`000?oooooo00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool0
0ol0003oooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`00001@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04oooool5o`0003Sooooo000eooooo`Co00000_oo
ool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01Ol0003oooooo`000?oo
oooo000003[ooooo0_l00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000001_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003ooooo
o`000007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`00
0?oooooooooo037ooooo0_l00003ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003o
ooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool02_l0003oooooooooool0003ooooo
o`000?oooooo0000ooooool0000iooooo`;o00000oooool02_l0003oooooooooool0003oooooo`00
0?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00002ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003o
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000002cooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003
o`0000;ooooo00Co0000oooooooooooo00000_ooool02?l0003oooooooooool0003oooooo`000?oo
oooo00000oooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000booooo`08o`00
0?oooooo0000o`000?oooooo0000ooooool00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000Cooooo00Go0000ooooool0003oooooo`00001:ooooo`06o`00
0?oooooo0000o`000?oooooo00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo0000
0_ooool00ol0003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`1>ooooo`;o00001Oooool00ol0003oooooooooo`0?ooooo`Co0000?Oooool003Gooooo
00Go0000ooooooooooooooooo`000002ooooo`?o00000_ooool3o`000006ooooool0003o0000o`00
0?oooooo00000_ooool00ol0003oooooo`000004o`0000;ooooo2?l0000jooooo`03o`000?oooooo
oooo00?ooooo0ol00002ooooo`04o`000?oooooo0000o`0000;ooooo0ol000000ooooooo0000oooo
o`06ooooo`?o000000?oooooo`000?l000001?l00003ooooo`;o000000?oooooo`000?l000000_l0
0006ooooo`;o000000Coooooo`000?oooooooooo0ol00002ooooo`;o0000<oooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo
1Ol00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l000001?oooooo0000o`000?l00003oooo
o`?o0000=Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo00;o00000oooool2o`00
0004ooooool0003o0000ooooo`Ko000000Goooooo`000?l0003o0000ooooo`03o`0002[ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo0ol000001?oooooo0000
o`000?l00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooo
oooo0000o`000002ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`Co00000_ooool01Ol0
003oooooo`000?l0003ooooo00Ko000000Coooooo`000?l0003ooooo0ol0000`ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_l00002ooooo`?o000000Coooooo`000?l0003o
00000oooool2o`0000;ooooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo2?l0001:oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`0000?ooooo0ol0
0002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00001Booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02oooool4o`00047ooooo000eooooo`05o`000?oooooo
ooooooooool000003?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo04Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00;ooooo0_l0000Fooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`0goooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
0016ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`02o`0000?ooooo0_l0000looooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000004Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000>?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0001Jooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool000002Oooool4
o`0004Gooooo000dooooo`Go00003_ooool5o`0000Kooooo00?o0000ooooooooool0@oooool3o`00
00Kooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`000003ooooool0003o
oooo01Kooooo0_l000000ooooooo0000ooooo`05ooooo`;o0000>_ooool3o`0000Kooooo0_l0000;
ooooo`03o`000?oooooooooo00Oooooo0_l000001?oooooo0000o`000?l00016ooooo`?o00001_oo
ool2o`0000_ooooo00?o0000ooooooooool01oooool2o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000ooooo`0gooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Gooooo
0_l0000:ooooo`Go00004oooool3o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo03_ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`0000[ooooo1?l00006ooooo`03
o`000?oooooooooo057ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00002?ooool2o`00
067ooooo0_l000000ooooooo0000ooooo`04ooooo`Co0000BOooool00?oooooooooooooooooooe?o
oooo0_l000000ooooooo0000o`000002o`0004gooooo003ooooooooooooooooooomDooooo`;o0000
DOooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooooooooooo
ooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooo
ooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWoooo
o`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo0018ooooo`;o0000j_oo
ool2o`000=kooooo0_l0003ooooooeWooooo0_l0000dooooo`00AOooool3o`000003ooooool0003o
oooo0>Kooooo0ol000000ooooooo0000ooooo`3Jooooo`?o000000?oooooo`000?ooool0oooooomE
ooooo`?o000000?oooooo`000?ooool0<oooool004?ooooo0_l00004ooooo`;o0000i?ooool2o`00
00?ooooo0ol0003Hooooo`;o00000oooool2o`000>kooooo00?o0000ooooooooool0HOooool3o`00
00?ooooo0_l0000dooooo`00@?ooool3o`0000Kooooo00?o0000ooooool00000h?ooool3o`0000Go
oooo0_l000000ooooooo0000ooooo`3Cooooo`?o00001Oooool2o`000>kooooo00?o0000oooooooo
ool0Goooool2o`0000Kooooo0_l0000dooooo`00?oooool00ol0003oooooooooo`07ooooo`Co0000
gOooool2o`0000Oooooo00Go0000o`00F?l0003oooooo`00003Booooo`;o00001oooool00ol0003o
ooooo`00003]ooooo`?o0000GOooool3o`0000Oooooo00?o0000ooooool00000=?ooool003oooooo
00?o0000ooooooooool01Oooool3o`0000?ooooo00?o0000ooooooooool0eoooool3o`0000Wooooo
00?o0000o`00F?l000000_ooool00ol0003oooooooooo`3<ooooo`?o00002Oooool00ol0003ooooo
o`00003/ooooo`05o`000?oooooo0000ooooool00000FOooool3o`0000[ooooo00?o0000ooooool0
0000=?ooool003oooooo00?o0000ooooooooool00_ooool3o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3Dooooo`;o00003?ooool00ol0003o001Ho`000002ooooo`03o`00
0?oooooooooo0<[ooooo0_l0000;ooooo`04o`000?ooooooooooo`000>_ooooo00Ko0000oooooooo
oooo0000ooooool0001Fooooo`?o00003?ooool01?l0003oooooooooool0000dooooo`00?oooool0
0ol0003oooooo`000002o`0000Cooooo0_l00004ooooo`;o0000d_ooool3o`0000gooooo00Co0000
o`00F?l005So00000oooool00ol0003oooooooooo`36ooooo`?o00003Oooool01?l0003ooooooooo
ool0003Zooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1Aooooo`;o
00003oooool01Ol0003ooooooooooooooooo000003?ooooo000nooooo`?o00001?ooool3o`000003
ooooool0003ooooo00?o000000?oooooo`000?ooool0coooool2o`00013ooooo00Co0000o`00F?l0
05So00001?ooool00ol0003oooooooooo`33ooooo`;o00004?ooool01?l0003oooooooooool0003Y
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000Coooool3o`00013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`00?_ooool2o`0000;ooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`3:ooooo`?o00004Oooool01Ol0003o001Ho`00F?l0
05So000000Cooooo00?o0000ooooooooool0`?ooool3o`00017ooooo00Go0000oooooooooooooooo
o`00003Xooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000C?ooool3o`0001?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`00?_ooool4o`0000Gooooo
0ol00006ooooo`03o`000?oooooooooo06Cooooo1?l0001Pooooo`;o00005?ooool01Ol0003o001H
o`00F?l005So000000Gooooo00?o0000ooooooooool0_Oooool2o`0001Cooooo00Go0000oooooooo
ooooooooo`00003Wooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00001:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0a
ooooo`00?_ooool00ol0003oooooo`000003ooooo`?o00000_ooool00ol0003oooooooooo`04oooo
o`;o0000Hoooool3o`0000;ooooo0ol0001Kooooo`?o00005Oooool00ol0003o001Ho`00F003o`00
F003o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool3o`0001Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Looooo`Ko0000POooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool003kooooo00Co0000ooooool0
003ooooo0_l00005ooooo`04o`000?ooooooooooooooo`?o000000?oRe:8o`000?l00000HOooool6
o`0000?ooooo00?o0000ooooooooool0E_ooool2o`0001Sooooo00?o0000o`00F?l005P00ol005P0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Oooooo0_l0000Hooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0F?ooool7o`0000?ooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool2
o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`00?_ooool01?l0
003oooooooooool00007ooooo`Co00001?n;DXP00ol0003oooooo`00001Nooooo`Ko00001Oooool2
o`0005Cooooo0ol0000Jooooo`03o`000?l005So001H00?o001H00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2cooooo`?o00006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05Gooooo2Ol00004ooooo`;o0000OOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool2o`0001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0aooooo`00?_ooool01?l0003oooooooooool00005ooooo`?o00001on;DXP0
1?l0003oooooo`000?l0001Looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
o`000002o`0000;ooooo00?o0000ooooooooool0Coooool2o`0001cooooo00?o0000o`00F?l005P0
1?l005P00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;7ooooo0_l0000Looooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool7o`0000?ooooo00Co0000ooooool0003o
00000_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`14ooooo`;o00004oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo037ooooo000nooooo`06o`000?ooooooooooooooool0003ooooo0ol000000on;
DXSo0000o`000008oh]BR003o`000?oooooo000005cooooo00?o0000ooooooooool00_l00003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool3o`0001kooooo00?o0000o`00
F?l005P01?l005P00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:gooooo0ol0000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool2o`000004ooooool0003ooooo
ooooo`;o00000_ooool3o`0000Gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooo`00000C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<Oooool003kooooo00?o0000oooo
ooooool00_ooool00ol0003oRe:8o`000002o`000003oh]BR?l0003oRe:800OoRe:800Co0000oooo
oooooooo0000F_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00oooool2
o`0004_ooooo00?o0000ooooooooool07_ooool00ol0003o001Ho`00F005o`00F003o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0AOoooolBo`0005Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01?l00000
1?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo00;ooooo0_l0001gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooo000001;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`00?_ooool0
1?l0003oooooooooooooool3o`0000CoRe:800?o0000oh]BR?n;DXP01_n;DXP01Ol0003ooooooooo
oooooooo000005Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0_l000000on;DXSo0000ooooo`1:ooooo`;o00007oooool00ol0003o001Ho`00F005o`00F003o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool4o`0000[ohYb40ol00004ojZmi`Go0000
D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
D_ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000Cooooo00Ko0000ooooool0
003o0000oh]BR?l0001fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0aooooo`00?_ooool4o`000003ooooool0003oRe:800CoRe:800?o0000
oh]BR?n;DXP01_n;DXP00ol0003oooooooooo`03o`0005Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?n;DXSoRe:800;oRe:80_l0001:ooooo`03o`000?oooooo
000001gooooo00?o0000o`00F?l005P01_l005P00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03gooooo0ol00005on:LQ0Ko/Vn60ol0000<ojZmi`Co0000C?ooool2o`0001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`?o000000?oooooo`000?ooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0ol00003oh]BR0;o0000M?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool01?l0003ooooooooo
ool0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<?ooool003kooooo00?o
0000ooooooooool00_ooool00ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800KoRe:80ol0
0002ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?n;DXSoRe:800;oRe:800?o0000ooooool00000BOooool01?l0003ooooooooo
ool0000Looooo`03o`000?l005So001H00Ko001H00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0jooooo`Go000000?ohYb4okZR4_nbKhH02?nbKhH00ol0003oooooojZmi`0AojZmi`Co0000
B?ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000;o
Re:800Oo0000oh]BR?n;DXSoRe:8o`000?oooooo000007;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`;o0000@_ooool01?l0003oooooooooool0000@ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0<?ooool003kooooo00?o0000ooooooooool00_ooool0
0ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800KoRe:800?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?n;DXSo
Re:800?oRe:800Co0000ooooool0003o0000B?ooool01Ol0003ooooooooooooooooo000001[ooooo
00?o0000o`00F?l005P01ol005P00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo
1Ol000000ooRW8Co^Z8BokZR4P07ok9_QP;o00006?nZ_NL5o`000003ooooool0003ooooo03oooooo
00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0D?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00004ooooo`05o`000?n;DXSoRe:8
oh]BR?l000000on;DXP00ol0003oooooo`00001aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000011ooooo`05o`000?ooooooooooooooool000004?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo033ooooo000nooooo`03o`000?oooooo
oooo00;ooooo00?o0000oh]BR?n;DXP00on;DXP00ol0003oRe:8oh]BR006oh]BR003o`000?oooooo
oooo00?ooooo0_l0001Dooooo`03o`000?oooooo000000;o000000?oYl3[o`000?ooool01Oooool0
0ol0003oRe:8oh]BR003oh]BR0;o000000?oooooo`000?ooool0A_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o0000o`00F?l005P01ol005P00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Oooooo0_l000001OnjXQ;o0000o`000?oRW8Cooooo00;o00001Onb
KhH2o`0001ooZ[gW0_l00010ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooooooo
1?l000000onW`>_o0000ooooo`03ooooo`05o`000?n;DXSoRe:8oh]BR?l000000on;DXP4o`0006oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000047o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0<?ooool003kooooo00?o0000ooooooooool00_ooool00ol0003oRe:8oh]BR003oh]BR003
o`000?n;DXSoRe:800KoRe:800?o0000ooooooooool00ol000000ooooooo0000ooooo`1Cooooo`;o
00001?nW`>/2o`0000Cooooo00?o0000oh]BR?n;DXP01?n;DXP01Ol0003ooooooooooooooooo0000
04Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?l005So001H
00Oo001H00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eooooo`;o000000Co^Z8Bo`00
0?l0003ohYb40oooool2o`000004ok9_Q_l0003o0000o`0002;oZ[gW0_l0000oooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04oooooo00Co0000oooooooooooooooo0_l00004ojO0j`;o00000oooool01Ol0003oRe:8
oh]BR?n;DXSo000000?oRe:800Co0000oooooooooooo0000K_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000@?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`
ooooo`00?_ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800;oRe:80_l00008oh]B
R0?o00001?ooool00ol0003oooooooooo`1Booooo`03o`000?nW`>_oYl3[00?oYl3[00?o0000ojO0
jol000000_ooool00ol0003oRe:8oh]BR005oh]BR005o`000?ooooooooooooooool00000A_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000o`00F?l005P02?l005P0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Cooooo0_l000000onjXQ;o0000o`000005
ooooo`;o00009OnZ_NL2o`0003oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Coooool4o`000003ojO0jol0003o
Yl3[00?oYl3[00?o0000ojO0jol000000_ooool01Ol0003oRe:8oh]BR?n;DXSo000000?oRe:800Go
0000ooooooooooooooooo`00001/ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`05o`00
0?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0`ooooo`00?_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?n;DXSo000000;o000000?oYl3[o`000?n;DXP01on;DXP00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ojO0jonW`>/00onW`>/01_l0003oYl3[
ojO0jol0003oooooo`0000OoRe:800Go0000ooooooooooooooooo`000016ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04oooool00ol0003o001Ho`00F008o`00F003o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0=?ooool01?l0003o^Z8Bo`000?l00006ooooo`03ojZmiol0
003oZ[gW02CoZ[gW0_l0000oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo00?o0000ojO0jonW`>/00_nW
`>/2o`0000?oYl3[00Ko0000ojO0jonW`>_o0000ooooool00003oh]BR005o`000?n;DXSoRe:8oh]B
R?l000001?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0<?ooool003kooooo00Co0000oooooooooooooooo0ol00004ojO0j`;o00001on;DXP00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ojO0jonW`>/00onW`>/01Ol0
003oYl3[ojO0jonW`>_o000000SoRe:800?o0000ooooooooool00_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o001Ho`00F009
o`00F003o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool4o`0000Sooooo00?oZ[gW
o`000?nZ_NL08onZ_NL2o`0003oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Coooool2o`0000?oYl3[00?o0000
ojO0jol000000_nW`>/01?l0003oYl3[ojO0jonW`>/2o`0000?oRe:800Co0000oh]BR?n;DXSoRe:8
0_l00003ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool04_ooool01ol0003ooooo
oooooooooooo0000ooooool000001Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
033ooooo000nooooo`Co00001onW`>/00ol0003oYl3[o`000006oh]BR003o`000?oooooooooo00Co
oooo00?o0000ooooooooool0D_ooool2o`0000CoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003o
Re:8oh]BR005oh]BR003o`000?oooooooooo00?o0000AOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo013ooooo00?o0000o`00F?l005P02Ol005P00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03;ooooo1?l00009ooooo`03ojZmiol0003oZ[gW02;oZ[gW0_l0000nooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooool000000_nW`>/01_l0003oYl3[ojO0jol0003oYl3[
o`0000CoYl3[00Go0000oh]BR?n;DXSoRe:8o`000004oh]BR003o`000?oooooooooo00?o0000Iooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0<?ooool003kooooo00?o0000ojO0jonW`>/02?nW`>/0
1?l0003oYl3[ojO0jol00005oh]BR003o`000?oooooooooo00Cooooo00?o0000ooooooooool0D_oo
ool2o`0000?oYl3[0_l00004ojO0j`03o`000?n;DXSoRe:800GoRe:80ol00002ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?l0
05So001H00[o001H00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`;o000000?o
cXR7o`000?ooool02Oooool00onZ_NOo0000ojZmi`0PojZmi`?o0000?_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1?ooooo`06o`000?ooooooooooo`000?nW`>_o00000onW`>/2o`0000CoYl3[00Go0000oh]BR?n;
DXSoRe:8o`000004oh]BR0?o00000_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0<?ooool003kooooo00?o0000ojO0jonW`>/02?nW`>/01Ol0003o
Yl3[ojO0jonW`>_o000000CoRe:800?o0000ooooooooool00oooool2o`0005Cooooo1Ol000000onW
`>_o0000ojO0j`04ojO0j`03o`000?n;DXSoRe:800CoRe:800?o0000ooooooooool00oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0
003o001Ho`00F00:o`00F003o`000?oooooooooo00_ooooo0ol0000booooo`03o`000?o>R8OocXR7
00;o00002_ooool00onZ_NOo0000ojZmi`0NojZmi`04o`000?oooooo0000o`0003kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Coooool01?l0003oooooooooooooool5o`000003ojO0jol0003oYl3[00CoYl3[00Co
0000oh]BR?n;DXSo00001?n;DXP2o`0000Cooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0<?ooool003kooooo00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0
j`02ojO0j`05o`000?n;DXSoRe:8oh]BR?l000000_ooool3o`000003ooooool0003ooooo05?ooooo
0_l00004ojO0j`03o`000?nW`>_oYl3[00CoYl3[00?o0000oh]BR?n;DXP00on;DXP2o`0000Gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000o`00F?l005P02_l005P00ol0003oooooooooo`08ooooo`?o00000_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?o>R8OocXR700;o00002oooool00onZ_NOo0000ojZmi`0MojZmi`04o`00
0?oooooo0000o`0003kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Coooool01?l0003oooooooooooooool2o`00
00CoYl3[0_l00005ojO0j`03o`000?n;DXSo000000CoRe:800?o0000ooooool000000oooool00ol0
003oooooooooo`0booooobOo00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02oooooo000nooooo`03o`000?nW`>_oYl3[00SoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0
003oRe:8oh]BR003o`0000Cooooo00?o0000ooooooooool0D_ooool2o`0000GoYl3[00?o0000ojO0
jonW`>/01?nW`>/00ol0003oRe:8oh]BR002oh]BR0;o00001Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003o001Ho`00F00<o`00
F003o`000?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo033ooooo0_l00002olj8
Q`;o00002oooool00onZ_NOo0000ojZmi`0KojZmi`06o`000?ooooooooooo`000?oi[V?o0000?Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1>ooooo`Co000000?oooooo`000?l000001?nW`>/2o`0000GoYl3[0_l0
0004oh]BR003o`000?oooooo000000?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00
000EooooocCo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;oooool003kooooo00?o0000ojO0jonW`>/02?nW`>/00ol0003oYl3[ojO0j`03
ojO0j`04o`000?n;DXSoRe:8o`0000Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`00
0004ojO0j`03o`000?nW`>_oYl3[00GoYl3[00Oo0000oh]BR?n;DXSoRe:8o`000?oooooo000000Co
oooo0_l00011ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003o
001Ho`00F00<o`00F004o`000?ooooooooooooooo`?o00002?ooool00ol0003oooooooooo`0`oooo
o`;o00000_o>R8L2o`0000cooooo00?oZ[gWo`000?nZ_NL06_nZ_NL01_l0003oooooooooool0003o
nJiSo`0003gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000?oYl3[00?o0000ojO0jol000001OnW`>/00ol0003oRe:8oh]BR002oh]BR003o`000?oo
oooo000000?ooooo0_l0000cooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02oooooo000mooooo`;o00002?nW`>/3o`0000KoYl3[
00?o0000oh]BR?l000001_ooool00ol0003oooooooooo`1Cooooo`;o00001?nW`>/00ol0003oYl3[
ojO0j`05ojO0j`08o`000?n;DXSoRe:8oh]BR?l0003oooooo`000?ooool3o`000003ooooool0003o
oooo043ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?l005So
001H00go001H1?l0000;ooooo`03o`000?oooooooooo033ooooo0_l000000onjXQ;ocXR7o`000002
o`0000cooooo00?o0000ojZmionZ_NL06?nZ_NL01ol0003ooooooooooooooooo0000ooV^Hol00000
?Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_nW`>/01?l0003oYl3[ojO0jol00005ojO0j`05o`000?n;DXSoRe:8oh]BR?l000000_ooool3
o`000003ooooool0003ooooo03;ooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00Co0000oooooooooooo0000
>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0_ooooo`00?Oooool00ol0003oooooo`000003ojO0j`Co00000_nW
`>/00ol0003oYl3[ojO0j`05ojO0j`;o00001oooool00ol0003oooooooooo`1Booooo`;o00001OnW
`>/00ol0003oYl3[ojO0j`05ojO0j`04o`000?n;DXSoRe:8o`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1_ooool00ol0003o001Ho`00F00=o`00F003o`000?oooooooooo00gooooo00?o0000ooooooooool0
;oooool2o`000003okZR4_o>R8OocXR700;o00003?ooool00ol0003oZ[gWo`00000GojZmi`03o`00
0?oooooooooo00;ooooo00?o0000ooV^Hol00000??ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000_nW`>/01?l0003oYl3[ojO0jol00005ojO0
j`03o`000?n;DXSoRe:800Co00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;oooool0
03gooooo00?o0000ooooool000000ol00006ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000000?oYl3[0_l00008ojO0
j`03o`000?n;DXSo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o001Ho`00F00>o`00
F003o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool3o`000004okZR4_o>R8Oo0000
on:LQ0;o00002_ooool00ol0003oljmoo`00000GojZmi`03o`000?oooooooooo00;ooooo00?o0000
ooV^Hol00000??ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0ol00002ojO0j`03o`000?nW`>_oYl3[00CoYl3[00?o0000oh]BR?l000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo0_l0000aooooo`00?Ooo
ool2o`000003ooooool0003oYl3[00OoYl3[00?o0000ojO0jonW`>/01OnW`>/00on;DXSo0000o`00
0006ooooo`03o`000?oooooooooo05?ooooo1Ol000000onW`>_o0000ojO0j`08ojO0j`;o00000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`03ooooo`03o`000?l005So001H00ko001H00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0`ooooo`05o`000?njXQ;o0000okZR4_l000000_oRW8@2o`0000Wooooo
00Co0000oo>_Ool0003o00005?nZ_NL2o`0000Kooooo0_l0000looooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`000003ojO0jol0003oYl3[00;o
Yl3[00?o0000ojO0jonW`>/01?nW`>/2o`0000?ooooo00Go0000ooooooooooooooooo`00000aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00000i
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool3o`00013ooooo0ol00000
0ooooooo0000ooooo`0`ooooo`00?Oooool01?l0003oooooooooool00008ojO0j`03o`000?nW`>_o
Yl3[00;oYl3[1?n;DXP00ol0003oYl3[o`000003ooooo`?o0000EOooool2o`0000CoYl3[00?o0000
ojO0jonW`>/02?nW`>/01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?l005So001H00ko001H00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`06o`000?njXQ;o0000okZR4_o>R8Oo
00000_oRW8@2o`0000Sooooo00Go0000oo>_Ool0003oooooo`00000@ojZmi`?o000000?oBbF0o`00
0?ooool01Oooool2o`0003cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool01?l0003oooooooooooooool3
o`0000?ooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00CoYl3[00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00000iooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo0ol00002ooooo`03o`000?oooooooooo00_ooooo0ol00003ooooo`03o`000?oooooooooo033o
oooo000mooooo`05o`000?ooooooooooooooool000001onW`>/00ol0003oYl3[oh]BR006oh]BR003
o`000?nW`>_oYl3[00?o00000_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo000000Co
Yl3[00?o0000ojO0jonW`>/01_nW`>/00on;DXSo0000o`000002ooooo`03o`000?oooooooooo00;o
oooo0_l0000nooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00004Ol005P00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00Ko0000okZR4_njXQ;o0000okZR4_l0
0003on:LQ0?o00001_ooool00ol0003oljmoo`000002ooooo`03o`000?nZ_NOoZ[gW00_oZ[gW0_l0
0003od/UP0;o00001_ooool2o`0003cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0000Booooo`03o`000?oooooooooo04oooooo1?l000000ooooooo0000ooooo`04ooooo`;o0000
1?nW`>/00ol0003oYl3[ojO0j`02ojO0j`03oh]BR?l0003ooooo00;ooooo00Co0000oooooooooooo
oooo0_l0000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo0ol00004ooooo`03o`000?oooooooooo00Go
oooo0_l0000hooooo`03o`000?oooooooooo00Sooooo1?l00005ooooo`03o`000?oooooooooo00So
oooo0ol00005ooooo`03o`000?oooooooooo037ooooo000mooooo`03o`000?oooooooooo00;ooooo
00?o0000ojO0jonW`>/00onW`>/00on;DXSo0000oh]BR007oh]BR005o`000?nW`>_oYl3[ojO0jol0
00000oooool00ol0003oooooooooo`1Cooooo`04o`000?ooooooooooo`0000?oYl3[00?o0000ojO0
jonW`>/00onW`>/4oh]BR006o`000?nW`>_o0000ooooool0003ooooo0ol000000ooooooo0000oooo
o`0mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004Ol005P00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo033ooooo0_l00002okZR4P;o00001OoRW8@2o`0000Gooooo00?o
0000oo>_Ool000000oooool00ol0003oZ[gWojZmi`07ojZmi`?o00001Om;9H000ol0003ooooooooo
o`05ooooo`;o0000??ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000001;ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ojO0jonW`>/00onW`>/00ol0003oRe:8oh]BR002oh]BR0;o00000oooool3o`000003ooooool0
003ooooo02oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool3o`0000;oSeV=00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_oo
ool3o`0000Sooooo00?o0000ooooooooool01Oooool3o`0000Sooooo00?o0000ooooooooool0<Ooo
ool003gooooo00?o0000ooooooooool00oooool00ol0003oYl3[oh]BR003oh]BR003o`000?n;DXSo
Re:800KoRe:800?o0000ojO0jonW`>/00_nW`>/01?l0003oooooooooool0001Fooooo`04o`000?oo
ooooooooo`0000;oYl3[00?o0000ojO0jonW`>/01on;DXP00ol0003oYl3[ojO0j`03o`0000Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Gooooo`03o`000?l005So001H00ko001H
0ol0000?ooooo`03o`000?oooooooooo037ooooo00Co0000okZR4_njXQ;o^Z8B0_l00006on:LQ003
o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?nZ_NOoZ[gW00?oZ[gW0ol00007od/UP0;o
00001oooool2o`0003_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`?o
0000DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00002ojO0j`;o
Re:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oYl3[o`000003o`0000?ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`?o00001On?FHd00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`?o
00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`03
o`000?oooooooooo03;ooooo000mooooo`03o`000?oooooooooo00?ooooo00?o0000oh]BR?n;DXP0
0on;DXP00ol0003oRe:8oh]BR006oh]BR003o`000?nW`>_oYl3[00?oYl3[00?o0000ooooool00000
E_ooool01ol0003ooooooooooooooooo0000ojO0jol000002_n;DXP01?l0003oYl3[ojO0jol00005
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool05oooool00ol0003o001Ho`00F00;
o`00F0?o00000_l005P00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo00?o0000
okZR4_njXQ800onjXQ800ol0003ohYb4on:LQ003on:LQ0?o00000_ooool2o`0000Kooooo0_l00000
0onZ_NOo0000o`00000:od/UP003o`000?oooooooooo00Kooooo0_l0000kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool03?ooool3o`0000;ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004oh]BR003o`000?n;DXSo
Re:800;oRe:800Ko0000ojO0jonW`>_o0000ooooool00003ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooooooo0ol00008ohmIS@03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooo000000;o00003?ooool00ol0003oooooooooo`0coooo
o`00?Oooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSoRe:800;oRe:80_l00008oh]BR003
o`000?nW`>_oYl3[00?oYl3[00?o0000ooooool00000E_ooool01Ol0003ooooooooooooooooo0000
00;oRe:800?o0000oh]BR?n;DXP01on;DXP00ol0003oYl3[ojO0j`02o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?l005So001H00So001H0ol00004o`00
F003o`000?oooooo000000oooooo00?o0000ooooooooool0<?ooool2o`0000Co^Z8B00?o0000on:L
Q?oRW8@01OoRW8@5o`0000Oooooo0_l0000;od/UP003ooRkC?l0003ooooo00Oooooo0_l0000koooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool3o`0000Cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oh]B
R?n;DXP00_n;DXP00ol0003oRe:8oh]BR002oh]BR004o`000?nW`>_oYl3[ojO0j`;o00001?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo1?l0000Mooooo`03o`000?oooooo
oooo00Kooooo1Ol0000;ohmIS@03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`?o00003oooool0
0ol0003oooooooooo`0cooooo`00?Oooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSo0000
00;o000000?oRe:8o`000?n;DXP01on;DXP00ol0003oYl3[ojO0j`04ojO0j`;o0000E_ooool01_l0
003ooooooooooooooooo0000oh]BR0;o00002On;DXP01Ol0003oYl3[ojO0jonW`>_o000000Gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?l005So001H00Go001H
0ol00006o`00F005o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0aooooo`;o
00001?njXQ86o`0000CohYb41?l00006ooooo`03o`000?m;9H3oBbF000SoBbF000?on;]<o`000?oo
ool02?ooool2o`0003_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`?o
00001_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool2o`0000CoRe:800?o0000oh]BR?n;DXP00_n;DXP01?l0003oYl3[ojO0jonW`>/2o`00
00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
ooooo`Ko00005oooool00ol0003oooooooooo`04ooooo`?o00003on?FHd00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo00?o0000
ooooooooool00_ooool3o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0=?ooool0
03gooooo00?o0000ooooooooool00_ooool3o`0000CoRe:800?o0000oh]BR?n;DXP01_n;DXP00ol0
003oYl3[ojO0j`03ojO0j`?o0000Eoooool00ol0003oooooo`000002o`000003oh]BR?l0003oRe:8
00SoRe:800?o0000ojO0jonW`>/00_nW`>/01?l0003oooooooooooooool2o`0003gooooo00?o0000
ooooooooool05oooool00ol0003o001Ho`00F002o`00F0?o00002Ol005P00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool2o`0000Co^Z8B00?o0000
ok9_Q_nbKhH00onbKhH6o`000003on:LQ?l0003o000000?o00000oooool00ol0003obh^>od/UP006
od/UP0;on;]<00?o0000ooooooooool01oooool2o`0003_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`03ooooo`?o00002Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000_l000000ooooooo0000oh]BR003oh]BR003o`000?n;DXSo
Re:800;oRe:800?o0000ojO0jonW`>/00_nW`>/2o`0000;ooooo0_l0000_ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool6o`00017ooooo00Co0000oooooooooooooooo1?l0
000AohmIS@03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_l00004ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0=?ooool003gooooo00?o0000ooooool000000ol00006
oh]BR003o`000?n;DXSoRe:800KoRe:800?o0000ojO0jonW`>/00ol00002ooooo`03o`000?oooooo
oooo05Gooooo0_l00002ooooo`04o`000?n;DXSoRe:8o`0000SoRe:800?o0000ojO0jonW`>/00onW
`>/3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003o001Ho`00
0002o`0000_o001H00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03;ooooo0_l00003okZR4P03o`000?nbKhKo/Vn600Oo/Vn600?o0000ok9_Q_l000002_l0
0002ol^;SPCoBbF00ooh^d`00ol0003oooooooooo`07ooooo`03o`000?oi[V?o000003[ooooo00?o
0000ooooooooool05oooool00ol0003oooooo`000003o`0000_ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000?oRe:800?o0000oh]BR?n;DXP00_n;
DXP2o`0000CoYl3[0ol000000ooooooo0000ooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03Oooool6o`0000_ooooo1?l00002ohmIS@03o`000?n?FHgoSeV=013oSeV=00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool02_ooool2o`0000Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0eooooo`00?Oooool2o`0000?ooooo00?o0000oh]BR?n;DXP01?n;DXP00ol0003oRe:8oh]BR006
oh]BR0?o00001Oooool00ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool000000_n;
DXP00ol0003oRe:8oh]BR006oh]BR003o`000?nW`>_oYl3[00CoYl3[00Co0000oooooooooooo0000
??ooool00ol0003oooooooooo`0Gooooo`?o00003_l005P00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0<oooool01Ol0003o^Z8BokZR4_njXQ;o000000ko
/Vn60ol00005ojC3k`Ko00000_oh^d`00ol0003oooooooooo`08ooooo`03o`000?oi[V?o000003Wo
oooo00?o0000ooooooooool05oooool3o`0000oooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooo`000002o`000003ooooool0003ooooo00?ooooo0_l00003oh]BR003o`000?n;DXSoRe:800;o
Re:800?o0000ojO0jol000001?nW`>/01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04_ooool7o`0000?ooooo0ol00004ohmIS@03o`000?n?FHgoSeV=
017oSeV=00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=_ooool003gooooo00?o0000ooooooooool00_ooool00ol0003o
Re:8oh]BR004oh]BR003o`000?n;DXSoRe:800KoRe:800?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Fooooo`04o`000?ooooooooooo`0000?oRe:800?o0000oh]BR?n;DXP01On;DXP00ol0
003oYl3[ojO0j`04ojO0j`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool04oooool4
o`000003ooooool0003o001H00go001H00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03?ooooo0_l00002okZR4P03o`000?nbKhKo/Vn600Wo/Vn60ol0000>
ojC3k`Go00002?ooool00ol0003onJiSo`00000iooooo`03o`000?oooooooooo01Cooooo0ol00000
0ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo05Gooooo0_l00005ooooo`07o`000?oooooo
ooooooooool0003oRe:8o`000002oh]BR003o`000?n;DXSoRe:800;oRe:800Co0000ojO0jonW`>_o
00001?nW`>/00ol0003oooooo`00000^ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06?ooool4o`0000;oSeV=00Go0000ohmISOn?FHgoSeV=o`00000DohmIS@03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`00?Oooool00ol0
003oooooooooo`02ooooo`03o`000?n;DXSoRe:800CoRe:800?o0000oh]BR?n;DXP01on;DXP00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00Co0000oooooooooooo00000on;DXP0
0ol0003oRe:8oh]BR005oh]BR003o`000?nW`>_oYl3[00GoYl3[00?o0000ooooool00000??ooool0
0ol0003oooooooooo`0@ooooo`?o00001Oooool00ol0003o001Ho`00F00;o`00F003o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`04o`000?njXQ;o
^Z8Bo`0000So/Vn60ol0000FojC3k`Ko00000_ooool00ol0003onJiSo`00000iooooo`03o`000?oo
oooooooo017ooooo0ol00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`04ooooo`07o`000?ooooooooooooooool0003oRe:8o`000002oh]BR003
o`000?n;DXSoRe:800;oRe:800Go0000ojO0jonW`>_oYl3[o`000004ojO0j`03o`000?oooooo0000
02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`05o`000?n?FHgoSeV=
ohmISOl000000_n?FHd00ol0003oSeV=ohmIS@0CohmIS@03o`000?oooooooooo00?ooooo00?o0000
ooooool00000??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0gooooo`00?Oooool00ol0003oooooooooo`02oooo
o`03o`000?n;DXSoRe:800CoRe:800?o0000oh]BR?n;DXP01on;DXP00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooool000000on;DXP00ol0003oRe:8oh]BR005oh]B
R0?o00001_nW`>/2o`0003cooooo00?o0000ooooooooool03Oooool3o`0000Oooooo00?o0000o`00
F?l005P03?l005P00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0=?ooool00ol0003o^Z8Bo`000005ok9_QP?o00007onT`nl3o`000003ooV^Hol0003ooooo
03Sooooo00?o0000ooooooooool03_ooool3o`0000Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000oh]BR?l0
0002oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[ojO0
j`02ojO0j`;o0000;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00Oo
0000ohmISOn?FHgoSeV=o`000?n?FHgo000001OoSeV=00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Sooooo000mooooo`03o`000?oooooooooo00;ooooo
00?o0000oh]BR?n;DXP01?n;DXP00ol0003oRe:8oh]BR007oh]BR003o`000?oooooooooo00Gooooo
00?o0000ooooooooool0E_ooool00ol0003oooooo`000003oh]BR0;o00001_n;DXP00ol0003ooooo
ooooo`02o`0000?oYl3[0ol0000looooo`03o`000?oooooooooo00[ooooo0ol0000:ooooo`03o`00
0?l005So001H00_o001H00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Gooooo0_l00002ok9_QP?o00009OnT`nl2o`0003Wooooo00?o0000ooooooooool0
2_ooool4o`0000[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Cooooo00Go0000oooooooooooo0000oh]BR002o`000003oh]BR?l0003oRe:800?o
Re:800?o0000ojO0jonW`>/00onW`>/00ol0003oYl3[ojO0j`03o`0002gooooo:Ol00003ooooo`04
o`000?n?FHgoSeV=ohmIS@;o00006?n?FHd00ol0003oooooooooo`02ooooo`;o0000?Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0hooooo`00??ooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSoRe:800Co
Re:800?o0000oh]BR?n;DXP01on;DXP00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00ol000000on;DXSo0000oh]BR005oh]BR003o`000?oooooooooo00;o
oooo0ol00002ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01oooool3o`0000go
oooo00?o0000o`00F?l005P02ol005P00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=_ooool3o`0002WoY<?_00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`07ooooo`?o00003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`000004oh]BR?l0003oRe:8o`00
00CoRe:800?o0000ojO0jonW`>/00onW`>/3o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo=ol0000nooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Wooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000oh]BR?n;DXP00_n;DXP3o`0000Wo
Re:800?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`?o00001?n;DXP00ol0003o
Re:8oh]BR003oh]BR003o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Gooooo0ol0000@ooooo`03o`000?l005So001H00[o
001H00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03So
oooo00?o0000ojC3konT`nl09onT`nl00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Co
oooo0ol0000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?n;DXP00_n;DXP2o`0000CoRe:80_l000001_nW`>_o
0000o`000?l0003oooooo`0000?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01_ooooo00?o0000ohmISOn?FHd06on?FHd00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool003cooooo00?o0000oooo
ooooool00oooool5o`0000?oRe:800?o0000oh]BR?n;DXP01_n;DXP00ol0003oooooooooo`02oooo
o`Co0000FOooool00ol0003oooooo`000005oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool00_ooool3o`0001?ooooo00?o0000o`00F?l005P02Ol005P00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oY<?_ojC3k`0CojC3
k`03o`000?nT`nooY<?_00ooY<?_00?o0000ooooooooool0=oooool00ol0003oooooooooo`02oooo
o`?o00005?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ool000000_l000001?oooooo0000ooooool00004oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000
ooooool000001?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?n?FHgoSeV=01_oSeV=00Go0000oooooooooooooooo
o`00000nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03[ooooo000looooo`03o`000?oooooo000000Co00002?n;
DXP00ol0003oRe:8oh]BR005oh]BR0Go00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooo000000CoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000002o`0001Kooooo00?o
0000o`00F?l005P02Ol005P00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>_ooool00ol0003oY<?_ojC3k`0BojC3k`03o`000?nT`nooY<?_00koY<?_00?o
0000ooooooooool0>?ooool00ol0003oooooo`000002o`0001Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00?ooooo0_l00004oh]BR003o`000?n;
DXSoRe:800;oRe:800?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?n?
FHgoSeV=01_oSeV=00Co0000oooooooooooo0000?oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`00??oo
ool2o`0000Cooooo00?o0000oh]BR?n;DXP01_n;DXP2o`0000KoRe:800?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooo000000GoRe:800Go0000oh]BR?n;DXSoRe:8
o`000004ooooo`03o`000?oooooooooo00?o0000>oooool2o`0001Wooooo00?o0000o`00F?l005P0
2?l005P00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool00ol0003oY<?_ojC3k`0RojC3k`03o`000?oooooooooo03Sooooo0_l0000Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`03ooooo`;o0000
1?n;DXP2o`0000?oRe:800?o0000ooooool000000oooool00ol0003oooooooooo`03o`0003?ooooo
0_l00006ooooo`03o`000?oooooooooo01_ooooo00?o0000ohmISOn?FHd06on?FHd00ol0003ooooo
o`000010ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03_ooooo000looooo`03o`000?oooooooooo00?ooooo00?o
0000oh]BR?n;DXP00on;DXP3o`0000;oRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05Wooooo0_l00004oh]BR0?o00000_n;DXP00ol0003ooooooooo
o`02ooooo`?o00000_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o
0000o`00F?l005P01ol005P00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>oooool00ol0003oY<?_ojC3k`0PojC3k`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool00oooool00ol0003oRe:8oh]BR002oh]BR0?o00000_n;DXP00ol0003oooooo`00
0002ooooo`Co00000_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06oooool00ol0003oSeV=ohmIS@0KohmIS@03o`000?oooooo0000043ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0??ooool003cooooo00?o0000ooooooooool00oooool00ol0003oRe:8oh]BR003
o`0000KoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooool000000ol00002oh]BR004o`000?n;DXSoRe:8o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Gooooo00?o
0000o`00F?l005P01ol005P00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0??ooool00ol0003oY<?_ojC3k`0CojC3k`03o`000?nT`nooY<?_00SoY<?_00?o
0000ooooooooool0?Oooool2o`0001Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP00ol000001_n;DXSo0000oh]B
R?n;DXSo0000ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0dooooo`05
o`000?ooooooooooooooool000007_ooool00ol0003oSeV=ohmIS@0KohmIS@;o0000@Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0mooooo`00?Oooool00ol0003oooooooooo`02ooooo`?o00002_n;DXP01Ol0003o
Re:8oh]BR?n;DXSo000000Oooooo00?o0000ooooooooool0F_ooool2o`0000KoRe:800?o0000oh]B
R?l000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo0_l0000Eoooo
o`03o`000?l005So001H00Ko001H00?o0000ooooooooool05_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03gooooo00?o0000ojC3konT`nl07OnT`nl00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Roooo
o`04o`000?ooooooooooooooo`Co00000_n;DXP02?l0003oRe:8oh]BR?l0003oRe:8o`000?oooooo
00000oooool01Ol0003ooooooooooooooooo000003Sooooo00Co0000oooooooooooo00007_ooool0
0ol0003oSeV=ohmIS@0IohmIS@?o0000@_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0mooooo`00?Oooool00ol0
003oooooo`000003o`0000_oRe:80ol00002oh]BR003o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Foooool2o`0000KoRe:80_l00003ooooo`03o`000?oooooooooo00Co0000@Oooool00ol0
003oooooooooo`0Booooo`03o`000?l005So001H00Ko001H00?o0000ooooooooool05oooool01Ol0
003ooooooooooooooooo0000043ooooo0_l0000LojC3k`03o`000?oooooooooo047ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06?ooooo0ol00000
1?oooooo0000oh]BR?l00002oh]BR004o`000?n;DXSoRe:8oh]BR0;o000000?oooooo`000?ooool0
0_ooool00ol0003oooooo`000002o`0003Wooooo00?o0000ooooool000007_ooool00ol0003oSeV=
ohmIS@0EohmIS@Co0000AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`00?Oooool2o`0000?ooooo00?o
0000oh]BR?n;DXP01On;DXP4o`0000?oRe:800?o0000oh]BR?l000001oooool00ol0003ooooooooo
o`1Looooo`;o00001On;DXP2o`0000?ooooo0ol00003ooooo`03o`000?oooooooooo043ooooo0_l0
000Booooo`03o`000?l005So001H00Go001H00?o0000ooooooooool06Oooool01?l0003ooooooooo
ool00011ooooo`;o00006_nT`nl00ol0003oooooooooo`13ooooo`;o00004_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06Cooooo00Go0000ooooooooooooooooo`000002oh]BR003
o`000?n;DXSo000000?oRe:80_l000001?oooooo0000ooooooooool3o`0000;ooooo00?o0000oooo
ooooool0>?ooool2o`0001kooooo00?o0000ohmISOn?FHd04_n?FHd3o`0004Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0?oooool003gooooo00?o0000ooooooooool00_ooool00ol0003oRe:8oh]BR005o`0000So
Re:80_l00005ooooo`?o0000Goooool00ol0003oRe:8oh]BR003o`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00oooooo00?o0000o`00
F?l005P01?l005P00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0004;ooooo0_l0000I
ojC3k`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo00000on;DXP2o`0000;oRe:81ol0
00001Ooooooo0000oooooooooooo000003cooooo1?l0000Kooooo`03o`000?n?FHgoSeV=00koSeV=
1?l0001<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03oooooo000nooooo`03o`000?oooooooooo00Co00003?n;
DXP3o`000003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`1Nooooo`;o00001_oo
ool2o`0000;ooooo0ol00017ooooo`03o`000?oooooooooo00kooooo00?o0000o`00F?l005P01?l0
05P00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ojC3konT`nl0
5OnT`nl00ol0003oooooooooo`17ooooo`;o00003oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooool000000on;DXP4o`0000?ooooo0ol000000ooooooo0000
ooooo`03o`00043ooooo1_l0000Eooooo`03o`000?n?FHgoSeV=00[oSeV=1?l0001@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000004;o
oooo000oooooo`;o000000?oooooo`000?n;DXP02On;DXP4o`000004ooooool0003o0000o`0000Ko
oooo00?o0000ooooooooool0H?ooool01?l0003oooooooooooooool7o`0004[ooooo0_l0000>oooo
o`03o`000?l005So001H00?o001H00?o0000ooooooooool07Oooool00ol0003oooooo`000014oooo
o`03o`000?nT`nooY<?_017oY<?_0ol0001<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Yooooo`Go00000oooool01?l0003oooooooooooooool7
o`0004Sooooo1ol0000>ooooo`03o`000?n?FHgoSeV=00KoSeV=1?l0001Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00013ooooo`00@?ooool0
0ol0003oooooo`000005oh]BR0Go00000oooool2o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Qooooo`Ko0000D?ooool00ol0003oooooooooo`0;ooooo`03o`000?l005So
001H00;o001H00?o0000ooooooooool07oooool2o`0004Gooooo00?o0000ojC3konT`nl03?nT`nl7
o`0004gooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Joooool2
o`0000Gooooo1_l000001?oooooo0000o`000?l0001@ooooo`Ko00002?ooool00ol0003oSeV=ohmI
S@03ohmIS@?o0000F?ooool01Ol0003ooooooooooooooooo000001;ooooo00Co0000oooooooooooo
0000@oooool0047ooooo0_l000000on;DXSo0000o`000002o`0000Sooooo00Co0000oooooooooooo
oooo0ol00004ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool02_ooool00ol0003o
001Ho`00F002o`00F003o`000?oooooooooo01kooooo0ol00016ooooo`03o`000?nT`nooY<?_00So
Y<?_0ol000000onT`nooBbF0od/UP003o`00053ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06gooooo0_l000001?oooooo0000o`000?ooool6o`00
05Wooooo1_l00002ooooo`03o`000?n?FHgo000000?o0000Foooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooool00000A?ooool004;ooooo0_l0000<ooooo`Co00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;Sooooo0_l00009ooooo`03o`000?l005So001H
00;o001H00?o0000ooooooooool06_ooool5o`0004[ooooo00?o0000ojC3konT`nl01?nT`nl3o`00
00CoBbF01?l0001Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1`ooooo`Go0000I?ooool4o`0005oooooo00Co0000oooooooooooo00004oooool0
0ol0003oooooo`000014ooooo`00A?ooool00ol0003oooooooooo`05ooooo`Go00001oooool01Ol0
003ooooooooooooooooo00000;cooooo00?o0000ooooooooool01_ooool00ol0003o001Ho`00F002
o`00F003o`000?oooooooooo01Kooooo1?l0001@ooooo`;o000000CoY<?_o`000?l0003o00001?m;
9H03o`000003ooRkC?l0003ooooo05Cooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0oooooollooooo`05o`000?ooooooooooooooool000004oooool2o`0004Gooooo
0015ooooo`03o`000?oooooooooo00Co00001?ooool00ol0003oooooooooo`04ooooo`Co000000?o
ooooo`000?ooool0_?ooool00ol0003oooooooooo`05ooooo`05o`000?l005So001Ho`00F?l00000
5?ooool5o`0005Gooooo2_l000000ooh^dcoooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`00003oooooocoooooo00Co0000oooooooooooo00004_ooool3o`00
04Kooooo0016ooooo`;o00002Oooool6o`0000Cooooo0_l0002nooooo`;o00001Oooool01?l0003o
001Ho`00F?l0000@ooooo`Go0000Foooool4o`0000;obh^>Goooool2o`0000Gooooo00Co0000oooo
oooooooo0000oooooom0ooooo`04o`000?ooooooooooo`0000kooooo1?l00019ooooo`00B?ooool3
o`0000;ooooo1Ol00008ooooo`?o0000`?ooool00ol0003oooooooooo`02ooooo`04o`000?l005So
001Ho`0000cooooo1?l00037ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
oooooom0ooooo`03o`000?oooooo000000_ooooo1?l0001=ooooo`00Boooool3o`0000?ooooo00?o
0000ooooooooool00_ooool4o`000<Cooooo0_l00002ooooo`03o`000?l005So000000Sooooo1Ol0
003<ooooo`07o`000?ooooooooooooooool0003oooooo`00003ooooood7ooooo00?o0000ooooool0
00001oooool4o`00057ooooo001>ooooo`Co000000Coooooo`000?l0003o0000b_ooool01Ol0003o
ooooo`000?l005So000000Cooooo1?l0003Booooo`;o000000Coooooo`000?oooooo0000oooooom1
ooooo`;o00001?ooool4o`0005Gooooo001Aooooo`;o0000c_ooool8o`000=Sooooo0ol0003ooooo
od;ooooo1_l0001Iooooo`00oooooolSooooo`;o0000g_ooool00ol0003oooooooooo`3ooooood7o
oooo0_l0001Mooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003o
oooooooooooooooooonWooooo`00oooooooooooool_ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000oooool01?l0003oooooooooooooool2o`0000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00?o00000_ooool00ol0003oooooo`000004o`0000Cooooo2?l00002ooooo`04o`000?oo
oooo0000ooooo`;o0000W?ooool004_ooooo0_l00037ooooo`Co00007Oooool3o`000?ooooooTooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000003oooo
o`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo000009gooooo001=ooooo`03o`00
0?oooooooooo0<Cooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo0?oo
ooooT_ooool01?l0003oooooooooool00002ooooo`Co000000Goooooo`000?oooooo0000ooooo`04
o`000004ooooool0003oooooooooo`;o00000_ooool00ol0003oooooo`000003ooooo`05o`000?oo
oooo0000ooooool000000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000;o
oooo00Go0000ooooool0003oooooo`00002Mooooo`003_ooool3o`0000?ooooo0ol000001ooooooo
0000o`000?l0003oooooo`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`?o00000ooo
ool3o`0000;ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooooooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool3o`0000Cooooo00?o0000ooooooooool01_l000000ooo
oooo0000ooooo`02o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000002ooooo`co000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`00
01;ooooo0ol00003ooooo`?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000Co
ooooo`000?l0003o00000oooool3o`0000?ooooo0ol00002ooooo`04o`000?oooooo0000o`0000;o
oooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool8o`000003ooooool0003o
000000;ooooo00?o0000ooooool000001?l0000Cooooo`?o00001?ooool3o`000005ooooool0003o
0000o`000?ooool00ol000000ooooooo0000o`00000:o`000003ooooool0003ooooo00;o000000?o
ooooo`000?l000001ol00003ooooo`;o00000_ooool3o`000005ooooool0003oooooo`000?ooool0
0_l000001?oooooo0000o`000?l00003ooooo`?o000000?oooooo`000?l000001?l00002ooooo`05
o`000?ooooooooooo`000?ooool00_l00002ooooo`;o00000_ooool3o`0000Cooooo0ol000001?oo
oooo0000o`000?l00002ooooo`;o00008Oooool3o`0000Cooooo0ol00002ooooo`;o000000Cooooo
o`000?l0003ooooo0ol000001?oooooo0000o`000?l00004ooooo`So00000_ooool01?l0003ooooo
o`000?ooool2o`0004kooooo0ol00004ooooo`So00000_ooool01?l0003oooooo`000?ooool2o`00
04Cooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooo`000002o`00
0004ooooool0003o0000ooooo`Co000000Coooooo`000?l0003o00000_ooool4o`000004ooooool0
003o0000o`0000;ooooo00?o0000ooooool000001?l00003ooooo`?o000000Coooooo`000?l0003o
00000_ooool01?l0003oooooo`000?l0000aooooo`Co00000_ooool02_l0003oooooooooool0003o
ooooo`000?oooooo0000ooooool00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0
003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01Ol0003oooooo`000?oooooo0000
037ooooo0ol00002ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00002
ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000005oooo
ool0003o0000o`000?ooool01ol00004ooooo`So00000_ooool01?l0003oooooo`000?ooool2o`00
02_ooooo000?ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`000002oooo
o`05o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?oo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000004
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oo
oooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooool000000oooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0
003oooooo`000004ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooooooo0_l00004
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooo`00
0?oooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`03o`000?oooooooooo00;o00009?ooool00ol0003oooooooooo`02ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00004ooooo`07o`000?oooooo0000ooooool0003ooooo
o`00001@ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001?ooool01ol0003o
ooooo`000?oooooo0000ooooool00000A_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooool00000<oooool01Ol0003ooooooooooooooooo000000;o
oooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000000ol00002ooooo`?o000000Coooooo`000?l0003o00000oooool01Ol0003ooooooooo
ool0003ooooo00Go00000_ooool8o`0003?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
ooooo`000?oooooo000000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o
0000ooooooooool00_l00003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oo
oooo000002cooooo000?ooooo`?o00000oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000
ooooool0003oooooo`000003ooooo`;o00001_ooool02Ol0003ooooooooooooooooo0000ooooool0
003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co00000_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004oooo
o`;o00000_ooool01?l0003oooooooooool00004ooooo`Co000000Coooooo`000?oooooo00000_oo
ool2o`0001?ooooo0ol00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003oooooo`00
0?oooooo000000?ooooo0_l00006ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo
000000;ooooo00Co0000ooooool0003ooooo1?l00002ooooo`05o`000?ooooooooooooooool00000
1?ooool4o`000004ooooool0003oooooo`0000;ooooo0_l0000Dooooo`?o00000_ooool01ol0003o
oooooooooooooooo0000ooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo
00Ko0000ooooooooooooooooo`000?ooool4o`000003ooooool0003o000000;ooooo00Go0000oooo
ool0003oooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?o000000Coooooo`000?oooooo
00001oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Go00008Oooool3o`0000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000oooool0
0ol0003oooooo`000002o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00Go
0000ooooool0003oooooo`00001@ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`;o
00000_ooool01Ol0003oooooo`000?oooooo000004Kooooo00Co0000oooooooooooo00000_ooool4
o`000004ooooool0003oooooooooo`;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00;o00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000ooooool0
003oooooo`000002ooooo`?o00000oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000oooo
ool000000ol0000`ooooo`05o`000?ooooooooooooooool000008oooool01?l0003oooooooooool0
0013ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000oooool0
1Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool00ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00002ooooo`05o`000?oooooo0000ooooool00000;?ooool000oooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ool0003oooooo`000003ooooo`;o00001_ooool02Ol0003ooooooooooooooooo0000ooooool0003o
ooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000001oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00[o
0000oooooooooooo0000ooooool0003oooooo`000?oooooo00005Oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooo`000?oooooo000000?o
oooo0_l00006ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0001Kooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00So0000oooooooooooo0000
ooooool0003oooooo`0000;ooooo00?o0000ooooooooool01?l00002ooooo`04o`000?oooooooooo
o`0000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l00003ooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000;ooooo00Go0000ooooool0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo01oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000oooool00ol0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool0
1Ol0003oooooo`000?oooooo0000053ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000Cooooo00Go0000ooooool0003oooooo`000016ooooo`Co00000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0;Oooool5
o`0001Oooooo00?o0000ooooooooool02Oooool4o`0000Kooooo00?o0000ooooooooool0>oooool4
o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003oooooo`000?oooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Cooooo00Go0000ooooool0003oooooo`00000/ooooo`003oooool01?l0003ooooooooo
ool00002ooooo`04o`000?oooooo0000o`0000;ooooo0ol00003ooooo`?o000000?oooooo`000?oo
ool01_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000ooooo`?o00001_ooool2o`000006ooooool0003o0000ooooool0003o
oooo0_l000001?oooooo0000o`000?l00003ooooo`?o000000?oooooo`000?l000000ol00002oooo
o`Go00000oooool01?l0003oooooooooool00005ooooo`;o000000Coooooo`000?l0003o00000ooo
ool3o`0001;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`?o
00000oooool3o`000003ooooool0003ooooo00Kooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003ooooo00Cooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00004oooool01?l0003ooooo
ooooool00002ooooo`?o00000_ooool01?l0003oooooo`000?l00002ooooo`Go000000?oooooo`00
0?l000001?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l000000ooooooo0000o`000002ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`Co00000_ooool01Ol0003oooooo`000?l0003ooooo00Ko000000Coooooo`000?l0003o
oooo1?l00006ooooo`;o000000Coooooo`000?oooooooooo0ol00002ooooo`;o00008_ooool01?l0
003oooooooooool00002ooooo`?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0
0002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`So0000DOooool01Ol0003ooooo
ooooool0003ooooo00Go00000_ooool8o`0004Oooooo00Go0000ooooooooooooooooo`000002oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo1Ol00002ooooo`?o000000Coooooo`000?l0003o00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?oooooo0000o`0000;ooooo0ol000000ooooooo0000o`00002Pooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`00
00?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool3o`0000;ooooo00Go0000oooo
oooooooo0000ooooo`05o`0000;ooooo2?l0000]ooooo`003oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0000Jooooo`03o`000?oooooo
oooo00;o00001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00Co0000
oooooooooooo00008oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_l0000Jooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000004Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool09_ooool01?l0003ooooooooo
ool0000Booooo`04o`000?ooooooooooo`00067ooooo00Co0000oooooooooooo0000Eoooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0:;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo03_ooooo000>ooooo`Co00000_ooool2o`00017ooooo0_l000000ooooooo0000
ooooo`0Jooooo`;o000000?oooooo`000?ooool01Oooool2o`0000;ooooo00?o0000ooooooooool0
1_ooool2o`0000Gooooo00?o0000ooooooooool01oooool2o`000004ooooool0003o0000o`00027o
oooo1?l00002ooooo`;o00004Oooool2o`000003ooooool0003ooooo01Sooooo0ol0000Rooooo`Co
00001oooool2o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`Go
00004oooool3o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo
0000ooooo`05ooooo`;o00009oooool4o`0001;ooooo1?l00006ooooo`03o`000?oooooooooo05So
oooo1?l00006ooooo`03o`000?oooooooooo04kooooo1Ol0000Booooo`;o00002Oooool00ol0003o
ooooooooo`09ooooo`Co00000_ooool2o`000:[ooooo1Ol00002ooooo`;o00003oooool2o`0000Wo
oooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002o`0000Kooooo00?o0000oooo
ooooool0=Oooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooo
ooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWoooo
o`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooo
oonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooo
oooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooool@ooooo`;o0000oooo
oonEooooo`00ooooooooooooo`gooooo0ol000000ooooooo0000ooooo`3ooooooiCooooo003ooooo
oooooooo2oooool2o`0000Cooooo0_l0003ooooooiCooooo003ooooooooooooo2Oooool3o`0000Go
oooo00?o0000ooooool00000oooooonCooooo`00ooooooooooooo`Sooooo00?o0000od4CKol00000
1_ooool01?l0003oooooooooool0003ooooooi;ooooo003ooooooooooooo1oooool01?l0003o@A=_
od4CKol00006ooooo`05o`000?ooooooooooooooool00000oooooonAooooo`00ooooooooooooo`Ko
oooo00Go0000od4CKom14foo@A=_o`000006ooooo`05o`000?ooooooooooooooool00000Hoooool3
o`000?oooooo:oooool00?ooooooooooool5ooooo`03o`000?m14foo@A=_00;o@A=_00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03o`0005oooooo0ol000000ooooooo0000on2DNP02o`00
0?oooooo:Oooool00?ooooooooooool4ooooo`03o`000?m14foo@A=_00?o@A=_00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo05_ooooo0_l00004ooooo`05
o`000?oPU7[oh9Ajon2DN_l00000oooooolXooooo`00ooooooooooooo`?ooooo00?o0000od4CKom1
4fl01?m14fl00ol0003oooooooooo`04ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0
003oooooooooo`1Fooooo`?o00001_ooool00ol0003oh9Ajon2DNP02on2DNP;o0000oooooolVoooo
o`00EOooool4o`000=Wooooo1Ol00039ooooo`03o`000?m14foo@A=_00Go@A=_00?o0000oooooooo
ool01?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0E?ooool2o`00
00Wooooo00?o0000on2DN_oPU7X01?oPU7X2o`0006gooooo0ol0002cooooo`00D_ooool5o`0000;o
oooo00?o0000ooooooooool0EOooool3o`0007_ooooo1Ol00003ooooo`03o`000?oooooooooo0<Go
oooo00?o0000od4CKom14fl01_m14fl00ol0003oooooooooo`04ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000005;ooooo0ol0000;ooooo`03o`000?oPU7[oh9Aj00Koh9Aj00?o0000oooo
ooooool0J?ooool2o`0000;ooooo0_l0001Uooooo`Ko0000Aoooool004oooooo1ol00003ooooo`;o
0000EOooool01?l0003oooooooooooooool2o`0007Oooooo1?l000000ooooooo0000ooooo`03oooo
o`;o0000aOooool00ol0003o@A=_od4CK`07od4CK`03o`000?oooooooooo00Cooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool3o`0000kooooo00?o0000on2D
N_oPU7X01ooPU7X2o`0006Gooooo0ol000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo
oooo05oooooo1_l00003ooooo`03o`000?oooooooooo04Cooooo001<ooooo`Ko00000_ooool00ol0
003oooooo`000002o`0000;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`04oooo
o`;o0000L_ooool5o`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`32oooo
o`;o00002_m14fl00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04[ooooo0_l0000Aooooo`03o`000?oPU7[oh9Aj00Woh9Aj0_l0001Qoooo
o`Wo00000_ooool2o`0005gooooo1_l00006ooooo`;o0000AOooool004Wooooo1ol00003ooooo`?o
00001_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0K?ooool5o`0000Cooooo1?l00005ooooo`03o`000?oooooooooo0;oooooo00?o0000od4CKom1
4fl02_m14fl00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`16ooooo`?o00004oooool00ol0003oh9Ajon2DNP0;on2DNP03o`000?oooooooooo
05cooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool00ol0003oooooooooo`1Goooo
o`Co000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo00?o0000ooooooooool0@_ooool0
04Kooooo2?l00002ooooo`?o000000?oooooo`000?ooool01_ooool2o`00053ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Yooooo`Go00000oooool5o`0000Oooooo00?o0000oooo
ooooool0__ooool00ol0003o@A=_od4CK`0;od4CK`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo04?ooooo0_l0000Fooooo`03o`000?oPU7[o
h9Aj00coh9Aj0_l0001Iooooo`?o00000_ooool3o`000003ooooool0003ooooo00Gooooo00Co0000
oooooooooooo0000EOooool4o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000
o`000?l00006ooooo`03o`000?oooooooooo047ooooo0014ooooo`Oo00000_ooool4o`0000?ooooo
00?o0000ooooooooool00_ooool3o`000003oh]BR?l0003ooooo04kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Uooooo`Go00000oooool5o`0000;ooooo00?o0000ooooooooool0
1Oooool2o`000;kooooo00?o0000od4CKom14fl03?m14fl00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`?o0000
6?ooool00ol0003oh9Ajon2DNP0>on2DNP;o0000EOooool2o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo00Gooooo00Co0000ooooool0003o0000Doooool3o`0000;ooooo2?l00009ooooo`;o
0000@_ooool004;ooooo3?l00006ooooo`03o`000?oooooo000000;o00001?n;DXP2o`0004kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Rooooo`Go00000oooool5o`0000?ooooo
00?o0000ooooooooool00oooool3o`000003oh]BR?l0003ooooo0;cooooo00?o0000od4CKom14fl0
3Om14fl00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`;o00006oooool00ol0003oh9Ajon2DNP0@on2DNP03o`00
0?oooooooooo053ooooo0_l00003ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?n;DXSo000005;ooooo00?o0000ooooooooool00_ooool3o`000005ooooool0003o0000ooooool0
00001oooool3o`000003oh]BR?l0003ooooo047ooooo0010ooooo`Ko000000?oooooo`000?l00000
0_l00008ooooo`?o00001on;DXP2o`0004kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Oooooo`Go00000oooool5o`0000Kooooo00?o0000ooooooooool00ol00004oh]BR0;o0000
^oooool00ol0003o@A=_od4CK`0>od4CK`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo0ol0000Mooooo`03
o`000?oPU7[oh9Aj017oh9Aj0_l0001?ooooo`03o`000?oooooooooo00?o00002?ooool00ol0003o
ooooooooo`06ooooo`04o`000?n;DXSo0000o`00057ooooo00?o0000ooooool000000_l00004oooo
o`03o`000?oooooo000000Kooooo0_l00004oh]BR0;o0000@Oooool003gooooo3?l00002ooooo`03
o`000?oooooooooo00;ooooo0ol000000onW`>_o0000oh]BR007oh]BR0?o0000COooool00ol0003o
ooooooooo`0;ooooo`;o0000GOooool6o`0000?ooooo1Ol00007ooooo`Co00002?n;DXP2o`0004[o
oooo1_l0001Yooooo`03o`000?m14foo@A=_00oo@A=_00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Nooooo`03o`000?oPU7[oh9Aj01?oh9Aj0_l0001;ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Sooooo00Go0000oh]BR?l0003oooooo`00001?ooooo`?o00002?ooool2
o`0000Cooooo0_l00006oh]BR003o`000?oooooo0000043ooooo000jooooo`Ko000000Goooooo`00
0?l0003o0000ooooo`02o`0000Gooooo1?l00004ojO0j`;o00001on;DXP00ol0003oooooo`00001<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000F_ooool5o`0000?ooooo1Ol00007
ooooo`?o000000?oYl3[o`000?n;DXP02On;DXP3o`0004Oooooo0_l00005ohP500;o000000?o?@00
ooooooooool0I?ooool00ol0003o@A=_od4CK`0@od4CK`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo03Oooooo0_l0000Oooooo`03o`00
0?oPU7[oh9Aj01Goh9Aj00?o0000ooooooooool0Aoooool01?l0003oooooo`000?l00009ooooo`?o
000000?oYl3[o`000?ooool01oooool01?l0003oRe:8o`000?ooool2o`0004gooooo00?o0000oooo
ooooool02Oooool2o`000004ooooool0003o0000o`0000SoRe:800?o0000ooooool00000@?ooool0
03Oooooo1_l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool00ol0003oooooooooo`03
o`0000OoYl3[00?o0000ojO0jol000001_n;DXP01?l0003oooooooooool0001;ooooo`;o00003Ooo
ool01?l0003oooooooooool0001Fooooo`Ko00000_ooool6o`0000Kooooo0ol00004ojO0j`;o0000
2On;DXP00ol0003oooooo`000017ooooo`04o`000?nR?dcoXSm<oj8oC0WoR0D00_lm001Pooooo`03
o`000?m14foo@A=_017o@A=_00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000001kooooo00?o0000
on2DN_oPU7X05_oPU7X2o`0004Kooooo0ol00008ooooo`?o00001?nW`>/2o`0000Oooooo00Ko0000
oh]BR?l0003o0000ooooool0001=ooooo`03o`000?oooooooooo00Kooooo0ol000000onW`>_o0000
o`00000;oh]BR004o`000?oooooo0000o`0003oooooo000fooooo`Go000000?oooooo`000?l00000
0_ooool3o`0000Gooooo0_l0000:ojO0j`03o`000?nW`>_o000000KoRe:800Co0000oooooooooooo
0000Boooool2o`0000gooooo00Co0000oooooooooooo0000Doooool7o`0000;ooooo0_l000000ooo
oooo0000o`000006ooooo`?o00001onW`>/00ol0003oYl3[o`000008oh]BR004o`000?oooooooooo
o`0004Gooooo0_l0000:oj8oC0?oR0D01?nT9a<2og@005[ooooo00?o0000od4CKom14fl04_m14fl0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooo
ooooo`0eooooo`04o`000?ooooooooooo`0001gooooo00?o0000on2DN_oPU7X06?oPU7X2o`0004?o
oooo00?o0000ooooooooool01_ooool3o`0000OoYl3[00?o0000ojO0jol000001_ooool00ol0003o
Re:8o`000003ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool3o`0000Co
Yl3[0ol0000:oh]BR0;o000000?oooooo`000?ooool0?_ooool003Gooooo0_l00003ooooo`;o0000
00Koooooo`000?l0003o0000ooooool00003ooooo`?o00003?nW`>/01?l0003oYl3[ojO0jol00005
oh]BR004o`000?ooooooooooo`0004_ooooo00?o0000ooooool000003?ooool01Ol0003ooooooooo
oooooooo0000057ooooo0_l00005oo6_P`Ko00001Oooool3o`0000_oYl3[00?o0000ojO0jol00000
1on;DXP01?l0003oooooooooool00015ooooo`03o`000?nR?dcoXSm<00_oXSm<0onbDE@5oj@W4`;o
M000E_ooool00ol0003o@A=_od4CK`0Cod4CK`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo03Cooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oPU7[oh9Aj01_oh9Aj00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`04ooooo`?o00002_nW`>/00ol0003oYl3[o`000006ooooo`03o`000?n;DXSo000000?ooooo00?o
0000ooooooooool0BOooool01?l0003oooooooooooooool3o`0000OoYl3[00Co0000ojO0jol0003o
00002On;DXP01Ol0003ooooooooooooooooo000003kooooo000dooooo`03o`000?oooooooooo00?o
00000_ooool2o`0000?ooooo1?l0000>ojO0j`;o00000_nW`>/00ol0003oRe:8oh]BR003oh]BR003
o`000?oooooooooo00;o0000B_ooool01?l0003oooooooooool0000;ooooo`05o`000?oooooooooo
ooooool00000DOooool00ol0003olJn3oo6_P`02oo6_P`;o00000_oa[h<2o`0000Cooooo0ol0000>
ojO0j`04o`000?nW`>_oYl3[o`0000KoRe:800Co0000oooooooooooo0000A?ooool00ol0003oXSm<
oj8oC00<oj8oC0Oo/U5D1?nT9a<2og@005?ooooo00?o0000od4CKom14fl04om14fl01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oh9Ajon2DNP0Lon2D
NP;o0000?_ooool00ol0003oooooooooo`03ooooo`;o00003OnW`>/01?l0003oYl3[ojO0jol00005
ooooo`03o`000?n;DXSo000000?ooooo00?o0000ooooooooool0BOooool4o`0000[oYl3[00?o0000
ojO0jonW`>/00ol00007oh]BR005o`000?ooooooooooooooool00000?_ooool003Cooooo0ol00006
ooooo`;o000000?oooooo`000?l000000ol0000;ojO0j`?o000000?oYl3[o`000?nW`>/00_nW`>/0
0ol0003oRe:8oh]BR003oh]BR0;o000000?oooooo`000?ooool0BOooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`03o`000?oa
[h?olJn300?o00001_oa[h<01?l0003oooooo`000?l0000@ojO0j`;o00000_nW`>/00ol0003oRe:8
oh]BR004oh]BR003o`000?oooooo000000;o0000@oooool00ol0003o[61fojaPMP05ojaPMPKoXSm<
2onbDE@2oj@W4`;oaE8_00?o]2/0ooooooooool0Coooool00ol0003o@A=_od4CK`0Cod4CK`03o`00
0?oooooo000000Gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oPU7[oh9Aj01co
h9Aj00?o0000ooooooooool0??ooool01?l0003oooooooooooooool3o`0000koYl3[0_l00003ojO0
j`03o`000?oooooooooo00;ooooo00?o0000oh]BR?l000000oooool2o`0004[ooooo0_l0000<ojO0
j`04o`000?nW`>_oYl3[ojO0j`;o00001on;DXP01Ol0003ooooooooooooooooo000003kooooo000c
ooooo`;o00002?ooool3o`000003ojO0jol0003oYl3[00;oYl3[1_l00002ojO0j`?o00001?nW`>/0
0ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800;oRe:800Go0000ooooooooooooooooo`00
0019ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04gooooo0ol00008oo6_P`?o00003onW`>/3o`000003ojO0jol0
003oYl3[00;oYl3[00?o0000oh]BR?n;DXP00on;DXP2o`0000;ooooo00?o0000ooooooooool0@Ooo
ool00ol0003o[61fojaPMP0;ojaPMPCo^6]h2?nbDE@2olU[G0;oaE8_00?o]2/0ooooooooool0C_oo
ool00ol0003o@A=_od4CK`0Cod4CK`03o`000?oooooo000000Gooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oPU7[oh9Aj01coh9Aj00?o0000ooooooooool0>oooool00ol0003ooooo
o`000002o`0000koYl3[0ol000000onW`>_o0000ojO0j`02ojO0j`03o`000?oooooooooo00?ooooo
00?o0000oh]BR?l000000_l000000ooooooo0000ooooo`19ooooo`03o`000?oooooo000000;o0000
2OnW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800GoRe:800Co0000oooooooooooo
oooo0_l0000mooooo`00<_ooool00ol0003oooooooooo`07ooooo`;o00000onW`>/00ol0003oYl3[
ojO0j`06ojO0j`Go00001_nW`>/00ol0003oYl3[ojO0j`02ojO0j`05o`000?n;DXSoRe:8oh]BR?l0
00000oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo00?o0000oo6_Pooa
[h<01_oa[h<3o`0000ooYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;
DXP00_n;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo0_l0000=ojaPMPWo
^6]h0onbDE@4olU[G004olEB;ond:`3o0000o`0004gooooo00?o0000od4CKom14fl04om14fl2o`00
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oPU7[oh9Aj01coh9Aj00?o0000
ooooooooool0>_ooool3o`0000ooYl3[0_l00004ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ooooooooool00_ooool00ol0003oRe:8o`000004ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool00_ooool2o`0000KoYl3[0_l00004ojO0j`;o00001_n;DXP4o`000003ooooool0003o
oooo03cooooo000booooo`03o`000?oooooooooo00Cooooo0ol000000onW`>_o0000ojO0j`02ojO0
j`03o`000?nW`>_oYl3[00CoYl3[0_l00005ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`03ojO0
j`04o`000?n;DXSoRe:8o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;
ooooo`03o`000?oa[h?olJn300?olJn30ol0000?ojO0j`?o00001onW`>/00ol0003oYl3[ojO0j`03
ojO0j`05o`000?n;DXSoRe:8oh]BR?l000001?ooool00ol0003oooooooooo`0ooooooaWo000000?o
^6]holYlNOo:O7T01?o9Je`01?o5DRoo]2/0o`000?l0001<ooooo`03o`000?m14foo@A=_01?o@A=_
0_l00006ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oh9Ajon2DNP0Lon2DNP03
o`000?oooooooooo03Wooooo6?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Oo0000oooooooo
ooooooooo`000?n;DXSo000000Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`04
ooooo`Ko000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oRe:8oh]BR004oh]BR003o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>_ooool003;ooooo00Co0000oooooooooooooooo0ol00003
ojO0j`;o00000onW`>/01?l0003oYl3[ojO0jonW`>/3o`0000[oYl3[1?l00005ojO0j`04o`000?n;
DXSoRe:8o`0000?ooooo0_l00018ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo00?o0000oo6_Pooa[h<0
0ol0000?ojO0j`?o00002onW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?n;DXSoRe:8o`0000Co
oooo00?o0000ooooooooool0?oooool2o`0000go/GF@1?nkOHl;o`000004olYlNOo9JecobF]LolU[
G0?o0000B_ooool00ol0003o@A=_od4CK`0Dod4CK`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oPU7[oh9Aj01goh9Aj00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0:ooooo`;o00002?ooool3o`0000GoYl3[00Ko0000oooooooooooo0000oh]B
R?l00004ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01?ooool5o`0000;oYl3[
00?o0000ojO0jonW`>/01?nW`>/00ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>Oooool0037ooooo00?o0000ooooool000000_l00006ojO0j`;o00000onW
`>/4o`00013oYl3[0_l00005ojO0j`03o`000?n;DXSo000000?o000000?oooooo`000?ooool0Aooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`19ooooo`Co00003onW`>/3o`0000koYl3[00?o0000ojO0jonW`>/00onW
`>/01?l0003oRe:8oh]BR?l00003ooooo`?o0000@?ooool2o`0000go/GF@2onkOHl3ol^9S0Ko0000
00?o053>o`000?l00000BOooool00ol0003o@A=_od4CK`0Dod4CK`03o`000?oooooooooo00?ooooo
0ol00003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000on2DN_oPU7X07OoPU7X00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Kooooo0ol0000<ooooo`Co00000onW`>/01Ol0003ooooo
o`000?n;DXSo000000Cooooo0_l00018ooooo`04o`000?ooooooooooooooo`?o00001Oooool2o`00
0003ojO0jol0003oYl3[00GoYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03Wooooo000aooooo`;o00002?nW`>/01?l0003oYl3[o`000?nW`>/3o`00
01;oYl3[0ol00006ojO0j`;o00001Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04Wooooo00?o0000ojO0jonW`>/03OnW`>/3o`00013oYl3[0_l00006ojO0j`03o`000?n;DXSoRe:8
00?o00000_ooool00ol0003oooooooooo`0nooooo`;o00003OnaMI0;ok]mS`OobhV<0_l00002oaYA
bP03o`000?oooooooooo04Oooooo00?o0000od4CKom14fl05?m14fl00ol0003oooooo`000003o`00
00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oPU7[oh9Aj01goh9Aj00?o0000
ooooooooool0>oooool00ol0003oooooooooo`03ooooo`;o00003oooool01?l0003ooooooooooooo
ool2o`000007ojO0jol0003oooooo`000?n;DXSo0000ooooo`03o`000003ooooool0003ooooo04Oo
oooo1?l0000:ooooo`;o00001onW`>/01Ol0003oRe:8oh]BR?n;DXSo000000Kooooo0_l0000joooo
o`00<Oooool00ol0003oYl3[ojO0j`07ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`0=ojO0j`?o
00000_nW`>/00ol0003oYl3[ojO0j`04ojO0j`;o00001Oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo0_l0000;ojO0j`?o00004?nW`>/3o`000003ojO0jol0003oYl3[00Ko
Yl3[00?o0000oh]BR?l000001Oooool00ol0003oooooooooo`0mooooo`03o`000?naMI3o/GF@00co
/GF@2onkOHl8ol^9S005o`000?lUAkko9DNnoaYAb_l00000B?ooool00ol0003o@A=_od4CK`05od4C
K`03o`000?m14foo@A=_00_o@A=_0ol00007ooooo`04o`000?ooooooooooo`00017ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000
on2DN_oPU7X07OoPU7X00ol0003oooooooooo`0looooo`03o`000?oooooo000000;o00004_ooool0
0ol0003oooooooooo`02ooooo`05o`000?nW`>_o0000o`000?n;DXP00_l00005ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool03?ooool3o`0000GoYl3[00Go0000oh]BR?n;DXSoRe:8
o`000003ooooo`?o000000?oooooo`000?ooool0>Oooool0037ooooo0_l00006ojO0j`?o000000?o
Yl3[o`000?nW`>/00onW`>/00ol0003oYl3[ojO0j`09ojO0j`?o00001OnW`>/2o`0000KoYl3[00?o
0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o
0000oo6_Pol000001onW`>/3o`00013oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[0_l0
0005ooooo`03o`000?oooooooooo03gooooo00?o0000ok5eT?naMI003?naMI06ok]mS`Go_H^P1Oo<
UI/3ol^9S005o`000?lUAkko9DNnobE7__l00000B?ooool00ol0003o@A=_od4CK`0Bod4CK`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oh9Ajon2DNP0Mon2DNP03o`00
0?oooooooooo03gooooo0_l0000Cooooo`;o00001Oooool01Ol0003oYl3[o`000?n;DXSo000000Ko
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`00
00CoYl3[00?o0000oh]BR?n;DXP01?l00004ooooo`03o`000?oooooooooo03Sooooo000aooooo`;o
00000onW`>/3o`000005ojO0jol0003oYl3[ojO0jol000001?nW`>/00ol0003oYl3[ojO0j`06ojO0
j`?o00002OnW`>/2o`0000CoYl3[00?oRe:8o`000?ooool01Oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo04Sooooo00Co0000oo6_Pooa[h?o00000onW`>/3o`00013oYl3[0ol00008ojO0j`03o`000?nW
`>_oYl3[00KoYl3[00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?na
MI3o/GF@00Go/GF@1oneQJ8;okf;X0Soc9FK00Co0000obE7__lUAkko9DNn0_l00017ooooo`03o`00
0?m14foo@A=_017o@A=_0_l0000<ooooo`;o00004_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oh9Ajon2DNP0Mon2DNP03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03Oooool3o`000003ooooool0003ooooo00Gooooo
00Co0000ojO0jol0003o00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00co
oooo0_l00003ooooo`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?l000001oooool00ol0003o
ooooooooo`0hooooo`00<Oooool5o`0000CoYl3[00Co0000ojO0jonW`>_o00001?nW`>/00ol0003o
Yl3[ojO0j`03ojO0j`?o00003?nW`>/00ol0003oYl3[o`000004oh]BR0;o00000oooool3o`0004So
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
04Oooooo00Co0000oo6_Pooa[h?olJn30ol0000@ojO0j`?o00002onW`>/00ol0003oYl3[ojO0j`04
ojO0j`;oRe:800?o0000ooooooooool00_ooool3o`0003kooooo00?o0000okF5X_neQJ803?neQJ8<
okf;X0Goc9FK0_o?X:L00ol0003o8cJ]ob<f[@02ob<f[@03o`000?oooooooooo04Gooooo00?o0000
od4CKom14fl04?m14fl00ol0003oooooo`00000=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000
on2DN_oPU7X07OoPU7X00ol0003oooooooooo`10ooooo`;o00002_ooool3o`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oYl3[o`000007ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool02Oooool3o`000003ooooool0003ooooo00?ooooo00?o0000ojO0jonW`>/00_nW`>/2
o`0000Sooooo00?o0000ooooooooool0=oooool0037ooooo0ol00006ojO0j`05o`000?nW`>_oYl3[
ojO0jol000001?nW`>/00ol0003oYl3[o`000002o`0000ooYl3[00?o0000oh]BR?l000001?n;DXP0
0ol0003oYl3[o`000002o`0000;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0Aoooool4o`000003oo6_Pol0003o
000000goYl3[0ol0000>ojO0j`04o`000?nW`>_oYl3[ojO0j`GoRe:81Ol00002ooooo`03o`000?oo
oooooooo03cooooo00?o0000okF5X_neQJ803OneQJ8;okf;X0;oc9FK1_o?X:L01Ol0003o8cJ]ob<f
[OlE79Oo000004Oooooo00?o0000od4CKom14fl03_m14fl2o`000003ooooool0003ooooo00gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03?ooool00ol0003oh9Ajon2DNP0Mon2DNP03o`000?oooooooooo04;ooooo
00?o0000ooooooooool01?ooool3o`0000Sooooo00?o0000ooooooooool00oooool2o`000003oh]B
R?l0003o000000Gooooo0_l00017ooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Oooooo000aooooo`03o`000?oooooo000000OoYl3[00Co0000ojO0jonW`>_o0000
0onW`>/3o`0000ooYl3[1?n;DXP2o`0000GoRe:800?o0000ojO0jol000000oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`03o`000?oooooooooo04Oooooo
00?o0000oo6_Pooa[h<01?oa[h<00ol0003oYl3[ojO0j`07ojO0j`?o00004OnW`>/00ol0003oRe:8
oh]BR006oh]BR003o`000?nW`>_o000000Cooooo00?o0000ooooooooool0??ooool00ol0003o]HFR
okF5XP0=okF5XPSo_H^P0oo1V:h7olnPY`03om>[/Ol0003o8cJ]00;o5AbG00?o0000ooooooooool0
AOooool00ol0003o@A=_od4CK`0=od4CK`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooo`00000Cooooo`;o0000:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_o
oooo00?o0000on2DN_oPU7X07_oPU7X00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00?o
00002oooool00ol0003oooooooooo`03ooooo`;o000000GoRe:8o`000?nW`>_o0000ooooo`03o`00
0003ooooool0003ooooo04Kooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000oooo
ooooool00oooool01?l0003oYl3[oh]BR?n;DXP2o`0000Kooooo0_l0000iooooo`00<Oooool01?l0
003oooooooooool00006ojO0j`03o`000?nW`>_oYl3[00Co000000?oYl3[o`000?nW`>/03?nW`>/5
oh]BR0Co00001On;DXP00ol0003oYl3[o`000004ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000
oo6_Pooa[h<01Ooa[h<00ol0003oYl3[ojO0j`03ojO0j`?o00004_nW`>/3oh]BR003o`000?n;DXSo
Re:800GoRe:800Co0000ojO0jonW`>_o00000oooool00ol0003oooooooooo`0mooooo`03o`000?ne
QJ;o]HFR00co]HFR0onmRj09ol6H[P?ocj2W1?oCZk42o`0000;o5AbG0_l00015ooooo`03o`000?m1
4foo@A=_00go@A=_00Go0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000oo
oooo0ol000000ooooooo0000ooooo`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01?ooool8o`0001ooh9Aj00?o0000ooooooooool0@oooool2o`0000kooooo00?o0000oooooooo
ool00oooool2o`000005oh]BR?l0003oYl3[ojO0jol000001?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooo000000;o00002oooool00ol0003oooooooooo`03ooooo`07o`000?n;DXSoRe:8
oh]BR?l0003oYl3[o`000002ooooo`?o000000?oooooo`000?ooool0>?ooool0037ooooo00Go0000
ooooooooooooooooo`000005ojO0j`Go00000onW`>/00ol0003oYl3[ojO0j`07ojO0j`KoRe:80ol0
0002oh]BR0;o00001On;DXP01?l0003oYl3[ojO0jol00003ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000ooooooooool0A_ooool00ol0003olJn3
oo6_P`06oo6_P`03o`000?nW`>_o000000;o00004_nW`>/4oh]BR0?o00001on;DXP01?l0003oYl3[
ojO0jol00004ooooo`03o`000?oooooooooo03cooooo00?o0000okF5X_neQJ802_neQJ82okVD/@co
`IR^00?ocj2Wom>[/OoCZk400ooCZk42omRh^@03o`000?lE79Oo5AbG00;o0000AOooool00ol0003o
@A=_od4CK`0<od4CK`03o`000?oooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo2_l00004ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool05?ooool6o`0000;oZg2?0ol00003oj]`S`;o00007OoPU7X00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00cooooo00Wo0000ooooooooooooooooo`000?oooooo
0000oh]BR?l000000onW`>/01Ol0003ooooooooooooooooo000004Oooooo0_l0000>ooooo`03o`00
0?oooooooooo00?ooooo00Go0000oh]BR?n;DXSoRe:8o`000002ojO0j`;o00001Oooool00ol0003o
ooooooooo`0fooooo`00<Oooool01Ol0003ooooooooooooooooo000000?oYl3[0ol00002ojO0j`03
o`000?nW`>_oYl3[00?oYl3[00?o0000ojO0jonW`>/00onW`>/6oh]BR0?o00001_n;DXP00ol0003o
Re:8oh]BR003oh]BR004o`000?nW`>_oYl3[ojO0j`Co0000B?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool0A_ooool00ol0003olJn3oo6_P`05oo6_
P`?o00004OnW`>/5oh]BR0?o00000_n;DXP00ol0003oRe:8oh]BR005oh]BR005o`000?nW`>_oYl3[
ojO0jol000000oooool00ol0003oooooooooo`0looooo`03o`000?neQJ;o]HFR00Go]HFR1oniU;4;
ol6H[P03olFV^OoCZk7odj^a00?odj^a0ooH^;T01?oOaKoo0000o`00M_l00016ooooo`03o`000?m1
4foo@A=_00[o@A=_0_l00003ooooo`03o`000?oooooo000000Kooooo4Ol00008oj]`S`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`03o`000?n[
L8ooZg2?00;oZg2?0ol00008oj]`S`;o00006ooPU7X00ol0003oooooooooo`16ooooo`;o00002_oo
ool3o`0000?ooooo0ol000000on;DXSo0000ojO0j`02ojO0j`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000oh]BR?n;DXP00_n;DXP01?l0003oYl3[ojO0jol00005ooooo`03o`000?oooooooooo03Kooooo
000aooooo`03o`000?oooooooooo00;ooooo0ol00003ojO0j`04o`000?nW`>_oYl3[o`0000CoYl3[
00?o0000ojO0jon;DXP01_n;DXP3o`0000WoRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003oYl3[
ojO0j`02ojO0j`03o`000?oooooo000004Sooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo04Oooooo00Co0000oo6_Pooa[h?olJn30ol00003oo6_
P`03o`000?nW`>_oYl3[00_oYl3[1On;DXP3o`0000KoRe:800?o0000oh]BR?n;DXP01?n;DXP00ol0
003oYl3[ojO0j`02ojO0j`Co0000?_ooool2o`000003okF5X_niU;7o^IBa00_o^IBa1oo1V:h5olFV
^@;odj^a1OoH^;T01?oOaKoo0000o`000?l00016ooooo`03o`000?m14foo@A=_00Wo@A=_00?o0000
ooooooooool01?ooool8o`0000KoZg2?00?o0000oj]`Son[L8l01On[L8l00ol0003oZg2?oj]`S`08
oj]`S`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0D
ooooo`03o`000?n[L8oo000000;o00003On[L8l2o`0001Woh9Aj00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`04ooooo`?o00000_ooool02Ol0003ooooooooooooooooo0000ooooool0003o
Re:8o`000004ojO0j`05o`000?ooooooooooooooool00000Aoooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP00_n;DXP01?l0003oYl3[ojO0jol00005
ooooo`03o`000?oooooooooo03Kooooo000aooooo`03o`000?oooooo000000;o000000?oooooo`00
0?nW`>/01?nW`>/00ol0003oYl3[o`000003ojO0j`03oh]BR?l0003oRe:800CoRe:80ol0000<oh]B
R003o`000?n;DXSoRe:800?oRe:800?o0000ojO0jonW`>/00_nW`>/00ol0003oooooo`000018oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo04Oooooo1?l00007oo6_P`03o`000?nW`>_oYl3[00OoYl3[1On;DXP3o`0000WoRe:800?o0000
oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`03ojO0j`03o`000?oooooo000003kooooo0_l0000>
okVD/@Co`IR^2?o5Y[T00ooCZk7of;RiomRh^@03omRh^@04omo5_ol0003olNO1oo?d[TOooooo00?o
0000od4CKom14fl02?m14fl00ol0003oooooooooo`05ooooo`03o`000?n[L8ooZg2?00[oZg2?00?o
0000oj]`Son[L8l01on[L8l00ol0003oZg2?oj]`S`07oj]`S`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`?o00004_n[L8l2o`0001Ooh9Aj00?o
0000ooooooooool0BOooool00ol0003oooooooooo`03o`0000Kooooo00?o0000ooooool000000_oo
ool00ol0003oRe:8o`000005ojO0j`Co0000Aoooool00ol0003oooooooooo`0;ooooo`?o00000ooo
ool00ol0003oRe:8oh]BR003oh]BR005o`000?nW`>_oYl3[ojO0jol000001Oooool00ol0003ooooo
ooooo`0eooooo`00<Oooool2o`0000Gooooo00?o0000ojO0jonW`>/00onW`>/2o`0000GoRe:800?o
0000oh]BR?l000000_l0000>oh]BR003o`000?n;DXSo000000CoRe:800?o0000ojO0jonW`>/00onW
`>/00ol0003oooooo`000018ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04Kooooo00?o0000oo6_Pooa[h<02Ooa[h<00ol0003oYl3[
ojO0j`03ojO0j`GoRe:80ol0000=oh]BR003o`000?n;DXSoRe:800?oRe:800?o0000ojO0jonW`>/0
0onW`>/00ol0003oooooo`00000nooooo`;o00003_niU;400oo1V:koaJJiolFV^@08olFV^@03ol^d
a?oH^;Wof;Ri00?of;Ri00GoglFoo`000?oWe/ColNO1oo?d[P17ooooo`03o`000?m14foo@A=_00Oo
@A=_00?o0000ooooooooool01_ooool00ol0003oZg2?oj]`S`0:oj]`S`03o`000?n[L8ooZg2?00Oo
Zg2?00?o0000oj]`Son[L8l01on[L8l00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool3o`000003ooooool0003oZg2?01CoZg2?0_l0000Eon2DNP03
o`000?oooooooooo04[ooooo0_l00009ooooo`03o`000?oooooo000000;ooooo00?o0000oh]BR?l0
00001_nW`>/00ol0003oooooo`000018ooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`05
o`000?ooooooooooooooool000001On;DXP00ol0003oYl3[ojO0j`02ojO0j`04o`000?oooooooooo
ooooo`;o0000=oooool0037ooooo00?o0000ooooooooool01Oooool02?l0003oYl3[ojO0jonW`>_o
Re:8o`000?n;DXSo00000_n;DXP4o`00017oRe:80ol00004oh]BR003o`000?nW`>_oYl3[00CoYl3[
0_l00018ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000oo6_Pooa[h<02_oa[h<00ol0003oYl3[
oh]BR003oh]BR0Co00004?n;DXP00ol0003oRe:8oh]BR003oh]BR003o`000?nW`>_oYl3[00CoYl3[
00?o0000ooooool00000?_ooool00ol0003o^IBaokVD/@0;okVD/@03okfR_Oo5Y[WoaJJi00OoaJJi
1?o;]<@3omRh^@;oglFo00?o0000oo7W`Oocm:h0B?ooool00ol0003o@A=_od4CK`05od4CK`;o0000
2Oooool00ol0003oZg2?oj]`S`09oj]`S`03o`000?n[L8ooZg2?00WoZg2?00?o0000oj]`Son[L8l0
1_n[L8l00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3Oooool3o`0000Cooooo00?o0000oj]`Son[L8l05On[L8l2o`0001Coh9Aj00?o0000ooooooooool0
Boooool00ol0003oooooooooo`07ooooo`07o`000?ooooooooooooooool0003oRe:8o`000006ojO0
j`03o`000?oooooo000004Sooooo00?o0000ooooooooool00oooool4o`0000Kooooo00Co0000oooo
oooooooo00001On;DXP00ol0003oYl3[ojO0j`03ojO0j`?o000000?oooooo`000?ooool0=_ooool0
03;ooooo00?o0000ooooooooool01Oooool01?l0003oRe:8oh]BR?n;DXP5o`0000;oRe:800?o0000
oh]BR?n;DXP03On;DXP3o`0000;oRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oYl3[ojO0j`03
ojO0j`?o0000B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`16ooooo`03o`000?oa[h?olJn300[olJn300?o0000
oh]BR?n;DXP00ol0000Coh]BR0?o00001On;DXP00ol0003oYl3[ojO0j`04ojO0j`;o0000?_ooool2
o`0000Wo^IBa1OnmX[d7olFV^@KobkC400Oof;Riomo5_ooOaKoo0000onOFa?oail7oloB^04Sooooo
00?o0000od4CKom14fl01?m14fl00ol0003oooooooooo`09ooooo`03o`000?n[L8ooZg2?00WoZg2?
00?o0000oj]`Son[L8l02_n[L8l00ol0003oZg2?oj]`S`05oj]`S`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`?o00001oooool00ol0003oZg2?
oj]`S`0Goj]`S`;o00004_oPU7X00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Gooooo
0_l00002ooooo`;o000000?oRe:8o`000?nW`>/01_nW`>/00ol0003oooooo`000017ooooo`03o`00
0?oooooooooo00?o00002_ooool01?l0003oooooooooool00005oh]BR003o`000?nW`>_oYl3[00Co
Yl3[00Co0000oooooooooooo0000=oooool003;ooooo00?o0000ooooooooool01Oooool5o`000003
oh]BR?l0003oRe:800CoRe:800?o0000oh]BR?n;DXP02On;DXP3o`0000;oRe:800Go0000oh]BR?n;
DXSoRe:8o`000003oh]BR003o`000?nW`>_o000000?o00000_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000004Wooooo00?o0000oo6_Pooa[h<02Ooa[h<3o`0001?oRe:80ol00002oh]BR003o`000?n;DXSo
Re:800?oRe:800?o0000ojO0jonW`>/00onW`>/3o`0003kooooo0_l00006okVD/@So_J:m1Oo5Y[T7
ol^da005om75c_oOaKooglFoo`000?oWe/@00_oail400ooHhWCoooooooooo`16ooooo`03o`000?m1
4foo@A=_00?o@A=_00?o0000ooooooooool02_ooool00ol0003oZg2?oj]`S`08oj]`S`03o`000?n[
L8ooZg2?00coZg2?00?o0000oj]`Son[L8l01?n[L8l00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01oooool3o`0000[ooooo00?o0000oj]`Son[L8l06On[
L8l3o`0000ooh9Aj00?o0000ooooooooool0COooool00ol0003oooooooooo`04ooooo`Ko00000_n;
DXP00ol0003oYl3[ojO0j`05ojO0j`;o0000B?ooool2o`0000kooooo00?o0000ooooool000001On;
DXP00ol0003oYl3[ojO0j`04ojO0j`04o`000?ooooooooooo`0003Oooooo000booooo`03o`000?oo
oooooooo00?ooooo0ol00003oh]BR004o`000?n;DXSoRe:8o`0000CoRe:800?o0000oh]BR?n;DXP0
1_n;DXP3o`0000CoRe:800?o0000oh]BR?n;DXP00_n;DXP01?l0003oRe:8oh]BR?n;DXP2o`0000Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo0000BOooool00ol0003olJn3oo6_P`06oo6_P`Co00004_n;DXP3o`00
00KoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oYl3[o`000003o`0000;ooooo00?o0000oooo
ooooool0?Oooool01?l0003o^IBaokVD/OniU;4;okfR_@?oaJJi2?o;]<@3om75cP05o`000?oWe/Co
imK4oo7W`Oocm:h0BOooool00ol0003o@A=_od4CK`02od4CK`03o`000?oooooooooo00_ooooo00?o
0000oj]`Son[L8l02?n[L8l00ol0003oZg2?oj]`S`0=oj]`S`03o`000?n[L8ooZg2?00CoZg2?00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0ol0
000=ooooo`03o`000?n[L8ooZg2?01coZg2?0_l0000=on2DNP03o`000?oooooooooo04kooooo00?o
0000ooooooooool00_ooool5o`000005ojO0jol0003oRe:8oh]BR?l000001_nW`>/3o`0004Sooooo
00?o0000ooooooooool03Oooool2o`0000KoRe:800?o0000ojO0jonW`>/01OnW`>/00ol0003ooooo
o`00000gooooo`00<oooool00ol0003oooooo`000002o`0000;ooooo00Go0000oh]BR?n;DXSoRe:8
o`000002oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP00on;DXP3o`0000OoRe:8
00?o0000oh]BR?n;DXP00on;DXP01?l0003oRe:8oh]BR?l00007ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000004Wo
oooo00?o0000oo6_Pooa[h<00ooa[h<3o`0000?olJn300?o0000oh]BR?n;DXP03On;DXP3o`0000Wo
Re:800?o0000oh]BR?n;DXP00_n;DXP2o`0000Kooooo00?o0000ooooooooool0?Oooool2o`0000ko
_J:m00?oaJJiol^da?o;]<@01_o;]<@4om75cP05o`000?oJfMKoimK4oo7W`Oocm:h0B?ooool01?l0
003o@A=_od4CKom14fl2o`0000kooooo00?o0000oj]`Son[L8l01on[L8l00ol0003oZg2?oj]`S`0?
oj]`S`03o`000?n[L8ooZg2?00?oZg2?00?o0000ooooooooool00oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo0ol0000@ooooo`03o`000?n[L8ooZg2?01koZg2?0_l0000;
on2DNP03o`000?oooooooooo04oooooo00?o0000ooooooooool01Ol00002ojO0j`04o`000?n;DXSo
Re:8o`0000;oYl3[1?l00002ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03?oo
ool2o`0000KoRe:800?o0000ojO0jonW`>/01_nW`>/2o`0003Oooooo000cooooo`;o00001Oooool0
1Ol0003oRe:8oh]BR?n;DXSo000000;oRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003oRe:8o`00
0002o`0000WoRe:800?o0000oh]BR?n;DXP01?n;DXP01?l0003oRe:8oh]BR?l00005ooooo`?o0000
B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
BOooool00ol0003olJn3o`000002o`0000KolJn300?o0000oh]BR?n;DXP02_n;DXP3o`0000goRe:8
00Go0000oh]BR?n;DXSoRe:8o`000007ooooo`03o`000?oooooooooo03gooooo0_l0000=okfR_@03
ol:abOo;]<CobkC400GobkC41OoAaLh01_l0003of]WFom[Ie_oRlMWolNO1o`0004Sooooo00Co0000
od4CKom14foo00004?ooool00ol0003oZg2?oj]`S`07oj]`S`03o`000?n[L8ooZg2?013oZg2?00?o
0000oj]`Son[L8l00_n[L8l00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooool000000_l0000Cooooo`03o`000?n[L8ooZg2?023oZg2?0_l00009on2DNP03o`000?oo
oooooooo053ooooo0ol000001ooooooo0000ojO0jonW`>_o0000ojO0jol000000_n;DXP3o`0000Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0;ooooo`?o00001_n;DXP00ol0003o
Yl3[ojO0j`05ojO0j`?o0000=oooool003?ooooo00?o0000ooooooooool01?ooool01Ol0003oRe:8
oh]BR?n;DXSo000000?oRe:800?o0000oh]BR?n;DXP01?l0000<oh]BR003o`000?n;DXSoRe:800?o
Re:80ol000001?n;DXSo0000ooooooooool3o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0_l00019ooooo`;o00002Ooa[h<00ol0
003oRe:8oh]BR006oh]BR0Co00004?n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000Gooooo0ol00010
ooooo`03o`000?nmX[go_J:m00Wo_J:m1?o2/LT5ol^da0GodLG>00Ko0000om[Ie_oJfMKof]WFon;a
fOoGo[m9ooooo`03o`000?m14foo0000017ooooo00?o0000oj]`Son[L8l01_n[L8l00ol0003oZg2?
oj]`S`0Boj]`S`05o`000?n[L8ooZg2?oj]`Sol000001Oooool00ol0003oooooooooo`0Uooooo`;o
00005_ooool00ol0003oZg2?oj]`S`0Roj]`S`;o00001ooPU7X00ol0003oooooooooo`1Aooooo`?o
00000onW`>/3o`0000;oRe:800?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00Oooooo0ol000000ooooooo0000o`000006oh]BR004o`000?nW`>_oYl3[ojO0
j`Co00000_ooool00ol0003oooooooooo`0eooooo`00=?ooool00ol0003oooooooooo`03ooooo`03
o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?l000000ol00002oh]BR003o`000?n;DXSoRe:800[o
Re:800?o0000oh]BR?n;DXP01?l00002oh]BR003o`000?n;DXSoRe:800;o00001Oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oa[h?olJn300SolJn300?o0000oh]BR?n;DXP00on;DXP3o`0001?o
Re:80ol00002oh]BR003o`000?oooooooooo00?o00000_ooool00ol0003oooooooooo`0nooooo`;o
00002?nmX[d7ol:ab@?obkC41?oAaLh2o`0000?of]WF0_oRlMU:ooooo`;o00004_ooool00ol0003o
Zg2?oj]`S`06oj]`S`03o`000?n[L8ooZg2?01;oZg2?00Go0000oj]`Son[L8ooZg2?o`000006oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool00ol0003oZg2?oj]`S`0Roj]`
S`;o8@]k0_l00005on2DNP03o`000?oooooooooo057ooooo00?o0000ojO0jol000001_l00002oh]B
R003o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03oooo
o`Co00001?ooool00ol0003oRe:8o`000005oh]BR0Co00001_ooool00ol0003oooooooooo`0eoooo
o`00=?ooool00ol0003oooooooooo`03ooooo`04o`000?n;DXSoRe:8oh]BR0?o000000?oRe:8o`00
0?n;DXP01?n;DXP00ol0003oRe:8oh]BR008oh]BR0Co00001on;DXP00ol0003oRe:8o`000006oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Sooooo00?o0000oo6_Pooa[h<01ooa[h<00ol0003oRe:8oh]BR003o`00
01?oRe:80ol00002oh]BR003o`000?n;DXSoRe:800?o00001Oooool00ol0003oooooooooo`0ooooo
o`;o00001OnmX[d:ol:ab@03ol^da?oAaLkodLG>00;odLG>0_l00003om[IeP;oh_7I00?o0000oooo
ooooool0B?ooool2o`0001;ooooo00?o0000oj]`Son[L8l01On[L8l00ol0003oZg2?oj]`S`0Doj]`
S`04o`000?n[L8ooZg2?o`0000Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0B
ooooo`03o`000?n[L8ooZg2?02;oZg2?1?lQ2g/2o`0000Coh9Aj00?o0000ooooooooool0Coooool5
o`0000?ooooo0_l00002oh]BR003o`000?oooooooooo00Cooooo0ol0001:ooooo`03o`000?oooooo
oooo00?o00002?ooool01?l0003oRe:8oh]BR?l00004oh]BR003o`000?oooooooooo00Oooooo00?o
0000ooooooooool0=Oooool003Gooooo00?o0000ooooooooool00_ooool4o`0000;oRe:800Co0000
oh]BR?n;DXSo00001On;DXP00ol0003oRe:8oh]BR004oh]BR0Co00002on;DXP2o`0000Cooooo0ol0
001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oa[h?olJn300OolJn30ol0000Boh]BR0Co00001_n;DXP00ol0003oRe:8o`00
0007ooooo`03o`000?oooooooooo03oooooo0_l00004okfR_@[o`[7900?obLCEom75c_oAaLh00_oA
aLh2o`0000?of]WF0_oRlMT00ooGo[ooooooooooo`1;ooooo`03o`000?oooooooooo00oooooo00?o
0000oj]`Son[L8l01?n[L8l00ol0003oZg2?oj]`S`0Foj]`S`03o`000?n[L8oo000000Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?n[L8ooZg2?02;oZg2?1_lQ
2g/2o`0000;oh9Aj00?o0000ooooooooool0C_ooool2o`0000Cooooo00?o0000ooooooooool00_l0
0002oh]BR004o`000?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`19ooooo`;o0000
2_ooool01Ol0003oRe:8oh]BR?n;DXSo000000CoRe:800?o0000ooooooooool01oooool00ol0003o
ooooooooo`0eooooo`00=Oooool00ol0003oooooooooo`03o`0000GoRe:800Go0000oh]BR?n;DXSo
Re:8o`000004oh]BR003o`000?n;DXSoRe:800Co00000_n;DXP00ol0003oRe:8oh]BR009oh]BR0Oo
00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`19ooooo`03o`000?oa[h?olJn300?olJn30ol0000Boh]BR0?o
00002on;DXP2o`0000Gooooo0ol00011ooooo`04o`000?nmX[go0000okfR_@_o`[790oo9a=D2om75
cP;o00000ooJfMH2on;af@03omOn_ooooooooooo04gooooo00?o0000ooooooooool03_ooool00ol0
003oZg2?oj]`S`04oj]`S`03o`000?n[L8ooZg2?01OoZg2?0_l00006ooooo`03o`000?oooooooooo
02Wooooo0_l0000@ooooo`03o`000?n[L8ooZg2?02?oZg2?2?lQ2g/3o`0005;ooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003o0000oh]BR0Co00001Oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00Wooooo00?o0000oh]BR?n;DXP00_n;DXP01Ol0003oRe:8oh]BR?n;
DXSo000000Oooooo0ol0000gooooo`00=_ooool2o`0000?ooooo00?o0000oh]BR?n;DXP00on;DXP2
o`0000;oRe:800?o0000oh]BR?n;DXP01?l00005oh]BR003o`000?n;DXSoRe:800OoRe:81_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Wooooo00?o0000oo6_Pooa[h<00ol00002
oo6_P`03o`000?n;DXSoRe:800coRe:81?l0000=oh]BR0So00000_ooool00ol0003oooooooooo`10
ooooo`;o00002_o2/LT5olW4e@?o00001?oJfMH2on;af@03omOn_ooooooooooo04kooooo00?o0000
ooooooooool03?ooool00ol0003oZg2?oj]`S`04oj]`S`03o`000?n[L8ooZg2?01WoZg2?00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000
oj]`Son[L8l08on[L8l:ob4;N`03o`000?oooooooooo057ooooo00?o0000ooooooooool00oooool3
o`000003oh]BR?l0003ooooo00Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`07
ooooo`03o`000?n;DXSoRe:800;oRe:80ol00002oh]BR004o`000?ooooooooooooooo`Co00000_oo
ool00ol0003oooooooooo`0eooooo`00=_ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSo
Re:800GoRe:81Ol00003oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP01?n;DXP5
o`0000Gooooo1_l0001?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1:ooooo`;o00001Ooa[h<00ol0003oRe:8oh]BR009oh]BR0?o00003On;DXP9
o`0000Cooooo00?o0000ooooooooool0@Oooool2o`0000Wo`[791Oo9a=D2o`0000;od=[P0ooJfMH2
on;af@03omOn_ooooooooooo053ooooo00?o0000ooooooooool02oooool00ol0003oZg2?oj]`S`04
oj]`S`03o`000?n[L8ooZg2?01WoZg2?0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool03?ooool00ol0003oZg2?oj]`S`0Soj]`S`[o8@]k00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`07o`0000Kooooo0ol0001<ooooo`03o`000?oooooooooo00Oooooo1Ol00002
oh]BR003o`000?n;DXSoRe:800Co00001_ooool00ol0003oooooooooo`0eooooo`00=oooool01Ol0
003ooooooooooooooooo000000GoRe:81_l00005oh]BR005o`000?n;DXSoRe:8oh]BR?l000000_n;
DXP5o`0000Gooooo2Ol0001Aooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oa[h?olJn300ColJn300?o0000oh]BR?n;DXP01On;DXP4o`0000goRe:8
1ol00003ooooo`Oo0000A?ooool2o`0000Ko`[791_o9a=D00ol0003oRe:8om3Jh003om3Jh004om[I
e_oRlMWoh_7IokOi`5Cooooo0_l0000;ooooo`03o`000?n[L8ooZg2?00?oZg2?00?o0000oj]`Son[
L8l06_n[L8l00ol0003oooooo`000004ooooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`03
o`000?n[L8ooZg2?02?oZg2?2OlQ2g/00ol0003oooooooooo`1Dooooo`;o00001?ooool9o`000003
ooooool0003ooooo04gooooo00?o0000ooooooooool01?ooool3o`0000OoRe:800?o0000oh]BR?l0
00002Oooool00ol0003oooooooooo`0eooooo`00>?ooool01?l0003oooooooooool00002oh]BR0?o
00001On;DXP2o`0000GoRe:800?o0000oh]BR?l000001Ol000001?oooooo0000ooooooooool:o`00
05Cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo04_ooooo00?o0000
oo6_Pooa[h<00ooa[h<00ol0003oRe:8oh]BR002oh]BR0?o00003On;DXP7o`0000?ooooo2Ol00017
ooooo`;o00001?o2/LT6olW4e@03o`000?o@f^3od=[P00?od=[P0ooDmND00ongnL3oooooooooo`1E
ooooo`03o`000?oooooooooo00Sooooo00?o0000oj]`Son[L8l00on[L8l00ol0003oZg2?oj]`S`0J
oj]`S`03o`000?oooooo000000Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09
ooooo`03o`000?n[L8ooZg2?02?oZg2?2?lQ2g/00ol0003oooooooooo`1Gooooo`;o00000_ooool5
o`0000?ooooo0_l0001?ooooo`03o`000?oooooooooo00Co000000?oooooo`000?n;DXP02?n;DXP2
o`0000Oooooo0ol0000gooooo`00>?ooool00ol0003oooooooooo`03o`0000[oRe:800Co0000oh]B
R?n;DXSoRe:81ol00002ooooo`Wo0000F_ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo04gooooo00?o0000oo6_Pooa[h<00_oa[h<5o`0000coRe:82?l00003ooooo`Wo0000Booo
ool00ol0003o`[79ol:ab@06olW4e@;o00001Oo@f^03omCei@03okOi`?oooooooooo05Oooooo00?o
0000ooooooooool01oooool00ol0003oZg2?oj]`S`02oj]`S`03o`000?n[L8ooZg2?01_oZg2?00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00?o0000oj]`Son[L8l09?n[L8l6ob4;N`03o`000?oooooooooo05[ooooo0_l000001?oooooo0000
ooooooooool4o`000003ooooool0003ooooo04oooooo0_l00004ooooo`03o`000?n;DXSoRe:800Oo
Re:80ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0eooooo`00>Oooool2o`000003oooo
ool0003oRe:800WoRe:82Ol00002ooooo`So0000Goooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo04gooooo00?o0000oo6_Pooa[h<00ol0000<oh]BR0So00000oooool9o`00053ooooo
00?o0000olW4eOo9a=D01?o9a=D2o`0000God=[P0ooDmND00ongnL3oooooooooo`1Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000oj]`Son[L8l00_n[L8l00ol0003oZg2?oj]`S`0Loj]`S`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03
o`000?n[L8ooZg2?02CoZg2?1OlQ2g/00ol0003oooooooooo`1Mooooo`03o`000?oooooo000000Ko
0000D_ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800CoRe:80ol000000ooooooo
0000o`000002o`0000Kooooo00?o0000ooooooooool0=_ooool003_ooooo0_l00006oh]BR0Oo0000
00Coooooo`000?oooooooooo1ol0001Uooooo`;o00002_ooool00ol0003oooooooooo`1>ooooo`;o
00000_oa[h<00ol0003oRe:8oh]BR006oh]BR0So00000oooool9o`0005Cooooo0_l00004olW4e@;o
00001Oo@f^03omCei@03okOi`?oooooooooo05_ooooo00?o0000ooooooooool01Oooool01Ol0003o
Zg2?oj]`Son[L8oo000001ooZg2?00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo037ooooo0_l00007ooooo`03o`000?n[L8ooZg2?02CoZg2?1?lQ2g/00ol0003oooooooooo`1O
ooooo`Co0000Eoooool01?l0003oooooooooool00003oh]BR0Co00000_ooool2o`0000?ooooo00Co
0000oooooooooooooooo0ol0000iooooo`00??ooool2o`000003oh]BR?l0003o000000;o00001?oo
ool00ol0003oooooooooo`07o`0006[ooooo0_l00008ooooo`03o`000?oooooooooo057ooooo00?o
0000oo6_Pol000001On;DXP3o`0000;olJn30_l00003ooooo`Wo0000FOooool2o`0000;obLCE0_l0
0005om3Jh0?oe?GU00?o]oW0ooooooooool0GOooool00ol0003oooooooooo`04ooooo`05o`000?n[
L8ooZg2?oj]`Sol000007on[L8l00ol0003oooooooooo`02ooooo`03o`000?oooooo000003Gooooo
00?o0000ooooooooool01?ooool00ol0003oZg2?oj]`S`0Toj]`S`Co8@]k00?o0000ooooooooool0
^oooool00ol0003oooooo`000003o`0000Kooooo00Co0000oooooooooooooooo1_l0000kooooo`00
?Oooool2o`0000Oooooo1ol0001`ooooo`;o00001Oooool00ol0003oooooooooo`1Cooooo`;o0000
00?oRe:8o`000?l000000_l00005oo6_P`Wo0000Goooool4o`0000God=[P0ooDmND00ongnL3ooooo
ooooo`1Oooooo`;o00001?ooool01?l0003oZg2?oj]`Sol0000Poj]`S`03o`000?oooooooooo00?o
oooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000oj]`Son[L8l09?n[L8l3ob4;N`03
o`000?oooooooooo0;gooooo0_l00008ooooo`So0000?_ooool003oooooo00?o0000ooooooooool0
1ol0001fooooo`?o000000?oooooo`000?ooool0E_ooool2o`0000OolJn31ol0001Tooooo`Co0000
0oo@f^03omCei@03o`000?oooooooooo06;ooooo00Oo0000ooooooooooooooooo`000?n[L8oo0000
027oZg2?00?o0000ooooooooool00_ooool3o`0003Oooooo0_l00003ooooo`03o`000?n[L8ooZg2?
02CoZg2?0_lQ2g/00ol0003oooooooooo`30ooooo`;o00000_ooool7o`0004?ooooo0010ooooo`Go
0000OOooool00ol0003oooooooooo`1Hooooo`03o`000?oa[h?olJn300Oo0000J_ooool3o`000003
om3Jh?oDmNGoe?GU00?o0000IOooool01_l0003oooooooooool0003oZg2?o`00027oZg2?00?o0000
ooooool000000_l0000looooo`04o`000?ooooooooooo`0002KoZg2?0_l00035ooooo`Go0000Aooo
ool00?oooooo7oooool5o`00073ooooo1Ol0001Xooooo`04o`000?oooooo0000o`0001WoZg2?2ol0
0010ooooo`03o`000?oooooo000001coZg2?2ol0003ooooooa?ooooo003ooooooooooooo0oooool3
o`0000OoZg2?4_l0001<ooooo`;o00002On[L8lCo`000?oooooo7_ooool00?ooooooooooool4oooo
o`Wo0000Goooool:o`000?oooooo<Oooool00?ooooooooooooooooooojOooooo003ooooooooooooo
oooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooo
oooooooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo
003ooooooooooooooooooonWooooo`00ooooooooooooooooooooYoooool0057ooooo0ol0003ooooo
ooooooooV_ooool2o`000;Kooooo001Booooo`03o`000?oooooooooo0?oooooooooooonKooooo`03
o`000?oooooooooo0;?ooooo000booooo`Ko000000?oooooo`000?l000000_ooool00ol0003ooooo
o`000004o`0000?ooooo0ol00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`03o`000003
ooooool0003o000000?ooooo00?o0000ooooooooool0>?ooool9o`000003ooooool0003ooooo00;o
000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000?o00001?ooool3o`000005
ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000007o`000003ooooool0003o0000
00;ooooo0_l00016ooooo`?o000000?oooooo`000?ooool01_l000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00013ooooo`?o00001?ooool3o`000004ooooool0
003o0000ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000Co
000000Coooooo`000?l0003ooooo0ol000000ooooooo0000ooooo`06o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0003Oooooo0ol00004ooooo`;o00000_oo
ool2o`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`000003ooooool0003ooooo00Go0000
1?ooool8o`0000;ooooo00Co0000ooooool0003ooooo0_l00010ooooo`?o00001?ooool2o`0000;o
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000005o`0000Cooooo2?l00002oooo
o`04o`000?oooooo0000ooooo`;o00007Oooool3o`0000?ooooo0ol000001ooooooo0000o`000?l0
003oooooo`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`?o00000oooool3o`0000;o
oooo00Go0000ooooool0003o0000ooooo`02o`0000;ooooo0ol00002ooooo`04o`000?oooooooooo
ooooo`;o00000oooool3o`0000Cooooo00?o0000ooooooooool01_l000000ooooooo0000ooooo`02
o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002
ooooo`co000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`0000kooooo0ol00003
ooooo`?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000Coooooo`000?l0003o
00000oooool3o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l00002oooo
o`?o00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_ooool00ol0003oooooo`000004o`0002Oooooo000cooooo`04o`000?oooooooooo
ooooo`;o00001?ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00004
ooooo`03o`000?oooooooooo03[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo
00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000015ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooooooool00_l00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000003Wooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo
0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001?ooool01ol0003oooooo`000?oooooo0000ooooool00000@_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01Ol0
003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0004ooooo`07o`000?oooooo0000ooooool0003oooooo`00000Oooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo0_l000002Ooooooo0000oooooooooooo0000ooooool0003oooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`00
0?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000oooo
ool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000oooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`000009ooooool0003oooooooooool0
003oooooo`000?oooooo000000Cooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool09?ooool003?ooooo00?o0000ooooooooool00_ooool4
o`000004ooooool0003oooooo`0000;ooooo0_l00004ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`Co000000?oooooo`00
0?ooool0>oooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooo`000?oooooo0000oooo
o`04o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00ol00002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000002ooooo`;o00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Co000000?oooooo`000?ooool0Aoooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooool00000AOooool3o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
o`000004ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`00000iooooo`?o00000_ooool5
o`0000Cooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00Go0000ooooool0003ooooo
o`000012ooooo`?o00000_ooool4o`000004ooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool00_l00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool01Ol0
003oooooo`000?oooooo000001oooooo0ol00003ooooo`03o`000?oooooooooo00;o00000_ooool0
1Ol0003oooooo`000?oooooo000000?ooooo0_l00006ooooo`0;o`000?ooooooooooooooool0003o
ooooo`000?oooooo0000ooooool000001?ooool2o`0000;ooooo00Co0000ooooool0003ooooo1Ol0
0007ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004oooo
o`;o00000_ooool01?l0003oooooooooool00004ooooo`Co000000Coooooo`000?oooooo00000_oo
ool2o`0000oooooo0ol00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003oooooo`00
0?oooooo000000?ooooo0_l00006ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo
0000ooooool000001?ooool2o`0000;ooooo00Co0000ooooool0003ooooo1?l000000ooooooo0000
ooooo`03ooooo`Co000000Coooooo`000?oooooo00000_ooool2o`0002Oooooo000cooooo`03o`00
0?oooooooooo00;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooool00000??ooool00ol0003oooooooooo`03oooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooooooooooooooo0000ooooool00000
0_ooool00ol0003oooooo`000018ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000015
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool00000>Oooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000Cooooo00Go0000ooooool0003oooooo`000012ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00004ooooo`05o`000?oooooo0000ooooool000007oooool01?l0003oooooooooool00002
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo
0_l00006ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000Oo
oooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000
ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0:o`000?ooooooooooo`00
0?oooooo0000ooooool0003oooooo`00017ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`;o00001_ooool0
2ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooool000001?oo
ool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool0000Yooooo`00<oooool00ol0
003oooooooooo`03ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo00?o0000
ooooooooool01Ol000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooooooool00_l00000
1?oooooo0000o`000?l0000kooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`000005ooooool0003oooooooooool0
00000_ooool3o`0000;ooooo00Co0000ooooool0003o00000_ooool5o`000003ooooool0003o0000
00;o000000Coooooo`000?l0003ooooo0ol00017ooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`Ko000000Goooooo`000?l0003o0000ooooo`03o`0004Cooooo00Go0000oooooooooooo
0000ooooo`02o`0000;ooooo1Ol00003ooooo`?o00000_ooool3o`0000;ooooo00Co0000ooooool0
003o00000_ooool3o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool6
o`000005ooooool0003o0000o`000?ooool00ol0000hooooo`04o`000?ooooooooooo`0000;ooooo
0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00003ooooo`05o`00
0?ooooooooooo`000?ooool01Ol00002ooooo`So0000@oooool01?l0003oooooooooool00002oooo
o`;o000000Coooooo`000?l0003o00000_ooool5o`0000?ooooo00Go0000oooooooooooo0000oooo
o`05o`0000;ooooo2?l0000Pooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o
00000_ooool3o`0000?ooooo0ol000000ooooooo0000ooooo`06ooooo`?o000000Coooooo`000?l0
003o00000oooool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
oooo00Gooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o
00000oooool3o`000003ooooool0003o000000?o00000_ooool5o`0000?ooooo00Co0000oooooooo
oooo00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0000>ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000ooooool0003o00000_ooool3o`0000?ooooo0ol000000ooooooo0000
ooooo`06ooooo`?o000000Coooooo`000?l0003o00000oooool5o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000
o`0000?ooooo0ol0000Vooooo`00<oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo05_ooooo0_l00003ooooo`;o0000E_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0001:ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0001Coooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
000`ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02o`0001gooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02o`0001gooooo00?o0000oooo
ooooool0=Oooool003;ooooo0ol0000@ooooo`Oo00000oooool00ol0003oooooooooo`04ooooo`;o
0000@_ooool3o`0000Cooooo00?o0000ooooooooool03oooool4o`0000Oooooo0_l00009ooooo`03
o`000?oooooooooo053ooooo0_l00005ooooo`;o000000?oooooo`000?ooool0DOooool4o`0000go
oooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`000003
ooooool0003ooooo04Gooooo1?l0000:ooooo`;o00003?ooool4o`0000Kooooo00?o0000oooooooo
ool0B_ooool4o`0001;ooooo1?l00006ooooo`03o`000?oooooooooo02Oooooo1?l00002ooooo`;o
00004Oooool2o`000003ooooool0003ooooo01gooooo0_l000000ooooooo0000ooooo`05ooooo`;o
00000_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`;o
000000Coooooo`000?l0003o00007Oooool4o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`00
0?ooool06oooool3o`0003Kooooo003ooooooooooooooooooonWooooo`00oooooooooooooooooooo
Yoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooooooooooo
ooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooo
ooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWoooo
o`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooo
oonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooo
oooooooooonWooooo`00ooooooooooooooooooooYoooool00?oooooooooooolVooooo`03o`000?oo
oooooooo0?ooooooO_ooool00?ooooooCOooool2o`000=Kooooo00?o0000ooooooooool0oooooomn
ooooo`00oooooom:ooooo`?o000000?oooooo`000?ooool0e?ooool3o`000?ooooooOoooool00?oo
ooooAoooool3o`0000Cooooo0_l0001^ooooo`;o0000Hoooool01Ol0003oooooo`000?oooooo0000
0?ooooooO_ooool00?ooooooA?ooool3o`0000Oooooo0_l0001[ooooo`?o000000?oooooo`000?oo
ool0HOooool01_l0003oooooooooool0003oooooo`000?ooooooO_ooool00;gooooo0ol00020oooo
o`?o00002_ooool00ol0003oooooo`00001Wooooo`?o00000oooool00ol0003oooooo`00001Poooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooog_ooooo002koooo
o`?o000000Coooooo`000?l0003o0000Noooool3o`0000gooooo00?o0000ooooool00000I?ooool3
o`0000Gooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00002iooooo`Ko0000L?ooool3o`0004Wooooo002hooooo`Oo00000ooo
ool00ol0003oooooooooo`1eooooo`?o00004?ooool01?l0003oooooooooool0001Pooooo`?o0000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo00000;Oooooo1_l00002ooooo`03o`000?oooooooooo06[o
oooo2?l00017ooooo`00]_ooool7o`0000Gooooo0_l0001cooooo`?o00004oooool01?l0003ooooo
ooooool0001Mooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000;Cooooo1ol000001Ooo
oooo0000o`000?oooooo000006Sooooo0ol000001?oooooo0000o`000?l00004ooooo`03o`000?oo
oooooooo04Cooooo002dooooo`Ko000000?oooooo`000?ooool00_ooool3o`0000;ooooo00?o0000
ooooooooool0KOooool3o`0001Kooooo00Co0000ooooool0003o0000F_ooool3o`0000cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00002cooooo`Co00001?ooool01_l0003oooooo`000?l0003oooooo`00
06Gooooo1_l000000ooooooo0000ooooo`03ooooo`?o0000AOooool00;7ooooo1_l00003ooooo`Go
00001_ooool00ol0003oooooooooo`1Yooooo`?o00006Oooool01?l0003oooooo`000?l0001Goooo
o`?o00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;3ooooo0_l000000ooo
oooo0000ooooo`04ooooo`06o`000?ooooooooooo`000?oooooo0000Hoooool4o`0000?ooooo00?o
0000ooooooooool00ol00003ooooo`03o`000?oooooooooo04;ooooo002_ooooo`Go00000oooool5
o`0000Wooooo0_l0001Wooooo`?o00007?ooool01?l0003oooooo`000?l0001Dooooo`?o00004?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:kooooo00Co0000ooooool0003o0000
1oooool01_l0003oooooooooool0003oooooo`00063ooooo1_l000000ooooooo0000o`000003o`00
00Oooooo00?o0000ooooooooool0@Oooool00:kooooo1?l00002ooooo`Go00000_ooool00ol0003o
ooooooooo`04ooooo`?o000000?oRe:8o`000?ooool0Hoooool3o`0001oooooo0_l00002ooooo`03
o`000?oooooooooo04kooooo0ol0000Booooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0@oooool2o`0006Sooooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?oooooo000000?o
0000GOooool2o`0000;ooooo00?o0000ooooool000000_l000001Ooooooo0000oooooooooooo0000
00Kooooo0ol00012ooooo`00[_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000CoRe:80_l0001Pooooo`?o00008oooool01?l0003oooooooooool0001>
ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000
okjAZ?l00000Ioooool01Ol0003oooooo`000?oooooo000000Wooooo00Go0000oh]BR?l0003oRe:8
o`00001Mooooo`03o`000?oooooooooo00?o00000oooool2o`0000?ooooo00?o0000ooooooooool0
0ol00002oh]BR003o`000?oooooooooo043ooooo002^ooooo`03o`000?oooooo000000;o00001ooo
ool00ol0003oooooo`000002o`0000OoRe:80_l0001Mooooo`?o00009Oooool2o`0000;ooooo00?o
0000ooooooooool0BOooool3o`0001Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`10ooooo`04o`000?nnTJSo_Y6XokjAZ0;o0000IOooool01?l0003oooooo`000?l0000:ooooo`04
o`000?n;DXSo0000oh]BR0;o0000Foooool4o`0000Kooooo0_l00003ooooo`?o00001On;DXP2o`00
047ooooo002_ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000[oRe:80ol0001Ioooo
o`?o0000:?ooool2o`0000;ooooo00?o0000ooooooooool0A_ooool3o`0001Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?nnTJSo_Y6X00Co_Y6X00?o0000oooo
ooooool0H_ooool2o`000003ooooool0003ooooo00Wooooo00Oo0000oh]BR?l0003oRe:8o`000?oo
oooo000005Wooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00Oo0000ooooool0003ooooo
o`000?n;DXSo000000KoRe:800?o0000ooooool00000@?ooool00:oooooo00Go0000oooooooooooo
ooooo`000002ooooo`?o000000?oYl3[o`000?l000002_n;DXP00ol0003oooooo`00001Gooooo`Oo
00009_ooool2o`0000;ooooo00?o0000ooooooooool0@oooool3o`0001[ooooo00?o0000oooooooo
ool03oooool2o`0004oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`;o
0000@Oooool00ol0003o_Y6XokjAZ005okjAZ0;o0000HOooool00ol0003oooooo`000002o`0000[o
oooo00Ko0000oh]BR?l0003oRe:8o`000?ooool2o`0005Sooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o000000?oooooo`000?n;DXP00_n;DXP00ol0003oRe:8oh]BR004oh]BR0?o0000?ooo
ool003?ooooo1?l00008ooooo`_oC`000onT9@h00omb003oooooooooo`1Pooooo`03o`000?oooooo
oooo00?o00001?nW`>/00ol0003oYl3[o`000009oh]BR004o`000?ooooooooooo`0005?ooooo0ol0
00000ooooooo0000ooooo`04ooooo`_o00006_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo043ooooo0ol0000Looooo`03o`000?oooooooooo00gooooo0ol000000ooooooo0000oooo
o`1=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?ooool00ol0003oooooo`00
000fooooo`Oo00000oooool00ol0003o_Y6XokjAZ008okjAZ003o`000?oooooooooo05kooooo0ol0
00000onW`>_o0000o`000009ooooo`04o`000?n;DXSo0000oh]BR0;o000000?oooooo`000?ooool0
Eoooool01Ol0003ooooooooooooooooo000000;ooooo0ol000000onW`>_o0000ojO0j`02o`0000Co
Re:800?o0000oh]BR?n;DXP00on;DXP00ol0003oooooo`00000oooooo`00<_ooool2o`0000ooC`00
1_n37c`3ok=AD0CoY2D>00?oLP00ooooooooool0G_ooool2o`000003oh]BR?l0003oYl3[00CoYl3[
00Co0000ojO0jonW`>_o00002?n;DXP01Ol0003ooooooooooooooooo000004oooooo0ol00003oooo
o`;o00004?ooool:o`00013ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0moooo
o`?o00007_ooool00ol0003oooooooooo`0;ooooo`?o00000oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0003Cooooo0_l00007oo:_PP03o`000?oooooo000000co_Y6X0_l0001Nooooo`07o`000?nW
`>_o0000ojO0jol0003oYl3[o`000008ooooo`04o`000?n;DXSo0000oh]BR0;o00000_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00;ooooo0ol00004ojO0j`04o`000?nW`>_oYl3[
o`0000CoRe:800?o0000oh]BR?n;DXP00on;DXP01?l0003oooooooooool0000nooooo`00<Oooool2
o`0000CoC`004_n37c`7ok=AD0?oY2D>00?oLP00ooooooooool0Foooool01?l0003oRe:8o`000?l0
0006ojO0j`04o`000?nW`>_oYl3[o`0000OoRe:800Go0000ooooooooooooooooo`00001<ooooo`?o
00001Oooool00ol0003oooooo`00000Jooooo`_o00001Oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo03Wooooo0ol0000Pooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool0<_ooool00ol0003olZn2oo:_PP07oo:_PP;o
00003_nnTJP00ol0003oooooooooo`1Kooooo`Go00000_nW`>/00ol0003oooooooooo`05ooooo`09
o`000?n;DXSo0000oh]BR?l0003oooooo`000?oooooo000005Kooooo00?o0000ooooooooool01?l0
0005ojO0j`05o`000?nW`>_oYl3[ojO0jol000001?n;DXP00ol0003oRe:8oh]BR002oh]BR004o`00
0?ooooooooooo`0003kooooo000aooooo`03o`000?n37ccoPall013oPall1?nGCG43okU[MPSo/e5@
00?oY2D>omAU=?l0Lm40Foooool3o`0000OoYl3[00Go0000ojO0jonW`>_oYl3[o`000006oh]BR004
o`000?ooooooooooooooo`;o0000B?ooool3o`0000Sooooo00?o0000ooooool000009Oooool5o`00
00;ooooo00Go0000ooooooooooooooooo`00000hooooo`?o00008oooool00ol0003oooooooooo`06
ooooo`?o00001oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00Co0000
oo:_P_ob[h;olZn21_l000000oob[h;o0000okjAZ00?okjAZ0;o0000Foooool01?l0003oooooo`00
0?nW`>/2o`0000;oYl3[00?o0000ooooooooool01?ooool01Ol0003oRe:8o`000?n;DXSo000000;o
oooo0_l0001Fooooo`?o00000_nW`>/01?l0003oYl3[o`000?l00004ojO0j`05o`000?nW`>_oYl3[
ojO0jol000000on;DXP00ol0003oRe:8oh]BR002oh]BR004o`000?ooooooooooo`0003kooooo000`
ooooo`03o`000?n37ccoPall00SoPall3OnGCG47okU[MPGo/e5@0_oFMeX00onY8P3o0000o`00001H
ooooo`03o`000?nW`>_o000000KoYl3[0_l00003ojO0j`03o`000?n;DXSoRe:800CoRe:81?l00000
0ooooooo0000ooooo`14ooooo`?o00002_ooool01?l0003oooooooooool0000Uooooo`?o000000Go
ooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo03?ooooo0ol0000Uooooo`03o`00
0?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
<?ooool00ol0003olZn2oo:_PP02o`0000Kooooo00?o0000okjAZ?nnTJP04OnnTJP2o`0005Wooooo
00Ko0000oooooooooooo0000ojO0jol00003ojO0j`03o`000?oooooooooo00?ooooo00Co0000oh]B
R?l0003oRe:80_l000001?oooooo0000ooooool0001Eooooo`03o`000?nW`>_oYl3[00;oYl3[00Co
0000ojO0jonW`>_oYl3[0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Go0000oh]BR?n;DXSo
Re:8o`000003oh]BR003o`000?oooooooooo00;o0000?Oooool002oooooo0_l00002oh<O?13oUdea
2_l00005okU[MP;o/e5@0ooFMeX00onY8P3o0000o`00001Fooooo`04o`000?nW`>_oYl3[o`0000?o
Yl3[0ol000000onW`>_o0000ojO0j`03ojO0j`03o`000?n;DXSoRe:800?oRe:800?o0000oooooooo
ool00oooool00ol0003oooooooooo`0oooooo`?o00003?ooool01Ol0003ooooooooooooooooo0000
02;ooooo0ol00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<Oooool2
o`0002Oooooo00?o0000ooooooooool00_ooool3o`0000cooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo02oooooo00Co0000oo:_P_ob[h;o00001oooool00ol0003o_Y6X
okjAZ00CokjAZ003o`000?oooooooooo05Kooooo00?o0000ooooooooool01?l00003ojO0j`03o`00
0?oooooooooo00;ooooo00Co0000oh]BR?l0003oRe:80_l000001?oooooo0000o`000?l0001Eoooo
o`;o00000onW`>/00ol0003oYl3[ojO0j`03ojO0j`?o00001OnW`>/01?l0003oRe:8oh]BR?l00004
oh]BR0;o000000?oooooo`000?ooool0??ooool002oooooo0_l0000;oiM=LAOo00000_oFQG@3omIg
FP03ojTR0?l0003o000005Gooooo00Co0000ojO0jol0003oYl3[0ol00004ojO0j`03o`000?nW`>_o
Yl3[00?oYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03cooooo0ol0000?ooooo`05o`000?ooooooooooooooool000007oooool3o`0000Oooooo1?l0
0003ooooo`03o`000?oooooooooo02kooooo0ol0000Xooooo`03o`000?oooooooooo00?o00003_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003olZn2
o`000007ooooo`03o`000?nnTJSo_Y6X01Go_Y6X0_l0001Fooooo`03o`000?oooooooooo00?o0000
00GoYl3[o`000?nW`>_oYl3[o`000004ooooo`0;o`000?n;DXSo0000oh]BR?l0003oooooo`000?oo
oooo0000ooooool00000E?ooool2o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol000000onW`>_o
0000o`000005ojO0j`03o`000?n;DXSo000000CoRe:800Go0000ooooooooooooooooo`00000loooo
o`00;oooool2o`0000GoUdea1_l00008oiM=L@CoXFR@1onlOHh3okU[MPGo00000_oFMeX00onY8P3o
ooooo`00001Cooooo`03o`000?nW`>_oYl3[00;o00001onW`>/00ol0003oYl3[ojO0j`04ojO0j`05
o`000?n;DXSoRe:8oh]BR?l000001Oooool00ol0003oooooooooo`0iooooo`?o00004Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo0ol00008ooooo`?o00000_ooool01Ol0
003ooooooooooooooooo000002gooooo0ol0000Zooooo`Co00004?ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`00033ooooo00Co0000oo:_P_ob[h;o00001_ooool00ol0003o_Y6X
okjAZ00HokjAZ003o`000?oooooooooo05?ooooo1?l000001Ooooooo0000o`000?nW`>_o000000;o
Yl3[00_o0000ooooooooooooooooo`000?n;DXSo0000oh]BR?l0003oooooo`000002ooooo`;o0000
EOooool2o`0000;oYl3[1?l00004ojO0j`03o`000?nW`>_o000000GoYl3[00?o0000oh]BR?l00000
0on;DXP01Ol0003ooooooooooooooooo000003cooooo000^ooooo`;o000000?oUdeao`000?l00000
1?l00004oiM=L@goXFR@2onlOHh3omJ@Q`Oo0000DOooool01Ol0003oYl3[ojO0jonW`>_o000000Wo
Yl3[00?o0000ojO0jonW`>/01?nW`>/01?l0003oRe:8oh]BR?l00006ooooo`03o`000?oooooooooo
03Gooooo0ol0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool3o`00
00Sooooo0ol00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0X
ooooo`?o0000:oooool3o`0001?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000`
ooooo`04o`000?ob[h;olZn2o`0000Kooooo00?o0000okjAZ?nnTJP06OnnTJP2o`0005?ooooo00[o
0000oooooooooooo0000ooooool0003oooooo`000?nW`>_o00000_nW`>/02?l0003oooooooooool0
003oRe:8o`000?n;DXSo00000_ooool01Ol0003oooooo`000?oooooo000005Cooooo0_l000000onW
`>_o0000o`000007ojO0j`03o`000?nW`>_oYl3[00;o00001?nW`>/2o`0000?oRe:800?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0iooooo`00;_ooool4o`0001KoXFR@2onlOHh5omJ@Q`?o
000000?o02J`o`000?ooool0Coooool01Ol0003oYl3[ojO0jonW`>_o000000[oYl3[00?o0000ojO0
jonW`>/01?nW`>/01?l0003oRe:8oh]BR?l00004ooooo`?o0000=?ooool3o`0001Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Dooooo`?o00002?ooool3o`0000Gooooo0_l00003
ooooo`04o`000?ooooooooooo`0002Kooooo0ol0000[ooooo`?o000000?oooooo`000?ooool04_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000033ooooo00Co0000oo:_P_ob[h;o0000
1Oooool00ol0003o_Y6XokjAZ00LokjAZ003o`000?oooooooooo053ooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`03o`000?nW`>_o000000;oYl3[00Oo0000ooooool0003oRe:8o`000?n;
DXSo000000;ooooo00Go0000ooooool0003oooooo`00001Dooooo`?o000000?oYl3[o`000?nW`>/0
1_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Go0000oh]BR?n;DXSo
Re:8o`000004ooooo`03o`000?oooooooooo03Wooooo000^ooooo`;o00006?nQJ906okamSPGo_hbO
1OoGViD2omJ@Q`04o`000?l08J[o0000o`0004oooooo00Go0000ojO0jonW`>_oYl3[o`00000:ojO0
j`03o`000?nW`>_oYl3[00GoYl3[00?o0000oh]BR?n;DXP01?l00002ooooo`03o`000?oooooooooo
02oooooo0ol0000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool3o`00
00Sooooo0ol00008ooooo`;o00001?ooool00ol0003oooooo`00000Sooooo`?o0000:oooool3o`00
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`Wo0000:oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool2o`00
033ooooo00?o0000oo:_P_l000001_ooool00ol0003o_Y6XokjAZ00MokjAZ0;o0000DOooool00ol0
003oooooo`000002ooooo`06o`000?ooooooooooo`000?nW`>_o00000_nW`>/2o`000004oh]BR?l0
003oRe:8o`0000;ooooo00?o0000ooooooooool00ol0001Cooooo`05o`000?oooooo0000ojO0jol0
00002?nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000oh]BR?n;
DXSo00000oooool3o`0003[ooooo000^ooooo`;o00005OnQJ903ojMlY0co_hbO1_oGViD2o`000003
o`0QZ_l0003ooooo04kooooo00Go0000ojO0jonW`>_oYl3[o`000008ojO0j`?o00002?nW`>/00ol0
003oRe:8o`000006ooooo`03o`000?oooooooooo02_ooooo0ol0000Jooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool3o`0000Oooooo1?l0000;ooooo`;o00001Oooool2o`00
023ooooo0ol0000[ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooool000001_oooolAo`0001Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;_ooool00ol0
003olZn2o`000005ooooo`03o`000?nnTJSo_Y6X023o_Y6X00?o0000ooooooooool0C_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ojO0jol000000_nW`>/01Ol0003oRe:8o`00
0?n;DXSo000000?ooooo0ol000000ooooooo0000ooooo`1Booooo`03o`000?oooooooooo00;o0000
2?nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?n;DXP0
0ol00002ooooo`03o`000?oooooooooo03Sooooo000^ooooo`;o00004?nQJ908ojMlY0co_hbO1_oG
ViD2o`000003o`0AV_l0003ooooo04kooooo00Co0000ojO0jonW`>_o00001_nW`>/3o`0000;oYl3[
00?o0000ojO0jonW`>/01onW`>/2o`0000Kooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool3o`0000Oooooo
0ol0000?ooooo`;o00001_ooool00ol0003oooooooooo`0Kooooo`?o0000:oooool3o`0000Gooooo
0ol0000Cooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00005_ooool@o`0000So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0;_ooool00ol0003olZn2o`000004ooooo`03o`000?nnTJSo_Y6X02;o
_Y6X00?o0000ooooooooool0COooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o0000
ojO0jol000000_nW`>/2o`000003oh]BR?l0003ooooo00;ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`1@ooooo`04o`000?ooooooooooooooo`;o00001onW`>/00ol0003oYl3[ojO0
j`04ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000oh]BR?l000001?ooool00ol0003ooooooooo
o`0hooooo`00;_ooool00ol0003oXFR@oj5XT00:oj5XT0koYgbT2?noS9l3ol:I[@KofJFP0_l00000
0ol04I[o0000o`00001>ooooo`04o`000?nW`>_oYl3[o`0000?oYl3[0ol00005ojO0j`03o`000?nW
`>_oYl3[00SoYl3[00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`;o00006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0ol00007ooooo`?o00004_oo
ool2o`0000Kooooo00?o0000ooooooooool06?ooool3o`0002_ooooo0ol00005ooooo`?o00000_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooooooo
o`00000Uooooo`So00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0;oooool00ol0003olZn2o`000004ooooo`03o`000?nnTJSo_Y6X02;o_Y6X
00?o0000ooooooooool0COooool00ol0003oooooooooo`03o`0000Gooooo00?o0000ojO0jol00000
0_nW`>/00ol0003oRe:8o`000004ooooo`05o`000?oooooo0000ooooool00000D_ooool00ol0003o
ooooooooo`02ooooo`03o`000?nW`>_oYl3[00?oYl3[0ol00007ojO0j`03o`000?nW`>_oYl3[00;o
Yl3[0_l00004ooooo`03o`000?oooooooooo03Sooooo000^ooooo`03o`000?nQJ93oXFR@00GoXFR@
4onWO:@3okn<W`Wo`YV]1?oIYJ02omb_Z004o`000?l04I[o0000o`0004kooooo00?o0000ojO0jonW
`>/01?l00009ojO0j`03o`000?nW`>_oYl3[00GoYl3[0_n;DXP00ol0003oooooooooo`04ooooo`;o
0000:oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool3o`0000Oooooo0ol0000Eooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`?o
0000:oooool3o`0000Gooooo0ol00006ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<?ooool00ol0003olZn2o`000003ooooo`03o`000?nnTJSo_Y6X02;o_Y6X00?o0000oooooooo
ool0Coooool3o`000003ooooool0003ooooo00Gooooo00?o0000ojO0jol000000_nW`>/2o`0000Co
oooo00Go0000ooooool0003oooooo`00001Cooooo`04o`000?ooooooooooooooo`Ko00000_nW`>/0
0ol0003oYl3[ojO0j`06ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`00;_ooool00ol0003oXFR@oj5XT00FojMlY0;o[8fd3?o2VJd00ooI
YJ3og:nXomb_Z002omb_Z003on:j[ol0003o000000;o0000C_ooool01?l0003oYl3[o`000?l0000<
ojO0j`03o`000?nW`>_oYl3[00;oYl3[1On;DXP2o`0000;ooooo0ol000000ooooooo0000ooooo`0Z
ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`?o00001_ooool4o`0001Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Eooooo`;o0000:_ooool3o`0000Gooooo0ol0000:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool2o`0000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00?o
0000oo:_P_l000000_ooool00ol0003o_Y6XokjAZ00RokjAZ003o`000?oooooooooo053ooooo00Go
0000ooooool0003oooooo`000007ooooo`03o`000?nW`>_o000000;oYl3[00?o0000ooooooooool0
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
0ol00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[00Go0000ojO0jon;DXSoRe:8o`000005ooooo`03
o`000?oooooooooo03Oooooo000^ooooo`03o`000?nWO:CoYgbT01?oYgbT1On/SK@;ol:I[@03olNV
^OoL[jSog:nX00;og:nX0_oR^Zl01?oXakCo0000o`000?l0001>ooooo`03o`000?nW`>_o000000go
Yl3[00?o0000ojO0jon;DXP01on;DXP01?l0003oYl3[o`000?l00004ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooool000000_l00006ooooo`Co00007?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool3o`0000Gooooo0ol0000>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool00ol0003olZn2o`000002oooo
o`03o`000?nnTJSo_Y6X02;o_Y6X00?o0000ooooooooool0D?ooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00Gooooo00Go0000ojO0jol0003oRe:8o`000005ooooo`03o`000?oooooo
000000;o0000D_ooool3o`000004ooooool0003oooooo`0000KoYl3[00?o0000ojO0jonW`>/01?nW
`>/2oh]BR004o`000?n;DXSoRe:8oh]BR0;o00000oooool2o`0003Wooooo000^ooooo`03o`000?nW
O:CoYgbT013oYgbT2On/SK@7ol:I[@GoajJi0_oL[jP3on:j[`04o`000?ohhZoo0000o`0004oooooo
00?o0000ojO0jonW`>/02onW`>/2oh]BR003o`000?n;DXSoRe:800KoRe:800Co0000ojO0jonW`>_o
00001?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`03
o`000?oooooooooo00Oooooo0ol00006ooooo`Co00007oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo0_l0000Qooooo`?o00001Oooool3o`0001;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0cooooo`05o`000?ob[h;o0000ooooool000009?nnTJP0
0ol0003oooooooooo`1Aooooo`06o`000?ooooooooooo`000?oooooo00001oooool01?l0003oRe:8
o`000?n;DXP2o`0000Cooooo0ol000000ooooooo0000ooooo`1Aooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oYl3[ojO0j`03ojO0j`04o`000?nW`>_oYl3[ojO0j`GoRe:800Ko0000
oh]BR?n;DXSoRe:8o`000?nW`>/3o`000003ooooool0003ooooo03Sooooo000^ooooo`03o`000?nW
O:CoYgbT00goYgbT3?n/SK@4ol:I[@SoajJi00Sog:nXon:j[ooR^Zooh[Z_onS7]?l0003on>:_o`00
053ooooo0_l00009ojO0j`CoRe:80_l00008oh]BR005o`000?nW`>_oYl3[ojO0jol000001?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ol0000?
ooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`03ooooo`?o00008oooool0
1Ol0003ooooooooooooooooo000001gooooo0_l0000Mooooo`?o00001Oooool3o`0001Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Cooooo00Co0000oo:_P_l0003o
00009OnnTJP00ol0003oooooooooo`1Booooo`05o`000?oooooo0000ooooool000001oooool01ol0
003oRe:8o`000?n;DXSo0000ojO0jol000000oooool01Ol0003oooooo`000?oooooo000005;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ojO0j`03o`000?n;DXSoRe:800Ko
Re:800Go0000oh]BR?n;DXSoRe:8o`000002ojO0j`05o`000?ooooooooooooooool00000>?ooool0
02oooooo00?o0000ojMlY?nWO:@02?nWO:@@ojb=]003ol:I[Oo7Y[WoajJi00SoajJi00Coc;G3on:j
[ooR^Zooh[Z_0_oXak@00ol0003on>:_o`00001@ooooo`03o`000?oooooo000000GoYl3[1?n;DXP3
o`000003oh]BR?l0003oRe:800OoRe:800?o0000ojO0jonW`>/00_nW`>/01Ol0003ooooooooooooo
oooo000002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Co00002_oo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooo`000002o`0002Kooooo00?o
0000ooooooooool00_l0000Nooooo`;o00006Oooool3o`0000Gooooo0ol0000Jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0=_ooool3o`0002Co_Y6X00?o0000ooooooooool0
Doooool01Ol0003oooooo`000?oooooo000000Oooooo00Co0000oh]BR?l0003oRe:80_l000002OnW
`>_o0000oooooooooooo0000ooooool0003oooooo`00001Booooo`03o`000?oooooooooo00;ooooo
00Ko0000ooooooooooooooooo`000?nW`>/3oh]BR003o`000?n;DXSoRe:800CoRe:800?o0000oh]B
R?n;DXP00_n;DXP01?l0003oYl3[ojO0jol00003ooooo`03o`000?oooooooooo03Kooooo000_oooo
o`03o`000?nWO:CoYgbT00GoYgbT4_n/SK@00onaW<?oajJiolNV^@07olNV^@Coc;G300Koh[Z_onS7
]?oXakCo0000ooSR[oojjI]@ooooo`06o`000?ooooooooooooooool0003oYl3[1?n;DXP3o`0000Go
Re:800?o0000oh]BR?n;DXP01On;DXP00ol0003oYl3[ojO0j`03ojO0j`Co0000:Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo1?l00006ooooo`03o`000?oooooooooo00?o
00001_ooool6o`0002Kooooo0_l000000ooooooo0000o`00000Oooooo`?o00005?ooool3o`0000Go
oooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0:ooooo`Wo00007?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo0_l0000TokjAZ003o`000?oooooooooo05Co
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`0=o`000?n;DXSo0000oh]B
R?l0003oYl3[o`000?nW`>_o0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo053o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?n;DXSoRe:8oh]BR0;o00001_n;DXP0
0ol0003oRe:8oh]BR002oh]BR005o`000?nW`>_oYl3[ojO0jol000000_ooool00ol0003ooooooooo
o`0fooooo`00;oooool00ol0003oYgbTojMlY002ojMlY1;o[8fd1OnaW<<7olNV^@Coc;G30_oCa/d2
onS7]003o`000?ohhZoo^:hR053ooooo00Go0000ooooooooooooooooo`000002oh]BR0?o00002?n;
DXP00ol0003oRe:8oh]BR005oh]BR003o`000?nW`>_oYl3[00CoYl3[00?o0000ooooool00000:Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0ol00002ooooo`Co00001_oo
ool3o`000003ooooool0003ooooo00?ooooo2Ol0000Mooooo`Co00008Oooool00ol0003oooooo`00
000@ooooo`?o00001Oooool3o`0002;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool?o`0000gooooo00?o
0000ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0hooooo`;o00009?nnTJP00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?o00001_oo
ool01ol0003oRe:8o`000?n;DXSo0000ojO0jol000000_nW`>/01ol0003oooooo`000?oooooo0000
ooooool00000D_ooool01Ol0003ooooooooooooooooo000000?ooooo1?l000000on;DXSo0000oh]B
R005oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000ojO0jonW`>/00_nW`>/4o`0003Oooooo000_
ooooo`03o`000?nWO:Co[8fd017o[8fd2?naW<<5olNV^@Goc;G31?oCa/d01?l0003ol=BeooSR[onh
[R9@ooooo`04o`000?ooooooooooooooo`?o00003?n;DXP00ol0003oRe:8oh]BR004oh]BR003o`00
0?nW`>_oYl3[00CoYl3[00?o0000ooooool00000:Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo0ol00005ooooo`Co00000oooool00ol0003oooooooooo`0<ooooo`Wo0000
5?ooool4o`0002;ooooo00Co0000ooooool0003o00002oooool3o`0000Gooooo0ol0000Vooooo`05
o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Gooooo3ol00003ooooo`06o`000?ooooooooooo`000?oooooo00003_ooool00ol0003ooooooooo
o`0iooooo`03o`000?ob[h;o000002;o_Y6X00?o0000ooooooooool0E_ooool3o`000003ooooool0
003ooooo00Gooooo00Co0000oh]BR?l0003oRe:80_l000001?nW`>_o0000ojO0jonW`>/2o`000004
ooooool0003o0000o`0005;ooooo00?o0000ooooooooool00_ooool4o`0000GoRe:800?o0000oh]B
R?n;DXP00on;DXP00ol0003oRe:8oh]BR002oh]BR003o`000?nW`>_oYl3[00;oYl3[00Co0000oooo
oooooooo0000=oooool002oooooo00?o0000ojb=]?n/SK@03_n/SK@;ok6L``?oajJi1_o<]L<4om?6
c@05o`000?oLfmKon>:_ooSR[ol002@0Coooool00ol0003oooooo`000003o`0000koRe:800?o0000
oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`05ojO0j`03o`000?oooooo000002Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooooooo`?o00001_oo
ool00ol0003oooooooooo`0Fooooo`Wo00002oooool3o`0002Cooooo00Co0000oooooooooooo0000
1oooool3o`0000Gooooo0ol0000Zooooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Oo00003_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?ob[h;o000000;o00008?nnTJP00ol0003oooooooooo`1Fooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00oooool02Ol0003oRe:8o`000?n;DXSo0000oooo
ool0003oYl3[o`000002ojO0j`?o000000?oooooo`000?ooool0D_ooool00ol0003oooooo`000002
o`0000;ooooo00?o0000oh]BR?n;DXP00on;DXP00ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSo
Re:800;oRe:800?o0000ojO0jonW`>/00onW`>/00ol0003oooooo`00000gooooo`00<?ooool00ol0
003o[8fdojb=]00:ojb=]0oo/Ic300?oajJiolbe`oo<]L<01?o<]L<4om?6c@;o000000?og=_Fon?c
eoojjI/0D?ooool2o`0000;ooooo00?o0000oh]BR?n;DXP03On;DXP00ol0003oRe:8oh]BR004oh]B
R003o`000?nW`>_oYl3[00KoYl3[0_l0000Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04?ooool4o`0000Sooooo00?o0000ooooooooool08?ooool9o`0000;ooooo0ol0000Uoooo
o`04o`000?ooooooooooo`0000?ooooo0ol00005ooooo`?o0000;?ooool3o`0002Cooooo2Ol00004
ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00007OnnTJP00ol0003ooooooooo
o`1Gooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003oRe:8o`000?n;DXSo0000
00;ooooo00?o0000ojO0jol000000_nW`>/2o`000003ooooool0003ooooo05;ooooo0_l00002oooo
o`04o`000?ooooooooooo`0000KoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8oh]BR002
oh]BR0;o00001?nW`>/00ol0003oooooo`00000gooooo`00<?ooool00ol0003o[8fdojb=]008ojb=
]13o/Ic300?o]Jg@olbe`oo<]L<01?o<]L<4om?6c@;o00000_oLfmH00ooSlmOoe_fiooooo`1?oooo
o`05o`000?ooooooooooooooool000003on;DXP2o`0000GoRe:800?o0000ojO0jonW`>/01_nW`>/2
o`0002Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`?o00002oooool0
0ol0003oooooooooo`0Yooooo`Co00009oooool00ol0003oooooooooo`03o`0000Gooooo0ol0000/
ooooo`?o0000:Oooool00ol0003oooooooooo`04oooooa7o00006?ooool00ol0003oooooo`000006
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?Oooool00ol0003olZn2o`000003
ooooo`03o`000?nnTJSo_Y6X01Wo_Y6X00?o0000ooooooooool0FOooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00Go0000oh]BR?l0003oRe:8o`000003ooooo`03o`000?nW
`>_o000000;oYl3[00?o0000ooooool00000Doooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000KoRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8oh]BR002oh]BR0;o00001OnW
`>/2o`0003Oooooo000`ooooo`03o`000?n/SKCo[8fd00Go[8fd4?naW<<5okF]d0Coc;G31?oCa/d2
o`0000;og=_F0_oSlmMAooooo`05o`000?ooooooooooooooool000003?n;DXP3o`000003oh]BR?l0
003oRe:800CoRe:800Ko0000ojO0jonW`>_oYl3[o`000?nW`>/3o`000003ooooool0003ooooo02Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`?o00000_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Sooooo0ol0000[ooooo`;o00000_ooool00ol0003o
ooooooooo`03o`0002cooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_oooolAo`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0?_ooool00ol0003olZn2o`000004ooooo`;o00006OnnTJP00ol0003oooooooooo`1Iooooo`06
o`000?ooooooooooo`000?oooooo00001?ooool01Ol0003oRe:8o`000?n;DXSo000000Cooooo00?o
0000ojO0jol000000_nW`>/00ol0003oooooo`00001Cooooo`07o`000?ooooooooooooooool0003o
ooooo`000006oh]BR003o`000?n;DXSoRe:800;oRe:800Oo0000oh]BR?n;DXSoRe:8o`000?nW`>_o
000000GoYl3[0_l0000gooooo`00<Oooool01?l0003o[8fdojb=]?n/SK@Aok6L``Oo]Jg@0oo<]L<4
om?6c@04o`000?oLfmKog=_FomcKeP;oho?GD_ooool01Ol0003ooooooooooooooooo000000WoRe:8
0ol00005oh]BR003o`000?n;DXSoRe:800;oRe:81_l00004ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo1?l0000`ooooo`03o`000?oooooooooo00;o0000
;?ooool3o`00037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`So0000
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo0_l00006ooooo`03o`00
0?nnTJSo_Y6X01Go_Y6X00?o0000ooooooooool0Foooool00ol0003oooooo`000002ooooo`09o`00
0?ooooooooooooooool0003oRe:8o`000?n;DXSo000000Gooooo00Go0000ojO0jol0003o0000ojO0
j`02o`0005?ooooo00?o0000ooooooooool00_ooool2o`0000GoRe:80ol00002oh]BR003o`000?n;
DXSoRe:800;oRe:800?o0000ojO0jol000001?nW`>/3o`0003Oooooo000aooooo`03o`000?naW<?o
/Ic3013o/Ic32_ne[M000oo<]L?odlK=om?6c@02om?6c@04o`000?oLfmKog=_FomcKeP;oho?G00?o
e_fiooooooooool0D?ooool01Ol0003ooooooooooooooooo000000KoRe:80ol00008oh]BR003o`00
0?n;DXSoRe:800;oRe:800Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`Co00002?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo0ol0000eooooo`;o00000_ooool00ol0003o
ooooooooo`0Vooooo`?o0000=Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047o
oooo0_l00007ooooo`;o00005?nnTJP00ol0003oooooooooo`1Looooo`03o`000?oooooo000000;o
oooo00Wo0000ooooooooooooooooo`000?n;DXSo0000oh]BR?l000001_ooool01?l0003oYl3[o`00
0?nW`>/2o`0005Cooooo00Co0000oooooooooooooooo0_l000000on;DXSo0000o`000002o`0000;o
Re:800Co0000oh]BR?n;DXSo00001?n;DXP01?l0003oYl3[o`000?nW`>/3o`0000;ooooo00?o0000
ooooooooool0=Oooool0037ooooo00?o0000ok6L`onaW<<03OnaW<<<okF]d0?o^/7O0_oCa/d01?l0
003og=_FomcKe_oLfmH2on?ce`03omKm^Ooooooooooo057ooooo00Go0000ooooooooooooooooo`00
0003oh]BR0?o00003?n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool4o`0003[o
oooo00Co0000oooooooooooo00008oooool4o`0003Wooooo0_l00004ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04;ooooo00?o0000oo:_P_l000002?ooool2o`0001;o_Y6X00?o0000ooooooooool0G?ooool00ol0
003oooooo`000004o`0000;ooooo00Go0000oh]BR?l0003oRe:8o`000007ooooo`?o000000?ooooo
o`000?ooool0Doooool01?l0003oooooooooooooool3o`0000OoRe:800?o0000oh]BR?l000001?n;
DXP4o`0000Gooooo00?o0000ooooooooool0=Oooool003;ooooo00?o0000ok6L`onaW<<02_naW<<<
okF]d0Go^/7O0_l00004omcKeP;oho?GE?ooool01?l0003oooooooooooooool4o`0000ooRe:800Go
0000oh]BR?n;DXSoRe:8o`000002ooooo`03o`000?oooooooooo00;ooooo0ol0000Vooooo`03o`00
0?oooooooooo00Cooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
7Oooool3o`0003oooooo00Co0000oooooooooooo00007oooool3o`0003oooooo00Go0000oooooooo
ooooooooo`00000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`14ooooo`03o`000?ob[h;o000000Wooooo00?o0000okjAZ?nnTJP03_nnTJP00ol0
003oooooooooo`1Nooooo`03o`000?oooooo000000;ooooo00So0000oooooooooooo0000oh]BR?l0
003oRe:8o`0000Oooooo00Go0000ooooool0003oooooo`00001Dooooo`05o`000?oooooo0000o`00
0?ooool00_l00008oh]BR0;o00001?n;DXP00ol0003oooooo`000006ooooo`03o`000?oooooooooo
03Gooooo000booooo`;o00002?naW<<=okF]d0Ko^/7O0_l000001?nnf^kog=_FomcKe_oLfmH2on?c
e`03omKm^Ooooooooooo05;ooooo00?o0000ooooool000000_l0000Aoh]BR0?o00000_n;DXP00ol0
003oooooooooo`05o`0000;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02oooo
o`?o00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo1?l00013oooo
o`;o000000?oooooo`000?ooool06_ooool3o`0004?ooooo00Co0000oooooooooooo0000:Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool0
0ol0003olZn2o`00000:ooooo`;o00003_nnTJP00ol0003oooooooooo`1Nooooo`04o`000?oooooo
ooooo`0000;ooooo00Oo0000ooooool0003oRe:8o`000?n;DXSo000000Oooooo00Co0000ooooool0
003o0000E_ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800KoRe:80_l00004oh]B
R003o`000?oooooo000000Kooooo00?o0000ooooooooool0=Oooool003?ooooo00?o0000ok6L`ona
W<<01?naW<<=okF]d0Ko^/7O0_l00004okkJkP04omcKe_oSlmOoho?GomKm^EGooooo0_l00002oooo
o`03o`000?n;DXSoRe:800coRe:80ol00003oh]BR003o`000?n;DXSoRe:800?o00001_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool3o`0004Wooooo00?o0000oooo
ool000005oooool3o`0004Oooooo00?o0000ooooool00000:_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool01?l0003olZn2oo:_P_l0000;
ooooo`03o`000?nnTJSo_Y6X00[o_Y6X00?o0000ooooooooool0H?ooool03?l0003oooooooooool0
003oooooo`000?oooooo0000oh]BR?l0003oRe:8o`0000Oooooo0_l000000ooooooo0000ooooo`1E
ooooo`03o`000?oooooooooo00;ooooo0_l00007oh]BR0;o00001?n;DXP00ol0003oooooo`000004
ooooo`?o0000=oooool003?ooooo0_l00003ok6L``go]Jg@1onj`Ml2o`0000Co_][^0_ndm?800om^
f:coooooooooo`1Eooooo`05o`000?ooooooooooooooool000002on;DXP3o`0000OoRe:800?o0000
oh]BR?l000001oooool00ol0003oooooooooo`0Uooooo`;o00001Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool4o`0004gooooo0ol0000B
ooooo`Co0000Boooool2o`0002_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo04Sooooo00?o0000oo:_P_l000003?ooool2o`0000Wo_Y6X00?o0000ooooooooool0H_oo
ool00ol0003oooooo`000002ooooo`;o000000CoRe:8o`000?n;DXSo00001oooool4o`0005Oooooo
00Co0000oooooooooooooooo0_l00007oh]BR0?o00000on;DXP01?l0003oooooo`000?ooool3o`00
00;ooooo00?o0000ooooooooool0=Oooool003Cooooo00?o0000okF]d?ne[M002one[M08ok[1g`03
okkJk_l0003o_][^00?o_][^0ondm?800om^f:coooooooooo`1Fooooo`05o`000?oooooooooooooo
ool000001on;DXP4o`0000_oRe:80_l00005ooooo`?o0000:Oooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`Co0000Doooool2
o`0000kooooo0ol0001@ooooo`Wo00009?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo04Wooooo00Co0000oo:_P_ob[h;o00003Oooool00ol0003o_Y6XokjAZ006okjAZ003o`00
0?oooooooooo06;ooooo00Go0000oooooooooooo0000ooooo`02o`000004oh]BR?l0003oRe:8o`00
00Oooooo0_l000000ooooooo0000ooooo`1Gooooo`06o`000?ooooooooooo`000?n;DXSo00000_n;
DXP4o`0000;oRe:800Go0000oh]BR?n;DXSo0000ooooo`03o`0000Gooooo00?o0000ooooooooool0
=Oooool003Cooooo00?o0000okF]d?ne[M002One[M08ok[1g`03okkJk_l0003o000000Co_][^0_nd
m?800om^f:coooooooooo`1Hooooo`05o`000?ooooooooooooooool000001?n;DXP3o`0000koRe:8
0ol000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooooooool0:?ooool01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool3o`0005So
oooo0_l0000:ooooo`?o0000G?ooool@o`0001Gooooo00Go0000ooooool0003oooooo`00001<oooo
o`05o`000?ob[h;olZn2oo:_P_l000003Oooool2o`0000Go_Y6X00?o0000ooooooooool0I?ooool0
0ol0003oooooo`000003o`000004oh]BR?l0003oRe:8o`0000Oooooo0_l000000ooooooo0000oooo
o`1Gooooo`03o`000?oooooooooo00Go00000on;DXP01_l0003oRe:8oh]BR?n;DXSo0000oh]BR0;o
000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`0eooooo`00=Oooool00ol0003o]Jg@
okF]d006okF]d0So^/7O00?o_][^o`000?l000001?nnf^h3okCdlUgooooo00Go0000oooooooooooo
0000oh]BR003o`0000koRe:81ol00005ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool0
00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo1?l0001Looooo`;o
00001_ooool3o`0006oooooo4?l00006ooooo`?o0000C_ooool01Ol0003olZn2oo:_P_ob[h;o0000
00cooooo00Co0000oo:_P_l0003o00000onnTJP00ol0003oooooooooo`1Uooooo`04o`000?oooooo
0000ooooo`?o000000?oRe:8o`000?ooool01_ooool2o`000003ooooool0003ooooo05Sooooo1?l0
00000on;DXSo0000oh]BR003oh]BR003o`000?n;DXSoRe:800;oRe:80_l00002ooooo`03o`000?oo
oooooooo00;ooooo0ol0000gooooo`00=_ooool00ol0003o]Jg@okF]d003okF]d0So^/7O0ol00004
okkJkP?o]?Cb00?oK]R/ooooooooool0G?ooool00ol0003oooooo`000002o`0000goRe:81ol00004
ooooo`03o`000?oooooooooo00?o0000;Oooool2o`0001;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`?o0000H_ooool00ol0003oooooooooo`03o`0008;ooooo2?l0001@ooooo`05o`000?ob
[h;olZn2oo:_P_l000002_ooool00ol0003olZn2oo:_PP03o`000003okjAZ?l0003ooooo06Sooooo
00So0000ooooool0003o0000oh]BR?l0003oRe:8o`0000Kooooo00?o0000ooooool000000_l0001J
ooooo`03o`000?oooooo000000;oRe:800Co0000oh]BR?n;DXSo00001?n;DXP5o`000003ooooool0
003o000000;o000000?oooooo`000?ooool0=oooool003Kooooo0_l00002okF]d0So^/7O0ol00004
okkJkPCo]?CbH?ooool2o`000003ooooool0003oRe:800[oRe:80ol00003ooooo`03o`000?oooooo
oooo00Cooooo1Ol0000`ooooo`?o00004?ooool01?l0003oooooooooool00008ooooo`Co0000I_oo
ool2o`000=kooooo00Go0000oo:_P_ob[h;olZn2o`000009ooooo`03o`000?ob[h;olZn200Co0000
Joooool01?l0003oooooo`000?n;DXP3o`0000Kooooo0ol000000ooooooo0000ooooo`1Jooooo`;o
00000on;DXP00ol0003oRe:8o`000004o`000003ooooool0003ooooo00?o00000_ooool3o`0003Wo
oooo000gooooo`;o00001onj`Ml2o`0000Ko_][^0ondm?9Rooooo`04o`000?ooooooooooo`0000So
Re:80ol00005ooooo`03o`000?oooooooooo00Oo0000=_ooool5o`0000_ooooo00Co0000oooooooo
oooo00001Oooool3o`000?ooooooC?ooool01?l0003olZn2oo:_P_ob[h82o`0000Kooooo00?o0000
oo:_P_ob[h800ol0001^ooooo`Oo00001Oooool01?l0003oooooo`000?l0001Mooooo`;o000000?o
Re:8o`000?l000000_l00005ooooo`Oo000000?oooooo`000?ooool0>Oooool003Sooooo0_l00003
ok[1g`?o00001_nnf^h3okCdlP03ofkH[?oooooooooo06;ooooo00?o0000ooooool000001?n;DXP4
o`0000Kooooo2?l0000oooooo`Go00001_ooool00ol0003oooooo`000002ooooo`Co0000oooooom@
ooooo`03o`000?ob[h;olZn200;olZn200Co0000oooooooooooooooo0_l00002oo:_PP03o`000?oo
oooooooo073ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo0ol0001Oooooo`;o00001?oo
ool2o`0000;ooooo1Ol000001?oooooo0000o`000?l0000kooooo`00>Oooool5o`0000Ko_][^1?nd
m?9Wooooo`;o000000CoRe:8o`000?l0003o00001_ooool8o`0004Sooooo1Ol000000ooooooo0000
o`000003o`000?ooooooEOooool00ol0003olZn2oo:_PP02oo:_PP?o00001?ob[h800ol0003ooooo
ooooo`1aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ol0001Rooooo`;o
00000_ooool:o`0003kooooo000jooooo`;o00001_nnf^h4okCdlP03ofkH[?oooooooooo06Oooooo
0ol00003ooooo`Wo0000DOooool3o`000?ooooooFOooool2o`0000SolZn200?o0000ooooooooool0
Loooool00ol0003oooooo`000007o`0006Gooooo0ol000000ooooooo0000o`000002o`0004;ooooo
000kooooo`?o00000onnf^h2okCdlP;o0000K_ooool8o`000?oooooo/oooool2o`0000GolZn20_l0
001fooooo`Go0000K?ooool2o`0004Gooooo000nooooo`Go0000ooooooooooooobkooooo1Ol0003o
oooooc7ooooo0011ooooo`03o`000?oooooooooo0?ooooooooooooooooooof?ooooo003ooooooooo
oooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003o
oooooooooooooooooonWooooo`00oooooon4ooooo`Co00001?ooool3o`0000?ooooo00Co0000oooo
oooooooooooo0_l000001?oooooo0000o`000?l00004ooooo`So00000_ooool01?l0003oooooo`00
0?ooool2o`000?oooooom_ooool00?ooooooQOooool01?l0003oooooooooool00002ooooo`0;o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000001?ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo0000
0?oooooomoooool00?oooooo1Oooool4o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool6o`000005ooooool0003o
0000o`000?ooool00ol00002ooooo`03o`000?oooooo000000Co00001?ooool8o`0000;ooooo00Co
0000ooooool0003ooooo0_l0000gooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`06o`000?oooooo0000ooooool0003ooooo1?l000001?oooooo0000o`000?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00002ooooo`05o`000?oooooo0000ooooool00000ooooooogoooo
o`00ooooool6ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool2o`0000?ooooo00?o0000oooooooo
ool00_ooool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000002
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001?ooool01ol0003oooooo`00
0?oooooo0000ooooool00000>?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool01Ol0003oooooo`000?oooooo0000
03kooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`05o`000?oooooo
0000o`000?ooool00_l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000oooo
o`02o`000004ooooool0003o0000o`0000;ooooo00Co0000ooooool0003ooooo0_l000001?oooooo
0000o`000?l0003ooooooh3ooooo003oooooo`Kooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooo`000?ooool01Ol00004ooooo`07o`000?ooooooooooooooool0003ooooo
o`000002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooo`000003ooooo`05o`00
0?oooooo0000ooooool000000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00;ooooo00Go0000ooooool0003oooooo`00000hooooo`05o`000?ooooooooooooooool000000_oo
ool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool01Ol0003ooooo
ooooool0003ooooo00Go00000_ooool8o`00043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000006ooooo`07o`000?oooooo0000ooooool0003oooooo`000004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool01ol0
003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0003oooooogoooooo
003oooooo`Kooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool2o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000002oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooool000000oooool01Ol0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Co
oooo00Go0000ooooool0003oooooo`00000hooooo`04o`000?ooooooooooo`00017ooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?o0000
00?oooooo`000?l000000_ooool01?l0003oooooo`000?ooool4o`000005ooooool0003ooooooooo
ool000000_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`000?ooooooOoooool0
0:3ooooo0_l0001Sooooo`06o`000?ooooooooooooooool0003ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00000_ooool6o`000006ooooool0003oooooooooool0003ooooo0_l00002oooo
o`Go00000_ooool3o`000004ooooool0003o0000o`0000?ooooo00Go0000oooooooooooo0000oooo
o`05o`0000;ooooo2?l0000hooooo`Co00004Oooool4o`0000Kooooo00?o0000ooooooooool0B?oo
ool4o`0000;ooooo00?o0000ooooool000000_ooool2o`0000Cooooo00Go0000ooooool0003ooooo
o`000002ooooo`03o`000?oooooo000000;ooooo1?l00003ooooo`05o`000?oooooo0000ooooool0
00000oooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0
003Gooooo`?o0000Y?ooool00:;ooooo00?o0000ooooooooool0H?ooool01?l0003oooooooooool0
000Aooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04oooool01?l0003ooooo
ooooool0002booooo`05o`000?ooooooooooo`000?ooool00ol000000ooooooo0000o`000002oooo
o`Ko00000oooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02
o`0000?ooooo0ol000000ooooooo0000o`000003o`0000?ooooo0ol0003Iooooo`03o`000?oooooo
oooo0:?ooooo000^ooooo`?o00001?ooool6o`0000?ooooo00?o0000ooooool000000_l00002oooo
o`04o`000?oooooo0000ooooo`Go000000?oooooo`000?ooool01_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000fooooo`?o00001?ooool00ol0003ooooo
ooooo`06o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003o`000003ooooool0003o000000;ooooo3?l000000ooooooo0000o`000002ooooo`03o`00
0?oooooo000000Co0000;?ooool4o`0000Cooooo00?o0000ooooooooool03Oooool3o`000003oooo
ool0003o000000;o00001_ooool00ol0003oooooooooo`09ooooo`Co00001_ooool00ol0003ooooo
ooooo`2Zooooo`05o`000?ooooooooooooooool000005Oooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0;Oooool3o`000005ooooool0003o
0000o`000?ooool00ol000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000?ooooo
00?o0000ooooool000001?ooool3o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?ooool0
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000Cooooo0ol000001?oooooo0000
o`000?l00002ooooo`;o00009_ooool2o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000o`00
0?ooool00_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?ooool00ol00000
1?oooooo0000o`000?l00002ooooo`03o`000?oooooo000000Ko000000?oooooo`000?l000000_oo
ool3o`0000?ooooo0ol00003ooooo`Co000000?oooooo`000?l00000=?ooool6o`000003ooooool0
003o000000;ooooo00?o0000ooooool000001?l000000ooooooo0000o`000002o`0000Cooooo0ol0
0003ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool0<?ooool002gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooool0003oooooo`000003ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000=_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`08o`000?oo
ooooooooo`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000_ooool2o`000005ooooool0003oooooooooool000000_ooool01?l0003ooooooooo
ooooool2o`0000Cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`3ooooooa;ooooo
1_l0000Dooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00003oooool2o`00033ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`03o`000?oooooooooo00;o0000:_ooool00ol0003oooooo`000003ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000006ooooo`03o`000?oooooo000000;ooooo00So0000oooo
oooooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo03;o
oooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooo000000Cooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_oo
ool02?l0003oooooooooool0003oooooo`000?oooooo00001?ooool00ol0003oooooooooo`0aoooo
o`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooo000003Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool2o`0000;ooooo00Co
0000oooooooooooo00001?ooool4o`000004ooooool0003oooooo`0000;ooooo0_l0003oooooogco
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000Ko
oooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo1?l0
00001?oooooo0000ooooool00007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1Ol0000Wooooo`03o`000?oooooo000000?ooooo00Ko0000ooooool0003oooooo`000?ooool4o`00
0003ooooool0003o000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000003Oooooo00?o0000ooooooooool00_ooool4o`000004ooooool0003oooooo`00
00;ooooo0_l00002ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?oo
oooo0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`000?ooool01?l000000ooo
oooo0000ooooo`0booooo`00;?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000oooo
ool000001?ooool00ol0003oooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool00ol0003oooooo`00000eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0:o`000?oooooooooo
o`000?oooooo0000ooooool0003oooooo`000?ooooooO_ooool5o`000003ooooool0003ooooo00;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`05o`000?oooooo0000oooo
ool000000_ooool2o`0000Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooo000000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00004
ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`0:o`000?ooooooooooo`000?oooooo0000
ooooool0003oooooo`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Go
0000ooooool0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002
ooooo`03o`000?oooooo000003?ooooo000/ooooo`03o`000?oooooooooo00Cooooo0_l000001?oo
oooo0000ooooooooool6o`000005ooooool0003o0000o`000?ooool01Ol00003ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Ko000000Goooooo`000?l0003o0000ooooo`03o`0003Co
oooo00?o0000ooooooooool01?ooool2o`000006ooooool0003o0000ooooool0003ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`?o000000?oooooo`000?l000000ol00002ooooo`Go00000ooo
ool01?l0003oooooooooool00005ooooo`;o000000Coooooo`000?l0003o00000oooool3o`000?oo
ooooNoooool01Ol0003ooooooooooooooooo000000;ooooo0ol00002ooooo`04o`000?oooooooooo
o`0000;ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Oooooo0ol0
00000ooooooo0000o`000004o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
00001?oooooo0000ooooooooool3o`0000;ooooo0_l0000Xooooo`03o`000?oooooooooo00?o0000
00Coooooo`000?l0003o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000000_ooool8o`000004ooooool0003o0000ooooo`?o00001Oooool5o`00
0003ooooool0003o000000?o00000_ooool3o`0003Cooooo00?o0000ooooooooool00oooool2o`00
0004ooooool0003o0000o`0000?ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00?o000000Goooooo`000?l0003oooooo`000002ooooo`?o00000_ooool00ol0003ooooooooo
o`02o`000004ooooool0003o0000o`0003;ooooo000]ooooo`03o`000?oooooooooo00;o00002ooo
ool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0004Oooooo00?o0000ooooooooool00_l0
0007ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool01?l0003ooooooooo
ool0003oooooohcooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00kooooo00?o0000ooooooooool00_l0000Fooooo`03o`000?oooooooooo00;o00001oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o00001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool002kooooo0_l00000
0ooooooo0000ooooo`0Hooooo`;o00001Oooool2o`000003ooooool0003ooooo04Cooooo0_l00000
0ooooooo0000ooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool0
0ol0003oooooooooo`07ooooo`;o000000Coooooo`000?l0003o0000oooooon:ooooo`?o000000Co
ooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000
ooooo`0Fooooo`;o000000?oooooo`000?ooool01Oooool2o`0002gooooo0ol0000Booooo`;o0000
1Oooool2o`0000_ooooo00?o0000ooooooooool01_ooool3o`0000_ooooo00?o0000ooooooooool0
=_ooool3o`00013ooooo1?l0000=ooooo`;o00000oooool2o`0003[ooooo003ooooooooooooooooo
oonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooo
oooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOooooo003o
oooooooooooooooooonWooooo`00ooooooooooooooooooooYoooool00?ooooooooooooooooooojOo
oooo003ooooooooooooooooooonWooooo`00ooooooooooooooooooooYoooool00?oooooooooooooo
ooooojOooooo003ooooooooooooo5_ooool2o`000?ooooooSoooool00?oooooooooooolCooooo`?o
000000?oooooo`000?ooool0oooooon>ooooo`00Eoooool2o`000?oooooo]oooool2o`0000?ooooo
0ol0003oooooohkooooo001Eooooo`;o000000?oooooo`000?ooool0oooooondooooo`;o00001Ooo
ool2o`000003ooooool0003ooooo0?ooooooS?ooool005Gooooo00?o0000ooooooooool00_l0003o
oooook7ooooo0ol00006ooooo`05o`000?oooooo0000ooooool00000oooooon=ooooo`00EOooool0
1_l0003oooooooooool0003oooooo`000?oooooo[_ooool2o`0000Wooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`3ooooooh[ooooo001Eooooo`05o`000?ooooooooooo`000?ooool0
0_l0003ooooooj_ooooo0_l0000;ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
oooooon:ooooo`00EOooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool0oooo
oonUooooo`?o00003?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0?oooooo
ROooool005Gooooo1?l00004ooooo`03o`000?oooooooooo0?ooooooX_ooool2o`0000oooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooohSooooo001Eooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0oooooonOooooo`;o00004?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0oooooon8ooooo`00EOooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l0003ooooooigooooo0ol0000Booooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`3oooooohOooooo001Eooooo`06o`000?oooooooooooooo
ool0003ooooo0ol00002ooooo`03o`000?oooooooooo0?oooooo;oooool3o`000003ooooool0003o
oooo06?ooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Kooooo`Go0000f_ooool5o`0004Oooooo001Eooooo`03o`000?oooooo0000
00?o00001_ooool00ol0003oooooooooo`3oooooobgooooo00Co0000ooN_Loog[g?omjmc0_l0001R
ooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Eoooool5o`0000?ooooo00?o0000ooooooooool0e?ooool5o`0000?ooooo00?o0000
ooooooooool0A?ooool005Gooooo1Ol00007ooooo`;o0000ooooool]ooooo`03o`000?og[g?omjmc
00Comjmc0ol0001Looooo`?o00005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0E?ooool5o`0000Gooooo0_l0003Cooooo`Go00001Oooool2o`00
04Gooooo001Eooooo`05o`000?ooooooooooooooool000001Oooool2o`000003ogm9QOl0003ooooo
0?oooooo;?ooool00ol0003omjmcooN_L`06ooN_L`03o`000?oooooooooo05Sooooo0_l0000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aoooo
o`Go000000?oooooo`000?ooool00_ooool3o`0000;ooooo00?o0000ooooooooool0H?ooool6o`00
06Oooooo1ol00004ooooo`;o000000?oooooo`000?ooool0A?ooool005Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000omoBHD2o`000?oooooo:oooool00ol0003omjmcooN_L`08ooN_
L`03o`000?oooooooooo05Gooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1>ooooo`Go000000?oooooo`000?l000000_ooool2o`00
00Kooooo00?o0000ooooooooool0G?ooool6o`0000?ooooo00?o0000ooooooooool0H_ooool5o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo04;ooooo001Eooooo`06
o`000?ooooooooooooooool0003ooooo0_l00005ogm9Q@03o`000?oooooo00000?oooooo:Oooool0
0ol0003omjmcooN_L`0:ooN_L`03o`000?oooooooooo057ooooo0ol0000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`Go000000Gooooo
o`000?l0003o0000ooooo`03o`0000Sooooo0_l0001Looooo`;o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`02o`00063ooooo1_l00002ooooo`?o000000?oooooo`000?l000001ooo
ool00ol0003oooooooooo`11ooooo`00EOooool6o`0000OoOdV500Co0000ooooool0003o0000C?oo
ool5o`000=Kooooo00?o0000ooN_Loog[g<02oog[g<00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Oooooo2Ol00002ooooo`?o00001oooool3o`000003oh]BR?l0003ooooo05[ooooo00Co
0000oooooooooooo00001Oooool2o`0000;ooooo00?o0000ooooooooool0G?ooool01_l0003ooooo
oooooooooooo0000ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`04
ooooo`;o0000@_ooool005Gooooo0_l00002ojO0j`03o`000?moBHGoOdV500KoOdV50_l00002oooo
o`03o`000?oooooooooo04Kooooo1Ol000001?oooooo0000ooooool0001_ooooo`Co<0001Omc001M
ooooo`03o`000?og[g?omjmc00_omjmc00?o0000ooooooooool0Coooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`15
ooooo`;o00000oooool2o`000003ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`03
ooooo`;o00001?n;DXP2o`0005[ooooo0ol00007ooooo`05o`000?ooooooooooooooool00000GOoo
ool00ol0003oooooooooo`03o`0000;ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo00?o000000?oRe:8o`000?ooool0@Oooool005Gooooo00Co0000ojO0jonW`>_oYl3[0_l0
0007ogm9Q@03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_ooool5o`0000?ooooo0_l0
00000ooooooo0000o`00001Yooooo`Co<0001Omk53<4ok=1<@KoL`00F?ooool00ol0003omjmcooN_
L`0;ooN_L`;o0000D?ooool2o`0001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool000000_l00004ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo0_l00005oh]BR004o`000?ooooooooooo`0005So
oooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00;o0000Foooool01_l0003o
ooooo`000?l0003oooooo`0000Cooooo0_l00005ooooo`?o00001?n;DXP2o`00047ooooo001Eoooo
o`07o`000?nW`>_oYl3[ojO0jol0003oYl3[o`000006ogm9Q@03o`000?oooooooooo00;ooooo0_l0
0011ooooo`;o000000Koooooo`000?l0003o0000ooooool00002ooooo`?o000000?oooooo`000?l0
0000I_ooool00ol3003oNa@cog/D<`08og/D<`Wo/d4a0_mc001Fooooo`03o`000?og[g?omjmc00co
mjmc00?o0000ooN_Lol00000Coooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`13ooooo`?o00002?ooool00ol0003o
ooooooooo`05o`0000OoRe:800Co0000oooooooooooo0000F?ooool01?l0003oooooooooool00009
ooooo`;o00000_n;DXP00ol0003oooooooooo`1Hooooo`;o00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?o000000?oRe:8o`000?n;DXP01?n;DXP00ol0003oooooo`000010
ooooo`00EOooool01Ol0003oYl3[ojO0jonW`>_o000000;oYl3[0_l00005ogm9Q@04o`000?oooooo
0000o`0000;ooooo00?o0000ooooooooool0>oooool6o`000004ooooool0003o0000ooooo`Co0000
00Koooooo`000?oooooo0000ooooool0001Tooooo`;o0`001omk53<3oiA9KP?o`Vi^2?nc@C42olQ9
05Cooooo00?o0000ooN_Loog[g<03?og[g<01?l0003omjmcooN_Lol0001=ooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`09ooooo`?o000000?oYl3[o`000?n;DXP02On;
DXP00ol0003oooooooooo`02o`0005Oooooo00?o0000ooooool000002_ooool00ol0003oRe:8oh]B
R002oh]BR003o`000?oooooooooo05Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`Go00001?n;DXP00ol0003oRe:8oh]BR004oh]BR0?o0000?oooool003cooooo0ol0000F
ooooo`;o000000?oYl3[o`000?l000001?nW`>/00ol0003oOdV5ogm9Q@02ogm9Q@;o00001Oooool0
0ol0003oooooooooo`0hooooo`co000000Coooooo`000?oooooooooo0_l000000ooooooo0000oooo
o`02o`00067ooooo0ol30003og/D<`SoU4U^1oo2KVh5ok=1<@;ob4T0Doooool00ol0003omjmcooN_
L`0<ooN_L`04o`000?og[g?omjmco`0004gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo00Kooooo0ol00004ojO0j`03o`000?n;DXSoRe:800SoRe:8
0ol000000ooooooo0000ooooo`1Fooooo`03o`000?oooooo000000Wooooo00?o0000oh]BR?n;DXP0
1?n;DXP00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0_l00002ojO0j`;o00001On;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?oooooo000003oooooo
000kooooo`04o`000?oooooo0000ooooo`?o00004oooool3o`000003ojO0jol0003oYl3[00CoYl3[
00Go0000ogm9QOmoBHGoOdV5o`000006ooooo`;o0000>?ooool01?l0003oooooo`000?ooool3o`00
0004ooooool0003o0000ooooo`;o000000Coooooo`000?oooooooooo1Ol000000on;DXSo0000oooo
o`0:ooooo`Co0000DOooool3o`<000coU4U^2oo2KVh01?nc@C7ob4T0olQ90?o8B@1Booooo`;o0000
3Oog[g<01Ol0003omjmcooN_Loog[g?o000004cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00?ooooo0ol00007ojO0j`03o`000?n;DXSoRe:800Oo
Re:800?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo000000;o
00001oooool00ol0003oRe:8oh]BR006oh]BR003o`000?oooooooooo05Cooooo00Co0000oooooooo
oooooooo0ol00005ojO0j`03o`000?nW`>_o000000CoRe:800?o0000oh]BR?n;DXP01?n;DXP01?l0
003oooooooooool0000nooooo`00>_ooool01?l0003oooooooooool00003ooooo`?o00004Oooool2
o`0000;oYl3[00?o0000ojO0jonW`>/01?nW`>/01?l0003oOdV5ogm9QOl00004ooooo`;o000000?o
ooooo`000?ooool0=oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;o0000
0_ooool00ol0003oooooo`000005o`0000;oRe:80_l00007ooooo`Go00000_ooool00ol0003ooooo
ooooo`1=ooooo`?o0`0000?oAPIHoiA9K_nDBFh02_nDBFh<ol9^KP;ojHaA0_o8B@1Aooooo`03o`00
0?og[g?o000000comjmc00Go0000ooN_Loog[g?omjmco`00001<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0?oooool01?l0003oooooooooooooool3o`0000[oYl3[0_l00008oh]B
R003o`000?oooooooooo00Cooooo00?o0000ooooooooool0D_ooool2o`000003ojO0jol0003oYl3[
00?o00001?ooool00ol0003oRe:8oh]BR006oh]BR003o`000?oooooooooo05?ooooo00?o0000oooo
ooooool00_l000000onW`>_o0000o`000005ojO0j`04o`000?nW`>_oYl3[o`0000?oRe:800?o0000
oh]BR?n;DXP01?n;DXP01Ol0003ooooooooooooooooo000003gooooo000iooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooooooool2o`0000oooooo0_l00002ojO0j`03o`00
0?nW`>_oYl3[00CoYl3[00Go0000ogm9QOmoBHGo0000ooooo`03o`0000?ooooo00?o0000oooooooo
ool0=Oooool3o`000009ooooool0003oooooooooool0003oooooo`000?oooooo000000;ooooo0ol0
0002oh]BR0;o000000?oRe:8o`000?n;DXP00_l00005ooooo`Ko00000oooool2o`0004gooooo0ol3
0002odH6F0[oU4U^0_nOIXh4olF5SPSo`Vi^0ooYS542olQ9053ooooo00Co0000ooN_Loog[g?o0000
2oog[g<00ol0003omjmcooN_L`02ooN_L`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0nooooo`Co00003OnW`>/2o`0000SoRe:800?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Booooo`04o`000?nW`>_oYl3[o`0000CoYl3[1?l0000:oh]BR003
o`000?oooooooooo05;ooooo0ol00003ojO0j`03o`000?nW`>_o000000GoYl3[00Co0000ojO0jonW
`>_o00000_n;DXP00ol0003oRe:8oh]BR004oh]BR005o`000?ooooooooooooooool00000?Oooool0
03Sooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooo
oooo00cooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00GoYl3[00Co0000ogm9QOl0003o00001_oo
ool00ol0003oooooooooo`0dooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooo`000004o`000005oh]BR?l0003oRe:8o`000?n;DXP00_l000000on;DXSo0000oh]BR003o`00
00Cooooo1?l000000ooooooo0000o`000002o`000003oh]BR?l0003ooooo04cooooo00?o0`00odH6
F?m61UP00_m61UP6oiA9KPKoWfJ>2?o5QHh5ol9^KPCojHaA00?ob4T0ooooooooool0COooool01Ol0
003omjmcooN_Loog[g?o000000[omjmc00?o0000ooN_Loog[g<00_og[g<00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool2o`0000ooYl3[0_l00008
oh]BR003o`000?oooooooooo00Cooooo0_l0001Cooooo`04o`000?nW`>_oYl3[o`0000OoYl3[0ol0
0008oh]BR003o`000?oooooooooo05;ooooo00?o0000ojO0jonW`>/00onW`>/01?l0003oYl3[ojO0
jol00004ojO0j`07o`000?nW`>_oYl3[ojO0jol0003oRe:8o`000006oh]BR003o`000?oooooooooo
00?o0000??ooool003Kooooo0_l00003ooooo`04o`000?oooooo0000o`0000Oooooo0ol0000=oooo
o`04o`000?nW`>_oYl3[o`0000SoYl3[0_l00007ooooo`03o`000?oooooooooo03Cooooo00So0000
ooooooooooooooooo`000?oooooo0000ooooo`?o000000?oYl3[o`000?l000000_n;DXP01?l0003o
Re:8o`000?n;DXP2o`000006oh]BR?l0003oRe:8o`000?oooooo00001?ooool01?l0003ooooooooo
ooooool2o`0000CoRe:80_l0001;ooooo`03o`<00?m61USoAPIH00?oAPIH0_nDBFh:oimVSPcoaHF>
00?o`Vi^onV<DOoYS5401?oYS55>ooooo`03o`000?og[g?omjmc00;omjmc00?o0000ooN_Loog[g<0
1oog[g<00ol0003omjmcooN_L`03ooN_L`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000goYl3[0ol00007oh]BR003o`00
0?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`1Booooo`05o`000?nW`>_oYl3[ojO0jol0
00002OnW`>/2o`0000OoRe:800?o0000ooooooooool0DOooool00ol0003oYl3[ojO0j`03ojO0j`05
o`000?nW`>_oYl3[ojO0jol000000_nW`>/2o`0000CoYl3[0_l00006oh]BR0?o00000_ooool00ol0
003oooooooooo`0jooooo`00=Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooooooo0_l0000;ooooo`04o`000?nW`>_o0000o`0000WoYl3[00?o
0000ooooooooool01?ooool2o`0003Kooooo0_l00002ooooo`Co00001?nW`>/00ol0003oYl3[o`00
0002oh]BR004o`000?n;DXSo0000oh]BR0?o000000?oRe:8o`000?ooool00_l00003ooooo`Co0000
00?oYl3[o`000?l000000on;DXP2o`0004_ooooo1Om61UP00omV>XOoWfJ>oimVSP0:oimVSPgoaHF>
0_oZYhD5onV<DDgooooo00?o0000ooN_Loog[g<00_og[g<00ol0003omjmcooN_L`07ooN_L`03o`00
0?og[g?omjmc00?omjmc00?o0000ooooooooool0Aoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`;o0000
?_ooool00ol0003oooooooooo`02o`0000SoYl3[0ol000000onW`>_o0000o`000007oh]BR003o`00
0?oooooo000000;o00001Oooool00ol0003oooooooooo`1@ooooo`05o`000?nW`>_oYl3[ojO0jol0
00002onW`>/2o`0000GoRe:800?o0000ooooooooool0DOooool2o`0000CoYl3[00Co0000ojO0jonW
`>_oYl3[0ol000000onW`>_o0000ojO0j`04ojO0j`03o`000?n;DXSoRe:800CoRe:800?o0000oooo
ooooool00oooool00ol0003oooooooooo`0iooooo`00=?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000;o00001_ooool00ol0003oooooooooo`03ooooo`?o00002Oooool2o`000003
ojO0jol0003oYl3[00OoYl3[00?oOdV5o`000?l000000_ooool3o`000003ooooool0003ooooo03Co
oooo00?o0000ooooooooool00ol00007ojO0j`04o`000?nW`>_oYl3[o`0000;oRe:81_l000001_n;
DXSo0000ooooool0003oooooo`0000;ooooo00?o0000ojO0jonW`>/00onW`>/2o`0000;oRe:80ol0
0019ooooo`CoAPIH0omV>XL<oimVSPgoaHF>0ooZYhD4onV<DDgooooo00?o0000ooN_Loog[g<00oog
[g<00ol0003omjmcooN_L`06ooN_L`03o`000?og[g?omjmc00Comjmc00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`09ooooo`?o000000?oooooo`000?ooool0?Oooool00ol0003ooooooooo
o`02ooooo`;o00000onW`>/3o`0000CoYl3[00?o0000ojO0jol000001_n;DXP2o`0000Sooooo00?o
0000ooooooooool0D?ooool01Ol0003oYl3[ojO0jonW`>_o000000goYl3[00?o0000oh]BR?n;DXP0
0on;DXP00ol0003oooooooooo`1@ooooo`03o`000?oooooo000000?oYl3[1?l00002ojO0j`03o`00
0?nW`>_o000000KoYl3[00?o0000oh]BR?n;DXP00on;DXP00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Wooooo000cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`;o00001Oooool01?l0003oGc:2o`000?ooool3o`0000Kooooo
00Co0000ojO0jonW`>_o00001OnW`>/4ogm9Q@04o`000?nW`>_o0000o`0000Cooooo00?o0000oooo
ooooool0<oooool4o`0000WoYl3[00Co0000ojO0jonW`>_oYl3[1Ol00003oh]BR0?o00000_ooool2
o`000003ooooool0003oYl3[00?oYl3[0ol00002oh]BR003o`000?oooooo000004Wooooo0_m61UP5
ofHjQ`coWfJ>3Oo5QHh4onZWQ@?ojHaACOooool00ol0003omjmcooN_L`04ooN_L`03o`000?og[g?o
mjmc00Gomjmc00?o0000ooN_Loog[g<01?og[g<00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0ol00004ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool3
o`0000OoYl3[00?o0000ojO0jol000001On;DXP00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo053ooooo00?o0000ojO0jol000000_l0000>ojO0j`;o00000on;DXP00ol0003oooooooooo`1@
ooooo`05o`000?ooooooooooo`000?nW`>/00_l00006ojO0j`;o00001onW`>/00ol0003oRe:8oh]B
R002oh]BR003o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool003;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000002ooooo`;o00000oooool00ol0003oooooooooo`04
ooooo`04o`000?mO<X;oGc:2o`0000?ooooo0ol00004ooooo`06o`000?nW`>_oYl3[ojO0jol0003o
Yl3[2?moBHD00ol0003oYl3[o`000005ooooo`03o`000?oooooooooo03;ooooo0_l0000;ojO0j`03
o`000?nW`>_oYl3[00;oYl3[0ol00003oh]BR0Ko000000?oooooo`000?ooool01Ol000001_nW`>_o
0000ojO0jol0003oRe:8o`0000;ooooo00?o0000ooooooooool0AOooool2odH6F0KoISZ72OnOIXh3
ojEjY0Coa9BT2Oo5QHh6onZWQ@;ojHaACOooool00ol0003omjmcooN_L`04ooN_L`03o`000?og[g?o
mjmc00Comjmc00?o0000ooN_Loog[g<01?og[g<00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo0ol00007ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooooooooooo0ol0
00000ooooooo0000o`000008ojO0j`03o`000?nW`>_o000000CoRe:800?o0000ooooooooool02?oo
ool2o`00057ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00koYl3[00Co0000oh]BR?n;DXSo0000
D_ooool00ol0003oooooo`000002o`000003ojO0jol0003oYl3[00KoYl3[0_l00007ojO0j`05o`00
0?n;DXSoRe:8oh]BR?l000001_ooool00ol0003oooooooooo`0hooooo`00<Oooool01?l0003ooooo
ooooooooool2o`000008ooooool0003oooooooooool0003oooooo`000?ooool2o`0000Gooooo0_l0
0003oelbPP04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ojO0j`03
o`000?moBHGoOdV500OoOdV500Co0000ojO0jonW`>_o00001?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooo000000SoYl3[1?l00004ojO0j`Go00000_n;DXP2o`0000;ooooo00?o0000oooo
ool000000ol00003ojO0j`03o`000?nW`>_oYl3[00;o000000?oooooo`000?l00000Aoooool8ofHj
Q`?oWfJ>2OnUNZ@;olBDY0;oaHF>1ooZYhD00ooYS57oooooooooo`1;ooooo`03o`000?og[g?omjmc
00Gomjmc00?o0000ooN_Loog[g<00oog[g<00ol0003omjmcooN_L`05ooN_L`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooool000000_l0000:ooooo`03o`000?oooooooooo03cooooo1?l00006oooo
o`;o00001_nW`>/00ol0003oYl3[o`000004oh]BR003o`000?oooooooooo00Gooooo0ol000000ooo
oooo0000ooooo`1@ooooo`05o`000?nW`>_oYl3[ojO0jol000004OnW`>/00ol0003oRe:8o`00001B
ooooo`;o00000oooool2o`0000SoYl3[00?o0000ojO0jonW`>/01OnW`>/01Ol0003oRe:8oh]BR?n;
DXSo000000Cooooo0ol0000jooooo`00<?ooool5o`0000;ooooo00Co0000oooooooooooo00000_oo
ool2o`0000Kooooo00?o0000oelbP_mO<X800omO<X800ol0003oooooo`000005ooooo`04o`000?oo
ooooooooo`0000;oOdV50_l00009ogm9Q@05o`000?nW`>_oYl3[ojO0jol000000_ooool2o`0003Co
oooo00Co0000oooooooooooo00001?nW`>/3o`0000;oYl3[00Go0000ojO0jol0003o0000ojO0j`04
o`0000CoRe:80_l000001?oooooo0000ooooooooool2o`0000;ooooo00Co0000ojO0jol0003o0000
0_nW`>/3o`000003ooooool0003ooooo04Gooooo2?mV>XL00omiG:CoYGZTojEjY00:ojEjY0goa9BT
0_oT]J@6onZWQDgooooo00?o0000ooN_Loog[g<01_og[g<00ol0003omjmcooN_L`02ooN_L`03o`00
0?og[g?omjmc00Gomjmc00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool3o`0000kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`09ooooo`03o`000?nW`>_oYl3[00?oYl3[00Co0000ojO0jonW`>_o
00000on;DXP00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1>ooooo`05
o`000?nW`>_oYl3[ojO0jol000004_nW`>/00ol0003oRe:8o`00001Aooooo`03o`000?oooooooooo
00?ooooo00?o0000ojO0jonW`>/01_nW`>/2o`0000OoYl3[00Go0000oh]BR?n;DXSo0000ooooo`03
o`0000;ooooo00?o0000ooooooooool0>?ooool0033ooooo00?o0000ooooooooool01ol00003oooo
o`03o`000?oooooooooo00Cooooo00?o0000oelbP_mO<X801?mO<X82o`0000Kooooo1_l000000omo
BHGo0000ogm9Q@08ogm9Q@03o`000?nW`>_oYl3[00;oYl3[0_l000000ooooooo0000ooooo`0coooo
o`04o`000?ooooooooooooooo`Co00001OnW`>/00ol0003oYl3[o`000002o`0000;oYl3[0ol00003
oh]BR0;o000000Coooooo`000?oooooooooo0_l000001_oooooo0000o`000?l0003oYl3[o`0000?o
Yl3[00Go0000ooooooooooooooooo`000015ooooo`OoISZ70_miG:@<ojEjY0goa9BT0ooT]J@5onZW
QDgooooo00?o0000ooN_Loog[g<01oog[g<01Ol0003omjmcooN_Loog[g?o000000Oomjmc00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool3o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0:ooooo`;o00000_nW`>/2o`0000;oYl3[00Ko0000oh]BR?n;DXSoRe:8o`00
0?ooool3o`0000Sooooo00?o0000ooooooooool0C_ooool2o`0000?oYl3[00?o0000ojO0jonW`>/0
4?nW`>/2o`00057ooooo00?o0000ooooooooool01?ooool00ol0003oYl3[ojO0j`04ojO0j`;o0000
00?oYl3[o`000?nW`>/01_nW`>/01?l0003oRe:8o`000?l00006ooooo`03o`000?oooooooooo03Oo
oooo000`ooooo`03o`000?oooooo000000Cooooo0_l000000ooooooo0000o`000008o`0000OoGc:2
00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000ogm9QOmoBHD00_moBHD00ol0003oOdV5
ogm9Q@06ogm9Q@06o`000?nW`>_oYl3[o`000?nW`>_o00000_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooo000000?o00001_nW`>/3o`0000?oYl3[0ol000001OnW`>_o0000o`000?l0003o
Re:800?o00000oooool3o`0000?ooooo00?o0000ojO0jol000000_n;DXP5o`0004Gooooo00?o001A
ofHjQomV>XL00_mV>XL4ogULY0coYGZT3Oo4U:@4onBeY0CojZN5C_ooool00ol0003omjmcooN_L`07
ooN_L`04o`000?og[g?omjmco`0000Somjmc00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool3o`0000Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo0ol0
00000onW`>_o0000ojO0j`02ojO0j`03o`000?n;DXSoRe:800;o00002oooool00ol0003ooooooooo
o`1?ooooo`05o`000?nW`>_oYl3[ojO0jol000004onW`>/00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00Cooooo0_l00002ojO0j`?o000000GoYl3[o`000?nW`>_oYl3[o`000007ojO0j`;o
00001oooool00ol0003oooooooooo`0gooooo`00;oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo0ol00004ooooo`03o`000?mO<X;oGc:200;oGc:200?o0000oelbP_mO<X80
0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ogm9QOmoBHD00omoBHD00ol0003oOdV5
ogm9Q@05ogm9Q@03o`000?nW`>_oYl3[00?oYl3[00?o0000ooooool00000=?ooool2o`0000?ooooo
00CoYl3[o`000?nW`>_oYl3[0ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00000_nW`>/00ol0
003oYl3[o`000006o`000003ooooool0003ooooo00?ooooo0ol00003oh]BR0;o000000?oooooo`00
0?ooool0@oooool01?l0003o001AofHjQomV>XL7ogULY0_oYGZT3Oo4U:@6onBeY0;ojZN500?okKa1
ooooooooool0Boooool00ol0003omjmcooN_L`08ooN_L`03o`000?og[g?o000000Somjmc00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool3o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`04o`000?nW`>_oYl3[o`0000?oYl3[00?o
0000oh]BR?l000003Oooool00ol0003oooooooooo`1>ooooo`05o`000?nW`>_oYl3[ojO0jol00000
4_nW`>/00on;DXSo0000ooooo`1Aooooo`03o`000?oooooooooo00?ooooo1?l00004ojO0j`05o`00
0?nW`>_oYl3[ojO0jol000001onW`>/2o`0000Kooooo00?o0000ooooooooool0=oooool002oooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00Co0000ojO0jol0003oYl3[0_l00002ooooo`03
o`000?mO<X;oGc:200GoGc:200?o0000ooooool000002Ol00005ogm9Q@;o00001_moBHD00ol0003o
Yl3[ojO0j`04ojO0j`;o0000=?ooool01?l0003oooooo`000?l00002ooooo`03ojO0jol0003o0000
00GoYl3[1?l00002ojO0j`06o`000?nW`>_oYl3[ojO0jol0003oYl3[1?l00003ooooo`;o000000Ko
ooooo`000?l0003o0000oh]BR?l00003oh]BR0Co0000A?ooool2o`00D@03ofHjQomiG:CoNEbT00Ko
NEbT2onUNZ@<olBDY0Soi;FT00?ojZN5onfl@Oooool0C?ooool00ol0003omjmcooN_L`09ooN_L`;o
00002?og[g<00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`?o00002_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ojO0jol0
00001?nW`>/2o`0000cooooo0_l0001@ooooo`Go00003onW`>/4oh]BR0;o0000DOooool00ol0003o
ooooooooo`02ooooo`;o00000_ooool00ol0003oYl3[ojO0j`03ojO0j`05o`000?nW`>_oYl3[ojO0
jol000001OnW`>/00on;DXSo0000o`000005ooooo`?o0000>?ooool002oooooo00Co0000oooooooo
oooooooo0_l00005ooooo`04o`000?nW`>_oYl3[o`0000?oYl3[00?o0000ooooool000001omO<X80
0ol0003oooooooooo`08ooooo`03o`000?moBHGoOdV500?o00000_moBHD00ol0003oOdV5ogm9Q@03
ogm9Q@03o`000?nW`>_oYl3[00CoYl3[0_l0000dooooo`07o`000?ooooooooooooooool0003ooooo
ojO0j`02o`0000?oYl3[1ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`Go00001?ooool2o`0000;o
oooo00Co0000oh]BR?n;DXSo00000_n;DXP01?l0003oYl3[o`000?l00014ooooo`;o001A2OmiG:@6
ojEjY0GoZ8Ze1?o2X;H8olBDY0Woi;FT00?okKa1ooooooooool0Boooool00ol0003omjmcooN_L`0:
ooN_L`03o`000?og[g?omjmc00Oomjmc00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0D
ooooo`04o`000?ooooooooooo`0000;ooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`02ooooo`?o00002Oooool2o`0000GoYl3[00?o
0000ooooooooool01oooool3o`000003ooooool0003ooooo04oooooo0_l00002ojO0j`03o`000?nW
`>_oYl3[00[oYl3[1on;DXP00ol0003oYl3[o`00001@ooooo`03o`000?oooooo000000;o000000?o
ooooo`000?ooool00_ooool00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o
0000ojO0jon;DXP00on;DXP2o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo03Kooooo000_
ooooo`04o`000?ooooooooooo`0000Gooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0
0007oelbPP03o`000?oooooooooo00Sooooo0ol00006ogm9Q@03o`000?moBHGoOdV500;oOdV500Co
0000ojO0jonW`>_oYl3[0ol000000ooooooo0000ooooo`0cooooo`03o`000?oooooooooo00;ooooo
0ol000000onW`>_o0000o`000002o`000003ojO0jol0003oYl3[00?oYl3[0ol00004ojO0j`05o`00
0?nW`>_o0000ooooool000000oooool01_l0003ooooooooooooooooo0000oh]BR0;o00000_n;DXP0
0ol0003oYl3[ojO0j`02o`0004;ooooo00?o0000o`00DOl005402?miG:@00on6M[WoZ8ZeojR:]@09
ojR:]@[o`Z2f0_o4U:@9onBeY0;okKa1COooool00ol0003omjmcooN_L`09ooN_L`;o00002?og[g<0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool000000_l0000@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?Oooool4o`0000gooooo0_l00000
1?nW`>_oRe:8oh]BR?n;DXP2o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo04kooooo00Go
0000ooooool0003oYl3[o`000009ojO0j`[oRe:800?o0000ojO0jol00000D?ooool2o`0000Cooooo
00?o0000ooooooooool00_ooool01Ol0003oYl3[ojO0jonW`>_o000000;oYl3[0_n;DXP00ol0003o
Re:8oh]BR003oh]BR004o`000?nW`>_o0000o`0000Gooooo00?o0000ooooooooool0=_ooool002oo
oooo00?o0000ooooool000001Oooool00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW`>_oYl3[00Co
Yl3[0ol00004oelbPP03o`000?oooooooooo00Sooooo00?o0000ogm9QOmoBHD01omoBHD01?l0003o
OdV5ogm9QOmoBHD4o`0000Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03oooo
o`Co00000onW`>/00ol0003oYl3[o`000002o`0000;oYl3[00?o0000ojO0jonW`>/00_n;DXP00ol0
003oRe:8o`000007o`000004ooooool0003o0000o`0000;oRe:800?o0000oh]BR?l000001?l00012
ooooo`;o001A00?o41bIogULY?miG:@01OmiG:@2ohIf^@_oZ8Ze3?o2X;H2ombm^POoi;FT0_o]_45=
ooooo`03o`000?og[g?omjmc00Womjmc00?o0000ooN_Lol000001oog[g<00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool3o`00013ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0>ooooo`;o00001?n;DXP01?l0003oYl3[o`000?oo
ool3o`0000Oooooo00?o0000ooooooooool0C_ooool01_l0003oooooooooool0003oYl3[o`0000Go
Yl3[3On;DXP01?l0003oYl3[ojO0jol0001?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01?l0003oYl3[oh]BR?l00004oh]BR003o`000?n;DXSoRe:800?oRe:800Co0000
ojO0jonW`>_o00001Oooool00ol0003oooooooooo`0fooooo`00;oooool2o`0000Cooooo0_l00005
ojO0j`;o00002OnW`>/2o`0000;oGc:200?o0000ooooooooool02?ooool00ol0003oOdV5ogm9Q@07
ogm9Q@?o000000?oOdV5o`000?ooool01oooool00ol0003oooooooooo`0booooo`04o`000?oooooo
ooooooooo`Co00000_nW`>/5o`0000GoYl3[00?oRe:8o`000?n;DXP00_n;DXP2o`000003ojO0jol0
003o000000;o000000Koooooo`000?oooooo0000ooooool00003oh]BR0?o00000oooool00ol0003o
ooooooooo`10ooooo`;o001A0_l@79T4ogULY0GoQWJi2_nXR[D<ol:P]P?og;fj1OoT]J@00oomhiCo
kKa1onfl@@1=ooooo`03o`000?og[g?omjmc00Womjmc00Co0000ooN_Loog[g?o00001_og[g<00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool3o`00
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00kooooo0_l00004oh]BR004o`000?nW`>_oYl3[o`0000_ooooo00?o0000ooooooooool0C_ooool0
1Ol0003oooooo`000?nW`>_o000000;oYl3[4?n;DXP01?l0003oYl3[ojO0jol0001?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oRe:8oh]BR?n;DXSo000000?o
Re:800?o0000oh]BR?n;DXP00on;DXP01Ol0003oYl3[ojO0jonW`>_o000000Gooooo00?o0000oooo
ooooool0=Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oYl3[ojO0j`04ojO0j`03
o`000?nW`>_o000000_oYl3[0ol0000:ooooo`;o00001OmoBHD3o`0000?oOdV500?o0000ogm9QOl0
00001oooool00ol0003oooooooooo`0booooo`Co00000_ooool00ol0003oooooo`000003o`0000;o
Yl3[00?o0000ojO0jonW`>/00_n;DXP3o`0000?oRe:81_l00002ooooo`04o`000?oooooo0000oooo
o`Co000000?oRe:8o`000?l000001?l00012ooooo`04o`00DOl@79Wo41bIoa0LV@;oNEbT1on6M[T:
ojR:]@_o`Z2f1_oL_KX3onBeY0;ooN>D00?okKa1ooooooooool0Boooool00ol0003omjmcooN_L`09
ooN_L`05o`000?og[g?omjmcooN_Lol000001Oog[g<00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool4o`0000Cooooo00?o0000ooooool000003ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00kooooo0ol00003oh]BR004o`000?nW
`>_oYl3[ojO0j`;o00002Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;o0000
4_n;DXP01?l0003oYl3[ojO0jol0001@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oRe:8o`000002o`0000?oRe:800?o0000oh]BR?n;DXP00on;DXP01Ol0003o
Yl3[ojO0jonW`>_o000000Gooooo00?o0000ooooooooool0=Oooool002oooooo00Go0000oooooooo
ooooooooo`000006ojO0j`04o`000?nW`>_oYl3[o`0000goYl3[0_l00009ooooo`;o00000omoBHD2
o`0000OoOdV50_l00006ooooo`;o0000=?ooool9o`000007ojO0jol0003oYl3[o`000?nW`>_o0000
oh]BR004o`000003oh]BR?l0003oRe:800;oRe:80_l000001onW`>_o0000o`000?oooooo0000oooo
ool000000_ooool2o`0000CoRe:80_l00003ooooo`03o`000?oooooooooo043ooooo00Go001Aoa0L
VOl@79Wo41bIogULY008ohIf^@[oZ8Ze2oo2X;H7ombm^P;oi;FT0_omhi@00oo]_47oooooooooo`1<
ooooo`03o`000?og[g?omjmc00Somjmc00Go0000ooN_Loog[g?omjmco`000006ooN_L`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`?o00001ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0:ooooo`Co000000?oRe:8o`000?n;DXP00_n;DXP00ol0003oYl3[ojO0j`03ojO0j`;o0000
1Oooool3o`00053ooooo00Ko0000oooooooooooo0000oh]BR?l0000Aoh]BR005o`000?nW`>_oYl3[
ojO0jol00000Coooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?o00000_n;DXP0
1Ol0003oRe:8oh]BR?n;DXSo000000GoRe:800?o0000ojO0jonW`>/00_nW`>/00ol0003ooooooooo
o`03o`0003Oooooo000_ooooo`04o`000?oooooo0000o`0000GoYl3[0_l00003ojO0j`03o`000?nW
`>_oYl3[00[oYl3[00?oGc:2o`000?nW`>/00ol00006ooooo`Go00002OmoBHD2o`0000?ooooo0ol0
00000ooooooo0000ooooo`0cooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000
ojO0jon;DXP6o`0000CoRe:800?o0000oh]BR?n;DXP00_l00002ojO0j`;o000000Goooooo`000?oo
oooo0000ooooo`02o`000005oh]BR?l0003o0000o`000?ooool01Ol00012ooooo`04o`00DOl@79Wo
41bIoa0LV@[oQWJi2OnXR[D;ol:P]PSog;fj0oomhiA?ooooo`03o`000?og[g?omjmc00Somjmc00?o
0000ooN_Loog[g<00_og[g<00ol0003omjmcooN_L`03ooN_L`03o`000?oooooooooo043ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`?o00002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`06ooooo`Co00000oooool01?l0003oRe:8oh]BR?l00002oh]BR003o`000?nW`>_oYl3[00GoYl3[
1Ol00002ooooo`03o`000?oooooooooo04oooooo00?o0000ooooool000000_l0000Aoh]BR005o`00
0?nW`>_oYl3[ojO0jol00000Coooool00ol0003oooooooooo`03ooooo`?o00000_ooool00ol0003o
Re:8oh]BR002oh]BR004o`000?n;DXSoRe:8o`0000GoRe:800?o0000ojO0jonW`>/00onW`>/2o`00
00;ooooo00?o0000ooooooooool0=Oooool002kooooo00?o0000ooooool000001_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00[oYl3[0_mO<X800ol0003oYl3[ojO0j`02ojO0j`;o
00001?ooool2o`0000WoOdV50ol00002ooooo`?o00001?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001_l00004oh]BR0?o00000_n;DXP2o`0000;o
Yl3[0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Go0000@oooool4oa0LV@03
od9F`?n6M[WoQWJi00OoQWJi1OnXR[D4ojZIa@Ko_j_61?o2X;H9ombm^P?ooN>DCoooool00ol0003o
mjmcooN_L`08ooN_L`03o`000?og[g?omjmc00?omjmc00?o0000ooN_Loog[g<00_og[g<00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo01Oooooo1Ol0000<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00?o
oooo0ol00007ooooo`04o`000?n;DXSoRe:8o`0000;oRe:800?o0000ojO0jonW`>/01onW`>/2o`00
00?ooooo00?o0000ooooooooool0Coooool3o`000003oh]BR?l0003oRe:800ooRe:800?o0000ojO0
jonW`>/00_nW`>/00ol0003oooooooooo`1>ooooo`03o`000?oooooo000000;o000000?oooooo`00
0?ooool00_ooool00ol0003oRe:8oh]BR002oh]BR004o`000?n;DXSoRe:8o`0000GoRe:800?o0000
ojO0jonW`>/01?nW`>/01?l0003oooooooooool0000gooooo`00;_ooool2o`0000GoYl3[0_l00005
ojO0j`03o`000?nW`>_oYl3[00SoYl3[1?mO<X800ol0003oYl3[ojO0j`04ojO0j`04o`000?oooooo
ooooooooo`;o00001_moBHD3o`0000;ooooo0ol000000ooooooo0000ooooo`05ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool00_ooool7o`0000;oRe:800?o0000oh]BR?l000000_l0
0002oh]BR003o`000?n;DXSoRe:800Co000000?oYl3[o`000?l000000ol00003ooooo`Ko0000Aooo
ool2oa0LV@?o@UK01on6M[T00on@S<_oZYW5ojZIa@07ojZIa@[o_j_60_oA`l`7ombm^P?ooN>DD?oo
ool00ol0003omjmcooN_L`07ooN_L`03o`000?og[g?omjmc00Comjmc00Go0000ooN_Loog[g?omjmc
o`000011ooooo`03o`000?oooooooooo01Kooooo0ol0000@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo000000;o0000
2_ooool01ol0003oRe:8oh]BR?n;DXSo0000oh]BR?l000002onW`>/01?l0003oooooooooool0001A
ooooo`06o`000?ooooooooooo`000?n;DXSo00003on;DXP01_l0003oYl3[ojO0jol0003oYl3[o`00
053ooooo0_l00005ooooo`04o`000?ooooooooooo`0000GoRe:800?o0000oh]BR?l000001On;DXP0
0ol0003oYl3[ojO0j`05ojO0j`03o`000?oooooo000003Oooooo000^ooooo`Go000000?oYl3[o`00
0?nW`>/01OnW`>/2o`0000WoYl3[1OmO<X800ol0003oYl3[ojO0j`05ojO0j`03o`000?oooooooooo
00;o00000omoBHD3o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00;o000000?oooooo`000?l000000_l000000on;DXSo0000o`000003o`00
00CoRe:80ol000000on;DXSo0000o`000002ojO0j`Co000000?oooooo`000?ooool01?ooool00ol0
003oooooooooo`18ooooo`;o41bI0om2E/06ohIf^@?oT8c;2?nZVLD:okn[aP?odL?<1OoL_KX01?ob
jL3ooN>DoogSU?omhiA@ooooo`03o`000?og[g?omjmc00Oomjmc00?o0000ooN_Loog[g<01Oog[g<0
1?l0003omjmcooN_Lol00011ooooo`03o`000?oooooooooo01;ooooo1?l00002ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03gooooo0_l0000=ooooo`07o`000?n;DXSoRe:8oh]BR?l0003oRe:8o`00000<ojO0j`;o
000000?oooooo`000?ooool0D?ooool01Ol0003oooooo`000?n;DXSo000000ooRe:800?o0000ojO0
jonW`>/00_nW`>/00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00001On;DXP00ol0003oRe:8o`000005oh]BR0;o00001onW`>/00ol0003oooooo`00000f
ooooo`00;_ooool00ol0003oooooooooo`02ooooo`go00001?nW`>/7oelbPP03o`000?nW`>_oYl3[
00KoYl3[1ol00003ooooo`?o00000oooool3o`0000;ooooo00Co0000oooooooooooooooo0_l0000e
ooooo`Go000000?oooooo`000?ooool00ol00003oh]BR003o`000?n;DXSoRe:800?o000000?oRe:8
o`000?l000001?l000001_nW`>_o0000ojO0jol0003oooooo`00053ooooo0_l@79T4od9F`0?oQWJi
1On@S</8ojZIa@Wo_j_61_oA`l`2ombm^P?ol^W000?ooN>Dooooooooool0Coooool00ol0003omjmc
ooN_L`07ooN_L`03o`000?og[g?omjmc00Komjmc00?o0000ooN_Lol00000@Oooool00ol0003ooooo
ooooo`0?ooooo`?o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo
00Go0000oh]BR?n;DXSoRe:8o`000002oh]BR003o`000?nW`>_oYl3[00_oYl3[0_l0001Aooooo`03
o`000?oooooo000000;oRe:800?o0000oh]BR?n;DXP02on;DXP00ol0003oYl3[ojO0j`02ojO0j`03
o`000?oooooooooo053ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000005oh]BR003
o`000?n;DXSo000000GoRe:80_l00008ojO0j`;o0000=_ooool002kooooo00?o0000ooooooooool0
0_l00005ooooo`;o00000_ooool01?l0003oooooooooooooool3o`0000SoGc:200?o0000ojO0jonW
`>/02?nW`>/3o`0000;ooooo0ol00003ooooo`?o00001_ooool3o`000003ooooool0003ooooo03Co
oooo0_l00004ooooo`?o000000?oRe:8o`000?n;DXP00_n;DXP3o`000004oh]BR?l0003oRe:8oh]B
R0?o00000_nW`>/2o`000006ojO0jol0003oYl3[o`000?oooooo0000D?ooool6od9F`003ohIf^On@
S<_oT8c;00GoT8c;1onZVLD9okn[aPOodL?<00Gog;fjoo;Y`?objL3ol^W0oogSU01Booooo`03o`00
0?og[g?omjmc00Komjmc00?o0000ooN_Loog[g<01oog[g<00ol0003omjmco`000010ooooo`03o`00
0?oooooooooo00_ooooo1?l00009ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
2oooool00ol0003oRe:8oh]BR003o`000003oh]BR?l0003oYl3[00_oYl3[0ol0001Booooo`;o0000
0_n;DXP00ol0003oRe:8oh]BR00;oh]BR003o`000?nW`>_oYl3[00;oYl3[00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000CoRe:81?l00005oh]BR003o`00
0?nW`>_o000000KoYl3[0ol0000fooooo`00;_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oGc:2oelbPP06oelbPP?o00002OnW
`>/4o`0000?ooooo0ol00006ooooo`Go00000_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00?ooooo00Ko0000ooooool0003oRe:8o`000?n;DXP2o`000005oh]BR?l0003oRe:8o`00
0?n;DXP00ol000000on;DXSo0000o`000003o`0000;oYl3[00Co0000ojO0jol0003o0000D?ooool0
0ol019;o@UK0od9F`003od9F`003ofEneon@S<_oT8c;00GoT8c;1onZVLD8okn[aPSodL?<1?objL00
0oomhiCoooooooooo`1@ooooo`03o`000?og[g?omjmc00Komjmc00?o0000ooN_Loog[g<02?og[g<2
o`00043ooooo00?o0000ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0:ooooo`Co00000_n;DXP00ol0003oRe:8o`000008ojO0j`Co00000_ooool0
0ol0003oooooooooo`1@ooooo`;o00000_n;DXP00ol0003oRe:8oh]BR00;oh]BR004o`000?nW`>_o
Yl3[ojO0j`;o0000Doooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Co00000_n;
DXP00ol0003oRe:8oh]BR004oh]BR004o`000?nW`>_oYl3[o`0000;oYl3[0ol00002ooooo`03o`00
0?oooooooooo03Cooooo000^ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oGc:2oelbPP06oelbPP03o`000?oooooooooo00_o00000_ooool3o`0000Kooooo1_l0
0002ooooo`03o`000?oooooo000003Kooooo00Ko0000ooooooooooooooooo`000?ooool5o`0000;o
Re:81Ol000001?n;DXSo0000oh]BR?n;DXP4o`000003ojO0jol0003oYl3[00Co0000DOooool00ol0
19;o@UK0od9F`002od9F`0;oIGkG1on@S</3ojZIa@?oZJWF1Onh]]L3okn[aPOodL?<00?ognGIoo;Y
`?objL000_objL1Cooooo`;o00001oog[g<00ol0003omjmcooN_L`09ooN_L`03o`000?oooooooooo
03kooooo00?o0000ooooooooool01Oooool3o`00013ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`06ooooo`Co00001_n;DXP00ol0003oRe:8o`000004ojO0j`?o00001_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooo000000?o00002on;DXP00ol0003oooooo`000002o`00
0003ooooool0003ooooo05;ooooo00?o0000ooooooooool00oooool3o`0000KoRe:80_l00005oh]B
R003o`000?nW`>_o000000?o00001Oooool00ol0003oooooooooo`0dooooo`00;_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0ol00004ooooo`03o`000?mO<X;oGc:200Ko
Gc:200?o0000ooooooooool02?ooool5o`0000Oooooo1Ol00006ooooo`;o0000=_ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000oh]BR?l000001_l00003oh]BR003o`000?n;DXSoRe:8
00?o000000?oYl3[o`000?l000000ol000000ooooooo0000ooooo`1Aooooo`03o`04T_m2E/3o@UK0
00CoIGkG1On@S</00onHXM_oZJWFojVYeP04ojVYePOo^;KG0_o4am`5om73c0?ognGI0oobjL1Doooo
o`03o`000?og[g?omjmc00Gomjmc00?o0000ooN_Loog[g<02Oog[g<00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00;ooooo1?l0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00?o0000oh]BR?n;DXP01?n;DXP00ol0003oRe:8o`000004o`00
00Wooooo00?o0000ooooooooool0DOooool2o`0000;oRe:800?o0000oh]BR?n;DXP02On;DXP01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool00ol00000
0ooooooo0000o`000006oh]BR003o`000?n;DXSo000000CoRe:80_l00002ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0=?ooool002kooooo00Co0000oooooooooooooooo0_l00006
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?mO<X801omO<X800ol0003ooooooooo
o`08ooooo`;o000000?oooooo`000?ooool01?ooool5o`0000Wooooo0_l0000gooooo`03o`000?oo
oooo000000?ooooo1_l00003oh]BR004o`000?n;DXSoRe:8o`0000;oRe:81Ol000001_oooooo0000
ooooool0003oooooo`0005;ooooo0_l019800om2E/3oIGkGofEne`03ofEne`03oi2<bonHXM_oV:7K
00?oV:7K1OnYZMH7okRfe`?oa<OL0ooA`l`4omoUf@;ol^W0EOooool00ol0003omjmcooN_L`05ooN_
L`03o`000?og[g?omjmc00Womjmc00?o0000ooooooooool0?Oooool00ol0003oooooo`000002o`00
01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03o`0000Kooooo00?o0000oh]B
R?n;DXP01On;DXP2o`0000gooooo00?o0000ooooooooool0DOooool2o`0000?oRe:800?o0000oh]B
R?n;DXP01on;DXP01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0D_ooool2
o`0000Gooooo00?o0000oh]BR?n;DXP01?n;DXP00ol0003oRe:8o`000004oh]BR005o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0dooooo`00;_ooool01?l0003oooooooooool0
0006ooooo`;o00001_ooool3o`0000SoGc:200?o0000ooooooooool02?ooool4o`0000;ooooo1Ol0
0009ooooo`?o0000>Oooool00ol0003oooooo`000004o`000003oh]BR?l0003oRe:800KoRe:800?o
0000oh]BR?l000000_n;DXP00ol0003oooooo`000002o`000004ooooool0003oooooooooo`;o0000
Doooool00ol019;o3fOKo`mWf`04ofEne`;oOikV1OnHXM/4ojVYePKo^;KG1Oo4am`00ooA`lcognGI
omoUf@03omoUf@03oo;Y`?oooooooooo05Gooooo00?o0000ooN_Loog[g<01?og[g<00ol0003omjmc
ooN_L`09ooN_L`03o`000?oooooooooo03gooooo0_l0000Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo
0_l00008ooooo`03o`000?n;DXSoRe:800KoRe:800?o0000oh]BR?l000002_ooool3o`0005Cooooo
0_l00003oh]BR003o`000?n;DXSoRe:800KoRe:800Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo00Cooooo0_l00005oh]BR004o`000?n;DXSoRe:8o`00
00?oRe:800Go0000ooooooooooooooooo`000004ooooo`?o0000=_ooool002gooooo00Co0000oooo
ool0003o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00001_mO<X80
0ol0003oooooooooo`08ooooo`So00002Oooool3o`0003gooooo0_l00002ooooo`04o`000?n;DXSo
Re:8o`0000OoRe:80_l00003oh]BR007o`000?oooooo0000o`000?oooooo0000ooooo`04o`0005Co
oooo00?o00BBo`mWfol?Im/00omUO]L3ognNiPCoV:7K1?nYZMH5okRfe`Goa<OL00?obMcWomoUfOoO
iMT00ooOiMT00oo1o]Soooooooooo`1Gooooo`03o`000?og[g?omjmc00?omjmc00?o0000ooN_Loog
[g<02Oog[g<00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`07ooooo`03o`000?n;DXSoRe:800GoRe:81?l00006ooooo`Co
00000_ooool00ol0003oooooooooo`1Cooooo`05o`000?n;DXSoRe:8oh]BR?l000001on;DXP01_l0
003ooooooooooooooooo0000ooooo`?o0000EOooool00ol0003oooooooooo`03ooooo`;o00001On;
DXP00ol0003oRe:8o`000002o`0000;oRe:800Ko0000ooooooooooooooooo`000?ooool3o`0000;o
oooo00?o0000ooooooooool0=?ooool002gooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo
00Co0000oelbP_mO<X;o00001OmO<X800ol0003oooooooooo`08ooooo`Go00002Oooool3o`00043o
oooo00Go0000ooooooooooooooooo`000002oh]BR003o`000?n;DXSoRe:800CoRe:80ol00003oh]B
R003o`000?oooooo000000Go00000_ooool00ol0003oooooooooo`1Booooo`04o`04T_l?Im_o3fOK
o`mWf`;oIGkG1?moW^H4oiRQf`?oZJWF1?nh]]L4olC7g0CobMcW0_oOiMT3ol7nf5Wooooo00?o0000
ooN_Loog[g<00oog[g<00ol0003omjmcooN_L`09ooN_L`03o`000?oooooooooo043ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00Co0000
oh]BR?n;DXSoRe:81?l00003oh]BR0;o00000_ooool3o`0000Kooooo00?o0000ooooooooool0Dooo
ool2o`0000;oRe:80_l00005oh]BR003o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oRe:8o`000002oh]BR0Co00000_n;
DXP00ol0003oRe:8oh]BR006o`0000Gooooo00?o0000ooooooooool0=?ooool002gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
oelbP_mO<X800ol00003oelbPP03o`000?oooooooooo00Sooooo1?l00008ooooo`;o0000A?ooool0
1?l0003oooooooooool00002oh]BR004o`000?n;DXSoRe:8oh]BR0?o00000on;DXP00ol0003oRe:8
oh]BR006o`0000;ooooo00?o0000ooooool00000EOooool4o`mWf`KoOikV0_nHXM/01?nN^^coYKcZ
ojFlj_nU_>X3ojc2jP?o[lS]00?oa<OLolWLioo9g>L00oo9g>L01?oOiMWo`OkHol7nf?o1o]QKoooo
o`03o`000?og[g?omjmc00;omjmc00?o0000ooN_Loog[g<02Oog[g<00ol0003oooooooooo`11oooo
o`;o00005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo1Ol00008oh]B
R0?o00002?ooool00ol0003oooooooooo`1Eooooo`?o00000_n;DXP00ol0003oRe:8oh]BR002oh]B
R003o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000oh]BR?l000000_l00002oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000
oh]BR?l000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000]oooo
o`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00001_ooool00ol0003oGc:2o`000003oelb
PPCo00002_ooool4o`0000Gooooo0ol00017ooooo`05o`000?oooooo0000oooooon;DXP01?l00007
oh]BR00:o`000?n;DXSo0000ooooool0003oooooo`000?oooooo0000ooooo`;o0000Eoooool3o`mW
f`?oGIkc0omoW^H2oiJjl0;oW[[/0_nU_>X3ojc2jP;o[lS]00?o[loaolWLioo9g>L00oo9g>L01?nk
koCo`OkHol7nf?o1o]QMooooo`05o`000?og[g?omjmcooN_Lol000002oog[g<00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`05o`000?ooooooooooooooool00000@oooool00ol0003oooooooooo`05o`0000goRe:8
00?o0000ooooooooool01Oooool3o`0005Sooooo00?o0000oh]BR?n;DXP00_n;DXP01?l0003oRe:8
oh]BR?l00005ooooo`04o`000?ooooooooooo`0005Sooooo00?o0000ooooooooool00ol00002oh]B
R004o`000?n;DXSoRe:8o`0000GoRe:80_l00003ooooo`04o`000?ooooooooooooooo`?o0000=ooo
ool002gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo0_l0
0006oelbPP?o00002Oooool4o`0000;ooooo0ol0001:ooooo`;o000000Coooooo`000?l0003o0000
2on;DXP2o`000005ooooool0003oooooo`000?ooool01?l0001Iooooo`;o3fOK1OmMW_<4oiJjl005
oijjk?nU_>[o[<;Zojc2j_n_b>d00on_co42olWLi`Co^nod00?o`OkHooooooooool0G_ooool01?l0
003omjmcooN_Lol0000:ooN_L`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00
0014ooooo`;o00001?ooool00ol0003oRe:8oh]BR00:oh]BR0Co000000?oooooo`000?l000000_l0
0002ooooo`03o`000?oooooooooo05Oooooo00?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8o`00
0004ooooo`03o`000?oooooo000000;o0000FOooool2o`000003ooooool0003oRe:800?oRe:800?o
0000oh]BR?l000001?n;DXP4o`000003ooooool0003ooooo00?o00000_ooool00ol0003ooooooooo
o`0eooooo`00;Oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Gooooo0ol0
0005oelbPP;o00000oooool3o`0000Kooooo00?o0000ooooool000000ol0001>ooooo`;o000000?o
ooooo`000?l000002_n;DXP4o`000003ooooool0003o000000;o000000?oooooo`000?ooool0Fooo
ool5oefNl`CoS[gf0_nF^_000on/`^[o[loaojo?l@03ojWDmPGo^nodHoooool00ol0003omjmco`00
000:ooN_L`03o`000?oooooooooo04Kooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06Oooool01?l0003oooooooooool00015ooooo`05o`000?ooooooooooooooool0
00002On;DXP4o`0000;ooooo0ol00003ooooo`?o0000Foooool00ol0003oRe:8oh]BR003o`0000Go
oooo0_l00002ooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo00001On;DXP2o`00
0004oh]BR?l0003o0000o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03Kooooo000]oooo
o`;o00001oooool2o`0000Oooooo00Co0000oooooooooooo00000omO<X82o`0000Oooooo0ol00004
ooooo`Co0000D?ooool01?l0003oooooooooool00008oh]BR0?o000000?oooooo`000?l000001ol0
001Oooooo`Go=j;d0on:`oX00on<bogoU=;moiCBo@02oioFn`;oZMCf0_nkko@00on:jO;ooooooooo
o`1Tooooo`;o00002_og[g<00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0004Gooooo
00Co0000oooooooooooo00001?n;DXP6o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001?l0001Nooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
05_ooooo00?o0000ooooool000001?n;DXP4o`0000;ooooo0ol00003ooooo`03o`000?oooooooooo
00?o0000>Oooool002gooooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`04
o`000?mO<X;oGc:2o`0000Oooooo0_l00003ooooo`?o000000Goooooo`000?ooooooooooo`00001A
ooooo`03o`000?oooooo000000CoRe:81?l00002ooooo`;o00000_ooool6o`0006?ooooo0olgX_@0
0on:`o[oS<_mohc;o@03oiCBo@04oioFnon:jO;oR^Wbocl006Wooooo00?o0000ooN_Loog[g<01oog
[g<00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooo000004Kooooo00?o0000ooooool000001?l0
0005ooooo`;o00000_ooool4o`000004ooooool0003o0000o`00067ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?oooooo0000o`0005gooooo0_l000001?n;DXSo0000o`000?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo1Ol0000kooooo`00<_ooool7o`0000?ooooo00?o0000
ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000
ooooooooool0D?ooool2o`000006oh]BR?l0003o0000o`000?oooooo00000_ooool6o`0000;ooooo
0ol0001Xooooo`;o::_U0om:b>A^ooooo`03o`000?og[g?omjmc00Gomjmc00?o0000ooooooooool0
C?ooool2o`0000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`;o0000
Aoooool2o`0000Sooooo1Ol000000ooooooo0000o`000002o`0006Gooooo00?o0000ooooooooool0
1Ol0001Pooooo`;o00001oooool2o`000003ooooool0003o000000Co0000?_ooool003Wooooo3_l0
0003ooooo`;o00001_ooool2o`0000?ooooo0ol0001Cooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`?o000000?oooooo`000?l000000_l0003Oooooo`03o`000?og[g?o000000?omjmc00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07_ooool3o`0004Wooooo00?o0000ooooooooool01?ooool3o`000004ooooool0
003o0000o`0006[ooooo1Ol0001Tooooo`;o00000oooool8o`00047ooooo0017ooooo`Oo00000ooo
ool00ol0003oooooooooo`03ooooo`?o0000EOooool3o`000003ooooool0003o000000Go0000i?oo
ool5o`0005?ooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_oo
ool4o`0004gooooo00?o0000ooooooooool01ol0003Hooooo`Ko0000A_ooool004kooooo2_l0001I
ooooo`Go0000oooooom3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`Co0000D_ooool5o`000?oooooo:Oooool00?oooooon_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool4o`00
0?ooooooQ?ooool00?oooooonoooool2o`0000Kooooo00Go0000ooooooooooooooooo`00000Boooo
o`Co0000oooooon8ooooo`00ooooooomooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00003_ooool5o`000?ooooooS?ooool00?ooooooo_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000[ooooo1?l0003ooooooi7ooooo003ooooooooooooo0_l00002ooooo`03
o`000?oooooo000000Oooooo1?l0003ooooooiGooooo003ooooooooooooo0_ooool01Ol0003ooooo
o`000?oooooo000000?ooooo1?l0003ooooooiWooooo003ooooooooooooo0oooool7o`000?oooooo
WOooool00?ooooooooooool4ooooo`;o0000oooooonQooooo`00ooooooooooooooooooooYoooool0
0?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00@_ooool3o`0006?ooooo
0ol0003`ooooo`?o0000H_ooool3o`000?ooooooB_ooool3o`0005Gooooo0013ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0l?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo0?ooooooB_ooool00ol0003oooooooooo`1Dooooo`008oooool3o`000007ooooool0003o
0000o`000?oooooo0000ooooo`02o`000009ooooool0003o0000o`000?oooooo0000ooooool0003o
oooo00;o000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
00?o0000ooooool000001?l000001?oooooo0000o`000?ooool3o`0000Cooooo2?l00002ooooo`04
o`000?oooooo0000ooooo`Go0000<?ooool3o`000003ooooool0003o000000Co00000_ooool3o`00
00;ooooo00Go0000ooooool0003o0000ooooo`02o`0000;ooooo1Ol000001?oooooo0000o`000?oo
ool6o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l00015ooooo`Go00000ooo
ool?o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l00015ooooo`Go00000ooo
ool2o`0000;ooooo0ol000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0003o
00000oooool3o`000003ooooool0003o000000Co00000_ooool01Ol0003oooooooooool0003ooooo
00;o00000_ooool2o`00037ooooo1Ol00003ooooo`;o00000_ooool3o`000005ooooool0003ooooo
o`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`;o00000_ooool3o`0000Cooooo
0ol000001?oooooo0000o`000?l00002ooooo`;o0000;Oooool5o`0000;ooooo0ol00002ooooo`?o
00000oooool3o`0000;ooooo00Go0000ooooool0003o0000ooooo`02o`0000;ooooo0ol00002oooo
o`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002
ooooo`03o`000?oooooo000000Co0000=?ooool5o`0000;ooooo0ol00002ooooo`?o00000oooool3
o`0000;ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooooooool2o`000004oooo
ool0003o0000ooooo`So000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`0003Go
oooo0ol00003ooooo`?o00000_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003o0000
o`0000;ooooo0ol00003ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo0000o`000008
o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l0000]ooooo`009?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool02?l0
003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooo000000Gooooo00Co0000oooooooooooo00001?ooool01ol0003oooooo`000?oooooo0000
ooooool000001?ooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000004ooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000003ooooo`;o00001?ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo04?ooooo00Wo0000ooooooooooooooooo`00
0?oooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo04?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo037ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`03o`000?oooooooooo00;o0000<?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`;o000000Woooooo`000?ooooooooooo`000?oooooo0000oooo
ool000001?ooool01?l0003oooooooooooooool2o`0000Cooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo037ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooo0000ooooool000000_ooool0
1Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool2o`0000Cooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`0Zooooo`009?ooool5o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000?o
oooo00?o0000ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_oo
ool00ol0003oooooo`000004ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`;o0000
0_ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l0000aooooo`Go00000_ooool2o`0000;o
oooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool01?l000001ooooooo0000oooo
oooooooo0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`Co000000Coooooo`000?oo
oooo00000_ooool2o`0004Kooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1?l000001?oooooo0000oooo
ool00002ooooo`;o0000A_ooool01_l0003ooooooooooooooooo0000ooooo`Co000000?oooooo`00
0?l000000_ooool01Ol0003oooooo`000?oooooo000000Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0ol000000ooooooo0000ooooo`0booooo`06o`000?ooooooooooooooool0003ooooo1?l000000ooo
oooo0000o`000002ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
o`000003o`000004ooooool0003oooooo`0000Oooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`05o`0002gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00Kooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000004ooooo`;o
00000_ooool01?l0003oooooo`000?ooool4o`000003ooooool0003ooooo00?ooooo1?l000001?oo
oooo0000ooooool00002ooooo`;o0000=Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000001_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000002oooo
o`04o`000?oooooo0000ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Cooooo1?l0
00001?oooooo0000ooooool00002ooooo`;o0000<oooool00ol0003oooooooooo`04ooooo`0;o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003ooooooooo
o`02o`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`Co000000Coooooo`000?oooooo00000_ooool2
o`0002gooooo000Uooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000oooool02_l0
003oooooooooool0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooo000000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
1?ooool01ol0003oooooo`000?oooooo0000ooooool00000=?ooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00001?ooool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00018ooooo`Co0000
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00[o0000oooo
oooooooo0000ooooool0003oooooo`000?oooooo0000B?ooool4o`0000;ooooo00Co0000oooooooo
oooo00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000oooool2o`0000?ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`00000cooooo`Co00000_ooool01?l0003oooooooooool0
0002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003ooooo`;o00000oooool01_l0
003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
o`000002ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`0[ooooo`Co00000oooool00ol0003o
ooooo`000006ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool00000
0_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0
003oooooo`000004ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0003Oo
oooo1?l00003ooooo`03o`000?oooooo000000Kooooo00Wo0000ooooooooooooooooo`000?oooooo
0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00[o0000oooooooooooo0000ooooool0003o
ooooo`000?oooooo0000=Oooool00ol0003oooooooooo`04ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go
0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003o
ooooooooool00004ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0002oo
oooo000Uooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`;o00000_ooool5o`0000?ooooo
0ol000000ooooooo0000o`000005o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`000006oooo
ool0003oooooooooool0003ooooo1Ol00002ooooo`So00000oooool3o`00037ooooo00?o0000oooo
ool000000oooool7o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00002oooo
o`?o000000?oooooo`000?ooool01?ooool2o`000004ooooool0003o0000o`0000?ooooo0ol00015
ooooo`06o`000?ooooooooooooooool0003ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000o`0000?ooooo0ol00015oooo
o`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003o000000;ooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`05o`000?oooooo0000o`000?ooool01_l0
00001?oooooo0000o`000?ooool3o`0003;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
000000?oooooo`000?l000000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool4o`0000;o
oooo00Go0000ooooool0003o0000ooooo`06o`000004ooooool0003o0000ooooo`Co00001_ooool2
o`000004ooooool0003oooooooooo`?o00000_ooool2o`0002kooooo00Ko0000oooooooooooooooo
o`000?ooool2o`000003ooooool0003ooooo00Kooooo0ol000001?oooooo0000o`000?l00003oooo
o`Go00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`03
ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0003Cooooo00Ko0000oooooooooooooooo
o`000?ooool2o`000003ooooool0003ooooo00Kooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003ooooo00Cooooo0_l000001?oooooo0000o`000?l00003ooooo`?o0000<_ooool00ol0003ooooo
ooooo`05ooooo`?o000000?oooooo`000?l000000ol00002ooooo`Co00000_ooool3o`000006oooo
ool0003o0000ooooool0003ooooo0ol00003ooooo`?o00000_ooool00ol0003oooooooooo`03oooo
o`;o000000Coooooo`000?l0003o00000oooool3o`0002cooooo000Uooooo`03o`000?oooooo0000
023ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00017ooooo`03o`000?oooooo
000000cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Dooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo05Cooooo
00Go0000ooooooooooooooooo`00000Aooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000jooooo`05o`000?ooooooooooooooool000004Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool0<_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_l0000Mooooo`03o`000?oooooooooo
04?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;o00006_ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;o00009?ooool01?l0003oooooooooool0
000mooooo`009_ooool00ol0003oooooooooo`0Nooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`Co00001_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00[ooooo0_l0000;
ooooo`03o`000?oooooooooo00?ooooo0ol0001Dooooo`Go00001_ooool2o`000004ooooool0003o
0000ooooo`?o0000E?ooool5o`0001?ooooo0ol00006ooooo`;o00000_ooool00ol0003ooooooooo
o`0mooooo`Go00004oooool3o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00kooooo0_l0
00000ooooooo0000ooooo`05ooooo`;o0000<oooool5o`0000?ooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000ooooo`0Kooooo`?o0000@oooool5o`0000?ooooo00Co0000oooooooooooo
oooo0_l000000ooooooo0000ooooo`0Hooooo`?o0000A?ooool2o`000003ooooool0003ooooo02;o
oooo0_l000001?oooooo0000o`000?l0000looooo`00ooooooooooooooooooooYoooool00?oooooo
ooooooooooooojOooooo003ooooooooooooooooooonWooooo`00ooooooooooooooooooooYoooool0
0?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooooooooooooooooooo
Yoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooooooooooo
ooooooooYoooool00?ooooooooooooooooooojOooooo003ooooooooooooooooooonWooooo`00oooo
ooooooooooooooooYoooool00?ooooooooooooooooooojOooooo0000\
\>"],
  ImageRangeCache->{{{0, 931}, {511.125, 0}} -> {-0.205577, -0.109969, \
0.00903451, 0.00903451}, {{22.75, 124.5}, {498.938, 408.75}} -> {-0.419684, \
-0.150607, 0.0123571, 0.0123571}, {{134.688, 236.438}, {498.938, 408.75}} -> \
{-1.79265, -0.148845, 0.0122126, 0.0122126}, {{246.625, 348.438}, {498.938, \
408.75}} -> {-3.23068, -0.151704, 0.0124471, 0.0124471}, {{358.625, 460.375}, \
{498.938, 408.75}} -> {-4.61955, -0.151558, 0.0124351, 0.0124351}, {{470.562, \
572.312}, {498.938, 408.75}} -> {-5.89496, -0.148865, 0.0122142, 0.0122142}, \
{{582.5, 684.312}, {498.938, 408.75}} -> {-7.26105, -0.148837, 0.0122119, \
0.0122119}, {{694.5, 796.25}, {498.938, 408.75}} -> {-8.72116, -0.150328, \
0.0123342, 0.0123342}, {{806.438, 908.188}, {498.938, 408.75}} -> {-8.37157, \
-0.125797, 0.0103218, 0.0103218}, {{22.75, 124.5}, {399.75, 309.625}} -> \
{-0.458888, -1.42497, 0.0128422, 0.0128422}, {{134.688, 236.438}, {399.75, \
309.625}} -> {-1.8429, -1.39021, 0.0124822, 0.0124822}, {{246.625, 348.438}, \
{399.75, 309.625}} -> {-3.11728, -1.34562, 0.0120818, 0.0120818}, {{358.625, \
460.375}, {399.75, 309.625}} -> {-4.38869, -1.32064, 0.0118575, 0.0118575}, \
{{470.562, 572.312}, {399.75, 309.625}} -> {-5.80729, -1.34237, 0.0120527, \
0.0120527}, {{582.5, 684.312}, {399.75, 309.625}} -> {-7.45793, -1.39472, \
0.0125227, 0.0125227}, {{694.5, 796.25}, {399.75, 309.625}} -> {-6.79945, \
-0.998399, 0.00979041, 0.00979041}, {{806.438, 908.188}, {399.75, 309.625}} -> \
{-9.13503, -1.21306, 0.011236, 0.011236}, {{22.75, 124.5}, {300.625, \
210.438}} -> {-0.417378, -2.55362, 0.0121312, 0.0121312}, {{134.688, \
236.438}, {300.625, 210.438}} -> {-1.86309, -2.65416, 0.0126088, 0.0126088}, \
{{246.625, 348.438}, {300.625, 210.438}} -> {-3.15218, -2.56545, 0.0121874, \
0.0121874}, {{358.625, 460.375}, {300.625, 210.438}} -> {-4.57538, -2.59483, \
0.0123269, 0.0123269}, {{470.562, 572.312}, {300.625, 210.438}} -> {-5.69777, \
-2.48942, 0.0118262, 0.0118262}, {{582.5, 684.312}, {300.625, 210.438}} -> \
{-6.98658, -2.47993, 0.0117811, 0.0117811}, {{694.5, 796.25}, {300.625, \
210.438}} -> {-8.72872, -2.59852, 0.0123445, 0.0123445}, {{806.438, 908.188}, \
{300.625, 210.438}} -> {-10.214, -2.6241, 0.012466, 0.012466}, {{22.75, \
124.5}, {201.438, 111.312}} -> {-0.422907, -3.77338, 0.0121845, 0.0121845}, \
{{134.688, 236.438}, {201.438, 111.312}} -> {-1.82363, -3.83202, 0.0123738, \
0.0123738}, {{246.625, 348.438}, {201.438, 111.312}} -> {-2.32938, -2.84527, \
0.0095552, 0.0095552}, {{358.625, 460.375}, {201.438, 111.312}} -> {-3.38151, \
-2.83047, 0.00951727, 0.00951727}, {{470.562, 572.312}, {201.438, 111.312}} -> \
{-4.59383, -2.93131, 0.00976241, 0.00976241}, {{582.5, 684.312}, {201.438, \
111.312}} -> {-7.2682, -3.78512, 0.0122224, 0.0122224}, {{694.5, 796.25}, \
{201.438, 111.312}} -> {-8.93317, -3.90923, 0.0126231, 0.0126231}, {{806.438, \
908.188}, {201.438, 111.312}} -> {-10.1741, -3.84595, 0.0124188, 0.0124188}, \
{{22.75, 124.5}, {102.312, 12.125}} -> {-0.339409, -4.56305, 0.0112371, \
0.0112371}, {{134.688, 236.438}, {102.312, 12.125}} -> {-1.78846, -4.98522, \
0.0121944, 0.0121944}, {{246.625, 348.438}, {102.312, 12.125}} -> {-3.10579, \
-4.92341, 0.0120432, 0.0120432}, {{358.625, 460.375}, {102.312, 12.125}} -> \
{-4.70809, -5.17689, 0.0126632, 0.0126632}, {{470.562, 572.312}, {102.312, \
12.125}} -> {-5.81743, -4.93524, 0.0120721, 0.0120721}, {{582.5, 684.312}, \
{102.312, 12.125}} -> {-7.40278, -5.08309, 0.0124338, 0.0124338}, {{694.5, \
796.25}, {102.312, 12.125}} -> {-8.74375, -5.05478, 0.0123645, 0.0123645}, \
{{806.438, 908.188}, {102.312, 12.125}} -> {-10.2262, -5.10197, 0.01248, \
0.01248}}]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{1470, 986},
WindowMargins->{{Automatic, 48}, {Automatic, 6}},
ShowCellTags->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 267, 7, 72, "Input"],
Cell[2046, 62, 712, 11, 75, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2795, 78, 43, 0, 27, "Input"],
Cell[2841, 80, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2914, 86, 304, 9, 132, "Input"],
Cell[3221, 97, 182, 4, 23, "Print"],
Cell[3406, 103, 174, 4, 23, "Print"],
Cell[3583, 109, 164, 3, 23, "Print"],
Cell[3750, 114, 174, 4, 23, "Print"],
Cell[3927, 120, 182, 4, 23, "Print"],
Cell[4112, 126, 176, 4, 23, "Print"],
Cell[4291, 132, 174, 4, 23, "Print"],
Cell[4468, 138, 174, 4, 23, "Print"],
Cell[4645, 144, 174, 4, 23, "Print"],
Cell[4822, 150, 269, 6, 23, "Print"],
Cell[5094, 158, 296, 6, 23, "Print"],
Cell[5393, 166, 182, 4, 23, "Print"],
Cell[5578, 172, 186, 4, 23, "Print"],
Cell[5767, 178, 168, 3, 23, "Print"],
Cell[5938, 183, 176, 4, 23, "Print"],
Cell[6117, 189, 184, 4, 23, "Print"],
Cell[6304, 195, 184, 4, 23, "Print"],
Cell[6491, 201, 174, 4, 23, "Print"],
Cell[6668, 207, 174, 4, 23, "Print"],
Cell[6845, 213, 182, 4, 23, "Print"],
Cell[7030, 219, 162, 3, 23, "Print"],
Cell[7195, 224, 182, 4, 23, "Print"],
Cell[7380, 230, 269, 6, 23, "Print"],
Cell[7652, 238, 296, 6, 23, "Print"],
Cell[7951, 246, 174, 4, 23, "Print"],
Cell[8128, 252, 177, 4, 23, "Print"],
Cell[8308, 258, 206, 4, 23, "Print"],
Cell[8517, 264, 184, 4, 23, "Print"],
Cell[8704, 270, 204, 4, 23, "Print"],
Cell[8911, 276, 182, 4, 23, "Print"],
Cell[9096, 282, 204, 4, 23, "Print"],
Cell[9303, 288, 177, 4, 23, "Print"],
Cell[9483, 294, 160, 3, 23, "Print"],
Cell[9646, 299, 184, 4, 23, "Print"],
Cell[9833, 305, 180, 4, 23, "Print"],
Cell[10016, 311, 178, 4, 23, "Print"],
Cell[10197, 317, 168, 3, 23, "Print"],
Cell[10368, 322, 182, 4, 23, "Print"],
Cell[10553, 328, 178, 4, 23, "Print"],
Cell[10734, 334, 182, 4, 23, "Print"],
Cell[10919, 340, 258, 5, 23, "Print"],
Cell[11180, 347, 292, 6, 23, "Print"],
Cell[11475, 355, 186, 4, 23, "Print"],
Cell[11664, 361, 177, 4, 23, "Print"],
Cell[11844, 367, 162, 3, 23, "Print"],
Cell[12009, 372, 712491, 27031, 521, 415337, 23356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

