(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1159784,      19923]
NotebookOptionsPosition[   1157809,      19852]
NotebookOutlinePosition[   1158425,      19877]
CellTagsIndexPosition[   1158336,      19872]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["?SurfaceFit", "Input",
 CellChangeTimes->{{3.609793955415214*^9, 3.6097939575126266`*^9}}],

Cell[BoxData[
 StyleBox["\<\"SurfaceFit[surfacesamples, height, partitions, options] \
creates an optical surface that with a surface shape the is fitted to the \
surfacesamples data. \\n\\nSurfaceFit calls the SegmentFit function \
internally to create piecewise continuous segments of the overall surface \
area. Each segment is based on third order polynomial function and SurfaceFit \
uses SegmentFit function to create each segment. The number of segments \
present is determined by the partitions parameter. The surface shape remains \
constant along vertical dimension. The height parameter determines the \
vertical dimension of the surface aperture. The horizontal dimension is \
matches the spatial range of the surfacesample data.  SurfaceFit uses the \
Component option with CubicMirror and CubicLensSurface to determine whether a \
reflective or refractive surface is generated.\\n\\nSee also: SegmentFit, \
CubicMirror, and CubicLensSurface.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614710540582152*^9},
 CellTags->"Info3614692540-3788911"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceFit", "Input"],

Cell[BoxData["SurfaceFit"], "Output",
 CellChangeTimes->{3.614710540841104*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Random", "Input",
 CellChangeTimes->{{3.609794857190175*^9, 3.609794857436467*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Random\\\", \\\"[\\\", \\\"]\\\"}]\) gives \
a uniformly distributed pseudorandom Real in the range 0 to 1. \
\\n\!\(\*RowBox[{\\\"Random\\\", \\\"[\\\", RowBox[{StyleBox[\\\"type\\\", \\\
\"TI\\\"], \\\",\\\", StyleBox[\\\"range\\\", \\\"TI\\\"]}], \\\"]\\\"}]\) \
gives a pseudorandom number of the specified type, lying in the specified \
range. Possible types are: Integer, Real and Complex. The default range is 0 \
to 1. You can give the range \!\(\*RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"min\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"max\\\", \
\\\"TI\\\"]}], \\\"}\\\"}]\) explicitly; a range specification of \
\!\(\*StyleBox[\\\"max\\\", \\\"TI\\\"]\) is equivalent to \
\!\(\*RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", StyleBox[\\\"max\\\", \
\\\"TI\\\"]}], \\\"}\\\"}]\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Random"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.614710541099176*^9},
 CellTags->"Info3614692540-3788911"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
surfacesamples = Table[{theta,4*Sin[theta]+0.2*Random[]},{theta,0,10,.2}]\
\>", "Input",
 CellChangeTimes->{{3.60979475697375*^9, 3.609794870730215*^9}, 
   3.60979494447108*^9, 3.609796344733452*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.055162954295453495`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2`", ",", "0.956300825691135`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", "1.5892581098799132`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6000000000000001`", ",", "2.3988225844314144`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8`", ",", "2.9163749978494375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "3.4468370036965523`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2000000000000002`", ",", "3.731697230661629`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4000000000000001`", ",", "4.02829287908907`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6`", ",", "4.0768141819714545`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.8`", ",", "3.930163839144601`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "3.7381568885272913`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.2`", ",", "3.3977504549073965`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.4000000000000004`", ",", "2.798747825412439`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.6`", ",", "2.222281162651099`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.8000000000000003`", ",", "1.3626123144190398`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", "0.6259164087099758`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.2`", ",", 
     RowBox[{"-", "0.0736645775977752`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.4000000000000004`", ",", 
     RowBox[{"-", "0.848973735758926`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.6`", ",", 
     RowBox[{"-", "1.6333526624096628`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.8000000000000003`", ",", 
     RowBox[{"-", "2.269129041449057`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", 
     RowBox[{"-", "2.9278298240363543`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.2`", ",", 
     RowBox[{"-", "3.4788822940217763`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.4`", ",", 
     RowBox[{"-", "3.644475299776881`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.6000000000000005`", ",", 
     RowBox[{"-", "3.9184641916879133`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.800000000000001`", ",", 
     RowBox[{"-", "3.9404412324434572`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", 
     RowBox[{"-", "3.7898998055308675`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.2`", ",", 
     RowBox[{"-", "3.403470367744741`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.4`", ",", 
     RowBox[{"-", "2.975010818229276`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.6000000000000005`", ",", 
     RowBox[{"-", "2.327799982840724`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.800000000000001`", ",", 
     RowBox[{"-", "1.6935644889983064`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.`", ",", 
     RowBox[{"-", "0.9908546244525547`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.2`", ",", 
     RowBox[{"-", "0.30280443841054216`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.4`", ",", "0.5849436182450997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.6000000000000005`", ",", "1.3762363670784141`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.800000000000001`", ",", "2.0022935916730202`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", "2.6937347281055635`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.2`", ",", "3.196523151031901`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.4`", ",", "3.764627620906165`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.6000000000000005`", ",", "3.8748591614491095`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.800000000000001`", ",", "3.9985253382583203`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.`", ",", "4.019452686016271`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.200000000000001`", ",", "3.959526792030347`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.4`", ",", "3.4848469949065377`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.6`", ",", "2.963637825934534`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.8`", ",", "2.5023083138944315`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.`", ",", "1.8376577106457064`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.200000000000001`", ",", "0.9960780231732167`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.4`", ",", "0.26885131340556667`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.600000000000001`", ",", 
     RowBox[{"-", "0.5788847854644461`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.8`", ",", 
     RowBox[{"-", "1.32253004045072`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", 
     RowBox[{"-", "2.001914331921118`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.609794810079488*^9, 3.609794871215846*^9}, 
   3.60979494492584*^9, 3.614710541243026*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ListPlot[surfacesamples]", "Input",
 CellChangeTimes->{{3.609794824262781*^9, 3.6097948261010303`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw10V1IU3EUAPC5zc259qH7aNVscxqakYiaZKn/ky9WhGUlFETLVQqmmD1I
NCOLVIReSrGUvghtLtQHwUlW7mqZOKdQKjEtlZmlDjKQuU0d1fqfHbhcLvec
3+GcE20oO3mZzWKxUv49gXcw7piONeVltZPmpkAMk4TCsiRu8y/8dpBzl0qX
mkp9JDUlEPNEeyJ+YTiJA/T/Ejmu2Ff89jQfqPab1MeV5GjqhUDzV0m7xim7
OyWCosJArJGPjb4xr1qK9T7yre/mhbZcKYzaA7FJwgzx73xXJeixoCO/0t73
U4T5IcDWn7c9TAz6HNiTqP8xeZGH9Vx4Mv78zMGhEOzHg9BF7/3sUTehXBhk
iBIdt/nfcT4BKNdMtZ3TXVbqCcHmGvLYElxW6m0Bf2xfYZpu3Uo9MTRcMWr3
xrEZ6knBtLwanlzCZ2i+FBZNxkxmQshQPwImvZWvnHEihtZHgmdQ3M85K2Fo
Pxk0ZtSJeDUS9ORQ7cvyW/LE6MkhbTWyPfdA0FOA45T9+mc7Hz0lJJevPMp/
xkZvK1S/mJF9UW1YqaeChpfz/fLuFZxHBW0tnJldBeNW6m2DI29GOqZ7nIR6
28HUOVAiDV3De+8Ax5i5qovLwnuowVIVPvLhXijuWw0Cy0TvjQcCvE8UpB8W
Kt1RYtz/TjiU6Y23/BHjvTSwoIep9c3gfbVQITAXuWRSzNfCe7JRoO6QoK+F
5VuKCs+cEP6Xp0RD+dPH1tpuPvaLhjlj6/5eLhc9HUxdqx0UFvlxHh10Gl5z
Z2dXCPV0cDSiJeZr6iecLwYGVD2G9Bon7iMGlMXGbMVuN+4vFurcOWYXh8X8
BTydVOk=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.},
  Method->{},
  PlotRange->{{0, 10.}, {-3.9404412324434572`, 4.0768141819714545`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.2, 0.2}, {0.16034510828829823`, 
   0.16034510828829823`}}]], "Output",
 CellChangeTimes->{
  3.609794826739152*^9, {3.609794865473906*^9, 3.609794873580667*^9}, 
   3.609794946708754*^9, 3.614710541304782*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["fittedsurface = SurfaceFit[surfacesamples,10,8]", "Input",
 CellChangeTimes->{{3.609794885214329*^9, 3.609794931415269*^9}, {
  3.609794985918391*^9, 3.609794989037047*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of Surface Partitions \"\>", "\[InvisibleSpace]", "8"}],
  
  SequenceForm["Number of Surface Partitions ", 8],
  Editable->False]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710541335629*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"endpoints \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "5", ",", "7", ",", "9", ",", "11", ",", "13", ",", 
     "15", ",", "17", ",", "19", ",", "21", ",", "23", ",", "25", ",", "27", 
     ",", "29", ",", "31", ",", "33", ",", "35", ",", "37", ",", "39", ",", 
     "41", ",", "43", ",", "45", ",", "47", ",", "49", ",", "51"}], "}"}]}],
  SequenceForm[
  "endpoints ", {1, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 
   33, 35, 37, 39, 41, 43, 45, 47, 49, 51}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710541337461*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"subsegments \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", "29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"29", ",", "31"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"31", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"33", ",", "35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"37", ",", "39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"39", ",", "41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"41", ",", "43"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"43", ",", "45"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"45", ",", "47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"47", ",", "49"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49", ",", "51"}], "}"}]}], "}"}]}],
  SequenceForm[
  "subsegments ", {{1, 3}, {3, 5}, {5, 7}, {7, 9}, {9, 11}, {11, 13}, {13, 
   15}, {15, 17}, {17, 19}, {19, 21}, {21, 23}, {23, 25}, {25, 27}, {27, 
   29}, {29, 31}, {31, 33}, {33, 35}, {35, 37}, {37, 39}, {39, 41}, {41, 
   43}, {43, 45}, {45, 47}, {47, 49}, {49, 51}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710541340507*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"segments \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "27"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"29", ",", "39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "45"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"41", ",", "51"}], "}"}]}], "}"}]}],
  SequenceForm[
  "segments ", {{1, 9}, {5, 15}, {11, 21}, {17, 27}, {23, 33}, {29, 39}, {35, 
   45}, {41, 51}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.61471054134415*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"domains \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25", ",", "31"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"31", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"37", ",", "43"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"43", ",", "51"}], "}"}]}], "}"}]}],
  SequenceForm[
  "domains ", {{1, 7}, {7, 13}, {13, 19}, {19, 25}, {25, 31}, {31, 37}, {37, 
   43}, {43, 51}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.6147105413478117`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    GraphicsComplexBox[{{0., 0.055162954295453495`}, {0.2, 
     0.956300825691135}, {0.4, 1.5892581098799132`}, {0.6000000000000001, 
     2.3988225844314144`}, {0.8, 2.9163749978494375`}, {1., 
     3.4468370036965523`}, {1.2000000000000002`, 3.731697230661629}, {
     1.4000000000000001`, 4.02829287908907}, {1.6, 
     4.0768141819714545`}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 
      0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVxX041AccAHAO0b38ao7oaV3OnUaEHNnK+X699KLzMjf2pBdWTtORQj20
rdAp9fRiNGoJpW5GKK/JQrXMRWrewh4cVzgvyd3P285o2x+f58M+eFQYRtHS
0vL5z/9Py1fZVQj2uAb/7MOTppeCI5WaeZd1HXbueWx+5o8GyG6d1gswL4Ab
NyXeGf2t0BlWIX5+rwxcdE/sUgZ0g62t/7uH+dXgzLgwLrvZD3MbDBMkFvVw
0oXSE12iAPdcqtDxxjNIBl46q2UI3D1YM+mKBghumo+krx+FcW8OO2fNC4hb
PYJRhyZg5oCX4ea1L8Hj6q7a6kMfwDlN26gm5DWYfsLNDfZTwWTYkSNhTq1g
4V+1RtqsBuMqobFneRuEnR032+YyDUHMpIbr/h1wsovmEdc4A76z0M3r6IQN
71vf5vPmIGR4B+kZ1wWPyyO6gx7Nw7YLMmGRYQ9Y94g87ztooLe0x2hP+l9w
oThuZfvlBUgd4clPOfSCV45/4nLtRSDzWHRlVR8UVB4XHP96CWIjhG6yvXKQ
WnHKZc8+gig2YX/CDwNgfR4Dd6dp4TCZ3cznD8LcPpZbr4M2zmoG+M6EAvSN
OWJCro1yz8jBr1oVEJIymEQ9RUEHJS8/68e3UCcvcvE01kGmoVk065t30PJU
t/vgQx1sOR0Q+Zw9BKXx0hXNAl00jimOkJJDAEVst5hRXWysc79c+nQYtqj/
uTqVqIdCX7OBgaQRyDfj9nrQlmGEyNxZIFRCQeR1iiZ7Ge6rjazvNhoFAT2H
08TRx+qj5OG09lEocGjwXbijj3m/5piezRuDN2fsDUqtDVDETZ/PCh2Hphpl
kHG+AVasL+x97zgBt1NsVu2wWo59EVT1wfkJoJl+Gh6buxyPUfOtdKrfw99x
tFHmSiqm2YWH9adMwnb38Ls/naPixWvRbb1eH6C402l1mYqK1N9fs2nEFKzj
+sdMHKCh7khyBP/EFORWFi6zeklDsU2/T1LnFDBMji49sKajSaVXmYKvAn13
CjMwlY72IUH3A3NV4EbipSwlHZecUvj9SyoQ6oez010YyPyy0Sf5kBqSfV2q
8q4yMOPivdmtjWoQLalq6YMMtNx+y4bHI0H1nZGYziPQwqdhyy+s83CM+3FX
VGYd9Culac6LapBHv8rNoxJo0L41uYAVD9wUTczGVdWwpcby+RcKNWSWlDMX
ZxgoMeGEOJmScPmGzvpFFoGv+i1NHrDCIbKeNdbaUQFKc3FfTYca3F54uF4Z
Z6B9oii+ikpC6N3DO3qMCHxTMritwoIE6WkjR8KKwKBZCr+WtRs6LlUWdPLK
wbWLKl5oUYPlnaU2v2EGpjjq6c3pkOBf6eH9ZAWBNqFn2qZZJGwuytA34BKY
oMFHsTYkrDVJLVxhS+Axi4fnu1g7QZY0SnqEloF4094HWU1q+GCf11fyloFl
VwIF17RIiJ/k0B0YBO6ubTPNWENC9kLIRgmbwMKAtI9MKxKaD7DPpVoTGHBr
KqbdjgSvBLh9xZ7AHMk6M/q6z8HwUpPjrKYUEoMl7eMyNdQVG5L7FQyU/XYq
amRJDZO6p78foxEYNabZOrSaBLv6AD80I/BJ0iNz0WckLJAvKX4bCBS3mGZy
bEn4880tgZ8dga6xMj/JJhLueH97r2UTgf8Cz/40uQ==
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], {{}, 
    GraphicsComplexBox[{{0.8, 2.9163749978494375`}, {1., 
     3.4468370036965523`}, {1.2000000000000002`, 3.731697230661629}, {
     1.4000000000000001`, 4.02829287908907}, {1.6, 4.0768141819714545`}, {1.8,
      3.930163839144601}, {2., 3.7381568885272913`}, {2.2, 
     3.3977504549073965`}, {2.4000000000000004`, 2.798747825412439}, {2.6, 
     2.222281162651099}, {2.8000000000000003`, 1.3626123144190398`}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVV3lcjGsUrobSNvOlFVGkUlpoL+q82tG+71HJLdGKihSTaENljRS5Qhuh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    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1FW4FlUAhtH/wEGlRKRDAenuVKSku0G6u0tAJJRSQZRulO6W7u5Uuru7
JNfIxZr32XMzF99+JlnDdpXahoVCoWgeQY8ylR58S2GyE4GIhBOJD/iQj4hM
FP5hGj2pRRFyEJV/mc731OYbcgbf5Rgz6EUdipKLSyxhMC2oSHSOM5MfqEsx
cnOZpfxMSyrxMSeYRW/qUZw8XGEZv9CKysTgJLPpQ31KcJs1/EFH8nKV5fxK
a56yjQlU4T4bGEVXPuEUc+hLAx6zhXGU5A5rGc5b9tOJF+xkcrCFoQ5pPq7x
d7CJd0P0DfuCTZzb6DO2B1s5T9QwPRhsolX1ARuDPZ1Hh0L/X4IDwZ7aTV+y
O9jZ+c/gDuhhjclp5tKP1+ylIU/YynhKcZd1jKAz/7GLKXzJdVYwlLY8ZweT
qMZDNjGG7/iUM8zjRxpRmnusZyRd+IobrOQ32lGdWJxlPj/RmDLk5yarGEZ7
ahCbcyygP00oy9fE4TwLGUBTylGAuFxgEQNpRnkKEo/4JCAhiUjMZ3xOEpKS
jC9ITgpSkorUpCEt6UhPBjKSicxkISsXWcwgmlOBQtxiNb/TgZo8YjNj6c4r
9vAX4bY/Enr/r8im7wDn1YGc
       "],
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDgARGjYBSMglEwCkbBKBgFVAYAd+UBuA==
     "]], {{}, 
    GraphicsComplexBox[{{2., 3.7381568885272913`}, {2.2, 
     3.3977504549073965`}, {2.4000000000000004`, 2.798747825412439}, {2.6, 
     2.222281162651099}, {2.8000000000000003`, 1.3626123144190398`}, {3., 
     0.6259164087099758}, {3.2, -0.0736645775977752}, {
     3.4000000000000004`, -0.848973735758926}, {3.6, -1.6333526624096628`}, {
     3.8000000000000003`, -2.269129041449057}, {
     4., -2.9278298240363543`}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVlH00lHkUxyczz6OeeappCylp8tKbxVSqWXb3uWXaqVRLxZQ1xyxREibl
qEgyR0kynJxRTJR1pEy7Y3cnkfxUjrJJqyQRpumFWpYyk3lM7D79cc89n3PP
vff7vX/cBWFxWyOsWCzWZia+5JoryatWrGBDx92B+5VROKwXhybLw9mg+i7U
Ju4ZBkdwP0VtPhsGkmuEz1diENaeEZR7nw39IS83eKs5UFob+FFuZsPsuioX
ZzYHMhvcfgz9mgNtxT7TdwWzYWH3tkPtIRzQjxiTk2qsINIuPSwklwMvBL/N
KSOsgLVnnc1gAwcE7r/EKH+aBP5NkjzcxAF1QmGc03UWiDYdaPNYggEv6nK0
ksWCf3v1+t6dGJjTp9W4XZ2gRk516wpPYbDYEqNJCBqnCgNf+UXewuC+JuuG
s8FC0ct8fq0exEDgKhXvVYxRFk9161wnHPYsGRltY9OURJR1KyMQB9mNonAs
Y5SKimpJSEnHoT/x2EJ750/UfK39UFo1DoLcMivvC0bqtHWVF+89Dv76nElD
HiNUYarUR+NoDULbE/EXiz9QGO8ssW2rNfQf890SajNMuWrnlKWlWQP/mqQy
WzxIvdtfYXX7ujVo5Y2qi07vqXBRtltGnzXwbDXjnoI+SujOmhdsNxn0QTcL
lm18TWlXJz3y9psMsodHOi1OL6mereu3lCZNBla1639vQ19QWqVjtoOW4Vmh
1X7mp9QLg0JV/Irh5pTsvh2PqLoffKIrZk4B1tEgqMm/S4maLaxGMcPyEa9n
0goqNWxaeNQhhvO6z2//thTZTdeesSv/UmevvVxVjwK6gw+3dTGcfzMxNvgh
WlMrWTaHJKBeJ/z+trINPa2VXo0FhsdsAqSDnWh+i27Ibz8B+qPOgYdi9KjB
pB5fcYkA8HU/Z7/tFSKpM81LnxLAj+70zT/4FhHnH+2+inGB5RAnSpK+Q5pZ
cxuE3lxIXd7n3pE6gMrLTP2tMVzQW2wkVO4QCt7g1DlygQu8BbFFUq8PSDt1
R5bLYy74v12gX1P7EdUaeokeKxL0Xp9kZxcZkXPLp4CS5SRosY2rPU+ZkHuX
bXBCJAkX23u23MFG0aA5w6NVxdQ7Ekv+jjAjcZCiqbmZhHqFoWj2PzQ6bo55
HuDHhuzRWWl9fBwKFuGfWypJyBGTzabFNHIMMJ1cS7Fhb9SfqrB1OIhyxDb+
pSTIfRMxxT0zGq5rMGxGJPDRh8+LMmm0b1zY6/0NG4IOaCqVEhzOifov5Vwg
QZYxXFWpMqN1ByLism8wLG7C83fSSE24BE1tJIFHSJXlNTQ6+6STWL2KDRP7
ExxLZDjcKRL2CwoYva8pF98UM5I/1Ok8dCQIWgj5+jU0atx1UH3tDgmpebnb
95bQKF77ZHpME6OPG3fF8JhGZXUVfJ0XG/Zkzdi0NAKHjgcy7vFzzH2O6GVE
vBmlj3V3pPxBgr9PQvH8lTTqylWj8Xqm//U8zQYVjU52W5bfusfcI/Mmv7GR
RiGKigGHByQMvxtbPNFDI4FXnpuR+S8csoAfuxuHMIPR4Uo+4+8Edmkw2ox4
M+Lfl/3OzAuf2U540iiyXNDqysz3t5WYhDk0+sqoFL1h/IPe/nBVPY36zlMT
or8Yf9U/Zw530OjxPrsuI7NPO8UtnfuGRv8DOzQ6gQ==
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], {{}, 
    GraphicsComplexBox[{{3.2, -0.0736645775977752}, {
     3.4000000000000004`, -0.848973735758926}, {3.6, -1.6333526624096628`}, {
     3.8000000000000003`, -2.269129041449057}, {4., -2.9278298240363543`}, {
     4.2, -3.4788822940217763`}, {4.4, -3.644475299776881}, {
     4.6000000000000005`, -3.9184641916879133`}, {
     4.800000000000001, -3.9404412324434572`}, {5., -3.7898998055308675`}, {
     5.2, -3.403470367744741}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVlns81OkXx12SS8Z3zOTWhUkSlRqFXEoPui3RhCRK6LK2ovnlWkokuqwQ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    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 182, 139, 105, 79, 61, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
       12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
        30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 183, 140, 106, 80, 62,
        52, 42, 184, 141, 107, 81, 63, 53, 192, 149, 115, 89, 71, 43, 185, 
       142, 108, 82, 64, 54, 193, 150, 116, 90, 72, 44, 186, 143, 109, 83, 65,
        55, 194, 151, 117, 91, 73, 45, 187, 144, 110, 84, 66, 200, 157, 123, 
       97, 56, 195, 152, 118, 92, 74, 204, 161, 127, 101, 46, 188, 145, 111, 
       85, 208, 165, 131, 67, 201, 158, 124, 98, 212, 169, 135, 57, 196, 153, 
       119, 217, 174, 93, 210, 167, 133, 221, 178, 75, 205, 162, 128, 219, 
       176, 102, 214, 171, 228, 137, 223, 180, 231, 47, 189, 146, 225, 112, 
       216, 173, 229, 86, 209, 166, 227, 132, 220, 177, 230, 68, 202, 159, 
       226, 125, 218, 175, 99, 213, 170, 136, 222, 179, 58, 197, 154, 120, 94,
        211, 168, 134, 76, 206, 163, 129, 103, 48, 190, 147, 113, 87, 69, 203,
        160, 126, 100, 59, 198, 155, 121, 95, 77, 49, 191, 148, 114, 88, 70, 
       60, 199, 156, 122, 96, 78, 207, 164, 130, 104, 215, 172, 138, 224, 181,
        232, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGB4wTAKRsEoGAWjYBSMAnIAAMBOApM=
     "]], {{}, 
    GraphicsComplexBox[{{4.4, -3.644475299776881}, {
     4.6000000000000005`, -3.9184641916879133`}, {
     4.800000000000001, -3.9404412324434572`}, {5., -3.7898998055308675`}, {
     5.2, -3.403470367744741}, {5.4, -2.975010818229276}, {
     5.6000000000000005`, -2.327799982840724}, {
     5.800000000000001, -1.6935644889983064`}, {6., -0.9908546244525547}, {
     6.2, -0.30280443841054216`}, {6.4, 0.5849436182450997}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVVHs81FkU/yXMjMf85DdmVBLb44MW47FGK7kxYSOLjTw2TZFHhVjyWNkh
Smw28iqtRx+vXqu0snq4tzy2LCWJYmJk9WnRPPKoidjbH/dzP+dzzvl+z7nn
nq/h/mjvA0oEQfjj8+VOkAxYW1lRoMdEdLL9CIkc7B8NeLlRwMAqr6ozkEQv
9ByGEg5ge7AufWEribqUh/mvj1GAeNiqSNUnkSShTbu3kALi7LsZxxRMNPqz
+bZH9RRAmtbn//iHibhZrc+VH1KggidZ3VjKRJ4bRJ0urykg1DDyMdzPRGU7
t6zXWqAAsDLhkuuZyCW1fUyPxQKEvtdOj3FNdN/h2XILMxYwcGlqWHFBExUx
1LJPObOA2P82b8pbE50LyooLC8Lx5MV9faqaKIqfA90TsV+U4htfr4HKLJuO
HD3DAsBCUXLcXwOV3whLr72M8fJCQNUHdfT4zt6Pe9pwPrdA502+OvJ7LOzz
E+F8hlbEKFcd3YzZuCJwjgUEkc477B+ooYNrZm9WMnWA8PC8GbFbDb33d22S
GukA8a5CeuEwA9UZjum3OmK/64dLliEM1CyvmRoM0AEoozw5XEJHpd7SVZ/i
dIDB1Z4A0UE6enFHUL/nNM5X+4qfNUVDTtdX1jlXY7+FnTwlkoaE3+xexoM6
gBAKReZiVaTbeg8dGsDx0342Rv6qKG20Tlwrx/Fe0cVHW1WQbs5QSIQ6GxCM
sZ82m6ogNXve99Hr2MDg7xQvpzJl1P0L53yKPRtUhCYPbSWU0VSngdtjHzYA
BYkS+sHlyLYyRlAdyQbi9Mo+3z4l5Et36T9+kg2EsdrDfHMl9CRhe0NNOcZv
rSkX5y9DKxMfSnqa2UCg7BY0+IZALcK4PIdebA8ntM07ESiPFV5iNYHzLauk
5/hL0GazeMlMmQPQokrNb6OfoU1oWneUHgcAXqhTUP4CpK2vnW+04QChYKxn
07p5qBrJyk33xHZ1fq34lgIKWi6fOBvOAQQL3RDt/QhzKtpHrqRjPOSffent
HNTOYZTTS7GdGvxKeHIWdhCFDyYaMH7adHGHyQx0p1U793Vhu/TcZM+199CU
PcxVGsfx3XGftV3l8B4/cHFpCfNFRHbcPyyFQ4WeJxwdKOCZUcafDSWRhmnG
yxA/Cgi8jEs3eZCo9wxT61oM/r9748kIcxLFX7vASXuP8Yp9kjN/kUFjx4JX
327G+fxbI/TDJNrYWOM35IX3rdvyR1MfEj3vr4nPP0SB68Lprj08Ej3dZ191
fxLXFzxXNjImgysV89lAgesR/3lGZbUMeuraMHg2eJ+8xjixUSSyVPBKijwo
IGtoL8ryI1G/ItYoM5wCRwabJTw7Ei3dOT2x7y1+Lw0N3qKOHLr84P5UPIvx
VlBmO3bK4GTZFX7FAvZXt2REP5XCkOW0tY3WeH/R76fKoklkW0rYzrhTgGts
1vZ1AIl2q79MWwzFfMUmk3r2JGL/16jZ8AbjeST2M8zlMEgYN8OdwXhkABER
KoNKXc/CZJ9wP6ime2SZDPbFHDf0XMTx2zrGV5VLoSRRajyD9Ud2wKnJEuvP
lql/aeswH1G4JnUB8+myfjWzw3xaz8qDNbH+XFz6bu0gnhd4wm/OtZPDiSK6
qv80fu/syqwPsTKY+zosSRfzCR3jP8YyZVCQxbFK/Izr0X7Svv0vKXQNlJJG
eL6Ed/W4JFMKG24G15/F/FqO1m4pmL+FNRB9G+sfyuhsDcb6l1gynvES65/s
+S79TMz/Vo1lFIX5hWG20p5tcsi92Mt8h+ctpPkWbE3C/b2zSL+K54XmJL53
WTJYc3bUTgPzC6nkR4NtUpgb2qx7F/dP3K5jZOZLoZLnBlrBl/9mIkryS5LC
/wEFnpI1
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 81, 73, 66, 60, 55, 51, 2, 82, 74, 67, 61, 56, 52, 3, 83, 
       75, 68, 62, 57, 53, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
       18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 84, 76, 69, 
       63, 58, 54, 85, 77, 70, 64, 59, 86, 78, 71, 65, 87, 79, 72, 88, 80, 89,
        50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGCIZBgFo2B4AACurwIE
     "]], {{}, 
    GraphicsComplexBox[{{5.6000000000000005`, -2.327799982840724}, {
     5.800000000000001, -1.6935644889983064`}, {6., -0.9908546244525547}, {
     6.2, -0.30280443841054216`}, {6.4, 0.5849436182450997}, {
     6.6000000000000005`, 1.3762363670784141`}, {6.800000000000001, 
     2.0022935916730202`}, {7., 2.6937347281055635`}, {7.2, 
     3.196523151031901}, {7.4, 3.764627620906165}, {7.6000000000000005`, 
     3.8748591614491095`}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwV03lQEwcUBvAlgcCuUkUUOWJrHS0qSD1S6wX7KAHayiHKoSgO0KKVlCiH
VamEFAUR5FDBi5HDRqCpHFaRQ8zGCjRi1HClHihQAgyCRBAUkUBf/tjZ+c37
3jd7fh66f2sYiyAITzz0Z5fbEgOCsARihUNI3gctM4M6J/nUEm0ZceJrh9eM
pH9GMX81WtpwZvHCV8yFJqlZ2ffotJ9u8aGPqeGf7sgNRWc17Zrap2FKvp00
PXcUXVchcPTpYiZ9M680ZennGTa/NLcz3JHi83PL0P62Qy1xaibcmhxuV6Ab
7W2ltIox33ymvL8TPT5PYPy4jkmbma/STaCLFSrrVeVMqFrt729uBQTRrq7e
m0uH2fk58+zQnd1xW97L6A1m209ZuaJbfZ/72Cvp8Oljji5BaNmYXMJqpQUi
nnfMIfQte16g8Bl9Kdm+fvlpdBPHRRjUSS/O8SxY8gfa1XU82KObjnd6+8L2
Hnp0tovHkV567au7YuFzdErogYXCflr2xbzjtWPojvVm2XmDdMxQ2UDGLGsg
au/t/iDT0omy6OoiW2sQv3R/WbF1mN77WW1fgzP6cWL8ou4RWpK84ujyQHT3
HarVf5SeFdcbYx6F+7tyEsblY7QHa/Ej9in0AR93c/f3tCYjJW2dBD2hYW0u
H6c9Sw+WxMjQG7/cEcWboDUBxavWPkE/5A93lHyk1aQhd9MbdGRfSgSloy96
aPZ8R9mA+H7GjSDxFF11/vX8nEU2QCS4rg57Ok0bCp1WRG2wAbmf8JDqLAGL
2sx/3+KL+eBH4Y1uBpDDnxMf/TNa9y4vasAAevjZty8noeeMFLjlsCDF03n3
zDzsMy3NatvEhqAuXhhRaQNwnzpY9IQNLE6J8qMK7SUS/SkyBNYar0sb+/X5
RItSCyNoeROtSGBzgUgelM6tMoLm9V2B3gvQActk1DYO2Kce2hb8FRfEV09e
C+zkwPaIM9cOe6NDstSvDhpDR4Ba0LaXC5Bdv2lKZwxnH4ZkVMbj/pW1aW/j
TcCqNdK84CLOp3x7x01ImPhPqnt0Hb1nds7H4ySkmC19oFRivi7hmIaioCh0
wbZZM/H7u9RzWZo1xHwTu0/jyXBBfrNwOkVBwtgnIVJjDs4zP1z1c9cyuQ5U
ZHoV7t/YWdtfSEJvvSLAtAG95F7jy34SuD0sNZuNeYPriqR8LaNMDqx0qMC+
1S2Ok9kkzF1olVvyN+YlLy47PSWhSnDYLOI+OtosWjBBwkpVy8BvBrhvVLTM
4qGW6a5IeCa6gddfU+ctSiPBztP5rk6O1lVu7FOR8PhCPu/OP9iffj3TdoSE
AqctQ9wHOJ8fu1/KoqDGtfadXP//x3JSd3ZrGaHSYrDwL5zLLdMdT5Jw64e2
5iXYRzg3VFUrSQgs47n16O8n36iRPUSCvZ9mmt+I+XV26alTJFgsrW0fxX7x
eLmFgkOBSLzyaLC+3zSjKG5Iy9z8t3N0g77f63YN9wQJk8K859X4PMU/vk+4
0khCfs2U1xHsh9CoyOEBEqKCS02e6u+/q7no10kSdq1J6knGfvmOoPBqQwpU
3JGWYHxf8q2CGLUJBf8DsfUawg==
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], {{}, 
    GraphicsComplexBox[{{6.800000000000001, 2.0022935916730202`}, {7., 
     2.6937347281055635`}, {7.2, 3.196523151031901}, {7.4, 
     3.764627620906165}, {7.6000000000000005`, 3.8748591614491095`}, {
     7.800000000000001, 3.9985253382583203`}, {8., 4.019452686016271}, {
     8.200000000000001, 3.959526792030347}, {8.4, 3.4848469949065377`}, {8.6, 
     2.963637825934534}, {8.8, 2.5023083138944315`}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwVlnc81f8Xx418Ex/uh8q8975vskdKFGmchJDsHcpMQhGJMpKVpGgrpTSk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    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1FWUFVQABdA3DN2ldAyggIJ0d6ciAyjSDl1Dd3d3o5R0qigIKChg0d3d
3d3sBx/7nnU+7te564ZFtAuPDAkEAjEdwdzHPHrwDaXIQxRCiUo0ohMjeI9Y
xCYOcYlHfBKQkEQkJglJ+YAP2c8P9KQOpclLMg4wn17UpQz5OMOPDKM51UjO
QRbQm3qUJT9n+YnhtOBLUnCIhfShPuUowDl+ZgQtqU5KDrOIvjSgPNdYzwQ6
UJDzrGYkrQjnFhuZQhdScYTF9KMh99jMDCpwnQ1MpCOP+IdZFOICvzCK52yn
NQ/Yyne8Zjc1uM2m4I5GnipfsjO4o95VPuG/4L76HPmGPcGN9dTyKEsI0fvL
Z2wLvgW9kbzPFkL1mfIVu6jIDX5nEi/YQSce8y+zKcxFfmU0bXjI33xPTe7w
J9PoRhqOsZQBfEslbvIHk+lMES6xhjG0pRZpOc4yBhJBZYpymbWMJZKvSMcJ
ljOIxlShGFf4jXG042vSc5IVDKYJVSlOGKdYyRCa8jklyEBGMvERH5OZLGTl
Ez4lG9n5jBzkJBenWcVQmvEFJbnKOsbTntrc5S+m052n/M/cQODdh7A38P5v
yC3fAn68gWo=
       "],
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDgABGjYBSMglEwCkbBKBgFJAIAH9UBtA==
     "]], {{}, 
    GraphicsComplexBox[{{8., 4.019452686016271}, {8.200000000000001, 
     3.959526792030347}, {8.4, 3.4848469949065377`}, {8.6, 
     2.963637825934534}, {8.8, 2.5023083138944315`}, {9., 
     1.8376577106457064`}, {9.200000000000001, 0.9960780231732167}, {9.4, 
     0.26885131340556667`}, {9.600000000000001, -0.5788847854644461}, {
     9.8, -1.32253004045072}, {10., -2.001914331921118}}, {{}, {}, 
      {RGBColor[0.24720000000000014`, 0.24, 0.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
        VertexColors->Automatic]}},
     VertexColors->{{1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {1., 0., 0.}, {
      1., 0., 0.}, {1., 0., 0.}}], {}}, GraphicsComplexBox[CompressedData["
1:eJwV03k0lWkcB/A315K7GJJCstzENdFcO0Pep8l6J5HT1VSmU3KljDU1YYyr
NMpSihstk6hwSiZGI8v03MjpHlt1KI2tbMlakV3vnd/7x3Pe8znf9/me8/ud
8xgFRviJFAiC8IZDf297DbU0NxsiYmNKDMOTjdp5f3zf1w1m3s1QwCyUGZI4
7DNpiMQi7S1ZXBayZmS/uUyBBdfjd55jorzFU+x0NSMkHjjAyhhXRTl+jeIu
A3CXluoxJ1V0QsnCkcEHT2nckl1Yifq0P1ie2Qr2WyhjP1dBWucSwh76gW2Z
kp0sFcTftXni30BwZmeSmY8y6ki0v28YA84I3+GdoIREygFl+5KNEBHwOmVj
hSKqHdk775oN+UIp84dRBsqzKE88ewd8t1NizWSgI83GP95+CP+HbYi5Z6OA
cNNHf91n4HKzulzPFajXVHLH5Q1YFBcTEUCgwV6hg9MHcEFJ4eI8RZ6YDWdd
WgCrTU7dZH0lP4Xc4j5R5SKi7LDgtMMSOevEjxOsA//m6FVkv0A+Dc1Zfcoc
XHHq9TvHOTJuVmf6ojOYf7DUcs8MWdv3RWPZG9xx/+q8YJocMh2LcdkPbgs/
fmDfZ7KjsUb3u3CwaxxzaGCSFLYOEnGJ4EZNpaV/Rslqc7NNf14AU1biV03v
yXtjDRLdfHA6Tz8ppZ8UqWzZ5l4O5oVbKBR2k8q/P7cR1IGTu0RBsnbSWlgd
XNwGfjM2cSVWRnqkSLt7B8Dqzty7jDLSeE2+pH4afCDTjispwRlKnecVlDYg
4oVy+471Mtzjs7lZRwssLdc8MtOGqxY7vdJMwF80ExTF3TiBuMV6ZQcWryU5
jv2YechNvcUdvN0DF+q8x1wTJDT4CVxsZeHpOYq5rv69XiHg9LGIYd4kLq17
WtQaC360kGv27WescINTsSKNtpVHlOU0dmmPUuRcA+urUJs0ZrBy6GZJdAmd
B52v0ZzDDwOUjz6oBbs3MAIn57HFvUdJ15vBjWU331UtYsu99f/194AfPwk6
dGcZ6wWNHF8xCb4cL1gKobDZ6WFKLgevmvuMzAmpc5WtYkc7vAf/wuJgRTYq
OBZSTcxBXrCUNXJQjiOTOCMvX0Ce/exwuAkbvR3jaSdNQd7/62zNEIWDl4oC
xEtgat3fST1ynCqK3fe8Fd6Py89+HvZsRJmqemz9RM8j6AoronCy/dk0tAAe
9Y+T5cmxJ35mIf0KbjA5mcohpDm7/1rd2gL33zpTxSQbcdxj9xt9hFyvUs/x
LIWzhPMFhvNgm+XKHrEc7+6xd7u5DFZTWeO7LMcO+bvXvKPAg2v1PugR0hu+
gijvFnq+7YYd29hotdDy6EV6H9HRwmsnKXw16EFpJj1vSfbLoCg53j/+0Ved
7tNjao2OyzF68A3Xl+7Lzhpw1CKk/Et5zEh6f1VrjSTGhNSoJceAQ/d7bEqe
cGOj3ABOpBfdL9uT2xRJYf1f0is86f7uqwlFR+S4f7rJX0bvq2I9325Ijp9W
jpmupPsT+LsCNQhpxZV4dR7db7Cq4bEhIS1JrVd8RNtWix/KI6T/A/uuFas=

    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotLabel->FormBox["\"Surface Shape\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{0.032, 0.032}, {0.0815362836394291, 
   0.0815362836394291}}]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710542551961*^9}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxFkm1IU1EYx69apmm2dL6mtd3VB5NqqFRm4zySZkSfRKKQxEY5MHGuNAwi
TqY1XcnAkS/TNpZTp2Qbk4Zl3THfKFMDRWYgiCHiB0HQFcustvZMHzhc/pxz
f8/vOfcKpfK8W4EMw5z1LO/TX1WLtq0ZrYprbfHWJ6LOHNEU5fcSX54j+vdS
NmTTyqWnees7gb+a6Q83TLi/Qui95ETVZQ3no60Ruh76buSXjvjOrxP61O2I
YTs5f7Zrl9KDDSZOVuytH4Q6IuucYa+Q5yZMR0bJ0fkmMvHFW78JXd7TpBN3
IJ8Bximud8N19A0A2lq6VWXVY78gANmpXBOvm/NnJj+m3yKXcT7eLtDPFU/2
TZuJr38wmFMg/rHTivwQgOG2b4MzPcgPhW6bdXrwZzvyw8DeEPtgubAd/cKB
RgyInA0qzp+ZiUrpZqoC54sARli4qqzvJD4+D6htLSNwuRnP84BJVT6R7xvA
fgegKGd4VvGnH/0igbkZVD2WI8X+UcDMNEvGy8t38hV5WQ3Uoj8fqCN7KmpS
i3w+MMb7e09f1OL9RgMtHdNP3FWjXwzQxvHS8+Zu5MUCldiu3Zl6jr5xnvfz
heP8am47FxCXlX2E88eBPtA4m3vVjP7xoNYoHWUiI/onwAL/dr9F04f8g2Cv
y3JWs13ISwTmUp4ieKMWfRPBLplPqUjo28lG5Qmr4TXyk0DQWHjO9WYA+YfA
fnKM1Q314Pc+DPYX1CXe7+cLPP+LdCNJWYnnBVAkfimTmD+ivwCosatk9YKB
2867cxcDhkzcf1yaEBYUNVk611vsLwTmzEr40mgX3g8L+uP85KBsC/JZgB6b
6n5BG/I8+3wL7/PDFpxfBIJnqopmtwF5IqC1OYPRo2r0PQI0M+Vr7zEN+QeI
aZEl
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Method->{},
  PlotLabel->FormBox["\"Fit Error\"", TraditionalForm],
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710542554227*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwVlPs3lHkcgIcx0RjMkNht982oESXkkmLH55sIadqapt2kmjYzlZly3Vqd
XU0uLdWROKerSDeMxChyKd1joqk1LmVzz7gr5sX7prDtD895zvMPPOw94Xyx
LoVC4X3jf493zHcsCdzulfj3r8E0Hgu50unnbmAXoHrXbstZOxbKrB+nCazl
kGGzb0CPykJN4hLJ81t34Msnt97bbUzk4LC5pyy3HLpuZBxyLGciYqmpLIHz
CMJff5QcP81E3lfofNdLT6HJMVlesvdbr8Um0rtfQLgp7+RJDyYa2rCInbXg
JdyPuh6/xJiJJn4LMF354ytoirggzK8xQe5pOvMqhW/glUbG7go1QR/FBw+K
3eqhoWBHbSTTBJnf45v73FVDdez0ZZ0yYxRkFvfiwuZGyDq0tW56izHaOAnv
XBqbQGp7WvVowggJe/1wnz/ewpluN016ihHyPaHkF5i2gPhkXIA3xwi1FrfM
257+L6T6lNJtnjJQap9LR6xzK+yzahHIBQyEX8MY/ffaYCKlZ9PFYUMULeWv
UQZ3wH4HQxvVEUMkipbtlP3VCbLr8d8b6BuiXjyzjsvtgt8jViuxS3Q0OdXJ
dTfuhhQLBdK3pqMOnwNdW+q74aedVw30FHORc79LbsaZD0Chbf/hiNdcZGZq
FYnt7oG1iUFVm54YINVRwYHnbA0wD8/U5q03QOZRt6U3cQ0MWmwm9JX6qOah
d0rxk15wKOuJf+Crj/gbrTo74/og7JTIdXftHCQVWbsH8vsBG4xZd9F7DtpR
deDRu3kDcOVByPDnJzRUHo6HpjUMgDNdpLLypqFreVmWx68Nwl3Tp+ywUj0k
WpxOZoQMgY+Q2bLRSQ+V2OS3jrgOQ94cYfNUJhW1SenaPeQw+JHPNFFmVBRB
z7Wjlo/AZTN67vsTuijNcb+4PekjLPPjQrZWB506H6luDfgEX6ljKzNDdBD9
2Ru2ofEoFMpzwy5VU5BeX6KUe2gUyDr+DvFSCpLYt/PimkbBaP1cm6Lls2BR
GnCnmzsGal2Gq2JgGpyEQUVbr4yBglPdFVH2FWbckrjtM2PQ6VE1vyjpC5ht
quEl7tVCnXtx4TKPKTh76takZ40WpOYmGpglwXZdtr2LCw4G0duexWQQwOG9
8MjBkuGxmvswy5OF2vtvprlPa+FuZsDyIR4JBg2eiXIsBuSLPywP8mEhj0rb
56u7tTD8JhIqckhIsFgkdLPE4f7Rc4VN4wS8bre1UGD74WL0B0axPwv1W0va
Khu1gP6pl9EaSHA6Joq5R8ehXhoXHMomobmwy7eEg8Ph5mQbJyUBQZO63Cps
G6TqOea8X89CXm/pki8qLXjVNo4sHiAhyZVGI6g42La+lBW4k2AfEq8ex3Cg
6I5zjrcTIJtCFdH2OHC+ChTNxQREcMqS32L+EJrrlzkayEKSFcGKjFotFNAC
SedxEu6c3hp4noLDS/Ue8StvErZVqS3PLsBh5S/Y59sDBOQL0mbN7HCwm/Wb
olYRIMgejWpwxCFMVeSfl0NAVsJCK8bCVRBeFEH9cwMLHduV0DCk1ILOlpD0
is8kKO/HhvXNaKE0ljES7E9C2OCUp+Y7HIaLzhBrPhHwOK7CWrQEBz8F9m0j
BEhUlucWOeAA+auyoYAAr2jlzwkrcCgWV8qZVwn4D6SUR1Q=
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwVjHs0lGkcgGfmm/HpQtrFoVVbxmWJJZIxdfxelIrQVtTBuNeyWTUorEiR
7gq5pihCbPeSTvG9bTbHKmIoUkMX1bQTmss3ZIy1fzznOc8/z5KIXZu2sxgM
hs8M/xstfuzi6CiH3XpGK7MraRAEHf/7Sr4cSrO5Hc9BCQ/7I0Rr1HJY185I
jG2WQ16KOGVUoABKsPifewEyMPJMvnG1SQFt4sEeoMdg2N9s53FzJVSow29b
j43AosOJTSnZSsizw8P2llI4P/k899CoEjrNdC0/mkpAVLZVVR1AA4RYBRrY
foA9ofuU/Q007N0gmDr62zsI2X5rj/WPKuCHN6oexQ7BrRM5OScyVMAaiKhJ
WD0ATUOHeewhFVzPZs8yf9ILusn5USVrx2HMUOJocL8T2u09rFDtODh4pdjt
r2uBThvObvb8CUiysT6yNOgGHPUfXitOmoAqvR7T+CvF1LXymMa2FxPgxym2
2GD8gDKxZdR3wzfwebgpumy0jVIO8Fd8qfgGeXVdfrzMbsqg47CH+exJeMN+
GbM/q4/6LJW9iRdOgunCJhERI6ZsbFnG3V2TUD89a+sz+RvqznVuty9fDUXf
S2SqL++pOn8J9/VZNaSLzAJX3PlIbbF8qnVgUg07MvJP/RT3mVqz6tFO98gp
WNA2ZjUY/oW6GC+IMWiZgprfx8LD5o9RntJZEo6tBvqyfZ5bn/pKVeT1TMw5
o4GGOeEj7Rw5tSPQo5Kr0EC/32Px3EgFlbC9pWNb8DQIXLt7y14rKWmuJK+8
aRoujag/d7mqqJN7DBVpugxUOC/Z7lPxONXq8XCQ785AQWbOCz30vlF3TZuL
MuJn+s/3K33iJilvbotebzUDuW18lZ4vUVMFy00Cbr5goMbOGtccbw3FDyai
SkkmesrPNI+rnqYOXpI75K5kolfi3HdwioEzpp069GKZ6NyFBaxaVyY2TT1g
XV7BREMVpQ1VaiZepBPsx+thosS3vODv7rLws2tHUCCbhW6J9dPfRxHYIrFZ
dozHQiFVzu/WLGFjh/WewtUxLBRWWxut28XGJcsFjdolLKRDb7P0SePgSrc0
PPCEhYqEPuMGPC0cGTp6xnmKhQL0XJReH7Tw1QcSO0dHAt3jVHperiVxR1Pt
/t2RcsB4m/3lr0rQzomNcDIi0B/D1olpa0lM7rr76hdvOXwwrwkr9KKhgb6S
2jCbQIeWuc0eNiRxkPnS9bfNCcSzoR30k0lc1ep63B3kkOp1dlwniYa59b7a
KoJA+SOLnYo1Wvhmf3uvYhGBMgIU2m2hJGYLjz1IsCHQ+R32spDTJJYlHHzL
d5GDd8kRttdJGnicct8iBoGGZIcuCmVa+LWjiUnBDwT6NfeTd+VmEtu3v2Tp
WxHoxSppuUsWifsN+XtFdgQquPyXVVYZiY29zHSdV8hBNG/fguhiGnwdWoUf
NSyU3OzkFyLVwrKw1TBsTKD146GRp31I7DnOsoiyJFCUsFVqkU7iEY+IEu7P
BJK1+OUKC0ncIpm/OXMZgbL0j94vvEhiGycl985yOQxqEq1U52joWxeUOW/m
X0bPrdwi0cJpSX0bdWb+RppSabYXiZ/pFjmfsCAQEXL79MJUEqcE0nXetgSa
ripwj84nsS+jOqrenkBucakJJ8tJ7CJKcwtyIJB/2b/Miksk/g9TWU/q
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwVV3k8VlsXlvGc1/EeZUwqFVFkLnNWIm8oc+FWhEyXiPKpcJVIKqUkISGp
DF1xyTXuSl2VpEgyJUVSNKBE6lv+Or/123uvvfZaz/OsdZZ4Bjvs4ufj42Pn
8PHNfquuR67R0REA3v3dqn+KUIRn6R4Z4iUAsr2xXz8foMgBYevYmvMCMN7V
PyIwThHP9oQtyY0CcEJB01V5J03yapy/hkwKQKPO6qqDjTRJbFC1dVcThEq4
MhKuyyHLexwj2rcJQorx/v2e5zjERybOc1uyIGi6ekfqTXEIn5+F1EiDILS0
zl8y4SJK7B5sTRGeEASPpJeBCcWixNwmrE19hRCUHI/Mni/EkNFXfX2vXIXA
b163y4QDQ8aO9ZRnHBMCxcSA3ZczGJLh/Mbap1YI9h4SKfEfZMgPLaMb/44I
gUeUc62rihiZ1sh8umCpMGTed1h65U8xstX8RG2CszAY/1jYcOC6GPH3b94X
HScMHk71vTteiZHFJfM/Hf5XGCR5g75lUlxyXOSWrviwMOiHrBpPNOeSjJjt
RkWLRMBPbi1IhXGJkPhZjqODCJQMPvQ4nMklSiVy+YcPi0Djl9E1LvVc8n5P
If/tChFw8uC8GO/jEi/zJNWEdyKgS6ZNgn9yif4qvoVuMhSYXx3MqJBgSYne
wSeG1hSIjzrn9KqwpNeBtznvIAWVbh6yDfq4fmpRknwJ7r+lzD62YEl3f2zq
pTcUtNUV1rhtZkndBqM/CyVoOP2AfEx0YIl50zTffUsaOpof2oyhHePJ9fKP
oEHfxngk1JYlMmzJSZlruH+HDPHgscS+x21/WxcN4snRG3KMWbKuZquWHMMB
vvXJ0h2rWPK8ZnvBbuBAn/X2H3nzWbK4ufyT9R4OtHy6FNDDz5KGicwZnRwO
XIsYeNc1xCWM6cmmlc85oCDZOnqskUs4F574FgiJQoL+4zOx+VxSJLmgQd9Q
FKg7phbBUVxyLX9i6GmQKLT8lXm5w45L3DYu7Ry7KAq87U0SYcu4pETM5YTi
M1EY8ud2S4yKkZr+V5xefgY098ZfdasUI8uav9nnajNAdt+YQ8eIkVVd0m77
fBiIiXrd8mKtGBmZTFB/msrANSt3cbVfDLHcEvugqYkB8fOBbuk3GXJoMuil
vbUAwIGVYnnrKNKsb6m457cI5Nls64unWLK31CTcSouC7pblUq2LWGJ573VS
sBcFPMV7OjwttPfo7O47R8FbVkWtzZQlGwzs5/U+oCAy68896VYseZzyKubK
NAWNDUdev7NjyaFjCyoqV9EQcj22gefIEk8ZoVIZDxpcch+KF9qzpEnfPQJO
0/A5tl1+uw1LdMPjBL7dpiHGpbuWWs+SBzauzt/HaOi7ItZeupolx2s6g8yX
Y75t13puVGTJgXv0ph4XDshmfFtfxWVJurLwz+abDCREX5oM72DIIvuJo2am
qAfDHQuuKFIkrW74auSYCGQ3CTNpWM/2T1kbHRQpSOtR+eaD9Y6MVtdw3kqB
Is1T0EI8zOs32XEngQJBve1UMOLl4Fs9u5kaCmqWrfRyRjy1Vd88nvuJgsnX
1mfqEG8KfoXipQo0kJJkMwbf27on5uWoIw2NUTWqQYjP/McVI05HaKg8m9Iu
iHjOv5PeKFyO+3WyitsR72JSbu8G3tHgl6icZmnAEh/jC7Ya8xGfx3+E6qxg
icrtsukrNhxo/Kr8ZpMk4v+0pZRdHgOT/23aF/6BIfOYc6PHginYa/q4axnm
K5JvRfSvXApsBkjsmBlL5iYFtNW1U5Cg/NEgE/N9P0gs/JoIDdt8txS0Yz36
C47/UW+I95elhgLG/6XmWCIE0hBhPDFdhPX8ellEQC2ThiF5fnIQ631nRcja
gWasX9PTz98QD5/rGvo31SNedzulr7rHkMAZ/VeGBgLQMBwfy0pTJPpQjf/h
ERH4+V3vbeJvLjmaZKvTvhD5bRVid16aJdJdTr8t7bEeGSabWVWWRMit36Jz
GPFHD2zMNcR1Q9VPJyooKBF9nTPfkiUuT+Tm5rynIKSSNymB+Q/eOlarLkfD
Tzkl7TbMN7N4bVDnJhqyZWKqb6Etkeap4h6NeDK0lr6L+e/1U1I9dQP14lWs
tiL609jvptnzGvHq/+jpNN7nFBlB8uZxIOaFf2gSxvOrjnJM3MABlcWev/lk
WJJmPpRz+iID+ks5f3WOM6TIr7ou0h/581Rvn4kO5lNfPTw4kwK+6gPJgetY
UvRme9jmFgqM53jXXbZmidWh8On8OTQoRFel+mD+tdNbKWNdGoCh12zC/K8M
sFyk5oN48ciM08F1991lJmtSabBb8CQ3DM9PP5nKDmpEfKnwOSagf4uwXcFJ
lRjPqeK4rmaG9CWZ3wy6S4Hdb37HmI0ssbvGE86boCDQqDzRDevZEuHltVoZ
65covEgH70tvuGMh4EaDx5yYixKYLwMB0TKrRLx/i6y6/iaWmLnlfb4uRkNk
jIu8Pq6frV5/w2wdDZNZageW4vlKtumbUygNJaufh8mg/0yO4hax+6hPC1LW
BFUz5GxrJ0dvjQAoXgzTqOdS5LPnFau4YRGISHjX92uGS/p6lFXS5ChQyBCS
XSHFEi/az3fdZgo6ApVaJxH/hRUWzz5EUyBvdsS9HPnx5m1enVMZ5te/NHTf
BpbIuT5xzB6kIG9fsfq/WF9p2/OSI9IY//u5FTcx3msT8notVtgPTo17vUDb
KqrSwvsg5ju8u1ke8TNVHbDNsRDx/1YvrQHxAIWdbR29NKhI3vVuMcL98kMR
7iwHXK4PBpersWTYpCw6cj3i49zVPidZ5EOW/pBmOupv5u3UuB8MmUptXh7u
Q4Hkss6/zbVZIvlc86vyBQpOTGifzAWW7E96YSb9mALvF1LaS7CejKjq2vxf
FER0OYivwHp3Jv/PfUoT43MYWDaLh/uwfGiJF+L3Ir/qHlxPdaT/MDqLenr4
g9ownpddBs+07mG88S5XrZDvIY/Ly9XLGZAN0kkqbGXIDYO6mNUE++8F84mP
qF/ztGd4l79S8E9jmScX6xURIlI1towGntSH9iV435qMHPbHFsTHH0HmZpiv
kCGPFtujyH/lYNtsxIPgWxed6xwaxosT9WhcNyx7JzhnLQ3XsvkuzuLJabCA
WAVjPp3/kfFG//e992YW38F+pHroli1hSKO7rW/IQtSf7VMeX2f989wvv7Wj
gfINckxBO+H77cqrgjTUFFXvzcb3JuZqlEbpYXwvRqdm+4nKoXrmfyuR33Pf
yszqVUzLp+ICcTz/qt7FC89/vHtp6xFzxPMNOY4YroeWtLJBDxCPpidl4isY
kl9XqFCuKwDdnsGXpUQpUtA6v1r4vQjsZXfF6iEeTwilLP0hi/PJ9UDPENTb
xOw9C+psUF/PS2oFIh4bBC3FeVHIp9JESxPEo1XVzvzKm9gvzkT8twTxOH1x
xcTiAQqI378BiYjHYav3pjZSNCTIzO3Kwvi+eTDy1huxfuGOLQNoDwR7tQ3u
x/yedLDnIR4TdontK7+O9dbu15HAevEa5K5u6UH+uzRaG2A/2vBx8fMaMQ7o
m0hvtsR+5RGVkDKxDucTP0mfGcRjxyMP0UNpqAfFjr4vpxmioN7R+dWbgqKT
+UP3sZ+rL9PWPHIe4xu0GDJCPPZ5paw88Aj12NjGpRf1/aNt3CulGeRT1uQI
hfm/cfJBoqsG8smoO8oa8ylZJPU4cyfizbfzXBKua234531tMuqRhrKsIvaX
/Kb+4bN3cT+fs2EB4jFuqqcjuowBl7/VXsxtZ4gke9DvQh3qe9+d0hx831j4
1uGlX5Dvl098GsT32wS6DjgsxXwo+KTK4H1HhJPHw5wRj2WUpgvmS7RL1P1Z
HPYnDk+4FfE4oFLWpkLToOg6s+szxsP920DTwxj3+4YlG+L5XPv0K/eCaOA7
3TjnGOKxKzmzfoYwoCB8w7j+DkMy/8g582QBDYIH9FrfoP+6ss0J7rbYD+ID
/spH299Y3k1ZAP29+W8qFv3vyDrU072ahrS/l+XO5uNn5Fz9dhXUc+ai4ux9
O6WsbFeyyN9faRqb8Typ/3L4jRnON96PrGVx/WjPtHbtfwzwvWs1nKpkiJmj
xfuTsrgf7kbdxf3CqUq6GdrobySrYpb/eXvLk1KUUG9PKgiqou1z69zLHFPk
2/a152btca8Zo7mLMb6GoK7feL4ivyd+kQENmrEBYDHLx7ig1zJqiLeMru/m
aMs2blJT2oDvi5Qr50N7W2zhR/lHDDQqkibxfxiiqZuiOo7/U93Zo0eApogw
4xRmOSQCaWbFUa0433vOf3hpBfIj08oyRwL5sTAwfN9PnO+NZ4bjlZAfTwst
NcIjUe8udT3jQ37MKEL6MM73skJjJ77jvBNI2u+5v0X+/DdREor8aOOdeX5Q
EuvT5yB8DuO/KH0kKYGH8UqeKPqItvb7ygUqyA/9Sdma7YgPu6odhwZxvhcP
+rDAEPHT1GJ4+lw34nFLsU8Q8sO8zSj2A873Q/ac56eQH3ILwxZrIz/AZWaT
Pc57nv3j8tfPM2Bn9bCPf4Yh//zo1tVCfkSc/VB4FPlh+FDbtjSVAifJhaso
5MfZ5tBFRQ+x/zRHx9cgP7aFapfs+kmBy8CcuEnEU9rxUIVj6qg//RfWW2E+
q3eeNO3Eefd0uO2XTMRLdD2t9RvnXWqX3S1AfgQt0f3ecAfraSeS9RL5IT43
dDi/lAHeQPsJ8xeoj/tdtz2qxXg8LxQdxPd5XxCs9vyM81u4Ru8zfP+aAP6D
h5dgfjoGuPPwPrUayvemE+ph4qtHnpgvF6ed+RLID+g0Ff2I/Nhi7XHFj8L/
JYmgK28wnsmi/nunjGiQndmdZ4LnrUTmyQrM8qOjSz4D3+NzTfOpEvIjgQo9
/e0uQ+JdrVR+43w1aSCr1I3+d/nfn8rcTEMLhBr9jXbnjgcrfflpyPMW9NmH
/nmZK8MY5IfHppgkG/Q/eKDqsRDyY7Kq+u4atJ/pfV8cwMV8jBmtX4/nC2rT
ZSWQH/pfdsUtxPV546fMB3B+yH6S16NTxRA1+9HoWhmcP4441VTh/s9nmx88
1MJ6s0WnZvmRFLpDsUER+XL706nlaNuVrw1+iv0obfexag20e3fmP4VFaPNl
wQ88n50XL79ZH/UpUxoscX1trPT/LFWRP/c2FpihzX//220nC9TfI4L8Imi/
u2D6y/wh9o8YmfPW5QxpOKUwsQL7c0iFVdjs+xRvnk7XNMF5fuyygR7ae7M7
LIvXoH5pj4XM4mHeX365+StQv6MLYDbf8mn456SD8X6sTZuNv+ma7pdR5Gtj
4vD07P0BRxush5CvfckX+GbjexYo0zWO/LRTO1r5vJQh/wfRLjTL
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1FW0VVUAhtFDc+nubqRBRLq7ryJINyKtgHR3dymNgtKotNLd0ijSIC1d
gswND/N8Y62H8/KvsdM37xTeMUIoFIrrJ+gpFtGb+pShABGJRGSiEJVoRCeM
GMQkFrGJE/wn8YhPAhKSiMQkISnJSM5pvqcPDSjLh6TgDD/Ql4aUoyApOcti
+tGI8nzENX5mFG2pTSrOsYT+NKYChbjOL4zmS8JJzZ/8yACaUJF7bGYyX/Ex
N/iVMbTjE9LwFz8xkKZU4j6/MYWvKcw/rGUs7XnBHubwKY/Yxgy+4T/2M5+0
nGcpg/ifQzTjGbv4LtjPwMe0Mv/yO1OJ4P6IduUV+4It3c0LttbjwZ5aRG+y
LtjdeVwo9O7RHA521w76kr3Be3Ceq5H1j+BNaB19zHbCnGdqRD2qPXjNARYQ
1f0JTcffLGMwzXnObmZThQdsYRrdKMot1jOejnzGE3Ywi56k5wLLGUILqvKQ
rUynO8W4zQYm0Im6ZOAiKxhKS6pRnDtsZCKdqUdGLrGSYbSiOiXIxGVWMZzW
1KAkmbnCakbQhpqUIgtZyUZ2PiAHOclFbvKQl3xcZQ0j+YJalOYum5hEFz7n
KTv5ll684SALiWafk6H33438+hZtXoHM
       "],
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDgBxGjYBSMglEwCkbBKBgFdAIAupkBuw==
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwVkHs0lHkYx19y7zVX2ezKGhOpCLkkyvssdQxttaVkN0fWlrOV225tY6TM
NkRicmvjsM7kCKXd6Wy5TvX+sikZ17kcU7mGIpWRMKHsu3/8zu98zvN8vs9z
Hk5U/N4j+hiG7aTe/39IgGVXWxsON1Pvmnwxj6OhQd0Ks0843N0+YTRdiiO2
ZMQ61M0cIl3/bKBvxtFCvJ12XZQ5ZEg32Zj0LEdbQycvmuWZQ30uJ8jr5HLE
jWge0zWbg+YvYdO84XJEnnrLTJg1B8nvMxegxAwt3bJZnFlHgxar3twcBzNU
pDfw9/kIGtSH04YGpaZoPGrKWSKmgaOjamW4nynqG8XjWppokKEvC3VHJihd
kJQkmKaBbW3424uBJiiLy9/tyaVTXFid22GMPCaTR5dC6dClqU0N4hmjPLkq
MCSdDvVVvOdrWoxQwRPP4zUyOmSIMsucfIyQts/+gN0kHTC+yPt6tSE6p3fH
OIvOgLCij3EzXEPUV/79NvFaBlRZlIY2Zhuggu8cX6m+YQB4eTGvfV6GrLNP
v7YLZ4D2R55bcuQypNhnuXf2NwYUjt2twJv00fDqZ1/TxFQ995QyZr0+ak6z
2+VcxQDM5cSAWZoe0p/Mf5GDKH646N35EkOxw98+F2gYIIxItJjnYejGz5ke
x94zIMeP6/qL5xLpP6udLjVjQo40Q5r2+hNZbdHLfr6aCdrMn6TXzyyS/vdp
hSV+TLCN9FW4MBdIj4Rj58pCmYClYIGSuo/k3D/B7dIEJkheHLN/6KMjLT+H
nNW7wIRb6VqjlO5ZMkpVnq+RMAEsO2Nnjs6QQt8k07pGJqD9Fc3yvmny443E
0acKJjC8n9BE0e/JgOoFjsFbJiSUPwDREy05drvy4a+GLMA6bjZwU9+RssBi
efQqii00IzLBBBkZw3aP2sQCqElR+3LGyMiiO1jZbhYMSgdPx8+OkG4Hnm0Y
P8oC2964PT+cHiJdJYEPakRUf2X/tNK4l8yc6mt4VMwCIf3pkSqBmqxV6lgD
NVR+4sk5bWYbufX+FoVvB8X5AVcfKe6RU+4tM6teUsxLa8linyf5PhqBMcYG
7JL1K8+FRiIsiHnYcyXFDsl83kU5McUXu7m7s0G4P6bxcp2a+DLP+MTECA7l
7eE7e9twVD7YGXzHng2Q90fVRlk3UftazOnV4MAbjku+NIyjzwUJPR9sKH/f
ChknpZMIdnK5f8KJ6pcPlVyoVxIGVxSJKgUOQv93tZp3OFo/iVZd/oqaP67r
eJzaTvDPpxhYrKX8bQVnKhsUhI2in690odghxehpnYpwij1Z3tWJg3f6xBbB
Bxz5W4/DqBXl51d0vUlvI8S3K9ccXsMGlCA/eshHQXgsGRVzN1D+2egqrreK
MLlWu0/kRvG/6+uub1ITELa9cVcHDhqxVRJvDkftG8/sNafyhIdiOvNN2wir
Vt/NWQ5Uvqi/tHm+myBXFN/c4UxxxR7vEJ2SyJcFR1e7Ujx77sO9ORWRLLYL
OLiR8rMFu0r4aqK13bk5ux2HxeNbeqQ6HLH8Ag9epe4tXLYjLqZVTkSoDf1t
/8+fsA9aeNZNGHCO1AxQ90IrDXNiNUpC88ginqDyIe5NWWuPimgqerNjktof
M/VzLDugJrxEYT6PqXloT//awitq4j+pADzD
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwVU3s01FkcH2MyD37WMjO/0ZFHHqvds+0wIm32foko7M7GtmNtmkpRnWha
orOl8VjUbJZFrdgxlJJqx7IpKZnEIvJmIiKnx44aj5Q8Gnv74557PufzuZ/P
93zuvTY7o7fsplIolEC8Puxx2n4XgcAMKLdkYybr1Qh5NPd/628GUlFA/6f7
HiO1BRqM241xYngKpI+hVtqw95NjZlDXFCnfxXqOtHH3TLtyMa89ZdW4X4NG
f/7Cs1mJ+b0M+8xlWsRPr++lNZmBYryOPls6iYT2j1p8n2D9Qjmne+80kgeu
tzNZxPmzc/Jq8xnkm9AwZsFmg7jKjV9//g1SoW59p9UY/543nO03i04zWSdP
bGSDgnQoj296h/LC0mMiwjAfHCfY7D6PorxldwLi2SBtdx1iqBaQ3Pn6wcOZ
GLu0fF3q8B4V/h2RdLGMDSODqiBlkQ49qNn+bts9NkyuEFqmGVBA9EDaI3qE
9X4tA6ZXKFApcfg49C3WOx82Fofqwb4VbyqLjDlwcGWtSm9BD6ZD/K5POHJA
AYc8i85RodRmzLLeiwPgHcxt8taH6qkLLwd+4IB4KPlHfr8+5G+ZWD4fwwHh
1FH6OQkN1DVi5bZTHDARyp61v6fBhnLz0o0lHJjUbVXEJi8D6Zrv9dzucIBv
VxWy1sQAePW36/b3Y2x1mFLwmwEkjpaOXJzC58vWpYVw6MCTDYbvNeRCx/ZJ
sU8OHVgebt9E23LB5JHlT7UGDGg7Tp496sEFvuRtqTyBAS9brP0ffIf1ebSU
FA0D1hZJxCUHuHAw7bjshJAJWxm+fclpXChv/GeRUcOE9jifiguFmE/pso9Z
zgLz+CZtRzX2F22xO3OMBbXSmCzUxQXKSmWXZR8LstiRfwg0XFAYFwZYrzIE
V/eRpdU0EqxnH7eOJ2C8J7EtyoKEOn9YoX/fEOh2FxeuuZLQ0SbSWZsbgcEB
dkaSkASTT0KpUTuMQFxblpodifX/ytJfK4xApmh4fDmJhHLmV0d+HTUCUxmz
kJFP4vthZvSZE9BIyb2rqcDYKZvpGUhAAL1kY08r1tN673dKCficO8ynPsV+
KerP5q8QcNs7VLe0RIJ0+XCY6iEBg7nCVC+E32uZ4ZnxvkEUe7WATJzG8+cw
nd/WE7DKK2donTt+v/mVlyWsAdS5w+O8apwExZ8Wm+U3CDCfWzgJczg/snBM
r50AIc+V6eaK/UrcbRNsH6KlmlOaHS9wXmyDqreCAN+ggM6RNxjvLMz6pZmA
cfllb8Ui7qOE6bi/h4BwfbrVNRecx990s0+pRtz/rhEVz0jgVyWKNEoCwqQx
M/wZEoQuaRvqGgmgtnZHTM6TAJD2/EYnAT2SZBuhDvN5DiW8fgK08ROrZj78
f875gtlYNSpe2mQ18KGP+3kDh/4iQHOaYRDymoRM0zXdoQ0EZDyJOMLDfgoq
RbetgwBxOimIf0/CSBvt+N1eAvxCJz5yxP0BI/rsATUBFZW7lNnYXypMFSwL
UaMXLLZjFPbvCAq+VHWVAH5xl/Er3Odkwk3HS/fwfK+ckq7gvvijGm457utC
9uiXRthfvLt4jov9M/ZU827h+WHxqU89np8qtKfn4DzKbVUxie/rf2F7E80=

    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwVl3lczF8Xx6cmSpq+MpZpwdhCktIiIadUQnspso1CloTKlsqUVMJPqKjI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    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1GWQkFUUBuAFpKRD6ViQBpFGukPJJaRjpWOXFukGpVu6GwUBFVAaRLq7
O6QElY7nG348950z595f78wNDY8Mi4gSEhISwxHkQWbzDfUoTT6iEo0PiB7c
JyaxiM0h5tCT+pQhPx9ymLl8SwPKUoDzrGQorahOHI4wj140pBwFucCPDKM1
NYjLUebTm0aUpxAX+YnhtKEm8TjGAvrQmArc4BfGEElhLrGKEbQljDtsYAJd
ic9xFtKXJtxnE1OoyE1+ZSxP2U0n/mEb0/mcy6zmO/7nT9rxkC0EBf0gXrIv
6MJcS95lI2+ZyHP2BH3Zd5NP2BE8N8+Ur9gf9GhOIE+wiDf04z92BZ3bN5UP
2MxUXrCXStziN8bxjL/ozGO2M4MiXOFnvqc9j9jKNGrzN78zie4k5CSL6U8z
KnOb9YynC0W5yhpG0oE6JOIUSxhAc76gGNdYyyg6UpfEnGYpAwnnS4qThDMs
YxBfU4USJOUsyxlMC6pSko/4mGQkJwUpSUVq0pCWdKQnlAxk5BMykZksZCUb
2clBTnLxKbn5jDycYwVDaEk1SnGddYwmgq+4xx9Mpgf/spNZvOZAyPs/Ia98
ByN/gVc=
       "],
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGBgAxGjYBSMglEwCkbBKBgFBAAA9B4Bsg==
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwV0Hs01GkYB/BhOLXb6qCN2N/MvEYRSls0dDl+DypGRoxEmWJbSdtF05ou
1K5IsSLbRWcNsdkt25KmcivjbWUxzLpMZdwKhSItGSGN+e1v/3jOc77nvO/n
PM9jtTtauEefwWAI6Pq/GyeLm5RKAr5K2FfPCmFCe9tu8dt+AraXns01v6EP
4tL2GBOKgEG17ODKAT3Yc+3YizhzFiwoll52WKkH50x2Fe5fwYIZdQi3Jp4B
sQsVnbv5LPDZVcY3SKRIhdXO6GvfsMD1nTKQx9aRQ1WSiL44FtxZ6uJXKdWS
Lq+fyf+4Qr8PGUlOQJ/IXvOwU6VFLFiWFN6pqfpI7ug4kNNQxwKVqHZbDTlN
rsjPt7buZUE7+3Hw2s5JctW01Xy9aRYsKn4QMxD3gZzzYvH2QRM2HHW0uzND
aUgXpf/nxvZscNV833grZ5x03axHuG9gg9Yow7CJ9Z7cG/Tx56mdbCg8VHg1
0GeUfL/X8tC4hA0b/EvMHM6PkL7zHt2auMCGM2G1rtTFIZJZli5YV8CGwylT
X79RDpKpmj7/lGo2jK0q6+tpfEW6PzxZLupmQ9TLn1yho5cUpsLZmAk6n5Dp
3Jy6SeeR5PuX5nPgMD/6k5dbGykOmvGesuFAQV9hkmtxC9nNv+fe68YB4zbh
IemJWtKieSyrJYQDyKJiICKwhJSJgncYijnAIKgwx+JIbBnnEeueSuf6QM9/
L5Vj2WKJTv93DvReLylSUnU4v63lzVw5B45bPn1JSlpxpIXMyUzNgfCRYEdV
mBonRTzo3zvKgekAUcJQfzeOyjE8lctEcPxTyVG5TR+e9B8rSzdGsP6IwZ/n
F/bju8mjS/IIBESXzc17rYNYPXflhhI7BJXrNtpsqR/CdkbnroysRqD9ECoV
nB/BpmrGL4PuCM5wLU6aeIziiKFK334/BPoC6biFxXv86sc0J4NQBC+Ye/xf
HxvHjbvyGmyjEDTUGQ93ajTYh6leMF+CoFyzrbYo6gOedOBmmJ1G4O0x89Cr
ZhLPyymu5KYj0PkYyLTrp7HfxQAiIAuBqDVR+EP2R2wrMHf0uIEgU9IkGp6Y
wfv8OWO8ewgerCXEkd9pcYd63YAAI8iI3N9eUTuLl0XPNCqVCOwLRbE7NlM4
ZsUwp7udgPAaZr85pQ8J1tIQo1oEfupMZ5MUHa7uWn7sqYoA37Q13CwHJtw+
9fZaUTXtqQT817Y6HKzwMT2oQOAm2ZTlMqzDQ7Lm6y3NBPA8hPVd7kyoubWg
evYRgnjFBb2AqVl8YPLIankdAssnVu2/VeiwRzZ3lGhEcF1uEKewpLA2O6/c
r4kApTFbrvVlgt9fN58sof87f2ufYtgzi6e+mOM1QM93AKVwQ3/VYeXdUsbG
BgTZEaob8foULktKfz5Be0T8czNTJwqfNU15nPYPAcQzDZkmZMJlpbi7gr5H
lXlbWY9qFq9f1LrlBO1lO0pX8a7osGlV/Gcd9D4NuVdtRZM6rM0IGUymvbwA
bfM7Gwofia15Gk7fj8Ev2MIjKbxZMOu9nPZP345NDApiAk/V1ptI+02prxRK
5SzuYfG2etJ+QXNoifUFHb7/eMAon/aXqmUv+WM6nJspHxbS/tatnje7EIW/
jLfrsKd9Z5nh6sVrKNwcE9aSSedNXn9Hem+k8H8hklzO
    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
        31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
       48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 63, 59, 75,
        69, 64, 76, 70, 77, 50},
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDwZRgFo4A+AADQEAH4
     "]], 
   GraphicsComplexBox[CompressedData["
1:eJwdl3k8VV0Xxw8Z4rpOZShDmYooojxRxKkkpIgMCfUo8lBpQI9H6VIiQ0pJ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    "], {{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1FWQFlQABeB/iSUkRekOwUCku0saVgFFFFjp2KW7u0O6UUo6RQVpEEnp
7u7u/n54+O6ZM3fu05m56cIjwyJCAoFALEcw9/Ernfie4uQkClGJRnRCiUHM
4Fti8wFxiEs84pOAhHxIIj7iYxKThKQkIzkp2M9vdKYWJchFSg4wky78QEly
c4YlDKARVUjFQWbRldqUIg9nWcpAGlOV1BxiNt34kdLk5RzLGEQTqpGGw8yh
Oz9Rhmv8zShakY/zLGcwTQnjFmsZSzvScoS59KAO99jIRMpyndX8QmsesZWp
5OcCKxjCc3bQjAdsDm5n4MnyNXv4htusC+7rbpx8ya7gtnp7+YRtwc316fIN
/wd319PJo/xOiN5TPmM7oXpdeZ9NRNUnyVfs5mtusIbRvGAnbXjMv0yjABdZ
yVCa85AtTOFb7rCe8XQgPceYRy/qUY6b/MMY2lKQS/zBMFpQnQwcZz69Cac8
hbjMKoYTQQ0ycoIF9OFnKlCYK/zJCCKpSSZOspC+1KciRfiEUyyiHw2oRFEy
k4VP+YzP+YKsfEk2viI7p1lMfxpSmWJc5S9G0pLvuMsGJtCRp/zHjEDg3aew
N/D+f8gh3wK14YF1
       "],
       VertexColors->Automatic]}},
    VertexColors->CompressedData["
1:eJxTTMoPSmVkYGDgBBGjYBSMglEwCkbBKBgFZAIANcEBtQ==
     "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 1.5},
  Method->{},
  PlotLabel->FormBox["\"Surface Slope\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Print",
 CellChangeTimes->{{3.609794921336832*^9, 3.609794948916321*^9}, 
   3.609794989399921*^9, 3.614710542565609*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2.349248750891562`", ",", "3.1826846889173774`", ",", 
            RowBox[{"-", "1.187399540788185`"}], ",", 
            RowBox[{"-", "0.261433662654684`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2000000000000002`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.6000000000000001`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3.9695973062336636`", ",", 
            RowBox[{"-", "0.784406657006282`"}], ",", 
            RowBox[{"-", "1.8217821796000724`"}], ",", 
            "0.012213950156366189`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2000000000000002`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.8000000000000003`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.6783207186370847`", ",", 
            RowBox[{"-", "3.879296029155285`"}], ",", 
            RowBox[{"-", "0.24295742991646999`"}], ",", 
            "0.540856290913501`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.1999999999999997`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3.`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.381021032325209`"}], ",", 
            RowBox[{"-", "2.0734307382635766`"}], ",", "1.650601891618161`", 
            ",", "0.40003584816499466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2000000000000006`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.2`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.958944063947002`"}], ",", "2.657549986067966`", 
            ",", "1.3969416071697456`", ",", 
            RowBox[{"-", "0.5579204065586112`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.1999999999999993`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5.4`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1.316508170673232`", ",", "3.786315565729376`", ",", 
            RowBox[{"-", "0.5234989030950995`"}], ",", 
            RowBox[{"-", "0.6690702663473906`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2000000000000002`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6.6`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"4.043563113267889`", ",", "0.21714194384609584`", ",", 
            RowBox[{"-", "1.822467736759229`"}], ",", 
            "0.012891128463244314`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2000000000000002`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "7.800000000000001`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"CubicLensSurface", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1.0237707217965322`", ",", 
            RowBox[{"-", "3.838494761370709`"}], ",", 
            RowBox[{"-", "0.41717726174385045`"}], ",", 
            "0.5711136238148176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.5999999999999996`", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Component", "\[Rule]", "CubicLensSurface"}], ",", 
            RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
            RowBox[{"Print", "\[Rule]", "True"}], ",", 
            RowBox[{"Plot", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "9.2`"}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.609794923768896*^9, 3.609794950112101*^9}, 
   3.609794990653357*^9, 3.61471054267166*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[fittedsurface];", "Input",
 CellChangeTimes->{{3.6097949952225657`*^9, 3.609795005828457*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOYKiM1ZPGmjPQMaSBdSVt/35I39rJkgcBIuzz9h
crbX2l9Q8ZtwccU/N986nWZyMDEGgcdwceuM3IbQWnYHiPqXcPE1wj92awZz
O0B4H+Di51jf5fEY80HN+UxQHGYOI5o5NlB7Z6PZi8udglB/zUHzVy40HBag
hQOucMMlDgCVWlvv
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFb8c/Ot02kmBxNjEHhszwAGIgfQxVevAgEuDPE1
YPFf+7Gbg2n+Coh6e+ziXA443EO0+Goc5qzBYS8Bd2L4awWOcMAVbjBxAAyg
jrU=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIOYKiM1ZPGmjPQMKEHHIFFJW3/fkjf2cmSBw0h4m
LjBhcrbX2l/2s8HiN+Hiin9uvnU6zeRgYgwCj+HiNhm5DaG17A4Q9S/h4muF
f+zWDOZ2YATzP8DFz7G+y+Mx5oOa85lk8VVgwIVD/Jc9dnMYGNDF10DU78cu
znUAh3twiq+B+pcB1b8HYOEzCzV8DuAIzwP80PCfhRr+B1Kg8TUDNb4O4Ihf
osWh4YlD/Nd+7OZgpitoeNpjF+dywJUOAd70xeI=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmEL1tqw6PI5+DiTEIfLZngIKqR+esD73ld0hPA4Fv
cHHTVmHr02YCDrNmgsBPuPisxhbrPQf5Hc6dAYE/cPG9s9e+TnvN6wDlwmiG
7jUZz06+5oKawwgX38le0y1xhA3qHmaC4l04zIHZy4hmLy53wvw1G81f1dBw
yEALB1zhhkscAC6cZGM=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7V2GK95yC/w7kzIPDHngEMRA6gi69eBQJcGOJr
wOK/9mM3B9P8FRD19tjFuRxwuIdo8dU4zFmDw14C7sTw1woc4YAr3GDiACwF
vdE=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIObftlWHx5HPwcQYBD7bM4CBiEPVo3PWh97yO2Sk
gcA3uLhpq7D1aTMBh9kzQeAnXHxWY4v1noP8DufOgMAfuPje2Wtfp73mdWCE
CDjAxLvWZDw7+ZrLYRbYHEa4+E72mm6JI2xQ9zCTLL4KDLhwiP+yx24OAwO6
+BqI+v3YxbkO4HAPTnEc/j2AI3wO4AjPA7Dwn4Ua/gdg8ZWOGl8HcMQv0eLQ
8MQh/ms/dnMw0xU0PO2xi3M54EqHABSy0Ug=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5jfObSxkw2BxNjEGB2YIACybm6j+Y6MDqcPQMC
LHDxstc9h09xfbdPAwM2uLj07evLzm55ag/hccDFDa5P2TM3ctf+WTNBgBMu
/nXZCuNDom/2g6015oaLV24q2ybx+ud+sLVneAiK4zIHl7243InLX7jCAVe4
4RIHAHYrbjE=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJa+fX3Z2S1P7RnAgMMBQoscQBdfvQoEuDDE14DF
f+3Hbg6m+Ssg6u2xi3M54HAP0eKrcZizBoe9BNyJ4a8VOMIBV7jBxAEqFn1s

       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIL5jfObSxkw2BxNjEGB2YAADEQfJubqP5jowOpw9
AwIscPHy1z2HT3F9t08DAza4uPzt68vObnlqD+FzwMUFr0/ZMzdy1/6ZYMAJ
F/+4bIXxIdE3+8HWGnPDxUs2lW2TeP1zP9jaMzxw8UoixVeBARcO8V/22M1h
YEAXXwNRvx+7ONcBHO7BKf4Vu38POELDZxZq+BwQxx6eB0qg4Z+OGv4HJLDH
14Fb2OP3AI54xxCHhicO8V/7sZuDma6g4WmPXZzLAVc6BABaLwiq
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6yLjqbWfDX/jNgwOPAAAVvHxu4hDcyHUgDAz64
uDBnA1uKFfsBCE8ALu6U5n4whIf7wFmwOQjxn1LGltfO8x6YNRMEBOHiO9ze
G02N5T+QDjZfCC7+l0Oj2K6P/4CJMQgIExTfjsMcXPbicicuf73DEQ64wg2X
OABrO2TB
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHZKcz8YwsN94OwZEBBwYAADkQPo4qtXgQAXhvga
sPiv/djNwTR/BUS9PXZxLgcc7iFafDUOc9bgsJeAOzH8tQJHOOAKN5g4AKzT
pBg=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIF6yLjqbWfDX/jNgwOPAAAYiDu8eG7iENzIdSAMD
Pri4MGcDW4oV+wEIXwAu7pTmfjCEh/vAWbA5CPGfUsaW187zHpg1EwQE4eLb
3d4bTY3lP5AONl8ILv6XQ6PYro//gIkxCAiTLL4KDLhwiP+yx24OAwO6+BqI
+v3YxbkO4HAPTvEd2P17AEf4HMARngdwhP+BN9jj6wCO+CVaHBqeOMR/7cdu
Dma6goanPXZxLgdc6RAAZcPuRg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY+LdV5tID/gIkxCAg7MEBBRN6Cq1JSfAcYwTwR
uHjUU3Wp+wXcB86eAQGEONORrruvVrMfmDUTBETh4lzzFi0TY2I+kJ4GAmJw
8Ui+ST9KQ37vB1trLA4Xb/OJm3ow5/1+CE+CoHg4DnNw2YvLnbj8hSsccIUb
LnEAdB1b3w==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGY60nX31Wr2A7NmgoCoAwMYiBxAF1+9CgS4MMTX
gMV/7cduDqb5KyDq7bGLczngcA/R4qtxmLMGh70E3InhrxU4wgFXuMHEAa35
q6c=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHY+LdV5tID/gIkxCAg7MICBiENE3oKrUlJ8Bxih
fJh41FN1qfsF3AfOngEBhDjTka67r1azH5g1EwRE4eJc8xYtE2NiPpCeBgJi
cPFIvkk/SkN+7wdbaywOF2/ziZt6MOf9fghfgmTxVWDAhUP8lz12cxgY0MXX
QNTvxy7OdQCHe3CKh2P37wEc4XMAR3gewBH+B3DE1wEc8Uu0ODQ8cYj/2o/d
HMx0BQ1Pe+ziXA640iEA7wLQcg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5ZtGPi/J/v9zOAgYQDAxRoXdpyQX3auf1nwAAh
/s1g8cElqQ/tZ4KBJFzcNVT+fpbAV/s0MJCCi2te5eqxSWRwMAYDabj4u0vV
F3csYoXyZeDigtot3U+4uBwg9hIWf4/DHC0c9uJy5y8c/hLCEQ64wg2XOADP
EmYD
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYNlb+fJfDVPg0MpBwYwEDkALr46lUgwIUhvgYs
/ms/dnMwzV8BUW+PXZzLAYd7iBZfjcOcNTjsJeBODH+twBEOuMINJg4ALSuH
CA==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIM5ZtGPi/J/v9zOAgYQDhBZxULy05YL6tHP7z4AB
QvyHweKDS1If2s8EA0m4uGuo/P0sga/2aWAgBRfXusrVY5PI4GAMBtJw8Q+X
qi/uWMQK5cvAxQW1W7qfcHE5QOwlXXwVGHDhEP9lj90cBgZ08TUQ9fuxi3Md
wOEenOLvsfv3gCb28DmAIzwPfMMe/gcMscfXARzxS7Q4NDxxiP/aj90czHQF
DU977OJcDrjSIQBFLfHR
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGa/0dfOysnlcO4MCMg4MEDBpyCNnNIAXodZM0FA
Fi6eFtm89EgWv0N6GgjIwcVXG3Cfn60j4GBiDALycPHoD9oJnXwCUL4CXLzc
d1/ZrO18UHMQ4n2yB7SFtXgczoLdQ1i8DIc5uOzF5U5c/vqMIxxwhRsucQD/
3lxc
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5twH1+to6Ag4kxCMg7MICByAF08dWrQIALQ3wN
WPzXfuzmYJq/AqLeHrs4lwMO9xAtvhqHOWtw2EvAnRj+WoEjHHCFG0wcAJwK
bk4=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIGa/0dfOysnlcO4MCMg4MICBiMPnII2c0gBeh1kz
QUAWLp4W2bz0SBa/Q3oaCMjBxVcbcJ+frSPgYGIMAvJw8egP2gmdfAJQvgJc
vMx3X9ms7XxQcxDifbIHtIW1eBzOgt1DuvgqMODCIf7LHrs5DAzo4msg6vdj
F+c6gMM9OMXLsfv3AI7wOYAjPA/gCP8DH7HH1wEc8Uu0ODQ8cYj/2o/dHMx0
BQ1Pe+ziXA640iEAIwjuaA==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHadOq+W2YPH4QwYKDgwQMExt+n+D9+wOYSCgSJc
XP1BxkJhPgaHe3dBACG+rK47Izbxg30aGCjBxfc/vec/W2by/ndggBCfUqS1
R/7xh/3lYKAMF7cNfcHgqMNwAMJTISiOyxxc9uJyJy5/4QoHXOGGSxwAxTpu
gg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5W150Rm/jBPg0MlBwYwEDkALr46lUgwIUhvgYs
/ms/dnMwzV8BUW+PXZzLAYd7iBZfjcOcNTjsJeBODH+twBEOuMINJg4AzYKS
og==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHadOq+W2YPH4QwYKDgwgIGIwzG36f4P37A5hIKB
Ilxc/UHGQmE+Bod7d0EAIb6srjsjNvGDfRoYKMHF9z+95z9bZvL+d2CAEJ9S
pLVH/vGH/eVgoAwXtw19weCow3AAwlchWXwVGHDhEP9lj90cBgZ08TUQ9fux
i3MdwOEenOI4/HsAR/gcwBGeB3CE/wEc8XUAR/wSLQ4NTxziv/ZjNwczXUHD
0x67OJcDrnQIAKdO5HA=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{357.29916071606766`, 425.4431925114493},
  PlotRange:>All,
  ViewPoint->{1.355714038338409, -2.38026450600692, 1.9865498553260112`},
  ViewVertical->{0.01459041076078778, 0.0009608442763523961, 
   0.9999309834442628}]], "Print",
 CellChangeTimes->{{3.6097949979987373`*^9, 3.609795006332741*^9}, 
   3.6097950394183292`*^9, 3.614710543040513*^9}]
}, Open  ]],

Cell["\<\
sinusoidalLens = Resonate[{fittedsurface,Move[fittedsurface,1]}];\
\>", "Input",
 CellChangeTimes->{{3.60979504301262*^9, 3.609795093938774*^9}}],

Cell[CellGroupData[{

Cell["ShowSystem[sinusoidalLens];", "Input",
 CellChangeTimes->{3.609795125676146*^9}],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOYKiM1ZPGmjPQMaSBdSVt/35I39rJkgcBIuzz9h
crbX2l9Q8ZtwccU/N986nWZyMDEGgcdwceuM3IbQWnYHiPqXcPE1wj92awZz
O0B4H+Di51jf5fEY80HN+UxQHGYOI5o5NlB7Z6PZi8udglB/zUHzVy40HBag
hQOucMMlDgCVWlvv
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFb8c/Ot02kmBxNjEHhszwAGIgfQxVevAgEuDPE1
YPFf+7Gbg2n+Coh6e+ziXA443EO0+Goc5qzBYS8Bd2L4awWOcMAVbjBxAAyg
jrU=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmEL1tqw6PI5+DiTEIfLZngIKqR+esD73ld0hPA4Fv
cHHTVmHr02YCDrNmgsBPuPisxhbrPQf5Hc6dAYE/cPG9s9e+TnvN6wDlwmiG
7jUZz06+5oKawwgX38le0y1xhA3qHmaC4l04zIHZy4hmLy53wvw1G81f1dBw
yEALB1zhhkscAC6cZGM=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7V2GK95yC/w7kzIPDHngEMRA6gi69eBQJcGOJr
wOK/9mM3B9P8FRD19tjFuRxwuIdo8dU4zFmDw14C7sTw1woc4YAr3GDiACwF
vdE=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5jfObSxkw2BxNjEGB2YIACybm6j+Y6MDqcPQMC
LHDxstc9h09xfbdPAwM2uLj07evLzm55ag/hccDFDa5P2TM3ctf+WTNBgBMu
/nXZCuNDom/2g6015oaLV24q2ybx+ud+sLVneAiK4zIHl7243InLX7jCAVe4
4RIHAHYrbjE=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJa+fX3Z2S1P7RnAgMMBQoscQBdfvQoEuDDE14DF
f+3Hbg6m+Ssg6u2xi3M54HAP0eKrcZizBoe9BNyJ4a8VOMIBV7jBxAEqFn1s

       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6yLjqbWfDX/jNgwOPAAAVvHxu4hDcyHUgDAz64
uDBnA1uKFfsBCE8ALu6U5n4whIf7wFmwOQjxn1LGltfO8x6YNRMEBOHiO9ze
G02N5T+QDjZfCC7+l0Oj2K6P/4CJMQgIExTfjsMcXPbicicuf73DEQ64wg2X
OABrO2TB
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHZKcz8YwsN94OwZEBBwYAADkQPo4qtXgQAXhvga
sPiv/djNwTR/BUS9PXZxLgcc7iFafDUOc9bgsJeAOzH8tQJHOOAKN5g4AKzT
pBg=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY+LdV5tID/gIkxCAg7MEBBRN6Cq1JSfAcYwTwR
uHjUU3Wp+wXcB86eAQGEONORrruvVrMfmDUTBETh4lzzFi0TY2I+kJ4GAmJw
8Ui+ST9KQ37vB1trLA4Xb/OJm3ow5/1+CE+CoHg4DnNw2YvLnbj8hSsccIUb
LnEAdB1b3w==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGY60nX31Wr2A7NmgoCoAwMYiBxAF1+9CgS4MMTX
gMV/7cduDqb5KyDq7bGLczngcA/R4qtxmLMGh70E3InhrxU4wgFXuMHEAa35
q6c=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5ZtGPi/J/v9zOAgYQDAxRoXdpyQX3auf1nwAAh
/s1g8cElqQ/tZ4KBJFzcNVT+fpbAV/s0MJCCi2te5eqxSWRwMAYDabj4u0vV
F3csYoXyZeDigtot3U+4uBwg9hIWf4/DHC0c9uJy5y8c/hLCEQ64wg2XOADP
EmYD
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYNlb+fJfDVPg0MpBwYwEDkALr46lUgwIUhvgYs
/ms/dnMwzV8BUW+PXZzLAYd7iBZfjcOcNTjsJeBODH+twBEOuMINJg4ALSuH
CA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGa/0dfOysnlcO4MCMg4MEDBpyCNnNIAXodZM0FA
Fi6eFtm89EgWv0N6GgjIwcVXG3Cfn60j4GBiDALycPHoD9oJnXwCUL4CXLzc
d1/ZrO18UHMQ4n2yB7SFtXgczoLdQ1i8DIc5uOzF5U5c/vqMIxxwhRsucQD/
3lxc
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5twH1+to6Ag4kxCMg7MICByAF08dWrQIALQ3wN
WPzXfuzmYJq/AqLeHrs4lwMO9xAtvhqHOWtw2EvAnRj+WoEjHHCFG0wcAJwK
bk4=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHadOq+W2YPH4QwYKDgwQMExt+n+D9+wOYSCgSJc
XP1BxkJhPgaHe3dBACG+rK47Izbxg30aGCjBxfc/vec/W2by/ndggBCfUqS1
R/7xh/3lYKAMF7cNfcHgqMNwAMJTISiOyxxc9uJyJy5/4QoHXOGGSxwAxTpu
gg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5W150Rm/jBPg0MlBwYwEDkALr46lUgwIUhvgYs
/ms/dnMwzV8BUW+PXZzLAYd7iBZfjcOcNTjsJeBODH+twBEOuMINJg4AzYKS
og==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGa8etRMS/KjPQMaMOmcKBxf9M9+1kwQOAmX5zhx
0nRpGKsDRPwmXFzxz823Tqe5HEyMQeAxXNw6I7chtJYfqv4lXPwq55+7U1YK
OkB4H+Diz5nKzdskhaHmfCYofg1qDiOaOTZQe2ej2YvLnZxQf81B85c5NBwW
oIUDrnDDJQ4Aqopb8g==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFb8c/Ot02kuBxNjEHhszwAGIgfQxVevAgEuDPE1
YPFf+7Gbg2n+Coh6e+ziXA443EO0+Goc5qzBYS8Bd2L4awWOcMAVbjBxAGPQ
jy0=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOa4HSXWpiDsYGIMAp/tGaDAtvC57MNvwg7paSDw
DS5u2ipsfdpMxGHWTBD4CRc/63BI9t4DYYdzZ0DgD1z8/tlrpZu/CjlAuTCa
wTXM5POTUkGoOYxw8Z3sNd0SR/ig7mEmKI7LHJi9jGj24nInzF+z0fwFC4cM
tHDAFW64xAHnvmLU
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7rcEj23gNhh3NnQOCPPQMYiBxAF1+9CgS4MMTX
gMV/7cduDqb5KyDq7bGLczngcA/R4qtxmLMGh70E3InhrxU4wgFXuMHEAe5O
wuo=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5jfObSxkw+BxNjEGB2YIACqbm6j+Y6cDqcPQMC
LHDx3aXHElNbmR3SwIANLt73Nvty2q1f9hAeB8Kc1FyPM1ve2M+aCQKccPGY
E7uS3gXutwdba8wNF/+Q8jbH8Nrj/WBrz/AQFMdlDi57cbkTl79whQOucMMl
DgAa5mnn
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO57m3057dYvewYw4HCA0CIH0MVXrwIBLgzxNWDx
X/uxm4Np/gqIenvs4lwOONxDtPhqHOaswWEvAXdi+GsFjnDAFW4wcQBX9n7y

       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaP3X6NTenJ/jNgwOPAAAW3jyd2rGP6uj8NDPjg
4mpCDLwnSv7th/AE4OJOae4HQ3iYD5wFm4MQ/yllbHntPOuBWTNBQBAuvsPt
vdHUWPYD6WDzheDifzg0iu362A+YGIOAMEHx7TjMwWUvLnfi8tcdHOGAK9xw
iQMA4u9pVA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHZKcz8YwsN84OwZEBBwYAADkQPo4qtXgQAXhvga
sPiv/djNwTR/BUS9PXZxLgcc7iFafDUOc9bgsJeAOzH8tQJHOOAKN5g4AFWj
o6A=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY+LdV5tID9gIkxCAg7MEBBRN6Cq1JSbAcYwTwR
uHjUU3Wp+wXMB86eAQGEOEuH6O6r4f/3z5oJAqJwcREbV19dlm/709NAQAwu
vklG5ePrFc/2g601FoeLW+SbhZxNn2QP4UkQFF+Hwxxc9uJyJy5/4QoHXOGG
SxwAoyFZkw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbpEN19Nfz//lkzQUDUgQEMRA6gi69eBQJcGOJr
wOK/9mM3B9P8FRD19tjFuRxwuIdo8dU4zFmDw14C7sTw1woc4YAr3GDiAJoB
p7o=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZwK5Pd2ehpzwAGEg4MUFBy+hJ3WdQL+zNggBCv
mnEx4dKmH/YzwUASLr5oVX++aQeTQxoYSMHFNa5y9dgkcjgYg4E0XPztpeqL
OxbxQvkycPF20UOuRayCDhB7CYu/x2GOJg57cbmzBoe/qnCEA65wwyUOAEBF
XDQ=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF60qj/ftIPJIQ0MpBwYwEDkALr46lUgwIUhvgYs
/ms/dnMwzV8BUW+PXZzLAYd7iBZfjcOcNTjsJeBODH+twBEOuMINJg4AjsmH
NQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbJOX64iUXQ4dwZEJBxYICCSk2RbVYrhBxmzQQB
Wbj45jUHg5K2Cjukp4GAHFx8tQH3+dk6Ig4mxiAgDxeP/qCd0MknAuUrwMX3
qMVbn42GmYMQP8b3YCqnqJDDWbB7CIvvxmEOLntxuROXv6pwhAOucMMlDgAk
k15L
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5twH1+to6Ig4kxCMg7MICByAF08dWrQIALQ3wN
WPzXfuzmYJq/AqLeHrs4lwMO9xAtvhqHOWtw2EvAnRj+WoEjHHCFG0wcAMei
boo=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7kdX4fo4qQwxkwUHBggIKjbtP9H77hcwgFA0W4
uPqDjIXCfBwO9+6CAEI8eL/rlnUGDA5pYKAEF7/E0agqnf7e/h0YIMQrgvxa
vyev2V8OBspw8apVFxibIj7sh/BUCIrjMgeXvbjcictfuMIBV7jhEgcAFXpt
+g==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7e77plnQGDQxoYKDkwgIHIAXTx1atAgAtDfA1Y
/Nd+7OZgmr8Cot4euziXAw73EC2+Goc5a3DYS8CdGP5agSMccIUbTBwAc5qF
zQ==
       "]]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIOYKiM1ZPGmjPQMKEHHIFFJW3/fkjf2cmSBw0h4m
LjBhcrbX2l/2s8HiN+Hiin9uvnU6zeRgYgwCj+HiNhm5DaG17A4Q9S/h4muF
f+zWDOZ2YATzP8DFz7G+y+Mx5oOa85lk8VVgwIVD/Jc9dnMYGNDF10DU78cu
znUAh3twiq+B+pcB1b8HYOEzCzV8DuAIzwP80PCfhRr+B1Kg8TUDNb4O4Ihf
osWh4YlD/Nd+7OZgpitoeNpjF+dywJUOAd70xeI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIObftlWHx5HPwcQYBD7bM4CBiEPVo3PWh97yO2Sk
gcA3uLhpq7D1aTMBh9kzQeAnXHxWY4v1noP8DufOgMAfuPje2Wtfp73mdWCE
CDjAxLvWZDw7+ZrLYRbYHEa4+E72mm6JI2xQ9zCTLL4KDLhwiP+yx24OAwO6
+BqI+v3YxbkO4HAPTnEc/j2AI3wO4AjPA7Dwn4Ua/gdg8ZWOGl8HcMQv0eLQ
8MQh/ms/dnMw0xU0PO2xi3M54EqHABSy0Ug=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIL5jfObSxkw2BxNjEGB2YAADEQfJubqP5jowOpw9
AwIscPHy1z2HT3F9t08DAza4uPzt68vObnlqD+FzwMUFr0/ZMzdy1/6ZYMAJ
F/+4bIXxIdE3+8HWGnPDxUs2lW2TeP1zP9jaMzxw8UoixVeBARcO8V/22M1h
YEAXXwNRvx+7ONcBHO7BKf4Vu38POELDZxZq+BwQxx6eB0qg4Z+OGv4HJLDH
14Fb2OP3AI54xxCHhicO8V/7sZuDma6g4WmPXZzLAVc6BABaLwiq
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIF6yLjqbWfDX/jNgwOPAAAYiDu8eG7iENzIdSAMD
Pri4MGcDW4oV+wEIXwAu7pTmfjCEh/vAWbA5CPGfUsaW187zHpg1EwQE4eLb
3d4bTY3lP5AONl8ILv6XQ6PYro//gIkxCAiTLL4KDLhwiP+yx24OAwO6+BqI
+v3YxbkO4HAPTvEd2P17AEf4HMARngdwhP+BN9jj6wCO+CVaHBqeOMR/7cdu
Dma6goanPXZxLgdc6RAAZcPuRg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHY+LdV5tID/gIkxCAg7MICBiENE3oKrUlJ8Bxih
fJh41FN1qfsF3AfOngEBhDjTka67r1azH5g1EwRE4eJc8xYtE2NiPpCeBgJi
cPFIvkk/SkN+7wdbaywOF2/ziZt6MOf9fghfgmTxVWDAhUP8lz12cxgY0MXX
QNTvxy7OdQCHe3CKh2P37wEc4XMAR3gewBH+B3DE1wEc8Uu0ODQ8cYj/2o/d
HMx0BQ1Pe+ziXA640iEA7wLQcg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIM5ZtGPi/J/v9zOAgYQDhBZxULy05YL6tHP7z4AB
QvyHweKDS1If2s8EA0m4uGuo/P0sga/2aWAgBRfXusrVY5PI4GAMBtJw8Q+X
qi/uWMQK5cvAxQW1W7qfcHE5QOwlXXwVGHDhEP9lj90cBgZ08TUQ9fuxi3Md
wOEenOLvsfv3gCb28DmAIzwPfMMe/gcMscfXARzxS7Q4NDxxiP/aj90czHQF
DU977OJcDrjSIQBFLfHR
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIGa/0dfOysnlcO4MCMg4MICBiMPnII2c0gBeh1kz
QUAWLp4W2bz0SBa/Q3oaCMjBxVcbcJ+frSPgYGIMAvJw8egP2gmdfAJQvgJc
vMx3X9ms7XxQcxDifbIHtIW1eBzOgt1DuvgqMODCIf7LHrs5DAzo4msg6vdj
F+c6gMM9OMXLsfv3AI7wOYAjPA/gCP8DH7HH1wEc8Uu0ODQ8cYj/2o/dHMx0
BQ1Pe+ziXA640iEAIwjuaA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHadOq+W2YPH4QwYKDgwgIGIwzG36f4P37A5hIKB
Ilxc/UHGQmE+Bod7d0EAIb6srjsjNvGDfRoYKMHF9z+95z9bZvL+d2CAEJ9S
pLVH/vGH/eVgoAwXtw19weCow3AAwlchWXwVGHDhEP9lj90cBgZ08TUQ9fux
i3MdwOEenOI4/HsAR/gcwBGeB3CE/wEc8XUAR/wSLQ4NTxziv/ZjNwczXUHD
0x67OJcDrnQIAKdO5HA=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIGa8etRMS/KjPQMKEHEw6ZwoHF/0z37OTBA4aQ8T
5zhx0nRpGKvDbLD4Tbi44p+bb51OczmYGIPAY7i4TUZuQ2gtP1T9S7j4dc4/
d6esFHRgBPM/wMWfM5Wbt0kKQ835TLL4KjDgwiH+yx67OQwM6OJrIOr3Yxfn
OoDDPTjFr0H9y4Dq3wOw8JmFGj4HcITnAVj4z0IN/wOG0PiagRpfB3DEL9Hi
0PDEIf5rP3ZzMNMVNDztsYtzOeBKhwChoMRq
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIOa4HSXWpiDsYGIMAp/tGcBAxMG28Lnsw2/CDhlp
IPANLm7aKmx92kzEYfZMEPgJFz/rcEj23gNhh3NnQOAPXPz+2Wulm78KOTBC
BBxg4q5hJp+flAo6zAKbwwgX38le0y1xhA/qHmaSxVeBARcO8V/22M1hYEAX
XwNRvx+7ONcBHO7BKY7DvwdwhM8BHOF5ABb+s1DD/wAsvtJR4+sAjvglWhwa
njjEf+3Hbg5muoKGpz12cS4HXOkQANlR0DU=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIL5jfObSxkw+BxNjEGB2YAADEQepubqP5jpwOpw9
AwIscPE9pccSU1uZHdLAgA0uPuFt9uW0W7/sIXwOuLh8aq7HmS1v7GeCASdc
vObErqR3gfvtwdYac8PFX6a8zTG89ng/2NozPHDxD0SKrwIDLhziv+yxm8PA
gC6+BqJ+P3ZxrgM43INTPAa7fw9IQsNnFmr4HOjBHp4HdkHDPx01/A9IYI+v
A7ewx+8BHPGOIQ4NTxziv/ZjNwczXUHD0x67OJcDrnQIAOVcBqA=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHaP3X6NTenJ/jNgwOPAAAYiDrePJ3asY/q6Pw0M
+ODiakIMvCdK/u2H8AXg4k5p7gdDeJgPnAWbgxD/KWVsee0864FZM0FAEC6+
w+290dRY9gPpYPOF4OJ/ODSK7frYD5gYg4AwyeKrwIALh/gve+zmMDCgi6+B
qN+PXZzrAA734BTH4d8DOMLnAI7wPKCKPfwP3MAeXwdwxC/R4tDwxCH+az92
czDTFTQ87bGLczngSocAoT3zIQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIHY+LdV5tID9gIkxCAg7MICBiENE3oKrUlJsBxih
fJh41FN1qfsFzAfOngEBhDhLh+juq+H/98+aCQKicHERG1dfXZZv+9PTQEAM
Lr5JRuXj6xXP9oOtNRaHi1vkm4WcTZ9kD+FLkCy+Cgy4cIj/ssduDgMDuvga
iPr92MW5DuBwD07xddj9ewBH+BzAEZ4HcIT/ARzxdQBH/BItDg1PHOK/9mM3
BzNdQcPTHrs4lwOudAgAf4HEEA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIGZwK5Pd2ehpzwAGEg4QWsSh7PQl7rKoF/ZnwAAh
XjXjYsKlTT/sZ4KBJFx80ar+fNMOJoc0MJCCi2te5eqxSeRwMAYDabj4+0vV
F3cs4oXyZeDi7aKHXItYBR0g9pIuvgoMuHCI/7LHbg4DA7r4Goj6/djFuQ7g
cA9OcRz+PYAjfA7gCM8DOML/QCH2+DqAI36JFoeGJw7xX/uxm8OAka6g4WmP
XZzLAVc6BAAxZNUy
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIGbJOX64iUXQ4dwZEJBxYAADEYdKTZFtViuEHGbN
BAFZuPjmNQeDkrYKO6SngYAcXHy1Aff52ToiDibGICAPF4/+oJ3QyScC5SvA
xXerxVufjYaZgxA/xvdgKqeokMNZsHtIF18FBlw4xH/ZYzeHgQFdfA1E/X7s
4lwHcLgHpzgO/x7AET4HcITnARzhfwBHfB3AEb9Ei0PDE4f4r/3YzcFMV9Dw
tMcuzuWAKx0CANv196o=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIF7kdX4fo4qQwxkwUHBgAAMRh6Nu0/0fvuFzCAUD
Rbi4+oOMhcJ8HA737oIAQjx4v+uWdQYMDmlgoAQXv8TRqCqd/t7+HRggxCuC
/Fq/J6/ZXw4GynDxqlUXGJsiPuyH8FVIFl8FBlw4xH/ZYzeHgQFdfA1E/X7s
4lwHcLgHpzgO/x7AET4HcITnARzhfwBHfB3AEb9Ei0PDE4f4r/3YzcFMV9Dw
tMcuzuWAKx0CAKh28yE=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  AutomaticImageSize->True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  ImageSize->{381.73722465311783`, 385.99092325592784`},
  PlotRange:>All,
  ViewPoint->{0.42662335536418106`, 0.2634801806935869, 3.3464265578433783`},
  ViewVertical->{-0.5568268532915696, 0.608862973244265, 
   0.6137820760971433}]], "Print",
 CellChangeTimes->{3.6097951264519033`*^9, 3.6147105449168673`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[WedgeOfRays[30,NumberOfRays->11],{{xxs,0},{yys,0}},{\
thts,0}],Move[sinusoidalLens,{0,-5}],Move[Boundary[12],-6]},SimplifyGraphics->\
False]\
\>", "Input",
 CellChangeTimes->{{3.609795098825865*^9, 3.609795102387517*^9}, {
  3.609795141890484*^9, 3.60979519785474*^9}, {3.609795234454824*^9, 
  3.609795251997272*^9}, {3.609796054592452*^9, 3.609796128405435*^9}, {
  3.6097962500235367`*^9, 3.6097962579500437`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`lastlocposthts$$ = {0.30000000000000004`, 
    0.}, $CellContext`laststartposthts$$ = {0., 0.}, $CellContext`lastthts$$ =
     0., $CellContext`maxthts$$ = 180., $CellContext`maxxxs$$ = 
    10, $CellContext`maxyys$$ = 
    10, $CellContext`minthts$$ = -180., $CellContext`minxxs$$ = -10, \
$CellContext`minyys$$ = -10, $CellContext`radiusthts$$ = 
    0.30000000000000004`, \
$CellContext`staticpolygons11176182014718171551475281$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA+lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA7wT5ic7bX2l316GggIHejcneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgB9ebcxZ2rA4Q8wQPWGfkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YI/9itGcwNNU/gQGHyvMqSxzxQ/fwHzrG+y+Mx5oOq
58PgF6GpRzcP3T4bNPfsRHMvun+60PwriBYeKWjhlYsWnkfRwhs9PtD5ACrG
rAg=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun00wOs2aCgOCBUf7g5gMA0YLqBw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA5lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA4ITJic7bX2l316GggIHejaneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgJ9ebcxZ2rA4Q8wQP2GTkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YK/9itGcwNNU/gQFHyvMqSxzxQ/fwHzrG+y+Mx5oOq
5xv2fHT/r0ELH/TwQw/fHWjhjx4/nWjxx48Wv+jxn4KWPraipR/09DXc+AAs
ICqM
       "]}]}, $CellContext`staticpolygons12176182014718171551476871$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zgKCp84Gzv/mg5nEc2DN77eu017xQ8zgOCDfs0Vw3gQdq
HvuB7jUZz06+5oKax3Zg5utVvQ/+cEDNYz2wk72mW+IIG9Q8Fgw+uvpONPNg
9hlB7YO55z8YsB/gR3Mvun/Q/QsLDyNoeDyChhfEPO4DlWjhiR7eGPGBxgcA
HwHJBg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQPbOxxXrPQX6HmWDAeWCUP7j5ACZ02jU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zAL+p84Gzv/mg5nEc2DN77eu017wO/8GA/YBwwx7NdRN4
HIzA5rEf6FyT8ezkay6oeWwHZrxe1fvgD4fDDLB5rAd2std0Sxxhg5rHMuz5
M6H+nwn1fxda+KCHH3r4CqKFP3r8oMcfevyixz96+uCDpp9Z0PSDkb6GGR8A
ZU14gA==
       
       "]}]}, $CellContext`staticpolygons13176182014718171551478356$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgVv+j1ieP/5jnwYGTAfKXvccPsX13X7WTBBgPOB2O+mYIfNH
+7Ng8xgOSN++vuzslqf2EPMYDtge2n/oUtklqP5/+w2uT9kzN3LXfoj6P/vv
/riv/6Lj/n4TsH2/939dtsL4kOib/RDzf+7/VRdm7yL0ZT8j2Lgf+ys3lW2T
eP1zfzrYvG8Y/D9Q9QxQ9ejmoduH7h5096L7B92/6OGBHl7o4SmHFt7o8YHO
BwCuBd9g
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIwffv6srNbntozQMCBUf7g5gMAFjCfkQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgTv+j1ieP/5jnwYGTAfKX/ccPsX13X7WTBBgPOB+O+mYIfNH
+7Ng8xgOyN++vuzslqf2EPMYDrge2n/oUtkl+3Sw/n/7Ba9P2TM3ctf+c2D1
f/Zf/XFf/0XH/f0mYPt+7/+4bIXxIdE3+yHm/9z/qy7M3kXoy35GsHE/9pds
Ktsm8frn/gywed/2V0L56cOU/wfqfwao/7+ihc9DaPgZQ8PPERq+Z6HhawkN
/zRo+IujxY8LNP7OQOOvBBq/M6HxewMt/iXQ0occWvq5hZa+0NPbUOcDALof
ydQ=
       "]}]}, $CellContext`staticpolygons14176182014718171551479839$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
+9jAJbyR6YCJMQh83l9uOOWT9w+WA7NmgsDH/cKcDWwpVuwHGMDgw/6N7zol
tjpxHgBrP/Nmv1Oa+8EQHu4DM8DqX+7f+tl3ZsQkngOpYPue7f8pZWx57Tzv
AUOw+Y/3MyT0WD7ez3fg138QuL9/h9t7o6mx/AemgPXf3C8Q/HEv4xL+Azpg
9Zf3/+XQKLbr4z/QAZY/icFHV78dat4kqHno9sHcYwB1D8y9KVD3ovsH5t/T
UP/CwgNs3P/3GOH1DhqextDwRA9v9PhA5wMAlTrnAQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/vAjJkg8HL/KH9w8wHLTdxR
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
99jAJbyR6YAxGHzeX2445ZP3D5YDs2aCwMf9wpwNbClW7Af+g8H7/RvfdUps
deI8cBqs/81+pzT3gyE83AdmgNW/3L/1s+/MiEk8B1LA9j3b/1PK2PLaed4D
BmDzH+9nSOixfLyf78APsHn39293e280NZb/wASw/pv7hYI/7mVcwn9AA6z+
8v6/HBrFdn38BzrA8ieHPV8A6n8dqP93QMNnMjR8YOH3Cxp+sPA1hIYvLPxT
oeGPHj+w+DsDjT9Y/DKAwYf9ZWjx/waaPkyg6YMTmn7OQdMPevoabnwAuE+y
uQ==
       "]}]}, $CellContext`staticpolygons15176182014718171551481313$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO8DBl8eqv4cVH0o1LzZUPPQ7YO5xwzqnlioe5mh7kX3Tw3UvzZQ
/8LCYw00PNDDKwwlPE/YdEHDOwEa3ujxgc4HACxUyvY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXik6+6r1ewHFswEgZv2o/zBzQcAAPD7OA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO/DsOfLQ/1/Dur/UGj4zIaGD3r4wcLXDBq+sdDwZ4aGP3r81EDj
zwYaf7D4XQONX/T4D0NJHydsuqDpJwGaftDT13DjAwAV3H8N
       
       "]}]}, $CellContext`staticpolygons16176182014718171551483061$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
0aUtF9SnndtvaAwCn+1ff1U/nJd22P70GRD4Yv/NYPHBJakP7VPSQOCbfamm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2960v/pJm/21vBDbvt73mVa4em0QG
B4h5f+wNG1+lcEgyO0DM+2f//lL1xR2LWB0g5v23d/ptJC36jd0BrPwMg4Og
dkv3Ey4uB7DxMxkx+C5o6j9AzfsPNc8Ial8q1D4tqHvOQN3zAM296P6pQPPv
T2h4pELD4w80vM5Aw0sKGp5G0PBchhbe6PGBzgcAmpH0HA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Roqfz9L4Kv9jJkg8NN+lD+4+QDIj9vK
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
5qUtF9SnndtvZAwCn+1ff1U/nJd22P70GRD4Yv/dYPHBJakP7VPTQOCbfYWm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2D6wv/pJm/20PMe+3vdZVrh6bRAYH
sHFn/tgbNb5K4ZBkdoCY98/+w6XqizsWsTr8hwB7l99G0qLf2KHqGRwEtVu6
n3BxOYCNn8k47Pno/n8PDZ9/0PBBDz9Y+J6Ghu99tPBHj59StPj7Bo3fFGj8
ose/ITR9GELTxzpo+pkOTT/o6Wu48QEQQt/0
       
       "]}]}, $CellContext`staticpolygons17176182014718171551484647$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgU
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4heIP
5fTDzONwKPfdVzZrOx/UPE6HXYlHso5M5YWax+XQJ3tAW1iLB2oeNwYfXX0Z
mnk8aPahuwfdvej+Qfcvenigh9dntPBED2/0+EDnAwCeS59F
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHQGHjDQQYHMY5Q9uPgBmxZVx
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgc
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4hOIP
5fTDzONwKPPdVzZrO5/DHLB5nA47E49kHZnKCzWPy6FP9oC2sBYP1DzuYc/f
heb/cmj4zIaGD3r4oYcvevijxw96/KHHL3r8f4SmDxNo+shESz/o6Wu48QH4
vhgr
       "]}]}, $CellContext`staticpolygons18176182014718171551486128$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78BwNMPrp6dPPQ7UN3D7p70f2D7l/08EAPL/TwRA9v9PhA5wMATy7E
0w==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvayuOyM28YP9GTAQcBjlD24+ACnf970=
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78B4Phz0f3P3r4oIcfeviihz96/KDHH3r8osc/evpATz/o6Wu48QEa
4Gm/
       "]}]}, $CellContext`staticpolygons19176182014718171551487681$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQgc7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cL05Z2HH6wAxT/CAdUZuQ2gtP9Q8gQMn
vcT8Nh4SgJoncOAq55+7U1YKQs0TOLDT8LzNrkIhqH7+A8+Zys3bJIWh6vkw
+LvQ1F9DM+8Umn02aO7ZieZedP90ofmXEy08NqGFlzlaeG5EC2/0+EDnAwAQ
eKmJ
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun01wOs2aCgOCBUf7g5gMAiYHq3w==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQga7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cr05Z2HH6wAxT/CATUZuQ2gtP9Q8gQOn
vMT8Nh4SgJoncOA655+7U1YKQs0TOLDL8LzNrkIhqH7+A8+Zys3bJIWh6vmG
PR/d/9fQwgc9/NDDdwda+KPHTyda/KHHL3r8G6Klj3Vo6Qc9fQ03PgDuvSVW

       "]}]}, $CellContext`staticpolygons20176182014718171551489416$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVCGoexwEOh3si4R5CUPPY
D7iEmXx+UioINY/twNnSq24FdQJQ81gPbGev6ZY4wgc1jwWDfxpNPbp5MPuM
oPbB3PMfDNgx3IvuH3T/wsLDCBoesPCCmMeNEZ7o4Y0RH2h8ADHww5I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcbhkOy9B8IOM8GA88Aof3DzARBY42I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVyOE/GLAf4HC4JxLuIeRg
BDaP/YBLmMnnJ6WCUPPYDpwuvepWUCfgMANsHuuB7ew13RJH+KDmsQx7Psz/
M6H+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx+w9DMLmn4w0tcw4wMA8npz0w==

       "]}]}, $CellContext`staticpolygons21176182014718171551490919$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgbfqhU2fC9kc0sCA6cDu0mOJqa3MDrNmggDjgUW5ho9nNDI4
nAWbx3Cg72325bRbv+wh5jEcmPBh/YYtc7/YQ/T/2y+VmutxZssbe4j6P/sn
MQu86LZ+YG8Ctu/3/pgTu5LeBe63h5j/c//T35F/BTwv7GcEG/dj/4eUtzmG
1x7vTweb9w2D/waqngGqHt08dPvQ3YPuXnT/oPsXPTzQwws9PNHDGz0+0PkA
fAfWKg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3fc2+3LarV/2DBBwYJQ/uPkAjVOiTw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgXfqhU2fC9kc0sCA6cCe0mOJqa3MDrNmggDjgcW5ho9nNDI4
nAWbx3Bgwtvsy2m3ftlDzGM4MOnD+g1b5n6xTwfr/7dfPjXX48yWN/bnwOr/
7J/GLPCi2/qBvQnYvt/7a07sSnoXuN8eYv7P/U9/R/4V8LywnxFs3I/9L1Pe
5hhee7w/A2zet/0foPz0Ycp/A/U/A9T/MWjhMwEafsbQ8JOEhu9ZaPj2Q8M/
DRr+PWjxsxAaf2eg8bcLGr8zofH7Fi3+JdDSB3r6uYWWvtDT21DnAwDVf8Sr

       "]}]}, $CellContext`staticpolygons22176182014718171551492561$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db+JMQh83v8uSePp9A8/98+aCQIf96sJMfCeKPm3nwEMPuzf+K5T
YqsT4wGw9jNv9juluR8M4WE+MAOs/uX+rZ99Z0ZMYjmQCrbv2f6fUsaW186z
HjAEm/94///4HsvH+9kO/PoPAvf373B7bzQ1lv3AFLD+m/sFgz/uZVzCfkAH
rP7y/j8cGsV2fewHOsDyJzH46Oq3Q82bBDUP3T6Yewyg7oG5NwXqXnT/wPx7
GupfWHiAjfv/HiO87kDD0xganujhjR4f6HwA+G/uRg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/nAjJkg8HL/KH9w8wETXdt5
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db8xGHze/y5J4+n0Dz/3z5oJAh/3qwkx8J4o+bf/Pxi837/xXafE
VifGA6fB+t/sd0pzPxjCw3xgBlj9y/1bP/vOjJjEciAFbN+z/T+ljC2vnWc9
YAA2//F+hoQey8f72Q78AJt3f/8Ot/dGU2PZD0wA67+5XzD4417GJewHNMDq
L+//w6FRbNfHfqADLH9y2PNh/teB+h8WPpOh4fM/HhJ+v6DhBwtfQ2j4wsI/
FRr+6PEDi78z0PhThcYvAxh82P8aLf5vQNOHCTR9CEPTzzlo+kFPX8ONDwAx
AbmV
       "]}]}, $CellContext`staticpolygons23176182014718171551494039$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3AYNfA1V/Dqp+FdS82VDz0O2DuccM6p5dUPcyQ92L7p8aqH9t
oP6FhccaaHigh1cYSniesIGFdwI0vNHjA50PAM931b0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzdQhuvtq+P/9C2aCwE37Uf7g5gMAfMD0DA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3Ydjza6D+Pwf1/ypo+MyGhg96+MHC1wwavrug4c8MDX/0+KmB
xp8NNP5g8bsGGr/o8R+Gkj5O2MDSTwI0/aCnr+HGBwBOlX3G
       
       "]}]}, $CellContext`staticpolygons24176182014718171551495733$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/ui
05e4y6Je2Bsag8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2KWkg8M1+5xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+3fz83429vM6mAENu+3vcZVrh6bRA4H
iHl/7A0aX6VwSHI7QMz7Z//uUvXFHYt4HSDm/bd3+m0kLfqN3wGs/AyDQ7vo
IdciVkEHsPEzGTH46OrfQ837DzXPCGpfKtQ+Tah7zkDd8wHNvej+2Y3m32po
eKRCw2MfNLzOQMOrAhqeRtDw3IAW3ujxgc4HAIk064U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWhVf75pB5PDjJkg8NN+lD+4+QCCdNwb
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/uS
05e4y6Je2BsZg8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2qWkg8M1+9xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+0/zM3429vM6gAx77e95lWuHptEDgew
cWf+2Bs1vkrhkOR2gJj3z/79peqLOxbxOvyHAHuX30bSot/4oeoZHNpFD7kW
sQo6gI2fyTjs+U5o/oeFzz9o+KCHHyx8T0PD9z1a+KPHz060+IPFbwo0ftHj
vxCaPgyh6WMBNP1Mh6Yf9PQ13PgAtwax9A==
       
       "]}]}, $CellContext`staticpolygons25176182014718171551497262$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgc9qjFW5+NFoaax+lw1yDJ9NEpIah5XA7H+B5M5RSFuY8bg4+ufjea
eej2obsH3b3o/kH3L3p4oIdXFVp4ooc3enyg8wE+qKGX
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHRGHjDQQYHMY5Q9uPgDCvZXd
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgcdqvFW5+NFnaYAzaP0+GuQZLpo1NCUPO4HI7xPZjKKQpzH/ew56P7
HxY+s6Hhgx5+6OGLHv7o8YMef+jxix7/sPRhAk0f6OkHPX0NNz4AkLgojQ==

       "]}]}, $CellContext`staticpolygons26176182014718171551498737$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YIDJR1ePbh66fejuQXcvun/Q/YseHujhhR6e6OGNHh/ofAAjXsB9

       "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQHbzfdcs6AwaHM2Ag4DDKH9x8AHF+4KQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YDD8+ej+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx/o6Qc9fQ03PgCb
joIE
       "]}]}, $CellContext`staticpolygons27176182014718171551499849$$ = {
    
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAEJBxz0AQJ8QvQBImlC9lFbH7n+wMUnVZxY
f+AyBxeNoQ8A6t0k2g==
      "]]}, $CellContext`thts$$ = 
    0., $CellContext`xoffthts$$ = 0.30000000000000004`, $CellContext`xthts$$ =
     0.30000000000000004`, $CellContext`xxs$$ = 0., $CellContext`yoffthts$$ = 
    0., $CellContext`ythts$$ = 0., $CellContext`yys$$ = 0., Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`thts$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xxs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yys$$], 0.}, -10, 10}, {{
       Hold[$CellContext`minthts$$], -180.}}, {{
       Hold[$CellContext`maxthts$$], 180.}}, {{
       Hold[$CellContext`minxxs$$], -10}}, {{
       Hold[$CellContext`maxxxs$$], 10}}, {{
       Hold[$CellContext`minyys$$], -10}}, {{
       Hold[$CellContext`maxyys$$], 10}}, {{
       Hold[$CellContext`minthts$$], -180.}}, {{
       Hold[$CellContext`maxthts$$], 180.}}, {{
       Hold[$CellContext`minxxs$$], -10}}, {{
       Hold[$CellContext`maxxxs$$], 10}}, {{
       Hold[$CellContext`minyys$$], -10}}, {{
       Hold[$CellContext`maxyys$$], 10}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "thts", "xxs", 
               "yys"}, {$CellContext`thts$$, $CellContext`xxs$$, \
$CellContext`yys$$}}], Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "thts", "xxs", 
                 "yys"}, {$CellContext`minthts$$, $CellContext`minxxs$$, \
$CellContext`minyys$$}, {$CellContext`maxthts$$, $CellContext`maxxxs$$, \
$CellContext`maxyys$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[WedgeOfRays[30, NumberOfRays -> 11], {{xxs, 0}, {yys, 0}}, \
{thts, 0.}, SymbolicValues -> {thts -> 0, xxs -> 0, yys -> 0}], \
Resonate[{Move[CubicLensSurface[{2.349248750891562, 3.1826846889173774, \
-1.187399540788185, -0.261433662654684}, {1.2000000000000002, 10}, {Component \
-> CubicLensSurface, Resonate -> False, Print -> True, Plot -> True}], {0, \
-4.4}], Move[CubicLensSurface[{3.9695973062336636, -0.784406657006282, \
-1.8217821796000724, 0.012213950156366189}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, -3.1999999999999997}], Move[CubicLensSurface[{0.6783207186370847, \
-3.879296029155285, -0.24295742991646999, 0.540856290913501}, \
{1.1999999999999997, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, -2.}], \
Move[CubicLensSurface[{-3.381021032325209, -2.0734307382635766, \
1.650601891618161, 0.40003584816499466}, {1.2000000000000006, 10}, {Component \
-> CubicLensSurface, Resonate -> False, Print -> True, Plot -> True}], {0, \
-0.7999999999999998}], Move[CubicLensSurface[{-2.958944063947002, \
2.657549986067966, 1.3969416071697456, -0.5579204065586112}, \
{1.1999999999999993, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, 0.40000000000000036}], \
Move[CubicLensSurface[{1.316508170673232, 3.786315565729376, \
-0.5234989030950995, -0.6690702663473906}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, 1.5999999999999996}], Move[CubicLensSurface[{4.043563113267889, \
0.21714194384609584, -1.822467736759229, 0.012891128463244314}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, 2.8000000000000007}], \
Move[CubicLensSurface[{1.0237707217965322, -3.838494761370709, \
-0.41717726174385045, 0.5711136238148176}, {1.5999999999999996, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, 4.199999999999999}], Move[CubicLensSurface[{2.349248750891562, \
3.1826846889173774, -1.187399540788185, -0.261433662654684}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., -4.4}], \
Move[CubicLensSurface[{3.9695973062336636, -0.784406657006282, \
-1.8217821796000724, 0.012213950156366189}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., -3.1999999999999997}], \
Move[CubicLensSurface[{0.6783207186370847, -3.879296029155285, \
-0.24295742991646999, 0.540856290913501}, {1.1999999999999997, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., -2.}], Move[CubicLensSurface[{-3.381021032325209, \
-2.0734307382635766, 1.650601891618161, 0.40003584816499466}, \
{1.2000000000000006, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., -0.7999999999999998}], \
Move[CubicLensSurface[{-2.958944063947002, 2.657549986067966, \
1.3969416071697456, -0.5579204065586112}, {1.1999999999999993, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., 0.40000000000000036}], Move[CubicLensSurface[{1.316508170673232, \
3.786315565729376, -0.5234989030950995, -0.6690702663473906}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., 1.5999999999999996}], \
Move[CubicLensSurface[{4.043563113267889, 0.21714194384609584, \
-1.822467736759229, 0.012891128463244314}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., 2.8000000000000007}], Move[CubicLensSurface[{1.0237707217965322, \
-3.838494761370709, -0.41717726174385045, 0.5711136238148176}, \
{1.5999999999999996, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., 4.199999999999999}]}], Move[Boundary[{0, \
-6, -6}, {12, 6, 6}], -6.]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "thts", "xxs", 
                "yys"}, {$CellContext`thts$$, $CellContext`xxs$$, \
$CellContext`yys$$}}]], ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "thts", "xxs", 
                  "yys"}, {$CellContext`minthts$$, $CellContext`minxxs$$, \
$CellContext`minyys$$}, {$CellContext`maxthts$$, $CellContext`maxxxs$$, \
$CellContext`maxyys$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xthts$$], 0.30000000000000004`}}, {{
       Hold[$CellContext`ythts$$], 0.}}, {{
       Hold[$CellContext`radiusthts$$], 0.30000000000000004`}}, {{
       Hold[$CellContext`xoffthts$$], 0.30000000000000004`}}, {{
       Hold[$CellContext`yoffthts$$], 0.}}, {{
       Hold[$CellContext`laststartposthts$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocposthts$$], {0.30000000000000004`, 0.}}}, {{
       Hold[$CellContext`lastthts$$], 0}}, {{
       Hold[$CellContext`staticpolygons11176182014718171551475281$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA+lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA7wT5ic7bX2l316GggIHejcneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgB9ebcxZ2rA4Q8wQPWGfkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YI/9itGcwNNU/gQGHyvMqSxzxQ/fwHzrG+y+Mx5oOq
58PgF6GpRzcP3T4bNPfsRHMvun+60PwriBYeKWjhlYsWnkfRwhs9PtD5ACrG
rAg=
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun00wOs2aCgOCBUf7g5gMA0YLqBw==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA5lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA4ITJic7bX2l316GggIHejaneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgJ9ebcxZ2rA4Q8wQP2GTkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YK/9itGcwNNU/gQFHyvMqSxzxQ/fwHzrG+y+Mx5oOq
5xv2fHT/r0ELH/TwQw/fHWjhjx4/nWjxx48Wv+jxn4KWPraipR/09DXc+AAs
ICqM
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons12176182014718171551476871$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zgKCp84Gzv/mg5nEc2DN77eu017xQ8zgOCDfs0Vw3gQdq
HvuB7jUZz06+5oKax3Zg5utVvQ/+cEDNYz2wk72mW+IIG9Q8Fgw+uvpONPNg
9hlB7YO55z8YsB/gR3Mvun/Q/QsLDyNoeDyChhfEPO4DlWjhiR7eGPGBxgcA
HwHJBg==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQPbOxxXrPQX6HmWDAeWCUP7j5ACZ02jU=
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zAL+p84Gzv/mg5nEc2DN77eu017wO/8GA/YBwwx7NdRN4
HIzA5rEf6FyT8ezkay6oeWwHZrxe1fvgD4fDDLB5rAd2std0Sxxhg5rHMuz5
M6H+nwn1fxda+KCHH3r4CqKFP3r8oMcfevyixz96+uCDpp9Z0PSDkb6GGR8A
ZU14gA==
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons13176182014718171551478356$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgVv+j1ieP/5jnwYGTAfKXvccPsX13X7WTBBgPOB2O+mYIfNH
+7Ng8xgOSN++vuzslqf2EPMYDtge2n/oUtklqP5/+w2uT9kzN3LXfoj6P/vv
/riv/6Lj/n4TsH2/939dtsL4kOib/RDzf+7/VRdm7yL0ZT8j2Lgf+ys3lW2T
eP1zfzrYvG8Y/D9Q9QxQ9ejmoduH7h5096L7B92/6OGBHl7o4SmHFt7o8YHO
BwCuBd9g
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIwffv6srNbntozQMCBUf7g5gMAFjCfkQ==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgTv+j1ieP/5jnwYGTAfKX/ccPsX13X7WTBBgPOB+O+mYIfNH
+7Ng8xgOyN++vuzslqf2EPMYDrge2n/oUtkl+3Sw/n/7Ba9P2TM3ctf+c2D1
f/Zf/XFf/0XH/f0mYPt+7/+4bIXxIdE3+yHm/9z/qy7M3kXoy35GsHE/9pds
Ktsm8frn/gywed/2V0L56cOU/wfqfwao/7+ihc9DaPgZQ8PPERq+Z6HhawkN
/zRo+IujxY8LNP7OQOOvBBq/M6HxewMt/iXQ0occWvq5hZa+0NPbUOcDALof
ydQ=
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons14176182014718171551479839$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
+9jAJbyR6YCJMQh83l9uOOWT9w+WA7NmgsDH/cKcDWwpVuwHGMDgw/6N7zol
tjpxHgBrP/Nmv1Oa+8EQHu4DM8DqX+7f+tl3ZsQkngOpYPue7f8pZWx57Tzv
AUOw+Y/3MyT0WD7ez3fg138QuL9/h9t7o6mx/AemgPXf3C8Q/HEv4xL+Azpg
9Zf3/+XQKLbr4z/QAZY/icFHV78dat4kqHno9sHcYwB1D8y9KVD3ovsH5t/T
UP/CwgNs3P/3GOH1DhqextDwRA9v9PhA5wMAlTrnAQ==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/vAjJkg8HL/KH9w8wHLTdxR
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
99jAJbyR6YAxGHzeX2445ZP3D5YDs2aCwMf9wpwNbClW7Af+g8H7/RvfdUps
deI8cBqs/81+pzT3gyE83AdmgNW/3L/1s+/MiEk8B1LA9j3b/1PK2PLaed4D
BmDzH+9nSOixfLyf78APsHn39293e280NZb/wASw/pv7hYI/7mVcwn9AA6z+
8v6/HBrFdn38BzrA8ieHPV8A6n8dqP93QMNnMjR8YOH3Cxp+sPA1hIYvLPxT
oeGPHj+w+DsDjT9Y/DKAwYf9ZWjx/waaPkyg6YMTmn7OQdMPevoabnwAuE+y
uQ==
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons15176182014718171551481313$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO8DBl8eqv4cVH0o1LzZUPPQ7YO5xwzqnlioe5mh7kX3Tw3UvzZQ
/8LCYw00PNDDKwwlPE/YdEHDOwEa3ujxgc4HACxUyvY=
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXik6+6r1ewHFswEgZv2o/zBzQcAAPD7OA==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO/DsOfLQ/1/Dur/UGj4zIaGD3r4wcLXDBq+sdDwZ4aGP3r81EDj
zwYaf7D4XQONX/T4D0NJHydsuqDpJwGaftDT13DjAwAV3H8N
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons16176182014718171551483061$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
0aUtF9SnndtvaAwCn+1ff1U/nJd22P70GRD4Yv/NYPHBJakP7VPSQOCbfamm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2960v/pJm/21vBDbvt73mVa4em0QG
B4h5f+wNG1+lcEgyO0DM+2f//lL1xR2LWB0g5v23d/ptJC36jd0BrPwMg4Og
dkv3Ey4uB7DxMxkx+C5o6j9AzfsPNc8Ial8q1D4tqHvOQN3zAM296P6pQPPv
T2h4pELD4w80vM5Aw0sKGp5G0PBchhbe6PGBzgcAmpH0HA==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Roqfz9L4Kv9jJkg8NN+lD+4+QDIj9vK
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
5qUtF9SnndtvZAwCn+1ff1U/nJd22P70GRD4Yv/dYPHBJakP7VPTQOCbfYWm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2D6wv/pJm/20PMe+3vdZVrh6bRAYH
sHFn/tgbNb5K4ZBkdoCY98/+w6XqizsWsTr8hwB7l99G0qLf2KHqGRwEtVu6
n3BxOYCNn8k47Pno/n8PDZ9/0PBBDz9Y+J6Ghu99tPBHj59StPj7Bo3fFGj8
ose/ITR9GELTxzpo+pkOTT/o6Wu48QEQQt/0
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons17176182014718171551484647$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgU
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4heIP
5fTDzONwKPfdVzZrOx/UPE6HXYlHso5M5YWax+XQJ3tAW1iLB2oeNwYfXX0Z
mnk8aPahuwfdvej+Qfcvenigh9dntPBED2/0+EDnAwCeS59F
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHQGHjDQQYHMY5Q9uPgBmxZVx
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgc
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4hOIP
5fTDzONwKPPdVzZrO5/DHLB5nA47E49kHZnKCzWPy6FP9oC2sBYP1DzuYc/f
heb/cmj4zIaGD3r4oYcvevijxw96/KHHL3r8f4SmDxNo+shESz/o6Wu48QH4
vhgr
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons18176182014718171551486128$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78BwNMPrp6dPPQ7UN3D7p70f2D7l/08EAPL/TwRA9v9PhA5wMATy7E
0w==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvayuOyM28YP9GTAQcBjlD24+ACnf970=
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78B4Phz0f3P3r4oIcfeviihz96/KDHH3r8osc/evpATz/o6Wu48QEa
4Gm/
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons19176182014718171551487681$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQgc7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cL05Z2HH6wAxT/CAdUZuQ2gtP9Q8gQMn
vcT8Nh4SgJoncOAq55+7U1YKQs0TOLDT8LzNrkIhqH7+A8+Zys3bJIWh6vkw
+LvQ1F9DM+8Umn02aO7ZieZedP90ofmXEy08NqGFlzlaeG5EC2/0+EDnAwAQ
eKmJ
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun01wOs2aCgOCBUf7g5gMAiYHq3w==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQga7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cr05Z2HH6wAxT/CATUZuQ2gtP9Q8gQOn
vMT8Nh4SgJoncOA655+7U1YKQs0TOLDL8LzNrkIhqH7+A8+Zys3bJIWh6vmG
PR/d/9fQwgc9/NDDdwda+KPHTyda/KHHL3r8G6Klj3Vo6Qc9fQ03PgDuvSVW

          "]}]}}}, {{
       Hold[$CellContext`staticpolygons20176182014718171551489416$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVCGoexwEOh3si4R5CUPPY
D7iEmXx+UioINY/twNnSq24FdQJQ81gPbGev6ZY4wgc1jwWDfxpNPbp5MPuM
oPbB3PMfDNgx3IvuH3T/wsLDCBoesPCCmMeNEZ7o4Y0RH2h8ADHww5I=
          
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcbhkOy9B8IOM8GA88Aof3DzARBY42I=
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVyOE/GLAf4HC4JxLuIeRg
BDaP/YBLmMnnJ6WCUPPYDpwuvepWUCfgMANsHuuB7ew13RJH+KDmsQx7Psz/
M6H+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx+w9DMLmn4w0tcw4wMA8npz0w==

          "]}]}}}, {{
       Hold[$CellContext`staticpolygons21176182014718171551490919$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgbfqhU2fC9kc0sCA6cDu0mOJqa3MDrNmggDjgUW5ho9nNDI4
nAWbx3Cg72325bRbv+wh5jEcmPBh/YYtc7/YQ/T/2y+VmutxZssbe4j6P/sn
MQu86LZ+YG8Ctu/3/pgTu5LeBe63h5j/c//T35F/BTwv7GcEG/dj/4eUtzmG
1x7vTweb9w2D/waqngGqHt08dPvQ3YPuXnT/oPsXPTzQwws9PNHDGz0+0PkA
fAfWKg==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3fc2+3LarV/2DBBwYJQ/uPkAjVOiTw==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgXfqhU2fC9kc0sCA6cCe0mOJqa3MDrNmggDjgcW5ho9nNDI4
nAWbx3Bgwtvsy2m3ftlDzGM4MOnD+g1b5n6xTwfr/7dfPjXX48yWN/bnwOr/
7J/GLPCi2/qBvQnYvt/7a07sSnoXuN8eYv7P/U9/R/4V8LywnxFs3I/9L1Pe
5hhee7w/A2zet/0foPz0Ycp/A/U/A9T/MWjhMwEafsbQ8JOEhu9ZaPj2Q8M/
DRr+PWjxsxAaf2eg8bcLGr8zofH7Fi3+JdDSB3r6uYWWvtDT21DnAwDVf8Sr

          "]}]}}}, {{
       Hold[$CellContext`staticpolygons22176182014718171551492561$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db+JMQh83v8uSePp9A8/98+aCQIf96sJMfCeKPm3nwEMPuzf+K5T
YqsT4wGw9jNv9juluR8M4WE+MAOs/uX+rZ99Z0ZMYjmQCrbv2f6fUsaW186z
HjAEm/94///4HsvH+9kO/PoPAvf373B7bzQ1lv3AFLD+m/sFgz/uZVzCfkAH
rP7y/j8cGsV2fewHOsDyJzH46Oq3Q82bBDUP3T6Yewyg7oG5NwXqXnT/wPx7
GupfWHiAjfv/HiO87kDD0xganujhjR4f6HwA+G/uRg==
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/nAjJkg8HL/KH9w8wETXdt5
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db8xGHze/y5J4+n0Dz/3z5oJAh/3qwkx8J4o+bf/Pxi837/xXafE
VifGA6fB+t/sd0pzPxjCw3xgBlj9y/1bP/vOjJjEciAFbN+z/T+ljC2vnWc9
YAA2//F+hoQey8f72Q78AJt3f/8Ot/dGU2PZD0wA67+5XzD4417GJewHNMDq
L+//w6FRbNfHfqADLH9y2PNh/teB+h8WPpOh4fM/HhJ+v6DhBwtfQ2j4wsI/
FRr+6PEDi78z0PhThcYvAxh82P8aLf5vQNOHCTR9CEPTzzlo+kFPX8ONDwAx
AbmV
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons23176182014718171551494039$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3AYNfA1V/Dqp+FdS82VDz0O2DuccM6p5dUPcyQ92L7p8aqH9t
oP6FhccaaHigh1cYSniesIGFdwI0vNHjA50PAM931b0=
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzdQhuvtq+P/9C2aCwE37Uf7g5gMAfMD0DA==
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3Ydjza6D+Pwf1/ypo+MyGhg96+MHC1wwavrug4c8MDX/0+KmB
xp8NNP5g8bsGGr/o8R+Gkj5O2MDSTwI0/aCnr+HGBwBOlX3G
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons24176182014718171551495733$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/ui
05e4y6Je2Bsag8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2KWkg8M1+5xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+3fz83429vM6mAENu+3vcZVrh6bRA4H
iHl/7A0aX6VwSHI7QMz7Z//uUvXFHYt4HSDm/bd3+m0kLfqN3wGs/AyDQ7vo
IdciVkEHsPEzGTH46OrfQ837DzXPCGpfKtQ+Tah7zkDd8wHNvej+2Y3m32po
eKRCw2MfNLzOQMOrAhqeRtDw3IAW3ujxgc4HAIk064U=
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWhVf75pB5PDjJkg8NN+lD+4+QCCdNwb
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/uS
05e4y6Je2BsZg8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2qWkg8M1+9xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+0/zM3429vM6gAx77e95lWuHptEDgew
cWf+2Bs1vkrhkOR2gJj3z/79peqLOxbxOvyHAHuX30bSot/4oeoZHNpFD7kW
sQo6gI2fyTjs+U5o/oeFzz9o+KCHHyx8T0PD9z1a+KPHz060+IPFbwo0ftHj
vxCaPgyh6WMBNP1Mh6Yf9PQ13PgAtwax9A==
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons25176182014718171551497262$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgc9qjFW5+NFoaax+lw1yDJ9NEpIah5XA7H+B5M5RSFuY8bg4+ufjea
eej2obsH3b3o/kH3L3p4oIdXFVp4ooc3enyg8wE+qKGX
          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHRGHjDQQYHMY5Q9uPgDCvZXd
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgcdqvFW5+NFnaYAzaP0+GuQZLpo1NCUPO4HI7xPZjKKQpzH/ew56P7
HxY+s6Hhgx5+6OGLHv7o8YMef+jxix7/sPRhAk0f6OkHPX0NNz4AkLgojQ==

          "]}]}}}, {{
       Hold[$CellContext`staticpolygons26176182014718171551498737$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YIDJR1ePbh66fejuQXcvun/Q/YseHujhhR6e6OGNHh/ofAAjXsB9

          "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQHbzfdcs6AwaHM2Ag4DDKH9x8AHF+4KQ=
          
          "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YDD8+ej+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx/o6Qc9fQ03PgCb
joIE
          "]}]}}}, {{
       Hold[$CellContext`staticpolygons27176182014718171551499849$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAEJBxz0AQJ8QvQBImlC9lFbH7n+wMUnVZxY
f+AyBxeNoQ8A6t0k2g==
         "]]}}}}, Typeset`size$$ = {
    800., {412.125, 417.875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`thts$21809$$ = 
    0, $CellContext`xxs$21810$$ = 0, $CellContext`yys$21811$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`lastlocposthts$$ = {0.30000000000000004`, 
         0.}, $CellContext`laststartposthts$$ = {0., 
         0.}, $CellContext`lastthts$$ = 0, $CellContext`maxthts$$ = 
        180., $CellContext`maxxxs$$ = 10, $CellContext`maxyys$$ = 
        10, $CellContext`minthts$$ = -180., $CellContext`minxxs$$ = -10, \
$CellContext`minyys$$ = -10, $CellContext`radiusthts$$ = 
        0.30000000000000004`, \
$CellContext`staticpolygons11176182014718171551475281$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA+lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA7wT5ic7bX2l316GggIHejcneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgB9ebcxZ2rA4Q8wQPWGfkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YI/9itGcwNNU/gQGHyvMqSxzxQ/fwHzrG+y+Mx5oOq
58PgF6GpRzcP3T4bNPfsRHMvun+60PwriBYeKWjhlYsWnkfRwhs9PtD5ACrG
rAg=
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun00wOs2aCgOCBUf7g5gMA0YLqBw==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA5lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA4ITJic7bX2l316GggIHejaneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgJ9ebcxZ2rA4Q8wQP2GTkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YK/9itGcwNNU/gQFHyvMqSxzxQ/fwHzrG+y+Mx5oOq
5xv2fHT/r0ELH/TwQw/fHWjhjx4/nWjxx48Wv+jxn4KWPraipR/09DXc+AAs
ICqM
            
            "]}]}, $CellContext`staticpolygons12176182014718171551476871$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zgKCp84Gzv/mg5nEc2DN77eu017xQ8zgOCDfs0Vw3gQdq
HvuB7jUZz06+5oKax3Zg5utVvQ/+cEDNYz2wk72mW+IIG9Q8Fgw+uvpONPNg
9hlB7YO55z8YsB/gR3Mvun/Q/QsLDyNoeDyChhfEPO4DlWjhiR7eGPGBxgcA
HwHJBg==
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQPbOxxXrPQX6HmWDAeWCUP7j5ACZ02jU=
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zAL+p84Gzv/mg5nEc2DN77eu017wO/8GA/YBwwx7NdRN4
HIzA5rEf6FyT8ezkay6oeWwHZrxe1fvgD4fDDLB5rAd2std0Sxxhg5rHMuz5
M6H+nwn1fxda+KCHH3r4CqKFP3r8oMcfevyixz96+uCDpp9Z0PSDkb6GGR8A
ZU14gA==
            
            "]}]}, $CellContext`staticpolygons13176182014718171551478356$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgVv+j1ieP/5jnwYGTAfKXvccPsX13X7WTBBgPOB2O+mYIfNH
+7Ng8xgOSN++vuzslqf2EPMYDtge2n/oUtklqP5/+w2uT9kzN3LXfoj6P/vv
/riv/6Lj/n4TsH2/939dtsL4kOib/RDzf+7/VRdm7yL0ZT8j2Lgf+ys3lW2T
eP1zfzrYvG8Y/D9Q9QxQ9ejmoduH7h5096L7B92/6OGBHl7o4SmHFt7o8YHO
BwCuBd9g
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIwffv6srNbntozQMCBUf7g5gMAFjCfkQ==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgTv+j1ieP/5jnwYGTAfKX/ccPsX13X7WTBBgPOB+O+mYIfNH
+7Ng8xgOyN++vuzslqf2EPMYDrge2n/oUtkl+3Sw/n/7Ba9P2TM3ctf+c2D1
f/Zf/XFf/0XH/f0mYPt+7/+4bIXxIdE3+yHm/9z/qy7M3kXoy35GsHE/9pds
Ktsm8frn/gywed/2V0L56cOU/wfqfwao/7+ihc9DaPgZQ8PPERq+Z6HhawkN
/zRo+IujxY8LNP7OQOOvBBq/M6HxewMt/iXQ0occWvq5hZa+0NPbUOcDALof
ydQ=
            
            "]}]}, $CellContext`staticpolygons14176182014718171551479839$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
+9jAJbyR6YCJMQh83l9uOOWT9w+WA7NmgsDH/cKcDWwpVuwHGMDgw/6N7zol
tjpxHgBrP/Nmv1Oa+8EQHu4DM8DqX+7f+tl3ZsQkngOpYPue7f8pZWx57Tzv
AUOw+Y/3MyT0WD7ez3fg138QuL9/h9t7o6mx/AemgPXf3C8Q/HEv4xL+Azpg
9Zf3/+XQKLbr4z/QAZY/icFHV78dat4kqHno9sHcYwB1D8y9KVD3ovsH5t/T
UP/CwgNs3P/3GOH1DhqextDwRA9v9PhA5wMAlTrnAQ==
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/vAjJkg8HL/KH9w8wHLTdxR
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
99jAJbyR6YAxGHzeX2445ZP3D5YDs2aCwMf9wpwNbClW7Af+g8H7/RvfdUps
deI8cBqs/81+pzT3gyE83AdmgNW/3L/1s+/MiEk8B1LA9j3b/1PK2PLaed4D
BmDzH+9nSOixfLyf78APsHn39293e280NZb/wASw/pv7hYI/7mVcwn9AA6z+
8v6/HBrFdn38BzrA8ieHPV8A6n8dqP93QMNnMjR8YOH3Cxp+sPA1hIYvLPxT
oeGPHj+w+DsDjT9Y/DKAwYf9ZWjx/waaPkyg6YMTmn7OQdMPevoabnwAuE+y
uQ==
            
            "]}]}, $CellContext`staticpolygons15176182014718171551481313$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO8DBl8eqv4cVH0o1LzZUPPQ7YO5xwzqnlioe5mh7kX3Tw3UvzZQ
/8LCYw00PNDDKwwlPE/YdEHDOwEa3ujxgc4HACxUyvY=
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXik6+6r1ewHFswEgZv2o/zBzQcAAPD7OA==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO/DsOfLQ/1/Dur/UGj4zIaGD3r4wcLXDBq+sdDwZ4aGP3r81EDj
zwYaf7D4XQONX/T4D0NJHydsuqDpJwGaftDT13DjAwAV3H8N
            
            "]}]}, $CellContext`staticpolygons16176182014718171551483061$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
0aUtF9SnndtvaAwCn+1ff1U/nJd22P70GRD4Yv/NYPHBJakP7VPSQOCbfamm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2960v/pJm/21vBDbvt73mVa4em0QG
B4h5f+wNG1+lcEgyO0DM+2f//lL1xR2LWB0g5v23d/ptJC36jd0BrPwMg4Og
dkv3Ey4uB7DxMxkx+C5o6j9AzfsPNc8Ial8q1D4tqHvOQN3zAM296P6pQPPv
T2h4pELD4w80vM5Aw0sKGp5G0PBchhbe6PGBzgcAmpH0HA==
            
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Roqfz9L4Kv9jJkg8NN+lD+4+QDIj9vK
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
5qUtF9SnndtvZAwCn+1ff1U/nJd22P70GRD4Yv/dYPHBJakP7VPTQOCbfYWm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2D6wv/pJm/20PMe+3vdZVrh6bRAYH
sHFn/tgbNb5K4ZBkdoCY98/+w6XqizsWsTr8hwB7l99G0qLf2KHqGRwEtVu6
n3BxOYCNn8k47Pno/n8PDZ9/0PBBDz9Y+J6Ghu99tPBHj59StPj7Bo3fFGj8
ose/ITR9GELTxzpo+pkOTT/o6Wu48QEQQt/0
            
            "]}]}, $CellContext`staticpolygons17176182014718171551484647$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgU
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4heIP
5fTDzONwKPfdVzZrOx/UPE6HXYlHso5M5YWax+XQJ3tAW1iLB2oeNwYfXX0Z
mnk8aPahuwfdvej+Qfcvenigh9dntPBED2/0+EDnAwCeS59F
            
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHQGHjDQQYHMY5Q9uPgBmxZVx
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgc
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4hOIP
5fTDzONwKPPdVzZrO5/DHLB5nA47E49kHZnKCzWPy6FP9oC2sBYP1DzuYc/f
heb/cmj4zIaGD3r4oYcvevijxw96/KHHL3r8f4SmDxNo+shESz/o6Wu48QH4
vhgr
            
            "]}]}, $CellContext`staticpolygons18176182014718171551486128$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78BwNMPrp6dPPQ7UN3D7p70f2D7l/08EAPL/TwRA9v9PhA5wMATy7E
0w==
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvayuOyM28YP9GTAQcBjlD24+ACnf970=
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78B4Phz0f3P3r4oIcfeviihz96/KDHH3r8osc/evpATz/o6Wu48QEa
4Gm/
            
            "]}]}, $CellContext`staticpolygons19176182014718171551487681$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQgc7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cL05Z2HH6wAxT/CAdUZuQ2gtP9Q8gQMn
vcT8Nh4SgJoncOAq55+7U1YKQs0TOLDT8LzNrkIhqH7+A8+Zys3bJIWh6vkw
+LvQ1F9DM+8Umn02aO7ZieZedP90ofmXEy08NqGFlzlaeG5EC2/0+EDnAwAQ
eKmJ
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun01wOs2aCgOCBUf7g5gMAiYHq3w==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQga7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cr05Z2HH6wAxT/CATUZuQ2gtP9Q8gQOn
vMT8Nh4SgJoncOA655+7U1YKQs0TOLDL8LzNrkIhqH7+A8+Zys3bJIWh6vmG
PR/d/9fQwgc9/NDDdwda+KPHTyda/KHHL3r8G6Klj3Vo6Qc9fQ03PgDuvSVW

            "]}]}, $CellContext`staticpolygons20176182014718171551489416$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVCGoexwEOh3si4R5CUPPY
D7iEmXx+UioINY/twNnSq24FdQJQ81gPbGev6ZY4wgc1jwWDfxpNPbp5MPuM
oPbB3PMfDNgx3IvuH3T/wsLDCBoesPCCmMeNEZ7o4Y0RH2h8ADHww5I=
            
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcbhkOy9B8IOM8GA88Aof3DzARBY42I=
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVyOE/GLAf4HC4JxLuIeRg
BDaP/YBLmMnnJ6WCUPPYDpwuvepWUCfgMANsHuuB7ew13RJH+KDmsQx7Psz/
M6H+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx+w9DMLmn4w0tcw4wMA8npz0w==

            "]}]}, $CellContext`staticpolygons21176182014718171551490919$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgbfqhU2fC9kc0sCA6cDu0mOJqa3MDrNmggDjgUW5ho9nNDI4
nAWbx3Cg72325bRbv+wh5jEcmPBh/YYtc7/YQ/T/2y+VmutxZssbe4j6P/sn
MQu86LZ+YG8Ctu/3/pgTu5LeBe63h5j/c//T35F/BTwv7GcEG/dj/4eUtzmG
1x7vTweb9w2D/waqngGqHt08dPvQ3YPuXnT/oPsXPTzQwws9PNHDGz0+0PkA
fAfWKg==
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3fc2+3LarV/2DBBwYJQ/uPkAjVOiTw==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgXfqhU2fC9kc0sCA6cCe0mOJqa3MDrNmggDjgcW5ho9nNDI4
nAWbx3Bgwtvsy2m3ftlDzGM4MOnD+g1b5n6xTwfr/7dfPjXX48yWN/bnwOr/
7J/GLPCi2/qBvQnYvt/7a07sSnoXuN8eYv7P/U9/R/4V8LywnxFs3I/9L1Pe
5hhee7w/A2zet/0foPz0Ycp/A/U/A9T/MWjhMwEafsbQ8JOEhu9ZaPj2Q8M/
DRr+PWjxsxAaf2eg8bcLGr8zofH7Fi3+JdDSB3r6uYWWvtDT21DnAwDVf8Sr

            "]}]}, $CellContext`staticpolygons22176182014718171551492561$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db+JMQh83v8uSePp9A8/98+aCQIf96sJMfCeKPm3nwEMPuzf+K5T
YqsT4wGw9jNv9juluR8M4WE+MAOs/uX+rZ99Z0ZMYjmQCrbv2f6fUsaW186z
HjAEm/94///4HsvH+9kO/PoPAvf373B7bzQ1lv3AFLD+m/sFgz/uZVzCfkAH
rP7y/j8cGsV2fewHOsDyJzH46Oq3Q82bBDUP3T6Yewyg7oG5NwXqXnT/wPx7
GupfWHiAjfv/HiO87kDD0xganujhjR4f6HwA+G/uRg==
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/nAjJkg8HL/KH9w8wETXdt5
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db8xGHze/y5J4+n0Dz/3z5oJAh/3qwkx8J4o+bf/Pxi837/xXafE
VifGA6fB+t/sd0pzPxjCw3xgBlj9y/1bP/vOjJjEciAFbN+z/T+ljC2vnWc9
YAA2//F+hoQey8f72Q78AJt3f/8Ot/dGU2PZD0wA67+5XzD4417GJewHNMDq
L+//w6FRbNfHfqADLH9y2PNh/teB+h8WPpOh4fM/HhJ+v6DhBwtfQ2j4wsI/
FRr+6PEDi78z0PhThcYvAxh82P8aLf5vQNOHCTR9CEPTzzlo+kFPX8ONDwAx
AbmV
            
            "]}]}, $CellContext`staticpolygons23176182014718171551494039$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3AYNfA1V/Dqp+FdS82VDz0O2DuccM6p5dUPcyQ92L7p8aqH9t
oP6FhccaaHigh1cYSniesIGFdwI0vNHjA50PAM931b0=
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQzdQhuvtq+P/9C2aCwE37Uf7g5gMAfMD0DA==
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3Ydjza6D+Pwf1/ypo+MyGhg96+MHC1wwavrug4c8MDX/0+KmB
xp8NNP5g8bsGGr/o8R+Gkj5O2MDSTwI0/aCnr+HGBwBOlX3G
            
            "]}]}, $CellContext`staticpolygons24176182014718171551495733$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/ui
05e4y6Je2Bsag8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2KWkg8M1+5xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+3fz83429vM6mAENu+3vcZVrh6bRA4H
iHl/7A0aX6VwSHI7QMz7Z//uUvXFHYt4HSDm/bd3+m0kLfqN3wGs/AyDQ7vo
IdciVkEHsPEzGTH46OrfQ837DzXPCGpfKtQ+Tah7zkDd8wHNvej+2Y3m32po
eKRCw2MfNLzOQMOrAhqeRtDw3IAW3ujxgc4HAIk064U=
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWhVf75pB5PDjJkg8NN+lD+4+QCCdNwb
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/uS
05e4y6Je2BsZg8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2qWkg8M1+9xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+0/zM3429vM6gAx77e95lWuHptEDgew
cWf+2Bs1vkrhkOR2gJj3z/79peqLOxbxOvyHAHuX30bSot/4oeoZHNpFD7kW
sQo6gI2fyTjs+U5o/oeFzz9o+KCHHyx8T0PD9z1a+KPHz060+IPFbwo0ftHj
vxCaPgyh6WMBNP1Mh6Yf9PQ13PgAtwax9A==
            
            "]}]}, $CellContext`staticpolygons25176182014718171551497262$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgc9qjFW5+NFoaax+lw1yDJ9NEpIah5XA7H+B5M5RSFuY8bg4+ufjea
eej2obsH3b3o/kH3L3p4oIdXFVp4ooc3enyg8wE+qKGX
            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHRGHjDQQYHMY5Q9uPgDCvZXd
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgcdqvFW5+NFnaYAzaP0+GuQZLpo1NCUPO4HI7xPZjKKQpzH/ew56P7
HxY+s6Hhgx5+6OGLHv7o8YMef+jxix7/sPRhAk0f6OkHPX0NNz4AkLgojQ==

            "]}]}, $CellContext`staticpolygons26176182014718171551498737$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YIDJR1ePbh66fejuQXcvun/Q/YseHujhhR6e6OGNHh/ofAAjXsB9

            "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQHbzfdcs6AwaHM2Ag4DDKH9x8AHF+4KQ=
            
            "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YDD8+ej+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx/o6Qc9fQ03PgCb
joIE
            
            "]}]}, $CellContext`staticpolygons27176182014718171551499849$$ = {
         
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAEJBxz0AQJ8QvQBImlC9lFbH7n+wMUnVZxY
f+AyBxeNoQ8A6t0k2g==
           "]]}, $CellContext`thts$$ = 
        0., $CellContext`xoffthts$$ = 
        0.30000000000000004`, $CellContext`xthts$$ = 
        0.30000000000000004`, $CellContext`xxs$$ = 
        0., $CellContext`yoffthts$$ = 0., $CellContext`ythts$$ = 
        0., $CellContext`yys$$ = 0.}, "ControllerVariables" :> {
        Hold[$CellContext`thts$$, $CellContext`thts$21809$$, 0], 
        Hold[$CellContext`xxs$$, $CellContext`xxs$21810$$, 0], 
        Hold[$CellContext`yys$$, $CellContext`yys$21811$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         Show[{
           Graphics[{{
              Opacity[
              0.8], $CellContext`staticpolygons11176182014718171551475281$$, \
$CellContext`staticpolygons12176182014718171551476871$$, \
$CellContext`staticpolygons13176182014718171551478356$$, \
$CellContext`staticpolygons14176182014718171551479839$$, \
$CellContext`staticpolygons15176182014718171551481313$$, \
$CellContext`staticpolygons16176182014718171551483061$$, \
$CellContext`staticpolygons17176182014718171551484647$$, \
$CellContext`staticpolygons18176182014718171551486128$$, \
$CellContext`staticpolygons19176182014718171551487681$$, \
$CellContext`staticpolygons20176182014718171551489416$$, \
$CellContext`staticpolygons21176182014718171551490919$$, \
$CellContext`staticpolygons22176182014718171551492561$$, \
$CellContext`staticpolygons23176182014718171551494039$$, \
$CellContext`staticpolygons24176182014718171551495733$$, \
$CellContext`staticpolygons25176182014718171551497262$$, \
$CellContext`staticpolygons26176182014718171551498737$$, \
$CellContext`staticpolygons27176182014718171551499849$$, 
              Opacity[1], 
              RGBColor[
              0.038747429704798886`, 0.9161617552424038, 
               0.039847212269181365`], 
              AbsoluteThickness[Medium], 
              Line[
               Dynamic[
                Refresh[
                 Map[{
                   Part[#, {1, 2}], 
                   Part[#, {4, 5}]}& , 
                  Select[
                   $CellContext`raytracefunction1176182014718171551509315[$\
CellContext`thts$$, $CellContext`xxs$$, $CellContext`yys$$], And[
                   Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                 TrackedSymbols :> {$CellContext`thts$$, $CellContext`xxs$$, \
$CellContext`yys$$}], SynchronousUpdating -> False]], 
              Arrowheads[Large], 
              Thickness[Large], 
              Dashing[{Small, Small}], 
              RGBColor[1, 1, 0], 
              Arrow[
               Dynamic[If[
                  
                  Or[$CellContext`laststartposthts$$ != {$CellContext`xxs$$, \
$CellContext`yys$$}, $CellContext`lastthts$$ =!= $CellContext`thts$$], \
$CellContext`laststartposthts$$ = {$CellContext`xxs$$, $CellContext`yys$$}; \
$CellContext`lastthts$$ = $CellContext`thts$$; {$CellContext`xthts$$, \
$CellContext`ythts$$} = $CellContext`laststartposthts$$ + \
$CellContext`radiusthts$$ {
                    Cos[$CellContext`thts$$ Degree], 
                    
                    Sin[$CellContext`thts$$ 
                    Degree]}]; {$CellContext`laststartposthts$$, \
{$CellContext`xthts$$, $CellContext`ythts$$}}, \
({$CellContext`laststartposthts$$, {$CellContext`xthts$$, \
$CellContext`ythts$$}} = #)& ]], 
              Tooltip[
               Locator[
                Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xthts$$, $CellContext`ythts$$} != \
$CellContext`lastlocposthts$$, $CellContext`lastthts$$ != \
$CellContext`thts$$], $CellContext`lastlocposthts$$ = {$CellContext`xthts$$, \
$CellContext`ythts$$}; $CellContext`lastthts$$ = $CellContext`thts$$; \
{$CellContext`xthts$$, $CellContext`ythts$$} = \
$CellContext`laststartposthts$$ + $CellContext`radiusthts$$ {
                    Cos[$CellContext`thts$$ Degree], 
                    
                    Sin[$CellContext`thts$$ 
                    Degree]}]; {$CellContext`xthts$$, $CellContext`ythts$$}), \
({$CellContext`xthts$$, $CellContext`ythts$$} = #; $CellContext`xoffthts$$ = \
$CellContext`xthts$$ - $CellContext`xxs$$; $CellContext`yoffthts$$ = \
$CellContext`ythts$$ - $CellContext`yys$$; $CellContext`radiusthts$$ = 
                  Sqrt[$CellContext`xoffthts$$^2 + $CellContext`yoffthts$$^2]; \
$CellContext`thts$$ = 
                  Chop[ArcTan[$CellContext`xoffthts$$, \
$CellContext`yoffthts$$]/
                    Degree]; {$CellContext`xthts$$, $CellContext`ythts$$})& ], 
                Graphics[{
                  RGBColor[1/3, 1/3, 1], 
                  Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["thts = ", 
                 ToString[$CellContext`thts$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[
                  1., 3.]; {$CellContext`xxs$$, $CellContext`yys$$}, \
({$CellContext`xxs$$, $CellContext`yys$$} = Chop[#])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["{xxs, yys} = ", 
                 ToString[
                  Chop[{$CellContext`xxs$$, $CellContext`yys$$}]]]]]}}]}, {
          PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
           Automatic}], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`thts$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xxs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yys$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`minthts$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxthts$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxxs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxxs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyys$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyys$$, 10}, ControlType -> 
         None}, {{$CellContext`minthts$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxthts$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxxs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxxs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyys$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyys$$, 10}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "thts", "xxs", 
                "yys"}, {$CellContext`thts$$, $CellContext`xxs$$, \
$CellContext`yys$$}}], Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "thts", "xxs", 
                  "yys"}, {$CellContext`minthts$$, $CellContext`minxxs$$, \
$CellContext`minyys$$}, {$CellContext`maxthts$$, $CellContext`maxxxs$$, \
$CellContext`maxyys$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[WedgeOfRays[30, NumberOfRays -> 11], {{xxs, 0}, {yys, 0}}, \
{thts, 0.}, SymbolicValues -> {thts -> 0, xxs -> 0, yys -> 0}], \
Resonate[{Move[CubicLensSurface[{2.349248750891562, 3.1826846889173774, \
-1.187399540788185, -0.261433662654684}, {1.2000000000000002, 10}, {Component \
-> CubicLensSurface, Resonate -> False, Print -> True, Plot -> True}], {0, \
-4.4}], Move[CubicLensSurface[{3.9695973062336636, -0.784406657006282, \
-1.8217821796000724, 0.012213950156366189}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, -3.1999999999999997}], Move[CubicLensSurface[{0.6783207186370847, \
-3.879296029155285, -0.24295742991646999, 0.540856290913501}, \
{1.1999999999999997, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, -2.}], \
Move[CubicLensSurface[{-3.381021032325209, -2.0734307382635766, \
1.650601891618161, 0.40003584816499466}, {1.2000000000000006, 10}, {Component \
-> CubicLensSurface, Resonate -> False, Print -> True, Plot -> True}], {0, \
-0.7999999999999998}], Move[CubicLensSurface[{-2.958944063947002, \
2.657549986067966, 1.3969416071697456, -0.5579204065586112}, \
{1.1999999999999993, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, 0.40000000000000036}], \
Move[CubicLensSurface[{1.316508170673232, 3.786315565729376, \
-0.5234989030950995, -0.6690702663473906}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, 1.5999999999999996}], Move[CubicLensSurface[{4.043563113267889, \
0.21714194384609584, -1.822467736759229, 0.012891128463244314}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {0, 2.8000000000000007}], \
Move[CubicLensSurface[{1.0237707217965322, -3.838494761370709, \
-0.41717726174385045, 0.5711136238148176}, {1.5999999999999996, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {0, 4.199999999999999}], Move[CubicLensSurface[{2.349248750891562, \
3.1826846889173774, -1.187399540788185, -0.261433662654684}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., -4.4}], \
Move[CubicLensSurface[{3.9695973062336636, -0.784406657006282, \
-1.8217821796000724, 0.012213950156366189}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., -3.1999999999999997}], \
Move[CubicLensSurface[{0.6783207186370847, -3.879296029155285, \
-0.24295742991646999, 0.540856290913501}, {1.1999999999999997, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., -2.}], Move[CubicLensSurface[{-3.381021032325209, \
-2.0734307382635766, 1.650601891618161, 0.40003584816499466}, \
{1.2000000000000006, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., -0.7999999999999998}], \
Move[CubicLensSurface[{-2.958944063947002, 2.657549986067966, \
1.3969416071697456, -0.5579204065586112}, {1.1999999999999993, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., 0.40000000000000036}], Move[CubicLensSurface[{1.316508170673232, \
3.786315565729376, -0.5234989030950995, -0.6690702663473906}, \
{1.2000000000000002, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., 1.5999999999999996}], \
Move[CubicLensSurface[{4.043563113267889, 0.21714194384609584, \
-1.822467736759229, 0.012891128463244314}, {1.2000000000000002, 10}, \
{Component -> CubicLensSurface, Resonate -> False, Print -> True, Plot -> \
True}], {1., 2.8000000000000007}], Move[CubicLensSurface[{1.0237707217965322, \
-3.838494761370709, -0.41717726174385045, 0.5711136238148176}, \
{1.5999999999999996, 10}, {Component -> CubicLensSurface, Resonate -> False, \
Print -> True, Plot -> True}], {1., 4.199999999999999}]}], Move[Boundary[{0, \
-6, -6}, {12, 6, 6}], -6.]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "thts", "xxs", 
                 "yys"}, {$CellContext`thts$$, $CellContext`xxs$$, \
$CellContext`yys$$}}]], ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                Transpose[{{
                  "thts", "xxs", 
                   "yys"}, {$CellContext`minthts$$, $CellContext`minxxs$$, \
$CellContext`minyys$$}, {$CellContext`maxthts$$, $CellContext`maxxxs$$, \
$CellContext`maxyys$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xthts$$, 0.30000000000000004`}, 
         ControlType -> None}, {{$CellContext`ythts$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiusthts$$, 0.30000000000000004`}, 
         ControlType -> 
         None}, {{$CellContext`xoffthts$$, 0.30000000000000004`}, ControlType -> 
         None}, {{$CellContext`yoffthts$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartposthts$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocposthts$$, {0.30000000000000004`, 0.}}, 
         ControlType -> None}, {{$CellContext`lastthts$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons11176182014718171551475281$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA+lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA7wT5ic7bX2l316GggIHejcneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgB9ebcxZ2rA4Q8wQPWGfkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YI/9itGcwNNU/gQGHyvMqSxzxQ/fwHzrG+y+Mx5oOq
58PgF6GpRzcP3T4bNPfsRHMvun+60PwriBYeKWjhlYsWnkfRwhs9PtD5ACrG
rAg=
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun00wOs2aCgOCBUf7g5gMA0YLqBw==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzRUQm7N40kZ7BjAQObBnmu++2Jn37WfNBAHhA5lC
yur7nryxNzEGAeEDSY6xYVe2fbE/ewYEhA4ITJic7bX2l316GggIHejaneG8
Sp3BAWKe0AHFPzffOp1mcoCYJ3hgJ9ebcxZ2rA4Q8wQP2GTkNoTWsjtAzBM4
MGWqzpykVk4HiHkCB9YK/9itGcwNNU/gQFHyvMqSxzxQ/fwHzrG+y+Mx5oOq
5xv2fHT/r0ELH/TwQw/fHWjhjx4/nWjxx48Wv+jxn4KWPraipR/09DXc+AAs
ICqM
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12176182014718171551476871$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zgKCp84Gzv/mg5nEc2DN77eu017xQ8zgOCDfs0Vw3gQdq
HvuB7jUZz06+5oKax3Zg5utVvQ/+cEDNYz2wk72mW+IIG9Q8Fgw+uvpONPNg
9hlB7YO55z8YsB/gR3Mvun/Q/QsLDyNoeDyChhfEPO4DlWjhiR7eGPGBxgcA
HwHJBg==
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQPbOxxXrPQX6HmWDAeWCUP7j5ACZ02jU=
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzb9tqw6PI59DGhjwHeC/dG2JmC2/w0ww4D1Q8eic
9aG3/A5nwIDnwOOI0+tmaQo4MIABzwHTVmHr02YCDsZgwH0gP3rPj1Y5Aah5
XAdmNrZY7zkIM4/zAL+p84Gzv/mg5nEc2DN77eu017wO/8GA/YBwwx7NdRN4
HIzA5rEf6FyT8ezkay6oeWwHZrxe1fvgD4fDDLB5rAd2std0Sxxhg5rHMuz5
M6H+nwn1fxda+KCHH3r4CqKFP3r8oMcfevyixz96+uCDpp9Z0PSDkb6GGR8A
ZU14gA==
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons13176182014718171551478356$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgVv+j1ieP/5jnwYGTAfKXvccPsX13X7WTBBgPOB2O+mYIfNH
+7Ng8xgOSN++vuzslqf2EPMYDtge2n/oUtklqP5/+w2uT9kzN3LXfoj6P/vv
/riv/6Lj/n4TsH2/939dtsL4kOib/RDzf+7/VRdm7yL0ZT8j2Lgf+ys3lW2T
eP1zfzrYvG8Y/D9Q9QxQ9ejmoduH7h5096L7B92/6OGBHl7o4SmHFt7o8YHO
BwCuBd9g
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIwffv6srNbntozQMCBUf7g5gMAFjCfkQ==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmWwOZ8CA5YD8u++y+18xOzCAAcsBybm6
j+Y6MDoYgwHzgTv+j1ieP/5jnwYGTAfKX/ccPsX13X7WTBBgPOB+O+mYIfNH
+7Ng8xgOyN++vuzslqf2EPMYDrge2n/oUtkl+3Sw/n/7Ba9P2TM3ctf+c2D1
f/Zf/XFf/0XH/f0mYPt+7/+4bIXxIdE3+yHm/9z/qy7M3kXoy35GsHE/9pds
Ktsm8frn/gywed/2V0L56cOU/wfqfwao/7+ihc9DaPgZQ8PPERq+Z6HhawkN
/zRo+IujxY8LNP7OQOOvBBq/M6HxewMt/iXQ0occWvq5hZa+0NPbUOcDALof
ydQ=
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons14176182014718171551479839$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
+9jAJbyR6YCJMQh83l9uOOWT9w+WA7NmgsDH/cKcDWwpVuwHGMDgw/6N7zol
tjpxHgBrP/Nmv1Oa+8EQHu4DM8DqX+7f+tl3ZsQkngOpYPue7f8pZWx57Tzv
AUOw+Y/3MyT0WD7ez3fg138QuL9/h9t7o6mx/AemgPXf3C8Q/HEv4xL+Azpg
9Zf3/+XQKLbr4z/QAZY/icFHV78dat4kqHno9sHcYwB1D8y9KVD3ovsH5t/T
UP/CwgNs3P/3GOH1DhqextDwRA9v9PhA5wMAlTrnAQ==
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/vAjJkg8HL/KH9w8wHLTdxR
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvWRddDaz4K/96Wkg8G0/r2Xj0Qdb/u8/ewYEvux/
99jAJbyR6YAxGHzeX2445ZP3D5YDs2aCwMf9wpwNbClW7Af+g8H7/RvfdUps
deI8cBqs/81+pzT3gyE83AdmgNW/3L/1s+/MiEk8B1LA9j3b/1PK2PLaed4D
BmDzH+9nSOixfLyf78APsHn39293e280NZb/wASw/pv7hYI/7mVcwn9AA6z+
8v6/HBrFdn38BzrA8ieHPV8A6n8dqP93QMNnMjR8YOH3Cxp+sPA1hIYvLPxT
oeGPHj+w+DsDjT9Y/DKAwYf9ZWjx/waaPkyg6YMTmn7OQdMPevoabnwAuE+y
uQ==
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons15176182014718171551481313$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO8DBl8eqv4cVH0o1LzZUPPQ7YO5xwzqnlioe5mh7kX3Tw3UvzZQ
/8LCYw00PNDDKwwlPE/YdEHDOwEa3ujxgc4HACxUyvY=
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQzXik6+6r1ewHFswEgZv2o/zBzQcAAPD7OA==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAf+BhpkgcHJ/9+9TN/Q/8x3IAfN37o/I
W3BVSorvAAMYHLGRDyubkPiG58ABiLx95FN1qfsF3AdWQfTb1/pNaM5bx3nA
yhgELtszHum6+2o1+4EFYPmb9nEVnyz0C1gPMIHNe2DPOW/RMjEm5gOmYPWP
7avTy8xrMhgOZKSBwDP7cL5JP0pDfu+fBdb/0l4p/jV3zJyv+8+AwRv7Jp+4
qQdz3u+HuO/DsOfLQ/1/Dur/UGj4zIaGD3r4wcLXDBq+sdDwZ4aGP3r81EDj
zwYaf7D4XQONX/T4D0NJHydsuqDpJwGaftDT13DjAwAV3H8N
             "]}]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons16176182014718171551483061$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
0aUtF9SnndtvaAwCn+1ff1U/nJd22P70GRD4Yv/NYPHBJakP7VPSQOCbfamm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2960v/pJm/21vBDbvt73mVa4em0QG
B4h5f+wNG1+lcEgyO0DM+2f//lL1xR2LWB0g5v23d/ptJC36jd0BrPwMg4Og
dkv3Ey4uB7DxMxkx+C5o6j9AzfsPNc8Ial8q1D4tqHvOQN3zAM296P6pQPPv
T2h4pELD4w80vM5Aw0sKGp5G0PBchhbe6PGBzgcAmpH0HA==
             
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Roqfz9L4Kv9jJkg8NN+lD+4+QDIj9vK
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQnbNox8T5P9/v//MfBN7br9IQDn757fH+GTNB4KO9
5qUtF9SnndtvZAwCn+1ff1U/nJd22P70GRD4Yv/dYPHBJakP7VPTQOCbfYWm
fsq6u2/t/4HN+27vGip/P0vgqz3EvJ/2D6wv/pJm/20PMe+3vdZVrh6bRAYH
sHFn/tgbNb5K4ZBkdoCY98/+w6XqizsWsTr8hwB7l99G0qLf2KHqGRwEtVu6
n3BxOYCNn8k47Pno/n8PDZ9/0PBBDz9Y+J6Ghu99tPBHj59StPj7Bo3fFGj8
ose/ITR9GELTxzpo+pkOTT/o6Wu48QEQQt/0
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons17176182014718171551484647$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgU
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4heIP
5fTDzONwKPfdVzZrOx/UPE6HXYlHso5M5YWax+XQJ3tAW1iLB2oeNwYfXX0Z
mnk8aPahuwfdvej+Qfcvenigh9dntPBED2/0+EDnAwCeS59F
             
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHQGHjDQQYHMY5Q9uPgBmxZVx
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX6jr52Vk8th9kwQYHTIOv3qauklboeMNBBgcvgc
pJFTGsDrYGoMAswO0bbTrus08zmA9DIwsDikRTYvPZLF73DuDAiwODy3mr9x
E7MA1DxWh9UG3Odn6whAzWNziP265qOhgQDUPHaH6A/aCZ18AlDzOBx4hOIP
5fTDzONwKPPdVzZrO5/DHLB5nA47E49kHZnKCzWPy6FP9oC2sBYP1DzuYc/f
heb/cmj4zIaGD3r4oYcvevijxw96/KHHL3r8f4SmDxNo+shESz/o6Wu48QH4
vhgr
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons18176182014718171551486128$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78BwNMPrp6dPPQ7UN3D7p70f2D7l/08EAPL/TwRA9v9PhA5wMATy7E
0w==
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQvayuOyM28YP9GTAQcBjlD24+ACnf970=
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7Tp1Xi2zB4+DkTEIcDs8/7ZJyvIyp4OzCwjwOBxz
m+7/8A2bQ0goCPA6zLlQuGTeUmaH1DQQ4HNQf5CxUJiPwaGsHAT4HbyaXOce
zf1hD9buIuCwrK47Izbxg/0ZMBBw2DXzQWa6wQN7iHmCDvuf3vOfLTN5/10w
EHQobcu7PT/s4X6w8WlCDlOKtPbIP/6w/x0YCDmoF/mcmHPpx36IfcIOtqEv
GBx1GA78B4Phz0f3P3r4oIcfeviihz96/KDHH3r8osc/evpATz/o6Wu48QEa
4Gm/
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons19176182014718171551487681$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQgc7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cL05Z2HH6wAxT/CAdUZuQ2gtP9Q8gQMn
vcT8Nh4SgJoncOAq55+7U1YKQs0TOLDT8LzNrkIhqH7+A8+Zys3bJIWh6vkw
+LvQ1F9DM+8Umn02aO7ZieZedP90ofmXEy08NqGFlzlaeG5EC2/0+EDnAwAQ
eKmJ
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQrfjn5lun01wOs2aCgOCBUf7g5gMAiYHq3w==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzXj1qJmW5Ed7BjAQObA+dXJ++LPv9rNmgoDwAZPO
icLxRf/sTYxBQPjAhgV62lnRTA5nz4CA0AGOEydNl4axOqSngYDQga7dGc6r
1DkcIOYJHVD8c/Ot02kuB4h5ggd2cr05Z2HH6wAxT/CATUZuQ2gtP9Q8gQOn
vMT8Nh4SgJoncOA655+7U1YKQs0TOLDL8LzNrkIhqH7+A8+Zys3bJIWh6vmG
PR/d/9fQwgc9/NDDdwda+KPHTyda/KHHL3r8G6Klj3Vo6Qc9fQ03PgDuvSVW

             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons20176182014718171551489416$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVCGoexwEOh3si4R5CUPPY
D7iEmXx+UioINY/twNnSq24FdQJQ81gPbGev6ZY4wgc1jwWDfxpNPbp5MPuM
oPbB3PMfDNgx3IvuH3T/wsLDCBoesPCCmMeNEZ7o4Y0RH2h8ADHww5I=
             
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcbhkOy9B8IOM8GA88Aof3DzARBY42I=
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzX47SqxNQdghDQz4DrBnZgd1zxN2mAkGvAdsCp/L
Pvwm7HAGDHgOPIo4vW6WpogDAxjwHDBpFbY+bSbiYAwG3Afyo/f8aJUTgZrH
deCMwyHZew9g5nEeaJ+l+OBZLcw8jgP3zl4r3fxVyOE/GLAf4HC4JxLuIeRg
BDaP/YBLmMnnJ6WCUPPYDpwuvepWUCfgMANsHuuB7ew13RJH+KDmsQx7Psz/
M6H+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx+w9DMLmn4w0tcw4wMA8npz0w==

             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons21176182014718171551490919$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgbfqhU2fC9kc0sCA6cDu0mOJqa3MDrNmggDjgUW5ho9nNDI4
nAWbx3Cg72325bRbv+wh5jEcmPBh/YYtc7/YQ/T/2y+VmutxZssbe4j6P/sn
MQu86LZ+YG8Ctu/3/pgTu5LeBe63h5j/c//T35F/BTwv7GcEG/dj/4eUtzmG
1x7vTweb9w2D/waqngGqHt08dPvQ3YPuXnT/oPsXPTzQwws9PNHDGz0+0PkA
fAfWKg==
             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQ3fc2+3LarV/2DBBwYJQ/uPkAjVOiTw==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQfcf4zKWNmXwOZ8CA5YD8u++y+19xOzCAAcsBqbm6
j+Y6cDoYgwHzgXfqhU2fC9kc0sCA6cCe0mOJqa3MDrNmggDjgcW5ho9nNDI4
nAWbx3Bgwtvsy2m3ftlDzGM4MOnD+g1b5n6xTwfr/7dfPjXX48yWN/bnwOr/
7J/GLPCi2/qBvQnYvt/7a07sSnoXuN8eYv7P/U9/R/4V8LywnxFs3I/9L1Pe
5hhee7w/A2zet/0foPz0Ycp/A/U/A9T/MWjhMwEafsbQ8JOEhu9ZaPj2Q8M/
DRr+PWjxsxAaf2eg8bcLGr8zofH7Fi3+JdDSB3r6uYWWvtDT21DnAwDVf8Sr

             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons22176182014718171551492561$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db+JMQh83v8uSePp9A8/98+aCQIf96sJMfCeKPm3nwEMPuzf+K5T
YqsT4wGw9jNv9juluR8M4WE+MAOs/uX+rZ99Z0ZMYjmQCrbv2f6fUsaW186z
HjAEm/94///4HsvH+9kO/PoPAvf373B7bzQ1lv3AFLD+m/sFgz/uZVzCfkAH
rP7y/j8cGsV2fewHOsDyJzH46Oq3Q82bBDUP3T6Yewyg7oG5NwXqXnT/wPx7
GupfWHiAjfv/HiO87kDD0xganujhjR4f6HwA+G/uRg==
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQ7ZTmfjCEh/nAjJkg8HL/KH9w8wETXdt5
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7R67/Rqb0pP96Wkg8G2/VBFT98HM9/vPngGBL/tv
H0/sWMf0db8xGHze/y5J4+n0Dz/3z5oJAh/3qwkx8J4o+bf/Pxi837/xXafE
VifGA6fB+t/sd0pzPxjCw3xgBlj9y/1bP/vOjJjEciAFbN+z/T+ljC2vnWc9
YAA2//F+hoQey8f72Q78AJt3f/8Ot/dGU2PZD0wA67+5XzD4417GJewHNMDq
L+//w6FRbNfHfqADLH9y2PNh/teB+h8WPpOh4fM/HhJ+v6DhBwtfQ2j4wsI/
FRr+6PEDi78z0PhThcYvAxh82P8aLf5vQNOHCTR9CEPTzzlo+kFPX8ONDwAx
AbmV
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons23176182014718171551494039$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3AYNfA1V/Dqp+FdS82VDz0O2DuccM6p5dUPcyQ92L7p8aqH9t
oP6FhccaaHigh1cYSniesIGFdwI0vNHjA50PAM931b0=
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQzdQhuvtq+P/9C2aCwE37Uf7g5gMAfMD0DA==
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7XhaqvNoAfuBhpkgcHJ/1+9TN/Q/sx3IAfN37o/I
W3BVSortAAMYHLGRDyubkPiG5cABiLx95FN1qfsFzAdWQfTb1/pNaM5bx3jA
yhgELtszdYjuvhr+f/8CsPxN+z0fnhTGPfi1nwls3gN7IRtXX12Wb/tNweof
23899ybvx4UP+zPSQOCZ/ToZlY+vVzzbPwus/6V9W81a/YLCa/vPgMEb+x35
ZiFn0yfZQ9z3Ydjza6D+Pwf1/ypo+MyGhg96+MHC1wwavrug4c8MDX/0+KmB
xp8NNP5g8bsGGr/o8R+Gkj5O2MDSTwI0/aCnr+HGBwBOlX3G
             "]}]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons24176182014718171551495733$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/ui
05e4y6Je2Bsag8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2KWkg8M1+5xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+3fz83429vM6mAENu+3vcZVrh6bRA4H
iHl/7A0aX6VwSHI7QMz7Z//uUvXFHYt4HSDm/bd3+m0kLfqN3wGs/AyDQ7vo
IdciVkEHsPEzGTH46OrfQ837DzXPCGpfKtQ+Tah7zkDd8wHNvej+2Y3m32po
eKRCw2MfNLzOQMOrAhqeRtDw3IAW3ujxgc4HAIk064U=
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQvWhVf75pB5PDjJkg8NN+lD+4+QCCdNwb
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzeBWJruz0dP+z38QeG+/Yt3NSF2hG/YzZoLAR/uS
05e4y6Je2BsZg8Bn+z3/Um6czflkf/oMCHyxr5pxMeHSph/2qWkg8M1+9xRx
o+vv/tn/A5v33X7Rqv580w4mB4h5P+0/zM3429vM6gAx77e95lWuHptEDgew
cWf+2Bs1vkrhkOR2gJj3z/79peqLOxbxOvyHAHuX30bSot/4oeoZHNpFD7kW
sQo6gI2fyTjs+U5o/oeFzz9o+KCHHyx8T0PD9z1a+KPHz060+IPFbwo0ftHj
vxCaPgyh6WMBNP1Mh6Yf9PQ13PgAtwax9A==
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons25176182014718171551497262$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgc9qjFW5+NFoaax+lw1yDJ9NEpIah5XA7H+B5M5RSFuY8bg4+ufjea
eej2obsH3b3o/kH3L3p4oIdXFVp4ooc3enyg8wE+qKGX
             "], CompressedData["

1:eJxTTMoPSmViYGCQBmIQvdqA+/xsHRGHjDQQYHMY5Q9uPgDCvZXd
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQzZJz/HATi6DD7JkgwOiwNfXrK6uXgg4ZaSDA5FCp
KbLNaoWQg6kxCDA7rJM7nT3NUdgBpBeo22HzmoNBSVuFHc6dAQEWh+dW8zdu
YhaBmsfqsNqA+/xsHRGoeWwOsV/XfDQ0EIGax+4Q/UE7oZNPBGoehwNbp37i
tuMw8zgcdqvFW5+NFnaYAzaP0+GuQZLpo1NCUPO4HI7xPZjKKQpzH/ew56P7
HxY+s6Hhgx5+6OGLHv7o8YMef+jxix7/sPRhAk0f6OkHPX0NNz4AkLgojQ==

             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons26176182014718171551498737$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[{CompressedData["
1:eJxTTMoPSmViYGCQBmIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YIDJR1ePbh66fejuQXcvun/Q/YseHujhhR6e6OGNHh/ofAAjXsB9

             "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQHbzfdcs6AwaHM2Ag4DDKH9x8AHF+4KQ=
             
             "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQvcjr/D5GFSEHI2MQ4HYoqY7snfNSwMHZBQR4HI66
Tfd/+IbPISQUBHgd5lwoXDJvKbdDahoI8DmoP8hYKMzH4VBWDgL8DqoHF517
ZMbiANbuIuAQvN91yzoDBoczYCDgcMfnwxZjiR/2EPMEHS5xNKpKp7+3vwsG
gg5in5U8DwTdtQcbnybkUBHk1/o9ec3+d2Ag5OD7ZMYEy6UP90PsE3aoWnWB
sSniw/7/YDD8+ej+Rw8f9PBDD1/08EePH/T4Q49f9PhHTx/o6Qc9fQ03PgCb
joIE
             "]}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons27176182014718171551499849$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAEJBxz0AQJ8QvQBImlC9lFbH7n+wMUnVZxY
f+AyBxeNoQ8A6t0k2g==
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{845., {459., 464.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`raytracefunction1176182014718171551509315 = 
      With[{$CellContext`compileoptionsetting$ = 
         If[$VersionNumber >= 8, {
           CompilationOptions -> {
             "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
              False}, CompilationTarget -> "MVM", 
            RuntimeAttributes -> {Listable}, Parallelization -> False, 
            RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
        Compile[{{$CellContext`thts$$, 
           Blank[Real]}, {$CellContext`xxs$$, 
           Blank[Real]}, {$CellContext`yys$$, 
           Blank[Real]}}, 
         Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
           Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
           1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
           1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
           1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
           1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
           1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
           1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
           1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
           1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
           1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
           1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
           1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
           1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
           1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
           1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
           1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
           1.; $CellContext`LocRSz$ = 1.; 
          Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
           1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
           1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
           1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
           0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
           1.; $CellContext`intensityscale$ = 
           1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
           1.; $CellContext`generationlimit$ = 
           200.; $CellContext`thresholdintensity$ = 
           1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
           1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
           1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
           1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
           1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
           1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
           1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
           1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
           1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
           1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
           1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
           1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
           1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
           1.; $CellContext`cloneposition$ = {0., 0., 
            0.}; $CellContext`clonerotation$ = {{
            1.}}; $CellContext`clonedata$ = {{1.}}; $CellContext`clonenumber$ = 
           1; $CellContext`clonescale$ = 1.; $CellContext`newdistance$ = 
           1.; $CellContext`closestdistances$ = {
            1.}; $CellContext`closestposition$ = 
           0; $CellContext`closestraylength$ = 
           1.; $CellContext`maximumposition$ = 
           1; $CellContext`closestpositions$ = {
            0}; $CellContext`cloneinput$ = {
            1.}; $CellContext`clonetraceinput$ = {{
            1.}}; $CellContext`clonetraceoutput$ = {{
            1.}}; $CellContext`tempclonedata$ = {{
            1.}}; $CellContext`clonegenerationnumber$ = 
           1.; $CellContext`maxclonegenerationnumber$ = 
           1.; $CellContext`clonescalevector$ = {
            1.}; $CellContext`clonesorthistogram$ = {
            1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 
            0., 0.}; $CellContext`oldgenerationnumber$ = 
           1.; $CellContext`intersections$ = {{-1., 0., 
            0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
            0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
            0.}}}; $CellContext`holeQlist$ = {
            0}; $CellContext`holeintersections$ = {{-1., 0., 
            0.}}; $CellContext`minimumraylength$ = 
           0.0001; $CellContext`originalray$ = {
            1.}; $CellContext`completedray$ = {
            1.}; $CellContext`reportedrayspresent$ = 
           False; $CellContext`propagate$ = 
           True; $CellContext`originalraytilt$ = {
            1.}; $CellContext`allowzeroraylength$ = 
           True; $CellContext`deflecteddummyrayspresent$ = 
           False; $CellContext`reporteddummyrayspresent$ = 
           False; $CellContext`localoutrayspresent$ = 
           False; $CellContext`localdummyoutrayspresent$ = 
           False; $CellContext`deflectedrayspresent$ = 
           False; $CellContext`intersectionspresent$ = 
           False; $CellContext`raysreported$ = 
           False; $CellContext`terminatedeflection$ = 
           False; $CellContext`allcreatedrays$ = {{
            1.}}; $CellContext`propagatedrays$ = {{
            1.}}; $CellContext`deflectedrays$ = {{
            1.}}; $CellContext`newdeflectedrays$ = {{
            1.}}; $CellContext`reportedrays$ = {{
            1.}}; $CellContext`clonereportedrays$ = {{
            1.}}; $CellContext`nonintersectingrays$ = {{
            1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
            1.}}; $CellContext`reportedlocalrays$ = {{
            1.}}; $CellContext`deflectedlocalrays$ = {{
            1.}}; $CellContext`localoutrays$ = {{
            1.}}; $CellContext`resonatenumber$ = 
           0; $CellContext`resonateraylength$ = 
           1.; $CellContext`minresonateraylength$ = 
           1.; $CellContext`resonateintersections$ = {{-1., 0., 
            0.}}; $CellContext`dummyvector$ = {
            1.}; $CellContext`dummymatrix$ = {{
            1.}}; $CellContext`dummymatrixlist$ = {{{
            1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
           1.; $CellContext`rzhlp$ = 
           1.; $CellContext`surfnorm$ = {{
            1.}}; $CellContext`originalsurfnorm$ = {{
            1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
            1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
            0.}; $CellContext`PAxis$ = {1., 0., 
            0.}; $CellContext`normalizedpolarization$ = {1., 
            1.}; $CellContext`amplitude$ = {
            1. + 0. I, 0. + 0. I, 0. + 
             0. I}; $CellContext`allcreatedamplitudes$ = {{
             0. + 0. I, 0. + 0. I, 0. + 
              0. I}}; $CellContext`perpendicularamplitude$ = 
           1. + 0. I; $CellContext`parallelamplitude$ = 
           1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
           1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
           1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
            0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0.,
             1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
            1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
            0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 0.}, {0.,
             1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{1., 0., 
            0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`axismagnitude$ = 
           1.; $CellContext`cosangle$ = 1.; $CellContext`sinangle$ = 
           1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
           1. + 0. I; $CellContext`ver$ = 
           0. + 0. I; $CellContext`propagatedrays$ = 
           Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                 Cos[Degree $CellContext`thts$$], 
                 Sin[Degree $CellContext`thts$$], 0, -
                 Sin[Degree $CellContext`thts$$], 
                 Cos[Degree $CellContext`thts$$], 0, 0, 0, 1}]; 
             Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xxs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yys$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xxs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yys$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BtKB6H4P97sv3tlPYJt8sHbCBXuYOJS/HyaP35QP
9guk9O+qsD2Eqot0cBOPLbnouh2u74lScJcU4wcc5uASRwUNDlcckGmEPjU0
PrHmEmcvVrcwVBn98Xlv/y3Cac3NOafg5kD5+2HyhOwfmHBjgNJqaHxizSU/
3GKe6E9Rmf3evjR4RTo32xG4OVD+fpg8IfsHJtw4oLQaGp9Yc8kPt2PpP6bI
X35vnxNuMzvh0C64OVD+fpg8IfsHJtwEoLQaGp9Yc8kPN9lnQm+Pfnlvz3fy
vcfx06vg5kD5+2HyhOwfmHATgdJqaHxizSU/3Khj/kCFmwSUVkPjE+9uYuzF
BtDS236YOCz9De70JgOl1dD4xJpLtfINHm6w8m5wl28KUFoNjU+suVSrT+Hh
BqtfB3d9qgSl1dD4xJpLtfYbPNxg7bnB3X5TgdJqaHxizSU/3ND6C/Bwg/Uf
Bnd/QQ0HTay5CHkAMiyIJw==
               "]]]; $CellContext`propagatedrays$ = 
           Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
              1.; $CellContext`frontid$ = 
              1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
           200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
           0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    4.4 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(2.349248750891562 - $CellContext`rx$ + \
$CellContext`ry$ (3.1826846889173774` + $CellContext`ry$ (-1.187399540788185 - 
                    0.261433662654684 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((2.349248750891562 - $CellContext`rx$ + $CellContext`ry$ (
                    3.1826846889173774` + $CellContext`ry$ \
(-1.187399540788185 - 
                    0.261433662654684 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.187399540788185) (-0.261433662654684) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.261433662654684)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.187399540788185)^3 $CellContext`yunit$^3 + 
                    9 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684) $CellContext`yunit$^3 - 27 
                    2.349248750891562 (-0.261433662654684)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.261433662654684)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.261433662654684)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-1.187399540788185)^2 (-0.261433662654684)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.1826846889173774` (-0.261433662654684)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.261433662654684)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.1826846889173774` (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.1826846889173774`^2 (-0.261433662654684)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 2.349248750891562 (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.1826846889173774`^2 (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 2.349248750891562 (-1.187399540788185)^3 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 3.1826846889173774`^3 (-0.261433662654684)^3 \
$CellContext`yunit$^6 - 486 2.349248750891562 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`yunit$^6 + 
                    729 2.349248750891562^2 (-0.261433662654684)^4 \
$CellContext`yunit$^6 - 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 
                    729 (-0.261433662654684)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.187399540788185) (-0.261433662654684) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.261433662654684)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.187399540788185)^3 $CellContext`yunit$^3 + 
                    9 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684) $CellContext`yunit$^3 - 27 
                    2.349248750891562 (-0.261433662654684)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.261433662654684)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.261433662654684)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-1.187399540788185)^2 (-0.261433662654684)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.1826846889173774` (-0.261433662654684)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.261433662654684)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.1826846889173774` (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.1826846889173774`^2 (-0.261433662654684)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 2.349248750891562 (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.1826846889173774`^2 (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 2.349248750891562 (-1.187399540788185)^3 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 3.1826846889173774`^3 (-0.261433662654684)^3 \
$CellContext`yunit$^6 - 486 2.349248750891562 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`yunit$^6 + 
                    729 2.349248750891562^2 (-0.261433662654684)^4 \
$CellContext`yunit$^6 - 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 
                    729 (-0.261433662654684)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 3.1826846889173774`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), ((-0.3333333333333333) \
(-1.187399540788185))/(-0.261433662654684) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.261433662654684) \
$CellContext`yunit$) + (
                    0.41997368329829105` (-1.187399540788185)^2 \
$CellContext`yunit$)/(Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    3.1826846889173774` $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.187399540788185) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.187399540788185) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.261433662654684) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.187399540788185)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    3.1826846889173774` (-0.261433662654684) \
$CellContext`yunit$^2)/((-0.261433662654684) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.261433662654684) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.187399540788185) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.187399540788185) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.261433662654684) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.187399540788185)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    3.1826846889173774` (-0.261433662654684) \
$CellContext`yunit$^2)/((-0.261433662654684) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.261433662654684) 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19002.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    3.1999999999999997` + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(3.9695973062336636` - $CellContext`rx$ + \
$CellContext`ry$ (-0.784406657006282 + $CellContext`ry$ (-1.8217821796000724` + 
                    0.012213950156366189` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((3.9695973062336636` - $CellContext`rx$ + $CellContext`ry$ \
(-0.784406657006282 + $CellContext`ry$ (-1.8217821796000724` + 
                    0.012213950156366189` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.8217821796000724`)^3 $CellContext`yunit$^3 + 
                    9 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`yunit$^3 - 27 
                    3.9695973062336636` 
                    0.012213950156366189`^2 $CellContext`yunit$^3 + 
                    27 0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012213950156366189`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-0.784406657006282) 
                    0.012213950156366189`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012213950156366189`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-0.784406657006282) (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-0.784406657006282)^2 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 3.9695973062336636` (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012213950156366189`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-0.784406657006282)^2 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 3.9695973062336636` (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 (-0.784406657006282)^3 
                    0.012213950156366189`^3 $CellContext`yunit$^6 - 486 
                    3.9695973062336636` (-0.784406657006282) \
(-1.8217821796000724`) 0.012213950156366189`^3 $CellContext`yunit$^6 + 
                    729 3.9695973062336636`^2 
                    0.012213950156366189`^4 $CellContext`yunit$^6 - 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012213950156366189`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.8217821796000724`)^3 $CellContext`yunit$^3 + 
                    9 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`yunit$^3 - 27 
                    3.9695973062336636` 
                    0.012213950156366189`^2 $CellContext`yunit$^3 + 
                    27 0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012213950156366189`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-0.784406657006282) 
                    0.012213950156366189`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012213950156366189`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-0.784406657006282) (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-0.784406657006282)^2 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 3.9695973062336636` (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012213950156366189`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-0.784406657006282)^2 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 3.9695973062336636` (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 (-0.784406657006282)^3 
                    0.012213950156366189`^3 $CellContext`yunit$^6 - 486 
                    
                    3.9695973062336636` (-0.784406657006282) \
(-1.8217821796000724`) 0.012213950156366189`^3 $CellContext`yunit$^6 + 
                    729 3.9695973062336636`^2 
                    0.012213950156366189`^4 $CellContext`yunit$^6 - 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012213950156366189`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2), \
((-0.3333333333333333) (-1.8217821796000724`))/
                    0.012213950156366189` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    0.41997368329829105` (-1.8217821796000724`)^2 \
$CellContext`yunit$)/(Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-0.784406657006282) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(0.012213950156366189` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.8217821796000724`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.8217821796000724`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.8217821796000724`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-0.784406657006282) 
                    0.012213950156366189` $CellContext`yunit$^2)/(
                    0.012213950156366189` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012213950156366189` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(0.012213950156366189` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.8217821796000724`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.8217821796000724`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.8217821796000724`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-0.784406657006282) 
                    0.012213950156366189` $CellContext`yunit$^2)/(
                    0.012213950156366189` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012213950156366189` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19101.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    2. + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(0.6783207186370847 - $CellContext`rx$ + \
$CellContext`ry$ (-3.879296029155285 + $CellContext`ry$ \
(-0.24295742991646999` + 
                    0.540856290913501 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((0.6783207186370847 - $CellContext`rx$ + $CellContext`ry$ \
(-3.879296029155285 + $CellContext`ry$ (-0.24295742991646999` + 
                    0.540856290913501 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.24295742991646999`)^3 $CellContext`yunit$^3 + 
                    9 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`yunit$^3 - 27 
                    0.6783207186370847 
                    0.540856290913501^2 $CellContext`yunit$^3 + 
                    27 0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.540856290913501^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.879296029155285) 
                    0.540856290913501^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.540856290913501^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.879296029155285) (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.879296029155285)^2 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 0.6783207186370847 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 0.6783207186370847 
                    
                    0.540856290913501^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.540856290913501^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.879296029155285)^2 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 0.6783207186370847 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 (-3.879296029155285)^3 
                    0.540856290913501^3 $CellContext`yunit$^6 - 486 
                    0.6783207186370847 (-3.879296029155285) \
(-0.24295742991646999`) 0.540856290913501^3 $CellContext`yunit$^6 + 
                    729 0.6783207186370847^2 
                    0.540856290913501^4 $CellContext`yunit$^6 - 
                    108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.540856290913501^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.24295742991646999`)^3 $CellContext`yunit$^3 + 
                    9 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`yunit$^3 - 27 
                    0.6783207186370847 
                    0.540856290913501^2 $CellContext`yunit$^3 + 
                    27 0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.540856290913501^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.879296029155285) 
                    0.540856290913501^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.540856290913501^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.879296029155285) (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.879296029155285)^2 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 0.6783207186370847 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.540856290913501^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.879296029155285)^2 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 0.6783207186370847 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 (-3.879296029155285)^3 
                    0.540856290913501^3 $CellContext`yunit$^6 - 486 
                    0.6783207186370847 (-3.879296029155285) \
(-0.24295742991646999`) 0.540856290913501^3 $CellContext`yunit$^6 + 
                    729 0.6783207186370847^2 
                    0.540856290913501^4 $CellContext`yunit$^6 - 
                    108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.540856290913501^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), \
((-0.3333333333333333) (-0.24295742991646999`))/
                    0.540856290913501 + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.540856290913501 $CellContext`yunit$) + (
                    0.41997368329829105` (-0.24295742991646999`)^2 \
$CellContext`yunit$)/(Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-3.879296029155285) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.24295742991646999`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.24295742991646999`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.540856290913501 $CellContext`xunit$ $CellContext`yunit$ + \
(0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.24295742991646999`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-3.879296029155285) 
                    0.540856290913501 $CellContext`yunit$^2)/(
                    0.540856290913501 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.540856290913501 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.24295742991646999`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.24295742991646999`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.540856290913501 $CellContext`xunit$ $CellContext`yunit$ + \
(0.36370787865724047` + 0.20998684164914547` 
                    I) (-0.24295742991646999`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-3.879296029155285) 
                    0.540856290913501 $CellContext`yunit$^2)/(
                    0.540856290913501 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.540856290913501 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19200.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    0.7999999999999998 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(-3.381021032325209 - $CellContext`rx$ + \
$CellContext`ry$ (-2.0734307382635766` + $CellContext`ry$ (1.650601891618161 + 
                    0.40003584816499466` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((-3.381021032325209 - $CellContext`rx$ + $CellContext`ry$ \
(-2.0734307382635766` + $CellContext`ry$ (1.650601891618161 + 
                    0.40003584816499466` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) 1.650601891618161 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.650601891618161^3 $CellContext`yunit$^3 + 
                    9 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466` $CellContext`yunit$^3 - 
                    27 (-3.381021032325209) 
                    0.40003584816499466`^2 $CellContext`yunit$^3 + 
                    27 0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.40003584816499466`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-2.0734307382635766`) 
                    0.40003584816499466`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.40003584816499466`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-2.0734307382635766`) 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-2.0734307382635766`)^2 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 (-3.381021032325209) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.40003584816499466`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 (-2.0734307382635766`)^2 
                    1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-3.381021032325209) 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-2.0734307382635766`)^3 
                    0.40003584816499466`^3 $CellContext`yunit$^6 - 
                    486 (-3.381021032325209) (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`yunit$^6 + 
                    729 (-3.381021032325209)^2 
                    0.40003584816499466`^4 $CellContext`yunit$^6 - 108 
                    1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 (-3.381021032325209) 
                    
                    0.40003584816499466`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.40003584816499466`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) 1.650601891618161 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.650601891618161^3 $CellContext`yunit$^3 + 
                    9 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466` $CellContext`yunit$^3 - 
                    27 (-3.381021032325209) 
                    0.40003584816499466`^2 $CellContext`yunit$^3 + 
                    27 0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.40003584816499466`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-2.0734307382635766`) 
                    0.40003584816499466`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.40003584816499466`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-2.0734307382635766`) 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-2.0734307382635766`)^2 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 (-3.381021032325209) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    
                    0.40003584816499466`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 (-2.0734307382635766`)^2 
                    1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-3.381021032325209) 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-2.0734307382635766`)^3 
                    0.40003584816499466`^3 $CellContext`yunit$^6 - 
                    486 (-3.381021032325209) (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`yunit$^6 + 
                    729 (-3.381021032325209)^2 
                    0.40003584816499466`^4 $CellContext`yunit$^6 - 108 
                    1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.40003584816499466`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2), \
((-0.3333333333333333) 1.650601891618161)/
                    0.40003584816499466` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    0.41997368329829105` 
                    1.650601891618161^2 $CellContext`yunit$)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-2.0734307382635766`) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(0.40003584816499466` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` 1.650601891618161 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] 1.650601891618161 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` I) 
                    1.650601891618161^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-2.0734307382635766`) 
                    0.40003584816499466` $CellContext`yunit$^2)/(
                    0.40003584816499466` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.40003584816499466` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(0.40003584816499466` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) 1.650601891618161 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` I) 
                    1.650601891618161 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 0.20998684164914547` I) 
                    1.650601891618161^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-2.0734307382635766`) 
                    0.40003584816499466` $CellContext`yunit$^2)/(
                    0.40003584816499466` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.40003584816499466` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19299.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -0.40000000000000036` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(-2.958944063947002 - $CellContext`rx$ + \
$CellContext`ry$ (2.657549986067966 + $CellContext`ry$ (1.3969416071697456` - 
                    0.5579204065586112 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((-2.958944063947002 - $CellContext`rx$ + $CellContext`ry$ (
                    2.657549986067966 + $CellContext`ry$ (1.3969416071697456` - 
                    0.5579204065586112 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.5579204065586112)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.3969416071697456`^3 $CellContext`yunit$^3 + 
                    9 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`yunit$^3 - 
                    27 (-2.958944063947002) (-0.5579204065586112)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.5579204065586112)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.5579204065586112)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 2.657549986067966 (-0.5579204065586112)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.5579204065586112)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 2.657549986067966 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    2.657549986067966^2 (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 (-2.958944063947002) 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.5579204065586112)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    2.657549986067966^2 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 (-2.958944063947002) 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 
                    2.657549986067966^3 (-0.5579204065586112)^3 \
$CellContext`yunit$^6 - 486 (-2.958944063947002) 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`yunit$^6 + 
                    729 (-2.958944063947002)^2 (-0.5579204065586112)^4 \
$CellContext`yunit$^6 - 108 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`yunit$^6 - 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.5579204065586112)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.5579204065586112)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.3969416071697456`^3 $CellContext`yunit$^3 + 
                    9 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`yunit$^3 - 
                    27 (-2.958944063947002) (-0.5579204065586112)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.5579204065586112)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.5579204065586112)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 2.657549986067966 (-0.5579204065586112)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.5579204065586112)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 2.657549986067966 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    2.657549986067966^2 (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 (-2.958944063947002) 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.5579204065586112)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    2.657549986067966^2 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 (-2.958944063947002) 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 
                    2.657549986067966^3 (-0.5579204065586112)^3 \
$CellContext`yunit$^6 - 486 (-2.958944063947002) 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`yunit$^6 + 
                    729 (-2.958944063947002)^2 (-0.5579204065586112)^4 \
$CellContext`yunit$^6 - 108 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`yunit$^6 - 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.5579204065586112)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 2.657549986067966)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) + (1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), ((-0.3333333333333333) 
                    1.3969416071697456`)/(-0.5579204065586112) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.5579204065586112) \
$CellContext`yunit$) + (0.41997368329829105` 
                    1.3969416071697456`^2 $CellContext`yunit$)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    2.657549986067966 $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) + (1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) - (0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474367 + 
                    1.0911236359717214` I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` 1.3969416071697456` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] 1.3969416071697456` 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.5579204065586112) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` I) 
                    1.3969416071697456`^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    2.657549986067966 (-0.5579204065586112) \
$CellContext`yunit$^2)/((-0.5579204065586112) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.5579204065586112) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474367 + 
                    1.0911236359717214` I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) - (0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) 1.3969416071697456` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` I) 
                    1.3969416071697456` 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.5579204065586112) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 0.20998684164914547` I) 
                    1.3969416071697456`^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    2.657549986067966 (-0.5579204065586112) \
$CellContext`yunit$^2)/((-0.5579204065586112) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.5579204065586112) 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19398.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -1.5999999999999996` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(1.316508170673232 - $CellContext`rx$ + \
$CellContext`ry$ (3.786315565729376 + $CellContext`ry$ (-0.5234989030950995 - 
                    0.6690702663473906 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((1.316508170673232 - $CellContext`rx$ + $CellContext`ry$ (
                    3.786315565729376 + $CellContext`ry$ (-0.5234989030950995 - 
                    0.6690702663473906 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.5234989030950995) (-0.6690702663473906) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.6690702663473906)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-0.5234989030950995)^3 $CellContext`yunit$^3 + 
                    9 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906) $CellContext`yunit$^3 - 27 
                    1.316508170673232 (-0.6690702663473906)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.6690702663473906)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.6690702663473906)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-0.5234989030950995)^2 (-0.6690702663473906)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.786315565729376 (-0.6690702663473906)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.6690702663473906)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.786315565729376 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.786315565729376^2 (-0.6690702663473906)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 1.316508170673232 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.6690702663473906)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.786315565729376^2 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 1.316508170673232 (-0.5234989030950995)^3 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 3.786315565729376^3 (-0.6690702663473906)^3 \
$CellContext`yunit$^6 - 486 1.316508170673232 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`yunit$^6 + 
                    729 1.316508170673232^2 (-0.6690702663473906)^4 \
$CellContext`yunit$^6 - 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.6690702663473906)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.5234989030950995) (-0.6690702663473906) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.6690702663473906)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-0.5234989030950995)^3 $CellContext`yunit$^3 + 
                    9 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906) $CellContext`yunit$^3 - 27 
                    1.316508170673232 (-0.6690702663473906)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.6690702663473906)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.6690702663473906)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-0.5234989030950995)^2 (-0.6690702663473906)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.786315565729376 (-0.6690702663473906)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.6690702663473906)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.786315565729376 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.786315565729376^2 (-0.6690702663473906)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 1.316508170673232 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.6690702663473906)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.786315565729376^2 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 1.316508170673232 (-0.5234989030950995)^3 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 3.786315565729376^3 (-0.6690702663473906)^3 \
$CellContext`yunit$^6 - 486 1.316508170673232 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`yunit$^6 + 
                    729 1.316508170673232^2 (-0.6690702663473906)^4 \
$CellContext`yunit$^6 - 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.6690702663473906)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 3.786315565729376)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), ((-0.3333333333333333) \
(-0.5234989030950995))/(-0.6690702663473906) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.6690702663473906) \
$CellContext`yunit$) + (
                    0.41997368329829105` (-0.5234989030950995)^2 \
$CellContext`yunit$)/(Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    3.786315565729376 $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.5234989030950995) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.5234989030950995) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.6690702663473906) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.5234989030950995)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    3.786315565729376 (-0.6690702663473906) \
$CellContext`yunit$^2)/((-0.6690702663473906) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.6690702663473906) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.5234989030950995) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.5234989030950995) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.6690702663473906) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-0.5234989030950995)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    3.786315565729376 (-0.6690702663473906) \
$CellContext`yunit$^2)/((-0.6690702663473906) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.6690702663473906) 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19497.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -2.8000000000000007` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(4.043563113267889 - $CellContext`rx$ + \
$CellContext`ry$ (0.21714194384609584` + $CellContext`ry$ (-1.822467736759229 + 
                    0.012891128463244314` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((4.043563113267889 - $CellContext`rx$ + $CellContext`ry$ (
                    0.21714194384609584` + $CellContext`ry$ \
(-1.822467736759229 + 
                    0.012891128463244314` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.822467736759229) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.822467736759229)^3 $CellContext`yunit$^3 + 
                    9 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314` $CellContext`yunit$^3 - 27 
                    4.043563113267889 
                    0.012891128463244314`^2 $CellContext`yunit$^3 + 
                    27 0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012891128463244314`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 0.21714194384609584` 
                    0.012891128463244314`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012891128463244314`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 0.21714194384609584` (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 0.21714194384609584`^2 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 4.043563113267889 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012891128463244314`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    0.21714194384609584`^2 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 4.043563113267889 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 0.21714194384609584`^3 
                    0.012891128463244314`^3 $CellContext`yunit$^6 - 486 
                    4.043563113267889 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`yunit$^6 + 
                    729 4.043563113267889^2 
                    0.012891128463244314`^4 $CellContext`yunit$^6 - 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012891128463244314`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.822467736759229) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.822467736759229)^3 $CellContext`yunit$^3 + 
                    9 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314` $CellContext`yunit$^3 - 27 
                    4.043563113267889 
                    0.012891128463244314`^2 $CellContext`yunit$^3 + 
                    27 0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012891128463244314`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 0.21714194384609584` 
                    0.012891128463244314`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012891128463244314`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 0.21714194384609584` (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 0.21714194384609584`^2 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 4.043563113267889 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012891128463244314`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    0.21714194384609584`^2 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 4.043563113267889 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 0.21714194384609584`^3 
                    0.012891128463244314`^3 $CellContext`yunit$^6 - 486 
                    4.043563113267889 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`yunit$^6 + 
                    729 4.043563113267889^2 
                    0.012891128463244314`^4 $CellContext`yunit$^6 - 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012891128463244314`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 0.21714194384609584`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2), \
((-0.3333333333333333) (-1.822467736759229))/
                    0.012891128463244314` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    0.41997368329829105` (-1.822467736759229)^2 \
$CellContext`yunit$)/(Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    0.21714194384609584` $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 0.21714194384609584`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(0.012891128463244314` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.822467736759229) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.822467736759229) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.822467736759229)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    0.21714194384609584` 
                    0.012891128463244314` $CellContext`yunit$^2)/(
                    0.012891128463244314` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012891128463244314` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(0.012891128463244314` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.822467736759229) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.822467736759229) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.822467736759229)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    0.21714194384609584` 
                    0.012891128463244314` $CellContext`yunit$^2)/(
                    0.012891128463244314` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012891128463244314` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19596.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -4.199999999999999 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(1.0237707217965322` - $CellContext`rx$ + \
$CellContext`ry$ (-3.838494761370709 + $CellContext`ry$ \
(-0.41717726174385045` + 
                    0.5711136238148176 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((1.0237707217965322` - $CellContext`rx$ + $CellContext`ry$ \
(-3.838494761370709 + $CellContext`ry$ (-0.41717726174385045` + 
                    0.5711136238148176 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.41717726174385045`)^3 $CellContext`yunit$^3 + 
                    9 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`yunit$^3 - 27 
                    1.0237707217965322` 
                    0.5711136238148176^2 $CellContext`yunit$^3 + 
                    27 0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.5711136238148176^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.838494761370709) 
                    0.5711136238148176^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.5711136238148176^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.838494761370709) (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.838494761370709)^2 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 1.0237707217965322` (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.5711136238148176^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.838494761370709)^2 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 1.0237707217965322` (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 (-3.838494761370709)^3 
                    0.5711136238148176^3 $CellContext`yunit$^6 - 486 
                    1.0237707217965322` (-3.838494761370709) \
(-0.41717726174385045`) 0.5711136238148176^3 $CellContext`yunit$^6 + 
                    729 1.0237707217965322`^2 
                    0.5711136238148176^4 $CellContext`yunit$^6 - 
                    108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.5711136238148176^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.41717726174385045`)^3 $CellContext`yunit$^3 + 
                    9 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`yunit$^3 - 27 
                    1.0237707217965322` 
                    0.5711136238148176^2 $CellContext`yunit$^3 + 
                    27 0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.5711136238148176^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.838494761370709) 
                    0.5711136238148176^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.5711136238148176^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.838494761370709) (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.838494761370709)^2 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 1.0237707217965322` (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.5711136238148176^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.838494761370709)^2 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 1.0237707217965322` (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 (-3.838494761370709)^3 
                    0.5711136238148176^3 $CellContext`yunit$^6 - 486 
                    1.0237707217965322` (-3.838494761370709) \
(-0.41717726174385045`) 0.5711136238148176^3 $CellContext`yunit$^6 + 
                    729 1.0237707217965322`^2 
                    0.5711136238148176^4 $CellContext`yunit$^6 - 
                    108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.5711136238148176^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), \
((-0.3333333333333333) (-0.41717726174385045`))/
                    0.5711136238148176 + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    0.41997368329829105` (-0.41717726174385045`)^2 \
$CellContext`yunit$)/(Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-3.838494761370709) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.41717726174385045`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.41717726174385045`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.41717726174385045`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-3.838494761370709) 
                    0.5711136238148176 $CellContext`yunit$^2)/(
                    0.5711136238148176 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.5711136238148176 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.41717726174385045`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.41717726174385045`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-0.41717726174385045`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-3.838494761370709) 
                    0.5711136238148176 $CellContext`yunit$^2)/(
                    0.5711136238148176 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.5711136238148176 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19695.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    4.4 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(2.349248750891562 - $CellContext`rx$ + \
$CellContext`ry$ (3.1826846889173774` + $CellContext`ry$ (-1.187399540788185 - 
                    0.261433662654684 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((2.349248750891562 - $CellContext`rx$ + $CellContext`ry$ (
                    3.1826846889173774` + $CellContext`ry$ \
(-1.187399540788185 - 
                    0.261433662654684 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.187399540788185) (-0.261433662654684) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.261433662654684)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.187399540788185)^3 $CellContext`yunit$^3 + 
                    9 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684) $CellContext`yunit$^3 - 27 
                    2.349248750891562 (-0.261433662654684)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.261433662654684)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.261433662654684)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-1.187399540788185)^2 (-0.261433662654684)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.1826846889173774` (-0.261433662654684)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.261433662654684)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.1826846889173774` (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.1826846889173774`^2 (-0.261433662654684)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 2.349248750891562 (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.1826846889173774`^2 (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 2.349248750891562 (-1.187399540788185)^3 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 3.1826846889173774`^3 (-0.261433662654684)^3 \
$CellContext`yunit$^6 - 486 2.349248750891562 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`yunit$^6 + 
                    729 2.349248750891562^2 (-0.261433662654684)^4 \
$CellContext`yunit$^6 - 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 
                    729 (-0.261433662654684)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.187399540788185) (-0.261433662654684) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.261433662654684)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.187399540788185)^3 $CellContext`yunit$^3 + 
                    9 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684) $CellContext`yunit$^3 - 27 
                    2.349248750891562 (-0.261433662654684)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.261433662654684)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.261433662654684)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-1.187399540788185)^2 (-0.261433662654684)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.1826846889173774` (-0.261433662654684)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.261433662654684)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.1826846889173774` (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.1826846889173774`^2 (-0.261433662654684)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 2.349248750891562 (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-1.187399540788185) (-0.261433662654684)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.1826846889173774`^2 (-1.187399540788185)^2 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 2.349248750891562 (-1.187399540788185)^3 \
(-0.261433662654684)^2 $CellContext`yunit$^6 + 
                    108 3.1826846889173774`^3 (-0.261433662654684)^3 \
$CellContext`yunit$^6 - 486 2.349248750891562 
                    3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`yunit$^6 + 
                    729 2.349248750891562^2 (-0.261433662654684)^4 \
$CellContext`yunit$^6 - 
                    108 (-1.187399540788185)^3 (-0.261433662654684)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.1826846889173774` (-1.187399540788185) \
(-0.261433662654684)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    2.349248750891562 (-0.261433662654684)^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 
                    729 (-0.261433662654684)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 3.1826846889173774`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), ((-0.3333333333333333) \
(-1.187399540788185))/(-0.261433662654684) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.261433662654684) \
$CellContext`yunit$) + (
                    0.41997368329829105` (-1.187399540788185)^2 \
$CellContext`yunit$)/(Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    3.1826846889173774` $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.187399540788185) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.187399540788185) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.261433662654684) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.187399540788185)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    3.1826846889173774` (-0.261433662654684) \
$CellContext`yunit$^2)/((-0.261433662654684) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.261433662654684) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.187399540788185) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.187399540788185) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.261433662654684) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.187399540788185)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    3.1826846889173774` (-0.261433662654684) \
$CellContext`yunit$^2)/((-0.261433662654684) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.261433662654684) 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    3.1826846889173774`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.187399540788185)^2)/(
                    Plus[I] (-0.261433662654684) Optica`Optica`TempVar2 - 
                    0.261433662654684 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-1.187399540788185))/((-0.261433662654684) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.261433662654684) \
$CellContext`ry$ $CellContext`yunit$)/((-0.261433662654684) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-2.349248750891562 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.1826846889173774` $CellContext`LocSCx$ + 
                    1.187399540788185 $CellContext`LocSCx$^2 + 
                    0.261433662654684 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19002.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    3.1999999999999997` + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(3.9695973062336636` - $CellContext`rx$ + \
$CellContext`ry$ (-0.784406657006282 + $CellContext`ry$ (-1.8217821796000724` + 
                    0.012213950156366189` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((3.9695973062336636` - $CellContext`rx$ + $CellContext`ry$ \
(-0.784406657006282 + $CellContext`ry$ (-1.8217821796000724` + 
                    0.012213950156366189` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.8217821796000724`)^3 $CellContext`yunit$^3 + 
                    9 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`yunit$^3 - 27 
                    3.9695973062336636` 
                    0.012213950156366189`^2 $CellContext`yunit$^3 + 
                    27 0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012213950156366189`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-0.784406657006282) 
                    0.012213950156366189`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012213950156366189`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-0.784406657006282) (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-0.784406657006282)^2 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 3.9695973062336636` (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012213950156366189`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-0.784406657006282)^2 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 3.9695973062336636` (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 (-0.784406657006282)^3 
                    0.012213950156366189`^3 $CellContext`yunit$^6 - 486 
                    3.9695973062336636` (-0.784406657006282) \
(-1.8217821796000724`) 0.012213950156366189`^3 $CellContext`yunit$^6 + 
                    729 3.9695973062336636`^2 
                    0.012213950156366189`^4 $CellContext`yunit$^6 - 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012213950156366189`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.8217821796000724`)^3 $CellContext`yunit$^3 + 
                    9 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189` $CellContext`yunit$^3 - 27 
                    3.9695973062336636` 
                    0.012213950156366189`^2 $CellContext`yunit$^3 + 
                    27 0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012213950156366189`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-0.784406657006282) 
                    0.012213950156366189`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012213950156366189`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-0.784406657006282) (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-0.784406657006282)^2 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 3.9695973062336636` (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012213950156366189`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-0.784406657006282)^2 (-1.8217821796000724`)^2 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 3.9695973062336636` (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`yunit$^6 + 
                    108 (-0.784406657006282)^3 
                    0.012213950156366189`^3 $CellContext`yunit$^6 - 486 
                    
                    3.9695973062336636` (-0.784406657006282) \
(-1.8217821796000724`) 0.012213950156366189`^3 $CellContext`yunit$^6 + 
                    729 3.9695973062336636`^2 
                    0.012213950156366189`^4 $CellContext`yunit$^6 - 
                    108 (-1.8217821796000724`)^3 
                    0.012213950156366189`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-0.784406657006282) (-1.8217821796000724`) 
                    0.012213950156366189`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 3.9695973062336636` 
                    0.012213950156366189`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012213950156366189`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2), \
((-0.3333333333333333) (-1.8217821796000724`))/
                    0.012213950156366189` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    0.41997368329829105` (-1.8217821796000724`)^2 \
$CellContext`yunit$)/(Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-0.784406657006282) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-0.784406657006282))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(0.012213950156366189` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.8217821796000724`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.8217821796000724`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.8217821796000724`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-0.784406657006282) 
                    0.012213950156366189` $CellContext`yunit$^2)/(
                    0.012213950156366189` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012213950156366189` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(0.012213950156366189` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.8217821796000724`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.8217821796000724`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.012213950156366189` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.8217821796000724`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-0.784406657006282) 
                    0.012213950156366189` $CellContext`yunit$^2)/(
                    0.012213950156366189` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012213950156366189` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-0.784406657006282))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.8217821796000724`)^2)/(
                    Plus[I] 0.012213950156366189` Optica`Optica`TempVar2 + 
                    0.012213950156366189` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.8217821796000724`))/(
                    0.012213950156366189` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    
                    0.012213950156366189` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012213950156366189` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-3.9695973062336636` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    0.784406657006282 $CellContext`LocSCx$ + 
                    1.8217821796000724` $CellContext`LocSCx$^2 - 
                    0.012213950156366189` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19101.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    2. + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(0.6783207186370847 - $CellContext`rx$ + \
$CellContext`ry$ (-3.879296029155285 + $CellContext`ry$ \
(-0.24295742991646999` + 
                    0.540856290913501 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((0.6783207186370847 - $CellContext`rx$ + $CellContext`ry$ \
(-3.879296029155285 + $CellContext`ry$ (-0.24295742991646999` + 
                    0.540856290913501 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.24295742991646999`)^3 $CellContext`yunit$^3 + 
                    9 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`yunit$^3 - 27 
                    0.6783207186370847 
                    0.540856290913501^2 $CellContext`yunit$^3 + 
                    27 0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.540856290913501^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.879296029155285) 
                    0.540856290913501^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.540856290913501^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.879296029155285) (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.879296029155285)^2 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 0.6783207186370847 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 0.6783207186370847 
                    
                    0.540856290913501^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.540856290913501^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.879296029155285)^2 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 0.6783207186370847 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 (-3.879296029155285)^3 
                    0.540856290913501^3 $CellContext`yunit$^6 - 486 
                    0.6783207186370847 (-3.879296029155285) \
(-0.24295742991646999`) 0.540856290913501^3 $CellContext`yunit$^6 + 
                    729 0.6783207186370847^2 
                    0.540856290913501^4 $CellContext`yunit$^6 - 
                    108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.540856290913501^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.24295742991646999`)^3 $CellContext`yunit$^3 + 
                    9 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501 $CellContext`yunit$^3 - 27 
                    0.6783207186370847 
                    0.540856290913501^2 $CellContext`yunit$^3 + 
                    27 0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.540856290913501^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.879296029155285) 
                    0.540856290913501^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.540856290913501^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.879296029155285) (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.879296029155285)^2 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 0.6783207186370847 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.540856290913501^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.879296029155285)^2 (-0.24295742991646999`)^2 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 0.6783207186370847 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`yunit$^6 + 
                    108 (-3.879296029155285)^3 
                    0.540856290913501^3 $CellContext`yunit$^6 - 486 
                    0.6783207186370847 (-3.879296029155285) \
(-0.24295742991646999`) 0.540856290913501^3 $CellContext`yunit$^6 + 
                    729 0.6783207186370847^2 
                    0.540856290913501^4 $CellContext`yunit$^6 - 
                    108 (-0.24295742991646999`)^3 
                    0.540856290913501^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.879296029155285) (-0.24295742991646999`) 
                    0.540856290913501^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 0.6783207186370847 
                    0.540856290913501^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.540856290913501^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), \
((-0.3333333333333333) (-0.24295742991646999`))/
                    0.540856290913501 + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.540856290913501 $CellContext`yunit$) + (
                    0.41997368329829105` (-0.24295742991646999`)^2 \
$CellContext`yunit$)/(Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-3.879296029155285) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-3.879296029155285))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.24295742991646999`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.24295742991646999`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.540856290913501 $CellContext`xunit$ $CellContext`yunit$ + \
(0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.24295742991646999`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-3.879296029155285) 
                    0.540856290913501 $CellContext`yunit$^2)/(
                    0.540856290913501 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.540856290913501 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.24295742991646999`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.24295742991646999`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.540856290913501 $CellContext`xunit$ $CellContext`yunit$ + \
(0.36370787865724047` + 0.20998684164914547` 
                    I) (-0.24295742991646999`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-3.879296029155285) 
                    0.540856290913501 $CellContext`yunit$^2)/(
                    0.540856290913501 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.540856290913501 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.879296029155285))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.24295742991646999`)^2)/(
                    Plus[I] 0.540856290913501 Optica`Optica`TempVar2 + 
                    0.540856290913501 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.24295742991646999`))/(
                    0.540856290913501 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.540856290913501 $CellContext`ry$ $CellContext`yunit$)/(
                    0.540856290913501 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999999, $CellContext`LocSCx$ >= \
-0.5999999999999999, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-0.6783207186370847 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.879296029155285 $CellContext`LocSCx$ + 
                    0.24295742991646999` $CellContext`LocSCx$^2 - 
                    0.540856290913501 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19200.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    0.7999999999999998 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(-3.381021032325209 - $CellContext`rx$ + \
$CellContext`ry$ (-2.0734307382635766` + $CellContext`ry$ (1.650601891618161 + 
                    0.40003584816499466` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((-3.381021032325209 - $CellContext`rx$ + $CellContext`ry$ \
(-2.0734307382635766` + $CellContext`ry$ (1.650601891618161 + 
                    0.40003584816499466` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) 1.650601891618161 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.650601891618161^3 $CellContext`yunit$^3 + 
                    9 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466` $CellContext`yunit$^3 - 
                    27 (-3.381021032325209) 
                    0.40003584816499466`^2 $CellContext`yunit$^3 + 
                    27 0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.40003584816499466`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-2.0734307382635766`) 
                    0.40003584816499466`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.40003584816499466`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-2.0734307382635766`) 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-2.0734307382635766`)^2 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 (-3.381021032325209) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.40003584816499466`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 (-2.0734307382635766`)^2 
                    1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-3.381021032325209) 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-2.0734307382635766`)^3 
                    0.40003584816499466`^3 $CellContext`yunit$^6 - 
                    486 (-3.381021032325209) (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`yunit$^6 + 
                    729 (-3.381021032325209)^2 
                    0.40003584816499466`^4 $CellContext`yunit$^6 - 108 
                    1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-2.0734307382635766`) 1.650601891618161 
                    
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.40003584816499466`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) 1.650601891618161 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.650601891618161^3 $CellContext`yunit$^3 + 
                    9 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466` $CellContext`yunit$^3 - 
                    27 (-3.381021032325209) 
                    0.40003584816499466`^2 $CellContext`yunit$^3 + 
                    27 0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.40003584816499466`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-2.0734307382635766`) 
                    0.40003584816499466`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.40003584816499466`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-2.0734307382635766`) 1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-2.0734307382635766`)^2 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 (-3.381021032325209) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-3.381021032325209) 
                    
                    0.40003584816499466`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.40003584816499466`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 (-2.0734307382635766`)^2 
                    1.650601891618161^2 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-3.381021032325209) 1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`yunit$^6 + 
                    108 (-2.0734307382635766`)^3 
                    0.40003584816499466`^3 $CellContext`yunit$^6 - 
                    486 (-3.381021032325209) (-2.0734307382635766`) 
                    1.650601891618161 
                    0.40003584816499466`^3 $CellContext`yunit$^6 + 
                    729 (-3.381021032325209)^2 
                    0.40003584816499466`^4 $CellContext`yunit$^6 - 108 
                    1.650601891618161^3 
                    0.40003584816499466`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-2.0734307382635766`) 1.650601891618161 
                    0.40003584816499466`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 (-3.381021032325209) 
                    0.40003584816499466`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.40003584816499466`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2), \
((-0.3333333333333333) 1.650601891618161)/
                    0.40003584816499466` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    0.41997368329829105` 
                    1.650601891618161^2 $CellContext`yunit$)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-2.0734307382635766`) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(0.40003584816499466` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` 1.650601891618161 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] 1.650601891618161 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` I) 
                    1.650601891618161^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-2.0734307382635766`) 
                    0.40003584816499466` $CellContext`yunit$^2)/(
                    0.40003584816499466` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.40003584816499466` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(0.40003584816499466` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) 1.650601891618161 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` I) 
                    1.650601891618161 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.40003584816499466` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 0.20998684164914547` I) 
                    1.650601891618161^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-2.0734307382635766`) 
                    0.40003584816499466` $CellContext`yunit$^2)/(
                    0.40003584816499466` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.40003584816499466` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-2.0734307382635766`))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.650601891618161^2)/(
                    Plus[I] 0.40003584816499466` Optica`Optica`TempVar2 + 
                    0.40003584816499466` Optica`Optica`TempVar1) - (
                    0.3333333333333333 1.650601891618161)/(
                    0.40003584816499466` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.40003584816499466` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.40003584816499466` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000003, $CellContext`LocSCx$ >= \
-0.6000000000000003, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[3.381021032325209 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    2.0734307382635766` $CellContext`LocSCx$ - 
                    1.650601891618161 $CellContext`LocSCx$^2 - 
                    0.40003584816499466` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19299.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -0.40000000000000036` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(-2.958944063947002 - $CellContext`rx$ + \
$CellContext`ry$ (2.657549986067966 + $CellContext`ry$ (1.3969416071697456` - 
                    0.5579204065586112 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((-2.958944063947002 - $CellContext`rx$ + $CellContext`ry$ (
                    2.657549986067966 + $CellContext`ry$ (1.3969416071697456` - 
                    0.5579204065586112 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.5579204065586112)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.3969416071697456`^3 $CellContext`yunit$^3 + 
                    9 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`yunit$^3 - 
                    27 (-2.958944063947002) (-0.5579204065586112)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.5579204065586112)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.5579204065586112)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 2.657549986067966 (-0.5579204065586112)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.5579204065586112)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 2.657549986067966 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    2.657549986067966^2 (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 (-2.958944063947002) 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.5579204065586112)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    2.657549986067966^2 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 (-2.958944063947002) 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 
                    2.657549986067966^3 (-0.5579204065586112)^3 \
$CellContext`yunit$^6 - 486 (-2.958944063947002) 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`yunit$^6 + 
                    729 (-2.958944063947002)^2 (-0.5579204065586112)^4 \
$CellContext`yunit$^6 - 108 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`yunit$^6 - 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.5579204065586112)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.5579204065586112)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 2 
                    1.3969416071697456`^3 $CellContext`yunit$^3 + 
                    9 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112) \
$CellContext`yunit$^3 - 
                    27 (-2.958944063947002) (-0.5579204065586112)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.5579204065586112)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.5579204065586112)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 2.657549986067966 (-0.5579204065586112)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.5579204065586112)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 2.657549986067966 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    2.657549986067966^2 (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 (-2.958944063947002) 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.5579204065586112)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    2.657549986067966^2 
                    1.3969416071697456`^2 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 (-2.958944063947002) 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`yunit$^6 + 108 
                    2.657549986067966^3 (-0.5579204065586112)^3 \
$CellContext`yunit$^6 - 486 (-2.958944063947002) 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`yunit$^6 + 
                    729 (-2.958944063947002)^2 (-0.5579204065586112)^4 \
$CellContext`yunit$^6 - 108 
                    1.3969416071697456`^3 (-0.5579204065586112)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 2.657549986067966 
                    1.3969416071697456` (-0.5579204065586112)^3 \
$CellContext`rx$ $CellContext`yunit$^6 - 
                    1458 (-2.958944063947002) (-0.5579204065586112)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.5579204065586112)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 2.657549986067966)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) + (1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), ((-0.3333333333333333) 
                    1.3969416071697456`)/(-0.5579204065586112) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.5579204065586112) \
$CellContext`yunit$) + (0.41997368329829105` 
                    1.3969416071697456`^2 $CellContext`yunit$)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    2.657549986067966 $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (0.41997368329829105` 
                    1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) + (1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) - (0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474367 + 
                    1.0911236359717214` I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` 1.3969416071697456` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] 1.3969416071697456` 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.5579204065586112) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` I) 
                    1.3969416071697456`^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    2.657549986067966 (-0.5579204065586112) \
$CellContext`yunit$^2)/((-0.5579204065586112) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.5579204065586112) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474367 + 
                    1.0911236359717214` I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 
                    Optica`Optica`TempVar1) - (0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) 1.3969416071697456` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` I) 
                    1.3969416071697456` 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.5579204065586112) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 0.20998684164914547` I) 
                    1.3969416071697456`^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    2.657549986067966 (-0.5579204065586112) \
$CellContext`yunit$^2)/((-0.5579204065586112) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.5579204065586112) 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    2.657549986067966)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) 1.3969416071697456`^2)/(
                    Plus[I] (-0.5579204065586112) Optica`Optica`TempVar2 - 
                    0.5579204065586112 Optica`Optica`TempVar1) - (
                    0.3333333333333333 
                    1.3969416071697456`)/((-0.5579204065586112) \
$CellContext`yunit$) - ((0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.5579204065586112) \
$CellContext`ry$ $CellContext`yunit$)/((-0.5579204065586112) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.5999999999999996, $CellContext`LocSCx$ >= \
-0.5999999999999996, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[2.958944063947002 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    2.657549986067966 $CellContext`LocSCx$ - 
                    1.3969416071697456` $CellContext`LocSCx$^2 + 
                    0.5579204065586112 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19398.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -1.5999999999999996` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(1.316508170673232 - $CellContext`rx$ + \
$CellContext`ry$ (3.786315565729376 + $CellContext`ry$ (-0.5234989030950995 - 
                    0.6690702663473906 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((1.316508170673232 - $CellContext`rx$ + $CellContext`ry$ (
                    3.786315565729376 + $CellContext`ry$ (-0.5234989030950995 - 
                    0.6690702663473906 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.5234989030950995) (-0.6690702663473906) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.6690702663473906)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-0.5234989030950995)^3 $CellContext`yunit$^3 + 
                    9 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906) $CellContext`yunit$^3 - 27 
                    1.316508170673232 (-0.6690702663473906)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.6690702663473906)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.6690702663473906)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-0.5234989030950995)^2 (-0.6690702663473906)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.786315565729376 (-0.6690702663473906)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.6690702663473906)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.786315565729376 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.786315565729376^2 (-0.6690702663473906)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 1.316508170673232 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.6690702663473906)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.786315565729376^2 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 1.316508170673232 (-0.5234989030950995)^3 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 
                    3.786315565729376^3 (-0.6690702663473906)^3 \
$CellContext`yunit$^6 - 486 1.316508170673232 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`yunit$^6 + 
                    729 1.316508170673232^2 (-0.6690702663473906)^4 \
$CellContext`yunit$^6 - 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.6690702663473906)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.5234989030950995) (-0.6690702663473906) \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    27 (-0.6690702663473906)^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-0.5234989030950995)^3 $CellContext`yunit$^3 + 
                    9 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906) $CellContext`yunit$^3 - 27 
                    1.316508170673232 (-0.6690702663473906)^2 \
$CellContext`yunit$^3 + 
                    27 (-0.6690702663473906)^2 $CellContext`rx$ \
$CellContext`yunit$^3 + 
                    Sqrt[(-108) (-0.6690702663473906)^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 
                    27 (-0.5234989030950995)^2 (-0.6690702663473906)^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    324 3.786315565729376 (-0.6690702663473906)^3 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`ry$ $CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 (-0.6690702663473906)^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 3.786315565729376 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`xunit$ $CellContext`yunit$^5 - 324 
                    3.786315565729376^2 (-0.6690702663473906)^3 \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    486 1.316508170673232 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`xunit$ $CellContext`yunit$^5 - 
                    486 (-0.5234989030950995) (-0.6690702663473906)^3 \
$CellContext`rx$ $CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 
                    1458 (-0.6690702663473906)^4 $CellContext`rx$ \
$CellContext`ry$ $CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    3.786315565729376^2 (-0.5234989030950995)^2 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 1.316508170673232 (-0.5234989030950995)^3 \
(-0.6690702663473906)^2 $CellContext`yunit$^6 + 
                    108 3.786315565729376^3 (-0.6690702663473906)^3 \
$CellContext`yunit$^6 - 486 1.316508170673232 
                    3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`yunit$^6 + 
                    729 1.316508170673232^2 (-0.6690702663473906)^4 \
$CellContext`yunit$^6 - 
                    108 (-0.5234989030950995)^3 (-0.6690702663473906)^2 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    486 3.786315565729376 (-0.5234989030950995) \
(-0.6690702663473906)^3 $CellContext`rx$ $CellContext`yunit$^6 - 1458 
                    1.316508170673232 (-0.6690702663473906)^4 \
$CellContext`rx$ $CellContext`yunit$^6 + 
                    729 (-0.6690702663473906)^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 3.786315565729376)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), ((-0.3333333333333333) \
(-0.5234989030950995))/(-0.6690702663473906) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1)/((-0.6690702663473906) \
$CellContext`yunit$) + (
                    0.41997368329829105` (-0.5234989030950995)^2 \
$CellContext`yunit$)/(Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    3.786315565729376 $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), -(((0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.5234989030950995) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.5234989030950995) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 
                    I) (-0.6690702663473906) $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.5234989030950995)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    3.786315565729376 (-0.6690702663473906) \
$CellContext`yunit$^2)/((-0.6690702663473906) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.6690702663473906) 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 
                    Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2), ((0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.5234989030950995) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.5234989030950995) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 
                    I) (-0.6690702663473906) $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-0.5234989030950995)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    3.786315565729376 (-0.6690702663473906) \
$CellContext`yunit$^2)/((-0.6690702663473906) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[I] (-0.6690702663473906) 
                    
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    3.786315565729376)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.5234989030950995)^2)/(
                    Plus[I] (-0.6690702663473906) Optica`Optica`TempVar2 - 
                    0.6690702663473906 Optica`Optica`TempVar1) - (
                    0.3333333333333333 \
(-0.5234989030950995))/((-0.6690702663473906) $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - (-0.6690702663473906) \
$CellContext`ry$ $CellContext`yunit$)/((-0.6690702663473906) \
$CellContext`yunit$^2)) $CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.316508170673232 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    3.786315565729376 $CellContext`LocSCx$ + 
                    0.5234989030950995 $CellContext`LocSCx$^2 + 
                    0.6690702663473906 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19497.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -2.8000000000000007` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(4.043563113267889 - $CellContext`rx$ + \
$CellContext`ry$ (0.21714194384609584` + $CellContext`ry$ (-1.822467736759229 + 
                    0.012891128463244314` \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((4.043563113267889 - $CellContext`rx$ + $CellContext`ry$ (
                    0.21714194384609584` + $CellContext`ry$ \
(-1.822467736759229 + 
                    0.012891128463244314` $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-1.822467736759229) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.822467736759229)^3 $CellContext`yunit$^3 + 
                    9 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314` $CellContext`yunit$^3 - 27 
                    4.043563113267889 
                    0.012891128463244314`^2 $CellContext`yunit$^3 + 
                    27 0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012891128463244314`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 0.21714194384609584` 
                    0.012891128463244314`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012891128463244314`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 0.21714194384609584` (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 0.21714194384609584`^2 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 4.043563113267889 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012891128463244314`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    0.21714194384609584`^2 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 4.043563113267889 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 0.21714194384609584`^3 
                    0.012891128463244314`^3 $CellContext`yunit$^6 - 486 
                    4.043563113267889 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`yunit$^6 + 
                    729 4.043563113267889^2 
                    0.012891128463244314`^4 $CellContext`yunit$^6 - 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012891128463244314`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-1.822467736759229) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^2 - 
                    2 (-1.822467736759229)^3 $CellContext`yunit$^3 + 
                    9 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314` $CellContext`yunit$^3 - 27 
                    4.043563113267889 
                    0.012891128463244314`^2 $CellContext`yunit$^3 + 
                    27 0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.012891128463244314`^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 0.21714194384609584` 
                    0.012891128463244314`^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.012891128463244314`^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 0.21714194384609584` (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 0.21714194384609584`^2 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 4.043563113267889 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 486 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 + 
                    1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 1458 
                    0.012891128463244314`^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 27 
                    0.21714194384609584`^2 (-1.822467736759229)^2 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 4.043563113267889 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`yunit$^6 + 
                    108 0.21714194384609584`^3 
                    0.012891128463244314`^3 $CellContext`yunit$^6 - 486 
                    4.043563113267889 
                    0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`yunit$^6 + 
                    729 4.043563113267889^2 
                    0.012891128463244314`^4 $CellContext`yunit$^6 - 
                    108 (-1.822467736759229)^3 
                    0.012891128463244314`^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 0.21714194384609584` (-1.822467736759229) 
                    0.012891128463244314`^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 4.043563113267889 
                    0.012891128463244314`^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.012891128463244314`^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) 0.21714194384609584`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2), \
((-0.3333333333333333) (-1.822467736759229))/
                    0.012891128463244314` + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    0.41997368329829105` (-1.822467736759229)^2 \
$CellContext`yunit$)/(Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` I] 
                    0.21714194384609584` $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) 0.21714194384609584`)/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 1.0911236359717214` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(0.012891128463244314` $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-1.822467736759229) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-1.822467736759229) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-1.822467736759229)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 I) 
                    0.21714194384609584` 
                    0.012891128463244314` $CellContext`yunit$^2)/(
                    0.012891128463244314` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012891128463244314` 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(0.012891128463244314` $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-1.822467736759229) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-1.822467736759229) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.012891128463244314` $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-1.822467736759229)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 0.6299605249474362 I) 
                    0.21714194384609584` 
                    0.012891128463244314` $CellContext`yunit$^2)/(
                    0.012891128463244314` 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.012891128463244314` 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` I) 
                    0.21714194384609584`)/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-1.822467736759229)^2)/(
                    Plus[I] 0.012891128463244314` Optica`Optica`TempVar2 + 
                    0.012891128463244314` Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-1.822467736759229))/(
                    0.012891128463244314` $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.012891128463244314` $CellContext`ry$ \
$CellContext`yunit$)/(
                    0.012891128463244314` $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.6000000000000001, $CellContext`LocSCx$ >= \
-0.6000000000000001, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-4.043563113267889 + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ - 
                    0.21714194384609584` $CellContext`LocSCx$ + 
                    1.822467736759229 $CellContext`LocSCx$^2 - 
                    0.012891128463244314` $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19596.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -4.199999999999999 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    0.1; $CellContext`LocSCy$ = 0.1; 
                    Which[Chop[$CellContext`yunit$] == 
                    0, {{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = 
                    Re[{(1.0237707217965322` - $CellContext`rx$ + \
$CellContext`ry$ (-3.838494761370709 + $CellContext`ry$ \
(-0.41717726174385045` + 
                    0.5711136238148176 \
$CellContext`ry$)))/$CellContext`xunit$, $CellContext`ry$, $CellContext`rz$ + \
((1.0237707217965322` - $CellContext`rx$ + $CellContext`ry$ \
(-3.838494761370709 + $CellContext`ry$ (-0.41717726174385045` + 
                    0.5711136238148176 $CellContext`ry$))) \
$CellContext`zunit$)/$CellContext`xunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}, True, 
                    Optica`Optica`TempVar1 = 
                    Re[((-9) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.41717726174385045`)^3 $CellContext`yunit$^3 + 
                    9 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`yunit$^3 - 27 
                    1.0237707217965322` 
                    0.5711136238148176^2 $CellContext`yunit$^3 + 
                    27 0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.5711136238148176^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.838494761370709) 
                    0.5711136238148176^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.5711136238148176^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.838494761370709) (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.838494761370709)^2 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 1.0237707217965322` (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.5711136238148176^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.838494761370709)^2 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 1.0237707217965322` (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 (-3.838494761370709)^3 
                    0.5711136238148176^3 $CellContext`yunit$^6 - 486 
                    1.0237707217965322` (-3.838494761370709) \
(-0.41717726174385045`) 0.5711136238148176^3 $CellContext`yunit$^6 + 
                    729 1.0237707217965322`^2 
                    0.5711136238148176^4 $CellContext`yunit$^6 - 
                    108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.5711136238148176^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar2 = 
                    Im[((-9) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$^2 - 27 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^2 - 2 (-0.41717726174385045`)^3 $CellContext`yunit$^3 + 
                    9 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176 $CellContext`yunit$^3 - 27 
                    1.0237707217965322` 
                    0.5711136238148176^2 $CellContext`yunit$^3 + 
                    27 0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^3 + Sqrt[(-108) 
                    0.5711136238148176^3 $CellContext`xunit$^3 \
$CellContext`yunit$^3 - 27 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 324 (-3.838494761370709) 
                    0.5711136238148176^3 $CellContext`xunit$^2 \
$CellContext`yunit$^4 + 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    729 0.5711136238148176^4 $CellContext`ry$^2 \
$CellContext`xunit$^2 $CellContext`yunit$^4 + 
                    54 (-3.838494761370709) (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`xunit$ \
$CellContext`yunit$^5 - 324 (-3.838494761370709)^2 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 + 486 1.0237707217965322` (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 + 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$^5 - 1458 
                    0.5711136238148176^4 $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$^5 - 
                    27 (-3.838494761370709)^2 (-0.41717726174385045`)^2 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 1.0237707217965322` (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`yunit$^6 + 
                    108 (-3.838494761370709)^3 
                    0.5711136238148176^3 $CellContext`yunit$^6 - 486 
                    1.0237707217965322` (-3.838494761370709) \
(-0.41717726174385045`) 0.5711136238148176^3 $CellContext`yunit$^6 + 
                    729 1.0237707217965322`^2 
                    0.5711136238148176^4 $CellContext`yunit$^6 - 
                    108 (-0.41717726174385045`)^3 
                    0.5711136238148176^2 $CellContext`rx$ \
$CellContext`yunit$^6 + 486 (-3.838494761370709) (-0.41717726174385045`) 
                    0.5711136238148176^3 $CellContext`rx$ \
$CellContext`yunit$^6 - 1458 1.0237707217965322` 
                    0.5711136238148176^4 $CellContext`rx$ \
$CellContext`yunit$^6 + 729 
                    0.5711136238148176^4 $CellContext`rx$^2 \
$CellContext`yunit$^6])^(3^(-1))]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = 
                    Re[{((-1.2599210498948732`) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), \
((-0.3333333333333333) (-0.41717726174385045`))/
                    0.5711136238148176 + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1)/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    0.41997368329829105` (-0.41717726174385045`)^2 \
$CellContext`yunit$)/(Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) + (
                    Plus[-(1.2599210498948732` I)] $CellContext`xunit$ + 
                    Plus[1.2599210498948732` 
                    I] (-3.838494761370709) $CellContext`yunit$)/(
                    Optica`Optica`TempVar2 - Plus[I] 
                    Optica`Optica`TempVar1), $CellContext`rz$ + \
(((-1.2599210498948732`) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) + (
                    0.41997368329829105` (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) + (
                    1.2599210498948732` $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + (
                    Plus[0.26456684199469993` I] Optica`Optica`TempVar2 + 
                    0.26456684199469993` Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474367 + 
                    1.0911236359717214` I) (-3.838494761370709))/(
                    Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), -(((
                    0.2291216061664338 + 0.13228342099734997` I) 
                    Optica`Optica`TempVar2^2 + (0.26456684199469993` - 
                    0.4582432123328676 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.2291216061664338 + 
                    0.13228342099734997` I) Optica`Optica`TempVar1^2 + 
                    0.33333333333333337` (-0.41717726174385045`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - 
                    Plus[0.33333333333333337` I] (-0.41717726174385045`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` - 0.6299605249474367 I) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$ + (0.3637078786572404 - 0.20998684164914552` 
                    I) (-0.41717726174385045`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` - 0.6299605249474368 
                    I) (-3.838494761370709) 
                    0.5711136238148176 $CellContext`yunit$^2)/(
                    0.5711136238148176 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.5711136238148176 
                    Optica`Optica`TempVar1 $CellContext`yunit$)), \
$CellContext`rz$ + (((0.6299605249474367 + 1.0911236359717214` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.20998684164914555` + 
                    0.3637078786572404 I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474367 + 1.0911236359717214` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + \
((-0.22912160616643382` - 0.13228342099734997` I) Optica`Optica`TempVar2 - (
                    0.13228342099734997` - 0.22912160616643382` I) 
                    Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = Re[{((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2), ((
                    0.22912160616643384` - 0.13228342099735002` I) 
                    Optica`Optica`TempVar2^2 - (0.26456684199470004` + 
                    0.4582432123328677 I) Optica`Optica`TempVar2 
                    Optica`Optica`TempVar1 - (0.22912160616643384` - 
                    0.13228342099735002` I) 
                    Optica`Optica`TempVar1^2 - (0.33333333333333326` + 
                    2.7755575615628914`*^-17 I) (-0.41717726174385045`) 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - (
                    2.7755575615628914`*^-17 - 0.33333333333333326` 
                    I) (-0.41717726174385045`) 
                    Optica`Optica`TempVar1 $CellContext`yunit$ + (
                    1.0911236359717216` + 0.6299605249474364 I) 
                    0.5711136238148176 $CellContext`xunit$ \
$CellContext`yunit$ + (0.36370787865724047` + 
                    0.20998684164914547` 
                    I) (-0.41717726174385045`)^2 $CellContext`yunit$^2 - (
                    1.0911236359717214` + 
                    0.6299605249474362 I) (-3.838494761370709) 
                    0.5711136238148176 $CellContext`yunit$^2)/(
                    0.5711136238148176 
                    Optica`Optica`TempVar2 $CellContext`yunit$ - Plus[I] 
                    0.5711136238148176 
                    Optica`Optica`TempVar1 $CellContext`yunit$), \
$CellContext`rz$ + (((0.6299605249474363 - 1.0911236359717216` 
                    I) (-3.838494761370709))/(Plus[I] Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar1) - ((0.2099868416491454 - 
                    0.36370787865724047` I) (-0.41717726174385045`)^2)/(
                    Plus[I] 0.5711136238148176 Optica`Optica`TempVar2 + 
                    0.5711136238148176 Optica`Optica`TempVar1) - (
                    0.3333333333333333 (-0.41717726174385045`))/(
                    0.5711136238148176 $CellContext`yunit$) - ((
                    0.6299605249474363 - 1.0911236359717216` 
                    I) $CellContext`xunit$)/(
                    Plus[I] Optica`Optica`TempVar2 $CellContext`yunit$ + 
                    Optica`Optica`TempVar1 $CellContext`yunit$) + ((
                    0.22912160616643382` - 0.13228342099734997` I) 
                    Optica`Optica`TempVar2 - (0.13228342099734997` + 
                    0.22912160616643382` I) Optica`Optica`TempVar1 - 
                    0.5711136238148176 $CellContext`ry$ $CellContext`yunit$)/(
                    0.5711136238148176 $CellContext`yunit$^2)) \
$CellContext`zunit$}]; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 0., 
                    
                    And[$CellContext`LocSCx$ <= 
                    0.7999999999999998, $CellContext`LocSCx$ >= \
-0.7999999999999998, $CellContext`LocSCy$ >= -5., $CellContext`LocSCy$ <= 5.],
                     Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[-1.0237707217965322` + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    3.838494761370709 $CellContext`LocSCx$ + 
                    0.41717726174385045` $CellContext`LocSCx$^2 - 
                    0.5711136238148176 $CellContext`LocSCx$^3] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    Optica`Optica`TempVar = Union[Optica`Optica`TempVar]; 
                    Optica`Optica`TempVar]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 19695.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    4.4 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    19002.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    19002.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = -4.4 + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -3.1826846889173774` + 
                    2.37479908157637 $CellContext`ray2$ + 
                    0.7843009879640519 $CellContext`ray2$^2, 0.}, {
                    3.1826846889173774` - 2.37479908157637 $CellContext`ray2$ - 
                    0.7843009879640519 $CellContext`ray2$^2, 1., 0.}, {0., 0.,
                     1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -3.1826846889173774` + 
                    2.37479908157637 (1.*^-6 + $CellContext`ray2$) + 
                    0.7843009879640519 (1.*^-6 + $CellContext`ray2$)^2, 0.}, {
                    3.1826846889173774` - 
                    2.37479908157637 (1.*^-6 + $CellContext`ray2$) - 
                    0.7843009879640519 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, -4.4, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    3.1999999999999997` + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    19101.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    19101.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = -3.1999999999999997` + \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0.784406657006282 + 
                    3.6435643592001448` $CellContext`ray2$ - 
                    0.03664185046909857 $CellContext`ray2$^2, 
                    0.}, {-0.784406657006282 - 
                    3.6435643592001448` $CellContext`ray2$ + 
                    0.03664185046909857 $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 0.784406657006282 + 
                    3.6435643592001448` (1.*^-6 + $CellContext`ray2$) - 
                    0.03664185046909857 (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-0.784406657006282 - 
                    3.6435643592001448` (1.*^-6 + $CellContext`ray2$) + 
                    0.03664185046909857 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, -3.1999999999999997`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    2. + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    19200.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    19200.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = -2. + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 3.879296029155285 + 
                    0.48591485983293997` $CellContext`ray2$ - 
                    1.6225688727405028` $CellContext`ray2$^2, 
                    0.}, {-3.879296029155285 - 
                    0.48591485983293997` $CellContext`ray2$ + 
                    1.6225688727405028` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 3.879296029155285 + 
                    0.48591485983293997` (1.*^-6 + $CellContext`ray2$) - 
                    1.6225688727405028` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-3.879296029155285 - 
                    0.48591485983293997` (1.*^-6 + $CellContext`ray2$) + 
                    1.6225688727405028` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, -2., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = 
                    0.7999999999999998 + $CellContext`rey$; $CellContext`rz$ = $\
CellContext`rez$; $CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    19299.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 4., 
                    19299.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = -0.7999999999999998 + \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 2.0734307382635766` - 
                    3.301203783236322 $CellContext`ray2$ - 
                    1.200107544494984 $CellContext`ray2$^2, 
                    0.}, {-2.0734307382635766` + 
                    3.301203783236322 $CellContext`ray2$ + 
                    1.200107544494984 $CellContext`ray2$^2, 1., 0.}, {0., 0., 
                    1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 2.0734307382635766` - 
                    3.301203783236322 (1.*^-6 + $CellContext`ray2$) - 
                    1.200107544494984 (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-2.0734307382635766` + 
                    3.301203783236322 (1.*^-6 + $CellContext`ray2$) + 
                    1.200107544494984 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, -0.7999999999999998, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -0.40000000000000036` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    19398.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 5., 
                    19398.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = 
                    0.40000000000000036` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -2.657549986067966 - 
                    2.793883214339491 $CellContext`ray2$ + 
                    1.6737612196758336` $CellContext`ray2$^2, 0.}, {
                    2.657549986067966 + 2.793883214339491 $CellContext`ray2$ - 
                    1.6737612196758336` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -2.657549986067966 - 
                    2.793883214339491 (1.*^-6 + $CellContext`ray2$) + 
                    1.6737612196758336` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {2.657549986067966 + 
                    2.793883214339491 (1.*^-6 + $CellContext`ray2$) - 
                    1.6737612196758336` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, 0.40000000000000036`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -1.5999999999999996` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    19497.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 6., 
                    19497.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = 
                    1.5999999999999996` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -3.786315565729376 + 
                    1.046997806190199 $CellContext`ray2$ + 
                    2.0072107990421717` $CellContext`ray2$^2, 0.}, {
                    3.786315565729376 - 1.046997806190199 $CellContext`ray2$ - 
                    2.0072107990421717` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -3.786315565729376 + 
                    1.046997806190199 (1.*^-6 + $CellContext`ray2$) + 
                    2.0072107990421717` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {3.786315565729376 - 
                    1.046997806190199 (1.*^-6 + $CellContext`ray2$) - 
                    2.0072107990421717` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, 1.5999999999999996`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -2.8000000000000007` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    19596.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 7., 
                    19596.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = 
                    2.8000000000000007` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -0.21714194384609584` + 
                    3.644935473518458 $CellContext`ray2$ - 
                    0.038673385389732945` $CellContext`ray2$^2, 0.}, {
                    0.21714194384609584` - 
                    3.644935473518458 $CellContext`ray2$ + 
                    0.038673385389732945` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -0.21714194384609584` + 
                    3.644935473518458 (1.*^-6 + $CellContext`ray2$) - 
                    0.038673385389732945` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {0.21714194384609584` - 
                    3.644935473518458 (1.*^-6 + $CellContext`ray2$) + 
                    0.038673385389732945` (1.*^-6 + $CellContext`ray2$)^2, 1.,
                     0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, 2.8000000000000007`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    8, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = -4.199999999999999 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 8., 
                    19695.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 8., 
                    19695.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = 
                    4.199999999999999 + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 3.838494761370709 + 
                    0.8343545234877009 $CellContext`ray2$ - 
                    1.7133408714444527` $CellContext`ray2$^2, 
                    0.}, {-3.838494761370709 - 
                    0.8343545234877009 $CellContext`ray2$ + 
                    1.7133408714444527` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 3.838494761370709 + 
                    0.8343545234877009 (1.*^-6 + $CellContext`ray2$) - 
                    1.7133408714444527` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-3.838494761370709 - 
                    0.8343545234877009 (1.*^-6 + $CellContext`ray2$) + 
                    1.7133408714444527` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, 4.199999999999999, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    9, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    4.4 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 9., 
                    19002.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 9., 
                    19002.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = -4.4 + \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -3.1826846889173774` + 
                    2.37479908157637 $CellContext`ray2$ + 
                    0.7843009879640519 $CellContext`ray2$^2, 0.}, {
                    3.1826846889173774` - 2.37479908157637 $CellContext`ray2$ - 
                    0.7843009879640519 $CellContext`ray2$^2, 1., 0.}, {0., 0.,
                     1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -3.1826846889173774` + 
                    2.37479908157637 (1.*^-6 + $CellContext`ray2$) + 
                    0.7843009879640519 (1.*^-6 + $CellContext`ray2$)^2, 0.}, {
                    3.1826846889173774` - 
                    2.37479908157637 (1.*^-6 + $CellContext`ray2$) - 
                    0.7843009879640519 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., -4.4, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    10, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    3.1999999999999997` + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 10., 
                    19101.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 10., 
                    19101.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = \
-3.1999999999999997` + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0.784406657006282 + 
                    3.6435643592001448` $CellContext`ray2$ - 
                    0.03664185046909857 $CellContext`ray2$^2, 
                    0.}, {-0.784406657006282 - 
                    3.6435643592001448` $CellContext`ray2$ + 
                    0.03664185046909857 $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 0.784406657006282 + 
                    3.6435643592001448` (1.*^-6 + $CellContext`ray2$) - 
                    0.03664185046909857 (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-0.784406657006282 - 
                    3.6435643592001448` (1.*^-6 + $CellContext`ray2$) + 
                    0.03664185046909857 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., -3.1999999999999997`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    11, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    
                    2. + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 11., 
                    19200.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 11., 
                    19200.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = -2. + \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 3.879296029155285 + 
                    0.48591485983293997` $CellContext`ray2$ - 
                    1.6225688727405028` $CellContext`ray2$^2, 
                    0.}, {-3.879296029155285 - 
                    0.48591485983293997` $CellContext`ray2$ + 
                    1.6225688727405028` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 3.879296029155285 + 
                    0.48591485983293997` (1.*^-6 + $CellContext`ray2$) - 
                    1.6225688727405028` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-3.879296029155285 - 
                    0.48591485983293997` (1.*^-6 + $CellContext`ray2$) + 
                    1.6225688727405028` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., -2., 0}; $CellContext`activeregion$ = 
                    
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    12, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = 
                    0.7999999999999998 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 12., 
                    19299.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 12., 
                    19299.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = \
-0.7999999999999998 + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 2.0734307382635766` - 
                    3.301203783236322 $CellContext`ray2$ - 
                    1.200107544494984 $CellContext`ray2$^2, 
                    0.}, {-2.0734307382635766` + 
                    3.301203783236322 $CellContext`ray2$ + 
                    1.200107544494984 $CellContext`ray2$^2, 1., 0.}, {0., 0., 
                    1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 2.0734307382635766` - 
                    3.301203783236322 (1.*^-6 + $CellContext`ray2$) - 
                    1.200107544494984 (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-2.0734307382635766` + 
                    3.301203783236322 (1.*^-6 + $CellContext`ray2$) + 
                    1.200107544494984 (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., -0.7999999999999998, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    13, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -0.40000000000000036` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 13., 
                    19398.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 13., 
                    19398.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = 
                    0.40000000000000036` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -2.657549986067966 - 
                    2.793883214339491 $CellContext`ray2$ + 
                    1.6737612196758336` $CellContext`ray2$^2, 0.}, {
                    2.657549986067966 + 2.793883214339491 $CellContext`ray2$ - 
                    1.6737612196758336` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -2.657549986067966 - 
                    2.793883214339491 (1.*^-6 + $CellContext`ray2$) + 
                    1.6737612196758336` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {2.657549986067966 + 
                    2.793883214339491 (1.*^-6 + $CellContext`ray2$) - 
                    1.6737612196758336` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., 0.40000000000000036`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    14, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -1.5999999999999996` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 14., 
                    19497.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 14., 
                    19497.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = 
                    1.5999999999999996` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -3.786315565729376 + 
                    1.046997806190199 $CellContext`ray2$ + 
                    2.0072107990421717` $CellContext`ray2$^2, 0.}, {
                    3.786315565729376 - 1.046997806190199 $CellContext`ray2$ - 
                    2.0072107990421717` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -3.786315565729376 + 
                    1.046997806190199 (1.*^-6 + $CellContext`ray2$) + 
                    2.0072107990421717` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {3.786315565729376 - 
                    1.046997806190199 (1.*^-6 + $CellContext`ray2$) - 
                    2.0072107990421717` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., 1.5999999999999996`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    15, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -2.8000000000000007` + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 15., 
                    19596.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 15., 
                    19596.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = 
                    2.8000000000000007` + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -0.21714194384609584` + 
                    3.644935473518458 $CellContext`ray2$ - 
                    0.038673385389732945` $CellContext`ray2$^2, 0.}, {
                    0.21714194384609584` - 
                    3.644935473518458 $CellContext`ray2$ + 
                    0.038673385389732945` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., -0.21714194384609584` + 
                    3.644935473518458 (1.*^-6 + $CellContext`ray2$) - 
                    0.038673385389732945` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {0.21714194384609584` - 
                    3.644935473518458 (1.*^-6 + $CellContext`ray2$) + 
                    0.038673385389732945` (1.*^-6 + $CellContext`ray2$)^2, 1.,
                     0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., 2.8000000000000007`, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    16, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1. + \
$CellContext`rex$; $CellContext`ry$ = -4.199999999999999 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 16., 
                    19695.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 16., 
                    19695.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1. + $CellContext`rxhlp$; $CellContext`rey$ = 
                    4.199999999999999 + $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 3.838494761370709 + 
                    0.8343545234877009 $CellContext`ray2$ - 
                    1.7133408714444527` $CellContext`ray2$^2, 
                    0.}, {-3.838494761370709 - 
                    0.8343545234877009 $CellContext`ray2$ + 
                    1.7133408714444527` $CellContext`ray2$^2, 1., 0.}, {0., 
                    0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., 3.838494761370709 + 
                    0.8343545234877009 (1.*^-6 + $CellContext`ray2$) - 
                    1.7133408714444527` (1.*^-6 + $CellContext`ray2$)^2, 
                    0.}, {-3.838494761370709 - 
                    0.8343545234877009 (1.*^-6 + $CellContext`ray2$) + 
                    1.7133408714444527` (1.*^-6 + $CellContext`ray2$)^2, 1., 
                    0.}, {0., 0., 1.}}]; 1., 1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1., 4.199999999999999, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
             1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

             "]; $CellContext`deflectedrayspresent$ = 
            True; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = True; While[
             And[$CellContext`deflectedrayspresent$, $CellContext`propagate$],
              AddTo[$CellContext`generationnumber$, 
               1.]; ($CellContext`deflecteddummyrayspresent$ = 
               False; $CellContext`deflectedrayspresent$ = 
               False; $CellContext`reportedrayspresent$ = 
               False; $CellContext`reporteddummyrayspresent$ = 
               True; $CellContext`localdummyoutrayspresent$ = 
               False; $CellContext`localoutrayspresent$ = 
               False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
               Map[Flatten[#, 1]& , 
                 Transpose[
                  
                  Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$82}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$82 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$82), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$82, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$82}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20837.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    6. + $CellContext`rey$; $CellContext`ry$ = \
-$CellContext`rex$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$84}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$84 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$84), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$84, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$84}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20838.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    6. + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$82}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$82 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$82), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$82, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$82}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20839.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rey$); $CellContext`ry$ = $CellContext`rex$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$84}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$84 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$84), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$84, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$84}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20840.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    6. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -$CellContext`rex$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$83}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$83 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$83), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$83, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$83}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20841.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-$CellContext`rex$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$83}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 6., Part[#, 2] >= -6., Part[#, 3] >= -6., 
                    Part[#, 3] <= 6.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$83 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$83), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$83, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$83}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 20842.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    20837.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    20837.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    6. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    6., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    6. + $CellContext`rey$; $CellContext`ry$ = \
-$CellContext`rex$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    20838.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    20838.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-$CellContext`ryhlp$; $CellContext`rey$ = -6. + $CellContext`rxhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, -6., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    
                    6. + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    20839.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 3., 
                    20839.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-6. + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-6., 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rey$); $CellContext`ry$ = $CellContext`rex$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    20840.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 4., 
                    20840.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`ryhlp$; $CellContext`rey$ = 
                    6. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0, 6., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    6. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -$CellContext`rex$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    20841.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 5., 
                    20841.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-$CellContext`rzhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = -6. + $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    0, 0, -6.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-6. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-$CellContext`rex$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    20842.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 6., 
                    20842.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-$CellContext`rzhlp$; $CellContext`rey$ = -$CellContext`ryhlp$; \
$CellContext`rez$ = 6. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    0, 0, 6.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                
                And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                 1., 1.]; 
              If[$CellContext`localoutrayspresent$, 
                If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                   Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 1.,
                   1.]; $CellContext`outrays$ = 
                 Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1., 
                1.]; If[
                
                And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                 Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                1., 1.]); 
             If[$CellContext`reportedrayspresent$, $CellContext`raysreported$ = 
                True; $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
            If[Length[$CellContext`outrays$] > 1, 
              Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
             
             And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
              
              Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
          If[Length[$CellContext`reportedrays$] > 
            2, $CellContext`reportedrays$ = 
            Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
          Map[{
             Part[#, 1], 
             Part[#, 2], 
             Part[#, 3], 
             Part[#, 4], 
             Part[#, 5], 
             
             Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.609795107685882*^9, 3.609795211285623*^9, {3.609796072201009*^9, 
   3.6097961093301086`*^9}, 3.609796143428746*^9, 3.6097962740873003`*^9, 
   3.6147105612028847`*^9}]
}, Open  ]]
},
WindowSize->{1530, 854},
WindowMargins->{{408, Automatic}, {Automatic, 64}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3614692540-3788911"->{
  Cell[678, 25, 1072, 15, 147, "Print",
   CellTags->"Info3614692540-3788911"],
  Cell[2026, 56, 1122, 20, 74, "Print",
   CellTags->"Info3614692540-3788911"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3614692540-3788911", 1158152, 19864}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 96, 1, 29, "Input"],
Cell[678, 25, 1072, 15, 147, "Print",
 CellTags->"Info3614692540-3788911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1787, 45, 27, 0, 29, "Input"],
Cell[1817, 47, 79, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1933, 53, 90, 1, 29, "Input"],
Cell[2026, 56, 1122, 20, 74, "Print",
 CellTags->"Info3614692540-3788911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3185, 81, 210, 4, 29, "Input"],
Cell[3398, 87, 4881, 125, 97, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8316, 217, 109, 1, 29, "Input"],
Cell[8428, 220, 1457, 30, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9922, 255, 179, 2, 29, "Input"],
Cell[CellGroupData[{
Cell[10126, 261, 311, 7, 21, "Print"],
Cell[10440, 270, 708, 14, 22, "Print"],
Cell[11151, 286, 2174, 62, 38, "Print"],
Cell[13328, 350, 896, 26, 22, "Print"],
Cell[14227, 378, 897, 26, 21, "Print"],
Cell[15127, 406, 36233, 621, 237, "Print"],
Cell[51363, 1029, 1390, 28, 231, "Print"],
Cell[52756, 1059, 29882, 527, 241, "Print"]
}, Open  ]],
Cell[82653, 1589, 7620, 201, 148, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90310, 1795, 111, 1, 29, "Input"],
Cell[90424, 1798, 7976, 166, 433, "Print"]
}, Open  ]],
Cell[98415, 1967, 155, 3, 29, "Input"],
Cell[CellGroupData[{
Cell[98595, 1974, 86, 1, 29, "Input"],
Cell[98684, 1977, 14318, 302, 394, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113039, 2284, 450, 8, 29, "Input"],
Cell[113492, 2294, 1044301, 17555, 940, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
