(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    247922,       9686]*)
(*NotebookOutlinePosition[    248720,       9714]*)
(*  CellTagsIndexPosition[    248676,       9710]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Construction of a trapezodial prism", "Chapter"],

Cell[CellGroupData[{

Cell["Dimensions", "SubsectionIcon"],

Cell["\<\
The prism will have a length L with entrance aperture {a,b} and \
exit aperture {c,d}. At the entrance we use a spherical surface with radius \
R. All other surfaces are planar. The trapezodial shape of the sides is \
defined by the entrance and exit apertures.\
\>", "Text"],

Cell["Off[General::\"spell1\"];", "Input",
  CellLabel->"In[68]:=",
  FormatType->InputForm]
}, Closed]],

Cell[CellGroupData[{

Cell["Surfaces needed", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Entrance and Exit", "SubsubsectionIcon"],

Cell["\<\
Clear[entrancesurface];
entrancesurface[a_, b_, R_, options___] := 
\tComponentRendering[
\t\tComponentFoundation[ R, {a, b}, SurfaceLabel->SphericalShape, options ]
\t, options];\
\>", "Input",
  CellLabel->"In[114]:="],

Cell["\<\
Clear[exitsurface];
exitsurface[c_, d_, L_, options___] := 
\tComponentRendering[
\t\tMove[
\t\t\tComponentFoundation[ Infinity, {c, d}, options]
\t\t,
\t\t\tL
\t\t]
\t, options];\
\>", "Input",
  CellLabel->"In[181]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Top and Bottom", "SubsubsectionIcon"],

Cell["\<\
The top and bottom surfaces are initially oriented along the \
z-axis, the second surface coordinate. The top surface is initially upside \
down.\
\>", "Text"],

Cell["\<\
Clear[topsurface];
topsurface[a_, b_, c_, d_, L_, options___] := 
Block[{angle, p1, p2, p3, p4, top},
\tangle = ArcTan[L,(b-d)/2];
\tp1 = { a/2,0};
\tp2 = { c/2,-L};
\tp3 = {-c/2,-L};
\tp4 = {-a/2,0};

\ttop = ComponentFoundation[ Infinity, {p1,p2,p3,p4}, options ];
\ttop = Move3D[
\t\ttop
\t,
\t\t{0,0,0.5 b}
\t,
\t\t{Sin[angle],0,Cos[angle]}
\t,
\t\t0
\t];
\ttop = ComponentRendering[top, options]
];\
\>", "Input",
  CellLabel->"In[133]:="],

Cell["\<\
Clear[bottomsurface];
bottomsurface[a_, b_, c_, d_, L_, options___] := 
Block[{angle, p1, p2, p3, p4, bottom},
\tangle = ArcTan[L,(b-d)/2];
\tp1 = {-a/2,0};
\tp2 = {-c/2,L};
\tp3 = { c/2,L};
\tp4 = { a/2,0};
\t
\tbottom = ComponentFoundation[ Infinity, {p1,p2,p3,p4}, options ];
\tbottom = Move3D[
\t\tbottom
\t,
\t\t{0,0,-0.5 b}
\t,
\t\t{Sin[-angle],0,Cos[-angle]}
\t,
\t\t0
\t];
\tbottom = ComponentRendering[bottom, options]
];\
\>", "Input",
  CellLabel->"In[135]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Left and Right", "SubsubsectionIcon"],

Cell["\<\
The left and right surfaces are initially oriented in the \
y-direction, the first surface coordinate.\
\>", "Text"],

Cell["\<\
Clear[leftsurface];
leftsurface[a_, b_, c_, d_, L_, options___] :=
Block[{angle, p1, p2, p3, p4, left},
\tangle = ArcTan[L,(a-c)/2];
\tp1 = {0,-b/2};
\tp2 = {L,-d/2};
\tp3 = {L, d/2};
\tp4 = {0, b/2};
\t
\tleft = ComponentFoundation[ Infinity, {p1,p2,p3,p4}, options ];
\tleft = Move3D[
\t\tleft
\t,
\t\t{0,-0.5 a,0}
\t,
\t\t{Sin[angle],-Cos[angle],0}
\t,
\t\t0
\t];
\tleft = ComponentRendering[left, options]
];\
\>", "Input",
  CellLabel->"In[229]:="],

Cell["\<\
Clear[rightsurface];
rightsurface[a_, b_, c_, d_, L_, options___] := 
Block[{angle, p1, p2, p3, p4, left},
\tangle = ArcTan[L,(a-c)/2];
\tp1 = {0,-b/2};
\tp2 = {L,-d/2};
\tp3 = {L, d/2};
\tp4 = {0, b/2};

\tright = ComponentFoundation[ Infinity, {p1,p2,p3,p4}, options];
\tright = Move3D[
\t\tright
\t,
\t\t{0,0.5 a,0}
\t,
\t\t{Sin[angle],Cos[angle],0}
\t,
\t\t180
\t];
\tright = ComponentRendering[right, options]
];\
\>", "Input",
  CellLabel->"In[231]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[topsurface[20., 10., 3., 7., 80, GraphicDesign->Wire], \
Axes -> True, BoxRatios -> {1, 1/3, 1/8}];\
\>", "Input",
  CellLabel->"In[196]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53258 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0220751 1.02208 -0.223233 1.02208 [
[.02977 .27234 -4.0285 -10.9375 ]
[.02977 .27234 4.9715 0 ]
[.21565 .20857 -6.557 -10.9375 ]
[.21565 .20857 7.443 0 ]
[.41181 .14129 -6.87296 -10.9375 ]
[.41181 .14129 7.12704 0 ]
[.61912 .0702 -7.21795 -10.9375 ]
[.61912 .0702 6.78205 0 ]
[.83857 -0.00502 -7.59615 -10.9375 ]
[.83857 -0.00502 6.40385 0 ]
[.87755 .00066 0 -7.33422 ]
[.87755 .00066 20.9375 3.60328 ]
[.90929 .04766 0 -7.33533 ]
[.90929 .04766 15.9375 3.66467 ]
[.93993 .09303 0 -7.25481 ]
[.93993 .09303 9 3.68269 ]
[.96952 .13684 0 -7.25883 ]
[.96952 .13684 9 3.74117 ]
[.99811 .17917 0 -7.18188 ]
[.99811 .17917 14 3.75562 ]
[1.00117 .18557 0 -7.21779 ]
[1.00117 .18557 16.5 3.78221 ]
[1.00472 .21598 0 -7.15494 ]
[1.00472 .21598 9 3.78256 ]
[1.00832 .24682 0 -7.17357 ]
[1.00832 .24682 16.5 3.82643 ]
[1.01196 .27811 0 -7.15101 ]
[1.01196 .27811 9 3.84899 ]
[ 0 0 0 0 ]
[ 1 .53258 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21484 .22132 m
.21444 .2277 L
s
gsave
.21565 .20857 -67.557 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41157 .15406 m
.41146 .16045 L
s
gsave
.41181 .14129 -67.873 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61952 .08297 m
.61972 .08936 L
s
gsave
.61912 .0702 -68.218 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83966 .00771 m
.8402 .01408 L
s
gsave
.83857 -0.00502 -68.5961 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07412 .26943 m
.07375 .27325 L
s
.1204 .25361 m
.12008 .25743 L
s
.16731 .23757 m
.16702 .2414 L
s
.26302 .20485 m
.26282 .20868 L
s
.31186 .18815 m
.31171 .19198 L
s
.36138 .17123 m
.36126 .17506 L
s
.46247 .13666 m
.46245 .1405 L
s
.51409 .11902 m
.51411 .12285 L
s
.56643 .10112 m
.5665 .10496 L
s
.67337 .06456 m
.67354 .06839 L
s
.728 .04589 m
.72822 .04971 L
s
.78342 .02694 m
.78369 .03076 L
s
.25 Mabswid
.86222 0 m
.98872 .18714 L
s
.86545 .00479 m
.85941 .00685 L
s
gsave
.87755 .00066 -61 -11.3342 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.89717 .05171 m
.89111 .05373 L
s
gsave
.90929 .04766 -61 -11.3353 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.92778 .09699 m
.92171 .09898 L
s
gsave
.93993 .09303 -61 -11.2548 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.95735 .14073 m
.95126 .14267 L
s
gsave
.96952 .13684 -61 -11.2588 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98591 .18299 m
.97982 .1849 L
s
gsave
.99811 .17917 -61 -11.1819 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87189 .01431 m
.86826 .01554 L
s
.87828 .02376 m
.87465 .02498 L
s
.88462 .03314 m
.88099 .03436 L
s
.89092 .04246 m
.88729 .04367 L
s
.90338 .06089 m
.89974 .0621 L
s
.90955 .07001 m
.90591 .07122 L
s
.91567 .07907 m
.91203 .08027 L
s
.92175 .08806 m
.91811 .08926 L
s
.93378 .10586 m
.93013 .10705 L
s
.93973 .11467 m
.93609 .11585 L
s
.94565 .12341 m
.942 .12459 L
s
.95152 .1321 m
.94787 .13327 L
s
.96314 .14929 m
.95949 .15046 L
s
.96889 .1578 m
.96524 .15896 L
s
.9746 .16626 m
.97095 .16741 L
s
.98028 .17465 m
.97662 .1758 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18938 m
.98288 .19128 L
s
gsave
1.00117 .18557 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99251 .21974 m
.98641 .22163 L
s
gsave
1.00472 .21598 -61 -11.1549 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99609 .25054 m
.98998 .2524 L
s
gsave
1.00832 .24682 -61 -11.1736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98968 .19542 m
.98602 .19656 L
s
.99039 .20147 m
.98673 .20261 L
s
.99109 .20755 m
.98743 .20868 L
s
.9918 .21364 m
.98814 .21477 L
s
.99322 .22587 m
.98956 .227 L
s
.99394 .23201 m
.99027 .23313 L
s
.99465 .23817 m
.99099 .23929 L
s
.99537 .24435 m
.99171 .24547 L
s
.99682 .25675 m
.99315 .25787 L
s
.99754 .26298 m
.99387 .26409 L
s
.99827 .26923 m
.9946 .27034 L
s
.99899 .2755 m
.99532 .2766 L
s
0 0 m
1 0 L
1 .53258 L
0 .53258 L
closepath
clip
newpath
.5 Mabswid
.18554 .52176 m
.915 .11969 L
s
.48896 .2878 m
.18554 .52176 L
s
.02304 .38166 m
.18554 .52176 L
s
.02304 .38166 m
.48896 .2878 L
s
.89677 .09316 m
.02304 .38166 L
s
.48896 .2878 m
.89677 .09316 L
s
.48896 .2878 m
.915 .11969 L
s
.915 .11969 m
.89677 .09316 L
s
.25 Mabswid
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21484 .22132 m
.21444 .2277 L
s
gsave
.21565 .20857 -67.557 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41157 .15406 m
.41146 .16045 L
s
gsave
.41181 .14129 -67.873 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61952 .08297 m
.61972 .08936 L
s
gsave
.61912 .0702 -68.218 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83966 .00771 m
.8402 .01408 L
s
gsave
.83857 -0.00502 -68.5961 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07412 .26943 m
.07375 .27325 L
s
.1204 .25361 m
.12008 .25743 L
s
.16731 .23757 m
.16702 .2414 L
s
.26302 .20485 m
.26282 .20868 L
s
.31186 .18815 m
.31171 .19198 L
s
.36138 .17123 m
.36126 .17506 L
s
.46247 .13666 m
.46245 .1405 L
s
.51409 .11902 m
.51411 .12285 L
s
.56643 .10112 m
.5665 .10496 L
s
.67337 .06456 m
.67354 .06839 L
s
.728 .04589 m
.72822 .04971 L
s
.78342 .02694 m
.78369 .03076 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18938 m
.98288 .19128 L
s
gsave
1.00117 .18557 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99251 .21974 m
.98641 .22163 L
s
gsave
1.00472 .21598 -61 -11.1549 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99609 .25054 m
.98998 .2524 L
s
gsave
1.00832 .24682 -61 -11.1736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98968 .19542 m
.98602 .19656 L
s
.99039 .20147 m
.98673 .20261 L
s
.99109 .20755 m
.98743 .20868 L
s
.9918 .21364 m
.98814 .21477 L
s
.99322 .22587 m
.98956 .227 L
s
.99394 .23201 m
.99027 .23313 L
s
.99465 .23817 m
.99099 .23929 L
s
.99537 .24435 m
.99171 .24547 L
s
.99682 .25675 m
.99315 .25787 L
s
.99754 .26298 m
.99387 .26409 L
s
.99827 .26923 m
.9946 .27034 L
s
.99899 .2755 m
.99532 .2766 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[196]:=",
  ImageSize->{306.125, 163},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004b0000X`P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_md<g@00?md<g@00?md<g@00?md<g@00?md
<g@00?md<g@00>Ud0Q43M08A@W@00>Qd00HAM7@AM142M0034GAd03md003XM0064GAd4G@A0W@00a5d
M00oM000jG@24@9d00@AM7@A@G@00>Qd00HAM7@AM142M0034GAd03md003XM0064GAd4G@A0W@00a5d
M00@M0<A0W@24BQd003YM08A0g@24AAd00@AM7@A0W@00a5dM00UM000lg@24@Md1144M0044GAd4@9d
00<AM7@09G@00?1d0a42M0034GAd00ad00@AM7@A0W@00a5dM00UM000kG@34@Ad0Q4>M0044GAd4@9d
00<AM7@09G@00>Yd0a400g@AM006M0034GAd00Yd0Q42M0044GAd4BMd003WM0<A17@00a5dM005M08A
37@0115dM7@24BQd003TM0<A47@00a5dM00hM000hW@24AAd00<AM7@0=g@00=id114FM08A>7@00=ad
0a4KM0034GAd03Ed003IM0<A7W@24CId003FM0<A8G@24CId003CM0<A9W@00a5dM00<M0<A97@00=1d
0a4XM08A3W@0115dM14SM000cG@34Bed00<AM7@01G@44@Ed00<AM7@08G@00:ad0Q43M08A5g@34@9d
00<AM7@0;7@00a5dM00=M0034GAd025d002[M0064GAd4G@A0W@00a5dM00AM0<A<g@24@ad0a4TM000
Zg@01Q5dM15d4@9d00<AM7@03W@34CQd00<AM7@02W@00a5dM00SM000Zg@01Q5dM15d4@9d00<AM7@0
2g@34C]d0Q4;M0<A8g@00:]d0a42M0044GAd4@]d0Q4oM0034GAd02md002/M0054GAdM1400W@00a5d
M006M0@A@G@00a5dM00^M000[G@24@9d0Q46M0<AAG@24Bmd002fM0<ABW@00a5dM00/M000/g@34Dad
0Q4^M000/7@34E5d00<AM7@0:g@00:ed115DM0034GAd00Ed0Q4SM000ZW@34@=d00<AM7@0DG@24@Id
00@AM7@A8W@00:Md0a5CM08A1g@00a5dM003M0044GAd4B9d002TM0<ADg@34@9d00<AM7@017@24@Ad
00@AM7@A8W@00:5d0a5CM0@A17@00a5dM003M0034G@A00Ad00@AM7@A8W@009md0a5BM0DA1g@00a5d
M005M0054GAdM1400W@00a5dM00PM000W7@34E9d0a400g@A4@0:M0034GAd00Ad0Q43M08A8g@009Ud
0a5BM0<A0W@24@ed00<AM7@017@00a5dM00VM000UW@34E9d0a43M08A3g@00a5dM004M08A9g@009=d
0a5BM0<A17@24A5d0Q47M0034GAd02Ad001dM0034GAd008A5g@44E5d0a45M08A4G@34@Ud00<AM7@0
8g@007Ad00<AM1400W@00a5dM00AM0<ADW@34@Id0Q4@M0@A2W@24BEd001aM0HA0W@00a5dM00>M0<A
DW@34@Md0Q4@M0@A3W@00a5dM005M0<A6W@0075d00HAM7@AM142M0034GAd00]d0a5BM0<A27@24@md
1A4?M0<A1W@0115dM14IM000LW@01A5d4G@A009d00<AM7@027@34E9d0a49M08A3g@24@9d00<AM7@0
4G@00a5dM007M0034GAd01Md001cM08A00Ed4GAd4@07M0@ADG@34@Yd0Q4>M0<A0W@24AAd0Q48M003
4GAd01Md001dM0034GAd008A1G@34E9d0a4:M0<A3W@24@=d0Q4EM0044GAd4@Ad0a4JM000O7@24E9d
0a4;M08A3W@34@=d0Q4JM0034GAd00=d00<AM7@06G@007Ud0a5AM0<A37@24@id0Q44M08A77@24@Ad
0a4IM000MW@34E5d0a4=M08A3G@34@Ad0Q4PM0034GAd01ed001cM0@AD7@34@id0Q4=M08A1W@00a5d
M00PM0034GAd01ed001`M0<A0g@00a5dM01;M0<A3g@24@ed0Q46M08A8W@00a5d4@0NM000KG@34E1d
114@M08A37@34@Id0Q4WM0034GAd01]d001ZM0<AD7@34A9d0Q4<M08A1g@24BQd0a4LM000Ig@34E1d
0a4CM08A2g@34@Md0Q4/M0034GAd00Id0a42M08A3G@006Ad0a400g@AM01=M0<A57@24@]d0Q49M003
4GAd02ad0Q48M0044GAd4@9d00<AM7@02W@0065d0a5@M0<A5G@24@Yd0a49M08A<G@00a5dM003M0<A
0W@24@04M14A4@Yd001NM0<AD7@34AId0Q4:M08A2W@24C9d0Q47M08A00Ed4GAd4@02M0034GAd00Md
001KM0<AD7@34AMd0Q49M0<A2W@24C=d00@AM7@A1W@24@05M15dM1400W@00a5dM007M000>W@44@9d
0Q4GM08AD7@34AMd0a49M08A2g@24CMd0Q45M08A0W@0115dM142M0034GAd00Md000kM0054GAdM140
0W@00a5dM00AM0<A00=d4G@0C7@34AQd0Q49M0<A2g@24CQd00<AM1401W@24@9d1A4:M000?7@0115d
M142M0034GAd00id0a5?M0<A6G@24@Ud0Q4=M0034GAd03Ud0Q44M0044GAd4@Ed00<AM7@02G@003ad
00@AM7@A0W@00a5dM00;M0<ACg@34AYd0Q48M0<A3G@24Ced00<AM7@00g@24@Id0a49M000?G@00a5d
4@02M0034GAd00Md115?M0<A6g@24@Qd0Q4>M08A?W@00a5d4@0HM000>W@01Q5dM15d4@9d00<AM7@0
1G@34Dmd0a4LM08A1g@34@id0Q51M08A67@003]d0Q43M08A1G@34Dmd0a4MM08A1g@24@md0Q54M003
4GAd00Ed00<AM7@03W@004Ad0a5?M0<A7W@24@Id0a4@M0034GAd04=d0Q47M0034GAd00id0011M0<A
Cg@34Amd0Q46M08A4G@24DMd00<AM7@00W@54@md000nM0<ACg@34B1d0Q45M0<A4G@24DMd0a44M004
4GAd4A1d000kM0<A00=d4G@0C7@34B5d0Q45M08A4W@24D]d00<AM7@00g@00a5d4@0@M000>G@24@=d
00<AM7@0BG@34B9d0Q44M0<A4W@24Dad0Q46M08A47@003Id0a5>M0<A8g@24@Ad0Q4DM0034GAd04ad
0Q47M0034GAd00id000cM0<ACW@34BAd0Q43M0<A57@24E1d00<AM7@05W@0031d0a5>M0<A97@34@=d
0Q4EM08ADW@24@Md00DAM7@AM0034@Qd000]M0<A00=d4G@0Bg@34BEd0Q43M0<A5G@24EEd00<AM7@0
1G@00a5dM002M0044GAd4@Md000ZM0<ACW@34BId0Q43M08A5W@24EId0Q44M0DA1W@00a5dM005M000
9g@34Did0a4WM08A0g@24AId0Q5HM08A17@0115dM147M0034GAd00Ed000:M08A67@34Did0a4XM08A
0W@34AMd00<AM7@0Eg@00a5d4@05M0034G@A00Ad0a48M0002G@0115dM14DM0@ACG@34BUd0Q42M08A
67@24E]d0Q46M08A1G@00a5dM007M0002G@0115dM14AM0<ACW@34BYd0Q4017@A4A4HM08AGW@00a5d
M005M0034GAd00=d0a47M0002G@0115dM14>M0<ACW@34B]d0Q400g@A4@0IM08AGg@24AMd0009M004
4GAd4@]d0a5>M0<A;7@54AUd0Q5RM08A5W@000Ud00@AM7@A2G@24Did0a4]M0@A6g@00a5dM01RM08A
1G@34@id000:M08A1g@34@03M15d04Yd0a4^M0@A6g@24FId00<AM7@00g@0115dM14=M00047@34Ded
0a4_M0<A77@24FMd0Q48M0034GAd00]d000=M0<ACG@34C1d0a4LM08AJG@24@Qd00<AM7@02g@000Yd
0a5=M0<A<G@24Aed0Q5ZM0034G@A00Ed0a4>M0001g@44Dad0a4`M0@A7W@00a5dM01cM0034GAd00ed
0005M08A0g@00a5dM017M0<A;W@54@03M15d01ed0Q5fM0<A3G@0055d0a4/M0DA17@24Aed0Q68M000
CW@34BYd1A48M0034GAd01]d0Q6:M000Bg@34BQd1A4<M0034GAd01Yd0Q6<M000B7@34BId1A4?M08A
6g@24Hid0014M0@A97@54A=d00<AM7@06W@00a5dM02>M000@G@34B=d1A4GM0034GAd01Ud0Q6AM000
?W@34B5d1A4JM08A6W@24I=d000kM0<A7g@54Aid00<AM7@067@24IEd000hM0<A7G@54B9d00<AM7@0
5g@24IMd000eM0<A6g@54BEd0Q4IM0034GAd09Md000bM0<A6G@54BUd00<AM7@05g@24IYd000_M0<A
5W@64Bed00<AM7@05W@24Iad000/M0<A57@54C5d0Q4GM08AWW@002Ud0a4BM0DA=G@00a5dM00EM08A
X7@002Id0a4@M0DA>G@00a5dM00DM08AXW@002=d0a4>M0DA?7@24AId00<AM7@0XW@0021d0a4<M0DA
@7@00a5dM00DM08AYG@001ed0a4:M0DAA7@00a5dM00CM08AYg@001Yd0a48M0DAAg@24AAd0Q6YM000
5g@34@Id1A5;M0034GAd019d0Q6[M00057@34@Ad1A5?M0034GAd019d00<AM7@0Zg@0015d0a42M0DA
DW@24A=d0Q6^M0003W@84EId00<AM7@04G@24K1d000;M0HAFW@00a5dM00@M08A/W@000Ud0a5MM08A
4G@24KAd000:M0034GAd05]d00<AM7@047@00a5dM02dM0002g@00a5dM01IM0034GAd00md0Q6gM000
37@24EMd0Q4@M08A^G@000id00<AM7@0Dg@00a5dM00>M08A^g@000md00<AM7@0DG@00a5dM00=M08A
_G@0011d00<AM7@0CW@24@id0Q6oM0004G@00a5dM01<M0034GAd00ed00<AM7@0_g@0019d00<AM7@0
BW@00a5dM00<M08A`W@001=d00<AM7@0B7@00a5dM00;M08Aa7@001Ad0Q56M08A37@24LId000FM003
4GAd049d00<AM7@02W@24LQd000GM0034GAd041d00<AM7@02W@00a5dM038M00067@00a5dM00mM08A
2g@24L]d000IM0034GAd03]d00<AM7@02G@24Led000JM0034GAd03Ud00<AM7@027@24Lmd000KM08A
=g@24@Ud0Q7AM0007G@00a5dM00cM0034GAd00Qd00<AM7@0dG@001id00<AM7@0<G@00a5dM007M08A
e7@001md00<AM7@0;W@24@Qd0Q7FM00087@00a5dM00/M0034GAd00Id0Q7HM0008G@00a5dM00ZM003
4GAd00Ed0Q7JM0008W@00a5dM00WM08A1W@24Mad000SM08A9W@00a5dM005M0034GAd0=ad000UM003
4GAd029d00<AM7@017@24Mmd000VM0034GAd01md0Q45M08AhG@002Md00<AM7@07G@00a5dM003M08A
hg@002Qd00<AM7@06g@00a5dM002M08AiG@002Ud00<AM7@067@24@Ad00<AM7@0iG@002Yd0Q4GM003
4GAd009d0Q7XM000;7@00a5dM00CM0044GAdM08AjW@002ed00<AM7@047@24@9d0Q7/M000;W@00a5d
M00>M0034GAd008AkW@002md00<AM7@037@0115d4A7`M000<7@00a5dM009M08A00=d4G@0lG@0035d
00<AM7@01g@0115d4A7cM000<W@24@Id0a7eM000=7@0115dM7@34OMd000eM0044G@A4OUd000fM003
4GAd0?Ud003oM3=d003oM3=d003oM3=d0000\
\>"],
  ImageRangeCache->{{{0, 305.125}, {162, 0}} -> {0.0123785, 0.175413, 
  0.00348195, 0.00348195}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[bottomsurface[20., 10., 3., 7., 80, \
GraphicDesign->Wire], Axes -> True, BoxRatios -> {1, 1/3, 1/8}];\
\>", "Input",\

  CellLabel->"In[197]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53258 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0220751 1.02208 -0.223233 1.02208 [
[.02977 .27234 -4.0285 -10.9375 ]
[.02977 .27234 4.9715 0 ]
[.21565 .20857 -6.557 -10.9375 ]
[.21565 .20857 7.443 0 ]
[.41181 .14129 -6.87296 -10.9375 ]
[.41181 .14129 7.12704 0 ]
[.61912 .0702 -7.21795 -10.9375 ]
[.61912 .0702 6.78205 0 ]
[.83857 -0.00502 -7.59615 -10.9375 ]
[.83857 -0.00502 6.40385 0 ]
[.87755 .00066 0 -7.33422 ]
[.87755 .00066 20.9375 3.60328 ]
[.90929 .04766 0 -7.33533 ]
[.90929 .04766 15.9375 3.66467 ]
[.93993 .09303 0 -7.25481 ]
[.93993 .09303 9 3.68269 ]
[.96952 .13684 0 -7.25883 ]
[.96952 .13684 9 3.74117 ]
[.99811 .17917 0 -7.18188 ]
[.99811 .17917 14 3.75562 ]
[1.00118 .18559 0 -7.21778 ]
[1.00118 .18559 15.9375 3.78222 ]
[1.00472 .216 0 -7.19581 ]
[1.00472 .216 23.4375 3.80419 ]
[1.00832 .24684 0 -7.13279 ]
[1.00832 .24684 15.9375 3.80471 ]
[1.01196 .27812 0 -7.151 ]
[1.01196 .27812 23.4375 3.849 ]
[ 0 0 0 0 ]
[ 1 .53258 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21484 .22132 m
.21444 .2277 L
s
gsave
.21565 .20857 -67.557 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41157 .15406 m
.41146 .16045 L
s
gsave
.41181 .14129 -67.873 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61952 .08297 m
.61972 .08936 L
s
gsave
.61912 .0702 -68.218 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83966 .00771 m
.8402 .01408 L
s
gsave
.83857 -0.00502 -68.5961 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07412 .26943 m
.07375 .27325 L
s
.1204 .25361 m
.12008 .25743 L
s
.16731 .23757 m
.16702 .2414 L
s
.26302 .20485 m
.26282 .20868 L
s
.31186 .18815 m
.31171 .19198 L
s
.36138 .17123 m
.36126 .17506 L
s
.46247 .13666 m
.46245 .1405 L
s
.51409 .11902 m
.51411 .12285 L
s
.56643 .10112 m
.5665 .10496 L
s
.67337 .06456 m
.67354 .06839 L
s
.728 .04589 m
.72822 .04971 L
s
.78342 .02694 m
.78369 .03076 L
s
.25 Mabswid
.86222 0 m
.98872 .18714 L
s
.86545 .00479 m
.85941 .00685 L
s
gsave
.87755 .00066 -61 -11.3342 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.89717 .05171 m
.89111 .05373 L
s
gsave
.90929 .04766 -61 -11.3353 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.92778 .09699 m
.92171 .09898 L
s
gsave
.93993 .09303 -61 -11.2548 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.95735 .14073 m
.95126 .14267 L
s
gsave
.96952 .13684 -61 -11.2588 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98591 .18299 m
.97982 .1849 L
s
gsave
.99811 .17917 -61 -11.1819 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87189 .01431 m
.86826 .01554 L
s
.87828 .02376 m
.87465 .02498 L
s
.88462 .03314 m
.88099 .03436 L
s
.89092 .04246 m
.88729 .04367 L
s
.90338 .06089 m
.89974 .0621 L
s
.90955 .07001 m
.90591 .07122 L
s
.91567 .07907 m
.91203 .08027 L
s
.92175 .08806 m
.91811 .08926 L
s
.93378 .10586 m
.93013 .10705 L
s
.93973 .11467 m
.93609 .11585 L
s
.94565 .12341 m
.942 .12459 L
s
.95152 .1321 m
.94787 .13327 L
s
.96314 .14929 m
.95949 .15046 L
s
.96889 .1578 m
.96524 .15896 L
s
.9746 .16626 m
.97095 .16741 L
s
.98028 .17465 m
.97662 .1758 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99251 .21976 m
.98641 .22164 L
s
gsave
1.00472 .216 -61 -11.1958 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99609 .25056 m
.98998 .25242 L
s
gsave
1.00832 .24684 -61 -11.1328 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99973 .2818 m
.99361 .28363 L
s
gsave
1.01196 .27812 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.98968 .19543 m
.98602 .19657 L
s
.99039 .20149 m
.98673 .20263 L
s
.99109 .20756 m
.98743 .2087 L
s
.9918 .21365 m
.98814 .21478 L
s
.99323 .22588 m
.98956 .22701 L
s
.99394 .23203 m
.99028 .23315 L
s
.99466 .23819 m
.99099 .23931 L
s
.99537 .24436 m
.99171 .24548 L
s
.99682 .25677 m
.99315 .25788 L
s
.99754 .263 m
.99387 .26411 L
s
.99827 .26925 m
.9946 .27035 L
s
.999 .27551 m
.99533 .27662 L
s
0 0 m
1 0 L
1 .53258 L
0 .53258 L
closepath
clip
newpath
.5 Mabswid
.19129 .43402 m
.92442 .21321 L
s
.48896 .2878 m
.19129 .43402 L
s
.03244 .29108 m
.19129 .43402 L
s
.03244 .29108 m
.48896 .2878 L
s
.90588 .18709 m
.03244 .29108 L
s
.48896 .2878 m
.90588 .18709 L
s
.48896 .2878 m
.92442 .21321 L
s
.92442 .21321 m
.90588 .18709 L
s
.25 Mabswid
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21484 .22132 m
.21444 .2277 L
s
gsave
.21565 .20857 -67.557 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41157 .15406 m
.41146 .16045 L
s
gsave
.41181 .14129 -67.873 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61952 .08297 m
.61972 .08936 L
s
gsave
.61912 .0702 -68.218 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83966 .00771 m
.8402 .01408 L
s
gsave
.83857 -0.00502 -68.5961 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07412 .26943 m
.07375 .27325 L
s
.1204 .25361 m
.12008 .25743 L
s
.16731 .23757 m
.16702 .2414 L
s
.26302 .20485 m
.26282 .20868 L
s
.31186 .18815 m
.31171 .19198 L
s
.36138 .17123 m
.36126 .17506 L
s
.46247 .13666 m
.46245 .1405 L
s
.51409 .11902 m
.51411 .12285 L
s
.56643 .10112 m
.5665 .10496 L
s
.67337 .06456 m
.67354 .06839 L
s
.728 .04589 m
.72822 .04971 L
s
.78342 .02694 m
.78369 .03076 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99251 .21976 m
.98641 .22164 L
s
gsave
1.00472 .216 -61 -11.1958 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99609 .25056 m
.98998 .25242 L
s
gsave
1.00832 .24684 -61 -11.1328 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99973 .2818 m
.99361 .28363 L
s
gsave
1.01196 .27812 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.98968 .19543 m
.98602 .19657 L
s
.99039 .20149 m
.98673 .20263 L
s
.99109 .20756 m
.98743 .2087 L
s
.9918 .21365 m
.98814 .21478 L
s
.99323 .22588 m
.98956 .22701 L
s
.99394 .23203 m
.99028 .23315 L
s
.99466 .23819 m
.99099 .23931 L
s
.99537 .24436 m
.99171 .24548 L
s
.99682 .25677 m
.99315 .25788 L
s
.99754 .263 m
.99387 .26411 L
s
.99827 .26925 m
.9946 .27035 L
s
.999 .27551 m
.99533 .27662 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[197]:=",
  ImageSize->{258.375, 137.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000R@P10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_md0g@00?md0g@00?md0g@00?md0g@00?md
0g@00?md0g@00;ed0Q43M08A?W@00;ad00HAM7@AM142M0034GAd03]d002lM0064GAd4G@A0W@00a5d
M00kM000_G@24@9d00@AM7@A?G@00;ad00HAM7@AM142M0034GAd03]d002lM0064GAd4G@A0W@00a5d
M00=M0<A0W@24BMd002mM08A0g@24A5d00@AM7@A0W@00a5dM00TM000aW@24@Ed1144M0044GAd4@9d
00<AM7@097@00<9d1a4<M0044GAd4@9d00<AM7@097@00<1d0a45M0034GAd00Yd00@AM7@A0W@00a5d
M00TM000_G@34@9d00<AM7@00g@24@Yd0Q42M0044GAd4BId002jM0<A3G@00a5dM008M0044GAdM08A
9g@00;Md0a4@M08A=W@00;Ad0a4DM0034GAd03Ad002aM0<A00=d4G@05G@00a5dM00cM000[g@24AYd
0Q4eM000[7@34Aid00<AM7@02g@34BAd002:M08A0g@24AMd114QM08A37@0115dM14SM000RG@01Q5d
M15d4@9d00<AM7@04W@34BEd00<AM7@017@44@Ed00<AM7@08G@008Ud00HAM7@AM142M0034GAd00md
0a4XM08A3W@00a5dM00QM000RG@01Q5dM15d4@9d00<AM7@037@34Bed00<AM7@027@34BAd0029M0<A
0W@0115dM14;M0<A;g@24@]d00<AM7@08g@008Yd00DAM7Ad4@02M0034GAd00Id0a4dM0034GAd00Qd
0a4SM000Rg@24@9d0Q46M0<A00=d4G@0=7@24Bmd002DM0<A>g@00a5dM00]M000TG@34Cid0Q4^M000
SW@34D=d00<AM7@01G@24BAd002;M0<A00=d4G@0@g@24@Ed00@AM7@A8g@008Qd0a5:M0034GAd00=d
00@AM7@A8g@008Ed0a5>M0034GAd009d00@AM7@A8g@0089d0a5@M0034G@A00=d00@AM7@A8g@007md
115DM0054GAdM1400W@00a5dM00QM000OG@24EUd00@AM7Ad0Q4TM000NW@34E]d0Q4XM000GG@00a5d
M0024AAd115OM0034GAd02Id001MM0034G@A009d00<AM7@03g@34F=d00<AM7@09G@005Yd1Q42M003
4GAd00ad0a5UM0034G@A00Id0a4MM000FW@01Q5dM15d4@9d00<AM7@02G@34FYd00<AM7@017@0115d
M14LM000Fg@01A5d4G@A009d00<AM7@01G@44Fed0Q48M0034GAd01Yd001LM08A00Ed4GAd4@05M0<A
LG@24@Md00<AM7@06W@005ed00<AM7@00Q43M0<ALg@00a5d4@04M0<A7G@0069d0a5hM08A17@00a5d
M00LM000Gg@34Ged00@AM7Ad0a4LM000G7@44Gmd00<AM7@087@005Ud0a43M0034GAd07id00<AM7@0
7g@005Id0a67M08A87@005=d0a6;M0034GAd00Ed0a42M08A4W@0051d116=M08A1g@0115dM142M003
4GAd00md001=M0<ATg@00a5dM004M0044GAd4@9d0a4?M000;G@44@9d0Q4FM08AUG@24@Id00@AM7@A
0W@0115dM14>M000;W@01A5dM7@A009d00<AM7@047@34H9d1A4BM0034GAd00=d1142M0044GAd4@id
000_M0044GAd4@9d00<AM7@03G@44Gad2Q43M0034GAd00id0Q44M08A0W@0115dM142M0034GAd00ad
000_M0044GAd4@9d00<AM7@02W@34GMd2A42M0@A1g@00a5dM00>M08A1G@0115dM7@54@md000`M003
4G@A009d00<AM7@01g@34G9d2147M0@A37@00a5dM00>M0034GAd00Yd00<AM7@03W@002ed00HAM7@A
M142M0034GAd00Ad0a5]M0PA2g@44A5d00<AM7@03G@24@]d0a4>M000;W@24@=d0Q44M0@AIW@94@md
114EM0034GAd00ed0Q4>M0054GAd4G@00a46M000=W@34F9d214CM0DA67@34@id0Q4>M0034GAd009d
00@AM7@A1G@003=d0a5LM0TA5g@44AMd1a4AM0034GAd00=d1142M0DA1W@00a5dM003M000<7@34EMd
214LM0@A5G@:4A=d0Q4;M0044GAd4@Md00<AM7@00g@002ed0a400g@AM01?M0PA87@44A=d1Q43M0<A
5g@24@ad00<AM14017@34@Id000ZM0<AC7@94BAd114AM0HA1W@34A]d00<AM7@02g@24@Ed00<AM7@0
1G@002Md0a57M0PA:7@54@md1Q48M0@A7G@24@id00<AM7@00g@34@Ed000TM0<A@G@94Bad114>M0HA
2g@34B9d0Q4>M0034GAd00Yd000QM0<A0W@00a5dM00gM0PA<G@44@ad1Q4>M0<A9G@24@id00<AM7@0
2W@000Ed0Q4GM0<A=W@94CEd114:M0HA47@44BUd00<AM7@00g@44@9d1A4;M00017@0115dM14CM0<A
<G@84CYd1149M0DA4g@34B]d0a4;M0044GAd4@ad0004M0044GAd4A5d0a4[M0PA?W@44@Md1Q4EM0<A
;g@24@ad00<AM14037@000Ad00@AM7@A3W@34BEd2A51M0DA1G@64AMd114cM0034GAd00]d0Q4<M000
17@0115dM14;M0<A87@84DId1144M0HA6W@34CId0Q4>M0034GAd00Yd0004M0044GAd4@Qd0a4JM0TA
BW@44@9d1Q4MM0<A>G@34@Yd0a43M0034G@A008A1G@000Ed0Q46M0<A00=d4G@04W@84Dmd2Q4OM0@A
?G@24@ed00<AM7@00W@0115dM144M0002W@34A1d215CM0PA8W@34D5d0Q44M0@A1G@00a5dM005M003
4GAd009d0007M0<A2W@94EMd1Q4UM0<A@g@34@]d0Q48M0034GAd009d0004M0<A1G@84BQd>14XM0<A
EW@00a5dM002M0<A1G@0009d0Q42M3HA<W@24BQd115FM0044GAd4@Ed00<AM7@017@000Qd00<AM7@0
HG@24BMd0a5KM08A1W@34@Ad0009M0034GAd05id0Q4VM0<AKG@000Yd00<AM7@0Fg@24BAd115`M000
2g@24EUd0Q4SM0<AM7@000ed00<AM7@0E7@24B9d0a5gM0003W@00a5dM01AM08A87@44GYd000?M003
4GAd04id0Q4OM0<AOW@0011d00<AM7@0Bg@24Aid0a61M0004G@00a5dM018M08A77@44HAd000BM003
4GAd04Ed0Q4KM0<AR7@001=d00<AM7@0@W@24AYd0a6;M00057@24D1d0Q4HM0@ASW@001Id00<AM7@0
>g@24AMd0a6BM0005g@00a5dM00hM08A5W@34IEd000HM0034GAd03Ed0Q4DM0@AV7@001Ud00<AM7@0
<W@24A=d0a6LM0006W@00a5dM00_M08A4W@34Imd000KM0034GAd02ad0Q4AM0<AXW@001ad00<AM7@0
:G@24@md116UM0007G@00a5dM00VM08A3W@34JUd000NM08A97@24@ed0a6/M00087@00a5dM00OM08A
2g@44Jmd000QM0034GAd01ad0Q4:M0<A/g@0029d00<AM7@06G@24@Ud0a6fM0008g@00a5dM00FM08A
1g@44KUd000TM0034GAd01=d0Q46M0<A_G@002Ed00<AM7@047@24@Ed0a70M0009W@00a5dM00=M08A
0g@44L=d000WM08A2g@24@9d0a77M000:G@00a5dM006M08A00Ad4A4AbW@002Yd00<AM7@00g@54Led
000[M0034GAd00<AdG@002ad0Q7DM000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000
og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000
og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000og@3M000\
\>"],
  ImageRangeCache->{{{0, 257.375}, {136.562, 0}} -> {0.0215933, 0.164355, 
  0.00423236, 0.00423236}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[leftsurface[20., 10., 3., 7., 80, GraphicDesign->Wire], \
Axes -> True, BoxRatios -> {1, 1/3, 1/8}];\
\>", "Input",
  CellLabel->"In[233]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53258 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0220751 1.02208 -0.223233 1.02208 [
[.02977 .27234 -4.0285 -10.9375 ]
[.02977 .27234 4.9715 0 ]
[.21669 .20821 -6.55865 -10.9375 ]
[.21669 .20821 7.44135 0 ]
[.414 .14054 -6.87656 -10.9375 ]
[.414 .14054 7.12344 0 ]
[.62261 .06901 -7.22385 -10.9375 ]
[.62261 .06901 6.77615 0 ]
[.8435 -0.00671 -7.6048 -10.9375 ]
[.8435 -0.00671 6.3952 0 ]
[.87755 .00066 0 -7.33422 ]
[.87755 .00066 20.9375 3.60328 ]
[.90762 .04519 0 -7.29578 ]
[.90762 .04519 15.9375 3.64172 ]
[.9367 .08825 0 -7.25889 ]
[.9367 .08825 15.9375 3.67861 ]
[.96483 .1299 0 -7.22346 ]
[.96483 .1299 15.9375 3.71404 ]
[.99207 .17023 0 -7.18941 ]
[.99207 .17023 15.9375 3.74809 ]
[1.00118 .18559 0 -7.21778 ]
[1.00118 .18559 15.9375 3.78222 ]
[1.00383 .20835 0 -7.20133 ]
[1.00383 .20835 23.4375 3.79867 ]
[1.00651 .23135 0 -7.1439 ]
[1.00651 .23135 9 3.7936 ]
[1.00922 .25461 0 -7.16795 ]
[1.00922 .25461 16.5 3.83205 ]
[1.01196 .27811 0 -7.15101 ]
[1.01196 .27811 9 3.84899 ]
[ 0 0 0 0 ]
[ 1 .53258 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21589 .22096 m
.21548 .22734 L
s
gsave
.21669 .20821 -67.5587 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41378 .15331 m
.41367 .1597 L
s
gsave
.414 .14054 -67.8766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62302 .08178 m
.62322 .08816 L
s
gsave
.62261 .06901 -68.2238 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.8446 .00602 m
.84515 .01239 L
s
gsave
.8435 -0.00671 -68.6048 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07437 .26935 m
.074 .27316 L
s
.12091 .25343 m
.12059 .25725 L
s
.16808 .23731 m
.1678 .24113 L
s
.26435 .2044 m
.26415 .20822 L
s
.31347 .1876 m
.31332 .19143 L
s
.36328 .17057 m
.36317 .17441 L
s
.46499 .1358 m
.46497 .13964 L
s
.51692 .11805 m
.51695 .12188 L
s
.56959 .10004 m
.56966 .10387 L
s
.67721 .06325 m
.67739 .06708 L
s
.7322 .04445 m
.73242 .04828 L
s
.78799 .02538 m
.78826 .0292 L
s
.25 Mabswid
.86222 0 m
.98872 .18714 L
s
.86545 .00479 m
.85941 .00685 L
s
gsave
.87755 .00066 -61 -11.3342 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.8955 .04924 m
.88944 .05126 L
s
gsave
.90762 .04519 -61 -11.2958 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.92456 .09222 m
.91849 .09421 L
s
gsave
.9367 .08825 -61 -11.2589 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95267 .13381 m
.94659 .13576 L
s
gsave
.96483 .1299 -61 -11.2235 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.97988 .17406 m
.97379 .17598 L
s
gsave
.99207 .17023 -61 -11.1894 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.87306 .01604 m
.86943 .01727 L
s
.88061 .0272 m
.87697 .02843 L
s
.88809 .03827 m
.88445 .03949 L
s
.90286 .06012 m
.89922 .06133 L
s
.91015 .07091 m
.90651 .07211 L
s
.91739 .08161 m
.91374 .08281 L
s
.93167 .10275 m
.92803 .10393 L
s
.93873 .11318 m
.93508 .11437 L
s
.94573 .12354 m
.94208 .12471 L
s
.95955 .14399 m
.9559 .14516 L
s
.96638 .15409 m
.96273 .15526 L
s
.97316 .16412 m
.9695 .16527 L
s
.98655 .18392 m
.98289 .18507 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99162 .21212 m
.98552 .21401 L
s
gsave
1.00383 .20835 -61 -11.2013 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9943 .2351 m
.98819 .23697 L
s
gsave
1.00651 .23135 -61 -11.1439 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.997 .25831 m
.99088 .26017 L
s
gsave
1.00922 .25461 -61 -11.1679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98951 .19392 m
.98585 .19506 L
s
.99004 .19846 m
.98638 .1996 L
s
.99056 .203 m
.9869 .20414 L
s
.99109 .20756 m
.98743 .20869 L
s
.99216 .2167 m
.98849 .21783 L
s
.99269 .22128 m
.98903 .22241 L
s
.99322 .22588 m
.98956 .227 L
s
.99376 .23048 m
.9901 .23161 L
s
.99483 .23972 m
.99117 .24084 L
s
.99537 .24435 m
.99171 .24547 L
s
.99591 .249 m
.99225 .25011 L
s
.99645 .25365 m
.99279 .25476 L
s
.99754 .26299 m
.99387 .2641 L
s
.99808 .26767 m
.99442 .26878 L
s
.99863 .27236 m
.99496 .27347 L
s
.99918 .27707 m
.99551 .27817 L
s
0 0 m
1 0 L
1 .53258 L
0 .53258 L
closepath
clip
newpath
.5 Mabswid
.03244 .29108 m
.96618 .20558 L
s
.48896 .2878 m
.03244 .29108 L
s
.02304 .38166 m
.03244 .29108 L
s
.02304 .38166 m
.48896 .2878 L
s
.97332 .27022 m
.02304 .38166 L
s
.48896 .2878 m
.97332 .27022 L
s
.48896 .2878 m
.96618 .20558 L
s
.96618 .20558 m
.97332 .27022 L
s
.25 Mabswid
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21589 .22096 m
.21548 .22734 L
s
gsave
.21669 .20821 -67.5587 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41378 .15331 m
.41367 .1597 L
s
gsave
.414 .14054 -67.8766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62302 .08178 m
.62322 .08816 L
s
gsave
.62261 .06901 -68.2238 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.8446 .00602 m
.84515 .01239 L
s
gsave
.8435 -0.00671 -68.6048 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07437 .26935 m
.074 .27316 L
s
.12091 .25343 m
.12059 .25725 L
s
.16808 .23731 m
.1678 .24113 L
s
.26435 .2044 m
.26415 .20822 L
s
.31347 .1876 m
.31332 .19143 L
s
.36328 .17057 m
.36317 .17441 L
s
.46499 .1358 m
.46497 .13964 L
s
.51692 .11805 m
.51695 .12188 L
s
.56959 .10004 m
.56966 .10387 L
s
.67721 .06325 m
.67739 .06708 L
s
.7322 .04445 m
.73242 .04828 L
s
.78799 .02538 m
.78826 .0292 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99162 .21212 m
.98552 .21401 L
s
gsave
1.00383 .20835 -61 -11.2013 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9943 .2351 m
.98819 .23697 L
s
gsave
1.00651 .23135 -61 -11.1439 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.997 .25831 m
.99088 .26017 L
s
gsave
1.00922 .25461 -61 -11.1679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98951 .19392 m
.98585 .19506 L
s
.99004 .19846 m
.98638 .1996 L
s
.99056 .203 m
.9869 .20414 L
s
.99109 .20756 m
.98743 .20869 L
s
.99216 .2167 m
.98849 .21783 L
s
.99269 .22128 m
.98903 .22241 L
s
.99322 .22588 m
.98956 .227 L
s
.99376 .23048 m
.9901 .23161 L
s
.99483 .23972 m
.99117 .24084 L
s
.99537 .24435 m
.99171 .24547 L
s
.99591 .249 m
.99225 .25011 L
s
.99645 .25365 m
.99279 .25476 L
s
.99754 .26299 m
.99387 .2641 L
s
.99808 .26767 m
.99442 .26878 L
s
.99863 .27236 m
.99496 .27347 L
s
.99918 .27707 m
.99551 .27817 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[233]:=",
  ImageSize->{387.875, 206.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000630000cPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_mdQ7@00?mdQ7@00?mdQ7@00?mdQ7@00?md
Q7@00?md;G@24@=d0Q5@M000og@/M0064GAd4G@A0W@00a5dM01=M000og@/M0064GAd4G@A0W@00a5d
M01=M000og@]M08A0W@0115dM15?M000og@/M0064GAd4G@A0W@00a5dM01=M000og@/M0064GAd4G@A
0W@00a5dM01=M000og@]M08A0g@24AAd0a42M08A=G@00?mdBG@0115dM142M0034GAd039d003oM3Md
0Q48M0@A17@0115dM142M0034GAd039d003oM3Ad0a42M0034GAd00ed00@AM7@A0W@00a5dM00bM000
og@aM0<A17@24@md00@AM7@A0W@00a5dM00bM000og@^M0<A00=d4G@00g@0115dM14=M08A0W@0115d
M14dM000og@[M0<A17@00a5dM006M0034GAd00]d00@AM7Ad0Q4eM000og@XM0<A1g@00a5dM006M003
4GAd04Id003oM2Ed0a4DM0034GAd04Ed003oM2=d0Q4FM0034G@A04Id003oM21d0a4JM0034GAd04Ad
003oM1ed0a4NM0034GAd04=d003oM1Yd114QM0034GAd049d003oM1Md0a44M0034GAd01ed0Q54M000
og@DM0<A:G@00a5dM011M000og@AM0<A;G@00a5dM010M000og@>M0<A<7@24A1d0Q4_M000og@;M0<A
<W@00a5d4@0?M0044GAd4Bid003oM0Qd0a4hM0034GAd00Id1142M0044GAd4Bid003oM0Ed0a400g@A
M00hM0034GAd00ed0Q4_M000og@2M0<A17@00a5dM00gM08A3G@0115dM14^M000gG@24@=d0Q4JM0<A
@7@0115dM14<M0044GAd4Bid003LM0064GAd4G@A0W@00a5dM00EM08AAg@00a5dM00:M08A;g@00=ad
00HAM7@AM142M0034GAd019d0a59M0034GAd03]d003LM0064GAd4G@A0W@00a5dM00?M0<AC7@24Cad
003LM0<A0W@0115dM14>M0<ADG@00a5dM00iM000gG@01A5dM7@A009d00<AM7@02G@34@03M15d055d
00<AM7@0>G@00=id0Q42M08A2G@34@Ed00<AM7@0D7@00a5dM00hM000jW@34EYd0a4iM000ig@34Emd
00<AM7@0=g@00>Ad0a5SM0034GAd03Id003QM0<AIg@00a5dM00eM000gW@44FQd0Q4@M08A9G@00=]d
0a43M0034GAd06Qd00<AM7@037@0115dM14TM000f7@34@Id00<AM7@0JG@00a5dM005M0@A0W@0115d
M14TM000eW@24GEd00<AM7@02g@0115dM14TM000dg@34GId0a4<M0<A9G@00=1d0a5lM0034GAd00Yd
00<AM7@097@00<ed0a5oM0034GAd00]d0Q4TM000bW@34@03M15d081d00<AM7@0<7@00<Md0a44M003
4GAd07id00<AM140<G@00<Ad0a6:M0034GAd02md0031M0<ASW@00a5dM00^M000_W@34I9d00<AM7@0
;G@00;]d0a6DM08A;g@00;Qd116HM0034GAd02ad002eM0<A0g@00a5dM02GM0034GAd02]d002DM003
4GAd008A6G@34Imd0Q4BM0034GAd01Qd002DM0034G@A009d00<AM7@057@24JAd00<AM7@03g@00a5d
M00HM000TG@64@9d00<AM7@04G@34JMd00<AM7@01G@44@9d1A4IM000TG@01Q5dM15d4@9d00<AM7@0
3W@34JYd00<AM7@02g@0115dM14JM000TW@01A5d4G@A009d00<AM7@02g@34Jad0a4=M0034G@A01Yd
002CM08A00Ed4GAd4@0:M0<A00=d4G@0[g@00a5dM00;M08A6W@009Ad00<AM7@00Q48M0<A17@00a5d
M02^M0034GAd00ad00<AM7@067@009id0a6iM0034GAd02Id002KM0<A^g@00a5d4@0WM000V7@34L5d
00<AM7@097@009Ed0a74M0034GAd02Ad002BM0@AaW@24BEd002?M0<A0g@00a5dM036M0034GAd029d
002<M0<A1W@00a5dM036M0034GAd029d002:M08Adg@00a5dM00QM000Qg@34MAd0a4>M0@A47@008Ad
0a7IM0034GAd00ed00<AM7@047@0085d0a7MM0034GAd00Ed1144M0034GAd00md001nM0<A0W@00a5d
M03KM08A3W@00a5dM00?M000Ng@34N9d00<AM1403g@00a5dM00>M000N7@34NQd00<AM7@02G@00a5d
M0034@id001eM0<Ak7@00a5dM009M0<A0W@00a5dM00;M000LW@34Nid0Q47M0@A1G@00a5dM00;M000
Kg@34O=d00<AM7@03G@00a5dM00;M000K7@34@9d00<AM7@0kg@34@ad0a4>M000BW@44@9d0Q4GM0<A
nG@00a5dM00;M0034GAd00ed001;M0054GAdM1400W@00a5dM00AM0<Ang@24@ed0a4=M000C7@0115d
M142M0034GAd00md0Q7nM08A7G@004ad00@AM7@A0W@00a5dM00<M0<Aog@3M0034GAd00Yd1142M003
4G@A008A1G@004ed00<AM1400W@00a5dM009M0<Amg@64@Id0a4=M0034GAd00Ad00@AM7@A17@004Yd
00HAM7@AM142M0034GAd00Id0a400g@AM03/M0hA0W@00a5dM005M08A1W@44@Ad00<AM7@01W@00a5d
M002M000Bg@24@=d0Q46M0<Aig@;4@9d1Q48M0034GAd00Ad00<AM1403W@00a5dM006M0034GAd009d
001EM0<Agg@;4@Md1Q4>M0034GAd00Ed0Q4?M0034GAd009d0a45M000DW@34MQd2Q4=M0DA57@00a5d
M004M0034G@A00ad00@AM7@A1G@00a5dM004M000Cg@34M1d2a4AM0HA6G@00a5dM005M08A3G@24@Id
0a44M000C7@34LQd2a4FM0HA7g@00a5dM006M0034GAd01Yd0019M0<A0W@00a5dM02kM0/A6g@64BId
00<AM7@017@24Aad0016M0<A1G@00a5dM02`M0/A8G@54Bad00<AM7@017@34@Id0Q4CM000@g@34K1d
2a4VM0HA<G@00a5dM005M08A1G@0115dM14BM000@7@34JQd2a4[M0HA=g@00a5dM004M0034G@A00Ed
00@AM7@A4W@003id0Q6PM0/A<G@54Ced00<AM7@01G@24@Ed00@AM7@A4W@003]d0a6HM0XA=W@64D9d
00<AM7@017@00a5d4@05M0044GAd4A9d000hM0<A0W@00a5dM02;M0/A>W@64DQd00<AM7@01G@24@Ed
00@AM7@A4W@003Ed0a68M0/A?g@64Did00<AM7@01W@00a5dM004M08A4g@0039d0a60M0/AAG@54EAd
00<AM7@01G@24A]d000_M0<AN7@;4DYd1Q5IM0034GAd00Id0Q45M0@A0W@00a5d4@024@Yd000/M0<A
L7@;4Dmd1Q5OM0034GAd00Ed00<AM1401W@00a5dM004M0044GAd4@Ud000YM0@AIg@;4EAd1Q5UM003
4GAd00Ed0a47M0034GAd00Id00<AM7@01g@000Yd0Q4JM0<A0g@00a5dM01KM0XAFW@54Fad00<AM7@0
1W@00a5dM005M0034GAd00Id00<AM7@01g@000Ud00@AM7@A5W@34EUd2a5NM0HALG@00a5dM004M0<A
27@00a5dM002M0<A2W@000Ud00@AM7@A4g@34E5d2a5SM0HAMg@00a5dM006M0034GAd00=d00@AM7@A
1G@00a5dM009M0002G@0115dM14@M0<ABG@;4FQd1Q5mM0034GAd00Ed0Q46M08A1W@34@Ud0009M004
4GAd4@ed0a51M0/AKW@54H=d00<AM7@01G@24AYd0009M0044GAd4@]d0Q400g@AM00fM0/ALg@64GYd
3a48M0034GAd01Qd000:M08A2G@34@=d00<AM7@0:W@;4GQd1Q5SM1dA0W@84@ad0a45M0<A4G@0019d
0a4XM0/AOW@54Dad7A4FM0TA5G@24@Ed00@AM7@A47@000md0a4QM0XAPg@64CAd7A4ZM0TA7G@00a5d
4@08M0034GAd00id000<M0<A6G@;4HMd1Q4MM1dA?g@84BMd0Q48M0034GAd00id0009M0<A4G@;4Had
1Q46M1dADg@94Bid00<AM1401G@34A5d0006M0<A00=d4G@01W@;4D9dHA5XM0PA@7@00a5dM00@M000
17@24@Ad00<AM140DQ5;M0DAL7@94DQd0a4@M00037@00a5dM02FM0DAKG@84FAd000<M0034GAd095d
1A5YM0TAK7@000ad00<AM7@0S7@54FEd2A5eM00037@00a5dM027M0DAHW@84Gid000;M0034GAd08=d
1A5NM0TAQW@000]d00<AM7@0OW@54E]d216?M0002g@00a5dM01iM0DAEg@94IMd000;M0034GAd07Ad
1A5DM0PAX7@000]d00<AM7@0Kg@54E1d2A6XM0002g@00a5dM01ZM0DAC7@94K5d000;M0034GAd06Ed
1A59M0PA^W@000]d00<AM7@0H7@54DEd2A72M0002W@00a5dM01LM0DA@W@84L]d000:M0034GAd05Md
1A4nM0TAdg@000Yd00<AM7@0DW@54C]d217LM0002W@00a5dM01>M0@A=g@94NAd000:M0034GAd04Ud
1A4bM0TAkG@000Yd00<AM7@0A7@54Bmd217fM0002W@00a5dM00oM0DA:g@94Oid000:M0034GAd03Yd
1A4XM0PAog@8M0002G@00a5dM00fM0DA97@94Omd47@000Ud00<AM7@0<G@54B5d217oM1Ud0009M003
4GAd02ad1A4MM0TAog@QM0002G@00a5dM00WM0DA6G@94Omd:W@000Ud00<AM7@08W@54AId217oM3=d
0009M0034GAd01ed1A4BM0TAog@kM0002G@00a5dM00HM0DA3g@84OmdA7@000Ud00<AM7@04g@54@]d
2A7oM4ad0008M0034GAd00md1A48M0PAogAEM00027@00a5dM00:M0DA17@94OmdGG@000Qd00<AM7@0
1G@>4OmdIW@000Qd00<AM7@02Q7oM6md0008M0DAogAgM000ogB4M000ogB4M000ogB4M000ogB4M000
ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000
ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000
ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000
ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000
ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000ogB4M000
\
\>"],
  ImageRangeCache->{{{0, 386.875}, {205.562, 0}} -> {0.0200153, 0.18219, 
  0.00271109, 0.00271109}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[rightsurface[20., 10., 3., 7., 80, GraphicDesign->Wire], \
Axes -> True, BoxRatios -> {1, 1/3, 1/8}];\
\>", "Input",
  CellLabel->"In[234]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53258 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0220751 1.02208 -0.223233 1.02208 [
[.02977 .27234 -4.0285 -10.9375 ]
[.02977 .27234 4.9715 0 ]
[.21669 .20821 -6.55865 -10.9375 ]
[.21669 .20821 7.44135 0 ]
[.414 .14054 -6.87656 -10.9375 ]
[.414 .14054 7.12344 0 ]
[.62261 .06901 -7.22385 -10.9375 ]
[.62261 .06901 6.77615 0 ]
[.8435 -0.00671 -7.6048 -10.9375 ]
[.8435 -0.00671 6.3952 0 ]
[.88444 .01087 0 -7.32538 ]
[.88444 .01087 9 3.61212 ]
[.91428 .05506 0 -7.2873 ]
[.91428 .05506 9 3.6502 ]
[.94315 .09779 0 -7.25075 ]
[.94315 .09779 9 3.68675 ]
[.97107 .13914 0 -7.21564 ]
[.97107 .13914 9 3.72186 ]
[.99811 .17917 0 -7.18188 ]
[.99811 .17917 14 3.75562 ]
[1.00118 .18559 0 -7.21778 ]
[1.00118 .18559 15.9375 3.78222 ]
[1.00383 .20835 0 -7.20133 ]
[1.00383 .20835 23.4375 3.79867 ]
[1.00651 .23135 0 -7.1439 ]
[1.00651 .23135 9 3.7936 ]
[1.00922 .25461 0 -7.16795 ]
[1.00922 .25461 16.5 3.83205 ]
[1.01196 .27811 0 -7.15101 ]
[1.01196 .27811 9 3.84899 ]
[ 0 0 0 0 ]
[ 1 .53258 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21589 .22096 m
.21548 .22734 L
s
gsave
.21669 .20821 -67.5587 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41378 .15331 m
.41367 .1597 L
s
gsave
.414 .14054 -67.8766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62302 .08178 m
.62322 .08816 L
s
gsave
.62261 .06901 -68.2238 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.8446 .00602 m
.84515 .01239 L
s
gsave
.8435 -0.00671 -68.6048 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07437 .26935 m
.074 .27316 L
s
.12091 .25343 m
.12059 .25725 L
s
.16808 .23731 m
.1678 .24113 L
s
.26435 .2044 m
.26415 .20822 L
s
.31347 .1876 m
.31332 .19143 L
s
.36328 .17057 m
.36317 .17441 L
s
.46499 .1358 m
.46497 .13964 L
s
.51692 .11805 m
.51695 .12188 L
s
.56959 .10004 m
.56966 .10387 L
s
.67721 .06325 m
.67739 .06708 L
s
.7322 .04445 m
.73242 .04828 L
s
.78799 .02538 m
.78826 .0292 L
s
.25 Mabswid
.86222 0 m
.98872 .18714 L
s
.87234 .01497 m
.86629 .01703 L
s
gsave
.88444 .01087 -61 -11.3254 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90216 .05909 m
.8961 .0611 L
s
gsave
.91428 .05506 -61 -11.2873 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.931 .10175 m
.92493 .10373 L
s
gsave
.94315 .09779 -61 -11.2508 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9589 .14303 m
.95282 .14497 L
s
gsave
.97107 .13914 -61 -11.2156 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98591 .18299 m
.97982 .1849 L
s
gsave
.99811 .17917 -61 -11.1819 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87989 .02614 m
.87626 .02737 L
s
.88738 .03722 m
.88374 .03844 L
s
.8948 .0482 m
.89117 .04941 L
s
.90946 .06989 m
.90582 .07109 L
s
.9167 .08059 m
.91306 .08179 L
s
.92388 .09122 m
.92024 .09241 L
s
.93806 .11219 m
.93441 .11338 L
s
.94506 .12256 m
.94142 .12373 L
s
.95201 .13283 m
.94836 .134 L
s
.96574 .15314 m
.96208 .1543 L
s
.97252 .16317 m
.96886 .16432 L
s
.97924 .17312 m
.97559 .17427 L
s
.86473 .00371 m
.8611 .00495 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99162 .21212 m
.98552 .21401 L
s
gsave
1.00383 .20835 -61 -11.2013 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9943 .2351 m
.98819 .23697 L
s
gsave
1.00651 .23135 -61 -11.1439 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.997 .25831 m
.99088 .26017 L
s
gsave
1.00922 .25461 -61 -11.1679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98951 .19392 m
.98585 .19506 L
s
.99004 .19846 m
.98638 .1996 L
s
.99056 .203 m
.9869 .20414 L
s
.99109 .20756 m
.98743 .20869 L
s
.99216 .2167 m
.98849 .21783 L
s
.99269 .22128 m
.98903 .22241 L
s
.99322 .22588 m
.98956 .227 L
s
.99376 .23048 m
.9901 .23161 L
s
.99483 .23972 m
.99117 .24084 L
s
.99537 .24435 m
.99171 .24547 L
s
.99591 .249 m
.99225 .25011 L
s
.99645 .25365 m
.99279 .25476 L
s
.99754 .26299 m
.99387 .2641 L
s
.99808 .26767 m
.99442 .26878 L
s
.99863 .27236 m
.99496 .27347 L
s
.99918 .27707 m
.99551 .27817 L
s
0 0 m
1 0 L
1 .53258 L
0 .53258 L
closepath
clip
newpath
.5 Mabswid
.19129 .43402 m
.48896 .2878 L
s
.84416 .02883 m
.19129 .43402 L
s
.19129 .43402 m
.18554 .52176 L
s
.18554 .52176 m
.84987 .09538 L
s
.48896 .2878 m
.18554 .52176 L
s
.48896 .2878 m
.84416 .02883 L
s
.48896 .2878 m
.84987 .09538 L
s
.84987 .09538 m
.84416 .02883 L
s
.25 Mabswid
.01034 .29124 m
.86222 0 L
s
.02844 .28505 m
.02777 .2914 L
s
gsave
.02977 .27234 -65.0285 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21589 .22096 m
.21548 .22734 L
s
gsave
.21669 .20821 -67.5587 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.41378 .15331 m
.41367 .1597 L
s
gsave
.414 .14054 -67.8766 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62302 .08178 m
.62322 .08816 L
s
gsave
.62261 .06901 -68.2238 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.8446 .00602 m
.84515 .01239 L
s
gsave
.8435 -0.00671 -68.6048 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07437 .26935 m
.074 .27316 L
s
.12091 .25343 m
.12059 .25725 L
s
.16808 .23731 m
.1678 .24113 L
s
.26435 .2044 m
.26415 .20822 L
s
.31347 .1876 m
.31332 .19143 L
s
.36328 .17057 m
.36317 .17441 L
s
.46499 .1358 m
.46497 .13964 L
s
.51692 .11805 m
.51695 .12188 L
s
.56959 .10004 m
.56966 .10387 L
s
.67721 .06325 m
.67739 .06708 L
s
.7322 .04445 m
.73242 .04828 L
s
.78799 .02538 m
.78826 .0292 L
s
.25 Mabswid
.98872 .18714 m
1 .28414 L
s
.98898 .18939 m
.98288 .1913 L
s
gsave
1.00118 .18559 -61 -11.2178 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99162 .21212 m
.98552 .21401 L
s
gsave
1.00383 .20835 -61 -11.2013 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9943 .2351 m
.98819 .23697 L
s
gsave
1.00651 .23135 -61 -11.1439 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.997 .25831 m
.99088 .26017 L
s
gsave
1.00922 .25461 -61 -11.1679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99973 .28178 m
.99361 .28362 L
s
gsave
1.01196 .27811 -61 -11.151 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.98951 .19392 m
.98585 .19506 L
s
.99004 .19846 m
.98638 .1996 L
s
.99056 .203 m
.9869 .20414 L
s
.99109 .20756 m
.98743 .20869 L
s
.99216 .2167 m
.98849 .21783 L
s
.99269 .22128 m
.98903 .22241 L
s
.99322 .22588 m
.98956 .227 L
s
.99376 .23048 m
.9901 .23161 L
s
.99483 .23972 m
.99117 .24084 L
s
.99537 .24435 m
.99171 .24547 L
s
.99591 .249 m
.99225 .25011 L
s
.99645 .25365 m
.99279 .25476 L
s
.99754 .26299 m
.99387 .2641 L
s
.99808 .26767 m
.99442 .26878 L
s
.99863 .27236 m
.99496 .27347 L
s
.99918 .27707 m
.99551 .27817 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[234]:=",
  ImageSize->{387.938, 206.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000630000cPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_mdQ7@00?mdQ7@00?mdQ7@00?mdQ7@00?md
Q7@00?md;G@24@=d0Q5@M000og@/M0064GAd4G@A0W@00a5dM01=M000og@/M0064GAd4G@A0W@00a5d
M01=M000og@]M08A0W@0115dM15?M000og@/M0064GAd4G@A0W@00a5dM01=M000og@/M0064GAd4G@A
0W@00a5dM01=M000og@]M08A0g@24E1d003oM8Ad003oM3Md0Q5;M000og@dM0<A0W@00a5dM018M000
og@aM0<A17@24@Qd114nM000og@^M0<A00=d4G@01W@00a5dM006M0034GAd03id003oM2]d0a44M003
4GAd00Id00<AM7@01W@00a5dM00mM000og@XM0<A1g@00a5dM006M0034GAd00Id00<AM7@0?G@00?md
9G@34A9d0a48M0034GAd03ad003oM2=d0Q4HM0034GAd009d00@AM7@A?W@00?md87@34AYd00<AM7@0
0g@24Cmd003oM1ed0a4NM0034GAd04=d003oM1Yd114OM0<AA7@00?md5g@34@Ad00<AM7@04G@00a5d
M00:M0034GAd049d003oM1Ad0a4IM0<A3G@00a5dM011M000og@AM0<A6W@24@9d00<AM7@037@00a5d
M010M000og@>M0<A77@24@=d00<AM7@02g@24D9d003oM0]d0a4MM0<A17@00a5dM00=M0034GAd03md
003oM0Qd0a4OM08A1W@00a5dM00>M0034GAd03id003oM0Ed0a400g@AM00MM0<A1g@00a5dM00>M003
4GAd03id003oM09d0a44M0034GAd01Yd1149M0034GAd00ed0Q4;M0034GAd035d003MM08A0g@24AYd
0a4SM0034G@A00]d00<AM7@03g@00a5dM008M0034GAd035d003LM0064GAd4G@A0W@00a5dM00EM08A
97@44@ad00<AM7@047@00a5dM004M0DA<W@00=ad00HAM7@AM142M0034GAd019d0a4UM0034G@A00id
00<AM7@047@00a5dM004M0044GAd4C=d003LM0064GAd4G@A0W@00a5dM00?M0<A9W@24@03M15d00id
00<AM7@03g@34@Id00<AM140<g@00=ad0a42M0044GAd4@id0a4WM08A00=d4A4047@00a5dM00BM003
4GAd00Ad0Q4cM000gG@01A5dM7@A009d00<AM7@02G@34@9d00<AM7@097@0115dM14BM0034GAd019d
00<AM7@01G@00a5dM00aM000gW@24@9d0Q49M0<A1G@00a5dM00RM08A0W@00a5dM00AM0034GAd01=d
00<AM7@0>7@00>Yd0a4[M08A0W@24AAd00<AM7@04W@34CUd003WM0<A;G@01A5dM7@A01Id00<AM7@0
57@00a5dM00gM000i7@34Bid0Q42M08A5g@00a5dM00EM0034GAd03Id003QM0<A<7@01A5dM7@A01Ud
00<AM7@05W@00a5dM00eM000gW@44C1d0Q43M0034GAd01Ud00<AM7@057@24CMd003KM0<A0g@00a5d
M00/M08A0g@24Aad00<AM7@05W@00a5dM00dM000f7@34@Id00<AM7@0:g@00a5dM002M0034GAd01ad
00<AM7@05g@00a5dM00cM000eW@24CEd0Q44M0034GAd01ed00<AM7@05g@24CAd003CM0<A=W@00a5d
M002M08A87@00a5dM00FM0034G@A00Qd0Q4ZM000d7@34CMd0Q44M0034GAd021d00<AM7@06G@00a5d
M004M0044GAd4BUd003=M0<A>7@24@Ad0Q4QM08A77@00a5dM004M0044GAd4BUd003:M0<A00=d4G@0
=g@00a5dM003M0034GAd01md0Q4NM08A1G@0115dM14YM000ag@34@Ad00<AM7@0=7@24@Ed00<AM7@0
7W@34Aid00@AM7@A17@34BYd0034M0<A?7@24@Ed0Q4OM0<A8g@00a5dM003M0034GAd02Ud0031M0<A
?W@00a5dM004M0034GAd01ed0a4VM0034GAd00=d0Q4YM000_W@34Cmd0Q46M0034GAd01ad114VM0<A
;g@00;]d0a51M0034GAd00Ad0Q4MM08A00=d4G@0:G@00a5dM00]M000^7@44D5d0Q46M0034GAd01]d
0Q400g@A4@0/M0034GAd02ad002eM0<A0g@00a5dM00mM08A1W@24Aed00@AM7@A;g@00a5dM00[M000
U7@00a5dM0024AUd0a55M0034GAd00Ed00<AM7@06g@24@03M14A02md0Q4]M000U7@00a5d4@02M003
4GAd01Ad0Q56M08A1g@00a5dM00JM08A0W@00a5dM00aM0034GAd02Yd002AM0HA0W@00a5dM00AM0<A
AW@24@Md0Q4KM08A0W@24CEd00<AM7@0:G@0095d00HAM7@AM142M0034GAd00id0a58M0034GAd00Id
00<AM7@06G@24@9d0Q4gM08A2G@24Amd002BM0054G@AM1400W@00a5dM00;M0<ABG@24@Qd00<AM7@0
67@24@=d00<AM7@0=W@00a5d4@08M0044GAd4Aid002CM08A00Ed4GAd4@0:M0<A00=d4G@0B7@00a5d
M006M08A6G@24@=d0Q4lM0034GAd00Ed00@AM7@A7W@009Ad00<AM7@00Q48M0<A17@00a5dM015M08A
27@00a5dM00GM08A17@00a5dM00lM0034GAd00Id0Q4OM000WW@34Ded0Q48M08A6G@00a5dM002M08A
?g@24@Id00@AM7@A7W@009]d0a5?M0034GAd00Md00<AM7@05g@24@Ad00<AM7@0?W@0115dM145M004
4GAd4Aid002HM0<AD7@24@Ud00<AM7@05W@24@Ad0Q55M0034GAd00=d0Q4OM000UG@34E9d00<AM7@0
1g@24AMd0Q45M0034GAd04Ed00<AM7@097@0099d115BM08A2G@00a5dM00EM08A1G@24DMd0a4UM000
Sg@34@=d00<AM7@0CW@24@Ud0Q4FM08A1G@24Dad00<AM7@08W@008ad0a46M0034GAd04ed00<AM7@0
27@00a5dM00DM08A1W@00a5dM01<M0034GAd029d002:M08AEg@24@Yd00<AM7@04g@24@Id0Q5@M003
4GAd025d0027M0<AEg@24@Yd0Q4DM08A1g@00a5dM01?M0034G@A029d0024M0<AFG@00a5dM009M003
4GAd01=d00<AM7@01G@24EAd00<AM7@087@0085d0a5JM08A2g@00a5dM00BM08A1g@00a5dM01EM003
4GAd01md001nM0<A0W@00a5dM01GM0034GAd00Ud0Q4CM08A1g@24EMd0a48M0<A0W@24A5d001kM0<A
GG@24@]d00<AM7@04G@24@Qd00<AM7@0FG@00a5dM007M0044GAd4@9d00<AM7@03W@007Qd0a5NM08A
2g@24A9d0Q48M08AGG@00a5dM006M0044GAd4@9d0a4>M000MG@34F1d00<AM7@02W@00a5dM00@M08A
27@24Emd0Q47M0044GAd4@9d00@AM7@A3G@0079d0a5QM08A37@00a5dM00?M08A2G@00a5dM01NM003
4G@A00Md1142M0044GAd4@ed001_M0<AHg@00a5dM00:M08A47@24@Ud0Q5TM0034GAd00=d0Q42M004
4GAd4@9d00<AM7@02g@006ad0a42M0034GAd05md0Q4<M0034GAd00id0Q4:M0034GAd069d0a46M004
4GAdM0DA3W@004Yd1142M08A5g@34FEd0Q4=M0034GAd00id00<AM7@027@24FMd00<AM7@02g@00a5d
M00=M000Bg@01A5dM7@A009d00<AM7@04G@34FMd00<AM7@02g@24@md0Q4:M0034GAd06Id0Q4=M0<A
3G@004ad00@AM7@A0W@00a5dM00?M08AJ7@24@ed00<AM7@03G@24@Yd0Q5YM08A7G@004ad00@AM7@A
0W@00a5dM00<M0<AJ7@24@ed0Q4>M08A2W@24Fed00<AM7@02W@44@9d00<AM1400Q45M000CG@00a5d
4@02M0034GAd00Ud0a5ZM0034GAd00ad00<AM7@037@24@]d00<AM7@0Jg@34@ed00<AM7@017@0115d
M144M000BW@01Q5dM15d4@9d00<AM7@01W@34@03M15d06Qd0Q4>M0034GAd00]d0Q4;M08AKg@24@Id
1144M0034GAd00Id00<AM7@00W@004]d0Q43M08A1W@34Fed00<AM7@037@24@ad0Q4<M0034GAd06id
00<AM1403W@00a5dM006M0034GAd009d001EM0<AKW@24@id00<AM7@02W@24@ad0Q5bM08A3g@00a5d
M002M0<A1G@0059d0a5_M08A3g@00a5dM00:M0034GAd00]d00<AM7@0LG@00a5d4@0<M0044GAd4@Ed
00<AM7@017@004md0a5aM0034GAd00ed0Q4;M08A37@24GEd0Q4=M08A1W@34@Ad001<M0<ALW@24@md
00<AM7@02G@24@ed00<AM7@0MW@00a5dM00JM000BG@34@9d00<AM7@0Kg@00a5dM00=M08A2W@24@ed
0Q5hM08A77@004Id0a45M0034GAd06ed0Q4?M0034GAd00Qd0Q4=M08ANW@34@Id0Q4CM000@g@34GId
0Q4@M0034GAd00Md0Q4>M0034GAd07]d0Q45M0044GAd4A9d0010M0<AN7@00a5dM00>M08A27@24@id
0Q5mM0034G@A00Ed00@AM7@A4W@003id0Q5iM08A47@00a5dM006M08A3g@00a5dM01nM08A1G@0115d
M14BM000>g@34GUd0Q4AM0034GAd00Ed0Q4?M08AP7@00a5d4@05M0044GAd4A9d000hM0<A0W@00a5d
M01fM0034GAd00md0Q47M0034GAd00id00<AM7@0PG@24@Ed00@AM7@A4W@003Ed0a5lM08A4G@00a5d
M005M08A3g@24HEd00<AM7@017@24A=d000bM0<AOW@00a5dM00?M08A1W@24A1d00<AM7@0Q7@24A]d
000_M0<AOg@24A5d00<AM7@017@24A1d0Q68M08A1G@44@9d00<AM1400Q4:M000;7@34H1d0Q4BM003
4GAd00=d0Q4@M08ARG@00a5d4@06M0034GAd00Ad00@AM7@A2G@002Ud1161M0034GAd011d0Q44M08A
4G@00a5dM029M0<A1g@00a5dM006M0034GAd00Md000:M08A6W@34@=d00<AM7@0OG@24A9d00<AM7@0
0W@24A5d0Q6>M0034GAd00Ed00<AM7@01W@00a5dM007M0002G@0115dM14FM0<AQG@00a5dM00AM004
4GAdM08A4W@00a5dM02<M0<A27@00a5dM002M0<A2W@000Ud00@AM7@A4g@34HId0Q4BM08A0g@00a5d
M00@M08ATG@00a5dM003M0044GAd4@Ed00<AM7@02G@000Ud00@AM7@A47@34HMd0Q4CM0044GAdM08A
4W@00a5dM02@M08A1W@24@Id0a49M0002G@0115dM14=M0<ARG@00a5dM00AM08A0W@24A9d0Q6CM08A
6W@000Ud00@AM7@A2g@24@03M15d08Md0Q4CM0034GAd008A4g@00a5dM02DM0034GAd01Qd000:M08A
2G@34@=d00<AM7@0Q7@24AAd00@AM14A4g@24IId0a45M0<A4G@0019d0a6<M0034GAd019d114CM08A
VG@24@Ed00@AM7@A47@000md0a6=M08A57@34AAd00<AM7@0V7@00a5d4@08M0034GAd00id000<M0<A
Sg@00a5dM00CM08A57@24Iad0Q48M0034GAd00id0009M0<AT7@24AAd0Q4EM0034GAd09]d00<AM140
1G@34A5d0006M0<A00=d4G@0SW@24AAd0Q4EM08AYg@00a5dM00@M00017@24@Ad00<AM7@0S7@00a5d
M00BM0<A5G@00a5dM02WM0<A47@009Md0Q4CM0@A57@24Ked002FM0034GAd015d0Q400g@AM00DM003
4GAd0;ed002DM08A4W@24@9d00<AM7@04W@24L1d002BM08A4W@24@9d0Q4CM08A`W@0095d00<AM7@0
47@24@=d00<AM7@04W@00a5dM032M000Sg@24A5d0Q44M0034GAd015d0Q75M000SG@24A5d0Q44M08A
4g@00a5dM035M000S7@00a5dM00?M08A1G@00a5dM00AM08Ab7@008Yd0Q4@M08A1W@00a5dM00AM003
4GAd0<Qd0029M0034GAd00id0Q47M0034GAd011d0Q7;M000Qg@24@md0Q47M08A4G@24Led0025M08A
3g@24@Qd00<AM7@047@00a5dM03=M000Q7@00a5dM00=M08A2G@00a5dM00?M08Ad7@0089d0Q4>M08A
2G@24A5d00<AM7@0d7@0081d0Q4>M08A2W@00a5dM00?M08Adg@007md00<AM7@037@24@]d00<AM7@0
3g@00a5dM03CM000OG@24@ed0Q4<M0034GAd00id0Q7FM000O7@00a5dM00;M08A37@24A1d00<AM7@0
eW@007Yd0Q4<M08A3G@00a5dM00>M08AfG@007Qd0Q4<M08A3W@00a5dM00=M08Afg@007Md00<AM7@0
2W@24@id0Q4?M0034GAd0=]d001eM08A2g@24@md00<AM7@03G@24Mid001dM0034GAd00Ud0Q4@M003
4GAd00ed00<AM7@0gW@0079d0Q4:M08A47@24@id0Q7QM000L7@24@Ud0a4AM0034GAd00ed00<AM7@0
hG@006md00<AM7@01g@24A=d00<AM7@037@24NAd001]M08A27@24AAd00<AM7@037@00a5dM03TM000
Jg@24@Qd0Q4DM08A3G@24NMd001ZM0034GAd00Id0Q4EM0034GAd00]d0Q7YM000J7@24@Md0Q4FM003
4GAd00]d00<AM7@0jG@006Md00<AM7@01G@24AId0Q4<M08Ak7@006Ed0Q46M08A5g@00a5dM00;M003
4GAd0>ad001SM08A1W@24AQd00<AM7@02W@24Nmd001RM0034GAd00Ad0Q4IM0034GAd00Yd00<AM7@0
kg@0061d0Q45M08A6G@24@]d0Q7bM000Gg@00a5dM003M08A6W@00a5dM00:M0034GAd0?9d001MM08A
17@24A]d00<AM7@02G@24OEd001KM08A17@24A]d0Q4:M08Amg@005Yd00<AM7@00W@24Aad00<AM7@0
2G@00a5dM03gM000F7@24@=d0Q4MM0034GAd00Qd0Q7jM000EW@24@=d0Q4MM08A2W@00a5dM03jM000
EG@0115dM7@24Aid00<AM7@027@24Oed001CM08A0W@24Amd00<AM7@027@00a5dM03mM000DW@00a5d
M0024B1d00<AM7@01g@24Omd0G@0051d0Q400g@A4@0PM08A27@24Omd0g@004id0Q400g@A4@0QM003
4GAd00Md00<AM7@0og@3M000CG@0115d4A4RM0034GAd00Id0Q7oM0Id001;M0@A8W@24@Qd00<AM7@0
og@6M000BW@34B=d00<AM7@01W@24Omd2G@004Qd0a4TM0034GAd00Id00<AM7@0og@9M000AW@34BEd
00<AM7@01G@24Omd37@004Ed0Q4UM08A1g@00a5dM03oM0ad0015M0034GAd02=d00<AM7@01G@24Omd
3g@004Ed00<AM7@08W@00a5dM004M08Aog@AM000AG@00a5dM00PM08A1W@00a5dM03oM15d0015M003
4GAd01md00<AM7@017@24Omd57@004Ed00<AM7@07W@00a5dM004M0034GAd0?md57@004Ed00<AM7@0
77@24@Ed0Q7oM1Md0015M0034GAd01]d00<AM7@017@00a5dM03oM1Md0015M0034GAd01Yd00<AM7@0
0g@24Omd6W@004Ad00<AM7@06W@00a5dM003M0034GAd0?md6W@004Ad00<AM7@067@24@Ad0Q7oM1ed
0014M0034GAd01Md00<AM7@00W@24Omd7g@004Ad00<AM7@05W@00a5dM002M0034GAd0?md7g@004Ad
00<AM7@057@24@=d0Q7oM29d0014M0034GAd01=d00<AM7@00W@00a5dM03oM29d0014M0034GAd019d
00@AM7Ad0Q7oM2Ed0014M0034GAd015d00DAM7Ad4@3oM2Md0014M0034GAd00md0Q42M08Aog@XM000
A7@00a5dM00>M0054GAdM140og@ZM000A7@00a5dM00=M0034GAd008Aog@[M000A7@00a5dM00;M08A
00=d4A40og@]M000A7@00a5dM00:M0044GAd4Omd;g@004Ad00<AM7@02G@0115d4A7oM31d0014M003
4GAd00Md0Q400g@AM03oM35d0014M0034GAd00Id00@AM14Aog@cM000@g@00a5dM006M0034G@A0?md
=G@004=d00<AM7@01G@34Omd=W@004=d00<AM7@00g@34Omd>7@004=d00<AM7@00W@34Omd>G@004=d
00@AM7Ad0Q7oM3]d0013M0044G@A4Omd?G@004=d0a7oM3id0013M0034GAd0?md?W@00?mdQ7@00?md
Q7@00?mdQ7@00001\
\>"],
  ImageRangeCache->{{{0, 386.938}, {205.562, 0}} -> {0.0199306, 0.18219, 
  0.00271109, 0.00271109}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[entrancesurface[20., 10., 100., GraphicDesign->Wire], \
Axes -> True,  BoxRatios -> {1/6, 1, 1}];\
\>", "Input",
  CellLabel->"In[347]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.99178 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.470477 2.04542 -2.14672e-17 2.04542 [
[.08585 .06629 -8.21838 -10.9375 ]
[.08585 .06629 .78162 0 ]
[.1489 .03969 -14.9138 -10.9375 ]
[.1489 .03969 1.58625 0 ]
[.2127 .01278 -14.7605 -10.9375 ]
[.2127 .01278 1.73954 0 ]
[.27725 -0.01445 -14.6072 -10.9375 ]
[.27725 -0.01445 1.89283 0 ]
[-0.00111 1.34621 -20.9375 -3.79291 ]
[-0.00111 1.34621 0 7.14459 ]
[.21744 1.53322 -15.9375 -3.94286 ]
[.21744 1.53322 0 7.05714 ]
[.41234 1.7 -9 -4.02996 ]
[.41234 1.7 0 6.90754 ]
[.58723 1.84966 -9 -4.14857 ]
[.58723 1.84966 0 6.85143 ]
[.74506 1.98471 -14 -4.20826 ]
[.74506 1.98471 0 6.72924 ]
[.07174 .12217 -15.9375 -3.19941 ]
[.07174 .12217 0 7.80059 ]
[.05146 .37586 -23.4375 -3.32517 ]
[.05146 .37586 0 7.67483 ]
[.02934 .65286 -9 -3.44336 ]
[.02934 .65286 0 7.49414 ]
[.00509 .95654 -16.5 -3.61483 ]
[.00509 .95654 0 7.38517 ]
[-0.02161 1.29095 -9 -3.7828 ]
[-0.02161 1.29095 0 7.2172 ]
[ 0 0 0 0 ]
[ 1 1.99178 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09724 .08806 m
.30667 0 L
s
.10213 .086 m
.11028 .09586 L
s
gsave
.08585 .06629 -69.2184 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.16497 .05958 m
.173 .06953 L
s
gsave
.1489 .03969 -75.9137 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.22854 .03285 m
.23646 .04289 L
s
gsave
.2127 .01278 -75.7605 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.29286 .00581 m
.30066 .01593 L
s
gsave
.27725 -0.01445 -75.6072 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11777 .07942 m
.12264 .08535 L
s
.13346 .07283 m
.13831 .07877 L
s
.14919 .06622 m
.15403 .07217 L
s
.18079 .05293 m
.18559 .05891 L
s
.19666 .04626 m
.20144 .05225 L
s
.21257 .03956 m
.21734 .04557 L
s
.24455 .02612 m
.24928 .03216 L
s
.2606 .01937 m
.26532 .02542 L
s
.27671 .0126 m
.28141 .01866 L
s
.25 Mabswid
0 1.31871 m
.78492 1.99178 L
s
.02334 1.33872 m
.03556 1.33498 L
s
gsave
-0.00111 1.34621 -81.9375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.24204 1.52626 m
.25434 1.52278 L
s
gsave
.21744 1.53322 -76.9375 -7.94286 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.43706 1.6935 m
.44943 1.69024 L
s
gsave
.41234 1.7 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61206 1.84356 m
.62448 1.84051 L
s
gsave
.58723 1.84966 -70 -8.14857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76997 1.97897 m
.78243 1.97609 L
s
gsave
.74506 1.98471 -75 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06918 1.37803 m
.07652 1.37581 L
s
.11393 1.4164 m
.12128 1.41422 L
s
.15763 1.45388 m
.16499 1.45173 L
s
.20032 1.49049 m
.20769 1.48837 L
s
.28281 1.56122 m
.2902 1.55916 L
s
.32267 1.5954 m
.33006 1.59337 L
s
.36164 1.62882 m
.36905 1.62682 L
s
.39977 1.66151 m
.40718 1.65953 L
s
.47356 1.72479 m
.48099 1.72287 L
s
.50929 1.75543 m
.51672 1.75353 L
s
.54427 1.78542 m
.5517 1.78354 L
s
.57852 1.81479 m
.58596 1.81294 L
s
.64493 1.87174 m
.65238 1.86993 L
s
.67713 1.89936 m
.68459 1.89757 L
s
.7087 1.92642 m
.71616 1.92466 L
s
.73964 1.95295 m
.74711 1.95121 L
s
.25 Mabswid
.09724 .08806 m
0 1.31871 L
s
.09532 .1123 m
.10712 .10737 L
s
gsave
.07174 .12217 -76.9375 -7.19941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.07524 .36646 m
.08713 .36176 L
s
gsave
.05146 .37586 -84.4375 -7.32517 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05331 .64398 m
.0653 .63954 L
s
gsave
.02934 .65286 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02927 .94825 m
.04136 .9441 L
s
gsave
.00509 .95654 -77.5 -7.61483 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.0028 1.28333 m
.015 1.27952 L
s
gsave
-0.02161 1.29095 -70 -7.7828 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.09144 .16141 m
.09853 .15847 L
s
.0875 .21135 m
.09459 .20845 L
s
.08348 .26216 m
.09059 .25928 L
s
.0794 .31385 m
.08652 .311 L
s
.07101 .41999 m
.07816 .4172 L
s
.06671 .47449 m
.07386 .47173 L
s
.06232 .52996 m
.06949 .52724 L
s
.05786 .58645 m
.06504 .58376 L
s
.04868 .70257 m
.05589 .69994 L
s
.04397 .76227 m
.05118 .75967 L
s
.03916 .82309 m
.04639 .82053 L
s
.03426 .88507 m
.04151 .88255 L
s
.02418 1.01266 m
.03145 1.01021 L
s
.01899 1.07833 m
.02628 1.07592 L
s
.0137 1.1453 m
.021 1.14294 L
s
.0083 1.21362 m
.01561 1.2113 L
s
0 0 m
1 0 L
1 1.99178 L
0 1.99178 L
closepath
clip
newpath
.5 Mabswid
.91839 .82645 m
.90696 .98995 L
s
.75265 .74315 m
.91839 .82645 L
s
.73723 .9084 m
.75265 .74315 L
s
.6118 .64473 m
.75265 .74315 L
s
.90696 .98995 m
.9033 1.15846 L
s
.73723 .9084 m
.90696 .98995 L
s
.72941 1.07881 m
.73723 .9084 L
s
.5927 .81195 m
.73723 .9084 L
s
.9033 1.15846 m
.90795 1.33273 L
s
.72941 1.07881 m
.9033 1.15846 L
s
.5927 .81195 m
.6118 .64473 L
s
.49639 .52918 m
.6118 .64473 L
s
.72974 1.25516 m
.72941 1.07881 L
s
.58111 .98451 m
.72941 1.07881 L
s
.58111 .98451 m
.5927 .81195 L
s
.47394 .69859 m
.5927 .81195 L
s
.90795 1.33273 m
.92155 1.51359 L
s
.72974 1.25516 m
.90795 1.33273 L
s
.90795 1.33273 m
.90795 1.33273 L
s
.47394 .69859 m
.49639 .52918 L
s
.4076 .39393 m
.49639 .52918 L
s
.49639 .52918 m
.49639 .52918 L
s
.73885 1.43832 m
.72974 1.25516 L
s
.57756 1.1632 m
.72974 1.25516 L
s
.57756 1.1632 m
.58111 .98451 L
s
.45896 .87351 m
.58111 .98451 L
s
.92155 1.51359 m
.94488 1.702 L
s
.73885 1.43832 m
.92155 1.51359 L
s
.47394 .69859 m
.45896 .87351 L
s
.38215 .5657 m
.47394 .69859 L
s
.38215 .5657 m
.4076 .39393 L
s
.34738 .23564 m
.4076 .39393 L
s
.7575 1.62928 m
.73885 1.43832 L
s
.58269 1.34895 m
.73885 1.43832 L
s
.58269 1.34895 m
.57756 1.1632 L
s
.45199 1.0548 m
.57756 1.1632 L
s
.94488 1.702 m
.97884 1.89905 L
s
.7575 1.62928 m
.94488 1.702 L
s
.45896 .87351 m
.45199 1.0548 L
s
.36421 .74319 m
.45896 .87351 L
s
.36421 .74319 m
.38215 .5657 L
s
.31935 .40992 m
.38215 .5657 L
s
.31935 .40992 m
.34738 .23564 L
s
.31867 .04998 m
.34738 .23564 L
s
.59727 1.54282 m
.58269 1.34895 L
s
.45369 1.24345 m
.58269 1.34895 L
s
.78659 1.82921 m
.7575 1.62928 L
s
.59727 1.54282 m
.7575 1.62928 L
s
.45369 1.24345 m
.45199 1.0548 L
s
.35433 .92732 m
.45199 1.0548 L
s
.97884 1.89905 m
.78659 1.82921 L
s
.36421 .74319 m
.35433 .92732 L
s
.29895 .59015 m
.36421 .74319 L
s
.29895 .59015 m
.31935 .40992 L
s
.28858 .22684 m
.31935 .40992 L
s
.62219 1.74604 m
.59727 1.54282 L
s
.46482 1.44057 m
.59727 1.54282 L
s
.78659 1.82921 m
.62219 1.74604 L
s
.45369 1.24345 m
.46482 1.44057 L
s
.35319 1.11913 m
.45369 1.24345 L
s
.28858 .22684 m
.31867 .04998 L
s
.35433 .92732 m
.35319 1.11913 L
s
.28675 .7773 m
.35433 .92732 L
s
.28675 .7773 m
.29895 .59015 L
s
.26634 .40988 m
.29895 .59015 L
s
.62219 1.74604 m
.48632 1.64747 L
s
.46482 1.44057 m
.48632 1.64747 L
s
.36158 1.31982 m
.46482 1.44057 L
s
.26634 .40988 m
.28858 .22684 L
s
.36158 1.31982 m
.35319 1.11913 L
s
.28348 .9725 m
.35319 1.11913 L
s
.28348 .9725 m
.28675 .7773 L
s
.25257 .60017 m
.28675 .7773 L
s
.48632 1.64747 m
.38048 1.5308 L
s
.48632 1.64747 m
.48632 1.64747 L
s
.25257 .60017 m
.26634 .40988 L
s
.38048 1.5308 m
.36158 1.31982 L
s
.28997 1.17705 m
.36158 1.31982 L
s
.28997 1.17705 m
.28348 .9725 L
s
.24805 .79891 m
.28348 .9725 L
s
.24805 .79891 m
.25257 .60017 L
s
.25257 .60017 m
.25257 .60017 L
s
.38048 1.5308 m
.30725 1.39248 L
s
.30725 1.39248 m
.28997 1.17705 L
s
.25368 1.00754 m
.28997 1.17705 L
s
.25368 1.00754 m
.24805 .79891 L
s
.30725 1.39248 m
.27058 1.22771 L
s
.27058 1.22771 m
.25368 1.00754 L
s
.25 Mabswid
.09724 .08806 m
.30667 0 L
s
.10213 .086 m
.11028 .09586 L
s
gsave
.08585 .06629 -69.2184 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.16497 .05958 m
.173 .06953 L
s
gsave
.1489 .03969 -75.9137 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.22854 .03285 m
.23646 .04289 L
s
gsave
.2127 .01278 -75.7605 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.29286 .00581 m
.30066 .01593 L
s
gsave
.27725 -0.01445 -75.6072 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11777 .07942 m
.12264 .08535 L
s
.13346 .07283 m
.13831 .07877 L
s
.14919 .06622 m
.15403 .07217 L
s
.18079 .05293 m
.18559 .05891 L
s
.19666 .04626 m
.20144 .05225 L
s
.21257 .03956 m
.21734 .04557 L
s
.24455 .02612 m
.24928 .03216 L
s
.2606 .01937 m
.26532 .02542 L
s
.27671 .0126 m
.28141 .01866 L
s
.25 Mabswid
0 1.31871 m
.78492 1.99178 L
s
.02334 1.33872 m
.03556 1.33498 L
s
gsave
-0.00111 1.34621 -81.9375 -7.79291 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.24204 1.52626 m
.25434 1.52278 L
s
gsave
.21744 1.53322 -76.9375 -7.94286 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.43706 1.6935 m
.44943 1.69024 L
s
gsave
.41234 1.7 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61206 1.84356 m
.62448 1.84051 L
s
gsave
.58723 1.84966 -70 -8.14857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76997 1.97897 m
.78243 1.97609 L
s
gsave
.74506 1.98471 -75 -8.20826 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06918 1.37803 m
.07652 1.37581 L
s
.11393 1.4164 m
.12128 1.41422 L
s
.15763 1.45388 m
.16499 1.45173 L
s
.20032 1.49049 m
.20769 1.48837 L
s
.28281 1.56122 m
.2902 1.55916 L
s
.32267 1.5954 m
.33006 1.59337 L
s
.36164 1.62882 m
.36905 1.62682 L
s
.39977 1.66151 m
.40718 1.65953 L
s
.47356 1.72479 m
.48099 1.72287 L
s
.50929 1.75543 m
.51672 1.75353 L
s
.54427 1.78542 m
.5517 1.78354 L
s
.57852 1.81479 m
.58596 1.81294 L
s
.64493 1.87174 m
.65238 1.86993 L
s
.67713 1.89936 m
.68459 1.89757 L
s
.7087 1.92642 m
.71616 1.92466 L
s
.73964 1.95295 m
.74711 1.95121 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[347]:=",
  ImageSize->{153.875, 306.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002I0001<PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>cYUd002IM000VG@009Ud002IM000VG@009Ud
002IM000VG@009Ud002IM000VG@009Ud002IM000VG@009Ud002IM000;W@24@=d00<AM7@00Q5QM000
;G@0115dM144M0044GAd4F1d000]M0044GAd4@Ad00@AM7@AH7@002ed00@AM7@A17@0115dM15PM000
9G@24@=d00DAM7@AM0024@Ad0a5QM00097@0115dM145M0044G@A4@Ed00<AM7@0H7@002Ad00@AM7@A
17@54@Id0Q5PM00097@0115dM144M0044GAd4FUd000LM08A0g@00a5d4@044@Ed00<AM14037@24E]d
000KM0044GAd4@Ed00@AM7@A1W@24@Yd0Q5MM0006g@0115dM146M08A27@00a5dM006M08A0W@00a5d
M01JM0006g@24@03M15d00Ed00<AM7@03G@44@03M15d05ed000JM08A00=d4A401g@00a5dM00:M0<A
Hg@001Yd0Q400g@A4@04M0044GAd4@Yd0a5UM0006W@0115d4A46M08A27@44@9d00<AM7@0HW@001Yd
00@AM7@A3W@24@03M15d00id00<AM7@0Eg@001Yd00@AM7@A37@24@03M15d011d00<AM7@0Eg@001]d
0Q4:M0<A00=d4G@04W@00a5dM01GM0009G@34@03M15d01=d0Q5IM0008W@44AQd0Q5IM0008G@24A]d
00<AM140F7@0025d00<AM1406W@00a5d4@1HM0008G@34AYd00<AM140F7@0025d00<AM7@06W@00a5d
4@1HM0008G@00a5dM00IM0044GAd4EQd000QM0034GAd01Ud00@AM7@AF7@001Md0a47M0034GAd01Ud
00@AM7@AF7@001Md00@AM7@A1G@00a5dM00JM0044GAd4EQd000AM0@A1G@00a5dM003M0034GAd01Yd
00DAM7Ad4@1GM0006W@00a5dM003M0<A6W@01A5dM7@A05Md000GM0<A1W@00a5dM00IM0034GAd009d
00<AM7@0EG@001Qd00<AM7@01G@00a5dM00IM0034GAd009d00<AM7@0EG@001Qd0a45M0034GAd01Ud
00<AM7@00W@00a5dM01EM00087@00a5dM00IM0034GAd009d00<AM7@0EG@0021d00<AM7@06G@00a5d
M002M0034GAd05Ed000PM0034GAd01Ud00<AM7@00W@00a5dM01EM00087@24AUd00<AM7@017@00a5d
M01DM00087@00a5dM00HM0034GAd00Ad00<AM7@0E7@0021d00<AM7@067@00a5dM004M0034GAd05Ad
000PM0034GAd01Qd00<AM7@017@00a5dM01DM00087@00a5dM00HM0034GAd00Ad00<AM7@0E7@001md
00<AM7@06G@00a5dM004M08AEG@001md00<AM1406G@24@Ed0Q5EM0007g@24AUd00<AM14017@0115d
M15DM0007g@00a5dM00HM0034G@A00Ad00@AM7@AE7@001md00<AM7@067@00a5d4@04M0044GAd4EAd
000OM0034GAd01Qd00<AM14017@01A5dM7@A05=d000OM0034GAd01Qd00<AM14017@01A5dM7@A05=d
000OM0034GAd01Qd00@AM7@A0g@01A5dM7@A05=d000OM08A6G@0115dM143M0034GAd009d00<AM7@0
D7@001md00<AM7@067@0115dM143M0034GAd009d00<AM7@0D7@001md00<AM7@05g@01A5dM7@A009d
00<AM7@017@00a5dM01?M0007g@00a5dM00GM0054GAdM1400W@00a5dM004M0034GAd04md000OM003
4GAd01Md00DAM7Ad4@02M0034GAd00Ad00<AM7@0Cg@001id00<AM7@067@00a5dM002M0034G@A00Md
00<AM7@0CW@001id00<AM7@067@00a5dM002M0034G@A00Md00<AM7@0CW@001id0a4HM0034GAd009d
00<AM1401g@00a5dM01>M0007W@00a5dM00HM0034GAd009d00<AM14027@00a5dM01=M0007W@00a5d
M00HM0034GAd009d00<AM14027@00a5dM01=M0003G@44@9d00<AM1400Q46M0034GAd01Md00<AM7@0
0g@24@Yd00<AM7@0C7@000id00<AM7@017@0115dM145M0034GAd01Md00<AM7@017@00a5dM008M003
4GAd04ad0007M0@A17@00a5dM006M0034GAd00=d00<AM7@05g@00a5dM004M0034GAd00Qd0Q5=M000
3g@00a5dM006M0034GAd00=d00<AM7@05g@00a5dM004M0034GAd00Qd0Q5=M00047@00a5dM002M0<A
1W@24AQd00<AM7@017@00a5dM008M0034G@A04ad000=M0044GAd4@Ed00<AM7@01G@00a5dM00GM003
4GAd00Ad0Q48M0054GAdM140Bg@000id0Q46M0<A1G@00a5dM00GM0034GAd00Ad0Q48M0054GAdM140
Bg@001id00<AM7@05g@24@Ed00<AM1401g@00a5dM002M0034GAd04Qd000NM0034GAd01Md0Q44M004
4GAd4@Md00<AM7@00g@00a5dM017M0007G@00a5dM00HM08A17@0115dM147M0034GAd00=d00<AM7@0
Ag@001ed00<AM7@05g@00a5d4@04M0054GAdM1401W@00a5dM004M0034GAd04Id000MM08A67@00a5d
4@04M0054GAdM1401W@00a5dM005M0034GAd04Ed000MM0034GAd01Md00<AM14017@01A5dM7@A00Id
00<AM7@01G@00a5dM015M0007G@00a5dM00GM0044GAd4@=d00<AM7@00W@00a5dM002M0034GAd00Md
00<AM7@0A7@001ed00<AM7@05g@0115dM143M0034GAd009d00<AM7@00W@00a5dM008M0034GAd04=d
000MM0034GAd01Md00@AM7@A0g@00a5dM003M0054GAdM1402W@00a5dM013M0007G@00a5dM00GM004
4GAd4@9d00<AM7@017@01A5dM7@A00]d00<AM7@0@W@001ed00<AM7@05g@0115dM142M0034GAd00Ad
00DAM7Ad4@0<M0034GAd045d000MM0034GAd01Md00@AM7@A0W@00a5dM005M0044GAd4@ad00<AM7@0
@G@001ed0Q4HM0074GAdM15d4@07M0044GAd4@ed00<AM7@0@7@001ed00<AM7@05g@01a5dM7@AM140
1g@0115dM14=M08A@G@001ed00<AM7@05g@01a5dM7@AM14027@24@id00<AM140@7@001ad00<AM7@0
5g@00a5dM002M0034G@A00Qd0Q4>M0044GAd4Cmd000LM0034GAd01Md00<AM7@00W@00a5d4@09M003
4GAd00]d00<AM7@00W@00a5dM00lM00077@00a5dM00GM0034GAd009d0Q4:M0034GAd00]d00<AM7@0
0g@00a5dM00kM00077@00a5dM00GM0034GAd00=d00<AM7@027@24@ad00<AM7@017@00a5dM00jM000
77@24AQd00<AM7@00g@00a5dM008M08A37@00a5dM005M0034GAd03Ud000LM0034GAd01Md00<AM7@0
0g@00a5dM008M0034G@A00]d00<AM7@01W@00a5dM00hM00077@00a5dM00GM0034GAd00=d00<AM7@0
27@0115dM14:M0034GAd00Md00<AM7@0=g@001ad00<AM7@05g@00a5dM003M08A2G@01A5dM7@A00Ud
00<AM7@027@00a5dM00fM00077@00a5dM00GM0034GAd00=d0Q48M0034GAd009d00<AM7@01g@00a5d
M009M0034GAd03Ed000LM0034GAd01Md0Q44M0034G@A00Md00<AM7@00g@00a5dM005M0034GAd00]d
00<AM7@0=7@001ad00<AM7@05g@24@Ad00<AM1401g@00a5dM004M0034GAd00Ad00<AM7@037@00a5d
M00cM00077@24AQd0Q44M0044GAd4@Id00<AM7@017@00a5dM004M0034GAd00ed00<AM7@0<W@001ad
00<AM7@05g@24@=d00DAM7Ad4@06M0034GAd00Ed00<AM7@00g@00a5dM00>M0034GAd035d000LM003
4GAd01Md0Q43M0034GAd009d00<AM7@00g@00a5dM006M0034GAd009d00<AM7@03W@34C5d000KM003
4GAd01Qd0Q43M0034GAd009d00<AM7@00g@00a5dM006M0034GAd009d00<AM7@03W@0115dM14`M000
4g@24@Id00<AM7@067@00a5d4@02M0034GAd009d00<AM7@00g@00a5dM007M0054GAdM14047@0115d
M7@24Bid000BM0044GAd4@Ed00<AM7@067@00a5d4@02M0034GAd00=d00<AM7@00W@00a5dM008M003
4G@A015d00<AM7@00g@00a5dM00[M0004W@0115dM145M0034GAd01Qd00<AM1400W@00a5dM003M003
4GAd009d00<AM7@02G@24A5d00<AM7@017@24B]d000BM0044GAd4@Ed00<AM7@067@00a5d4@02M003
4GAd00Ad00DAM7Ad4@0;M08A47@00a5dM007M0034GAd02Qd000BM0044GAd4@Ed0Q4IM0034G@A009d
00<AM7@017@01A5dM7@A00ad00<AM7@03W@00a5dM008M0034GAd02Md000BM0044GAd4@Ed00<AM7@0
5g@0115dM142M0034GAd00Ed00<AM1403G@24@md00<AM7@02G@24BMd000CM08A1W@00a5dM00GM007
4GAdM15d4@07M0034G@A00ed00<AM1403W@00a5dM00;M0034GAd02Ad000KM0034GAd01Md00LAM7Ad
4G@A00Qd0Q4=M0044GAd4@ed00<AM7@037@24BAd000KM0034GAd01Md00LAM7Ad4G@A00Qd0Q4=M005
4GAdM14037@00a5dM00>M0034GAd025d000KM0034GAd01Md00@AM7Ad0Q4:M0034GAd00]d00<AM7@0
0W@00a5dM009M0034GAd00md0Q4QM0006g@00a5dM00GM0044GAdM08A2W@00a5dM00:M0034GAd00Ad
00<AM7@027@00a5dM00AM0034GAd01id000KM0034GAd01Md00@AM7Ad0Q4:M08A2g@00a5dM005M003
4GAd00Md00<AM7@04G@34Aid000JM08A6G@00a5dM002M0034GAd00Qd0Q4;M0034GAd00Id0Q47M003
4GAd015d00<AM7@00Q4LM0006W@00a5dM00HM0034GAd009d00<AM7@027@00a5d4@0:M0034GAd00Qd
00<AM7@017@00a5dM00AM0034GAd009d0Q4JM0006W@00a5dM00HM0034GAd009d00<AM7@027@0115d
M149M0034GAd00Ud00<AM7@00W@00a5dM00BM0034GAd00Ad0Q4HM0006W@00a5dM00HM0034GAd009d
00<AM7@027@01A5dM7@A00Qd00<AM7@02W@01A5dM7@A01Ad00<AM7@01W@24AId000JM0034GAd01Qd
00<AM7@00W@24@Ud00DAM7Ad4@08M0034GAd00]d00@AM7@A4g@00a5dM009M08A57@001Yd00<AM7@0
67@00a5dM002M08A27@00a5dM003M0034GAd00Ed00<AM7@037@00a5d4@0CM0034GAd00]d0Q4BM000
6W@00a5dM00HM0034GAd009d00<AM1401g@00a5dM004M0034GAd00Ad00<AM7@03G@24A=d00<AM7@0
3G@24A1d000JM0034GAd01Qd00<AM7@00W@00a5d4@07M0034GAd00Ad00<AM7@017@00a5dM00>M003
4GAd015d00<AM7@03g@24@id000JM08A6G@24@=d00@AM7@A1W@00a5dM005M0034GAd00=d00<AM7@0
3W@34A5d00<AM7@04G@24@ad000JM0034GAd01Qd0Q43M0044GAd4@Id00<AM7@01W@00a5dM002M003
4GAd00id00@AM7@A47@00a5dM00CM08A2W@001Yd00<AM7@067@24@=d00DAM7Ad4@05M0034GAd00Id
00DAM7Ad4@0AM0044GAdM08A3W@00a5dM00DM0034GAd00Qd000JM0034GAd01Qd0Q43M0054GAdM140
1G@00a5dM007M0044GAd4A5d00<AM7@00g@00a5dM00;M0034GAd01Ad00<AM7@027@001Yd00<AM7@0
67@00a5d4@02M0054GAdM1401G@00a5dM008M0034G@A015d00<AM7@017@24@]d00<AM7@057@00a5d
M008M0006W@00a5dM00HM0034G@A009d00<AM7@00W@00a5dM002M0034GAd00Ud0Q4@M0034GAd00Md
00<AM7@027@00a5dM00DM0034GAd00Qd000IM0034GAd01Ud00<AM1400W@00a5dM002M0034GAd009d
00<AM7@02G@24A1d00<AM7@027@00a5dM007M0034GAd01Ad00<AM7@027@001Ud00<AM7@06G@00a5d
4@02M0034GAd00=d00DAM7Ad4@0<M0034GAd00id00<AM7@02G@24@Id00<AM7@057@00a5dM009M000
6G@24AYd00<AM1400W@00a5dM003M0054GAdM14037@24@md00<AM7@02g@00a5dM003M0034GAd01Ad
00<AM7@02G@001Ud00<AM7@06G@01Q5dM15d4@Id00<AM1403G@00a5d4@0>M0034GAd00ad0Q43M003
4GAd01Ad00<AM7@02G@001Ud00<AM7@06G@01Q5dM15d4@Id00<AM1403G@0115dM14=M0034GAd00id
00@AM7@A5W@00a5dM009M0006G@00a5dM00IM0064GAd4G@A1g@24@ed00DAM7Ad4@0<M0034GAd00md
0a4FM0034GAd00Ud000IM0034GAd01Yd00DAM15d4@07M08A3G@00a5dM002M0034GAd00Ud00<AM7@0
4G@00a5dM00DM0034GAd00Ud000IM0034GAd01Yd00DAM15d4@08M0034GAd00]d00<AM7@00g@00a5d
M008M0034GAd015d0a4DM0034GAd00Ud000IM0034GAd01Yd00<AM7@00Q48M0034GAd00]d00<AM7@0
17@00a5dM007M0034GAd015d00<AM7@00Q4BM0034GAd00Ud000IM0034GAd01Yd00<AM7@00Q48M08A
37@00a5dM005M08A1g@00a5dM00AM0034GAd009d0Q4@M0034GAd00Ud000IM08A6g@00a5dM0024@Qd
00<AM1402g@00a5dM007M0034GAd00Ad00<AM7@04G@00a5dM004M08A3W@00a5dM009M00067@24Aad
00<AM7@00Q48M0034G@A00]d00<AM7@027@00a5dM002M0034GAd019d00<AM7@01W@24@ad00<AM7@0
2G@001Ud00<AM7@06W@01A5dM7@A00Qd00@AM7@A2W@00a5dM009M0054GAdM14057@00a5dM008M08A
2G@00a5dM00:M00067@00a5dM00KM0054GAdM14027@01A5dM7@A00Ud00<AM7@02W@0115dM14DM003
4GAd00Yd0Q47M0034GAd00Yd0007M0@A0W@00a5d4@024@Id00<AM7@06g@01A5dM7@A00Qd00<AM7@0
0W@00a5dM005M0034GAd00ad00<AM14057@00a5dM00<M08A1G@00a5dM00:M00027@00a5dM004M004
4GAd4@Ed00<AM7@06g@01A5dM7@A00Qd00<AM7@00W@00a5dM005M0034GAd00ed0Q4DM0034GAd00id
0Q43M0034GAd00Yd0009M0034GAd00Id00<AM7@00g@00a5dM00KM0044GAdM08A1g@00a5dM003M003
4GAd00Ad00<AM7@03W@00a5dM00BM0034GAd011d0Q400g@AM00;M0002G@00a5dM006M0034GAd00=d
00<AM7@06g@0115dM7@24@Md00<AM7@017@00a5dM003M0034GAd00id0a4BM0034GAd019d0Q4<M000
2W@00a5dM002M0<A1W@00a5dM00KM0074GAdM15d4@06M0034GAd00Ed00<AM7@00W@00a5dM00>M003
4GAd008A3g@00a5dM00DM0034GAd00Yd0007M0044GAd4@Ed00<AM7@01G@24Aad00LAM7Ad4G@A00Id
00<AM7@01G@00a5dM002M0034GAd00id00<AM7@00W@00a5dM00<M0034GAd01Ad00<AM7@02W@000Qd
0Q46M0<A1G@00a5dM00KM0054GAdM1400W@00a5dM003M0034GAd00Id00DAM7Ad4@0@M0034GAd00=d
0Q4<M0034GAd01Ad00<AM7@02W@001Qd00<AM7@06g@01A5dM7@A009d00<AM7@00g@00a5dM007M004
4GAd4A1d00<AM7@01G@24@Yd00<AM7@057@00a5dM00:M00067@00a5dM00KM08A0W@01A5dM7@A00Ad
00<AM7@027@00a5d4@0@M0034GAd00Md00<AM7@01g@00a5dM00DM0034GAd00Yd000HM0034GAd01]d
0Q42M0054GAdM14017@00a5dM008M0034G@A011d00<AM7@027@24@Md00<AM7@057@00a5dM00:M000
67@00a5dM00KM08A0W@01A5dM7@A00Ad00<AM7@02G@24A1d00<AM7@02W@24@Ed00<AM7@057@00a5d
M00:M00067@00a5dM00KM08A0W@00a5dM002M0054GAdM14037@00a5dM00>M0034GAd00ad00<AM7@0
0W@00a5dM00DM0034GAd00Yd000HM0034GAd01]d00DAM15d4@04M0054GAdM14037@24@md00<AM7@0
3G@24@9d00<AM7@057@00a5dM00:M0005g@00a5dM00MM08A00=d4G@017@0115dM14<M0044G@A4@ed
00<AM7@03g@34AId00<AM7@02W@001Md0Q4NM08A0W@00a5dM002M0044GAd4@ad00DAM7Ad4@0<M003
4GAd015d0Q4EM0034GAd00Yd000GM0034GAd01ed0Q42M0034GAd00=d00<AM14037@00a5dM002M003
4GAd00Ud00<AM7@04G@0115d4A4CM0034GAd00Yd000GM0034GAd01ed0Q42M0034GAd00=d00<AM140
37@00a5dM003M0034GAd00Qd00<AM7@04G@0115dM7@24A5d00<AM7@02W@001Md00<AM7@07G@01A5d
4G@A00Id0Q4<M0034GAd00Ad00<AM7@01g@00a5dM00AM0034GAd00=d0Q4?M0034GAd00Yd000GM003
4GAd01ed00DAM15d4@06M08A37@00a5dM005M08A1g@00a5dM00AM0034GAd00Ed0Q4=M0034GAd00Yd
000GM0034GAd01ed00DAM15d4@07M0034GAd00Yd00<AM7@01g@00a5dM004M0034GAd015d00<AM7@0
1g@24@]d00<AM7@02W@001Md00<AM7@07G@01A5d4G@A00Md00<AM7@02W@00a5dM008M0034GAd00=d
00<AM7@04G@00a5dM009M08A2G@00a5dM00:M0005g@00a5dM00MM0034GAd008A1g@24@]d00<AM7@0
2G@00a5dM002M0034GAd015d00<AM7@02g@24@Md00<AM7@02W@001Md00<AM7@07G@00a5dM0024@Md
00<AM1402W@00a5dM00:M0054GAdM1404g@00a5dM00=M08A1G@00a5dM00:M0005W@24Amd00<AM7@0
0Q47M0034G@A00Yd00<AM7@02g@24@03M15d019d00<AM7@03g@24@=d00<AM7@02W@001Md00<AM7@0
7G@00a5dM0024@Md00@AM7@A2G@00a5dM00=M08A4g@00a5dM00AM08A00=d4G@02g@001Md00<AM7@0
7G@01A5dM7@A00Md00DAM7Ad4@08M0034GAd00id00<AM7@04G@00a5dM00CM08A37@001Id00<AM7@0
7W@01A5dM7@A00Md00<AM7@00W@00a5dM005M0034GAd00id0a4AM0034GAd01Ad00<AM7@02W@001Id
00<AM7@07g@0115dM147M0034GAd00=d00<AM7@017@00a5dM00>M0034GAd008A3g@00a5dM00DM003
4GAd00Yd000FM0034GAd01md00@AM7@A1g@00a5dM003M0034GAd00Ad00<AM7@03W@00a5dM002M003
4GAd00ad00<AM7@057@00a5dM00:M0005W@00a5dM00OM0034GAd008A1W@00a5dM004M0034GAd00=d
00<AM7@03W@00a5dM003M08A37@00a5dM00DM0034GAd00Yd000FM0034GAd01md00<AM7@00Q46M003
4GAd00Ed00<AM7@00W@00a5dM00>M0034GAd00Ed0Q4:M0034GAd01Ad00<AM7@02W@001Id00<AM7@0
7g@01Q5dM15d4@Ed00<AM7@01W@01A5dM7@A011d00<AM7@01g@00a5dM007M0034GAd01Ad00<AM7@0
2W@001Id0Q4PM0064GAd4G@A1G@00a5dM007M0044GAd4A1d00<AM7@027@24@Md00<AM7@057@00a5d
M00:M0005W@00a5dM00OM0044GAd4@9d00<AM7@00W@00a5dM008M0034G@A011d00<AM7@02W@24@Ed
00<AM7@057@00a5dM00:M0005W@00a5dM00OM0044GAd4@9d00<AM7@00g@00a5dM007M0034G@A011d
00<AM7@037@00a5dM002M0034GAd01Ad00<AM7@02W@001Id00<AM7@07g@01A5dM7@A009d00<AM7@0
0W@00a5dM008M08A47@00a5dM00=M08A0W@00a5dM00DM0034GAd00Yd000FM0034GAd01md00DAM7Ad
4@02M0034GAd009d00<AM7@02G@00a5dM00>M0034GAd00md0a4FM0034GAd00Yd000FM0034GAd021d
00@AM7@A0g@01A5dM7@A00]d0Q4?M0034GAd015d0Q4EM0034GAd00Yd000FM0034GAd021d00@AM7@A
0g@01A5dM7@A00]d00@AM14A3G@00a5dM00AM0044G@A4A=d00<AM7@02W@001Id00<AM7@087@0115d
M144M0044GAd4@]d00DAM7Ad4@0<M0034GAd015d00@AM7Ad0Q4AM0034GAd00Yd000EM0034GAd025d
00@AM7@A17@0115dM14;M0034GAd009d00<AM7@02G@00a5dM00AM0034GAd00=d0Q4?M0034GAd00Yd
000EM0<A8W@00a5d4@05M0034G@A00]d00<AM7@00g@00a5dM008M0034GAd015d00<AM7@01G@24@ed
00<AM7@02W@001Ed00<AM7@08W@00a5d4@05M0034G@A00]d00<AM7@017@00a5dM007M0034GAd015d
00<AM7@01g@24@]d00<AM7@02W@001Ed00<AM7@08W@00a5d4@06M08A37@00a5dM004M08A1g@00a5d
M00AM0034GAd00Ud0Q49M0034GAd00Yd000;M0<A1g@00a5dM00RM0034G@A00Id0Q4<M0034GAd00Id
00<AM7@017@00a5dM00AM0034GAd00]d0Q47M0034GAd00Yd000;M0044GAd4@Id00<AM7@08W@00a5d
4@07M0034GAd00Yd00<AM7@01g@00a5dM003M0034GAd015d00<AM7@03G@24@Ed00<AM7@02W@000id
00<AM7@017@00a5dM00SM08A1g@00a5dM00:M0034GAd00Qd00<AM7@00W@00a5dM00AM0034GAd00md
0Q43M0034GAd00Yd000>M0034GAd00Ed00<AM7@08W@24@Md0Q4;M0034GAd00Ud00DAM7Ad4@0CM003
4GAd015d0Q400g@AM00;M0002g@34@Ud0a4QM08A1g@00a5d4@0:M0034GAd00Yd0Q400g@AM00BM003
4GAd01=d0Q4<M00037@00a5dM009M08A8G@00a5d4@06M0044GAd4@Ud00<AM7@037@24A=d00<AM7@0
57@00a5dM00:M00037@34@]d00<AM7@07g@24@Id00@AM7@A2G@00a5dM00=M0034GAd019d00<AM7@0
4g@00a5dM00:M0002G@34@9d0Q4;M0034GAd01id0Q47M0044GAd4@Qd00<AM7@03G@34A9d00<AM7@0
4g@00a5dM00:M0002W@0115dM142M0034GAd00Ud00<AM7@07G@24@Md00DAM7Ad4@07M0034GAd00ed
00<AM7@00Q4@M0034GAd01=d00<AM7@02W@000=d1143M0044GAd4@9d00<AM7@02W@00a5d4@0LM08A
1g@00a5dM002M0034GAd00Ad00<AM7@03G@00a5dM002M08A3W@00a5dM00CM0034GAd00Yd000:M004
4GAd4@9d00<AM7@02g@00a5dM00LM0034GAd00Ed00<AM7@00g@00a5dM003M0034GAd00ed00<AM7@0
17@00a5dM00;M0034GAd01=d00<AM7@02W@000Yd00@AM7@A0W@00a5dM00<M0034GAd01]d00<AM7@0
1G@00a5dM004M0034GAd009d00<AM7@03G@00a5dM005M08A2g@00a5dM00DM0034GAd00Ud0009M08A
0W@0115dM14?M08A6g@00a5dM005M0034GAd00Ed00<AM7@00W@00a5dM00<M0034GAd00Md0Q49M003
4GAd01Ad00<AM7@02G@000Yd00@AM7Ad0Q4BM0034GAd01Ud00<AM7@017@00a5dM006M0054GAdM140
3g@00a5dM008M08A1g@00a5dM00DM0034GAd00Ud000SM0034G@A01Qd00<AM7@017@00a5dM006M005
4GAdM1403g@00a5dM00:M0034GAd00Ad00<AM7@057@00a5dM009M00097@00a5dM00HM0034GAd00=d
00<AM7@01g@0115dM14?M0034GAd00]d0Q44M0034GAd01Ad00<AM7@02G@002Ed00<AM7@05g@00a5d
M003M0034GAd00Qd00<AM1403g@00a5dM00=M08A0W@00a5dM00DM0034GAd00Ud000VM0034GAd01Md
00<AM7@00g@00a5dM008M08A3g@00a5dM00?M0<A5W@00a5dM009M0009g@24AMd00<AM7@00g@00a5d
M009M0034GAd00ed00<AM7@04G@24AEd00<AM7@02G@002Ud0Q4FM0034GAd009d00<AM7@02G@24@id
00<AM7@04G@0115d4A4CM0034GAd00Ud000YM08A5W@00a5dM002M0034GAd00Ud00@AM14A37@00a5d
M00AM0044GAdM08A4G@00a5dM009M000:g@00a5dM00DM0054GAdM1402g@01A5dM7@A00]d00<AM7@0
4G@00a5dM003M0<A3W@00a5dM009M000;7@00a5dM00DM0044GAd4@]d00<AM7@00W@00a5dM008M003
4GAd015d00<AM7@01W@24@ad00<AM7@02G@002ed00<AM7@04g@0115dM14<M0034GAd009d0Q48M003
4GAd015d00<AM7@027@34@Yd00<AM7@027@002id0a4CM0034G@A00ad00<AM7@017@00a5dM005M003
4GAd015d00<AM7@02g@24@Qd00<AM7@027@0031d00<AM7@04G@00a5d4@0<M0034GAd00Ed00<AM7@0
1G@00a5dM00AM0034GAd00ad0Q46M0034GAd00Qd000aM0034GAd015d00<AM1402g@00a5dM006M08A
1G@00a5dM00AM0034GAd00id0a43M0034GAd00Qd000bM0034GAd011d00<AM1402g@00a5dM008M003
4GAd009d00<AM7@04G@00a5dM00AM08A00=d4G@02G@003=d00<AM7@047@24@]d00<AM7@02G@01A5d
M7@A01=d00<AM7@04g@24@Yd000dM0<A3g@24@]d00<AM7@02W@24@03M15d019d00<AM7@057@00a5d
M008M000=G@00a5dM00?M0034GAd00Ud00<AM7@037@24A=d00<AM7@057@00a5dM008M000:W@34@Ud
0Q4@M0034GAd00Qd00<AM7@03G@00a5dM00AM0034GAd01Ad00<AM7@027@002Yd00@AM7@A2W@00a5d
M00>M0034GAd00Qd00<AM7@037@34A5d00<AM7@057@00a5dM008M00097@44@Ed00<AM7@02G@00a5d
M00>M0034GAd00Md00<AM7@037@00a5dM0024@md00<AM7@05G@00a5dM007M000;G@00a5dM00:M08A
3g@00a5dM006M0034GAd00ad00<AM7@00W@24@ed00<AM7@05G@00a5dM007M000:W@34@id00<AM7@0
3W@00a5dM005M0034GAd00ed00<AM7@00g@00a5dM00:M0034GAd01Ed00<AM7@01g@002]d00<AM7@0
3W@00a5dM00>M0034GAd00Ad00<AM7@03G@00a5dM004M08A2W@00a5dM00EM0034GAd00Md000[M0<A
3g@24@md00<AM7@00g@00a5dM00=M0034GAd00Id0Q49M0034GAd01Ad00<AM7@01g@003md0Q4=M003
4GAd00=d00<AM7@03G@00a5dM008M08A1g@00a5dM00DM0034GAd00Md0010M0034GAd00ad00<AM7@0
0W@00a5dM00=M0034GAd00Yd00<AM7@017@00a5dM00DM0034GAd00Md0011M0034GAd00ad00DAM7Ad
4@0?M0034GAd00]d0Q44M0034GAd01Ad00<AM7@01g@0049d00<AM7@037@01A5dM7@A00id00<AM7@0
3G@24@9d00<AM7@05G@00a5dM006M000@g@00a5d4@0<M0044GAd4@md00<AM7@03W@34AMd00<AM7@0
1W@004Ad0Q4=M0034G@A00md00<AM7@047@24AId00<AM7@01W@004Id00<AM7@02g@24@md00<AM7@0
47@00a5d4@024A=d00<AM7@01W@004Md00<AM7@02g@00a5dM00=M0034GAd011d00<AM7@00W@24A5d
00<AM7@01W@004Qd00<AM7@02g@24@ed00<AM7@047@00a5dM004M0<A3W@00a5dM006M000BG@24@ed
00<AM7@02W@00a5dM00AM0034GAd00Id0a4;M0034GAd00Id001:M0034GAd00ad00<AM7@02W@00a5d
M00@M0034GAd00Ud0a48M0034GAd00Id001;M0034GAd00ad0Q4:M0034GAd011d00<AM7@037@34@Id
00<AM7@01G@004ad0Q4>M0034GAd00Md00<AM7@047@00a5dM00?M08A17@00a5dM005M000CW@34@ad
00<AM7@01W@00a5dM00@M0034GAd015d0a400g@AM006M000Cg@00a5dM00<M08A1W@00a5dM00@M003
4GAd01Ad0Q47M000AG@24@Ud00<AM7@03G@00a5dM003M0034GAd015d00<AM7@057@00a5dM005M000
A7@0115dM149M0034GAd00ed0Q43M0034GAd015d00<AM7@057@00a5dM005M000A7@0115dM14:M0<A
3W@01A5dM7@A019d00<AM7@05G@00a5dM004M000A7@0115dM14;M08A3g@0115dM14BM0034GAd01Ed
00<AM7@017@004Ad00@AM7@A3G@00a5dM00=M0<A4W@00a5dM00EM0034GAd00Ad0014M0044GAd4@id
00<AM7@03W@00a5dM00@M0034GAd01Ed00<AM7@017@004Ed0Q4@M0<A3W@24A1d00<AM7@05G@00a5d
M004M000F7@00a5dM00?M08A3g@00a5dM00EM0034GAd00=d001IM0034GAd011d0Q4=M0034GAd01Ed
00<AM7@00g@005Yd0Q4BM08A2g@00a5dM00EM0034GAd00=d001LM08A4W@24@Ud00<AM7@05G@00a5d
M003M000GG@00a5dM00BM08A1g@00a5dM00EM0034GAd00=d001NM0034GAd01=d0Q45M0034GAd01Ed
00<AM7@00g@005md00<AM7@057@24@Ad00<AM7@05G@00a5dM002M000H7@34AEd0Q42M0034GAd01Ed
00<AM7@00W@0065d00<AM7@05W@34AMd00<AM7@00W@0069d0Q4HM08A5W@00a5dM002M000I7@00a5d
M00GM0<A4g@00a5dM002M000IG@34AUd0a4AM0034GAd005d001VM0034GAd01]d0a4>M0034GAd005d
001KM0<A2G@00a5dM00MM08A37@00a5dM001M000Fg@0115dM149M0044GAd4Aed0a49M0034GAd005d
001NM0034GAd00Qd0Q4QM0<A1W@00a5dM001M000GW@00a5dM00:M0034GAd025d0a44M04A0G@1M000
Fg@34@id00<AM7@08g@34@03M15d005d001LM0034GAd00id0a4UM08A0W@005ad0a4?M0034GAd02Qd
001_M0034GAd02Md001`M08A9g@0079d0Q4UM000Lg@00a5dM00SM000M7@00a5dM00RM000MG@34B5d
001fM0034GAd021d001gM0034GAd01md001hM08A00=d4A4077@007Yd00<AM7@077@007]d00<AM7@0
6g@006ad0a42M08A2G@00a5dM00JM000KG@0115dM142M0034GAd02=d001]M0044GAd4@9d00<AM7@0
8g@006ed00@AM7@A0W@00a5dM00SM000KG@0115dM142M0034GAd02=d001/M08A0W@0115dM14UM000
KG@0115dM7@24BId002IM000VG@009Ud002IM000VG@009Ud002IM000VG@009Ud002IM000VG@00001
\
\>"],
  ImageRangeCache->{{{0, 152.875}, {305.438, 0}} -> {0.151799, -0.0927147, 
  0.00370967, 0.00370967}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[exitsurface[3., 7., 80., GraphicDesign->Wire], Axes -> \
True,  BoxRatios -> {1/6, 1, 1}];\
\>", "Input",
  CellLabel->"In[348]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.99178 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.470477 2.04542 5.00359e-17 2.04542 [
[.08585 .06629 -8.21838 -10.9375 ]
[.08585 .06629 .78162 0 ]
[.14761 .04024 -12.6567 -11 ]
[.14761 .04024 1.34326 0 ]
[.21008 .01388 -17.0041 -10.9375 ]
[.21008 .01388 1.99592 0 ]
[.27329 -0.01277 -16.8312 -11 ]
[.27329 -0.01277 2.16883 0 ]
[.14742 1.47331 -15.9375 -3.88015 ]
[.14742 1.47331 0 7.05735 ]
[.41234 1.7 -9 -4.02996 ]
[.41234 1.7 0 6.90754 ]
[.64161 1.89619 -9 -4.15395 ]
[.64161 1.89619 0 6.78355 ]
[.05447 .33826 -15.9375 -3.28771 ]
[.05447 .33826 0 7.64979 ]
[.02934 .65286 -9 -3.44336 ]
[.02934 .65286 0 7.49414 ]
[.00143 1.00233 -9 -3.61711 ]
[.00143 1.00233 0 7.32039 ]
[ 0 0 0 0 ]
[ 1 1.99178 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09724 .08806 m
.30667 0 L
s
.10213 .086 m
.11028 .09586 L
s
gsave
.08585 .06629 -69.2184 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.16368 .06012 m
.17171 .07007 L
s
gsave
.14761 .04024 -73.6567 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.22593 .03395 m
.23386 .04398 L
s
gsave
.21008 .01388 -78.0041 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.28891 .00747 m
.29672 .01759 L
s
gsave
.27329 -0.01277 -77.8312 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11439 .08085 m
.11926 .08677 L
s
.12667 .07569 m
.13153 .08162 L
s
.13898 .07051 m
.14382 .07645 L
s
.15131 .06532 m
.15615 .07128 L
s
.17607 .05491 m
.18088 .06089 L
s
.18849 .04969 m
.19329 .05568 L
s
.20095 .04445 m
.20573 .05045 L
s
.21342 .03921 m
.21819 .04521 L
s
.23847 .02868 m
.24321 .03471 L
s
.25103 .02339 m
.25576 .02943 L
s
.26363 .0181 m
.26834 .02415 L
s
.27625 .01279 m
.28095 .01885 L
s
.30159 .00214 m
.30626 .00822 L
s
.25 Mabswid
0 1.31871 m
.78492 1.99178 L
s
.17197 1.46618 m
.18425 1.46261 L
s
gsave
.14742 1.47331 -76.9375 -7.88015 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.43706 1.6935 m
.44943 1.69024 L
s
gsave
.41234 1.7 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.66647 1.89021 m
.6789 1.88723 L
s
gsave
.64161 1.89619 -70 -8.15395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.22824 1.51443 m
.23562 1.51233 L
s
.28281 1.56122 m
.2902 1.55916 L
s
.33575 1.60662 m
.34315 1.6046 L
s
.38715 1.65069 m
.39456 1.64871 L
s
.48556 1.73508 m
.49298 1.73316 L
s
.53269 1.77549 m
.54012 1.77361 L
s
.57852 1.81479 m
.58596 1.81294 L
s
.62309 1.85302 m
.63054 1.85119 L
s
.11393 1.4164 m
.12128 1.41422 L
s
.05402 1.36503 m
.06136 1.36281 L
s
.7087 1.92642 m
.71616 1.92466 L
s
.74981 1.96168 m
.75729 1.95994 L
s
.25 Mabswid
.09724 .08806 m
0 1.31871 L
s
.07822 .32879 m
.09009 .32405 L
s
gsave
.05447 .33826 -76.9375 -7.28771 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.05331 .64398 m
.0653 .63954 L
s
gsave
.02934 .65286 -70 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02565 .99413 m
.03776 .99003 L
s
gsave
.00143 1.00233 -70 -7.61711 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07223 .4046 m
.07937 .4018 L
s
.06608 .48235 m
.07324 .4796 L
s
.05978 .56212 m
.06696 .55941 L
s
.04667 .72802 m
.05388 .72541 L
s
.03985 .81433 m
.04708 .81176 L
s
.03285 .903 m
.04009 .90049 L
s
.08406 .25485 m
.09117 .25197 L
s
.08976 .18271 m
.09685 .17979 L
s
.09532 .1123 m
.1024 .10934 L
s
.01824 1.08782 m
.02553 1.08541 L
s
.01063 1.18418 m
.01793 1.18183 L
s
.0028 1.28333 m
.01012 1.28104 L
s
0 0 m
1 0 L
1 1.99178 L
0 1.99178 L
closepath
clip
newpath
.5 Mabswid
.8301 .85532 m
.83677 1.01193 L
s
.74284 .74648 m
.8301 .85532 L
s
.83677 1.01193 m
.84377 1.17624 L
s
.74755 .90505 m
.83677 1.01193 L
s
.74755 .90505 m
.74284 .74648 L
s
.65038 .63116 m
.74284 .74648 L
s
.84377 1.17624 m
.85112 1.34884 L
s
.7525 1.07165 m
.84377 1.17624 L
s
.7525 1.07165 m
.74755 .90505 L
s
.65288 .79163 m
.74755 .90505 L
s
.65288 .79163 m
.65038 .63116 L
s
.55223 .50875 m
.65038 .63116 L
s
.85112 1.34884 m
.85885 1.53037 L
s
.7577 1.24692 m
.85112 1.34884 L
s
.85112 1.34884 m
.85112 1.34884 L
s
.7577 1.24692 m
.7525 1.07165 L
s
.65551 .9605 m
.7525 1.07165 L
s
.65551 .9605 m
.65288 .79163 L
s
.55223 .67107 m
.65288 .79163 L
s
.55223 .50875 m
.55223 .50875 L
s
.55223 .67107 m
.55223 .50875 L
s
.44787 .37858 m
.55223 .50875 L
s
.85885 1.53037 m
.86699 1.72154 L
s
.76319 1.43154 m
.85885 1.53037 L
s
.76319 1.43154 m
.7577 1.24692 L
s
.65828 1.13842 m
.7577 1.24692 L
s
.65828 1.13842 m
.65551 .9605 L
s
.55223 .84215 m
.65551 .9605 L
s
.55223 .67107 m
.55223 .84215 L
s
.44504 .54265 m
.55223 .67107 L
s
.44504 .54265 m
.44787 .37858 L
s
.33667 .2399 m
.44787 .37858 L
s
.86699 1.72154 m
.87557 1.92313 L
s
.76897 1.62628 m
.86699 1.72154 L
s
.76897 1.62628 m
.76319 1.43154 L
s
.6612 1.32616 m
.76319 1.43154 L
s
.6612 1.32616 m
.65828 1.13842 L
s
.55223 1.02271 m
.65828 1.13842 L
s
.55223 .84215 m
.55223 1.02271 L
s
.44205 .71588 m
.55223 .84215 L
s
.44205 .71588 m
.44504 .54265 L
s
.33063 .4056 m
.44504 .54265 L
s
.33063 .4056 m
.33667 .2399 L
s
.21796 .09182 m
.33667 .2399 L
s
.87557 1.92313 m
.77508 1.83201 L
s
.77508 1.83201 m
.76897 1.62628 L
s
.66429 1.52454 m
.76897 1.62628 L
s
.66429 1.52454 m
.6612 1.32616 L
s
.55223 1.21357 m
.6612 1.32616 L
s
.55223 1.02271 m
.55223 1.21357 L
s
.43889 .89903 m
.55223 1.02271 L
s
.43889 .89903 m
.44205 .71588 L
s
.32424 .58086 m
.44205 .71588 L
s
.32424 .58086 m
.33063 .4056 L
s
.20826 .259 m
.33063 .4056 L
s
.20826 .259 m
.21796 .09182 L
s
.77508 1.83201 m
.66756 1.73451 L
s
.66756 1.73451 m
.66429 1.52454 L
s
.55223 1.41564 m
.66429 1.52454 L
s
.55223 1.21357 m
.55223 1.41564 L
s
.43554 1.09301 m
.55223 1.21357 L
s
.43554 1.09301 m
.43889 .89903 L
s
.31747 .76654 m
.43889 .89903 L
s
.31747 .76654 m
.32424 .58086 L
s
.19798 .43617 m
.32424 .58086 L
s
.19798 .43617 m
.20826 .259 L
s
.66756 1.73451 m
.55223 1.62993 L
s
.55223 1.41564 m
.55223 1.62993 L
s
.43199 1.29878 m
.55223 1.41564 L
s
.43199 1.29878 m
.43554 1.09301 L
s
.31028 .96358 m
.43554 1.09301 L
s
.31028 .96358 m
.31747 .76654 L
s
.18707 .62425 m
.31747 .76654 L
s
.18707 .62425 m
.19798 .43617 L
s
.55223 1.62993 m
.55223 1.62993 L
s
.55223 1.62993 m
.42822 1.51747 L
s
.42822 1.51747 m
.43199 1.29878 L
s
.30264 1.17307 m
.43199 1.29878 L
s
.30264 1.17307 m
.31028 .96358 L
s
.17546 .82429 m
.31028 .96358 L
s
.17546 .82429 m
.18707 .62425 L
s
.18707 .62425 m
.18707 .62425 L
s
.42822 1.51747 m
.2945 1.39622 L
s
.2945 1.39622 m
.30264 1.17307 L
s
.1631 1.03745 m
.30264 1.17307 L
s
.1631 1.03745 m
.17546 .82429 L
s
.2945 1.39622 m
.14989 1.26509 L
s
.14989 1.26509 m
.1631 1.03745 L
s
.25 Mabswid
.09724 .08806 m
.30667 0 L
s
.10213 .086 m
.11028 .09586 L
s
gsave
.08585 .06629 -69.2184 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.16368 .06012 m
.17171 .07007 L
s
gsave
.14761 .04024 -73.6567 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.22593 .03395 m
.23386 .04398 L
s
gsave
.21008 .01388 -78.0041 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.28891 .00747 m
.29672 .01759 L
s
gsave
.27329 -0.01277 -77.8312 -15 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.000000 moveto
 558.000000 15.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.000000 lineto
closepath
clip newpath
63.000000 11.875000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11439 .08085 m
.11926 .08677 L
s
.12667 .07569 m
.13153 .08162 L
s
.13898 .07051 m
.14382 .07645 L
s
.15131 .06532 m
.15615 .07128 L
s
.17607 .05491 m
.18088 .06089 L
s
.18849 .04969 m
.19329 .05568 L
s
.20095 .04445 m
.20573 .05045 L
s
.21342 .03921 m
.21819 .04521 L
s
.23847 .02868 m
.24321 .03471 L
s
.25103 .02339 m
.25576 .02943 L
s
.26363 .0181 m
.26834 .02415 L
s
.27625 .01279 m
.28095 .01885 L
s
.30159 .00214 m
.30626 .00822 L
s
.25 Mabswid
0 1.31871 m
.78492 1.99178 L
s
.17197 1.46618 m
.18425 1.46261 L
s
gsave
.14742 1.47331 -76.9375 -7.88015 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
69.937500 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.43706 1.6935 m
.44943 1.69024 L
s
gsave
.41234 1.7 -70 -8.02996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.66647 1.89021 m
.6789 1.88723 L
s
gsave
.64161 1.89619 -70 -8.15395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 14.937500 moveto
 558.000000 14.937500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 14.937500 lineto
closepath
clip newpath
63.000000 11.812500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.22824 1.51443 m
.23562 1.51233 L
s
.28281 1.56122 m
.2902 1.55916 L
s
.33575 1.60662 m
.34315 1.6046 L
s
.38715 1.65069 m
.39456 1.64871 L
s
.48556 1.73508 m
.49298 1.73316 L
s
.53269 1.77549 m
.54012 1.77361 L
s
.57852 1.81479 m
.58596 1.81294 L
s
.62309 1.85302 m
.63054 1.85119 L
s
.11393 1.4164 m
.12128 1.41422 L
s
.05402 1.36503 m
.06136 1.36281 L
s
.7087 1.92642 m
.71616 1.92466 L
s
.74981 1.96168 m
.75729 1.95994 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[348]:=",
  ImageSize->{127.875, 254.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001o0000oPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>cWmd001oM000Og@007md001oM000Og@007md
001oM000Og@001]d0a4017@A4A43M08AF7@001ad00@AM7@A0W@00a5d4@02M0034GAd05Ed000LM003
4GAd00=d00<AM1400W@00a5dM01EM00057@34@9d0Q400g@AM0024@9d00<AM1400W@00a5dM01EM000
5G@0115dM142M0<A00Ad4A4A0W@0115dM15GM0005G@0115dM142M0<A0W@01A5dM7@A009d00<AM7@0
EG@0011d0a42M0@A0W@34@9d0a42M08AF7@0011d00HAM7@AM142M0064GAd4G@A0W@00a5dM009M08A
DG@001=d0a42M0064GAd4G@A0W@00a5dM007M08A00=d4G@0D7@000id0Q43M0034G@A009d0a43M08A
1g@44@03M15d055d000=M0034GAd00<A0W@0115dM14<M0<A00=d4G@0E7@000ed00<AM7@00Q43M004
4GAd4@Ud0a400g@A4@1GM0003G@00a5dM0044@9d0Q48M0DAFW@000ed00@AM7@A37@34@03M15d05ad
000=M0044GAd4@Yd0Q4017@AM15NM0003W@24@Qd11400g@AM01PM0005W@34@03M15d06=d000DM0DA
IW@001Ad00<AM14037@00a5dM01IM00057@00a5dM00<M08AFW@001Ad0Q4=M0034G@A05Ud000DM003
4GAd00ad00<AM140FG@001Ad00<AM7@037@0115dM15HM00057@00a5dM00;M0034GAd009d00<AM7@0
EG@001=d00<AM7@037@00a5dM003M0034GAd05Ad000CM0034GAd00ad00<AM7@017@00a5dM01CM000
4g@00a5dM00<M0034GAd00Ed00<AM7@0DW@001=d00<AM7@037@00a5dM005M0034GAd059d000CM08A
3G@00a5dM006M0034GAd055d000CM0034GAd00ad00<AM7@01g@00a5dM01@M0004g@00a5dM00<M003
4GAd00Qd00<AM7@0Cg@001=d00<AM7@037@00a5dM009M0034GAd04id000CM0034GAd00ad00<AM7@0
2W@00a5dM01=M0004g@00a5dM00;M0034GAd00]d00<AM7@0CG@001=d00<AM7@02g@00a5dM00<M003
4GAd04ad000CM0034GAd00]d00<AM7@03G@00a5dM01;M0004g@00a5dM00;M0034GAd00ed0Q5<M000
4W@34@ad00<AM7@03G@00a5d4@1;M0004W@00a5dM00<M08A3W@00a5d4@1;M0004W@00a5dM00<M003
4G@A00ed00@AM7@ABW@0019d00<AM7@037@00a5d4@0=M0054GAdM140BG@0019d00<AM7@037@0115d
M14<M0034GAd009d00<AM7@0AW@0019d00<AM7@037@01A5dM7@A00]d00<AM7@00g@00a5dM015M000
4W@00a5dM00<M0034GAd009d00<AM7@027@00a5dM003M0034GAd04Ed000BM0034GAd00ad00<AM7@0
0g@00a5dM007M0034GAd00Ad00<AM7@0A7@0019d0a4<M0034GAd00Ad00<AM7@01W@00a5dM005M003
4GAd04=d000BM0034GAd00ad00<AM7@017@00a5dM005M0034GAd00Md00<AM7@0@W@0019d00<AM7@0
37@00a5dM005M0034GAd00Ad00<AM7@027@00a5dM011M0004W@00a5dM00;M0034GAd00Md00<AM7@0
0g@00a5dM009M0034GAd041d0008M0@A1W@00a5dM00;M0034GAd00Qd00<AM7@00W@00a5dM009M003
4GAd041d0009M0034GAd00Ed00<AM7@037@00a5dM009M0054GAdM14037@00a5dM00oM0000g@44@=d
00<AM7@017@00a5dM00<M0034GAd00Yd00@AM7@A3G@00a5dM00nM0002W@00a5dM004M0034GAd00ad
00<AM7@02W@0115dM14=M08A?g@000]d00<AM7@00g@00a5dM00<M0034GAd00]d00<AM1403G@24Cmd
0008M0044GAd4@Ed0Q4=M0034GAd00ad0Q4=M0034G@A03id0009M08A1W@24@ed00<AM7@03G@00a5d
M00;M0044GAd4Ced000AM0034GAd00ad00<AM7@03G@24@ad00DAM7Ad4@0lM0004G@00a5dM00<M003
4GAd00ed00<AM1402g@01A5dM7@A03ad000AM0034GAd00ad00<AM7@03G@00a5d4@0;M0034GAd009d
00<AM7@0>G@0015d00<AM7@037@24@id00@AM7@A2W@00a5dM003M0034GAd03Qd000AM0034GAd00ad
00<AM1403G@01A5dM7@A00Ud00<AM7@017@00a5dM00gM0004G@00a5dM00<M0044GAd4@ad00<AM7@0
0W@00a5dM006M0034GAd00Ad00<AM7@0=g@0015d00<AM7@037@01A5dM7@A00]d00<AM7@00g@00a5d
M004M0034GAd00Id00<AM7@0=W@0015d0Q4=M0054GAdM1402g@00a5dM003M0034GAd00Ad00<AM7@0
1g@00a5dM00eM00047@24@id00<AM7@00W@00a5dM008M0034GAd00Ad00<AM7@00g@00a5dM008M003
4GAd03Ad000@M0034GAd00ed00<AM7@00g@00a5dM007M0034GAd00Ed00<AM7@00W@00a5dM008M003
4GAd03Ad000@M0034GAd00ed00<AM7@017@00a5dM005M0034GAd00Md00DAM7Ad4@0;M08A=7@0011d
00<AM7@03G@00a5dM005M0034GAd00Ad00<AM7@027@0115dM14<M0034GAd039d000@M0034GAd00ed
00<AM7@01W@00a5dM003M0034GAd00Ud00<AM14037@24C=d000@M0034GAd00ed00<AM7@01g@00a5d
M002M0034GAd00Ud00<AM14037@00a5d4@0bM00047@00a5dM00<M0034GAd00Ud00DAM7Ad4@0<M08A
37@00a5d4@0bM00047@00a5dM00<M0034GAd00Ud00DAM7Ad4@0=M0034GAd00Yd00@AM7@A<G@0011d
00<AM7@037@00a5dM00:M0044GAd4@ed0Q4;M0054GAdM140<7@0011d0Q4=M0034GAd00]d00<AM140
3G@00a5d4@0:M0034GAd009d00<AM7@0;G@0011d00<AM7@037@00a5dM00<M08A3G@0115dM149M003
4GAd009d00<AM7@0;G@0011d00<AM7@037@00a5dM00=M0034GAd00]d00@AM7@A2G@00a5dM003M003
4GAd02ad000@M0034GAd00ad00<AM7@03G@24@ad00DAM7Ad4@08M0034GAd00Ad00<AM7@0:g@000md
00<AM7@03G@00a5dM00=M0034G@A00]d00<AM7@00W@00a5dM005M0034GAd00Ed00<AM7@0:W@000md
00<AM7@03G@00a5dM00=M0044GAd4@Yd00<AM7@00g@00a5dM004M0034GAd00Id00<AM7@0:G@000md
00<AM7@03G@00a5dM00=M0044GAd4@Yd00<AM7@017@00a5dM003M0034GAd00Id00<AM7@0:G@000md
00<AM7@03G@00a5dM00=M0054GAdM1402G@00a5dM005M0034GAd009d00<AM7@01g@00a5dM00XM000
3g@00a5dM00=M08A3W@00a5dM002M0034GAd00Id00<AM7@01W@01A5dM7@A00Yd00<AM7@09g@000md
0a4=M0034G@A00ed00<AM7@00g@00a5dM005M0034GAd00Md00@AM7@A2W@24BQd000?M0034GAd00ed
00@AM7@A37@00a5dM004M0034GAd00Ad00<AM7@01g@0115dM14:M0034G@A02Md000?M0034GAd00ed
00DAM7Ad4@0;M0034GAd00Ed00<AM7@00g@00a5dM008M0034G@A00Yd00<AM1409g@000Md0Q46M003
4GAd00ed00DAM7Ad4@0;M0034GAd00Id00<AM7@00W@00a5dM009M08A2W@0115dM14VM0001W@0115d
M145M0034GAd00ed00<AM7@00W@00a5dM008M0034GAd00Md00DAM7Ad4@0<M0034GAd00Qd00DAM7Ad
4@0UM0001W@0115dM145M0034GAd00ed00<AM7@00g@00a5dM006M0034GAd00Qd00DAM7Ad4@0<M08A
2G@00a5dM002M0034GAd029d0006M0044GAd4@Ed00<AM7@03G@00a5dM004M0034GAd00Ed00<AM7@0
2G@0115dM14<M0034G@A00Qd00<AM7@00W@00a5dM00RM0001W@0115dM145M0034GAd00ed00<AM7@0
1G@00a5dM004M0034GAd00Yd00<AM14037@0115dM147M0034GAd00=d00<AM7@08G@000Id00@AM7@A
17@00a5dM00>M0034GAd00Id00<AM7@00g@00a5dM00;M08A37@0115dM147M0034GAd00Ad00<AM7@0
87@000Md0Q45M0034GAd00id00<AM7@01g@00a5dM002M0034GAd00ad00<AM7@02W@01A5dM7@A00Md
00<AM7@017@00a5dM00OM0003W@24@md00<AM7@027@01A5dM7@A00id0Q4;M0034GAd009d00<AM7@0
17@00a5dM005M0034GAd01id000>M0034GAd00ed00<AM7@02G@01A5dM7@A00id00<AM1402W@00a5d
M003M0034GAd00=d00<AM7@01G@00a5dM00NM0003W@00a5dM00=M0034GAd00Yd00@AM7@A3W@0115d
M149M0034GAd00Ad00<AM7@00W@00a5dM006M0034GAd01ed000>M0034GAd00ed00<AM7@02g@00a5d
4@0>M0044GAd4@Ud00<AM7@01G@01A5dM7@A00Ud00<AM7@077@000id00<AM7@03G@00a5dM00<M08A
3W@01A5dM7@A00Qd00<AM7@01W@0115dM149M08A7G@000id00<AM7@03G@00a5dM00=M0034GAd00ad
00<AM7@00W@00a5dM005M0034GAd00Id00@AM7@A2G@00a5d4@0LM0003W@00a5dM00=M0034GAd00ed
0Q4=M0034GAd00=d00<AM7@017@00a5dM007M0034G@A00Ud00<AM14077@000id00<AM7@03G@00a5d
M00=M0034G@A00ad00<AM7@017@00a5dM003M0034GAd00Qd0Q49M0044GAd4A]d000>M0034GAd00ed
00<AM7@03G@0115dM14;M0034GAd00Ed00<AM7@00W@00a5dM009M0034GAd00Md00DAM7Ad4@0JM000
3W@00a5dM00=M0034GAd00ed00DAM7Ad4@0:M0034GAd00Id00DAM7Ad4@0;M08A27@00a5dM002M003
4GAd01Md000>M08A3W@00a5dM00=M0034GAd009d00<AM7@01g@00a5dM007M0044GAd4@]d00<AM140
1g@00a5dM003M0034GAd01Id000=M08A3g@00a5dM00=M0034GAd00=d00<AM7@01W@00a5dM007M004
4GAd4@]d00@AM7@A1W@00a5dM004M0034GAd01Ed000=M0034GAd00id00<AM7@03G@00a5dM004M003
4GAd00Ed00<AM7@027@00a5d4@0;M0044GAd4@Id00<AM7@017@00a5dM00EM0003G@00a5dM00>M08A
3W@00a5dM004M0034GAd00Ed00<AM7@02G@24@]d00DAM7Ad4@06M0034GAd00Ad00<AM7@057@000ed
00<AM7@03W@00a5d4@0=M0034GAd00Ed00<AM7@017@00a5dM00:M0034GAd00Ud00<AM7@00W@00a5d
M003M0034GAd00Ed00<AM7@04g@000ed00<AM7@03W@0115dM14<M0034GAd00Id00<AM7@00g@00a5d
M00:M08A2W@00a5dM003M0034GAd009d00<AM7@01W@00a5dM00BM0003G@00a5dM00>M0054GAdM140
2g@00a5dM007M0034GAd009d00<AM7@02W@00a5d4@09M0034GAd00Ad00DAM7Ad4@08M0034GAd019d
000=M0034GAd00id00<AM7@00W@00a5dM007M0034GAd00Ud00DAM7Ad4@0<M0044GAd4@Qd00<AM7@0
1G@0115dM148M0034GAd019d000=M0034GAd00id00<AM7@00g@00a5dM006M0034GAd00Yd00@AM7@A
37@0115dM148M0034GAd00Ed00@AM7@A27@00a5dM00BM0003G@00a5dM00=M0034GAd00Ed00<AM7@0
1G@00a5dM00;M0034G@A00ad00DAM7Ad4@07M0034GAd00Id00<AM14027@00a5dM00BM0003G@00a5d
M00=M0034GAd00Ed00<AM7@01G@00a5dM00<M08A37@00a5dM002M0034GAd00Ad00<AM7@01g@24@Qd
00<AM7@04W@000ed0Q4>M0034GAd00Id00<AM7@017@00a5dM00=M0034GAd00Yd00<AM7@00g@00a5d
M003M0034GAd00Qd00<AM7@01W@00a5dM00BM0003G@00a5dM00=M0034GAd00Md00<AM7@00g@00a5d
M00=M08A2g@00a5dM004M0034GAd009d00<AM7@027@24@Md00<AM7@04W@000ed00<AM7@03G@00a5d
M008M0034GAd009d00<AM7@03G@00a5d4@0:M0034GAd00Ed00DAM7Ad4@0:M0034G@A00Id00<AM7@0
4W@000ad00<AM7@03W@00a5dM009M0054GAdM1403g@0115dM149M0034GAd00Id00@AM7@A2W@00a5d
4@06M0034GAd019d000<M0034GAd00id00<AM7@02W@0115dM14?M0054GAdM14027@00a5dM006M004
4GAd4@Yd00@AM7@A1W@00a5dM00AM00037@00a5dM00>M0034GAd00]d00<AM1403g@00a5dM002M003
4GAd00Ed00<AM7@01g@00a5d4@0:M0054GAdM1401G@00a5dM00AM00037@00a5dM00>M0034GAd00ad
0Q4?M0034GAd00=d00<AM7@017@00a5dM008M08A2W@00a5dM002M0034GAd009d00<AM7@04G@000ad
00<AM7@03W@00a5dM00=M0034GAd00ed00<AM7@00g@00a5dM004M0034GAd00Ud00<AM7@027@00a5d
M002M0034GAd009d00<AM7@04G@000ad00<AM7@03W@00a5dM00=M08A3W@00a5dM004M0034GAd00=d
00<AM7@02G@24@Ud00<AM7@00g@01A5dM7@A01=d000<M0034GAd00id00<AM7@03G@00a5d4@0=M003
4GAd00Ed00<AM7@00W@00a5dM009M0034G@A00Qd00<AM7@017@0115dM14CM00037@24@id00<AM7@0
3W@0115dM14<M0034GAd00Id00DAM7Ad4@0;M0044GAd4@Md00<AM7@01G@00a5d4@0CM00037@00a5d
M00=M0034GAd00id00DAM7Ad4@0;M0034GAd00Md00@AM7@A2g@0115dM147M0034GAd00Ed00<AM140
4g@000ad00<AM7@03G@00a5dM00>M0034GAd009d00<AM7@01g@00a5dM009M0034G@A00]d00DAM7Ad
4@06M0034GAd00Id0Q4CM0000W@44@Id00<AM7@03G@00a5dM00>M0034GAd00=d00<AM7@01W@00a5d
M00:M08A2g@00a5dM002M0034GAd00=d00<AM7@01g@00a5dM00AM0000g@00a5dM006M0034GAd00ed
00<AM7@03W@00a5dM004M0034GAd00Ed00<AM7@02g@00a5dM009M0034GAd00=d00<AM7@00W@00a5d
M007M0034GAd015d0004M0034GAd00Ed00<AM7@03G@00a5dM00>M0034GAd00Ed00<AM7@017@00a5d
M00;M08A2W@00a5dM004M0054GAdM1402G@00a5dM00AM00017@00a5dM005M0034GAd00ed00<AM7@0
3W@00a5dM006M0034GAd00=d00<AM7@02g@00a5d4@09M0034GAd00Ed00@AM7@A2G@00a5dM00AM000
1G@00a5dM003M0034GAd00id0Q4?M0034GAd00Md00<AM7@00W@00a5dM00;M0044GAd4@Qd00<AM7@0
1G@0115dM149M0034GAd015d0002M0044GAd4@Ed00<AM7@03W@00a5d4@0>M0034GAd00Qd00DAM7Ad
4@0=M0044GAd4@Qd00<AM7@01W@00a5d4@09M0034GAd015d0003M08A1W@00a5dM00>M0044GAd4@ed
00<AM7@02G@0115dM14=M0054GAdM1401g@00a5dM007M08A2G@00a5dM00AM0002g@00a5dM00>M005
4GAdM14037@00a5dM00:M0034G@A00ed00<AM7@00W@00a5dM004M0034GAd00Qd00<AM7@01g@00a5d
M00AM0002g@24@md00<AM7@00W@00a5dM009M0034GAd00]d0Q4=M0034GAd00=d00<AM7@00g@00a5d
M008M08A27@00a5dM00AM0002g@00a5dM00>M0034GAd00=d00<AM7@027@00a5dM00<M0034GAd00]d
00<AM7@017@00a5dM002M0034GAd00Qd00<AM1401g@00a5dM00AM0002g@00a5dM00>M0034GAd00Ad
00<AM7@01g@00a5dM00<M08A37@00a5dM005M0054GAdM1402W@0115dM147M0034GAd011d000;M003
4GAd00id00<AM7@01G@24@Md00<AM7@037@00a5d4@0;M0034GAd00Id00@AM7@A2W@01A5dM7@A00Id
00<AM7@047@000]d00<AM7@03W@00a5dM007M0034GAd00Ad00<AM7@037@0115dM14:M0034GAd00Id
00@AM7@A2W@00a5dM002M0034GAd00=d00<AM7@047@000]d00<AM7@03W@00a5dM008M0034GAd00=d
00<AM7@037@01A5dM7@A00Ud00<AM7@01g@00a5d4@0:M0034GAd009d00<AM7@00g@00a5dM00@M000
2g@00a5dM00>M0034GAd00Ud00<AM7@00W@00a5dM00<M0034GAd009d00<AM7@01W@00a5dM008M08A
2W@00a5dM003M0034GAd009d00<AM7@047@000]d00<AM7@03W@00a5dM00:M0054GAdM1403W@00a5d
M003M0034GAd00Ed00<AM7@02G@00a5dM008M0034GAd00Ad00DAM7Ad4@0BM0002g@00a5dM00>M003
4GAd00]d00@AM7@A3W@00a5dM004M0034GAd00Ad00<AM7@02G@24@Ud00<AM7@01G@0115dM14BM000
2W@00a5dM00>M0034GAd00ed00<AM1403W@00a5dM005M0034GAd00=d00<AM7@02G@00a5d4@08M003
4GAd00Id00<AM1404W@000Yd00<AM7@03W@00a5dM00>M08A3W@00a5dM006M0034GAd009d00<AM7@0
2G@0115dM148M0034GAd00Id0Q4BM0002W@00a5dM00>M0034GAd00md00<AM7@037@00a5dM007M005
4GAdM1402g@01A5dM7@A00Md00<AM7@01g@00a5dM00@M0002W@24@md00<AM7@03g@24@ed00<AM7@0
27@0115dM14;M0034GAd009d00<AM7@017@00a5dM007M0034GAd011d000:M0034GAd00id00<AM7@0
3g@00a5d4@0<M0034GAd00Ud00<AM1402g@00a5dM003M0034GAd00=d00<AM7@01g@00a5dM00@M000
2W@00a5dM00>M0034GAd00md00@AM7@A2g@00a5dM00:M08A2g@00a5dM004M0034GAd009d00<AM7@0
1g@00a5dM00@M0002W@00a5dM00>M0034GAd00md00DAM7Ad4@0:M0034GAd00]d00<AM7@02G@00a5d
M005M0054GAdM1402G@00a5dM00@M0002W@00a5dM00>M0034GAd00md00<AM7@00W@00a5dM007M003
4GAd00]d0Q4:M0034GAd00Id00@AM7@A2G@00a5dM00@M0002W@00a5dM00>M0034GAd00md00<AM7@0
0g@00a5dM006M0034GAd00]d00<AM1402G@00a5dM007M0034G@A00Ud00<AM7@047@000Yd00<AM7@0
3W@00a5dM00?M0034GAd00Ad0Q46M0034GAd00]d00@AM7@A27@00a5dM008M08A2G@00a5dM00@M000
2W@00a5dM00>M0034GAd00md00<AM7@01W@00a5dM003M0034GAd00]d00DAM7Ad4@08M0034GAd00Qd
00<AM7@01g@00a5dM00@M0002W@00a5dM00>M0034GAd00md00<AM7@01g@00a5dM002M0034GAd00]d
00<AM7@00W@00a5dM005M0034GAd00Qd0Q48M0034GAd011d000:M0034GAd00id00<AM7@03g@00a5d
M008M0054GAdM1403G@00a5dM003M0034GAd00Ad00<AM7@027@00a5d4@07M0034GAd011d0009M003
4GAd011d00<AM7@03W@00a5dM009M0044GAd4@ed00<AM7@00g@00a5dM004M0034GAd00Qd00@AM7@A
1g@00a5dM00?M0002G@24A9d00<AM7@03G@00a5dM00:M0034G@A00ed00<AM7@017@00a5dM003M003
4GAd00Qd00DAM7Ad4@06M0034GAd00md0009M0034GAd019d00<AM7@037@00a5dM00;M08A3G@00a5d
M005M0034GAd009d00<AM7@027@00a5dM002M0034GAd00=d00<AM7@03g@000Ud00<AM7@04g@00a5d
M00:M0034GAd00ed00<AM7@02g@00a5dM006M0054GAdM1402W@00a5dM002M0034GAd00=d00<AM7@0
3g@000Ud00<AM7@057@00a5dM009M0034GAd00ed0Q4<M0034GAd00Md00@AM7@A2W@00a5dM003M003
4GAd009d00<AM7@03g@000Ud00<AM7@05G@00a5dM008M0034GAd00ed00<AM1402g@00a5dM008M003
4G@A00Yd00<AM7@017@01A5dM7@A015d0009M0034GAd01Id00<AM7@01g@00a5dM00=M0044GAd4@Yd
00<AM7@02G@24@Yd00<AM7@01G@0115dM14AM0002W@00a5dM00FM08A1g@00a5dM00=M0054GAdM140
2G@00a5dM00:M0034GAd00Qd00<AM7@01W@00a5d4@0AM0002g@00a5dM00GM0034GAd00Ad00<AM7@0
3G@00a5dM002M0034GAd00Id00<AM7@02W@24@Ud00<AM7@01g@24A5d000<M08A67@00a5dM003M003
4GAd00ed00<AM7@00g@00a5dM005M0034GAd00Yd00<AM1402G@00a5dM007M0034GAd00md000>M003
4GAd01Id00<AM7@00W@00a5dM00=M0034GAd00Ad00<AM7@017@00a5dM00:M0044GAd4@Qd00<AM7@0
1g@00a5dM00?M0003g@24AMd00DAM7Ad4@0?M0034GAd00Ed00<AM7@00g@00a5dM00:M0054GAdM140
1g@00a5dM007M0034GAd00md000@M0034GAd01Id00@AM7@A3g@00a5dM006M0034GAd009d00<AM7@0
2W@00a5dM002M0034GAd00Ad00<AM7@01g@00a5dM00?M0004G@00a5dM00FM0034G@A00md00<AM7@0
1g@01A5dM7@A00ad00<AM7@00g@00a5dM003M0034GAd00Md00<AM7@03g@0019d00<AM7@05W@24@md
00<AM7@027@0115dM14<M0034GAd00Ad00<AM7@00W@00a5dM007M0034GAd00md000CM08A5g@00a5d
M00=M0034GAd00Ud00<AM14037@00a5dM005M0054GAdM1402G@00a5dM00?M0005G@00a5dM00EM003
4GAd00ad00<AM7@02W@24@ad00<AM7@01W@0115dM149M0034GAd00md000FM08A5W@00a5dM00:M003
4GAd00ad00<AM7@02W@00a5dM007M0034G@A00Ud00<AM7@03g@001Md00<AM7@05G@00a5dM009M003
4GAd00ad0Q4;M0034GAd00Qd0Q49M0034GAd00md000HM0034GAd01Ed00<AM7@027@00a5dM00<M003
4G@A00Yd00<AM7@02G@00a5dM007M0034GAd00md000IM0034GAd01Ed00<AM7@01g@00a5dM00<M004
4GAd4@Ud00<AM7@02G@24@Qd00<AM7@03g@001Yd0Q4FM0034GAd00Id00<AM7@037@01A5dM7@A00Qd
00<AM7@02G@00a5d4@08M0034GAd00id000LM0034GAd01Ad0Q46M0034GAd00ad00<AM7@00W@00a5d
M005M0034GAd00Ud00@AM7@A1g@00a5dM00>M0007G@34AEd00<AM7@00g@00a5dM00<M0034GAd00=d
00<AM7@017@00a5dM009M0054GAdM1401W@00a5dM00>M0007W@00a5dM00EM0034GAd009d00<AM7@0
37@00a5dM004M0034GAd00=d00<AM7@02G@00a5dM002M0034GAd00=d00<AM7@03W@001Ad0a48M003
4GAd01Ed00DAM7Ad4@0>M0034GAd00Ed00<AM7@00W@00a5dM009M0034GAd009d00<AM7@00g@00a5d
M00>M0005G@00a5dM008M0034GAd01Ed00@AM7@A3W@00a5dM006M0054GAdM1402g@00a5dM003M003
4GAd009d00<AM7@03W@000ed1144M0034GAd00Ud0Q4FM0034G@A00id00<AM7@01g@0115dM14;M003
4GAd00Ad00DAM7Ad4@0@M0005G@00a5dM00;M0034G@A01Ad0Q4>M0034GAd00Qd00<AM1402g@00a5d
M005M0044GAd4A1d000EM0034GAd00ad00<AM7@057@00a5dM00<M0034GAd00Ud0Q4;M0034GAd00Id
00<AM14047@001Ad0Q4?M0034GAd01Ad00<AM7@02g@00a5dM00:M0034GAd00Ud00<AM7@01g@24A1d
000EM0034GAd00id00<AM7@057@00a5dM00:M0034GAd00Yd0Q4:M0034GAd00Qd00<AM7@03W@002Md
00<AM7@057@24@Yd00<AM7@02W@00a5d4@09M0034GAd00Qd00<AM7@03W@002Qd0Q4FM0034GAd00Md
00<AM7@02W@0115dM148M0034GAd00Qd00<AM7@03W@002Yd0Q4EM0034GAd00Id00<AM7@02W@01A5d
M7@A00Md00<AM7@027@00a5dM00>M000:g@00a5dM00DM0034GAd00Ed00<AM7@02W@00a5dM002M003
4GAd00Ad00<AM7@027@00a5dM00>M000;7@00a5dM00DM0034GAd00Ad00<AM7@02W@00a5dM003M003
4GAd00=d00<AM7@027@00a5dM00>M000;G@00a5dM00DM0034GAd00=d00<AM7@02W@00a5dM004M003
4GAd009d00<AM7@027@00a5dM00>M000;W@00a5dM00DM0034GAd009d00<AM7@02W@00a5dM005M005
4GAdM1402W@00a5dM00>M000;g@34AAd0Q42M0034GAd00Yd00<AM7@01W@0115dM14:M0034GAd00id
000`M08A5W@00a5d4@0<M0034GAd00Md00<AM1402W@00a5dM00>M000<W@00a5dM00DM08A37@00a5d
M008M08A2W@00a5dM00>M000<g@00a5dM00DM0034GAd00Yd00<AM7@02G@00a5dM008M0034GAd00id
000dM0034GAd01Ad00<AM7@02G@00a5dM009M08A2W@00a5dM00=M000=G@00a5d4@0DM0034GAd00Qd
00<AM7@02G@00a5d4@09M0034GAd00ed000fM0034GAd01Ad00<AM7@01g@00a5dM009M0044GAd4@Qd
00<AM7@03G@003Md0Q4EM0034GAd00Id00<AM7@02G@01A5dM7@A00Md00<AM7@03G@003Ud00<AM7@0
4g@00a5dM005M0034GAd00Ud00<AM7@00W@00a5dM004M0034GAd00ed000jM0034GAd01=d00<AM7@0
17@00a5dM009M0034GAd00=d0Q44M0034GAd00ed000kM0044G@A4A9d00<AM7@00g@00a5dM009M003
4GAd00Ed00DAM7Ad4@0?M000?7@00a5dM00CM0034GAd009d00<AM7@02G@00a5dM006M0044GAd4@md
000mM0034GAd01=d00DAM7Ad4@0;M0034GAd00Md00<AM1403g@003=d0Q49M08A57@0115dM14;M003
4GAd00Qd0Q4?M000<W@0115dM14:M0034GAd019d00<AM1402g@00a5dM009M0034GAd00ed000bM004
4GAd4@]d00<AM1404W@24@]d00<AM7@02G@00a5dM00=M000<W@0115dM14<M0034GAd019d00<AM7@0
2W@00a5dM008M0034GAd00ed000bM0044GAd4@ed00<AM7@04W@00a5dM009M0034GAd00Qd00<AM7@0
3G@0039d00@AM7@A3W@00a5dM00BM0034GAd00Qd00<AM7@027@00a5dM00=M000<g@24A1d0Q4CM08A
27@00a5dM008M0034GAd00ed0017M08A4g@00a5dM005M0034GAd00Qd00<AM7@03G@004Qd00<AM7@0
4W@00a5dM004M0034GAd00Qd00<AM7@03G@004Ud00<AM7@04W@00a5dM003M0034GAd00Qd00<AM7@0
3G@004Yd00<AM7@04W@00a5dM002M0034GAd00Qd00<AM7@03G@004]d00<AM7@04W@24@9d00<AM7@0
27@00a5dM00=M000C7@34A=d00<AM1402W@00a5dM00=M000CW@00a5dM00BM08A2W@00a5dM00=M000
Cg@00a5dM00BM0034GAd00Ud00<AM7@037@0051d00<AM7@04W@00a5dM008M0034GAd00ad001AM0<A
4W@00a5dM007M0034GAd00ad001BM0034GAd019d00<AM7@01W@00a5dM00<M000Dg@24A=d00<AM7@0
1G@00a5dM00<M000EG@00a5dM00AM0034GAd00Ad00<AM7@037@005Id00@AM14A47@24@Ad00<AM7@0
37@005Md00<AM7@04W@01A5dM7@A00id001HM0034GAd019d00@AM7@A3W@004id0a48M0034GAd019d
00<AM1403W@004md00<AM7@027@24A=d0Q4>M000Cg@00a5dM00:M08A4W@00a5dM00<M000Cg@00a5d
M00;M0034GAd01md001?M0034GAd00ad00<AM7@07W@004id0Q4?M0034GAd01ed001?M0034GAd00id
0a4LM000HG@24Aad001SM0034GAd01Ud001TM0034GAd01Qd001UM0034GAd01Md001oM000Og@007md
0000\
\>"],
  ImageRangeCache->{{{0, 126.875}, {253.688, 0}} -> {0.190232, -0.0677042, 
  0.00416695, 0.00416695}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrapezodialPrism", "SubsectionIcon"],

Cell["Clear[TrapezodialPrism];", "Input",
  CellLabel->"In[172]:="],

Cell["\<\
TrapezodialPrism::usage=
\t\"TrapezodialPrism[frontwidth, frontheight, endwidth, endheight, length, \
radius, options] refers to a six-sided prism having trapezoidal dimensions on \
four sides and rectangular dimensions on the end surface. TrapezodialPrism \
has a spherical shape on its first surface.\";\
\>", "Input"],

Cell["\<\
Options[TrapezodialPrism] = {
\tLabels -> \"P\", 
\tLabelPositions -> Automatic, 
\tComponentDescription -> Automatic,
\tGraphicDesign -> Automatic, 
\tComponentMedium -> BK7, 
\tTemperature -> Temperature, 
\tTension -> Tension, 
\tTransmittance -> Transmittance, 
\tAutomatic -> {SurfaceRendering -> Trace, CrossRendering -> Trace}, 
\tSketch -> {SurfaceRendering -> Trace, CrossRendering -> Trace}, 
\tWire -> {SurfaceRendering -> Mesh, CrossRendering -> Empty}, 
\tSolid -> {SurfaceRendering -> {{Fill, Trace}}, CrossRendering -> Empty}
};\
\>", "Input",
  CellLabel->"In[173]:="],

Cell["\<\
TrapezodialPrism[a_, b_, c_, d_, L_, R_, opts___] := 
Block[{options, component, entrance, exit,
\ttop, bottom, left, right
},

\toptions = Flatten[{opts, Options[TrapezodialPrism]}];
\t
\tentrance = entrancesurface[a, b, R, options];
\texit = exitsurface[c, d, L, options];
\ttop = topsurface[a, b, c, d, L, options];
\tbottom = bottomsurface[a, b, c, d, L, options];
\tleft = leftsurface[a, b, c, d, L, options];
\tright = rightsurface[a, b, c, d, L, options];
\t
\tResonate[{
\t\tRefraction[{entrance, exit},options]
\t,
\t\tReflection[{top, bottom, left, right},options]
\t},
\t\toptions
\t]
];\
\>", "Input",
  CellLabel->"In[335]:="],

Cell[CellGroupData[{

Cell["DrawSystem[TrapezodialPrism[20., 10., 3., 7., 80., 100.]];", "Input",
  CellLabel->"In[337]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50967 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0309051 1.03091 -0.242259 1.03091 [
[ 0 0 0 0 ]
[ 1 .50967 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .50967 L
0 .50967 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15565 .40757 m
.14925 .49913 L
s
.92151 .11136 m
.15565 .40757 L
s
.03189 .29621 m
.15565 .40757 L
s
.15565 .40757 m
.92625 .10943 L
s
.16136 .40577 m
.139 .38871 L
s
.16136 .40577 m
.16136 .40577 L
s
.15969 .42099 m
.16136 .40577 L
s
.15827 .43623 m
.15969 .42099 L
s
.15709 .45148 m
.15827 .43623 L
s
.139 .38871 m
.11734 .37106 L
s
.15616 .46675 m
.15709 .45148 L
s
.15709 .45148 m
.13449 .4346 L
s
.15709 .45148 m
.15709 .45148 L
s
.15549 .48204 m
.15616 .46675 L
s
.11734 .37106 m
.09638 .35282 L
s
.15507 .49736 m
.15549 .48204 L
s
.13449 .4346 m
.11258 .41713 L
s
.14925 .49913 m
.92825 .17941 L
s
.02265 .38997 m
.14925 .49913 L
s
.14925 .49913 m
.93307 .1775 L
s
.15507 .49736 m
.15507 .49736 L
s
.13222 .48065 m
.15507 .49736 L
s
.09638 .35282 m
.07612 .33394 L
s
.09638 .35282 m
.09638 .35282 L
s
.09447 .36822 m
.09638 .35282 L
s
.11258 .41713 m
.09138 .39907 L
s
.09447 .36822 m
.0928 .38363 L
s
.11008 .46337 m
.13222 .48065 L
s
.09138 .39907 m
.0928 .38363 L
s
.07612 .33394 m
.05658 .31442 L
s
.09021 .41452 m
.09138 .39907 L
s
.09138 .39907 m
.07089 .38038 L
s
.08864 .44549 m
.11008 .46337 L
s
.0893 .42999 m
.09021 .41452 L
s
.05658 .31442 m
.03777 .29422 L
s
.0893 .42999 m
.08864 .44549 L
s
.07089 .38038 m
.05111 .36105 L
s
.06792 .42698 m
.08864 .44549 L
s
.08864 .44549 m
.08864 .44549 L
s
.02265 .38997 m
.03189 .29621 L
s
.03189 .29621 m
.90678 .09009 L
s
.912 .08879 m
.03189 .29621 L
s
.03777 .29422 m
.03562 .30981 L
s
.03777 .29422 m
.03777 .29422 L
s
.05111 .36105 m
.03206 .34104 L
s
.03562 .30981 m
.03372 .32542 L
s
.04791 .40784 m
.06792 .42698 L
s
.03372 .32542 m
.03206 .34104 L
s
.03206 .34104 m
.03067 .35669 L
s
.03206 .34104 m
.03206 .34104 L
s
.02865 .38803 m
.04791 .40784 L
s
.03067 .35669 m
.02953 .37235 L
s
.02953 .37235 m
.02865 .38803 L
s
.91335 .15837 m
.02265 .38997 L
s
.91865 .15709 m
.02265 .38997 L
s
.92825 .17941 m
.92151 .11136 L
s
.92625 .10943 m
.912 .08879 L
s
.92641 .10938 m
.93323 .17745 L
s
.91216 .08874 m
.92641 .10938 L
s
.91931 .0991 m
.91931 .0991 L
s
.92042 .11032 m
.91931 .0991 L
s
.92154 .1216 m
.92042 .11032 L
s
.90678 .09009 m
.91335 .15837 L
s
.92979 .14316 m
.92742 .13976 L
s
.92979 .14316 m
.92979 .14316 L
s
.91882 .15703 m
.91216 .08874 L
s
.92742 .13976 m
.92504 .13635 L
s
.92266 .13293 m
.92154 .1216 L
s
.92504 .13635 m
.92266 .13293 L
s
.92378 .14432 m
.92266 .13293 L
s
.92266 .13293 m
.92026 .12951 L
s
.92026 .12951 m
.91787 .12607 L
s
.92492 .15577 m
.92378 .14432 L
s
.91787 .12607 m
.91546 .12263 L
s
.93307 .1775 m
.91865 .15709 L
s
.93323 .17745 m
.91882 .15703 L
s
.91546 .12263 m
.91546 .12263 L
s
.92605 .16728 m
.92492 .15577 L
s
.92605 .16728 m
.92605 .16728 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[337]:=",
  ImageSize->{263.5, 134.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000470000QPP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_md27@00?md27@00?md27@00?md27@00?md
27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md
27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00?md27@00>ad114GM000
j7@64@03M15d01Id003TM0LA0W@0115d4A4FM000h7@74@Id00<AM1400Q4EM000g7@74@Yd00<AM140
0Q4EM000eg@84@id00DAM15d4@0EM000dg@74AAd1A4DM000cg@74AQd1A4DM000bg@74AUd1A400g@A
4@0DM000ag@74A]d0a42M0DA57@00<=d1Q4MM0<A1G@00a5d4@024AAd002nM0LA7W@44@Md00<AM140
0a4CM000^W@74B1d0a4:M0034G@A00<A4g@00;Id1a4QM0@A37@00a5d4@034A=d002bM0HA97@34@md
00@AM15d0Q4CM000[W@64BEd114BM08A00=d4A404g@00:Ud1a4WM0<A5G@24@03M14A01=d002UM0LA
:7@34AQd0Q400g@A4@0CM000XG@74BUd114JM08A00=d4A404g@009ed1Q4/M0<A6G@54@04M14A4A=d
002IM0HA;G@44AMd1a43M0@A4W@009Ed1Q4_M0<A5W@74@Qd0a4BM000T7@74C1d114DM0LA3G@24A9d
002<M0HA<g@34A=d1a4AM08A4W@008Qd1Q4dM0<A4g@64AAd0a4BM000Q7@64CEd114AM0HA5W@34AAd
0020M0HA=g@34A1d1Q4GM0@A5W@007]d1Q4iM0@A3W@64AUd0a4IM000Mg@64C]d0a4=M0HA6g@34A]d
001cM0HA?7@44@]d1a4KM0@A7G@006md1Q4nM0<A2g@64Aed0a4PM000Jg@54D1d0a4:M0HA7W@44B9d
001WM0DA@W@34@Qd1Q4PM0<A9G@0069d1Q53M0<A1g@64B5d114WM000GW@64DAd1145M0HA8g@34BYd
001JM0DAAg@34@Ad1Q4UM0<A;7@005Id1A58M0<A17@54BId0a4_M000DW@54DYd0a42M0HA9g@34C5d
001=M0HABg@34@03M14A00@A:7@44C=d0019M0DACW@84BYd0a4fM000AG@54Dmd1a4[M0@A>7@0045d
1A5@M0HA;G@34C]d000mM0DADG@54Bmd0a4mM000>G@54E5d1A4`M0<A@7@003Ad1A5BM0LA<7@34D9d
000`M0DADW@84C1d0a55M000;7@54E9d1Q4017@A4A4`M0<AAg@002Qd1A5BM0HA0W@34C1d1159M000
97@44E=d1Q44M0<A<7@34Dad000OM0DAE7@54@Ed0a4aM0<ACW@001]d1A5DM0DA1W@34C5d0a5AM000
5g@54EAd1A48M0<A<G@34E=d000CM0@AEG@54@Ud0a4aM0<AEW@000md115EM0DA2g@34C5d0a5HM000
2W@54EEd1Q4;M0<A<G@44EYd0008M0@AEG@54@ed0a4aM0<AGG@000Qd0a400g@AM01?M0DA3W@34C9d
0a5OM00027@34@9d00<AM7@0BG@54@md0a4bM0<AHW@000Qd0Q401G@AM7@A04Id1A4AM0<A<W@34FAd
0008M08A0W@24@03M15d041d1A4BM0<A<W@34FMd0008M08A17@00a5d4@0lM0DA57@34C9d0a5YM000
27@24@Ed00<AM140>7@44AEd0a4bM0<AK7@000Md00<AM1401W@24CAd114GM08A<g@34Fid0007M003
4G@A00Md0Q4_M0DA5g@34C=d0a5`M0001g@00a5d4@08M08A:W@54AQd0a4cM0<ALg@000Md0Q4:M08A
9G@54AYd0a4cM0<AMG@000Md0a4:M08A87@54A]d0a4cM0<AN7@000Md0a4<M08A6g@44Aed0a4cM0<A
NW@000Md0Q400g@AM00;M08A5W@44Aid0a4cM0<AOG@000Md0Q400g@AM00<M08A4G@44B1d0Q4dM0<A
Og@000Md0Q42M0034GAd00]d0Q4<M0@A8G@34CAd0Q62M0001g@24@=d00<AM7@02W@34@Md1A4RM08A
=7@34HAd0007M08A17@00a5dM009M0034G@A008A00=d4A400a4SM0<A=7@34HId0007M08A1G@00a5d
M008M0034GAd00@A97@34CAd0a69M0001W@00a5d4@06M0034GAd00Id1142M08A8W@34CAd0a6;M000
1W@00a5d4@07M08A0W@44@03M15d00Ad0Q4NM0<A=7@34Hid0006M0034G@A00Md1145M0034GAd00Ad
0Q4KM08A=G@34I1d0006M0034G@A00=d1143M0034GAd009d00<AM7@01W@24AMd0a4eM08ATg@000Id
00<AM1400a48M0054GAdM1402G@24AAd0Q4eM0<AUG@000Id0a4<M0044GAd4@Yd0Q4@M0<A=G@24IQd
0007M0034G@A00ad00<AM1402g@34@]d0a4eM0<AVW@000Qd00<AM14037@24@ed0Q48M0<A=G@34Iad
0009M0034G@A00ad00<AM7@037@34@=d0a4eM0<AWg@000Yd0a4;M08A3W@00a5d4@024CId0a6QM000
37@24@Yd00@AM14A3G@24CId0Q6TM0003G@24@Ud00DAM7Ad4@0<M08A<g@34JId000>M08A27@00a5d
M002M0034GAd00Ud0Q4aM08AZG@000md0Q47M0034GAd00=d00<AM7@027@24Bid0a6[M00047@24@Id
00<AM7@017@00a5dM007M08A;7@34Jed000AM08A17@00a5dM006M08A1g@24BUd0a6`M0004W@24@=d
00<AM7@027@00a5dM004M0034GAd02Id0a6bM00057@0115dM14;M0034GAd009d0Q4VM08A]G@001Ed
00<AM14037@24@9d0Q4SM0<A]g@001Id0Q4>M0044G@A4B5d0Q6jM0005g@00a5dM00=M0<A7W@34Kad
000HM08A3W@24Aad0Q6oM0006G@24@ed0Q4IM0<A`G@001Yd0a4;M08A5g@34L=d000LM08A2W@24AEd
0Q76M0007G@24@Ud0Q4BM0<Ab7@001id0Q48M08A47@24L]d000OM0<A1W@24@ed0a7=M00087@00a5d
4@05M08A2g@24M1d000QM0034G@A00=d00<AM14027@34M9d000RM0@A00Ad4G@A1W@24MEd000TM006
4G@A4G@A17@24MMd000UM0034G@A008A00Ad4A4AfG@002Id0Q400g@A4@3LM0009g@24Mid003oM0Qd
003oM0Qd0000\
\>"],
  ImageRangeCache->{{{0, 262.5}, {133.25, 0}} -> {0.0280189, 0.234995, 
  0.00371023, 0.00371023}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{
\tConeOfRays[10, NumberOfRays->3],
\tMove[TrapezodialPrism[20., 10., 3., 7., 80., 100.],20],
\tBoundary[120, GraphicDesign -> Off]}
];\
\>", "Input",
  CellLabel->"In[343]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47687 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0312714 1.03127 -0.259269 1.03127 [
[ 0 0 0 0 ]
[ 1 .47687 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47687 L
0 .47687 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.23901 .33125 m
.23573 .39365 L
s
.75702 .12841 m
.23901 .33125 L
s
.1571 .25306 m
.23901 .33125 L
s
.23901 .33125 m
.76009 .12715 L
s
.24302 .32996 m
.22795 .31784 L
s
.24302 .32996 m
.24302 .32996 L
s
.24204 .34039 m
.24302 .32996 L
s
.24124 .35081 m
.24204 .34039 L
s
.24061 .36122 m
.24124 .35081 L
s
.039 .916 .04 r
.06893 .36537 m
.19387 .31106 L
s
.06893 .36537 m
.19268 .33015 L
s
.06893 .36537 m
.20409 .33077 L
s
0 g
.22795 .31784 m
.21345 .30536 L
s
.24016 .37162 m
.24061 .36122 L
s
.24061 .36122 m
.22543 .34918 L
s
.24061 .36122 m
.24061 .36122 L
s
.23989 .382 m
.24016 .37162 L
s
.21345 .30536 m
.19952 .29251 L
s
.23979 .39238 m
.23989 .382 L
s
.22543 .34918 m
.21082 .33678 L
s
.23573 .39365 m
.75979 .17387 L
s
.15258 .31645 m
.23573 .39365 L
s
.23573 .39365 m
.7629 .17261 L
s
.23979 .39238 m
.23979 .39238 L
s
.22451 .38042 m
.23979 .39238 L
s
.19952 .29251 m
.18616 .27929 L
s
.19952 .29251 m
.19952 .29251 L
s
.19843 .30303 m
.19952 .29251 L
s
.21082 .33678 m
.19678 .32402 L
s
.19752 .31353 m
.19843 .30303 L
s
.20979 .3681 m
.22451 .38042 L
s
.039 .916 .04 r
.20409 .33077 m
.56989 .22745 L
s
0 0 0 r
2 Mabswid
.20409 .33077 Mdot
0 g
.5 Mabswid
.19752 .31353 m
.19678 .32402 L
s
.18616 .27929 m
.17338 .26569 L
s
.039 .916 .04 r
.19387 .31106 m
.56403 .16707 L
s
0 0 0 r
2 Mabswid
.19387 .31106 Mdot
0 g
.5 Mabswid
.19623 .33449 m
.19678 .32402 L
s
.18332 .31088 m
.19678 .32402 L
s
.19565 .35542 m
.20979 .3681 L
s
.19585 .34496 m
.19623 .33449 L
s
.039 .916 .04 r
.19268 .33015 m
.56493 .21823 L
s
0 0 0 r
2 Mabswid
.19268 .33015 Mdot
0 g
.5 Mabswid
.17338 .26569 m
.16119 .25168 L
s
.19565 .35542 m
.19585 .34496 L
s
.18332 .31088 m
.17044 .29736 L
s
.18209 .34236 m
.19565 .35542 L
s
.19565 .35542 m
.19565 .35542 L
s
.15258 .31645 m
.1571 .25306 L
s
.1571 .25306 m
.74633 .11447 L
s
.74975 .11362 m
.1571 .25306 L
s
.16119 .25168 m
.16 .26229 L
s
.16119 .25168 m
.16119 .25168 L
s
.17044 .29736 m
.15815 .28345 L
s
.16 .26229 m
.15899 .27287 L
s
.16911 .32893 m
.18209 .34236 L
s
.15899 .27287 m
.15815 .28345 L
s
.15815 .28345 m
.15749 .29401 L
s
.15815 .28345 m
.15815 .28345 L
s
.15673 .3151 m
.16911 .32893 L
s
.15749 .29401 m
.15702 .30456 L
s
.15702 .30456 m
.15673 .3151 L
s
.74901 .16003 m
.15258 .31645 L
s
.75246 .15919 m
.15258 .31645 L
s
.039 .916 .04 r
.56989 .22745 m
.71944 .14415 L
s
0 0 0 r
2 Mabswid
.56989 .22745 Mdot
.039 .916 .04 r
.5 Mabswid
.56403 .16707 m
.66562 .13923 L
s
0 0 0 r
2 Mabswid
.56403 .16707 Mdot
.97101 .18116 Mdot
.039 .916 .04 r
.5 Mabswid
.75691 .14365 m
.97101 .18116 L
s
.56493 .21823 m
.66709 .17562 L
s
0 0 0 r
2 Mabswid
.56493 .21823 Mdot
.039 .916 .04 r
.5 Mabswid
.66562 .13923 m
.75556 .13061 L
s
0 0 0 r
2 Mabswid
.66562 .13923 Mdot
0 g
.5 Mabswid
.75979 .17387 m
.75702 .12841 L
s
.76009 .12715 m
.74975 .11362 L
s
.7602 .12711 m
.763 .17257 L
s
.74985 .11359 m
.7602 .12711 L
s
.75504 .12037 m
.75504 .12037 L
s
.7555 .12789 m
.75504 .12037 L
s
.75595 .13544 m
.7555 .12789 L
s
.74633 .11447 m
.74901 .16003 L
s
.039 .916 .04 r
.75556 .13061 m
.9349 .13387 L
s
0 0 0 r
2 Mabswid
.75556 .13061 Mdot
0 g
.5 Mabswid
.76159 .14973 m
.75987 .14749 L
s
.76159 .14973 m
.76159 .14973 L
s
.75257 .15915 m
.74985 .11359 L
s
.75987 .14749 m
.75814 .14525 L
s
.75641 .14301 m
.75595 .13544 L
s
.039 .916 .04 r
.66709 .17562 m
.75705 .1552 L
s
0 0 0 r
2 Mabswid
.66709 .17562 Mdot
0 g
.5 Mabswid
.75814 .14525 m
.75641 .14301 L
s
.039 .916 .04 r
.71944 .14415 m
.75691 .14365 L
s
0 0 0 r
2 Mabswid
.71944 .14415 Mdot
.75691 .14365 Mdot
0 g
.5 Mabswid
.75687 .15061 m
.75641 .14301 L
s
.75641 .14301 m
.75468 .14076 L
s
.75468 .14076 m
.75294 .13851 L
s
.75734 .15823 m
.75687 .15061 L
s
.75294 .13851 m
.75121 .13625 L
s
.7629 .17261 m
.75246 .15919 L
s
.763 .17257 m
.75257 .15915 L
s
.75121 .13625 m
.75121 .13625 L
s
.039 .916 .04 r
.75705 .1552 m
.93386 .12349 L
s
0 0 0 r
2 Mabswid
.75705 .1552 Mdot
0 g
.5 Mabswid
.7578 .16588 m
.75734 .15823 L
s
0 0 0 r
2 Mabswid
.93386 .12349 Mdot
0 g
.5 Mabswid
.7578 .16588 m
.7578 .16588 L
s
0 0 0 r
2 Mabswid
.9349 .13387 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[343]:=",
  ImageSize->{400.125, 190.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_PP10`40000100000?oooljfYKjn_W61
TEeMGM;BdUfMXFUYJBa<D87NhUeE`]Yae[:QX@00@210`T21o`000000E@00ZP00o`0l000lE@0lZP0l
o`1m001mE@1mZP1mo`2n002nE@2nZP2no`3o003oE@3oZP3ooc`003`0EC`0ZS`0oc`l03`lEC`lZS`l
ocam03amECamZSamocbn03bnECbnZSbnocco03coECcoZScoogd007d0EGd0ZWd0ogdl07dlEGdlZWdl
ogem07emEGemZWemogfn07fnEGfnZWfnoggo07goEGgoZWgookh00;h0EKh0Z[h0okhl0;hlEKhlZ[hl
okim0;imEKimZ[imokjn0;jnEKjnZ[jnokko0;koEKkoZ[koool00?l0EOl0Z_l0ooll0?llEOllZ_ll
oomm0?mmEOmmZ_mmoonn0?nnEOnnZ_nnoooo0?ooEOooZ_oooeEEELh0003>0<k>0000c/h0cP3>c^KV
iTa<C<k>c_[jnWemOHf=SM[JfZ4PlZj^[WUiNL;2`^[ZjW5aLH40030`IFEUcX61PIVIo`00PB0P89T0
IH610021PD2IY@0d?0210?mU<?mUcQQMIBP`:65QHE1@D8F=Q@1a003V0?oocP00kUDHRJFUYIVIV@00
<000I@00V@0`000`<00`I@0`V@0`cP0`o`1U001U<01UI@1UV@1UcP1Uo`2I002I<02II@2IV@2IcP2I
o`3><03>I@3>V@3>o`3o<03oI@3oV@3ocS000300<300IC00VC00cS00oc0`030`<30`VC0`cS0`oc1U
031U<31UIC1UVC1UcS1Uoc2I032I<32IIC2IVC2IcS2Ioc3>033><33>IC3>VC3>cS3>oc3o033o<33o
IC3oVC3ocS3oofD006D0<6D0IFD0VFD0cVD0ofD`06D`<6D`IFD`VFD`cVD`ofEU06EU<6EUIFEUVFEU
ofFI06FI<6FIIFFIVFFIcVFIofG>06G><6G>IFG>VFG>c_mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?md:7@44FEd003oM2Ad1A4017@A4A5TM000og@PM0DA1G@24@03M14A069d003oM1ad1A49M08A
0W@00a5dM013M08A6g@00?md5g@64@ed0Q42M08A@g@28@034GAd01Ud003oM1=d1A4BM0044G@AM0<A
?7@01QdQ7B4M8Aid003oM0md1A4FM0034G@A008A00=d4G@0=W@58BAd003oM0]d1A4HM00Z8AdA7A4M
4AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M8AdQ7B4M47@01R4M8AdQ7BUd003oM0Id1A4AM0`Q
0a401W@AM15d4B5d8b424AYd003oM09d1A49M00<8AdQ7B4M8AdQ7B4M2G@34@9d00LAM15d4G@A02Id
00HM8AdQ7B4IM0034GAd01Qd003mM0DA1W@24@DQ4g@34@Ed11400g@AM00PM0DQ>W@00?Ud1A46M006
7B4M8G@A5G@34@Qd1Q4LM0057B4M8Ad0?g@00?Ad1A47M0@Q67@44@dQ0a4FM0HQA7@00?1d1A48M003
8AdQ01Yd0Q4011dQM14:M08A00Yd4A4A7B4M8AdQ2g@01B4M8AdQ04Yd003/M0DA27@48AYd0a428@id
00HAM14AM146M0/QCg@00>Qd1A48M0048AdQ7Aad0a400adQM00?M0044G@A4@9d00<AM7@00g@02adQ
7B4MM1dQ7B4M04md003SM0DA2W@38Aed0a400g@Q8@0BM0034G@A008A00=d8B40124;M0HQBG@00=md
1A4:M0047B4M8Aid0a42M0038GAd019d00LA8AdQ4B4A01Id00HQ7B4M8Ae3M000fg@54@]d0b4OM0<A
0g@28A9d12444@03M15d01]d1B4nM000eg@44@ad00@Q7B4M87@34@=d00<Q7G@03g@0124M8Ad44@9d
0Q400g@AM00PM0067B4M8AdQ>7@00=9d1A4<M0@Q8G@34@Ad0R4=M0DQ1147M0034G@A02Md1R4bM000
cW@54@ed0Q400aedM00QM0<A1G@00aedM009M0047B4M8@DA2g@00a5d4@0]M0057B4M8Ad0;G@00<Yd
1A4?M08Q00=d4G@087@34@Id0R47M0DQ1A4?M0<A<W@68BMd0036M0@A4G@00b4M8@0SM0<A1W@00adQ
M004M0058AdQ7G@01A4CM0<A>7@01R4M8AdQ7B5d0031M0DA4g@28B=d0a47M0038A4A009d12400g@A
4@044AEd0Q50M0DQ77@00;ed1A4DM0037B4M029d0a48M0087B5d8A4Q7G@64AMd0Q57M0067B4M8AdQ
5W@00;Ud1A4EM0<Q8g@34@Ud00@QM24Q0W@54AQd0a5?M0HQ0W@24@ad002dM0DA67@00b4MM00RM0<A
2W@0124M8Ad54AYd0a5GM0047B4M4@ad002`M0DA6G@38B=d0a4:M0<Q114KM0<AJW@00:ad1A4KM003
7B5d029d0a4;M0038AdQ00<A77@34Fad002XM0@A7G@38B=d0a49M08A0b400a5dM00LM08AKg@00:=d
1A4OM0038Aed029d0a49M0<A00<Q7G@07W@34G5d002OM0DA87@38B=d0a47M0@A124NM0<ALg@009]d
1A4RM0037B5d029d0a46M0DA00Ed7B4M8@0MM0<AMW@009Md114TM0<Q8g@34@Ad1Q42M0@Q7G@34GQd
002BM0DA9G@00adQ7@0SM0<A17@54@=d00DQ7B4M8@0MM08ANg@008id1A4WM08Q97@24@=d1A45M08Q
0W@00b5dM00JM0<AOG@008Yd1A4XM0038AdQ02=d0a400g@A4@034@Id00<M8Ad00W@00b4MM00JM0<A
Og@008Id114[M08Q97@84@Md0R43M08Q6g@24H9d0021M0DA;7@00adQ7@0SM0LA2G@00adQM002M003
8Aed01Ud0a64M000OG@54Bid0R4SM0HA2W@38@Ad00<QM7@067@24HMd001iM0@A<7@00b4M8@0RM0DA
2G@24@03M24M00Ed00<M8G@05g@34HUd001eM0@A<W@28B5d1A4=M0038A4Q00Ed0R4HM0<ARg@0071d
1A4cM0037B4M021d1Q4;M0047B4M8@Id00<M8G@05g@24Hid001/M0DA=G@28Amd1a4;M0<Q27@28AMd
0a6@M000J7@44CMd00<Q7B407G@54@04M14A4@Yd00<M8Ad02G@24AMd0Q6CM000I7@44CQd0b4LM0DA
0W@34@Ud1248M0@Q00=d4G@04g@34IEd001OM0DA>W@00adQM00KM0@A17@24@Ud00<Q7B402G@00b4M
8@0HM0<AUg@005]d1A4kM0<Q6W@54@Ad0a48M0<Q27@48AUd0Q6JM000Eg@44Cid00<Q7G@067@54@Id
0Q47M0047B4M8@Md00@Q7B4M6W@34Iad001CM0@A?g@38AMd1A47M0<A1W@38@Qd0b4LM0<AWW@004id
1A51M0037B5d01Ed1A49M08A1W@00adQ7@07M0047B4M8Aad0a6QM000BW@44D=d0b4EM0@A2W@34@Ad
1247M0<Q7W@34J=d0016M0@AAG@00b4MM00CM0DA2W@34@Ad00<Q7B401g@0124M8AdOM08AYW@0049d
1156M0<Q4W@54@ad0a42M0@Q1g@38B1d0a6XM000?g@34DMd00<Q7B404G@54@ed0a42M0037B4M00Md
00@M8AdQ8G@34JYd000oM0<AAG@28A5d114?M0<A00Ad8B4Q1g@38B=d0Q6]M000?g@44D5d00<M8Ad0
3g@44A1d0a40124M8Ad6M0048AdQ7B=d0a6_M000?g@24@03M14A03id0R4>M0DA4G@24@<Q1W@48BEd
0Q6bM000?g@24@9d0Q4jM0038AdQ00ad1A4BM08A00<Q7B401W@00adQ7@0VM0<A]7@003md0Q43M08A
=g@28@ad114DM0@Q1G@48BMd0a6fM000?g@24@Ad0Q4cM0037B4M00Yd114EM0037B4M00Id00<Q7B40
:G@24KUd000nM08A1W@24C1d0R49M0@A5W@38@Ed124YM0<A^g@003id0Q47M0034GAd02]d00<Q7B40
1g@54AEd00DQ7B4M4@04M0037B4M02]d0Q6nM000?W@24@Qd00<AM7@09g@38@Md114FM0<Q0Q43M0@Q
:g@34L1d000nM08A2G@00a5dM00TM0037B5d00Ed114FM0047B4M8@<A00Ed7B4M8@0]M0<A`W@003id
0Q4:M0034GAd021d0b44M0@A5g@38@05M14A4G@00b4_M08AaG@003id0Q4;M0034GAd01ed00<Q7G@0
0W@54AMd00<M8Ad00W@24@048AdQ7Bmd0a77M000?W@24@ad00<AM7@06G@38@9d114GM0@Q0W@24@<Q
<G@24LYd000nM0<A37@24AMd00<M8G@0114HM0038AdQ00Ad00@M8AdQ<W@24Lad000nM08A00=d4G@0
2g@24A=d0R444AUd0b44M0<Q<g@34Lid000nM08A0W@00a5dM00:M08A47@44AUd00@M8AdQ0g@0124M
8AddM08AdG@003id0Q43M0034GAd00Yd0Q4;M0DA6G@38@Ad0b424C=d0a7CM000?W@24@Ad00<AM7@0
2G@34@Md114JM0037B4M00=d00@M8AdQ0Q4dM0<AeG@003id0Q45M0034GAd00Md00<AM7@00Q42M0@A
0R4HM0@Q0W@48@04M14A4CAd0Q7HM000?G@00a5d4@06M0034GAd00Id00<AM7@011400adQ7@0HM003
8AdQ00=d00<Q7B400g@24CAd0a7JM000?G@00a5d4@07M0034GAd00Ad1142M08Q5g@48@9d1243M0<A
=7@24Med000mM0034G@A00Qd00<AM7@01A401G@Q7B5d008A4g@00adQ7@03M0037B4M00Ed0Q4dM0<A
gg@003ed00<AM1401g@44@9d0Q428@Ed0Q4?M0<Q0W@48@Ed0a4dM0<AhG@003ed0Q44M0@A0g@0115d
7B424@Md0a49M0048AdQ7@9d00<Q7B401g@24CEd0Q7TM000?G@64@Md00<Q4G@00W@00a5dM006M003
4G@A00Ed0b42M0@Q1g@34CAd0a7VM000?G@34@Qd00@M8G@A0g@00a5dM007M0074G@AM24M8@02M003
7B4M00Qd0a4eM08AjG@003id00<AM14017@38@Ad00@AM7@A2G@48@03M24Q008Q2G@24CId0Q7[M000
?g@24@9d00<Q7G@01g@24@Md00PM8Aed7B4M8@Yd0a4eM0<AkG@0041d0Q400b5dM009M0034GAd009d
0b4017@Q8B42M0044G@A4@Id0Q4fM08Al7@003id00<M8Ad00Q4;M0094B4M8AdQ7B4M00Id00@AM7@A
0W@34CEd0a7bM000?7@28@Ad0Q48M08A00<QM1400Q4;M0034GAd008A=W@24OEd000jM0037B5d00Md
00TAM7Ad7B4M8Ad00Q40125d4A4<M0<A=G@24OMd000gM0<Q2g@00a4Q8@048@9d00<AM7@00W@00a5d
M009M0034G@A039d0a7iM000=G@00b4MM009M0058AdQ7B400Q46M0034GAd00=d00<AM7@027@24C5d
0Q7lM000<g@28@Ud1R43M08A1G@00a5dM004M0034GAd00Md0Q4^M0<AoW@0031d00<M8Ad01g@01QdQ
7B4M8@Qd0Q44M0034GAd00Ed00<AM7@01W@24Bad0a7oM05d000^M08Q1g@68@ad0Q43M0034GAd00Id
0Q46M08A:W@24Omd17@002ad00<M8G@017@01R4M8AdQ7A5d0Q42M0034GAd00Qd00<AM7@00g@24BMd
0a7oM0Id000YM0<Q17@58AId0Q400g@AM00:M0034GAd009d0Q4UM08Aog@9M0009g@00b4MM002M005
7B4M8Ad06g@34@ad0Q42M08A8W@34Omd2g@002Ed0R42M0DQ7g@24@id00@AM14A87@34Omd3G@0029d
00PM8AdQ7B4M8BEd00<AM7@037@34Aid0Q7oM11d000PM0HQ:W@00a5dM00<M08A6g@34Omd4W@001id
00@M8AdQ;g@24@ad0Q4IM08Aog@EM00077@28CAd0Q4:M0034G@A01Md0Q7oM1Md001CM08A2G@00a5d
4@0DM0<Aog@IM000E7@24@Qd00<AM1404W@24Omd77@005Ed0Q47M0034G@A00md0a7oM1id001FM08A
1W@00a5d4@0=M08Aog@QM000Eg@24@Ed00<AM1402g@24Omd8g@005Qd0Q44M0034G@A00Qd0a7oM2Ed
001JM08A0W@00a5d4@06M08Aog@XM000Fg@24@04M15d4@=d0a7oM2Yd001LM0<A00=d4G@00Q7oM2ed
001MM0DAog@_M000GW@34Omd<7@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?md
TG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00?mdTG@00001\
\>"],
  ImageRangeCache->{{{0, 399.125}, {189.75, 0}} -> {0.0288345, 0.251405, 
  0.00243697, 0.00243697}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{866, 550},
WindowMargins->{{Automatic, 115}, {115, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 54, 0, 57, "Chapter"],

Cell[CellGroupData[{
Cell[1788, 53, 36, 0, 38, "SubsectionIcon"],
Cell[1827, 55, 285, 5, 40, "Text"],
Cell[2115, 62, 92, 2, 26, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2244, 69, 41, 0, 28, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2310, 73, 46, 0, 24, "SubsubsectionIcon"],
Cell[2359, 75, 230, 7, 96, "Input"],
Cell[2592, 84, 230, 11, 164, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2859, 100, 43, 0, 20, "SubsubsectionIcon"],
Cell[2905, 102, 169, 4, 24, "Text"],
Cell[3077, 108, 454, 23, 368, "Input"],
Cell[3534, 133, 481, 23, 368, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4052, 161, 43, 0, 20, "SubsubsectionIcon"],
Cell[4098, 163, 126, 3, 24, "Text"],
Cell[4227, 168, 463, 23, 368, "Input"],
Cell[4693, 193, 468, 23, 368, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5210, 222, 34, 0, 28, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[5269, 226, 161, 4, 28, "Input"],
Cell[5433, 232, 30982, 1255, 169, 23380, 1156, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36452, 1492, 166, 5, 28, "Input"],
Cell[36621, 1499, 30954, 1311, 144, 25268, 1236, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67612, 2815, 162, 4, 28, "Input"],
Cell[67777, 2821, 34217, 1411, 213, 26887, 1315, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102031, 4237, 163, 4, 28, "Input"],
Cell[102197, 4243, 36264, 1401, 213, 25678, 1265, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138498, 5649, 159, 4, 28, "Input"],
Cell[138660, 5655, 46872, 1689, 313, 27309, 1442, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185569, 7349, 152, 4, 28, "Input"],
Cell[185724, 7355, 39467, 1406, 261, 21277, 1176, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[225240, 8767, 42, 0, 28, "SubsectionIcon"],
Cell[225285, 8769, 67, 1, 28, "Input"],
Cell[225355, 8772, 330, 6, 79, "Input"],
Cell[225688, 8780, 594, 16, 249, "Input"],
Cell[226285, 8798, 649, 24, 385, "Input"],

Cell[CellGroupData[{
Cell[226959, 8826, 126, 2, 26, "Input"],
Cell[227088, 8830, 8194, 342, 141, 3287, 276, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235319, 9177, 198, 7, 96, "Input"],
Cell[235520, 9186, 12374, 496, 197, 4665, 396, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

