(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1373487,      27018]
NotebookOptionsPosition[   1161994,      22148]
NotebookOutlinePosition[   1333936,      26034]
CellTagsIndexPosition[   1331116,      25949]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["6. Visualizing Your System", "Subtitle",
 CellTags->{
  "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
   "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
   "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
   "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
   "PR6.8", "PR6.10"}],

Cell[TextData[ButtonBox["6.1 Introduction",
 BaseStyle->"Hyperlink",
 ButtonData:>"6.1"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.2 Adjusting Graphics",
 BaseStyle->"Hyperlink",
 ButtonData:>"6.2"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{"Adjusting Graphics", "PR6.2"}],

Cell[TextData[{
 ButtonBox["6.2.1 Magnifying Graphics",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.2.1"],
 "\n",
 ButtonBox["6.2.2 Manual Graphics Control",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.2.2"],
 "\n",
 ButtonBox["6.2.3 Custom Graphics",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.2.3"],
 "\n",
 ButtonBox["6.2.4 Interactive 3D Graphics and Stereo Graphics",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.2.4"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],

Cell[TextData[{
 ButtonBox["6.3 ShowText",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.3"],
 "\n",
 ButtonBox["6.4 ShowRange",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.4"],
 "\n",
 ButtonBox["6.5 ColorView",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.5"],
 "\n",
 ButtonBox["6.6 RayChoice",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.6"],
 "\n",
 ButtonBox["6.7 OutputType",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.7"],
 "\n",
 ButtonBox["6.8 LineStyle and FillStyle\n",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.8"],
 ButtonBox["6.9 Other Rendering Options",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.9"],
 "\n",
 ButtonBox["6.10 ModelRayColor",
  BaseStyle->"Hyperlink",
  ButtonData:>"6.10"]
}], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellChangeTimes->{{3.5661601285819197`*^9, 3.566160156459993*^9}, {
  3.614730458531764*^9, 3.614730460769747*^9}}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.11 Labelling of Components",
 BaseStyle->"Hyperlink",
 ButtonData:>"6.11"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{"Labelling of Components", "PR6.11"}],

Cell[TextData[ButtonBox["6.11.1 Labelling Your Printed Output",
 BaseStyle->"Hyperlink",
 ButtonData:>"6.11.1"]], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{"Labelling of Components", "PR6.11"}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.11.2 Labelling Your Graphics",
 BaseStyle->"Hyperlink",
 ButtonData:>"6.11.2"]], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],

Cell[TextData[{
 ButtonBox["Numbering Your Labels\n",
  BaseStyle->"Hyperlink",
  ButtonData:>"Numbering Your Labels"],
 "Optica",
 ButtonBox["'s Default Treatment of Labels",
  BaseStyle->"Hyperlink",
  ButtonData:>"Rayica's Default Treatment of Labels"],
 "\n",
 ButtonBox["Placement of Your Labels",
  BaseStyle->"Hyperlink",
  ButtonData:>"Placement of Your Labels"],
 "\n",
 ButtonBox["Labels with Resonate",
  BaseStyle->"Hyperlink",
  ButtonData:>"Labels with Resonate"],
 "\n",
 ButtonBox["The Labels Option",
  BaseStyle->"Hyperlink",
  ButtonData:>"The Labels Option"],
 "\n",
 ButtonBox["Surpressing Labels",
  BaseStyle->"Hyperlink",
  ButtonData:>"Surpressing Labels"]
}], "Outline4",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellChangeTimes->{3.566158951109707*^9},
 CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.1 Introduction", "Section",
 PageBreakAbove->True,
 CellTags->{"6.1", "6.1 Introduction", "PR6.1"}],

Cell["\<\
Ray-tracing is independent of graphical output.  Optica uses exact surface \
equations for ray-tracing.  Yet for rendering  purposes, Optica employs \
visual approximations.  You can produce the same analysis using  fine \
graphics, rough graphics, or no graphics at all.  Moreover, individual  \
components can be rendered at different levels of graphic quality.\
\>", "Text",
 CellChangeTimes->{{3.56615895120395*^9, 3.566158951288867*^9}},
 CellTags->{"6.1 Introduction", "PR6.1"}],

Cell[TextData[{
 StyleBox["In this chapter, we discuss in more detail the various rendering \
options of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". Typically, you first perform a ray-tracing operation by \
evaluating ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[". This process can be quite slow in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 "Optica",
 StyleBox[". After this initial ray-tracing step, you can examine various \
parameter characteristics very quickly using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" shares its options with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[". In this chapter, we will examine the use of some of these \
options.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.566158951389738*^9},
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],

Cell[CellGroupData[{

Cell["Options[AnalyzeSystem]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"},
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"AddLabels", "\[Rule]", "AddLabels"}], ",", 
   RowBox[{"AppendGraphics", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
   RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
   RowBox[{"ColorView", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"CreateClones", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"CreateStereoView", "\[Rule]", "False"}], ",", 
   RowBox[{"FilterTrace", "\[Rule]", "False"}], ",", 
   RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
   RowBox[{"GraphicDesign", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"GraphicsSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.25`"}], ",", "0"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "None"}], ",", 
   RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"LabelOffset", "\[Rule]", "0.04`"}], ",", 
   RowBox[{"MinimumArrowLength", "\[Rule]", 
    FractionBox["Max", "20"]}], ",", 
   RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
   RowBox[{"MoveRayLabels", "\[Rule]", "MoveRayLabels"}], ",", 
   RowBox[{"OutputType", "\[Rule]", "OpticalSystem"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "15"}], ",", 
   RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
   RowBox[{"PrependGraphics", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
   RowBox[{"RayChoice", "\[Rule]", "All"}], ",", 
   RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"RayShowLabels", "\[Rule]", "False"}], ",", 
   RowBox[{"ReplaceGraphics", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
   RowBox[{"ReverseStereoLayers", "\[Rule]", "False"}], ",", 
   RowBox[{"SequentialTrace", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ShowArrows", "\[Rule]", "100"}], ",", 
   RowBox[{"ShowClones", "\[Rule]", "True"}], ",", 
   RowBox[{"ShowComponents", "\[Rule]", "True"}], ",", 
   RowBox[{"ShowGaussian", "\[Rule]", "False"}], ",", 
   RowBox[{"ShowLabels", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ShowRange", "\[Rule]", "All"}], ",", 
   RowBox[{"ShowRays", "\[Rule]", "True"}], ",", 
   RowBox[{"SingleStereoImage", "\[Rule]", "True"}], ",", 
   RowBox[{"StereoViewAngle", "\[Rule]", "5"}], ",", 
   RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
   RowBox[{"TracingEngine", "\[Rule]", "PropagateSystem"}], ",", 
   RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FormatType", "\[RuleDelayed]", "$FormatType"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.563367779277594*^9, 3.566158863936596*^9, 
  3.566158963330174*^9, 3.5672682967830677`*^9, 3.614729563120064*^9, 
  3.614730558633729*^9, 3.6147317315350657`*^9},
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"},
 CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["In addition to the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem/ShowSystem", "Input"],
 StyleBox[" options, you can use any of the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" or ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Graphics3D",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" options for rendering. In this way, you can include labels and \
titles with the rendered objects. For the rest of this section, we examine \
the rendering options uniquely associated with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 "Optica",
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.566158951489873*^9},
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Adjusting Graphics", "Section",
 CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[TextData[{
 "Sometimes a component's graphics do not seem to match the underlying  \
model.  When such a mismatch presents itself, bear in mind the distinction  \
between models and graphics.  You may be tempted to alter your model merely  \
for the sake of graphics.  This approach is mistaken.  Instead, use  \
designated graphics options.  ",
 "Optica",
 " includes a variety of tools for adjusting graphics.  For example, here is  \
a ",
 StyleBox["SphericalLens", "MB"],
 " with ",
 StyleBox["PlotPoints\[Rule]30", "MB"],
 "."
}], "Text",
 CellChangeTimes->{3.5661589515900717`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LineOfRays", "[", 
       RowBox[{"40", ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "7"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalLens", "[", 
         RowBox[{"30", ",", 
          RowBox[{"-", "30"}], ",", "50", ",", "40"}], "]"}], ",", "10"}], 
       "]"}], ",", 
      RowBox[{"Boundary", "[", "75", "]"}]}], "\[IndentingNewLine]", "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"RayPointSize", "\[Rule]", "4"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotPoints", "\[Rule]", "30"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5661588904719687`*^9, 3.566158895071653*^9}},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"},
 CellLabel->"In[3]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{23.416876048223, -25.}, {36.583123951777, -25.}, {
      41.586389744981034`, -20.83333333333333}, {
      18.41361025501897, -20.833333333333336`}, {23.416876048223, -25.}}], 
     PolygonBox[{{18.41361025501897, -20.833333333333336`}, {
      41.586389744981034`, -20.83333333333333}, {
      44.94438257849295, -16.666666666666664`}, {
      15.055617421507058`, -16.666666666666668`}, {
      18.41361025501897, -20.833333333333336`}}], 
     PolygonBox[{{15.055617421507058`, -16.666666666666668`}, {
      44.944382578492934`, -16.66666666666667}, {47.27178028658929, -12.5}, {
      12.728219713410713`, -12.5}, {
      15.055617421507058`, -16.666666666666668`}}], 
     PolygonBox[{{12.728219713410713`, -12.5}, {47.27178028658929, -12.5}, {
      48.81936077631764, -8.333333333333329}, {
      11.180639223682363`, -8.333333333333336}, {
      12.728219713410713`, -12.5}}], 
     PolygonBox[{{11.180639223682363`, -8.333333333333336}, {
      48.81936077631764, -8.333333333333336}, {
      49.70923911662648, -4.166666666666668}, {
      10.290760883373519`, -4.166666666666668}, {
      11.180639223682363`, -8.333333333333336}}], 
     PolygonBox[{{10.290760883373519`, -4.166666666666668}, {
      49.70923911662648, -4.166666666666668}, {50., 0.}, {
      10., -3.552713678800501*^-15}, {
      10.290760883373519`, -4.166666666666668}}], 
     PolygonBox[{{10., 0.}, {50., 0.}, {49.70923911662648, 
      4.166666666666664}, {10.290760883373519`, 4.166666666666668}, {10., 
      0.}}], PolygonBox[{{10.290760883373519`, 4.166666666666664}, {
      49.70923911662648, 4.166666666666664}, {48.81936077631764, 
      8.333333333333329}, {11.180639223682359`, 8.333333333333329}, {
      10.290760883373519`, 4.166666666666664}}], 
     PolygonBox[{{11.180639223682359`, 8.333333333333329}, {48.81936077631764,
       8.333333333333332}, {47.27178028658929, 12.499999999999996`}, {
      12.728219713410713`, 12.5}, {11.180639223682359`, 8.333333333333329}}], 
     PolygonBox[{{12.728219713410713`, 12.5}, {47.27178028658929, 12.5}, {
      44.94438257849295, 16.666666666666664`}, {15.055617421507062`, 
      16.66666666666667}, {12.728219713410713`, 12.5}}], 
     PolygonBox[{{15.055617421507055`, 16.666666666666664`}, {
      44.94438257849295, 16.666666666666664`}, {41.586389744981034`, 
      20.83333333333333}, {18.413610255018966`, 20.83333333333333}, {
      15.055617421507055`, 16.666666666666664`}}], 
     PolygonBox[{{18.413610255018966`, 20.83333333333333}, {
      41.586389744981034`, 20.833333333333332`}, {36.583123951777004`, 
      24.999999999999996`}, {23.416876048223, 25.}, {18.413610255018966`, 
      20.83333333333333}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQXT+rMXlHlrkDAxhYHjg4Y1rMo0wjh7BQILhqcuDO
6z+PKmX0HFavAgGDA5PO3jK7WaLpwAhWr3kgQa9nX02MmsMasLzCAQtxrzn3
pqg4bADzBQ5AzFWBmv9hjxlUfgVE3iEOqh/CV3CYADX/z38Q0HC4AbUfIm/g
cADqvhCI+xxqoe7/B1Zv4XDAyP7cYi8nmH8cFmzecpHvtAvMPw6cRx3aH1a4
wfzjMMfHc9PJRe4w/zhkfIm58CDDA+YfB6OqtxEnbnnA/AM11xPmHxuYPNQ/
B2D6of45ADMf6p8DXFD7of45AHMf1D8HDkHdD/XPAfT4AQCFRsdt
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{23.416876048223, 0.}, {36.583123951777, 
        3.061616997868383*^-15}, {41.586389744981034`, 
        2.8064822480460174`*^-15}, {18.41361025501897, 
        2.5513474982236524`*^-16}, {23.416876048223, 0.}}], 
       PolygonBox[{{18.41361025501897, 2.5513474982236524`*^-16}, {
        41.586389744981034`, 2.8064822480460174`*^-15}, {44.94438257849295, 
        2.5513474982236525`*^-15}, {15.055617421507058`, 
        5.102694996447305*^-16}, {18.41361025501897, 
        2.5513474982236524`*^-16}}], 
       PolygonBox[{{15.055617421507058`, 5.102694996447305*^-16}, {
        44.944382578492934`, 2.551347498223653*^-15}, {47.27178028658929, 
        2.296212748401287*^-15}, {12.728219713410713`, 
        7.654042494670958*^-16}, {15.055617421507058`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{12.728219713410713`, 7.654042494670958*^-16}, {
        47.27178028658929, 2.296212748401287*^-15}, {48.81936077631764, 
        2.041077998578922*^-15}, {11.180639223682363`, 
        1.020538999289461*^-15}, {12.728219713410713`, 
        7.654042494670958*^-16}}], 
       PolygonBox[{{11.180639223682363`, 1.020538999289461*^-15}, {
        48.81936077631764, 2.0410779985789223`*^-15}, {49.70923911662648, 
        1.785943248756557*^-15}, {10.290760883373519`, 
        1.2756737491118262`*^-15}, {11.180639223682363`, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{10.290760883373519`, 1.2756737491118262`*^-15}, {
        49.70923911662648, 1.785943248756557*^-15}, {50., 
        1.5308084989341915`*^-15}, {10., 1.5308084989341913`*^-15}, {
        10.290760883373519`, 1.2756737491118262`*^-15}}], 
       PolygonBox[{{10., 1.5308084989341915`*^-15}, {50., 
        1.5308084989341915`*^-15}, {49.70923911662648, 
        1.2756737491118264`*^-15}, {10.290760883373519`, 
        1.785943248756557*^-15}, {10., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{10.290760883373519`, 1.7859432487565566`*^-15}, {
        49.70923911662648, 1.2756737491118264`*^-15}, {48.81936077631764, 
        1.0205389992894613`*^-15}, {11.180639223682359`, 
        2.041077998578922*^-15}, {10.290760883373519`, 
        1.7859432487565566`*^-15}}], 
       PolygonBox[{{11.180639223682359`, 2.041077998578922*^-15}, {
        48.81936077631764, 1.0205389992894611`*^-15}, {47.27178028658929, 
        7.65404249467096*^-16}, {12.728219713410713`, 
        2.296212748401287*^-15}, {11.180639223682359`, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{12.728219713410713`, 2.296212748401287*^-15}, {
        47.27178028658929, 7.654042494670958*^-16}, {44.94438257849295, 
        5.102694996447306*^-16}, {15.055617421507062`, 
        2.551347498223653*^-15}, {12.728219713410713`, 
        2.296212748401287*^-15}}], 
       PolygonBox[{{15.055617421507055`, 2.5513474982236525`*^-15}, {
        44.94438257849295, 5.102694996447308*^-16}, {41.586389744981034`, 
        2.551347498223655*^-16}, {18.413610255018966`, 
        2.8064822480460174`*^-15}, {15.055617421507055`, 
        2.5513474982236525`*^-15}}], 
       PolygonBox[{{18.413610255018966`, 2.8064822480460174`*^-15}, {
        41.586389744981034`, 2.551347498223654*^-16}, {36.583123951777004`, 
        1.2746541313564603`*^-31}, {23.416876048223, 
        3.061616997868383*^-15}, {18.413610255018966`, 
        2.8064822480460174`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQXT+rMXlHlrkDAxQcnDEt5lGmEZx/5/WfR5UyenD+
pLO3zG6WaML5CXo9+2pi1OB8C3GvOfemqMD5EIDgm6HJx6Hpn4Bm/g00+w+g
ua8Wzf0HjOzPLfZygvMXbN5yke+0C5zPedSh/WGFG5w/x8dz08lF7nB+xpeY
Cw8yPOB8o6q3ESduIfgQ4IlTHl0/uvlcaPaju+8QmvvR4wcAejxiGA==
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{23.416876048223, 25.}, {36.583123951777, 25.}, {
       36.583123951777, 24.78612153434526}, {23.416876048223, 
       24.78612153434526}, {23.416876048223, 25.}}], 
      LineBox[{{23.416876048223, 24.78612153434526}, {36.583123951777, 
       24.78612153434526}, {36.583123951777, 24.148145657226706`}, {
       23.416876048223, 24.148145657226706`}, {23.416876048223, 
       24.78612153434526}}], 
      LineBox[{{23.416876048223, 24.148145657226706`}, {36.583123951777, 
       24.148145657226706`}, {36.583123951777, 23.09698831278217}, {
       23.416876048223, 23.09698831278217}, {23.416876048223, 
       24.148145657226706`}}], 
      LineBox[{{23.416876048223, 23.09698831278217}, {36.583123951777, 
       23.09698831278217}, {36.583123951777, 21.65063509461097}, {
       23.416876048223003`, 21.65063509461097}, {23.416876048223, 
       23.09698831278217}}], 
      LineBox[{{23.416876048223003`, 21.65063509461097}, {36.583123951777, 
       21.65063509461097}, {36.583123951777, 19.833833507280882`}, {
       23.416876048223003`, 19.833833507280882`}, {23.416876048223003`, 
       21.65063509461097}}], 
      LineBox[{{23.416876048223003`, 19.833833507280882`}, {36.583123951777, 
       19.833833507280882`}, {36.583123951777004`, 17.67766952966369}, {
       23.416876048222996`, 17.67766952966369}, {23.416876048223003`, 
       19.833833507280882`}}], 
      LineBox[{{23.416876048222996`, 17.67766952966369}, {36.583123951777004`,
        17.67766952966369}, {36.583123951777, 15.219035725218017`}, {
       23.416876048223003`, 15.219035725218017`}, {23.416876048222996`, 
       17.67766952966369}}], 
      LineBox[{{23.416876048223003`, 15.219035725218017`}, {36.583123951777, 
       15.219035725218017`}, {36.583123951777, 12.500000000000004`}, {
       23.416876048223003`, 12.500000000000004`}, {23.416876048223003`, 
       15.219035725218017`}}], 
      LineBox[{{23.416876048223003`, 12.500000000000004`}, {36.583123951777, 
       12.500000000000004`}, {36.583123951777, 9.567085809127246}, {
       23.416876048223, 9.567085809127246}, {23.416876048223003`, 
       12.500000000000004`}}], 
      LineBox[{{23.416876048223, 9.567085809127246}, {36.583123951777, 
       9.567085809127246}, {36.583123951777004`, 6.4704761275630185`}, {
       23.416876048222996`, 6.4704761275630185`}, {23.416876048223, 
       9.567085809127246}}], 
      LineBox[{{23.416876048223, 6.470476127563024}, {36.583123951777, 
       6.470476127563024}, {36.583123951777, 3.263154805501293}, {
       23.416876048223, 3.263154805501293}, {23.416876048223, 
       6.470476127563024}}], 
      LineBox[{{23.416876048223, 3.263154805501293}, {36.583123951777, 
       3.263154805501293}, {36.583123951777, 1.5308084989341915`*^-15}, {
       23.416876048223, 1.5308084989341915`*^-15}, {23.416876048223, 
       3.263154805501293}}], 
      LineBox[{{23.416876048223, 1.5308084989341915`*^-15}, {36.583123951777, 
       1.5308084989341915`*^-15}, {36.583123951777, -3.2631548055012902`}, {
       23.416876048223, -3.2631548055012902`}, {23.416876048223, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{23.416876048223, -3.2631548055012845`}, {
       36.583123951777, -3.2631548055012845`}, {
       36.583123951777004`, -6.470476127563016}, {
       23.416876048222996`, -6.470476127563016}, {
       23.416876048223, -3.2631548055012845`}}], 
      LineBox[{{23.416876048222996`, -6.470476127563016}, {
       36.583123951777004`, -6.470476127563016}, {
       36.583123951777, -9.567085809127244}, {
       23.416876048223, -9.567085809127244}, {
       23.416876048222996`, -6.470476127563016}}], 
      LineBox[{{23.416876048222996`, -9.567085809127237}, {
       36.583123951777004`, -9.567085809127237}, {
       36.583123951777, -12.499999999999995`}, {
       23.416876048223, -12.499999999999995`}, {
       23.416876048222996`, -9.567085809127237}}], 
      LineBox[{{23.416876048223, -12.499999999999995`}, {
       36.583123951777, -12.499999999999995`}, {
       36.583123951777, -15.219035725218008`}, {
       23.416876048223003`, -15.219035725218008`}, {
       23.416876048223, -12.499999999999995`}}], 
      LineBox[{{23.416876048223003`, -15.219035725218008`}, {
       36.583123951777, -15.219035725218008`}, {
       36.583123951777, -17.677669529663678`}, {
       23.416876048223, -17.677669529663678`}, {
       23.416876048223003`, -15.219035725218008`}}], 
      LineBox[{{23.416876048222996`, -17.677669529663685`}, {
       36.583123951777004`, -17.677669529663685`}, {
       36.583123951777, -19.833833507280875`}, {
       23.416876048223, -19.833833507280875`}, {
       23.416876048222996`, -17.677669529663685`}}], 
      LineBox[{{23.416876048223, -19.833833507280875`}, {
       36.583123951777, -19.833833507280875`}, {
       36.583123951777, -21.650635094610962`}, {
       23.416876048223003`, -21.650635094610962`}, {
       23.416876048223, -19.833833507280875`}}], 
      LineBox[{{23.416876048223003`, -21.650635094610962`}, {
       36.583123951777, -21.650635094610962`}, {
       36.583123951777004`, -23.096988312782162`}, {
       23.416876048222996`, -23.096988312782162`}, {
       23.416876048223003`, -21.650635094610962`}}], 
      LineBox[{{23.416876048223003`, -23.09698831278217}, {
       36.583123951777, -23.09698831278217}, {
       36.583123951777, -24.148145657226706`}, {
       23.416876048223, -24.148145657226706`}, {
       23.416876048223003`, -23.09698831278217}}], 
      LineBox[{{23.416876048223, -24.148145657226706`}, {
       36.583123951777, -24.148145657226706`}, {
       36.583123951777, -24.78612153434526}, {
       23.416876048223003`, -24.78612153434526}, {
       23.416876048223, -24.148145657226706`}}], 
      LineBox[{{23.416876048223003`, -24.78612153434526}, {
       36.583123951777, -24.78612153434526}, {36.583123951777, -25.}, {
       23.416876048223, -25.}, {23.416876048223003`, -24.78612153434526}}], 
      LineBox[{{23.416876048223, -25.}, {36.583123951777, -25.}, {
       36.583123951777, -24.786121534345263`}, {
       23.416876048223003`, -24.786121534345263`}, {23.416876048223, -25.}}], 
      LineBox[{{23.416876048223003`, -24.786121534345263`}, {
       36.583123951777, -24.786121534345263`}, {
       36.583123951777, -24.14814565722671}, {
       23.416876048223003`, -24.14814565722671}, {
       23.416876048223003`, -24.786121534345263`}}], 
      LineBox[{{23.416876048223003`, -24.14814565722671}, {
       36.583123951777, -24.14814565722671}, {
       36.583123951777, -23.096988312782173`}, {
       23.416876048223, -23.096988312782173`}, {
       23.416876048223003`, -24.14814565722671}}], 
      LineBox[{{23.416876048223, -23.096988312782173`}, {
       36.583123951777, -23.096988312782173`}, {
       36.583123951777, -21.650635094610976`}, {
       23.416876048223003`, -21.650635094610976`}, {
       23.416876048223, -23.096988312782173`}}], 
      LineBox[{{23.416876048223, -21.65063509461097}, {
       36.583123951777, -21.65063509461097}, {
       36.583123951777, -19.833833507280886`}, {
       23.416876048223003`, -19.833833507280886`}, {
       23.416876048223, -21.65063509461097}}], 
      LineBox[{{23.416876048223003`, -19.833833507280886`}, {
       36.583123951777, -19.833833507280886`}, {
       36.583123951777004`, -17.677669529663696`}, {
       23.416876048222996`, -17.677669529663696`}, {
       23.416876048223003`, -19.833833507280886`}}], 
      LineBox[{{23.416876048222996`, -17.677669529663696`}, {
       36.583123951777004`, -17.677669529663696`}, {
       36.583123951777004`, -15.219035725218022`}, {
       23.416876048222996`, -15.219035725218022`}, {
       23.416876048222996`, -17.677669529663696`}}], 
      LineBox[{{23.416876048222996`, -15.219035725218022`}, {
       36.583123951777004`, -15.219035725218022`}, {
       36.583123951777004`, -12.50000000000001}, {
       23.416876048222996`, -12.50000000000001}, {
       23.416876048222996`, -15.219035725218022`}}], 
      LineBox[{{23.416876048222996`, -12.50000000000001}, {
       36.583123951777004`, -12.50000000000001}, {
       36.583123951777004`, -9.567085809127258}, {
       23.416876048222996`, -9.567085809127258}, {
       23.416876048222996`, -12.50000000000001}}], 
      LineBox[{{23.416876048222996`, -9.567085809127258}, {
       36.583123951777004`, -9.567085809127258}, {
       36.583123951777, -6.470476127563038}, {
       23.416876048223003`, -6.470476127563038}, {
       23.416876048222996`, -9.567085809127258}}], 
      LineBox[{{23.416876048223003`, -6.470476127563038}, {
       36.583123951777, -6.470476127563038}, {
       36.583123951777004`, -3.2631548055013124`}, {
       23.416876048222996`, -3.2631548055013124`}, {
       23.416876048223003`, -6.470476127563038}}], 
      LineBox[{{23.416876048222996`, -3.2631548055013124`}, {
       36.583123951777004`, -3.2631548055013124`}, {
       36.583123951777, -2.6796885989305705`*^-14}, {
       23.416876048223, -2.6796885989305705`*^-14}, {
       23.416876048222996`, -3.2631548055013124`}}], 
      LineBox[{{23.416876048223, -4.592425496802574*^-15}, {
       36.583123951777, -4.592425496802574*^-15}, {36.583123951777, 
       3.263154805501282}, {23.416876048223, 3.263154805501282}, {
       23.416876048223, -4.592425496802574*^-15}}], 
      LineBox[{{23.416876048223, 3.263154805501282}, {36.583123951777, 
       3.263154805501282}, {36.583123951777, 6.470476127563007}, {
       23.416876048223, 6.470476127563007}, {23.416876048223, 
       3.263154805501282}}], 
      LineBox[{{23.416876048223, 6.470476127563007}, {36.583123951777, 
       6.470476127563007}, {36.583123951777, 9.56708580912723}, {
       23.416876048223, 9.56708580912723}, {23.416876048223, 
       6.470476127563007}}], 
      LineBox[{{23.416876048223, 9.56708580912723}, {36.583123951777, 
       9.56708580912723}, {36.583123951777, 12.499999999999984`}, {
       23.416876048223, 12.499999999999984`}, {23.416876048223, 
       9.56708580912723}}], 
      LineBox[{{23.416876048223, 12.499999999999984`}, {36.583123951777, 
       12.499999999999984`}, {36.583123951777, 15.219035725217998`}, {
       23.416876048223003`, 15.219035725217998`}, {23.416876048223, 
       12.499999999999984`}}], 
      LineBox[{{23.416876048223003`, 15.219035725217998`}, {36.583123951777, 
       15.219035725217998`}, {36.583123951777, 17.67766952966367}, {
       23.416876048223003`, 17.67766952966367}, {23.416876048223003`, 
       15.219035725217998`}}], 
      LineBox[{{23.416876048223003`, 17.677669529663685`}, {36.583123951777, 
       17.677669529663685`}, {36.583123951777004`, 19.833833507280872`}, {
       23.416876048222996`, 19.833833507280872`}, {23.416876048223003`, 
       17.677669529663685`}}], 
      LineBox[{{23.416876048222996`, 19.833833507280872`}, {
       36.583123951777004`, 19.833833507280872`}, {36.583123951777004`, 
       21.65063509461096}, {23.416876048222996`, 21.65063509461096}, {
       23.416876048222996`, 19.833833507280872`}}], 
      LineBox[{{23.416876048222996`, 21.65063509461096}, {36.583123951777004`,
        21.65063509461096}, {36.583123951777, 23.096988312782162`}, {
       23.416876048223, 23.096988312782162`}, {23.416876048222996`, 
       21.65063509461096}}], 
      LineBox[{{23.416876048223, 23.096988312782162`}, {36.583123951777, 
       23.096988312782162`}, {36.583123951777, 24.148145657226703`}, {
       23.416876048223003`, 24.148145657226703`}, {23.416876048223, 
       23.096988312782162`}}], 
      LineBox[{{23.416876048223003`, 24.148145657226703`}, {36.583123951777, 
       24.148145657226703`}, {36.583123951777004`, 24.786121534345256`}, {
       23.416876048222996`, 24.786121534345256`}, {23.416876048223003`, 
       24.148145657226703`}}], 
      LineBox[{{23.416876048222996`, 24.786121534345256`}, {
       36.583123951777004`, 24.786121534345256`}, {36.583123951777, 25.}, {
       23.416876048223, 25.}, {23.416876048222996`, 24.786121534345256`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {75., -37.5}, {75., 37.5}, {75., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {0., -37.5}, {0., -37.5}, {75., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[NCache[{{0, Rational[-75, 2]}, {0, Rational[75, 2]}, {
         0, Rational[75, 2]}, {0, Rational[-75, 2]}, {
         0, Rational[-75, 2]}}, {{0, -37.5}, {0, 37.5}, {0, 37.5}, {
         0, -37.5}, {0, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 37.5}, {75., 37.5}, {75., 37.5}, {0., 37.5}, {0., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {75., 37.5}, {0., 37.5}, {0., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {0., -37.5}, {0., 37.5}, {75., 
       37.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -20.}, {17.639320225002102`, -20.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.333333333333334`}, {
       13.125807505671503`, -13.333333333333334`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -6.666666666666668}, {
       10.750118708692924`, -6.666666666666668}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {10., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 6.666666666666664}, {10.750118708692924`, 
       6.666666666666664}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 13.333333333333329`}, {13.1258075056715, 
       13.333333333333329`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 20.}, {17.639320225002102`, 20.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{17.639320225002102`, -20.}, {
       47.70669973966436, -11.503859766881838`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.125807505671503`, -13.333333333333334`}, {
       49.07350501128092, -7.398060986435744}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.750118708692924`, -6.666666666666668}, {
       49.77777975395612, -3.6446992914205145`}}]}, 
     {Arrowheads[Small], ArrowBox[{{10., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.750118708692924`, 6.666666666666664}, {49.77777975395612, 
       3.6446992914205127`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.1258075056715, 13.333333333333329`}, {49.07350501128092, 
       7.398060986435741}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{17.639320225002102`, 20.}, {47.70669973966436, 
       11.503859766881838`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.70669973966436, -11.503859766881838`}, {75., 
       18.648852558669297`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.07350501128092, -7.398060986435744}, {75., 
       3.75203876884951}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.77777975395612, -3.6446992914205145`}, {75., 
       1.0316702129799324`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.77777975395612, 3.6446992914205127`}, {
       75., -1.0316702129799316`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.07350501128092, 7.398060986435741}, {
       75., -3.752038768849502}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.70669973966436, 11.503859766881838`}, {
       75., -18.648852558669297`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[4.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrcfXVLtqsaEDAxiYHFjwLOV6poOWw+pVIKB1IOGF
cT9/g6rDGjBf6gBEnQpUPQMDTH4FRN5hHlQ/hK/lgGa+w7yfYsqlt9wddPg8
X/xkVD8w/ejOORmdHg7hFrN85k6XPXAwttyz77GHQ56dslSEBi/UPk+4fTD5
LIi8A0x/CEQ/uvkQfQeCHKQy242llxnB+ULOb57psPDB+Q6SAgt2NH6wh/EZ
kAGQbwOR3w+Xh+g/gGb+AQDoym2u
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731732041587*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"},
 CellLabel->"During evaluation of In[3]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["This ",
  FontSlant->"Italic"],
 StyleBox["SphericalLens", "MB"],
 StyleBox[" looks good with ",
  FontSlant->"Italic"],
 StyleBox["PlotPoints\[Rule]30", "MB"],
 StyleBox[".",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[TextData[{
 "The graphical representation looks good.  Each face of the lens curves  \
smoothly.  Lowering the value of ",
 StyleBox["PlotPoints", "MB"],
 " causes ",
 "Optica",
 " to approximate the spherical surfaces with fewer polygons."
}], "Text",
 CellChangeTimes->{3.5661589423207684`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LineOfRays", "[", 
       RowBox[{"40", ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "7"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalLens", "[", 
         RowBox[{"30", ",", 
          RowBox[{"-", "30"}], ",", "50", ",", "40"}], "]"}], ",", "10"}], 
       "]"}], ",", 
      RowBox[{"Boundary", "[", "75", "]"}]}], "\[IndentingNewLine]", "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"RayPointSize", "\[Rule]", "4"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotPoints", "\[Rule]", "10"}]}], "]"}], ";"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"},
 CellLabel->"In[4]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{23.416876048223, -25.}, {36.583123951777, -25.}, {
      47.27178028658929, -12.5}, {12.728219713410713`, -12.5}, {
      23.416876048223, -25.}}], 
     PolygonBox[{{12.728219713410713`, -12.5}, {47.27178028658929, -12.5}, {
      50., 0.}, {10., 0.}, {12.728219713410713`, -12.5}}], 
     PolygonBox[{{10., 0.}, {50., 0.}, {47.27178028658929, 12.5}, {
      12.728219713410713`, 12.5}, {10., 0.}}], 
     PolygonBox[{{12.728219713410713`, 12.5}, {47.27178028658929, 12.5}, {
      36.583123951777, 25.}, {23.416876048223, 25.}, {12.728219713410713`, 
      12.5}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{23.416876048223, -25.}, {12.728219713410713`, -12.5}, {10., 
       0.}, {12.728219713410713`, 12.5}, {23.416876048223, 25.}, {
       36.583123951777, 25.}, {47.27178028658929, 12.5}, {50., 0.}, {
       47.27178028658929, -12.5}, {36.583123951777, -25.}, {
       23.416876048223, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{23.416876048223, 0.}, {36.583123951777, 
        3.061616997868383*^-15}, {47.27178028658929, 
        2.296212748401287*^-15}, {12.728219713410713`, 
        7.654042494670958*^-16}, {23.416876048223, 0.}}], 
       PolygonBox[{{12.728219713410713`, 7.654042494670958*^-16}, {
        47.27178028658929, 2.296212748401287*^-15}, {50., 
        1.5308084989341915`*^-15}, {10., 1.5308084989341915`*^-15}, {
        12.728219713410713`, 7.654042494670958*^-16}}], 
       PolygonBox[{{10., 1.5308084989341915`*^-15}, {50., 
        1.5308084989341915`*^-15}, {47.27178028658929, 
        7.654042494670958*^-16}, {12.728219713410713`, 
        2.296212748401287*^-15}, {10., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{12.728219713410713`, 2.296212748401287*^-15}, {
        47.27178028658929, 7.654042494670958*^-16}, {36.583123951777, 0.}, {
        23.416876048223, 3.061616997868383*^-15}, {12.728219713410713`, 
        2.296212748401287*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{23.416876048223, 0.}, {12.728219713410713`, 0.}, {10., 
         0.}, {12.728219713410713`, 0.}, {23.416876048223, 0.}, {
         36.583123951777, 0.}, {47.27178028658929, 0.}, {50., 0.}, {
         47.27178028658929, 0.}, {36.583123951777, 0.}, {23.416876048223, 
         0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{23.416876048223, 25.}, {36.583123951777, 25.}, {
       36.583123951777, 23.09698831278217}, {23.416876048223, 
       23.09698831278217}, {23.416876048223, 25.}}], 
      LineBox[{{23.416876048223, 23.09698831278217}, {36.583123951777, 
       23.09698831278217}, {36.583123951777004`, 17.67766952966369}, {
       23.416876048222996`, 17.67766952966369}, {23.416876048223, 
       23.09698831278217}}], 
      LineBox[{{23.416876048222996`, 17.67766952966369}, {36.583123951777004`,
        17.67766952966369}, {36.583123951777, 9.567085809127246}, {
       23.416876048223, 9.567085809127246}, {23.416876048222996`, 
       17.67766952966369}}], 
      LineBox[{{23.416876048223, 9.567085809127246}, {36.583123951777, 
       9.567085809127246}, {36.583123951777, 1.5308084989341915`*^-15}, {
       23.416876048223, 1.5308084989341915`*^-15}, {23.416876048223, 
       9.567085809127246}}], 
      LineBox[{{23.416876048223, 1.5308084989341915`*^-15}, {36.583123951777, 
       1.5308084989341915`*^-15}, {36.583123951777, -9.567085809127244}, {
       23.416876048223, -9.567085809127244}, {23.416876048223, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{23.416876048223, -9.567085809127244}, {
       36.583123951777, -9.567085809127244}, {
       36.583123951777004`, -17.677669529663685`}, {
       23.416876048222996`, -17.677669529663685`}, {
       23.416876048223, -9.567085809127244}}], 
      LineBox[{{23.416876048222996`, -17.677669529663685`}, {
       36.583123951777004`, -17.677669529663685`}, {
       36.583123951777, -23.09698831278217}, {
       23.416876048223003`, -23.09698831278217}, {
       23.416876048222996`, -17.677669529663685`}}], 
      LineBox[{{23.416876048223003`, -23.09698831278217}, {
       36.583123951777, -23.09698831278217}, {36.583123951777, -25.}, {
       23.416876048223, -25.}, {23.416876048223003`, -23.09698831278217}}], 
      LineBox[{{23.416876048223, -25.}, {36.583123951777, -25.}, {
       36.583123951777, -23.09698831278217}, {
       23.416876048223, -23.09698831278217}, {23.416876048223, -25.}}], 
      LineBox[{{23.416876048223, -23.09698831278217}, {
       36.583123951777, -23.09698831278217}, {
       36.583123951777, -17.677669529663692`}, {
       23.416876048223003`, -17.677669529663692`}, {
       23.416876048223, -23.09698831278217}}], 
      LineBox[{{23.416876048223003`, -17.677669529663692`}, {
       36.583123951777, -17.677669529663692`}, {
       36.583123951777004`, -9.567085809127258}, {
       23.416876048222996`, -9.567085809127258}, {
       23.416876048223003`, -17.677669529663692`}}], 
      LineBox[{{23.416876048222996`, -9.567085809127258}, {
       36.583123951777004`, -9.567085809127258}, {
       36.583123951777, -4.592425496802574*^-15}, {
       23.416876048223, -4.592425496802574*^-15}, {
       23.416876048222996`, -9.567085809127258}}], 
      LineBox[{{23.416876048223, -4.592425496802574*^-15}, {
       36.583123951777, -4.592425496802574*^-15}, {36.583123951777, 
       9.56708580912725}, {23.416876048223, 9.56708580912725}, {
       23.416876048223, -4.592425496802574*^-15}}], 
      LineBox[{{23.416876048223, 9.56708580912725}, {36.583123951777, 
       9.56708580912725}, {36.583123951777, 17.6776695296637}, {
       23.416876048223, 17.6776695296637}, {23.416876048223, 
       9.56708580912725}}], 
      LineBox[{{23.416876048223003`, 17.677669529663685`}, {36.583123951777, 
       17.677669529663685`}, {36.583123951777, 23.096988312782162`}, {
       23.416876048223, 23.096988312782162`}, {23.416876048223003`, 
       17.677669529663685`}}], 
      LineBox[{{23.416876048223, 23.096988312782162`}, {36.583123951777, 
       23.096988312782162`}, {36.583123951777, 25.}, {23.416876048223, 25.}, {
       23.416876048223, 23.096988312782162`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {75., -37.5}, {75., 37.5}, {75., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {0., -37.5}, {0., -37.5}, {75., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[NCache[{{0, Rational[-75, 2]}, {0, Rational[75, 2]}, {
         0, Rational[75, 2]}, {0, Rational[-75, 2]}, {
         0, Rational[-75, 2]}}, {{0, -37.5}, {0, 37.5}, {0, 37.5}, {
         0, -37.5}, {0, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 37.5}, {75., 37.5}, {75., 37.5}, {0., 37.5}, {0., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {75., 37.5}, {0., 37.5}, {0., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {0., -37.5}, {0., 37.5}, {75., 
       37.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -20.}, {17.639320225002102`, -20.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.333333333333334`}, {
       13.125807505671503`, -13.333333333333334`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -6.666666666666668}, {
       10.750118708692924`, -6.666666666666668}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {10., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 6.666666666666664}, {10.750118708692924`, 
       6.666666666666664}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 13.333333333333329`}, {13.1258075056715, 
       13.333333333333329`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 20.}, {17.639320225002102`, 20.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{17.639320225002102`, -20.}, {
       47.70669973966436, -11.503859766881838`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.125807505671503`, -13.333333333333334`}, {
       49.07350501128092, -7.398060986435744}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.750118708692924`, -6.666666666666668}, {
       49.77777975395612, -3.6446992914205145`}}]}, 
     {Arrowheads[Small], ArrowBox[{{10., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.750118708692924`, 6.666666666666664}, {49.77777975395612, 
       3.6446992914205127`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.1258075056715, 13.333333333333329`}, {49.07350501128092, 
       7.398060986435741}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{17.639320225002102`, 20.}, {47.70669973966436, 
       11.503859766881838`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.70669973966436, -11.503859766881838`}, {75., 
       18.648852558669297`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.07350501128092, -7.398060986435744}, {75., 
       3.75203876884951}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.77777975395612, -3.6446992914205145`}, {75., 
       1.0316702129799324`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.77777975395612, 3.6446992914205127`}, {
       75., -1.0316702129799316`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.07350501128092, 7.398060986435741}, {
       75., -3.752038768849502}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.70669973966436, 11.503859766881838`}, {
       75., -18.648852558669297`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[4.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrcfXVLtqsaEDAxiYHFjwLOV6poOWw+pVIKB1IOGF
cT9/g6rDGjBf6gBEnQpUPQMDTH4FRN5hHlQ/hK/lgGa+w7yfYsqlt9wddPg8
X/xkVD8w/ejOORmdHg7hFrN85k6XPXAwttyz77GHQ56dslSEBi/UPk+4fTD5
LIi8A0x/CEQ/uvkQfQeCHKQy242llxnB+ULOb57psPDB+Q6SAgt2NH6wh/EZ
kAGQbwOR3w+Xh+g/gGb+AQDoym2u
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731732473605*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"},
 CellLabel->"During evaluation of In[4]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["This ",
  FontSlant->"Italic"],
 StyleBox["SphericalLens", "MB"],
 StyleBox[" looks poor with ",
  FontSlant->"Italic"],
 StyleBox["PlotPoints\[Rule]10", "MB"],
 StyleBox[".  However the ray trace is still good because graphics do not  \
affect ray-tracing.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell["\<\
The lens now looks jagged, but the ray intercepts are the same everywhere.   \
This result shows that Optica can produce different graphics for the same \
optical system models,  depending on graphics settings.\
\>", "Text",
 CellChangeTimes->{3.5661589471551523`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[TextData[{
 StyleBox["PlotPoints", "MB"],
 " is a standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics option.  In ",
 "Optica",
 ", it can apply either to individual components or to your entire system, \
depending on where the option is inserted.  ",
 StyleBox["GraphicDesign", "MB"],
 " is an important option for individual components.  It can take the values  \
",
 StyleBox["Automatic", "MB"],
 ", ",
 StyleBox["Sketch", "MB"],
 ", ",
 StyleBox["Wire", "MB"],
 ", ",
 StyleBox["Solid", "MB"],
 ", or ",
 StyleBox["Off", "MB"],
 ".  You may render different components in the same system with different  \
",
 StyleBox["GraphicDesign", "MB"],
 " settings between them."
}], "Text",
 CellChangeTimes->{3.566158947217915*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell["\<\
The distinction between graphics and underlying models also bears upon the \
question of lens edges, discussed previously in Section 3.4.2.\
\>", "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"PR6.2", "Adjusting Graphics"}],

Cell[CellGroupData[{

Cell["6.2.1 Magnifying Graphics", "Subsection",
 CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}],

Cell[TextData[{
 "Another way to modify Optica's graphics is the ",
 StyleBox["Magnification", "MB"],
 " option.  This option scales ",
 "Optica",
 " graphics by multiplication factor.  This option requires a certain care,  \
because it also affects ray intercepts."
}], "Text",
 CellChangeTimes->{{3.56615894728398*^9, 3.56615894733885*^9}},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],

Cell["\<\
The following system has two lenses.  The physical shape of the smaller lens \
disappears at this scale.\
\>", "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"light", "=", 
   RowBox[{"LineOfRays", "[", 
    RowBox[{"1", ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "5"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"smalllens", "=", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"PlanoConcaveLens", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "2.5", ",", "1", ",", "\"\<Small Lens\>\""}], 
      "]"}], ",", "10"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"biglens", "=", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"PlanoConvexLens", "[", 
      RowBox[{"100", ",", "50", ",", "10", ",", "\"\<Big Lens\>\""}], "]"}], 
     ",", "60"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"boundary", "=", 
   RowBox[{"Boundary", "[", "75", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"light", ",", "smalllens", ",", "biglens", ",", "boundary"}], 
     "}"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", "Automatic"}]}], "]"}], ";"}]}], "Input",\

 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"},
 CellLabel->"In[5]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{9.370735463147023, -1.25}, {11., -1.25}, {
      11., -0.8333333333333335}, {9.758066001600648, -0.8333333333333334}, {
      9.370735463147023, -1.25}}], 
     PolygonBox[{{9.758066001600648, -0.8333333333333334}, {
      11., -0.8333333333333335}, {11., -0.41666666666666696`}, {
      9.943180837741203, -0.41666666666666674`}, {
      9.758066001600648, -0.8333333333333334}}], 
     PolygonBox[{{9.943180837741203, -0.41666666666666674`}, {
      11., -0.41666666666666696`}, {11., -2.220446049250313*^-16}, {10., 
      0.}, {9.943180837741203, -0.41666666666666674`}}], 
     PolygonBox[{{10., 0.}, {11., 0.}, {11., 0.4166666666666665}, {
      9.943180837741203, 0.4166666666666665}, {10., 0.}}], 
     PolygonBox[{{9.943180837741203, 0.4166666666666665}, {11., 
      0.4166666666666665}, {11., 0.8333333333333333}, {9.75806600160065, 
      0.833333333333333}, {9.943180837741203, 0.4166666666666665}}], 
     PolygonBox[{{9.75806600160065, 0.833333333333333}, {11., 
      0.8333333333333331}, {11., 1.2499999999999998`}, {9.370735463147025, 
      1.2499999999999996`}, {9.75806600160065, 0.833333333333333}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.370735463147023, -1.25}, {
       9.758066001600648, -0.8333333333333334}, {
       9.943180837741203, -0.41666666666666674`}, {10., 0.}, {
       9.943180837741203, 0.4166666666666665}, {9.75806600160065, 
       0.833333333333333}, {9.370735463147023, 1.25}, {11., 1.25}, {11., 
       0.8333333333333334}, {11., 0.41666666666666674`}, {11., 0.}, {
       11., -0.4166666666666665}, {11., -0.833333333333333}, {11., -1.25}, {
       9.370735463147023, -1.25}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{9.370735463147023, 0.}, {11., 1.5308084989341916`*^-16}, {
        11., 1.2756737491118264`*^-16}, {9.758066001600648, 
        2.5513474982236523`*^-17}, {9.370735463147023, 0.}}], 
       PolygonBox[{{9.758066001600648, 2.5513474982236523`*^-17}, {11., 
        1.2756737491118264`*^-16}, {11., 1.0205389992894612`*^-16}, {
        9.943180837741203, 5.1026949964473046`*^-17}, {9.758066001600648, 
        2.5513474982236523`*^-17}}], 
       PolygonBox[{{9.943180837741203, 5.1026949964473046`*^-17}, {11., 
        1.0205389992894612`*^-16}, {11., 7.654042494670959*^-17}, {10., 
        7.654042494670958*^-17}, {9.943180837741203, 
        5.1026949964473046`*^-17}}], 
       PolygonBox[{{10., 7.654042494670958*^-17}, {11., 
        7.654042494670958*^-17}, {11., 5.102694996447306*^-17}, {
        9.943180837741203, 1.0205389992894609`*^-16}, {10., 
        7.654042494670958*^-17}}], 
       PolygonBox[{{9.943180837741203, 1.0205389992894609`*^-16}, {11., 
        5.102694996447306*^-17}, {11., 2.5513474982236532`*^-17}, {
        9.75806600160065, 1.2756737491118262`*^-16}, {9.943180837741203, 
        1.0205389992894609`*^-16}}], 
       PolygonBox[{{9.75806600160065, 1.2756737491118262`*^-16}, {11., 
        2.5513474982236535`*^-17}, {11., 1.2746541313564605`*^-32}, {
        9.370735463147025, 1.5308084989341913`*^-16}, {9.75806600160065, 
        1.2756737491118262`*^-16}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{9.370735463147023, 0.}, {9.758066001600648, 0.}, {
         9.943180837741203, 0.}, {10., 0.}, {9.943180837741203, 0.}, {
         9.75806600160065, 0.}, {9.370735463147023, 0.}, {11., 0.}, {11., 
         0.}, {11., 0.}, {11., 0.}, {11., 0.}, {11., 0.}, {11., 0.}, {
         9.370735463147023, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.370735463147023, 1.25}, {11., 1.25}, {11., 
       1.2074072828613354`}, {9.370735463147023, 1.2074072828613354`}, {
       9.370735463147023, 1.25}}], 
      LineBox[{{9.370735463147023, 1.2074072828613354`}, {11., 
       1.2074072828613354`}, {11., 1.0825317547305484`}, {9.370735463147023, 
       1.0825317547305484`}, {9.370735463147023, 1.2074072828613354`}}], 
      LineBox[{{9.370735463147023, 1.0825317547305484`}, {11., 
       1.0825317547305484`}, {11., 0.8838834764831844}, {9.370735463147023, 
       0.8838834764831844}, {9.370735463147023, 1.0825317547305484`}}], 
      LineBox[{{9.370735463147023, 0.8838834764831844}, {11., 
       0.8838834764831844}, {11., 0.6250000000000001}, {9.370735463147023, 
       0.6250000000000001}, {9.370735463147023, 0.8838834764831844}}], 
      LineBox[{{9.370735463147023, 0.6250000000000001}, {11., 
       0.6250000000000001}, {11., 0.3235238063781512}, {9.370735463147025, 
       0.3235238063781512}, {9.370735463147023, 0.6250000000000001}}], 
      LineBox[{{9.370735463147025, 0.3235238063781512}, {11., 
       0.3235238063781512}, {11., 3.540961811029987*^-16}, {9.370735463147023,
        3.540961811029987*^-16}, {9.370735463147025, 0.3235238063781512}}], 
      LineBox[{{9.370735463147023, 7.654042494670958*^-17}, {11., 
       7.654042494670958*^-17}, {11., -0.3235238063781508}, {
       9.370735463147023, -0.3235238063781508}, {9.370735463147023, 
       7.654042494670958*^-17}}], 
      LineBox[{{9.370735463147023, -0.3235238063781508}, {
       11., -0.3235238063781508}, {11., -0.6249999999999998}, {
       9.370735463147023, -0.6249999999999998}, {
       9.370735463147023, -0.3235238063781508}}], 
      LineBox[{{9.370735463147023, -0.6249999999999998}, {
       11., -0.6249999999999998}, {11., -0.8838834764831843}, {
       9.370735463147023, -0.8838834764831843}, {
       9.370735463147023, -0.6249999999999998}}], 
      LineBox[{{9.370735463147023, -0.8838834764831843}, {
       11., -0.8838834764831843}, {11., -1.0825317547305484`}, {
       9.370735463147023, -1.0825317547305484`}, {
       9.370735463147023, -0.8838834764831843}}], 
      LineBox[{{9.370735463147023, -1.0825317547305482`}, {
       11., -1.0825317547305482`}, {11., -1.2074072828613351`}, {
       9.370735463147025, -1.2074072828613351`}, {
       9.370735463147023, -1.0825317547305482`}}], 
      LineBox[{{9.370735463147025, -1.2074072828613351`}, {
       11., -1.2074072828613351`}, {11., -1.25}, {9.370735463147023, -1.25}, {
       9.370735463147025, -1.2074072828613351`}}], 
      LineBox[{{9.370735463147023, -1.25}, {11., -1.25}, {
       11., -1.2074072828613354`}, {
       9.370735463147023, -1.2074072828613354`}, {9.370735463147023, -1.25}}],
       LineBox[{{9.370735463147023, -1.2074072828613356`}, {
       11., -1.2074072828613356`}, {11., -1.0825317547305486`}, {
       9.370735463147023, -1.0825317547305486`}, {
       9.370735463147023, -1.2074072828613356`}}], 
      LineBox[{{9.370735463147023, -1.0825317547305486`}, {
       11., -1.0825317547305486`}, {11., -0.8838834764831847}, {
       9.370735463147023, -0.8838834764831847}, {
       9.370735463147023, -1.0825317547305486`}}], 
      LineBox[{{9.370735463147023, -0.8838834764831849}, {
       11., -0.8838834764831849}, {11., -0.6250000000000006}, {
       9.370735463147023, -0.6250000000000006}, {
       9.370735463147023, -0.8838834764831849}}], 
      LineBox[{{9.370735463147023, -0.6250000000000006}, {
       11., -0.6250000000000006}, {11., -0.3235238063781519}, {
       9.370735463147023, -0.3235238063781519}, {
       9.370735463147023, -0.6250000000000006}}], 
      LineBox[{{9.370735463147023, -0.3235238063781519}, {
       11., -0.3235238063781519}, {11., -1.3398442994652851`*^-15}, {
       9.370735463147023, -1.3398442994652851`*^-15}, {
       9.370735463147023, -0.3235238063781519}}], 
      LineBox[{{9.370735463147023, -2.296212748401287*^-16}, {
       11., -2.296212748401287*^-16}, {11., 0.32352380637815037`}, {
       9.370735463147023, 0.32352380637815037`}, {
       9.370735463147023, -2.296212748401287*^-16}}], 
      LineBox[{{9.370735463147023, 0.32352380637815037`}, {11., 
       0.32352380637815037`}, {11., 0.6249999999999991}, {9.370735463147023, 
       0.6249999999999991}, {9.370735463147023, 0.32352380637815037`}}], 
      LineBox[{{9.370735463147023, 0.6249999999999991}, {11., 
       0.6249999999999991}, {11., 0.8838834764831835}, {9.370735463147023, 
       0.8838834764831835}, {9.370735463147023, 0.6249999999999991}}], 
      LineBox[{{9.370735463147023, 0.8838834764831842}, {11., 
       0.8838834764831842}, {11., 1.082531754730548}, {9.370735463147023, 
       1.082531754730548}, {9.370735463147023, 0.8838834764831842}}], 
      LineBox[{{9.370735463147023, 1.082531754730548}, {11., 
       1.082531754730548}, {11., 1.2074072828613351`}, {9.370735463147023, 
       1.2074072828613351`}, {9.370735463147023, 1.082531754730548}}], 
      LineBox[{{9.370735463147023, 1.2074072828613351`}, {11., 
       1.2074072828613351`}, {11., 1.25}, {9.370735463147023, 1.25}, {
       9.370735463147023, 1.2074072828613351`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{66.42197458095559, -25.}, {70., -25.}, {
      70., -16.66666666666667}, {62.75044883428479, -16.666666666666668`}, {
      66.42197458095559, -25.}}], 
     PolygonBox[{{62.75044883428479, -16.666666666666668`}, {
      70., -16.66666666666667}, {70., -8.333333333333336}, {
      60.67375799589206, -8.333333333333336}, {
      62.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{60.67375799589206, -8.333333333333336}, {
      70., -8.333333333333336}, {70., -7.105427357601002*^-15}, {60., 0.}, {
      60.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{60., 0.}, {70., 0.}, {70., 8.333333333333332}, {
      60.67375799589206, 8.333333333333329}, {60., 0.}}], 
     PolygonBox[{{60.67375799589206, 8.333333333333329}, {70., 
      8.333333333333332}, {70., 16.666666666666664`}, {62.75044883428479, 
      16.666666666666664`}, {60.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{62.75044883428479, 16.666666666666664`}, {70., 
      16.666666666666664`}, {70., 24.999999999999996`}, {66.42197458095559, 
      24.999999999999993`}, {62.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{66.42197458095559, -25.}, {
       62.75044883428479, -16.666666666666668`}, {
       60.67375799589206, -8.333333333333336}, {
       60., -3.552713678800501*^-15}, {60.67375799589206, 
       8.333333333333329}, {62.75044883428478, 16.666666666666657`}, {
       66.42197458095559, 24.999999999999993`}, {70., 25.}, {70., 
       16.666666666666668`}, {70., 8.333333333333336}, {70., 
       3.552713678800501*^-15}, {70., -8.333333333333329}, {
       70., -16.666666666666657`}, {70., -24.999999999999993`}, {
       66.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{66.42197458095559, 0.}, {70., 3.061616997868383*^-15}, {
        70., 2.551347498223653*^-15}, {62.75044883428479, 
        5.102694996447305*^-16}, {66.42197458095559, 0.}}], 
       PolygonBox[{{62.75044883428479, 5.102694996447305*^-16}, {70., 
        2.551347498223653*^-15}, {70., 2.0410779985789223`*^-15}, {
        60.67375799589206, 1.020538999289461*^-15}, {62.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{60.67375799589206, 1.020538999289461*^-15}, {70., 
        2.0410779985789223`*^-15}, {70., 1.530808498934192*^-15}, {60., 
        1.5308084989341915`*^-15}, {60.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{60., 1.5308084989341915`*^-15}, {70., 
        1.5308084989341915`*^-15}, {70., 1.0205389992894611`*^-15}, {
        60.67375799589206, 2.041077998578922*^-15}, {60., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{60.67375799589206, 2.041077998578922*^-15}, {70., 
        1.0205389992894611`*^-15}, {70., 5.102694996447307*^-16}, {
        62.75044883428479, 2.5513474982236525`*^-15}, {60.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{62.75044883428479, 2.5513474982236525`*^-15}, {70., 
        5.102694996447308*^-16}, {70., 2.5493082627129206`*^-31}, {
        66.42197458095559, 3.0616169978683826`*^-15}, {62.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{66.42197458095559, 0.}, {62.75044883428479, 0.}, {
         60.67375799589206, 0.}, {60., 0.}, {60.67375799589206, 0.}, {
         62.75044883428478, 0.}, {66.42197458095559, 0.}, {70., 0.}, {70., 
         0.}, {70., 0.}, {70., 0.}, {70., 0.}, {70., 0.}, {70., 0.}, {
         66.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{66.42197458095559, 25.}, {70., 25.}, {70., 
       24.148145657226706`}, {66.42197458095559, 24.148145657226706`}, {
       66.42197458095559, 25.}}], 
      LineBox[{{66.42197458095559, 24.148145657226706`}, {70., 
       24.148145657226706`}, {70., 21.65063509461097}, {66.42197458095559, 
       21.65063509461097}, {66.42197458095559, 24.148145657226706`}}], 
      LineBox[{{66.42197458095559, 21.65063509461097}, {70., 
       21.65063509461097}, {70., 17.67766952966369}, {66.42197458095559, 
       17.67766952966369}, {66.42197458095559, 21.65063509461097}}], 
      LineBox[{{66.42197458095559, 17.67766952966369}, {70., 
       17.67766952966369}, {70., 12.500000000000004`}, {66.42197458095559, 
       12.500000000000004`}, {66.42197458095559, 17.67766952966369}}], 
      LineBox[{{66.42197458095559, 12.500000000000004`}, {70., 
       12.500000000000004`}, {70., 6.470476127563024}, {66.42197458095559, 
       6.470476127563024}, {66.42197458095559, 12.500000000000004`}}], 
      LineBox[{{66.42197458095559, 6.470476127563024}, {70., 
       6.470476127563024}, {70., 7.0819236220599744`*^-15}, {
       66.42197458095559, 7.0819236220599744`*^-15}, {66.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{66.42197458095559, 1.5308084989341915`*^-15}, {70., 
       1.5308084989341915`*^-15}, {70., -6.470476127563016}, {
       66.42197458095559, -6.470476127563016}, {66.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{66.42197458095559, -6.470476127563016}, {
       70., -6.470476127563016}, {70., -12.499999999999995`}, {
       66.42197458095559, -12.499999999999995`}, {
       66.42197458095559, -6.470476127563016}}], 
      LineBox[{{66.42197458095559, -12.499999999999995`}, {
       70., -12.499999999999995`}, {70., -17.677669529663685`}, {
       66.42197458095559, -17.677669529663685`}, {
       66.42197458095559, -12.499999999999995`}}], 
      LineBox[{{66.42197458095559, -17.677669529663685`}, {
       70., -17.677669529663685`}, {70., -21.65063509461097}, {
       66.42197458095559, -21.65063509461097}, {
       66.42197458095559, -17.677669529663685`}}], 
      LineBox[{{66.4219745809556, -21.650635094610962`}, {
       70., -21.650635094610962`}, {70., -24.148145657226706`}, {
       66.42197458095559, -24.148145657226706`}, {
       66.4219745809556, -21.650635094610962`}}], 
      LineBox[{{66.42197458095559, -24.148145657226706`}, {
       70., -24.148145657226706`}, {70., -25.}, {66.42197458095559, -25.}, {
       66.42197458095559, -24.148145657226706`}}], 
      LineBox[{{66.42197458095559, -25.}, {70., -25.}, {
       70., -24.148145657226706`}, {
       66.42197458095559, -24.148145657226706`}, {66.42197458095559, -25.}}], 
      LineBox[{{66.42197458095559, -24.14814565722671}, {
       70., -24.14814565722671}, {70., -21.65063509461097}, {
       66.42197458095559, -21.65063509461097}, {
       66.42197458095559, -24.14814565722671}}], 
      LineBox[{{66.42197458095559, -21.65063509461097}, {
       70., -21.65063509461097}, {70., -17.677669529663692`}, {
       66.42197458095559, -17.677669529663692`}, {
       66.42197458095559, -21.65063509461097}}], 
      LineBox[{{66.42197458095559, -17.677669529663696`}, {
       70., -17.677669529663696`}, {70., -12.50000000000001}, {
       66.42197458095559, -12.50000000000001}, {
       66.42197458095559, -17.677669529663696`}}], 
      LineBox[{{66.42197458095559, -12.50000000000001}, {
       70., -12.50000000000001}, {70., -6.470476127563038}, {
       66.42197458095559, -6.470476127563038}, {
       66.42197458095559, -12.50000000000001}}], 
      LineBox[{{66.42197458095559, -6.470476127563038}, {
       70., -6.470476127563038}, {70., -2.6796885989305705`*^-14}, {
       66.42197458095559, -2.6796885989305705`*^-14}, {
       66.42197458095559, -6.470476127563038}}], 
      LineBox[{{66.42197458095559, -4.592425496802574*^-15}, {
       70., -4.592425496802574*^-15}, {70., 6.470476127563007}, {
       66.42197458095559, 6.470476127563007}, {
       66.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{66.42197458095559, 6.470476127563007}, {70., 
       6.470476127563007}, {70., 12.499999999999984`}, {66.42197458095559, 
       12.499999999999984`}, {66.42197458095559, 6.470476127563007}}], 
      LineBox[{{66.42197458095559, 12.499999999999984`}, {70., 
       12.499999999999984`}, {70., 17.67766952966367}, {66.4219745809556, 
       17.67766952966367}, {66.42197458095559, 12.499999999999984`}}], 
      LineBox[{{66.42197458095559, 17.677669529663685`}, {70., 
       17.677669529663685`}, {70., 21.65063509461096}, {66.42197458095559, 
       21.65063509461096}, {66.42197458095559, 17.677669529663685`}}], 
      LineBox[{{66.42197458095559, 21.65063509461096}, {70., 
       21.65063509461096}, {70., 24.148145657226703`}, {66.42197458095559, 
       24.148145657226703`}, {66.42197458095559, 21.65063509461096}}], 
      LineBox[{{66.42197458095559, 24.148145657226703`}, {70., 
       24.148145657226703`}, {70., 25.}, {66.42197458095559, 25.}, {
       66.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {75., -37.5}, {75., 37.5}, {75., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {0., -37.5}, {0., -37.5}, {75., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[NCache[{{0, Rational[-75, 2]}, {0, Rational[75, 2]}, {
         0, Rational[75, 2]}, {0, Rational[-75, 2]}, {
         0, Rational[-75, 2]}}, {{0, -37.5}, {0, 37.5}, {0, 37.5}, {
         0, -37.5}, {0, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 37.5}, {75., 37.5}, {75., 37.5}, {0., 37.5}, {0., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {75., 37.5}, {0., 37.5}, {0., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {0., -37.5}, {0., 37.5}, {75., 
       37.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -0.5}, {9.917486534971452, -0.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., -0.25}, {9.979787260123233, -0.25}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {9.999999999999996, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.25}, {9.979787260123233, 0.25}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.5}, {9.917486534971452, 0.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.917486534971452, -0.5}, {11., -0.6239238043898814}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.979787260123233, -0.25}, {11., -0.3065732595916709}}]}, 
     {Arrowheads[Small], ArrowBox[{{9.999999999999996, 0.}, {11., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.979787260123233, 0.25}, {11., 0.3065732595916709}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.917486534971452, 0.5}, {11., 0.6239238043898814}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{11., -0.6239238043898814}, {
       60.85303894314536, -9.368567304762962}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{11., -0.3065732595916709}, {
       60.19197643983885, -4.458650196369402}}]}, 
     {Arrowheads[Small], ArrowBox[{{11., 0.}, {60.00000000000001, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{11., 0.3065732595916709}, {60.19197643983885, 
       4.458650196369402}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{11., 0.6239238043898814}, {60.85303894314536, 
       9.368567304762962}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.85303894314536, -9.368567304762962}, {
       70., -9.820937242117102}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.19197643983885, -4.458650196369402}, {
       70., -4.710945294665234}}]}, 
     {Arrowheads[Small], ArrowBox[{{60.00000000000001, 0.}, {70., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.19197643983885, 4.458650196369402}, {70., 
       4.710945294665234}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.85303894314536, 9.368567304762962}, {70., 
       9.820937242117102}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., -9.820937242117102}, {75., -10.197171469841576`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., -4.710945294665234}, {75., -4.9064067339952775`}}]}, 
     {Arrowheads[Small], ArrowBox[{{70., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., 4.710945294665234}, {75., 4.9064067339952775`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., 9.820937242117102}, {75., 10.197171469841576`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQzVPUc/rAVWUHBjB4sH9ix781y77C+Bf2//sPAjA+
AwOavD2afnsIreZgMfchr/73x/th/Ht9H4uezrsM5zOgALg8un57zmbfRINc
P4cHKyfc2rJH6cDbKMn1kyT8HOZeX5a64qrgAUawej+4eWjyDmj6IeoaAh2s
39x9FLhE+QCMbxsizs10QwjOR3EeQh5dP4R/IMjhf8TaFZ9TVA7A+FKdtmKa
C4ThfBTzEPLo+h0AxDh6nQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"Big Lens\"\>", {65., -26.907886858793663`}, {0., 0.}], 
    InsetBox["\<\"Small Lens\"\>", {10.5, -3.1578868587936633`}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>Automatic,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731733065462*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"},
 CellLabel->"During evaluation of In[5]:="]
}, Open  ]],

Cell[TextData[{
 "You may define the same optical component with a different ",
 StyleBox["Magnification", "MB"],
 ".  Sometimes this change necessitates parallel changes to ",
 StyleBox["LabelPositions", "MB"],
 " for good-looking output."
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"magnifiedlens", "=", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"PlanoConcaveLens", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "2.5", ",", "1", ",", 
       "\"\<Magnified Lens\>\"", ",", 
       RowBox[{"Magnification", "\[Rule]", "4"}], ",", 
       RowBox[{"LabelPositions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"5", ",", 
           RowBox[{"-", "10"}], ",", "0"}], "}"}], "}"}]}]}], "]"}], ",", 
     "10"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"light", ",", "magnifiedlens", ",", "biglens", ",", "boundary"}],
      "}"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", "Automatic"}]}], "]"}], ";"}]}], "Input",\

 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"},
 CellLabel->"In[10]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.92683865786756, -5.}, {13.443896805279469`, -5.}, {
      13.443896805279469`, -3.333333333333334}, {
      8.47616081168206, -3.3333333333333335`}, {6.92683865786756, -5.}}], 
     PolygonBox[{{8.47616081168206, -3.3333333333333335`}, {
      13.443896805279469`, -3.333333333333334}, {
      13.443896805279469`, -1.6666666666666679`}, {
      9.216620156244279, -1.666666666666667}, {
      8.47616081168206, -3.3333333333333335`}}], 
     PolygonBox[{{9.216620156244279, -1.666666666666667}, {
      13.443896805279469`, -1.6666666666666679`}, {
      13.443896805279469`, -8.881784197001252*^-16}, {9.443896805279469, 
      0.}, {9.216620156244279, -1.666666666666667}}], 
     PolygonBox[{{9.443896805279469, 0.}, {13.443896805279469`, 0.}, {
      13.443896805279469`, 1.666666666666666}, {9.216620156244279, 
      1.666666666666666}, {9.443896805279469, 0.}}], 
     PolygonBox[{{9.216620156244279, 1.666666666666666}, {13.443896805279469`,
       1.666666666666666}, {13.443896805279469`, 3.333333333333333}, {
      8.476160811682067, 3.333333333333332}, {9.216620156244279, 
      1.666666666666666}}], 
     PolygonBox[{{8.476160811682067, 3.333333333333332}, {13.443896805279469`,
       3.3333333333333326`}, {13.443896805279469`, 4.999999999999999}, {
      6.926838657867567, 4.999999999999998}, {8.476160811682067, 
      3.333333333333332}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.92683865786756, -5.}, {
       8.47616081168206, -3.3333333333333335`}, {
       9.216620156244279, -1.666666666666667}, {9.443896805279469, 0.}, {
       9.216620156244279, 1.666666666666666}, {8.476160811682067, 
       3.333333333333332}, {6.92683865786756, 5.}, {13.443896805279469`, 
       5.}, {13.443896805279469`, 3.3333333333333335`}, {13.443896805279469`, 
       1.666666666666667}, {13.443896805279469`, 0.}, {
       13.443896805279469`, -1.666666666666666}, {
       13.443896805279469`, -3.333333333333332}, {13.443896805279469`, -5.}, {
       6.92683865786756, -5.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{6.92683865786756, 0.}, {13.443896805279469`, 
        6.123233995736766*^-16}, {13.443896805279469`, 
        5.102694996447306*^-16}, {8.47616081168206, 
        1.0205389992894609`*^-16}, {6.92683865786756, 0.}}], 
       PolygonBox[{{8.47616081168206, 1.0205389992894609`*^-16}, {
        13.443896805279469`, 5.102694996447306*^-16}, {13.443896805279469`, 
        4.0821559971578447`*^-16}, {9.216620156244279, 
        2.0410779985789218`*^-16}, {8.47616081168206, 
        1.0205389992894609`*^-16}}], 
       PolygonBox[{{9.216620156244279, 2.0410779985789218`*^-16}, {
        13.443896805279469`, 4.0821559971578447`*^-16}, {13.443896805279469`, 
        3.0616169978683836`*^-16}, {9.443896805279469, 
        3.061616997868383*^-16}, {9.216620156244279, 
        2.0410779985789218`*^-16}}], 
       PolygonBox[{{9.443896805279469, 3.061616997868383*^-16}, {
        13.443896805279469`, 3.061616997868383*^-16}, {13.443896805279469`, 
        2.0410779985789223`*^-16}, {9.216620156244279, 
        4.0821559971578437`*^-16}, {9.443896805279469, 
        3.061616997868383*^-16}}], 
       PolygonBox[{{9.216620156244279, 4.0821559971578437`*^-16}, {
        13.443896805279469`, 2.0410779985789223`*^-16}, {13.443896805279469`, 
        1.0205389992894613`*^-16}, {8.476160811682067, 
        5.102694996447305*^-16}, {9.216620156244279, 
        4.0821559971578437`*^-16}}], 
       PolygonBox[{{8.476160811682067, 5.102694996447305*^-16}, {
        13.443896805279469`, 1.0205389992894614`*^-16}, {13.443896805279469`, 
        5.098616525425842*^-32}, {6.926838657867567, 
        6.123233995736765*^-16}, {8.476160811682067, 
        5.102694996447305*^-16}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.92683865786756, 0.}, {8.47616081168206, 0.}, {
         9.216620156244279, 0.}, {9.443896805279469, 0.}, {9.216620156244279, 
         0.}, {8.476160811682067, 0.}, {6.92683865786756, 0.}, {
         13.443896805279469`, 0.}, {13.443896805279469`, 0.}, {
         13.443896805279469`, 0.}, {13.443896805279469`, 0.}, {
         13.443896805279469`, 0.}, {13.443896805279469`, 0.}, {
         13.443896805279469`, 0.}, {6.92683865786756, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.92683865786756, 5.}, {13.443896805279469`, 5.}, {
       13.443896805279469`, 4.8296291314453415`}, {6.92683865786756, 
       4.8296291314453415`}, {6.92683865786756, 5.}}], 
      LineBox[{{6.92683865786756, 4.8296291314453415`}, {13.443896805279469`, 
       4.8296291314453415`}, {13.443896805279469`, 4.330127018922194}, {
       6.92683865786756, 4.330127018922194}, {6.92683865786756, 
       4.8296291314453415`}}], 
      LineBox[{{6.92683865786756, 4.330127018922194}, {13.443896805279469`, 
       4.330127018922194}, {13.443896805279469`, 3.5355339059327378`}, {
       6.92683865786756, 3.5355339059327378`}, {6.92683865786756, 
       4.330127018922194}}], 
      LineBox[{{6.92683865786756, 3.5355339059327378`}, {13.443896805279469`, 
       3.5355339059327378`}, {13.443896805279469`, 2.5000000000000004`}, {
       6.92683865786756, 2.5000000000000004`}, {6.92683865786756, 
       3.5355339059327378`}}], 
      LineBox[{{6.92683865786756, 2.5000000000000004`}, {13.443896805279469`, 
       2.5000000000000004`}, {13.443896805279469`, 1.2940952255126048`}, {
       6.926838657867567, 1.2940952255126048`}, {6.92683865786756, 
       2.5000000000000004`}}], 
      LineBox[{{6.926838657867567, 1.2940952255126048`}, {13.443896805279469`,
        1.2940952255126048`}, {13.443896805279469`, 
       1.4163847244119948`*^-15}, {6.92683865786756, 
       1.4163847244119948`*^-15}, {6.926838657867567, 1.2940952255126048`}}], 
      LineBox[{{6.92683865786756, 3.061616997868383*^-16}, {
       13.443896805279469`, 3.061616997868383*^-16}, {
       13.443896805279469`, -1.2940952255126033`}, {
       6.92683865786756, -1.2940952255126033`}, {6.92683865786756, 
       3.061616997868383*^-16}}], 
      LineBox[{{6.92683865786756, -1.2940952255126033`}, {
       13.443896805279469`, -1.2940952255126033`}, {
       13.443896805279469`, -2.499999999999999}, {
       6.92683865786756, -2.499999999999999}, {
       6.92683865786756, -1.2940952255126033`}}], 
      LineBox[{{6.92683865786756, -2.499999999999999}, {
       13.443896805279469`, -2.499999999999999}, {
       13.443896805279469`, -3.5355339059327373`}, {
       6.92683865786756, -3.5355339059327373`}, {
       6.92683865786756, -2.499999999999999}}], 
      LineBox[{{6.92683865786756, -3.5355339059327373`}, {
       13.443896805279469`, -3.5355339059327373`}, {
       13.443896805279469`, -4.330127018922194}, {
       6.92683865786756, -4.330127018922194}, {
       6.92683865786756, -3.5355339059327373`}}], 
      LineBox[{{6.92683865786756, -4.330127018922193}, {
       13.443896805279469`, -4.330127018922193}, {
       13.443896805279469`, -4.829629131445341}, {
       6.926838657867567, -4.829629131445341}, {
       6.92683865786756, -4.330127018922193}}], 
      LineBox[{{6.926838657867567, -4.829629131445341}, {
       13.443896805279469`, -4.829629131445341}, {13.443896805279469`, -5.}, {
       6.92683865786756, -5.}, {6.926838657867567, -4.829629131445341}}], 
      LineBox[{{6.92683865786756, -5.}, {13.443896805279469`, -5.}, {
       13.443896805279469`, -4.8296291314453415`}, {
       6.92683865786756, -4.8296291314453415`}, {6.92683865786756, -5.}}], 
      LineBox[{{6.92683865786756, -4.829629131445342}, {
       13.443896805279469`, -4.829629131445342}, {
       13.443896805279469`, -4.3301270189221945`}, {
       6.92683865786756, -4.3301270189221945`}, {
       6.92683865786756, -4.829629131445342}}], 
      LineBox[{{6.92683865786756, -4.3301270189221945`}, {
       13.443896805279469`, -4.3301270189221945`}, {
       13.443896805279469`, -3.5355339059327386`}, {
       6.92683865786756, -3.5355339059327386`}, {
       6.92683865786756, -4.3301270189221945`}}], 
      LineBox[{{6.92683865786756, -3.5355339059327395`}, {
       13.443896805279469`, -3.5355339059327395`}, {
       13.443896805279469`, -2.500000000000002}, {
       6.92683865786756, -2.500000000000002}, {
       6.92683865786756, -3.5355339059327395`}}], 
      LineBox[{{6.92683865786756, -2.500000000000002}, {
       13.443896805279469`, -2.500000000000002}, {
       13.443896805279469`, -1.2940952255126077`}, {
       6.92683865786756, -1.2940952255126077`}, {
       6.92683865786756, -2.500000000000002}}], 
      LineBox[{{6.92683865786756, -1.2940952255126077`}, {
       13.443896805279469`, -1.2940952255126077`}, {
       13.443896805279469`, -5.3593771978611406`*^-15}, {
       6.92683865786756, -5.3593771978611406`*^-15}, {
       6.92683865786756, -1.2940952255126077`}}], 
      LineBox[{{6.92683865786756, -9.184850993605148*^-16}, {
       13.443896805279469`, -9.184850993605148*^-16}, {13.443896805279469`, 
       1.2940952255126015`}, {6.92683865786756, 1.2940952255126015`}, {
       6.92683865786756, -9.184850993605148*^-16}}], 
      LineBox[{{6.92683865786756, 1.2940952255126015`}, {13.443896805279469`, 
       1.2940952255126015`}, {13.443896805279469`, 2.4999999999999964`}, {
       6.92683865786756, 2.4999999999999964`}, {6.92683865786756, 
       1.2940952255126015`}}], 
      LineBox[{{6.92683865786756, 2.4999999999999964`}, {13.443896805279469`, 
       2.4999999999999964`}, {13.443896805279469`, 3.535533905932734}, {
       6.92683865786756, 3.535533905932734}, {6.92683865786756, 
       2.4999999999999964`}}], 
      LineBox[{{6.92683865786756, 3.535533905932737}, {13.443896805279469`, 
       3.535533905932737}, {13.443896805279469`, 4.330127018922192}, {
       6.92683865786756, 4.330127018922192}, {6.92683865786756, 
       3.535533905932737}}], 
      LineBox[{{6.92683865786756, 4.330127018922192}, {13.443896805279469`, 
       4.330127018922192}, {13.443896805279469`, 4.829629131445341}, {
       6.92683865786756, 4.829629131445341}, {6.92683865786756, 
       4.330127018922192}}], 
      LineBox[{{6.92683865786756, 4.829629131445341}, {13.443896805279469`, 
       4.829629131445341}, {13.443896805279469`, 5.}, {6.92683865786756, 
       5.}, {6.92683865786756, 4.829629131445341}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{66.42197458095559, -25.}, {70., -25.}, {
      70., -16.66666666666667}, {62.75044883428479, -16.666666666666668`}, {
      66.42197458095559, -25.}}], 
     PolygonBox[{{62.75044883428479, -16.666666666666668`}, {
      70., -16.66666666666667}, {70., -8.333333333333336}, {
      60.67375799589206, -8.333333333333336}, {
      62.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{60.67375799589206, -8.333333333333336}, {
      70., -8.333333333333336}, {70., -7.105427357601002*^-15}, {60., 0.}, {
      60.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{60., 0.}, {70., 0.}, {70., 8.333333333333332}, {
      60.67375799589206, 8.333333333333329}, {60., 0.}}], 
     PolygonBox[{{60.67375799589206, 8.333333333333329}, {70., 
      8.333333333333332}, {70., 16.666666666666664`}, {62.75044883428479, 
      16.666666666666664`}, {60.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{62.75044883428479, 16.666666666666664`}, {70., 
      16.666666666666664`}, {70., 24.999999999999996`}, {66.42197458095559, 
      24.999999999999993`}, {62.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{66.42197458095559, -25.}, {
       62.75044883428479, -16.666666666666668`}, {
       60.67375799589206, -8.333333333333336}, {
       60., -3.552713678800501*^-15}, {60.67375799589206, 
       8.333333333333329}, {62.75044883428478, 16.666666666666657`}, {
       66.42197458095559, 24.999999999999993`}, {70., 25.}, {70., 
       16.666666666666668`}, {70., 8.333333333333336}, {70., 
       3.552713678800501*^-15}, {70., -8.333333333333329}, {
       70., -16.666666666666657`}, {70., -24.999999999999993`}, {
       66.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{66.42197458095559, 0.}, {70., 3.061616997868383*^-15}, {
        70., 2.551347498223653*^-15}, {62.75044883428479, 
        5.102694996447305*^-16}, {66.42197458095559, 0.}}], 
       PolygonBox[{{62.75044883428479, 5.102694996447305*^-16}, {70., 
        2.551347498223653*^-15}, {70., 2.0410779985789223`*^-15}, {
        60.67375799589206, 1.020538999289461*^-15}, {62.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{60.67375799589206, 1.020538999289461*^-15}, {70., 
        2.0410779985789223`*^-15}, {70., 1.530808498934192*^-15}, {60., 
        1.5308084989341915`*^-15}, {60.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{60., 1.5308084989341915`*^-15}, {70., 
        1.5308084989341915`*^-15}, {70., 1.0205389992894611`*^-15}, {
        60.67375799589206, 2.041077998578922*^-15}, {60., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{60.67375799589206, 2.041077998578922*^-15}, {70., 
        1.0205389992894611`*^-15}, {70., 5.102694996447307*^-16}, {
        62.75044883428479, 2.5513474982236525`*^-15}, {60.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{62.75044883428479, 2.5513474982236525`*^-15}, {70., 
        5.102694996447308*^-16}, {70., 2.5493082627129206`*^-31}, {
        66.42197458095559, 3.0616169978683826`*^-15}, {62.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{66.42197458095559, 0.}, {62.75044883428479, 0.}, {
         60.67375799589206, 0.}, {60., 0.}, {60.67375799589206, 0.}, {
         62.75044883428478, 0.}, {66.42197458095559, 0.}, {70., 0.}, {70., 
         0.}, {70., 0.}, {70., 0.}, {70., 0.}, {70., 0.}, {70., 0.}, {
         66.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{66.42197458095559, 25.}, {70., 25.}, {70., 
       24.148145657226706`}, {66.42197458095559, 24.148145657226706`}, {
       66.42197458095559, 25.}}], 
      LineBox[{{66.42197458095559, 24.148145657226706`}, {70., 
       24.148145657226706`}, {70., 21.65063509461097}, {66.42197458095559, 
       21.65063509461097}, {66.42197458095559, 24.148145657226706`}}], 
      LineBox[{{66.42197458095559, 21.65063509461097}, {70., 
       21.65063509461097}, {70., 17.67766952966369}, {66.42197458095559, 
       17.67766952966369}, {66.42197458095559, 21.65063509461097}}], 
      LineBox[{{66.42197458095559, 17.67766952966369}, {70., 
       17.67766952966369}, {70., 12.500000000000004`}, {66.42197458095559, 
       12.500000000000004`}, {66.42197458095559, 17.67766952966369}}], 
      LineBox[{{66.42197458095559, 12.500000000000004`}, {70., 
       12.500000000000004`}, {70., 6.470476127563024}, {66.42197458095559, 
       6.470476127563024}, {66.42197458095559, 12.500000000000004`}}], 
      LineBox[{{66.42197458095559, 6.470476127563024}, {70., 
       6.470476127563024}, {70., 7.0819236220599744`*^-15}, {
       66.42197458095559, 7.0819236220599744`*^-15}, {66.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{66.42197458095559, 1.5308084989341915`*^-15}, {70., 
       1.5308084989341915`*^-15}, {70., -6.470476127563016}, {
       66.42197458095559, -6.470476127563016}, {66.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{66.42197458095559, -6.470476127563016}, {
       70., -6.470476127563016}, {70., -12.499999999999995`}, {
       66.42197458095559, -12.499999999999995`}, {
       66.42197458095559, -6.470476127563016}}], 
      LineBox[{{66.42197458095559, -12.499999999999995`}, {
       70., -12.499999999999995`}, {70., -17.677669529663685`}, {
       66.42197458095559, -17.677669529663685`}, {
       66.42197458095559, -12.499999999999995`}}], 
      LineBox[{{66.42197458095559, -17.677669529663685`}, {
       70., -17.677669529663685`}, {70., -21.65063509461097}, {
       66.42197458095559, -21.65063509461097}, {
       66.42197458095559, -17.677669529663685`}}], 
      LineBox[{{66.4219745809556, -21.650635094610962`}, {
       70., -21.650635094610962`}, {70., -24.148145657226706`}, {
       66.42197458095559, -24.148145657226706`}, {
       66.4219745809556, -21.650635094610962`}}], 
      LineBox[{{66.42197458095559, -24.148145657226706`}, {
       70., -24.148145657226706`}, {70., -25.}, {66.42197458095559, -25.}, {
       66.42197458095559, -24.148145657226706`}}], 
      LineBox[{{66.42197458095559, -25.}, {70., -25.}, {
       70., -24.148145657226706`}, {
       66.42197458095559, -24.148145657226706`}, {66.42197458095559, -25.}}], 
      LineBox[{{66.42197458095559, -24.14814565722671}, {
       70., -24.14814565722671}, {70., -21.65063509461097}, {
       66.42197458095559, -21.65063509461097}, {
       66.42197458095559, -24.14814565722671}}], 
      LineBox[{{66.42197458095559, -21.65063509461097}, {
       70., -21.65063509461097}, {70., -17.677669529663692`}, {
       66.42197458095559, -17.677669529663692`}, {
       66.42197458095559, -21.65063509461097}}], 
      LineBox[{{66.42197458095559, -17.677669529663696`}, {
       70., -17.677669529663696`}, {70., -12.50000000000001}, {
       66.42197458095559, -12.50000000000001}, {
       66.42197458095559, -17.677669529663696`}}], 
      LineBox[{{66.42197458095559, -12.50000000000001}, {
       70., -12.50000000000001}, {70., -6.470476127563038}, {
       66.42197458095559, -6.470476127563038}, {
       66.42197458095559, -12.50000000000001}}], 
      LineBox[{{66.42197458095559, -6.470476127563038}, {
       70., -6.470476127563038}, {70., -2.6796885989305705`*^-14}, {
       66.42197458095559, -2.6796885989305705`*^-14}, {
       66.42197458095559, -6.470476127563038}}], 
      LineBox[{{66.42197458095559, -4.592425496802574*^-15}, {
       70., -4.592425496802574*^-15}, {70., 6.470476127563007}, {
       66.42197458095559, 6.470476127563007}, {
       66.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{66.42197458095559, 6.470476127563007}, {70., 
       6.470476127563007}, {70., 12.499999999999984`}, {66.42197458095559, 
       12.499999999999984`}, {66.42197458095559, 6.470476127563007}}], 
      LineBox[{{66.42197458095559, 12.499999999999984`}, {70., 
       12.499999999999984`}, {70., 17.67766952966367}, {66.4219745809556, 
       17.67766952966367}, {66.42197458095559, 12.499999999999984`}}], 
      LineBox[{{66.42197458095559, 17.677669529663685`}, {70., 
       17.677669529663685`}, {70., 21.65063509461096}, {66.42197458095559, 
       21.65063509461096}, {66.42197458095559, 17.677669529663685`}}], 
      LineBox[{{66.42197458095559, 21.65063509461096}, {70., 
       21.65063509461096}, {70., 24.148145657226703`}, {66.42197458095559, 
       24.148145657226703`}, {66.42197458095559, 21.65063509461096}}], 
      LineBox[{{66.42197458095559, 24.148145657226703`}, {70., 
       24.148145657226703`}, {70., 25.}, {66.42197458095559, 25.}, {
       66.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {75., -37.5}, {75., 37.5}, {75., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {0., -37.5}, {0., -37.5}, {75., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[NCache[{{0, Rational[-75, 2]}, {0, Rational[75, 2]}, {
         0, Rational[75, 2]}, {0, Rational[-75, 2]}, {
         0, Rational[-75, 2]}}, {{0, -37.5}, {0, 37.5}, {0, 37.5}, {
         0, -37.5}, {0, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 37.5}, {75., 37.5}, {75., 37.5}, {0., 37.5}, {0., 
       37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -37.5}, {75., 37.5}, {0., 37.5}, {0., -37.5}, {
       75., -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 37.5}, {75., -37.5}, {0., -37.5}, {0., 37.5}, {75., 
       37.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -2.}, {9.113842945165278, -2.}}], 
     {Arrowheads[Small], ArrowBox[{{0., -1.}, {9.363045845772401, -1.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {9.443896805279454, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 1.}, {9.363045845772401, 1.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 2.}, {9.113842945165278, 2.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.113842945165278, -2.}, {
       13.443896805279469`, -2.4956952175595255`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.363045845772401, -1.}, {
       13.443896805279469`, -1.2262930383666837`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.443896805279454, 0.}, {13.443896805279469`, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.363045845772401, 1.}, {13.443896805279469`, 
       1.2262930383666837`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{9.113842945165278, 2.}, {13.443896805279469`, 
       2.4956952175595255`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.443896805279469`, -2.4956952175595255`}, {
       60.85303894314536, -9.368567304762962}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.443896805279469`, -1.2262930383666837`}, {
       60.19197643983885, -4.458650196369402}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.443896805279469`, 0.}, {60.00000000000001, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.443896805279469`, 1.2262930383666837`}, {
       60.19197643983885, 4.458650196369402}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{13.443896805279469`, 2.4956952175595255`}, {
       60.85303894314536, 9.368567304762962}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.85303894314536, -9.368567304762962}, {
       70., -9.820937242117102}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.19197643983885, -4.458650196369402}, {
       70., -4.710945294665234}}]}, 
     {Arrowheads[Small], ArrowBox[{{60.00000000000001, 0.}, {70., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.19197643983885, 4.458650196369402}, {70., 
       4.710945294665234}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.85303894314536, 9.368567304762962}, {70., 
       9.820937242117102}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., -9.820937242117102}, {75., -10.197171469841576`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., -4.710945294665234}, {75., -4.9064067339952775`}}]}, 
     {Arrowheads[Small], ArrowBox[{{70., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., 4.710945294665234}, {75., 4.9064067339952775`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70., 9.820937242117102}, {75., 10.197171469841576`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/WtXzHxPKyUHBgg4wCeqqvpwJ4z/Yf+hT1qFbo/h
8gxo8vZo+h1OgdVrOVjMfcir/535AIx/r+9j0dN5n/fD+DDz0OTt0fQ7cDb7
Jhrk+jk8WDnh1pY9SgfeRkmunyTh5zD3+rLUFVcFDzCCTfGDm4cmj64foq4h
0MH6zd1HgUuUD8D4tiHi3Ew3hOB8BmSAkEfXD+EfCHL4H7F2xecUlQMwvlSn
rZjmAmE4H8U8hDy6fgcA1vCBkQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"Big Lens\"\>", {65., -26.907886858793663`}, {0., 0.}], 
    InsetBox["\<\"Magnified Lens\"\>", {15., -10.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>Automatic,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731733566001*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"},
 CellLabel->"During evaluation of In[10]:="]
}, Open  ]],

Cell[TextData[{
 "Graphics incorporating the ",
 StyleBox["Magnification", "MB"],
 " option require care in interpretation.  ",
 "Optica",
 " magnifies the ray intercepts on the altered lens so that they emerge from  \
the same relative positions on the surface.  Technically, the graphics no  \
longer match the actual physics.  The angles of the rays have changed to  \
follow the graphical magnification.  The trace data is identical, however.   \
Only the visual representation has changed."
}], "Text",
 CellChangeTimes->{3.5661589473877*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.2 Manual Graphics Control", "Subsection",
 CellTags->{
  "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
   "PR6.2.2"}],

Cell[TextData[{
 "Optica",
 "'s graphics are often the best feedback about a system's performance.  ",
 StyleBox["AnalyzeSystem", "MB"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " produces graphics automatically."
}], "Text",
 CellChangeTimes->{3.566158947458276*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell["\<\
However, Optica can also trace systems without producing graphics.  The \
primary advantage  of doing so is speed.  The speed advantage is especially \
important within  iterative design loops.  Some parameter increments with \
each iteration, and  you are mostly interested in numerical results.\
\>", "Text",
 CellChangeTimes->{3.566158947554105*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell[TextData[{
 "The ",
 "Optica",
 " function for tracing without graphics is called ",
 StyleBox["PropagateSystem", "MB"],
 " or ",
 StyleBox["TurboTrace", "Input"],
 ".  When you call ",
 StyleBox["PropagateSystem", "MB"],
 "/",
 StyleBox["TurboTrace", "Input"],
 " be sure to assign its return value into a variable.  Otherwise there  will \
be no data source for subsequent data extraction."
}], "Text",
 CellChangeTimes->{3.5661589476588173`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"PropagateSystem", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LineOfRays", "[", 
       RowBox[{"40", ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "7"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"SphericalLens", "[", 
         RowBox[{"30", ",", 
          RowBox[{"-", "30"}], ",", "50", ",", "40"}], "]"}], ",", "10"}], 
       "]"}], ",", 
      RowBox[{"Boundary", "[", "75", "]"}]}], "\[IndentingNewLine]", "}"}], 
    "]"}]}], ";"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"},
 CellLabel->"In[12]:="],

Cell[TextData[{
 "Now ",
 StyleBox["sys", "MB"],
 " holds the result of the trace.  If you later desire a visualization, do  \
not recompute ",
 StyleBox["sys", "MB"],
 " with ",
 StyleBox["AnalyzeSystem", "MB"],
 ".  Instead, use ",
 StyleBox["ShowSystem", "MB"],
 ".  This function produces a graphic without performing trace  \
computations."
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowSystem", "[", "sys", "]"}], ";"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"},
 CellLabel->"In[13]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{23.416876048223, -25., 0.}, {36.583123951777, -25., 
      6.123233995736766*^-15}, {44.944382578492934`, -16.66666666666667, 
      5.102694996447306*^-15}, {15.055617421507058`, -16.666666666666668`, 
      0.}, {23.416876048223, -25., 0.}}], 
     Polygon3DBox[{{15.055617421507058`, -16.666666666666668`, 0.}, {
      44.944382578492934`, -16.66666666666667, 5.102694996447306*^-15}, {
      48.81936077631764, -8.333333333333336, 4.0821559971578446`*^-15}, {
      11.180639223682363`, -8.333333333333336, 0.}, {
      15.055617421507058`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{11.180639223682363`, -8.333333333333336, 0.}, {
      48.81936077631764, -8.333333333333336, 4.0821559971578446`*^-15}, {
      50., -7.105427357601002*^-15, 3.061616997868384*^-15}, {10., 0., 0.}, {
      11.180639223682363`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{10., 0., 0.}, {50., 0., 3.061616997868383*^-15}, {
      48.81936077631764, 8.333333333333332, 2.0410779985789223`*^-15}, {
      11.180639223682359`, 8.333333333333329, 0.}, {10., 0., 0.}}], 
     Polygon3DBox[{{11.180639223682359`, 8.333333333333329, 0.}, {
      48.81936077631764, 8.333333333333332, 2.0410779985789223`*^-15}, {
      44.94438257849295, 16.666666666666664`, 1.0205389992894613`*^-15}, {
      15.055617421507055`, 16.666666666666664`, 0.}, {11.180639223682359`, 
      8.333333333333329, 0.}}], 
     Polygon3DBox[{{15.055617421507055`, 16.666666666666664`, 0.}, {
      44.94438257849295, 16.666666666666664`, 1.0205389992894615`*^-15}, {
      36.583123951777004`, 24.999999999999996`, 5.098616525425841*^-31}, {
      23.416876048222992`, 24.999999999999993`, 0.}, {15.055617421507055`, 
      16.666666666666664`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK6f1Zi8I8vcgQEMLA8wQMGd138eVcroOaxeBQIG
cPEEvZ59NTFqDmvA4gpwcQhQgZrzYQ9MJA6qfgVEvQNM/AbUfIi4AVy8Fuqe
f/9BwAIufsDI/txiLyeYO+HinEcd2h9WuMHcCRfP+BJz4UGGB8ydcHEI8IS5
0wZd/Qo0f3FBzV+BFg6HoO6BuhMujis8ARLsaxs=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{23.416876048223, 0., -25.}, {36.583123951777, 
        3.061616997868383*^-15, -25.}, {44.944382578492934`, 
        2.551347498223653*^-15, -16.66666666666667}, {15.055617421507058`, 
        5.102694996447305*^-16, -16.666666666666668`}, {23.416876048223, 
        0., -25.}}], 
       Polygon3DBox[{{15.055617421507058`, 
        5.102694996447305*^-16, -16.666666666666668`}, {44.944382578492934`, 
        2.551347498223653*^-15, -16.66666666666667}, {48.81936077631764, 
        2.0410779985789223`*^-15, -8.333333333333336}, {11.180639223682363`, 
        1.020538999289461*^-15, -8.333333333333336}, {15.055617421507058`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{11.180639223682363`, 
        1.020538999289461*^-15, -8.333333333333336}, {48.81936077631764, 
        2.0410779985789223`*^-15, -8.333333333333336}, {50., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {10., 
        1.5308084989341915`*^-15, 0.}, {11.180639223682363`, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{10., 1.5308084989341915`*^-15, 0.}, {50., 
        1.5308084989341915`*^-15, 0.}, {48.81936077631764, 
        1.0205389992894611`*^-15, 8.333333333333332}, {11.180639223682359`, 
        2.041077998578922*^-15, 8.333333333333329}, {10., 
        1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{11.180639223682359`, 2.041077998578922*^-15, 
        8.333333333333329}, {48.81936077631764, 1.0205389992894611`*^-15, 
        8.333333333333332}, {44.94438257849295, 5.102694996447307*^-16, 
        16.666666666666664`}, {15.055617421507055`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {11.180639223682359`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{15.055617421507055`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {44.94438257849295, 5.102694996447308*^-16, 
        16.666666666666664`}, {36.583123951777004`, 2.5493082627129206`*^-31, 
        24.999999999999996`}, {23.416876048222992`, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {15.055617421507055`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK6f1Zi8I8vcgQEFWB648/rPo0oZPbj46lUgYHAg
Qa9nX02MGlx8DVhc4QCEp4Jmzoc9cWjqV0DUO9xAMx8ibuBQi+aef/9BwMLh
gJH9ucVeTujudOA86tD+sMIN3Z0OGV9iLjzI8EB3J5Tvie5OG3T1UHce4EIz
H+rOA4fQ3AN15wFc4QkAVLZrGw==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{23.416876048223, 25., 0.}, {36.583123951777, 25., 0.}, {
       36.583123951777, 24.148145657226706`, 6.4704761275630185`}, {
       23.416876048223, 24.148145657226706`, 6.4704761275630185`}, {
       23.416876048223, 25., 0.}}], 
      Line3DBox[{{23.416876048223, 24.148145657226706`, 
       6.4704761275630185`}, {36.583123951777, 24.148145657226706`, 
       6.4704761275630185`}, {36.583123951777, 21.65063509461097, 
       12.499999999999998`}, {23.416876048223003`, 21.65063509461097, 
       12.499999999999998`}, {23.416876048223, 24.148145657226706`, 
       6.4704761275630185`}}], 
      Line3DBox[{{23.416876048223003`, 21.65063509461097, 
       12.499999999999998`}, {36.583123951777, 21.65063509461097, 
       12.499999999999998`}, {36.583123951777004`, 17.67766952966369, 
       17.677669529663685`}, {23.416876048222996`, 17.67766952966369, 
       17.677669529663685`}, {23.416876048223003`, 21.65063509461097, 
       12.499999999999998`}}], 
      Line3DBox[{{23.416876048222996`, 17.67766952966369, 
       17.677669529663685`}, {36.583123951777004`, 17.67766952966369, 
       17.677669529663685`}, {36.583123951777, 12.500000000000004`, 
       21.650635094610966`}, {23.416876048223003`, 12.500000000000004`, 
       21.650635094610966`}, {23.416876048222996`, 17.67766952966369, 
       17.677669529663685`}}], 
      Line3DBox[{{23.416876048223003`, 12.500000000000004`, 
       21.650635094610966`}, {36.583123951777, 12.500000000000004`, 
       21.650635094610966`}, {36.583123951777, 6.470476127563024, 
       24.148145657226706`}, {23.416876048223, 6.470476127563024, 
       24.148145657226706`}, {23.416876048223003`, 12.500000000000004`, 
       21.650635094610966`}}], 
      Line3DBox[{{23.416876048223, 6.470476127563024, 24.148145657226706`}, {
       36.583123951777, 6.470476127563024, 24.148145657226706`}, {
       36.583123951777, 7.0819236220599744`*^-15, 25.}, {23.416876048223, 
       7.0819236220599744`*^-15, 25.}, {23.416876048223, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{23.416876048223, 1.5308084989341915`*^-15, 25.}, {
       36.583123951777, 1.5308084989341915`*^-15, 25.}, {
       36.583123951777004`, -6.470476127563016, 24.148145657226706`}, {
       23.416876048222996`, -6.470476127563016, 24.148145657226706`}, {
       23.416876048223, 1.5308084989341915`*^-15, 25.}}], 
      Line3DBox[{{23.416876048222996`, -6.470476127563016, 
       24.148145657226706`}, {36.583123951777004`, -6.470476127563016, 
       24.148145657226706`}, {36.583123951777, -12.499999999999995`, 
       21.65063509461097}, {23.416876048223, -12.499999999999995`, 
       21.65063509461097}, {23.416876048222996`, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{23.416876048223, -12.499999999999995`, 21.65063509461097}, {
       36.583123951777, -12.499999999999995`, 21.65063509461097}, {
       36.583123951777004`, -17.677669529663685`, 17.67766952966369}, {
       23.416876048222996`, -17.677669529663685`, 17.67766952966369}, {
       23.416876048223, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{23.416876048222996`, -17.677669529663685`, 
       17.67766952966369}, {36.583123951777004`, -17.677669529663685`, 
       17.67766952966369}, {36.583123951777, -21.65063509461097, 
       12.499999999999998`}, {23.416876048223003`, -21.65063509461097, 
       12.499999999999998`}, {23.416876048222996`, -17.677669529663685`, 
       17.67766952966369}}], 
      Line3DBox[{{23.416876048223003`, -21.650635094610962`, 
       12.500000000000009`}, {36.583123951777, -21.650635094610962`, 
       12.500000000000009`}, {36.583123951777, -24.148145657226706`, 
       6.470476127563026}, {23.416876048223, -24.148145657226706`, 
       6.470476127563026}, {23.416876048223003`, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{23.416876048223, -24.148145657226706`, 6.470476127563026}, {
       36.583123951777, -24.148145657226706`, 6.470476127563026}, {
       36.583123951777, -25., 3.061616997868383*^-15}, {23.416876048223, -25.,
        3.061616997868383*^-15}, {23.416876048223, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{23.416876048223, -25., 3.061616997868383*^-15}, {
       36.583123951777, -25., 3.061616997868383*^-15}, {
       36.583123951777, -24.148145657226706`, -6.47047612756302}, {
       23.416876048223, -24.148145657226706`, -6.47047612756302}, {
       23.416876048223, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       23.416876048223003`, -24.14814565722671, -6.470476127563009}, {
       36.583123951777, -24.14814565722671, -6.470476127563009}, {
       36.583123951777, -21.65063509461097, -12.499999999999993`}, {
       23.416876048223, -21.65063509461097, -12.499999999999993`}, {
       23.416876048223003`, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       23.416876048223, -21.65063509461097, -12.499999999999993`}, {
       36.583123951777, -21.65063509461097, -12.499999999999993`}, {
       36.583123951777, -17.677669529663692`, -17.677669529663685`}, {
       23.416876048223003`, -17.677669529663692`, -17.677669529663685`}, {
       23.416876048223, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       23.416876048222996`, -17.677669529663696`, -17.677669529663678`}, {
       36.583123951777004`, -17.677669529663696`, -17.677669529663678`}, {
       36.583123951777004`, -12.50000000000001, -21.65063509461096}, {
       23.416876048222996`, -12.50000000000001, -21.65063509461096}, {
       23.416876048222996`, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       23.416876048222996`, -12.50000000000001, -21.65063509461096}, {
       36.583123951777004`, -12.50000000000001, -21.65063509461096}, {
       36.583123951777, -6.470476127563038, -24.148145657226703`}, {
       23.416876048223003`, -6.470476127563038, -24.148145657226703`}, {
       23.416876048222996`, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       23.416876048223003`, -6.470476127563038, -24.148145657226703`}, {
       36.583123951777, -6.470476127563038, -24.148145657226703`}, {
       36.583123951777, -2.6796885989305705`*^-14, -25.}, {
       23.416876048223, -2.6796885989305705`*^-14, -25.}, {
       23.416876048223003`, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{23.416876048223, -4.592425496802574*^-15, -25.}, {
       36.583123951777, -4.592425496802574*^-15, -25.}, {36.583123951777, 
       6.470476127563007, -24.14814565722671}, {23.416876048223, 
       6.470476127563007, -24.14814565722671}, {
       23.416876048223, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{23.416876048223, 6.470476127563007, -24.14814565722671}, {
       36.583123951777, 6.470476127563007, -24.14814565722671}, {
       36.583123951777, 12.499999999999984`, -21.650635094610976`}, {
       23.416876048223, 12.499999999999984`, -21.650635094610976`}, {
       23.416876048223, 6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{23.416876048223, 
       12.499999999999984`, -21.650635094610976`}, {36.583123951777, 
       12.499999999999984`, -21.650635094610976`}, {36.583123951777, 
       17.67766952966367, -17.67766952966371}, {23.416876048223003`, 
       17.67766952966367, -17.67766952966371}, {23.416876048223, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{23.416876048223003`, 
       17.677669529663685`, -17.677669529663692`}, {36.583123951777, 
       17.677669529663685`, -17.677669529663692`}, {36.583123951777004`, 
       21.65063509461096, -12.50000000000001}, {23.416876048222996`, 
       21.65063509461096, -12.50000000000001}, {23.416876048223003`, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{23.416876048222996`, 
       21.65063509461096, -12.50000000000001}, {36.583123951777004`, 
       21.65063509461096, -12.50000000000001}, {36.583123951777, 
       24.148145657226703`, -6.470476127563039}, {23.416876048223003`, 
       24.148145657226703`, -6.470476127563039}, {23.416876048222996`, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{23.416876048223003`, 
       24.148145657226703`, -6.470476127563039}, {36.583123951777, 
       24.148145657226703`, -6.470476127563039}, {36.583123951777, 
       25., -2.8327694488239898`*^-14}, {23.416876048223, 
       25., -2.8327694488239898`*^-14}, {23.416876048223003`, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., 37.5, -37.5}, {75., -37.5, -37.5}, {75., -37.5, 
       37.5}, {75., 37.5, 37.5}, {75., 37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., -37.5, -37.5}, {0., -37.5, -37.5}, {0., -37.5, 37.5}, {
       75., -37.5, 37.5}, {75., -37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[
       NCache[{{0, Rational[-75, 2], Rational[-75, 2]}, {
         0, Rational[75, 2], Rational[-75, 2]}, {
         0, Rational[75, 2], Rational[75, 2]}, {
         0, Rational[-75, 2], Rational[75, 2]}, {
         0, Rational[-75, 2], Rational[-75, 2]}}, {{0, -37.5, -37.5}, {
         0, 37.5, -37.5}, {0, 37.5, 37.5}, {0, -37.5, 37.5}, {
         0, -37.5, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 37.5, -37.5}, {75., 37.5, -37.5}, {75., 37.5, 37.5}, {
       0., 37.5, 37.5}, {0., 37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., -37.5, -37.5}, {75., 37.5, -37.5}, {0., 37.5, -37.5}, {
       0., -37.5, -37.5}, {75., -37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., 37.5, 37.5}, {75., -37.5, 37.5}, {0., -37.5, 37.5}, {
       0., 37.5, 37.5}, {75., 37.5, 37.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGAQBWImIAaxUYHJARhLj6+pdtViQwd0cRhYvQoEtODiC56l
XM900HJAF4eBNWBxKbh4wgvjfv4GVQd0cfxAxQGXzAqIOXB5mPno4qjqteDi
86DuRxdHBSZwcbTwwSV+AG7+TzHl0lvuDjp8ni9+MqrDxXGF2/SjO+dkdHo4
hFvM8pk7XRYujivcDsaWe/Y99nDIs1OWitDghYtDAK5w88QQxxVuMPOzIObD
xXGFG8z9IRD34wofhDmo4YNLHNVfB4IcpDLbjaWXGWHYix5uMPVCzm+e6bDw
YfgLa7gB1TtICizY0fjBnlC4wdSjC+EKN5h6G4j5+9Hdjx5ucPMh7oe7E1e4
wdRDwweuHgAuVdHI
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQBWJmINbja6pdtdjQgQEMTA4wQMGCZynXMx20HFavAgEt
uHjCC+N+/gZVhzVgcSm4OASoODCgAZj6FRD1cPl5UPMh4lpwcTT3INT/FFMu
veXuoMPn+eInozrc3ulHd87J6PRwCLeY5TN3uixc/GBsuWffYw+HPDtlqQgN
XjR3emK4E6Y+C6IeLg8zPwRiPi73oJp3IMhBKrPdWHqZEYa4kPObZzosfBji
DpICC3Y0frBHF0d3J0zcBqJ+P4Z6iPkH0MWh7oGLAwDvlW2v
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317340048037`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"},
 CellLabel->"During evaluation of In[13]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["ShowSystem", "MB"],
 " produces a graphic without recomputing the system."
}], "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell[TextData[{
 StyleBox["AnalyzeSystem", "MB"],
 " effectively calls ",
 StyleBox["PropagateSystem", "MB"],
 " to calculate a trace, and ",
 StyleBox["ShowSystem", "MB"],
 " to display it."
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell["\<\
Optica's turbo trace capability presents a parallel suite of functions for \
turbo  systems.  These functions are discussed in a later section.\
\>", "Text",
 CellChangeTimes->{3.56615894774664*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.3 Custom Graphics", "Subsection",
 CellTags->{
  "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 "Optica",
 " graphics are ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics.  You can edit them using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics primitives.  These include lines, circles, text, solids, and  \
other objects.  There are several ways to customize graphics with these  \
objects."
}], "Text",
 CellChangeTimes->{3.566158947858891*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " features an ",
 StyleBox["Epilog", "MB"],
 " option to permit customization of graphical output.  ",
 StyleBox["Epilog", "MB"],
 " defines a list of graphics primitives for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to insert into the output.   "
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Sin", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"Epilog", " ", "\[Rule]", " ", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"Sin", "[", "2", "]"}]}], "}"}]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"In[14]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwlmXk4lN/7x61ZUmaeISRF+0pKaaH7VEKRUqJFSFpIEhGSSiUk2SvZUpb4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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->LineBox[
    NCache[{{2, 0}, {2, 
       Sin[2]}}, {{2, 0}, {2, 0.9092974268256817}}]],
  Method->{},
  PlotRange->
   NCache[{{0, 2 Pi}, {-0.9999998592131705, 0.9999998782112116}}, {{
     0, 6.283185307179586}, {-0.9999998592131705, 0.9999998782112116}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5633677820686283`*^9, 3.5661588642005377`*^9, 
  3.5661589716592216`*^9, 3.5672683021888237`*^9, 3.614729563483198*^9, 
  3.614730559694756*^9, 3.6147317340664797`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[{
 "Use of ",
 StyleBox["Epilog", "MB"],
 " to customize graphics."
}], "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 "However, ",
 StyleBox["pilog", "MB"],
 " can only augment graphics, not alter them.  For alterations you will need  \
the underlying primitives.  Optica includes a mechanism to fill this need.  \
The ",
 StyleBox["OutputType", "MB"],
 " option for ",
 StyleBox["AnalyzeSystem", "MB"],
 " and ",
 StyleBox["ShowSystem", "MB"],
 "  has a special setting, ",
 StyleBox["StandardGraphics", "MB"],
 ".  Under this setting, ",
 "Optica",
 " changes the output type to standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics."
}], "Text",
 CellChangeTimes->{{3.5661589479486313`*^9, 3.566158948060937*^9}},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 "Optica",
 " normally returns an optical system.  The optional behavior instead  \
returns graphics.  This output is the normal kind that you get from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " after calling any graphics function.  For instance, the return value from  \
",
 StyleBox["Plot", "MB"],
 " is of type ",
 StyleBox["Graphics.", "MB"]
}], "Text",
 CellChangeTimes->{3.566158948160866*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "result", "]"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"In[15]:="],

Cell[BoxData["Graphics"], "Output",
 CellChangeTimes->{3.563367782120838*^9, 3.5661588642384577`*^9, 
  3.566158971692683*^9, 3.567268302240336*^9, 3.614729563526155*^9, 
  3.6147305599118347`*^9, 3.614731734093135*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
 "In three dimensions, it is ",
 StyleBox["Graphics3D", "MB"],
 " or possibly ",
 StyleBox["SurfaceGraphics", "MB"],
 ".  Usually you would employ a semicolon to suppress the output echo from  \
the ",
 StyleBox["Plot", "MB"],
 " call, which otherwise consumes memory."
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell["You can see the individual graphics primitives. ", "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InputForm", "[", "result", "]"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"In[16]:="],

Cell["\<\
Graphics[{{{}, {}, {Hue[0.67, 0.6, 0.6], Line[{{1.2822827157509358*^-7, \
1.2822827157509324*^-7}, {0.0019271655319089223, 0.001927164339004283}, 
     {0.0038542028355462695, 0.00385419329326691}, {0.007708277442820964, \
0.007708201108565738}, {0.015416426657370353, 0.015415816004008815}, 
     {0.030832725086469132, 0.030827840094677948}, {0.06166532194466669, \
0.061626247826437476}, {0.1233305156610618, 0.12301810194283724}, 
     {0.2570347881802097, 0.2542138749185557}, {0.3818787050494512, \
0.3726645007390021}, {0.504273679847541, 0.4831716559080398}, 
     {0.6370425397319885, 0.5948206667810294}, {0.7609510439665297, \
0.6896104843619676}, {0.8952334332874284, 0.7803550768254575}, 
     {0.8972933309007058, 0.7816415498416075}, {0.8993532285139831, \
0.7829247062145637}, {0.9034730237405377, 0.7854810472663536}, 
     {0.9117126141936469, 0.7905536910323366}, {0.9281917950998653, \
0.8005376246467047}, {0.961150156912302, 0.8198506642936907}, 
     {1.0270668805371757, 0.855785278429456}, {1.0289883350934232, \
0.8567777264106476}, {1.0309097896496706, 0.8577670111800607}, 
     {1.0347526987621656, 0.8597360764855387}, {1.0424385169871557, \
0.8636360886325238}, {1.0578101534371358, 0.8712828366943681}, 
     {1.088553426337096, 0.8859569678649591}, {1.0904748808933435, \
0.8868464399329709}, {1.092396335449591, 0.8877326377759202}, 
     {1.0962392445620859, 0.8894951977114104}, {1.103925062787076, \
0.8929808837325072}, {1.119296699237056, 0.8997938037956826}, 
     {1.1500399721370163, 0.9127802676472789}, {1.152123518647738, \
0.9136293123298869}, {1.15420706515846, 0.9144743907973655}, 
     {1.1583741581799036, 0.9161526344296697}, {1.166708344222791, \
0.9194613668487993}, {1.1833767163085658, 0.9258870137580502}, 
     {1.2167134604801153, 0.9379648812640387}, {1.2187970069908372, \
0.9386852734597927}, {1.220880553501559, 0.9394015906683686}, 
     {1.2250476465230027, 0.9408219877030862}, {1.23338183256589, \
0.9436137462886434}, {1.2500502046516648, 0.9490004488089845}, 
     {1.2833869488232146, 0.9589814532774429}, {1.2853320522769067, \
0.9595310149939811}, {1.2872771557305986, 0.9600769463956869}, 
     {1.291167362637983, 0.9611579100063794}, {1.298947776452751, \
0.9632761834893663}, {1.3145086040822878, 0.9673376713325591}, 
     {1.3164537075359797, 0.9678289078627277}, {1.3183988109896718, \
0.9683164826835982}, {1.3222890178970559, 0.9692806398324919}, 
     {1.3300694317118242, 0.9711649333808123}, {1.3456302593413607, \
0.9747570429220562}, {1.3475753627950526, 0.9751894785134673}, 
     {1.3495204662487448, 0.9756182245474039}, {1.3534106731561288, \
0.9764646414683034}, {1.3611910869708972, 0.9781131301827487}, 
     {1.3767519146004337, 0.9812323825384774}, {1.3786970180541256, \
0.9816055983862323}, {1.3806421215078177, 0.9819751004015963}, 
     {1.3845323284152018, 0.982702957357274}, {1.3923127422299701, \
0.9841140447107248}, {1.4078735698595066, 0.9867574189497462}, 
     {1.409780408593337, 0.9870649196839719}, {1.4116872473271673, \
0.9873688314177196}, {1.415500924794828, 0.9879658834767021}, 
     {1.4231282797301492, 0.9891168718422977}, {1.4250351184639793, \
0.989395630363058}, {1.4269419571978097, 0.9896707914087998}, 
     {1.4307556346654704, 0.9902103170863328}, {1.4383829896007918, \
0.9912461555962515}, {1.4402898283346222, 0.9914961070359759}, 
     {1.4421966670684525, 0.9917424533632795}, {1.446010344536113, \
0.992224327110842}, {1.4536376994714342, 0.9931447747237425}, 
     {1.4688924093420768, 0.9948122874129468}, {1.470799248075907, \
0.9950044569152444}, {1.4727060868097372, 0.9951930085486457}, 
     {1.476519764277398, 0.9955592554795967}, {1.4841471192127194, \
0.9962483056308926}, {1.4860539579465497, 0.9964115137227522}, 
     {1.48796079668038, 0.9965710988296106}, {1.4917744741480405, \
0.9968793977804729}, {1.4994018290833617, 0.9974524952137558}, 
     {1.501308667817192, 0.9975867039163834}, {1.5032155065510224, \
0.9977172853609797}, {1.5070291840186831, 0.9979675645900754}, 
     {1.5089360227525135, 0.9980872614645513}, {1.5108428614863438, \
0.9982033292609522}, {1.5146565389540043, 0.998424575944621}, 
     {1.5165633776878344, 0.9985297540274285}, {1.5184702164216648, \
0.9986313014232436}, {1.5222838938893255, 0.9988235026901806}, 
     {1.5241907326231559, 0.9989141558624522}, {1.5260975713569862, \
0.9990011769500338}, {1.529911248824647, 0.9991643216186877}, 
     {1.5319801795129515, 0.9992467479388707}, {1.5340491102012561, \
0.9993248970106624}, {1.5361180408895607, 0.9993987684995479}, 
     {1.5381869715778655, 0.9994683620893222}, {1.5402559022661704, \
0.999533677482092}, {1.542324832954475, 0.9995947143982763}, 
     {1.5464626943310842, 0.9997039517741367}, {1.5485316250193888, \
0.9997521517662251}, {1.5506005557076934, 0.9997960723465549}, 
     {1.552669486395998, 0.9998357133271253}, {1.5547384170843028, \
0.9998710745382542}, {1.5568073477726077, 0.9999021558285789}, 
     {1.5588762784609123, 0.9999289570650568}, {1.5609452091492169, \
0.9999514781329658}, {1.5630141398375215, 0.9999697189359052}, 
     {1.565083070525826, 0.9999836793957958}, {1.5671520012141307, \
0.9999933594528801}, {1.5692209319024353, 0.9999987590657231}, 
     {1.57128986259074, 0.9999998782112116}, {1.573358793279045, \
0.9999967168845553}, {1.5754277239673495, 0.9999892750992861}, 
     {1.5774966546556541, 0.9999775528872585}, {1.5795655853439587, \
0.999961550298649}, {1.5816345160322633, 0.9999412674019562}, 
     {1.583703446720568, 0.9999167042840006}, {1.5857723774088726, \
0.9998878610499239}, {1.5878413080971774, 0.9998547378231887}, 
     {1.5899102387854822, 0.9998173347455782}, {1.5919791694737868, \
0.9997756519771952}, {1.5940481001620914, 0.9997296896964616}, 
     {1.596117030850396, 0.9996794481001177}, {1.5981859615387006, \
0.9996249274032214}, {1.6002548922270052, 0.9995661278391469}, 
     {1.6023238229153098, 0.9995030496595841}, {1.6043927536036147, \
0.9994356931345377}, {1.6064616842919195, 0.9993640585523252}, 
     {1.608530614980224, 0.9992881462195765}, {1.6126684763568333, \
0.9991234896205428}, {1.614737407045138, 0.9990347460590658}, 
     {1.6168063377334425, 0.9989417261566658}, {1.620944199110052, \
0.9987428589400763}, {1.6292199218632706, 0.9982938271614664}, 
     {1.6312888525515752, 0.9981708850461833}, {1.6333577832398798, \
0.9980436702877108}, {1.6374956446164892, 0.9977764250376405}, 
     {1.6457713673697079, 0.9971906880040196}, {1.6478402980580125, \
0.9970335810141968}, {1.649909228746317, 0.9968722062493834}, 
     {1.6540470901229263, 0.9965366561760906}, {1.662322812876145, \
0.9958143743466595}, {1.6642533005074198, 0.9956360747050302}, 
     {1.6661837881386945, 0.995454064545459}, {1.6700447634012443, \
0.9950789153995656}, {1.677766713926344, 0.9942841216643886}, 
     {1.6796972015576188, 0.9940761576460222}, {1.6816276891888937, \
0.9938644889231839}, {1.6854886644514433, 0.9934300405332672}, 
     {1.6932106149765427, 0.9925167229335421}, {1.6951411026078176, \
0.9922791441397993}, {1.6970715902390925, 0.992037867338661}, 
     {1.7009325655016423, 0.9915442233247193}, {1.7086545160267417, \
0.990512599695223}, {1.7240984170769407, 0.9882722299515398}, 
     {1.7260289047082156, 0.9879755986512128}, {1.7279593923394905, \
0.987675285381863}, {1.7318203676020403, 0.9870636174266212}, 
     {1.7395423181271397, 0.9857961480515994}, {1.7549862191773387, \
0.9830849445640588}, {1.7858740212777366, 0.9769598153400458}, 
     {1.7879666008634858, 0.9765110713568594}, {1.790059180449235, \
0.9760580513413295}, {1.7942443396207335, 0.9751391911668498}, 
     {1.8026146579637303, 0.9732502469670653}, {1.819355294649724, \
0.9692679326365597}, {1.8528365680217114, 0.9604896062780456}, 
     {1.8549291476074605, 0.9599051056843635}, {1.8570217271932097, \
0.959316401773997}, {1.8612068863647082, 0.9581263943330792}, 
     {1.869577204707705, 0.9556960543090358}, {1.8863178413936987, \
0.9506346758110856}, {1.9197991147656859, 0.9397141875380657}, 
     {1.9218534296315735, 0.9390097098112606}, {1.9239077444974608, \
0.9383012692680873}, {1.9280163742292356, 0.936872511708413}, 
     {1.9362336336927854, 0.9339675754613147}, {1.9526681526198852, \
0.9279687105727975}, {1.9855371904740848, 0.9152207709228335}, 
     {2.0512752661824836, 0.8867736568214569}, {2.053191137991341, \
0.8858865063862249}, {2.055107009800199, 0.8849961042481709}, 
     {2.058938753417914, 0.883205557948632}, {2.066602240653345, \
0.8795855895181172}, {2.081929215124206, 0.8721908974026384}, 
     {2.112583164065929, 0.8567886352600307}, {2.1738910619493748, \
0.8235842465112402}, {2.175969025712707, 0.8224038607722788}, 
     {2.178046989476039, 0.8212199239494951}, {2.182202917002703, \
0.818841417516406}, {2.190514772056031, 0.8140420176039472}, 
     {2.207138482162687, 0.804274835207209}, {2.2403859023759995, \
0.7840764676698918}, {2.306880742802624, 0.7411031219178127}, 
     {2.4310100680059663, 0.6522754710746894}, {2.5655132782956667, \
0.5447402771484026}, {2.697567546514215, 0.42957772713203446}, 
     {2.820761459082857, 0.3153554511260218}, {2.954329256737857, \
0.1861708352681441}, {3.0790366987429505, 0.06251516334017572}, 
     {3.2012951986768923, -0.05966708417636863}, {3.3339275836971916, \
-0.19115128932767655}, {3.4576996130675846, -0.3108687742575189}, 
     {3.5918455275243355, -0.43519321980343784}, {3.7235424999099345, \
-0.549653867612323}, {3.846379116645627, -0.6478711825589064}, 
     {3.9795896184676773, -0.7433046755726647}, {3.981532589501617, \
-0.7446030280816351}, {3.983475560535557, -0.7458985696134667}, 
     {3.987361502603436, -0.7484812001929632}, {3.9951333867391954, \
-0.7536125151423854}, {4.010677155010713, -0.7637382790138112}, 
     {4.041764691553749, -0.7834338385481846}, {4.103939764639821, \
-0.8205354257281964}, {4.105844470953899, -0.8216226585479436}, 
     {4.107749177267976, -0.8227069105987015}, {4.111558589896132, \
-0.8248664566698257}, {4.1191774151524445, -0.8291496072337002}, 
     {4.134415065665069, -0.8375712755391325}, {4.164890366690317, \
-0.8538292962794404}, {4.166795073004395, -0.8548192476558022}, 
     {4.168699779318473, -0.855806097829102}, {4.172509191946629, \
-0.8577704802569843}, {4.180128017202941, -0.861661873902663}, 
     {4.195365667715565, -0.8692943895789487}, {4.225840968740814, \
-0.8839521934370734}, {4.227907767009366, -0.884916692708362}, 
     {4.229974565277918, -0.8858774119221074}, {4.234108161815023, \
-0.8877874937776966}, {4.242375354889233, -0.8915621173125434}, 
     {4.258909741037652, -0.8989283062064903}, {4.291978513334489, \
-0.9129214911665804}, {4.294045311603041, -0.91376307387258}, 
     {4.2961121098715935, -0.9146007532992904}, {4.300245706408699, \
-0.9162643880184258}, {4.308512899482908, -0.9195446617800588}, 
     {4.325047285631326, -0.9259164475524849}, {4.358116057928164, \
-0.9378989661064421}, {4.360044413139687, -0.9385661847535481}, 
     {4.36197276835121, -0.9392299132928624}, {4.365829478774255, \
-0.9405468901886643}, {4.373542899620345, -0.9431388549606081}, 
     {4.3889697413125255, -0.948154293060208}, {4.419823424696887, \
-0.9575070963446649}, {4.421751779908409, -0.9580614720957839}, 
     {4.423680135119932, -0.9586122852448582}, {4.427536845542977, \
-0.9597032155572174}, {4.435250266389067, -0.9618422357239117}, 
     {4.450677108081248, -0.9659484732670754}, {4.481530791465609, \
-0.9734703886979993}, {4.483621238631606, -0.9739465828809345}, 
     {4.485711685797603, -0.9744185209487001}, {4.489892580129597, \
-0.9753496205079142}, {4.498254368793584, -0.9771606567479661}, 
     {4.51497794612156, -0.9805776407913966}, {4.517068393287556, \
-0.9809855000855563}, {4.519158840453553, -0.9813890725047052}, 
     {4.523339734785547, -0.982183349682318}, {4.531701523449534, \
-0.9837203851951678}, {4.54842510077751, -0.9865880110231746}, 
     {4.550515547943506, -0.9869270791939445}, {4.552605995109504, \
-0.9872618345251946}, {4.556786889441497, -0.987918400836508}, 
     {4.565148678105485, -0.9891797162821415}, {4.567239125271482, \
-0.989484241832617}, {4.5693295724374785, -0.9897844433688542}, 
     {4.573510466769473, -0.9903718691700315}, {4.58187225543346, \
-0.9914947761459183}, {4.583962702599457, -0.9917646739089758}, 
     {4.586053149765454, -0.9920302376923803}, {4.590234044097448, \
-0.9925483586971543}, {4.598595832761435, -0.9935325431581933}, 
     {4.615319410089411, -0.9952924474135678}, {4.6172714141983775, \
-0.9954797338799681}, {4.619223418307345, -0.995663227251192}, 
     {4.623127426525279, -0.9960188319258931}, {4.630935442961148, \
-0.9966844943384429}, {4.6328874470701145, -0.9968414172764121}, 
     {4.634839451179082, -0.9969945419307571}, {4.638743459397016, \
-0.9972893940692339}, {4.646551475832885, -0.9978334942406683}, 
     {4.648503479941851, -0.9979600153836806}, {4.650455484050819, \
-0.9980827339808533}, {4.654359492268753, -0.9983167616817821}, 
     {4.65631149637772, -0.998428069893818}, {4.6582635004866875, \
-0.9985355737765774}, {4.662167508704622, -0.9987391669302672}, 
     {4.664119512813588, -0.9988352554254427}, {4.666071516922556, \
-0.9989275380398349}, {4.66997552514049, -0.9991006842342673}, 
     {4.671927529249457, -0.9991815471545655}, {4.673879533358424, \
-0.9992586028745983}, {4.677783541576359, -0.9994012915539486}, 
     {4.679735545685325, -0.9994669239695767}, {4.681687549794293, \
-0.9995287480975628}, {4.6836395539032605, -0.9995867637023375}, 
     {4.685591558012227, -0.9996409705628425}, {4.687543562121194, \
-0.9996913684725326}, {4.689495566230161, -0.9997379572393758}, 
     {4.691447570339129, -0.9997807366858539}, {4.693399574448096, \
-0.9998197066489635}, {4.695351578557062, -0.9998548669802167}, 
     {4.69730358266603, -0.9998862175456416}, {4.699255586774997, \
-0.9999137582257822}, {4.701207590883964, -0.9999374889157}, 
     {4.703159594992931, -0.9999574095249734}, {4.705111599101898, \
-0.9999735199776986}, {4.707063603210866, -0.9999858202124895}, 
     {4.709015607319833, -0.9999943101824783}, {4.710967611428799, \
-0.9999989898553157}, {4.712919615537767, -0.9999998592131705}, 
     {4.714871619646734, -0.9999969182527302}, {4.716823623755701, \
-0.9999901669852007}, {4.718775627864668, -0.9999796054363067}, 
     {4.720727631973635, -0.9999652336462909}, {4.722679636082603, \
-0.9999470516699144}, {4.72463164019157, -0.9999250595764564}, 
     {4.726583644300536, -0.9998992574497138}, {4.728535648409504, \
-0.9998696453880008}, {4.730487652518471, -0.9998362235041489}, 
     {4.732439656627438, -0.9997989919255063}, {4.734391660736405, \
-0.9997579507939368}, {4.736343664845372, -0.9997131002658205}, 
     {4.7402476730633065, -0.9996119717180407}, {4.742161412452412, \
-0.9995568338809567}, {4.744075151841518, -0.9994980352695916}, 
     {4.747902630619728, -0.9993694565987994}, {4.749816370008833, \
-0.9992996770102786}, {4.751730109397938, -0.9992262375892872}, 
     {4.755557588176149, -0.9990683803391527}, {4.757471327565255, \
-0.9989839630881456}, {4.75938506695436, -0.9988958871609377}, 
     {4.763212545732571, -0.9987087605815942}, {4.770867503288993, \
-0.9982906183991543}, {4.772781242678098, -0.9981769415206926}, 
     {4.774694982067203, -0.9980596089216637}, {4.778522460845414, \
-0.9978139782941661}, {4.786177418401836, -0.9972788681968285}, 
     {4.788091157790942, -0.9971359583355132}, {4.790004897180047, \
-0.9969893965661247}, {4.7938323759582575, -0.9966853194635711}, 
     {4.801487333514679, -0.9960333668752152}, {4.803401072903784, \
-0.9958612575275346}, {4.80531481229289, -0.9956855009402419}, 
     {4.8091422910711, -0.9953230486349366}, {4.8167972486275215, \
-0.9945544063660269}, {4.818710988016627, -0.9943531378725057}, 
     {4.820624727405733, -0.9941482276627056}, {4.824452206183943, \
-0.9937274851094541}, {4.832107163740364, -0.9928423333212237}, 
     {4.83402090312947, -0.9926119528569672}, {4.835934642518575, \
-0.9923779370533432}, {4.839762121296785, -0.991899002869539}, 
     {4.847417078853207, -0.9908975490317617}, {4.86272699396605, \
-0.988720509333535}, {4.86480282530963, -0.988407477199899}, 
     {4.86687865665321, -0.9880901859450845}, {4.871030319340369, \
-0.9874428315591933}, {4.879333644714688, -0.9860970747203687}, 
     {4.895940295463326, -0.9832016996684034}, {4.8980161268069065, \
-0.9828206959267954}, {4.900091958150486, -0.9824354571378642}, 
     {4.904243620837645, -0.9816522810763635}, {4.912546946211964, \
-0.9800351826482793}, {4.929153596960601, -0.9765983969046794}, 
     {4.9312294283041815, -0.9761498418106058}, {4.933305259647761, \
-0.9756970804144146}, {4.9374569223349205, -0.9747789465377251}, 
     {4.945760247709239, -0.9728922902155126}, {4.962366898457876, \
-0.9689178846305395}, {4.9955801999551515, -0.9601686346199421}, 
     {4.997517588241701, -0.9596254856638143}, {4.999454976528251, \
-0.9590787347801046}, {5.003329753101351, -0.9579744354523093}, 
     {5.0110793062475505, -0.9557227048680353}, {5.02657841253995, \
-0.9510471938096906}, {5.057576625124749, -0.9410119752114029}, 
     {5.059514013411299, -0.9403546492016023}, {5.061451401697849, \
-0.9396937935967685}, {5.065326178270949, -0.9383615035372543}, 
     {5.073075731417148, -0.9356546783064531}, {5.088574837709547, \
-0.9300726207859755}, {5.119573050294346, -0.9182396411990768}, 
     {5.1216725305353705, -0.9174061710059187}, {5.1237720107763955, \
-0.9165686570554701}, {5.127970971258444, -0.9148815126669392}, 
     {5.13636889222254, -0.9114588624253163}, {5.153164734150735, \
-0.9044209668719675}, {5.186756418007123, -0.8895818387807382}, 
     {5.253939785719899, -0.8569103254512629}, {5.256001001241062, \
-0.8558460203515067}, {5.258062216762224, -0.8547780790975703}, 
     {5.262184647804549, -0.8526313062916385}, {5.270429509889199, \
-0.8482943275018867}, {5.286919234058499, -0.8394476742174765}, 
     {5.319898682397099, -0.8210720854972529}, {5.3858575790743, \
-0.7816630038752191}, {5.508915016778795, -0.6991945692154065}, 
     {5.642346339569648, -0.5978681634714186}, {5.766917306710594, \
-0.49363798436551354}, {5.889039331780388, -0.3840197868001835}, 
     {6.02153524193654, -0.2586748077041959}, {6.145170796442786, \
-0.137576777656183}, {6.147327271169481, -0.13544049038322992}, 
     {6.149483745896177, -0.13330357326033349}, {6.153796695349569, \
-0.1290278892175115}, {6.162422594256352, -0.12046940037221722}, 
     {6.179674392069918, -0.10332616932911103}, {6.214177987697051, \
-0.06895256359568983}, {6.216334462423746, -0.06680106274856791}, 
     {6.218490937150442, -0.06464925125102332}, {6.222803886603834, \
-0.06034473633304029}, {6.231429785510617, -0.051732419079817016}, 
     {6.248681583324183, -0.03449687810901285}, {6.250838058050879, \
-0.03234160836264792}, {6.252994532777574, -0.030186188215467574}, 
     {6.257307482230966, -0.025874936813415964}, {6.265933381137749, \
-0.017251070275793867}, {6.268089855864445, -0.015094878014923548}, 
     {6.2702463305911404, -0.012938615557112596}, {6.274559280044532, \
-0.008625920160720309}, {6.276715754771227, -0.006469507277817619}, 
     {6.278872229497923, -0.004313064309238329}, {6.281028704224619, \
-0.0021566012832639164}, {6.283185178951315, -1.28228271801381*^-7}}]}}}, 
 {AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesLabel -> {None, None}, \
AxesOrigin -> {0, 0}, Epilog -> Line[{{2, 0}, {2, Sin[2]}}], 
  Method -> {}, PlotRange -> {{0, 2*Pi}, {-0.9999998592131705, \
0.9999998782112116}}, PlotRangeClipping -> True, 
  PlotRangePadding -> {Scaled[0.02], Scaled[0.02]}}]\
\>", "Output",
 CellChangeTimes->{3.56336778217128*^9, 3.56615886429062*^9, 
  3.5661589717456903`*^9, 3.56726830230054*^9, 3.614729563558229*^9, 
  3.614730559930359*^9, 3.614731734208847*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"Out[16]//InputForm="]
}, Open  ]],

Cell[TextData[{
 "This call produces the equivalent input expression that, in the absence of  \
",
 StyleBox["Plot", "MB"],
 ", would have to be entered by hand to assign the same ",
 StyleBox["result", "MB"],
 ".  Incidentally, the graphics expression includes any primitives that were  \
inserted by means of ",
 StyleBox["Epilog", "MB"],
 "."
}], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 "Returning then to ",
 "Optica",
 ", you can use ",
 StyleBox["OutputType\[Rule]StandardGraphics", "MB"],
 " and verify that you get a legitimate graphics variable."
}], "Text",
 CellChangeTimes->{3.5661589482460737`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"myComponent", "=", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"50", ",", "25", ",", "5"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mySource", "=", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"ConeOfRays", "[", 
      RowBox[{"20", ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "40"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "31.33"}], ",", "0", ",", "0"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"mySystem", "=", 
   RowBox[{"{", 
    RowBox[{"mySource", ",", "myComponent"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"result", " ", "=", " ", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{"mySystem", ",", 
     RowBox[{"PlotType", "\[Rule]", "SideView"}], ",", " ", 
     RowBox[{"OutputType", "\[Rule]", "StandardGraphics"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"In[17]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "result", "]"}]], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"In[21]:="],

Cell[BoxData["Graphics"], "Output",
 CellChangeTimes->{3.5633677827878838`*^9, 3.566158864367881*^9, 
  3.5661589730255527`*^9, 3.567268303963023*^9, 3.6147295636406393`*^9, 
  3.614730559984439*^9, 3.614731734879286*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"},
 CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
 "Use of ",
 StyleBox["OutputType\[Rule]StandardGraphics", "MB"],
 " in ",
 "Optica",
 ".  The variable ",
 StyleBox["result", "MB"],
 " now holds ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics instead of an optical system."
}], "Commentary",
 CellChangeTimes->{3.5661589483456907`*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[{
 "You may employ this ",
 StyleBox["Graphics", "MB"],
 " object in any kind of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work.  At this stage it is completely independent of ",
 "Optica",
 ".  The variable holds a ",
 StyleBox["Graphics", "MB"],
 " object with standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics primitives."
}], "Text",
 CellChangeTimes->{3.566158948461782*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.4 Interactive 3D Graphics and Stereo Graphics", "Subsection",
 CellTags->{
  "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
   "Adjusting Graphics", "PR6.2", "PR6.2.4"}],

Cell[TextData[{
 "Often there is no substitute for a three-dimensional visualization.  If  \
you are running ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Version 4 or higher, Optica can produce interactive graphics.  These \
graphics allow you to change the  viewpoint with your mouse in real time.  \
This capability depends upon the ",
 StyleBox["RealTime3D", "MB"],
 " package (automatically loaded with ",
 "Optica",
 ").  This package is not well documented in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " literature, but ships standard with Version 4.  Use the option ",
 StyleBox["PlotType\[Rule]RealTime3D", "MB"],
 " to get this kind of output."
}], "Text",
 CellChangeTimes->{{3.566158948563093*^9, 3.566158948663043*^9}},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],

Cell["Here is a collection of lenses shown in standard 3D format.", "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lens", "=", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"100", ",", "50", ",", "10"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{"lens", ",", "50"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Move", "[", 
        RowBox[{"lens", ",", 
         RowBox[{"{", 
          RowBox[{"75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Move", "[", 
        RowBox[{"lens", ",", 
         RowBox[{"{", 
          RowBox[{"25", ",", "75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Move", "[", 
        RowBox[{"lens", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "25"}], ",", "50", ",", "50"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"125", ",", "125", ",", "125"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}], ";"}]}], "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"},
 CellLabel->"In[22]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{56.42197458095559, -25., 0.}, {60., -25., 
      6.123233995736766*^-15}, {60., -16.66666666666667, 
      5.102694996447306*^-15}, {52.75044883428479, -16.666666666666668`, 
      0.}, {56.42197458095559, -25., 0.}}], 
     Polygon3DBox[{{52.75044883428479, -16.666666666666668`, 0.}, {
      60., -16.66666666666667, 5.102694996447306*^-15}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      50.67375799589206, -8.333333333333336, 0.}, {
      52.75044883428479, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{50.67375799589206, -8.333333333333336, 0.}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      60., -7.105427357601002*^-15, 3.061616997868384*^-15}, {50., 0., 0.}, {
      50.67375799589206, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{50., 0., 0.}, {60., 0., 3.061616997868383*^-15}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {50.67375799589206, 
      8.333333333333329, 0.}, {50., 0., 0.}}], 
     Polygon3DBox[{{50.67375799589206, 8.333333333333329, 0.}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {60., 16.666666666666664`,
       1.0205389992894613`*^-15}, {52.75044883428479, 16.666666666666664`, 
      0.}, {50.67375799589206, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{52.75044883428479, 16.666666666666664`, 0.}, {60., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {60., 
      24.999999999999996`, 5.098616525425841*^-31}, {56.42197458095559, 
      24.999999999999993`, 0.}, {52.75044883428479, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYAADywMMUNDpKbGVL8HLYfUqEDCA
ixs83rbZNszTYQ1YXAEuDgGeUHM+7EFXvwKi3gEm3gE1HyJuABeHuefffxCw
gItDgB/MnRjiq9HMgYmvQbMX1ZwPNujiK7D6CyZugCEOdSdcHFd4AgCmzVCy

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{56.42197458095559, 0., -25.}, {60., 
        3.061616997868383*^-15, -25.}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {56.42197458095559, 
        0., -25.}}], 
       Polygon3DBox[{{52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {60., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {50., 
        1.5308084989341915`*^-15, 0.}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{50., 1.5308084989341915`*^-15, 0.}, {60., 
        1.5308084989341915`*^-15, 0.}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {50., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {60., 5.102694996447307*^-16, 
        16.666666666666664`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {60., 5.102694996447308*^-16, 
        16.666666666666664`}, {60., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {56.42197458095559, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYEABlgc6PSW28iV4wcVXrwIBgwMG
j7dttg3zhIuvAYsrHIDwPNHM+bAHXf0KiHqHDjTzIeIGDuju+fcfBCygfD90
d2KIQ92JIQ51Jw5zPtigi69A8Re6uAGGONSdB3CFJwDol1Cy
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{56.42197458095559, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 25., 
       0.}}], Line3DBox[{{56.42197458095559, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461097, 
       12.499999999999998`}, {60., 21.65063509461097, 12.499999999999998`}, {
       60., 17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{56.42197458095559, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{56.42197458095559, 12.500000000000004`, 
       21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563024, 
       24.148145657226706`}, {60., 6.470476127563024, 24.148145657226706`}, {
       60., 7.0819236220599744`*^-15, 25.}, {56.42197458095559, 
       7.0819236220599744`*^-15, 25.}, {56.42197458095559, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, 1.5308084989341915`*^-15, 25.}, {60., 
       1.5308084989341915`*^-15, 25.}, {60., -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, -12.499999999999995`, 
       21.65063509461097}, {60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{56.42197458095559, -17.677669529663685`, 
       17.67766952966369}, {60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{56.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {60., -21.650635094610962`, 
       12.500000000000009`}, {60., -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -24.148145657226706`, 6.470476127563026}, {
       56.4219745809556, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{56.42197458095559, -24.148145657226706`, 
       6.470476127563026}, {60., -24.148145657226706`, 6.470476127563026}, {
       60., -25., 3.061616997868383*^-15}, {56.42197458095559, -25., 
       3.061616997868383*^-15}, {56.42197458095559, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{56.42197458095559, -25., 3.061616997868383*^-15}, {
       60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       56.42197458095559, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{56.42197458095559, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}, {
       56.42197458095559, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563007, -24.14814565722671}, {
       60., 6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.4219745809556, 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461096, -12.50000000000001}, {
       60., 21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{81.42197458095559, 50., 0.}, {85., 50., 
      6.123233995736766*^-15}, {85., 58.33333333333333, 
      5.102694996447306*^-15}, {77.75044883428478, 58.33333333333333, 0.}, {
      81.42197458095559, 50., 0.}}], 
     Polygon3DBox[{{77.75044883428478, 58.33333333333333, 0.}, {85., 
      58.33333333333333, 5.102694996447306*^-15}, {85., 66.66666666666666, 
      4.0821559971578446`*^-15}, {75.67375799589206, 66.66666666666666, 0.}, {
      77.75044883428478, 58.33333333333333, 0.}}], 
     Polygon3DBox[{{75.67375799589206, 66.66666666666666, 0.}, {85., 
      66.66666666666666, 4.0821559971578446`*^-15}, {85., 75., 
      3.061616997868384*^-15}, {75., 75., 0.}, {75.67375799589206, 
      66.66666666666666, 0.}}], 
     Polygon3DBox[{{75., 75., 0.}, {85., 75., 3.061616997868383*^-15}, {85., 
      83.33333333333333, 2.0410779985789223`*^-15}, {75.67375799589206, 
      83.33333333333333, 0.}, {75., 75., 0.}}], 
     Polygon3DBox[{{75.67375799589206, 83.33333333333333, 0.}, {85., 
      83.33333333333333, 2.0410779985789223`*^-15}, {85., 91.66666666666666, 
      1.0205389992894613`*^-15}, {77.75044883428478, 91.66666666666666, 0.}, {
      75.67375799589206, 83.33333333333333, 0.}}], 
     Polygon3DBox[{{77.75044883428478, 91.66666666666666, 0.}, {85., 
      91.66666666666666, 1.0205389992894615`*^-15}, {85., 100., 
      5.098616525425841*^-31}, {81.42197458095559, 100., 0.}, {
      77.75044883428478, 91.66666666666666, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5qs2YhY3SIAwMYeEJpBoYjKj1R7AXBDqtAQMsX
Lj6j8PZNuddBEPFVAXBxMDgQ5IBCI6kPBYGrIXBxFPNfhcHFUd0TiWq+QyhO
8dVo5sDEw9DsRTEHyZ0o5qD7Cyi+Bi0cYOKMYAYi3HCFJwBPoEcG
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{81.42197458095559, 75., -25.}, {85., 75., -25.}, {85., 
        75., -16.66666666666667}, {77.75044883428478, 
        75., -16.666666666666668`}, {81.42197458095559, 75., -25.}}], 
       Polygon3DBox[{{77.75044883428478, 75., -16.666666666666668`}, {85., 
        75., -16.66666666666667}, {85., 75., -8.333333333333336}, {
        75.67375799589206, 75., -8.333333333333336}, {77.75044883428478, 
        75., -16.666666666666668`}}], 
       Polygon3DBox[{{75.67375799589206, 75., -8.333333333333336}, {85., 
        75., -8.333333333333336}, {85., 75., -7.105427357601002*^-15}, {75., 
        75., 0.}, {75.67375799589206, 75., -8.333333333333336}}], 
       Polygon3DBox[{{75., 75., 0.}, {85., 75., 0.}, {85., 75., 
        8.333333333333332}, {75.67375799589206, 75., 8.333333333333329}, {75.,
         75., 0.}}], 
       Polygon3DBox[{{75.67375799589206, 75., 8.333333333333329}, {85., 75., 
        8.333333333333332}, {85., 75., 16.666666666666664`}, {
        77.75044883428478, 75., 16.666666666666664`}, {75.67375799589206, 75.,
         8.333333333333329}}], 
       Polygon3DBox[{{77.75044883428478, 75., 16.666666666666664`}, {85., 75.,
         16.666666666666664`}, {85., 75., 24.999999999999996`}, {
        81.42197458095559, 75., 24.999999999999993`}, {77.75044883428478, 75.,
         16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5qs2YhY3SIAwMIHAiC0AyWB46o9ESxFwTDxVev
AgGDAzMKb9+Uex0EF18DFlc4gKIfbs6HPejqV0DUO6CbDxE3cEB3z7//IGAB
4TuEorsTQxzqTgxxqDtxmPPBBl18BbK/MMQNMMSh7jyAKzwB9e9sLg==
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{81.42197458095559, 100., 0.}, {85., 100., 0.}, {85., 
       99.1481456572267, 6.4704761275630185`}, {81.42197458095559, 
       99.1481456572267, 6.4704761275630185`}, {81.42197458095559, 100., 
       0.}}], Line3DBox[{{81.42197458095559, 99.1481456572267, 
       6.4704761275630185`}, {85., 99.1481456572267, 6.4704761275630185`}, {
       85., 96.65063509461098, 12.499999999999998`}, {81.42197458095559, 
       96.65063509461098, 12.499999999999998`}, {81.42197458095559, 
       99.1481456572267, 6.4704761275630185`}}], 
      Line3DBox[{{81.42197458095559, 96.65063509461098, 
       12.499999999999998`}, {85., 96.65063509461098, 12.499999999999998`}, {
       85., 92.67766952966369, 17.677669529663685`}, {81.42197458095559, 
       92.67766952966369, 17.677669529663685`}, {81.42197458095559, 
       96.65063509461098, 12.499999999999998`}}], 
      Line3DBox[{{81.42197458095559, 92.67766952966369, 
       17.677669529663685`}, {85., 92.67766952966369, 17.677669529663685`}, {
       85., 87.5, 21.650635094610966`}, {81.42197458095559, 87.5, 
       21.650635094610966`}, {81.42197458095559, 92.67766952966369, 
       17.677669529663685`}}], 
      Line3DBox[{{81.42197458095559, 87.5, 21.650635094610966`}, {85., 87.5, 
       21.650635094610966`}, {85., 81.47047612756302, 24.148145657226706`}, {
       81.42197458095559, 81.47047612756302, 24.148145657226706`}, {
       81.42197458095559, 87.5, 21.650635094610966`}}], 
      Line3DBox[{{81.42197458095559, 81.47047612756302, 
       24.148145657226706`}, {85., 81.47047612756302, 24.148145657226706`}, {
       85., 75., 25.}, {81.42197458095559, 75., 25.}, {81.42197458095559, 
       81.47047612756302, 24.148145657226706`}}], 
      Line3DBox[{{81.42197458095559, 75., 25.}, {85., 75., 25.}, {85., 
       68.52952387243698, 24.148145657226706`}, {81.42197458095559, 
       68.52952387243698, 24.148145657226706`}, {81.42197458095559, 75., 
       25.}}], Line3DBox[{{81.42197458095559, 68.52952387243698, 
       24.148145657226706`}, {85., 68.52952387243698, 24.148145657226706`}, {
       85., 62.50000000000001, 21.65063509461097}, {81.42197458095559, 
       62.50000000000001, 21.65063509461097}, {81.42197458095559, 
       68.52952387243698, 24.148145657226706`}}], 
      Line3DBox[{{81.42197458095559, 62.50000000000001, 21.65063509461097}, {
       85., 62.50000000000001, 21.65063509461097}, {85., 57.32233047033631, 
       17.67766952966369}, {81.42197458095559, 57.32233047033631, 
       17.67766952966369}, {81.42197458095559, 62.50000000000001, 
       21.65063509461097}}], 
      Line3DBox[{{81.42197458095559, 57.32233047033631, 17.67766952966369}, {
       85., 57.32233047033631, 17.67766952966369}, {85., 53.34936490538903, 
       12.499999999999998`}, {81.42197458095559, 53.34936490538903, 
       12.499999999999998`}, {81.42197458095559, 57.32233047033631, 
       17.67766952966369}}], 
      Line3DBox[{{81.4219745809556, 53.34936490538904, 12.500000000000009`}, {
       85., 53.34936490538904, 12.500000000000009`}, {85., 
       50.851854342773294`, 6.470476127563026}, {81.42197458095559, 
       50.851854342773294`, 6.470476127563026}, {81.4219745809556, 
       53.34936490538904, 12.500000000000009`}}], 
      Line3DBox[{{81.42197458095559, 50.851854342773294`, 
       6.470476127563026}, {85., 50.851854342773294`, 6.470476127563026}, {
       85., 50., 3.061616997868383*^-15}, {81.42197458095559, 50., 
       3.061616997868383*^-15}, {81.42197458095559, 50.851854342773294`, 
       6.470476127563026}}], 
      Line3DBox[{{81.42197458095559, 50., 3.061616997868383*^-15}, {85., 50., 
       3.061616997868383*^-15}, {85., 
       50.851854342773294`, -6.47047612756302}, {81.42197458095559, 
       50.851854342773294`, -6.47047612756302}, {81.42197458095559, 50., 
       3.061616997868383*^-15}}], 
      Line3DBox[{{81.42197458095559, 
       50.851854342773294`, -6.470476127563009}, {85., 
       50.851854342773294`, -6.470476127563009}, {85., 
       53.34936490538903, -12.499999999999993`}, {81.42197458095559, 
       53.34936490538903, -12.499999999999993`}, {81.42197458095559, 
       50.851854342773294`, -6.470476127563009}}], 
      Line3DBox[{{81.42197458095559, 
       53.34936490538903, -12.499999999999993`}, {85., 
       53.34936490538903, -12.499999999999993`}, {85., 
       57.32233047033631, -17.677669529663685`}, {81.42197458095559, 
       57.32233047033631, -17.677669529663685`}, {81.42197458095559, 
       53.34936490538903, -12.499999999999993`}}], 
      Line3DBox[{{81.42197458095559, 
       57.322330470336304`, -17.677669529663678`}, {85., 
       57.322330470336304`, -17.677669529663678`}, {85., 
       62.499999999999986`, -21.65063509461096}, {81.42197458095559, 
       62.499999999999986`, -21.65063509461096}, {81.42197458095559, 
       57.322330470336304`, -17.677669529663678`}}], 
      Line3DBox[{{81.42197458095559, 
       62.499999999999986`, -21.65063509461096}, {85., 
       62.499999999999986`, -21.65063509461096}, {85., 
       68.52952387243697, -24.148145657226703`}, {81.42197458095559, 
       68.52952387243697, -24.148145657226703`}, {81.42197458095559, 
       62.499999999999986`, -21.65063509461096}}], 
      Line3DBox[{{81.42197458095559, 
       68.52952387243697, -24.148145657226703`}, {85., 
       68.52952387243697, -24.148145657226703`}, {85., 
       74.99999999999997, -25.}, {81.42197458095559, 
       74.99999999999997, -25.}, {81.42197458095559, 
       68.52952387243697, -24.148145657226703`}}], 
      Line3DBox[{{81.42197458095559, 75., -25.}, {85., 75., -25.}, {85., 
       81.470476127563, -24.14814565722671}, {81.42197458095559, 
       81.470476127563, -24.14814565722671}, {81.42197458095559, 75., -25.}}],
       Line3DBox[{{81.42197458095559, 81.470476127563, -24.14814565722671}, {
       85., 81.470476127563, -24.14814565722671}, {85., 
       87.49999999999999, -21.650635094610976`}, {81.42197458095559, 
       87.49999999999999, -21.650635094610976`}, {81.42197458095559, 
       81.470476127563, -24.14814565722671}}], 
      Line3DBox[{{81.42197458095559, 
       87.49999999999999, -21.650635094610976`}, {85., 
       87.49999999999999, -21.650635094610976`}, {85., 
       92.67766952966367, -17.67766952966371}, {81.4219745809556, 
       92.67766952966367, -17.67766952966371}, {81.42197458095559, 
       87.49999999999999, -21.650635094610976`}}], 
      Line3DBox[{{81.42197458095559, 
       92.67766952966369, -17.677669529663692`}, {85., 
       92.67766952966369, -17.677669529663692`}, {85., 
       96.65063509461096, -12.50000000000001}, {81.42197458095559, 
       96.65063509461096, -12.50000000000001}, {81.42197458095559, 
       92.67766952966369, -17.677669529663692`}}], 
      Line3DBox[{{81.42197458095559, 96.65063509461096, -12.50000000000001}, {
       85., 96.65063509461096, -12.50000000000001}, {85., 
       99.1481456572267, -6.470476127563039}, {81.42197458095559, 
       99.1481456572267, -6.470476127563039}, {81.42197458095559, 
       96.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{81.42197458095559, 99.1481456572267, -6.470476127563039}, {
       85., 99.1481456572267, -6.470476127563039}, {85., 
       100., -2.8327694488239898`*^-14}, {81.42197458095559, 
       100., -2.8327694488239898`*^-14}, {81.42197458095559, 
       99.1481456572267, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{31.42197458095559, 50., 75.}, {35., 50., 75.}, {35., 
      58.33333333333333, 75.}, {27.75044883428479, 58.33333333333333, 75.}, {
      31.42197458095559, 50., 75.}}], 
     Polygon3DBox[{{27.75044883428479, 58.33333333333333, 75.}, {35., 
      58.33333333333333, 75.}, {35., 66.66666666666666, 75.}, {
      25.67375799589206, 66.66666666666666, 75.}, {27.75044883428479, 
      58.33333333333333, 75.}}], 
     Polygon3DBox[{{25.67375799589206, 66.66666666666666, 75.}, {35., 
      66.66666666666666, 75.}, {35., 75., 75.}, {25., 75., 75.}, {
      25.67375799589206, 66.66666666666666, 75.}}], 
     Polygon3DBox[{{25., 75., 75.}, {35., 75., 75.}, {35., 83.33333333333333, 
      75.}, {25.67375799589206, 83.33333333333333, 75.}, {25., 75., 75.}}], 
     Polygon3DBox[{{25.67375799589206, 83.33333333333333, 75.}, {35., 
      83.33333333333333, 75.}, {35., 91.66666666666666, 75.}, {
      27.75044883428479, 91.66666666666666, 75.}, {25.67375799589206, 
      83.33333333333333, 75.}}], 
     Polygon3DBox[{{27.75044883428479, 91.66666666666666, 75.}, {35., 
      91.66666666666666, 75.}, {35., 100., 75.}, {31.42197458095559, 100., 
      75.}, {27.75044883428479, 91.66666666666666, 75.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7yaUMbW469AwMYeELoA0EOQpMNsmQPWDusAgEt
X7h4wrHc9Oo1lhDxVQFwcYh+S1Q+kvpQELgaAhcXQDb/VRhcHNU9kajmNTji
FF+NZg5MPAzNXhRzkNyJYg66v4Dia9DCASbOiBZuuMITACo0Wtw=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{31.42197458095559, 75., 50.}, {35., 75., 50.}, {35., 
        75., 58.33333333333333}, {27.75044883428479, 75., 
        58.33333333333333}, {31.42197458095559, 75., 50.}}], 
       Polygon3DBox[{{27.75044883428479, 75., 58.33333333333333}, {35., 75., 
        58.33333333333333}, {35., 75., 66.66666666666666}, {25.67375799589206,
         75., 66.66666666666666}, {27.75044883428479, 75., 
        58.33333333333333}}], 
       Polygon3DBox[{{25.67375799589206, 75., 66.66666666666666}, {35., 75., 
        66.66666666666666}, {35., 75., 75.}, {25., 75., 75.}, {
        25.67375799589206, 75., 66.66666666666666}}], 
       Polygon3DBox[{{25., 75., 75.}, {35., 75., 75.}, {35., 75., 
        83.33333333333333}, {25.67375799589206, 75., 83.33333333333333}, {25.,
         75., 75.}}], 
       Polygon3DBox[{{25.67375799589206, 75., 83.33333333333333}, {35., 75., 
        83.33333333333333}, {35., 75., 91.66666666666666}, {27.75044883428479,
         75., 91.66666666666666}, {25.67375799589206, 75., 
        83.33333333333333}}], 
       Polygon3DBox[{{27.75044883428479, 75., 91.66666666666666}, {35., 75., 
        91.66666666666666}, {35., 75., 100.}, {31.42197458095559, 75., 
        100.}, {27.75044883428479, 75., 91.66666666666666}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7yaUMbW469AwMIHAiC0AyeDkKTDbJkD1jDxVeB
gJavQ8Kx3PTqNZao4qsCoPosUc0B0ujqQ0HgaoiDADbzX4U5YHdPJIRucCQo
vhpqDrp4GNRerObAaHRzYP5CEl8DDQd0cUZouOEKTwCVTVrc
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{31.42197458095559, 100., 75.}, {35., 100., 75.}, {35., 
       99.1481456572267, 81.47047612756302}, {31.42197458095559, 
       99.1481456572267, 81.47047612756302}, {31.42197458095559, 100., 75.}}],
       Line3DBox[{{31.42197458095559, 99.1481456572267, 81.47047612756302}, {
       35., 99.1481456572267, 81.47047612756302}, {35., 96.65063509461098, 
       87.5}, {31.42197458095559, 96.65063509461098, 87.5}, {
       31.42197458095559, 99.1481456572267, 81.47047612756302}}], 
      Line3DBox[{{31.42197458095559, 96.65063509461098, 87.5}, {35., 
       96.65063509461098, 87.5}, {35., 92.67766952966369, 
       92.67766952966369}, {31.42197458095559, 92.67766952966369, 
       92.67766952966369}, {31.42197458095559, 96.65063509461098, 87.5}}], 
      Line3DBox[{{31.42197458095559, 92.67766952966369, 92.67766952966369}, {
       35., 92.67766952966369, 92.67766952966369}, {35., 87.5, 
       96.65063509461096}, {31.42197458095559, 87.5, 96.65063509461096}, {
       31.42197458095559, 92.67766952966369, 92.67766952966369}}], 
      Line3DBox[{{31.42197458095559, 87.5, 96.65063509461096}, {35., 87.5, 
       96.65063509461096}, {35., 81.47047612756302, 99.1481456572267}, {
       31.42197458095559, 81.47047612756302, 99.1481456572267}, {
       31.42197458095559, 87.5, 96.65063509461096}}], 
      Line3DBox[{{31.42197458095559, 81.47047612756302, 99.1481456572267}, {
       35., 81.47047612756302, 99.1481456572267}, {35., 75., 100.}, {
       31.42197458095559, 75., 100.}, {31.42197458095559, 81.47047612756302, 
       99.1481456572267}}], 
      Line3DBox[{{31.42197458095559, 75., 100.}, {35., 75., 100.}, {35., 
       68.52952387243698, 99.1481456572267}, {31.42197458095559, 
       68.52952387243698, 99.1481456572267}, {31.42197458095559, 75., 100.}}],
       Line3DBox[{{31.42197458095559, 68.52952387243698, 99.1481456572267}, {
       35., 68.52952387243698, 99.1481456572267}, {35., 62.50000000000001, 
       96.65063509461098}, {31.42197458095559, 62.50000000000001, 
       96.65063509461098}, {31.42197458095559, 68.52952387243698, 
       99.1481456572267}}], 
      Line3DBox[{{31.42197458095559, 62.50000000000001, 96.65063509461098}, {
       35., 62.50000000000001, 96.65063509461098}, {35., 57.32233047033631, 
       92.67766952966369}, {31.42197458095559, 57.32233047033631, 
       92.67766952966369}, {31.42197458095559, 62.50000000000001, 
       96.65063509461098}}], 
      Line3DBox[{{31.42197458095559, 57.32233047033631, 92.67766952966369}, {
       35., 57.32233047033631, 92.67766952966369}, {35., 53.34936490538903, 
       87.5}, {31.42197458095559, 53.34936490538903, 87.5}, {
       31.42197458095559, 57.32233047033631, 92.67766952966369}}], 
      Line3DBox[{{31.4219745809556, 53.34936490538904, 87.50000000000001}, {
       35., 53.34936490538904, 87.50000000000001}, {35., 50.851854342773294`, 
       81.47047612756303}, {31.42197458095559, 50.851854342773294`, 
       81.47047612756303}, {31.4219745809556, 53.34936490538904, 
       87.50000000000001}}], 
      Line3DBox[{{31.42197458095559, 50.851854342773294`, 
       81.47047612756303}, {35., 50.851854342773294`, 81.47047612756303}, {
       35., 50., 75.}, {31.42197458095559, 50., 75.}, {31.42197458095559, 
       50.851854342773294`, 81.47047612756303}}], 
      Line3DBox[{{31.42197458095559, 50., 75.}, {35., 50., 75.}, {35., 
       50.851854342773294`, 68.52952387243698}, {31.42197458095559, 
       50.851854342773294`, 68.52952387243698}, {31.42197458095559, 50., 
       75.}}], Line3DBox[{{31.42197458095559, 50.851854342773294`, 
       68.529523872437}, {35., 50.851854342773294`, 68.529523872437}, {35., 
       53.34936490538903, 62.50000000000001}, {31.42197458095559, 
       53.34936490538903, 62.50000000000001}, {31.42197458095559, 
       50.851854342773294`, 68.529523872437}}], 
      Line3DBox[{{31.42197458095559, 53.34936490538903, 62.50000000000001}, {
       35., 53.34936490538903, 62.50000000000001}, {35., 57.32233047033631, 
       57.32233047033631}, {31.42197458095559, 57.32233047033631, 
       57.32233047033631}, {31.42197458095559, 53.34936490538903, 
       62.50000000000001}}], 
      Line3DBox[{{31.42197458095559, 57.322330470336304`, 
       57.322330470336325`}, {35., 57.322330470336304`, 
       57.322330470336325`}, {35., 62.499999999999986`, 53.34936490538904}, {
       31.42197458095559, 62.499999999999986`, 53.34936490538904}, {
       31.42197458095559, 57.322330470336304`, 57.322330470336325`}}], 
      Line3DBox[{{31.42197458095559, 62.499999999999986`, 
       53.34936490538904}, {35., 62.499999999999986`, 53.34936490538904}, {
       35., 68.52952387243697, 50.851854342773294`}, {31.42197458095559, 
       68.52952387243697, 50.851854342773294`}, {31.42197458095559, 
       62.499999999999986`, 53.34936490538904}}], 
      Line3DBox[{{31.42197458095559, 68.52952387243697, 
       50.851854342773294`}, {35., 68.52952387243697, 50.851854342773294`}, {
       35., 74.99999999999997, 50.}, {31.42197458095559, 74.99999999999997, 
       50.}, {31.42197458095559, 68.52952387243697, 50.851854342773294`}}], 
      Line3DBox[{{31.42197458095559, 75., 50.}, {35., 75., 50.}, {35., 
       81.470476127563, 50.851854342773294`}, {31.42197458095559, 
       81.470476127563, 50.851854342773294`}, {31.42197458095559, 75., 50.}}],
       Line3DBox[{{31.42197458095559, 81.470476127563, 50.851854342773294`}, {
       35., 81.470476127563, 50.851854342773294`}, {35., 87.49999999999999, 
       53.349364905389024`}, {31.42197458095559, 87.49999999999999, 
       53.349364905389024`}, {31.42197458095559, 81.470476127563, 
       50.851854342773294`}}], 
      Line3DBox[{{31.42197458095559, 87.49999999999999, 
       53.349364905389024`}, {35., 87.49999999999999, 53.349364905389024`}, {
       35., 92.67766952966367, 57.32233047033629}, {31.4219745809556, 
       92.67766952966367, 57.32233047033629}, {31.42197458095559, 
       87.49999999999999, 53.349364905389024`}}], 
      Line3DBox[{{31.42197458095559, 92.67766952966369, 57.32233047033631}, {
       35., 92.67766952966369, 57.32233047033631}, {35., 96.65063509461096, 
       62.499999999999986`}, {31.42197458095559, 96.65063509461096, 
       62.499999999999986`}, {31.42197458095559, 92.67766952966369, 
       57.32233047033631}}], 
      Line3DBox[{{31.42197458095559, 96.65063509461096, 
       62.499999999999986`}, {35., 96.65063509461096, 62.499999999999986`}, {
       35., 99.1481456572267, 68.52952387243695}, {31.42197458095559, 
       99.1481456572267, 68.52952387243695}, {31.42197458095559, 
       96.65063509461096, 62.499999999999986`}}], 
      Line3DBox[{{31.42197458095559, 99.1481456572267, 68.52952387243695}, {
       35., 99.1481456572267, 68.52952387243695}, {35., 100., 
       74.99999999999997}, {31.42197458095559, 100., 74.99999999999997}, {
       31.42197458095559, 99.1481456572267, 68.52952387243695}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-18.57802541904441, 25., 50.}, {-15., 25., 
      50.00000000000001}, {-15., 33.33333333333333, 
      50.00000000000001}, {-22.24955116571521, 33.33333333333333, 
      50.}, {-18.57802541904441, 25., 50.}}], 
     Polygon3DBox[{{-22.24955116571521, 33.33333333333333, 50.}, {-15., 
      33.33333333333333, 50.00000000000001}, {-15., 41.666666666666664`, 
      50.00000000000001}, {-24.32624200410794, 41.666666666666664`, 
      50.}, {-22.24955116571521, 33.33333333333333, 50.}}], 
     Polygon3DBox[{{-24.32624200410794, 41.666666666666664`, 50.}, {-15., 
      41.666666666666664`, 50.00000000000001}, {-15., 49.99999999999999, 
      50.}, {-25., 50., 50.}, {-24.32624200410794, 41.666666666666664`, 
      50.}}], Polygon3DBox[{{-25., 50., 50.}, {-15., 50., 50.}, {-15., 
      58.33333333333333, 50.}, {-24.32624200410794, 58.33333333333333, 
      50.}, {-25., 50., 50.}}], 
     Polygon3DBox[{{-24.32624200410794, 58.33333333333333, 50.}, {-15., 
      58.33333333333333, 50.}, {-15., 66.66666666666666, 
      50.}, {-22.24955116571521, 66.66666666666666, 50.}, {-24.32624200410794,
       58.33333333333333, 50.}}], 
     Polygon3DBox[{{-22.24955116571521, 66.66666666666666, 50.}, {-15., 
      66.66666666666666, 50.}, {-15., 75., 50.}, {-18.57802541904441, 75., 
      50.}, {-22.24955116571521, 66.66666666666666, 50.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM7h9a/8OdnoAAMYWDpAaE+Hdznnpz6yNzuwCgwc
4OILLCfNaAm2OBAKAldd4OJQ/QdQ+Qj1YGO0fOHiH1DMD4CLo7jnQBCa+Xo4
xVejmYMijmQvijlI7oSJh2H1l96BNWjhABNnQgs3XOEJAGUqUxs=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-18.57802541904441, 50., 25.}, {-15., 50., 25.}, {-15., 
        50., 33.33333333333333}, {-22.24955116571521, 50., 
        33.33333333333333}, {-18.57802541904441, 50., 25.}}], 
       Polygon3DBox[{{-22.24955116571521, 50., 33.33333333333333}, {-15., 50.,
         33.33333333333333}, {-15., 50., 
        41.666666666666664`}, {-24.32624200410794, 50., 
        41.666666666666664`}, {-22.24955116571521, 50., 33.33333333333333}}], 
       Polygon3DBox[{{-24.32624200410794, 50., 41.666666666666664`}, {-15., 
        50., 41.666666666666664`}, {-15., 50., 49.99999999999999}, {-25., 50.,
         50.}, {-24.32624200410794, 50., 41.666666666666664`}}], 
       Polygon3DBox[{{-25., 50., 50.}, {-15., 50., 50.}, {-15., 50., 
        58.33333333333333}, {-24.32624200410794, 50., 
        58.33333333333333}, {-25., 50., 50.}}], 
       Polygon3DBox[{{-24.32624200410794, 50., 58.33333333333333}, {-15., 50.,
         58.33333333333333}, {-15., 50., 
        66.66666666666666}, {-22.24955116571521, 50., 
        66.66666666666666}, {-24.32624200410794, 50., 58.33333333333333}}], 
       Polygon3DBox[{{-22.24955116571521, 50., 66.66666666666666}, {-15., 50.,
         66.66666666666666}, {-15., 50., 75.}, {-18.57802541904441, 50., 
        75.}, {-22.24955116571521, 50., 66.66666666666666}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM7h9a/8OdnoAAMYeDpAaEuHdznnpz6yN4OLrwID
B4cFlpNmtARbwMVDQeCqC0wfmjmeGOrBxmj5OnzAan6AA1b3HAiCmqdHUHw1
1Bys4kB7sZoDpxHiYSj+QoivgYYDujgTNNxwhScAeuNTGw==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-18.57802541904441, 75., 50.}, {-15., 75., 50.}, {-15., 
       74.1481456572267, 56.47047612756302}, {-18.57802541904441, 
       74.1481456572267, 56.47047612756302}, {-18.57802541904441, 75., 50.}}],
       Line3DBox[{{-18.57802541904441, 74.1481456572267, 
       56.47047612756302}, {-15., 74.1481456572267, 56.47047612756302}, {-15.,
        71.65063509461098, 62.5}, {-18.57802541904441, 71.65063509461098, 
       62.5}, {-18.57802541904441, 74.1481456572267, 56.47047612756302}}], 
      Line3DBox[{{-18.57802541904441, 71.65063509461098, 62.5}, {-15., 
       71.65063509461098, 62.5}, {-15., 67.67766952966369, 
       67.67766952966369}, {-18.57802541904441, 67.67766952966369, 
       67.67766952966369}, {-18.57802541904441, 71.65063509461098, 62.5}}], 
      Line3DBox[{{-18.57802541904441, 67.67766952966369, 
       67.67766952966369}, {-15., 67.67766952966369, 
       67.67766952966369}, {-15., 62.5, 
       71.65063509461096}, {-18.57802541904441, 62.5, 
       71.65063509461096}, {-18.57802541904441, 67.67766952966369, 
       67.67766952966369}}], 
      Line3DBox[{{-18.57802541904441, 62.5, 71.65063509461096}, {-15., 62.5, 
       71.65063509461096}, {-15., 56.470476127563025`, 
       74.1481456572267}, {-18.57802541904441, 56.470476127563025`, 
       74.1481456572267}, {-18.57802541904441, 62.5, 71.65063509461096}}], 
      Line3DBox[{{-18.57802541904441, 56.470476127563025`, 
       74.1481456572267}, {-15., 56.470476127563025`, 
       74.1481456572267}, {-15., 50.00000000000001, 75.}, {-18.57802541904441,
        50.00000000000001, 75.}, {-18.57802541904441, 56.470476127563025`, 
       74.1481456572267}}], 
      Line3DBox[{{-18.57802541904441, 50., 75.}, {-15., 50., 75.}, {-15., 
       43.52952387243698, 74.1481456572267}, {-18.57802541904441, 
       43.52952387243698, 74.1481456572267}, {-18.57802541904441, 50., 75.}}],
       Line3DBox[{{-18.57802541904441, 43.52952387243698, 
       74.1481456572267}, {-15., 43.52952387243698, 74.1481456572267}, {-15., 
       37.50000000000001, 71.65063509461098}, {-18.57802541904441, 
       37.50000000000001, 71.65063509461098}, {-18.57802541904441, 
       43.52952387243698, 74.1481456572267}}], 
      Line3DBox[{{-18.57802541904441, 37.50000000000001, 
       71.65063509461098}, {-15., 37.50000000000001, 
       71.65063509461098}, {-15., 32.32233047033631, 
       67.67766952966369}, {-18.57802541904441, 32.32233047033631, 
       67.67766952966369}, {-18.57802541904441, 37.50000000000001, 
       71.65063509461098}}], 
      Line3DBox[{{-18.57802541904441, 32.32233047033631, 
       67.67766952966369}, {-15., 32.32233047033631, 
       67.67766952966369}, {-15., 28.34936490538903, 
       62.5}, {-18.57802541904441, 28.34936490538903, 
       62.5}, {-18.57802541904441, 32.32233047033631, 67.67766952966369}}], 
      Line3DBox[{{-18.5780254190444, 28.349364905389038`, 
       62.50000000000001}, {-15., 28.349364905389038`, 
       62.50000000000001}, {-15., 25.851854342773294`, 
       56.470476127563025`}, {-18.57802541904441, 25.851854342773294`, 
       56.470476127563025`}, {-18.5780254190444, 28.349364905389038`, 
       62.50000000000001}}], 
      Line3DBox[{{-18.57802541904441, 25.851854342773294`, 
       56.470476127563025`}, {-15., 25.851854342773294`, 
       56.470476127563025`}, {-15., 25., 50.}, {-18.57802541904441, 25., 
       50.}, {-18.57802541904441, 25.851854342773294`, 56.470476127563025`}}],
       Line3DBox[{{-18.57802541904441, 25., 50.}, {-15., 25., 50.}, {-15., 
       25.851854342773294`, 43.52952387243698}, {-18.57802541904441, 
       25.851854342773294`, 43.52952387243698}, {-18.57802541904441, 25., 
       50.}}], Line3DBox[{{-18.57802541904441, 25.85185434277329, 
       43.52952387243699}, {-15., 25.85185434277329, 
       43.52952387243699}, {-15., 28.34936490538903, 
       37.50000000000001}, {-18.57802541904441, 28.34936490538903, 
       37.50000000000001}, {-18.57802541904441, 25.85185434277329, 
       43.52952387243699}}], 
      Line3DBox[{{-18.57802541904441, 28.34936490538903, 
       37.50000000000001}, {-15., 28.34936490538903, 
       37.50000000000001}, {-15., 32.32233047033631, 
       32.32233047033631}, {-18.57802541904441, 32.32233047033631, 
       32.32233047033631}, {-18.57802541904441, 28.34936490538903, 
       37.50000000000001}}], 
      Line3DBox[{{-18.57802541904441, 32.322330470336304`, 
       32.322330470336325`}, {-15., 32.322330470336304`, 
       32.322330470336325`}, {-15., 37.499999999999986`, 
       28.34936490538904}, {-18.57802541904441, 37.499999999999986`, 
       28.34936490538904}, {-18.57802541904441, 32.322330470336304`, 
       32.322330470336325`}}], 
      Line3DBox[{{-18.57802541904441, 37.499999999999986`, 
       28.34936490538904}, {-15., 37.499999999999986`, 
       28.34936490538904}, {-15., 43.52952387243696, 
       25.851854342773297`}, {-18.57802541904441, 43.52952387243696, 
       25.851854342773297`}, {-18.57802541904441, 37.499999999999986`, 
       28.34936490538904}}], 
      Line3DBox[{{-18.57802541904441, 43.52952387243696, 
       25.851854342773297`}, {-15., 43.52952387243696, 
       25.851854342773297`}, {-15., 49.99999999999997, 
       25.}, {-18.57802541904441, 49.99999999999997, 
       25.}, {-18.57802541904441, 43.52952387243696, 25.851854342773297`}}], 
      Line3DBox[{{-18.57802541904441, 49.99999999999999, 25.}, {-15., 
       49.99999999999999, 25.}, {-15., 56.470476127563, 
       25.85185434277329}, {-18.57802541904441, 56.470476127563, 
       25.85185434277329}, {-18.57802541904441, 49.99999999999999, 25.}}], 
      Line3DBox[{{-18.57802541904441, 56.470476127563, 
       25.85185434277329}, {-15., 56.470476127563, 25.85185434277329}, {-15., 
       62.499999999999986`, 28.349364905389024`}, {-18.57802541904441, 
       62.499999999999986`, 28.349364905389024`}, {-18.57802541904441, 
       56.470476127563, 25.85185434277329}}], 
      Line3DBox[{{-18.57802541904441, 62.499999999999986`, 
       28.349364905389024`}, {-15., 62.499999999999986`, 
       28.349364905389024`}, {-15., 67.67766952966367, 
       32.32233047033629}, {-18.5780254190444, 67.67766952966367, 
       32.32233047033629}, {-18.57802541904441, 62.499999999999986`, 
       28.349364905389024`}}], 
      Line3DBox[{{-18.57802541904441, 67.67766952966369, 
       32.32233047033631}, {-15., 67.67766952966369, 
       32.32233047033631}, {-15., 71.65063509461096, 
       37.499999999999986`}, {-18.57802541904441, 71.65063509461096, 
       37.499999999999986`}, {-18.57802541904441, 67.67766952966369, 
       32.32233047033631}}], 
      Line3DBox[{{-18.57802541904441, 71.65063509461096, 
       37.499999999999986`}, {-15., 71.65063509461096, 
       37.499999999999986`}, {-15., 74.1481456572267, 
       43.52952387243696}, {-18.57802541904441, 74.1481456572267, 
       43.52952387243696}, {-18.57802541904441, 71.65063509461096, 
       37.499999999999986`}}], 
      Line3DBox[{{-18.57802541904441, 74.1481456572267, 
       43.52952387243696}, {-15., 74.1481456572267, 43.52952387243696}, {-15.,
        75., 49.99999999999997}, {-18.57802541904441, 75., 
       49.99999999999997}, {-18.57802541904441, 74.1481456572267, 
       43.52952387243696}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{125., 125., -50.}, {125., -50., -50.}, {125., -50., 125.}, {
       125., 125., 125.}, {125., 125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{125., -50., -50.}, {-50., -50., -50.}, {-50., -50., 125.}, {
       125., -50., 125.}, {125., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-50., -50., -50.}, {-50., 125., -50.}, {-50., 125., 
       125.}, {-50., -50., 125.}, {-50., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-50., 125., -50.}, {125., 125., -50.}, {125., 125., 
       125.}, {-50., 125., 125.}, {-50., 125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{125., -50., -50.}, {125., 125., -50.}, {-50., 
       125., -50.}, {-50., -50., -50.}, {125., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{125., 125., 125.}, {125., -50., 125.}, {-50., -50., 
       125.}, {-50., 125., 125.}, {125., 125., 125.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731735307864*^9},
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"},
 CellLabel->"During evaluation of In[22]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3 ShowText", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"ShowText", "6.3", "PR6.3"}],

Cell[CellGroupData[{

Cell["?ShowText", "Input",
 CellTags->{"ShowText", "PR6.3"},
 CellLabel->"In[24]:="],

Cell[BoxData[
 StyleBox["\<\"ShowText is a PlugIn of ShowSystem and an Option of Component, \
Ray and ShowSystem (the rule is applied in this order) that describes the \
information to be added to the plot. Options of ShowSystem are additional to \
options directly given in Ray or Component.\\n\\nThe value is a list \
structure, where each sublist, {rulename, scalingfactor, size, prefixstring, \
postfixstring}, gives a separate information to be shown. All elements of the \
sublists, but the first, are optional.\\nThe 1st element is a formula with \
names of rules of the values to be shown, for example Polarization. If a part \
is to be accessed, it must be wrapped with Hold, for example \
Hold[Polarization[[1]]]*Intensity for a Ray. If all optional arguments are \
omitted, the rulename needs not to be wrapped with a list.\\nThe value of the \
desired rule is multiplied by the scalingfactor and converted to an object of \
size. Scalingfactor and size can have the same number of dimensions as value, \
a False inside scalingfactor suppresses this dimension of value.\\nIf a \
threefold list is given, each list belongs to the corresponding element in \
the LabelPositions or RayLabelPositions list. In the case of a twofold or a \
simple list or a simple formula, all information is shown at the first \
labelposition. If two- and threefold lists are mixed, each second level \
element appears in its own labelposition.\\n\\nOne line of text for each \
innermost list is added to the label, with the same font as the label. The \
text may be formatted with a StyleForm wrapper. The prefixstring and the \
postfixstring are put in front of and behind the value to be shown. The text \
is shown at the position chosen by the LabelPositions or RayLabelPositions \
rule. The amount of information to be shown can be diminished by giving a \
ShowTextSelection rule.\\nSee also: ShowTextSelection, RayNumber, \
LabelPositions, RayLabelPositions, ShowSystem, ShowText, ShowSurfaceEllipse, \
ShowEllipse, ShowSurfacePlot, ShowValue.\"\>", "MSG"]], "Print", "PrintUsage",
 
 CellChangeTimes->{3.6147317356995487`*^9},
 CellTags->{"Info3614713735-8131145", "PR6.3", "ShowText"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 AnalyzeSystem[{
\tMove[LineOfRays[40],{0,-5},5],
\tMove[PlanoConvexLens[100,50,10, FresnelReflections -> True],50],
\tBoundary[100]},
\tPlotType->TopView, ShowText -> Intensity];\
\>", "Input",
 CellTags->{"ShowText", "PR6.3"},
 CellLabel->"In[25]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.7431148549531632`, -24.92389396183491}, {
      54.15358479945905, -20.338571991624484`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -5.}, {50.00376827030235, -0.6252371427712431}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-1.7431148549531632`, 14.92389396183491}, {53.92523180426972,
        19.794243211748157`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
       60., -19.171068189440202`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
       20.235045606249336`, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
       60., -0.009292879215369254}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
       7.105427357601002*^-15, 2.5371555495783014`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.92523180426972, 19.794243211748157`}, {60., 
       19.286502990943365`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.92523180426972, 19.794243211748157`}, {
       28.458389529954687`, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -19.171068189440202`}, {100., -6.707767791388587}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -19.171068189440202`}, {
       53.15089604404306, -17.803331784164836`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -0.009292879215369254}, {100., 3.744079102316289}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -0.009292879215369254}, {50.00354772074953, 
       0.6066649740846766}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 19.286502990943365`}, {100., 14.1845047352222}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 19.286502990943365`}, {53.504851242997255`, 
       18.743626595040972`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.15089604404306, -17.803331784164836`}, {0., 
       15.636644356946643`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.00354772074953, 0.6066649740846766}, {
       7.105427357601002*^-15, 4.990817736505169}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.504851242997255`, 18.743626595040972`}, {
       7.105427357601002*^-15, -1.258326331242742}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{54.15358479945905, -20.338571991624484`}, {
      50.00376827030235, -0.6252371427712431}, {53.92523180426972, 
      19.794243211748157`}, {60., -19.171068189440202`}, {
      20.235045606249336`, -50.}, {60., -0.009292879215369254}, {
      7.105427357601002*^-15, 2.5371555495783014`}, {60., 
      19.286502990943365`}, {28.458389529954687`, 50.}, {
      100., -6.707767791388587}, {53.15089604404306, -17.803331784164836`}, {
      100., 3.744079102316289}, {50.00354772074953, 0.6066649740846766}, {
      100., 14.1845047352222}, {53.504851242997255`, 18.743626595040972`}, {
      0., 15.636644356946643`}, {7.105427357601002*^-15, 4.990817736505169}, {
      7.105427357601002*^-15, -1.258326331242742}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"100.\"\>", {27.948349827206105`, -22.6312329767297}, \
{0, 0}], InsetBox["\<\"100.\"\>", \
{25.001884135151176`, -2.8126185713856215`}, {0, 0}], 
    InsetBox["\<\"100.\"\>", {26.09105847465828, 17.359068586791533`}, \
{0, 0}], InsetBox["\<\"95.157\"\>", {57.07679239972953, -19.75482009053234}, \
{0, 0}], InsetBox["\<\"4.8424\"\>", \
{37.19431520285419, -35.169285995812245`}, {0, 0}], 
    InsetBox["\<\"95.722\"\>", {55.00188413515117, -0.3172650109933062}, \
{0, 0}], InsetBox["\<\"4.2775\"\>", {25.00188413515118, 0.9559592034035291}, \
{0, 0}], InsetBox["\<\"94.249\"\>", {56.96261590213486, 19.54037310134576}, \
{0, 0}], InsetBox["\<\"5.7506\"\>", {41.19181066711221, 34.89712160587408}, \
{0, 0}], InsetBox["\<\"90.600\"\>", {80., -12.939417990414395`}, {0, 0}], 
    InsetBox["\<\"4.5570\"\>", {56.57544802202153, -18.48719998680252}, \
{0, 0}], InsetBox["\<\"91.611\"\>", {80., 1.8673931115504598`}, {0, 0}], 
    InsetBox["\<\"4.1113\"\>", {55.00177386037477, 0.29868604743465366`}, \
{0, 0}], InsetBox["\<\"90.161\"\>", {80., 16.735503863082783`}, {0, 0}], 
    InsetBox["\<\"4.0873\"\>", {56.75242562149863, 19.01506479299217}, \
{0, 0}], InsetBox["\<\"3.9707\"\>", \
{26.57544802202153, -1.0833437136090964`}, {0, 0}], 
    InsetBox["\<\"3.9354\"\>", {25.00177386037477, 2.7987413552949225`}, \
{0, 0}], InsetBox["\<\"3.7366\"\>", {26.75242562149863, 8.742650131899115}, \
{0, 0}]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731736468493*^9},
 CellTags->{"ShowText", "PR6.3"},
 CellLabel->"During evaluation of In[25]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4 ShowRange", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.4", "ShowRange", "PR6.4"}],

Cell[TextData[{
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is very useful for viewing segments of very large optical \
systems. By displaying a subset of components in the system, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox["can be used to \"zoom-in\" on a particular component",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox["area.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],

Cell[TextData[{
 StyleBox["\nShowRange->",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["values",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" uses ",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["ComponentNumber",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" values to select the components and ray segments being displayed. \
\n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],

Cell[TextData[{
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" can either take the value ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["All",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" or a list of the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ComponentNumber",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" values.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],

Cell[CellGroupData[{

Cell["\<\
sys = AnalyzeSystem[
\t{LineOfRays[1, NumberOfRays -> 7],
\tMove[PlanoConvexLens[5,2,.5],5],
\tMove[PinHole[1.0,.1],10],
\tMove[PlanoConvexLens[100,50,10, CurvatureDirection->Back],110],
\tBoundary[{0,-100,-100},{150,100,100}]},
\tPlotType->TopView];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"},
 
 CellLabel->"In[26]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.200534679946088, -1.}, {5.5, -1.}, {
      5.5, -0.6666666666666667}, {5.08714497247726, -0.6666666666666667}, {
      5.200534679946088, -1.}}], 
     PolygonBox[{{5.08714497247726, -0.6666666666666667}, {
      5.5, -0.6666666666666667}, {5.5, -0.3333333333333335}, {
      5.021509426103136, -0.33333333333333337`}, {
      5.08714497247726, -0.6666666666666667}}], 
     PolygonBox[{{5.021509426103136, -0.33333333333333337`}, {
      5.5, -0.3333333333333335}, {5.5, -2.220446049250313*^-16}, {5., 0.}, {
      5.021509426103136, -0.33333333333333337`}}], 
     PolygonBox[{{5., 0.}, {5.5, 0.}, {5.5, 0.33333333333333326`}, {
      5.021509426103136, 0.33333333333333326`}, {5., 0.}}], 
     PolygonBox[{{5.021509426103136, 0.33333333333333326`}, {5.5, 
      0.33333333333333326`}, {5.5, 0.6666666666666665}, {5.08714497247726, 
      0.6666666666666665}, {5.021509426103136, 0.33333333333333326`}}], 
     PolygonBox[{{5.08714497247726, 0.6666666666666665}, {5.5, 
      0.6666666666666665}, {5.5, 0.9999999999999998}, {5.200534679946088, 
      0.9999999999999998}, {5.08714497247726, 0.6666666666666665}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.200534679946088, -1.}, {
       5.08714497247726, -0.6666666666666667}, {
       5.021509426103136, -0.33333333333333337`}, {5., 0.}, {
       5.021509426103136, 0.33333333333333326`}, {5.08714497247726, 
       0.6666666666666665}, {5.200534679946088, 1.}, {5.5, 1.}, {5.5, 
       0.6666666666666667}, {5.5, 0.33333333333333337`}, {5.5, 0.}, {
       5.5, -0.33333333333333326`}, {5.5, -0.6666666666666665}, {5.5, -1.}, {
       5.200534679946088, -1.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{5.200534679946088, 0.}, {5.5, 1.2246467991473532`*^-16}, {
        5.5, 1.020538999289461*^-16}, {5.08714497247726, 
        2.041077998578922*^-17}, {5.200534679946088, 0.}}], 
       PolygonBox[{{5.08714497247726, 2.041077998578922*^-17}, {5.5, 
        1.020538999289461*^-16}, {5.5, 8.164311994315689*^-17}, {
        5.021509426103136, 4.082155997157844*^-17}, {5.08714497247726, 
        2.041077998578922*^-17}}], 
       PolygonBox[{{5.021509426103136, 4.082155997157844*^-17}, {5.5, 
        8.164311994315689*^-17}, {5.5, 6.123233995736767*^-17}, {5., 
        6.123233995736766*^-17}, {5.021509426103136, 
        4.082155997157844*^-17}}], 
       PolygonBox[{{5., 6.123233995736766*^-17}, {5.5, 
        6.123233995736766*^-17}, {5.5, 4.0821559971578444`*^-17}, {
        5.021509426103136, 8.164311994315688*^-17}, {5., 
        6.123233995736766*^-17}}], 
       PolygonBox[{{5.021509426103136, 8.164311994315688*^-17}, {5.5, 
        4.0821559971578444`*^-17}, {5.5, 2.0410779985789225`*^-17}, {
        5.08714497247726, 1.0205389992894609`*^-16}, {5.021509426103136, 
        8.164311994315688*^-17}}], 
       PolygonBox[{{5.08714497247726, 1.0205389992894609`*^-16}, {5.5, 
        2.0410779985789228`*^-17}, {5.5, 1.0197233050851682`*^-32}, {
        5.200534679946088, 1.224646799147353*^-16}, {5.08714497247726, 
        1.0205389992894609`*^-16}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{5.200534679946088, 0.}, {5.08714497247726, 0.}, {
         5.021509426103136, 0.}, {5., 0.}, {5.021509426103136, 0.}, {
         5.08714497247726, 0.}, {5.200534679946088, 0.}, {5.5, 0.}, {5.5, 
         0.}, {5.5, 0.}, {5.5, 0.}, {5.5, 0.}, {5.5, 0.}, {5.5, 0.}, {
         5.200534679946088, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.200534679946088, 1.}, {5.5, 1.}, {5.5, 
       0.9659258262890683}, {5.200534679946088, 0.9659258262890683}, {
       5.200534679946088, 1.}}], 
      LineBox[{{5.200534679946088, 0.9659258262890683}, {5.5, 
       0.9659258262890683}, {5.5, 0.8660254037844387}, {5.200534679946088, 
       0.8660254037844387}, {5.200534679946088, 0.9659258262890683}}], 
      LineBox[{{5.200534679946088, 0.8660254037844387}, {5.5, 
       0.8660254037844387}, {5.5, 0.7071067811865476}, {5.200534679946088, 
       0.7071067811865476}, {5.200534679946088, 0.8660254037844387}}], 
      LineBox[{{5.200534679946088, 0.7071067811865476}, {5.5, 
       0.7071067811865476}, {5.5, 0.5000000000000001}, {5.200534679946088, 
       0.5000000000000001}, {5.200534679946088, 0.7071067811865476}}], 
      LineBox[{{5.200534679946088, 0.5000000000000001}, {5.5, 
       0.5000000000000001}, {5.5, 0.25881904510252096`}, {5.200534679946088, 
       0.25881904510252096`}, {5.200534679946088, 0.5000000000000001}}], 
      LineBox[{{5.200534679946088, 0.25881904510252096`}, {5.5, 
       0.25881904510252096`}, {5.5, 2.83276944882399*^-16}, {
       5.200534679946088, 2.83276944882399*^-16}, {5.200534679946088, 
       0.25881904510252096`}}], 
      LineBox[{{5.200534679946088, 6.123233995736766*^-17}, {5.5, 
       6.123233995736766*^-17}, {5.5, -0.25881904510252063`}, {
       5.200534679946088, -0.25881904510252063`}, {5.200534679946088, 
       6.123233995736766*^-17}}], 
      LineBox[{{5.200534679946088, -0.25881904510252063`}, {
       5.5, -0.25881904510252063`}, {5.5, -0.4999999999999998}, {
       5.200534679946088, -0.4999999999999998}, {
       5.200534679946088, -0.25881904510252063`}}], 
      LineBox[{{5.200534679946088, -0.4999999999999998}, {
       5.5, -0.4999999999999998}, {5.5, -0.7071067811865475}, {
       5.200534679946088, -0.7071067811865475}, {
       5.200534679946088, -0.4999999999999998}}], 
      LineBox[{{5.200534679946088, -0.7071067811865475}, {
       5.5, -0.7071067811865475}, {5.5, -0.8660254037844387}, {
       5.200534679946088, -0.8660254037844387}, {
       5.200534679946088, -0.7071067811865475}}], 
      LineBox[{{5.200534679946088, -0.8660254037844385}, {
       5.5, -0.8660254037844385}, {5.5, -0.9659258262890682}, {
       5.200534679946088, -0.9659258262890682}, {
       5.200534679946088, -0.8660254037844385}}], 
      LineBox[{{5.200534679946088, -0.9659258262890682}, {
       5.5, -0.9659258262890682}, {5.5, -1.}, {5.200534679946088, -1.}, {
       5.200534679946088, -0.9659258262890682}}], 
      LineBox[{{5.200534679946088, -1.}, {5.5, -1.}, {
       5.5, -0.9659258262890683}, {5.200534679946088, -0.9659258262890683}, {
       5.200534679946088, -1.}}], 
      LineBox[{{5.200534679946088, -0.9659258262890684}, {
       5.5, -0.9659258262890684}, {5.5, -0.8660254037844388}, {
       5.200534679946088, -0.8660254037844388}, {
       5.200534679946088, -0.9659258262890684}}], 
      LineBox[{{5.200534679946088, -0.8660254037844388}, {
       5.5, -0.8660254037844388}, {5.5, -0.7071067811865477}, {
       5.200534679946088, -0.7071067811865477}, {
       5.200534679946088, -0.8660254037844388}}], 
      LineBox[{{5.200534679946088, -0.7071067811865479}, {
       5.5, -0.7071067811865479}, {5.5, -0.5000000000000004}, {
       5.200534679946088, -0.5000000000000004}, {
       5.200534679946088, -0.7071067811865479}}], 
      LineBox[{{5.200534679946088, -0.5000000000000004}, {
       5.5, -0.5000000000000004}, {5.5, -0.2588190451025215}, {
       5.200534679946088, -0.2588190451025215}, {
       5.200534679946088, -0.5000000000000004}}], 
      LineBox[{{5.200534679946088, -0.2588190451025215}, {
       5.5, -0.2588190451025215}, {5.5, -1.0718754395722282`*^-15}, {
       5.200534679946088, -1.0718754395722282`*^-15}, {
       5.200534679946088, -0.2588190451025215}}], 
      LineBox[{{5.200534679946088, -1.8369701987210297`*^-16}, {
       5.5, -1.8369701987210297`*^-16}, {5.5, 0.2588190451025203}, {
       5.200534679946088, 0.2588190451025203}, {
       5.200534679946088, -1.8369701987210297`*^-16}}], 
      LineBox[{{5.200534679946088, 0.2588190451025203}, {5.5, 
       0.2588190451025203}, {5.5, 0.49999999999999933`}, {5.200534679946088, 
       0.49999999999999933`}, {5.200534679946088, 0.2588190451025203}}], 
      LineBox[{{5.200534679946088, 0.49999999999999933`}, {5.5, 
       0.49999999999999933`}, {5.5, 0.7071067811865468}, {5.200534679946088, 
       0.7071067811865468}, {5.200534679946088, 0.49999999999999933`}}], 
      LineBox[{{5.200534679946088, 0.7071067811865474}, {5.5, 
       0.7071067811865474}, {5.5, 0.8660254037844384}, {5.200534679946088, 
       0.8660254037844384}, {5.200534679946088, 0.7071067811865474}}], 
      LineBox[{{5.200534679946088, 0.8660254037844384}, {5.5, 
       0.8660254037844384}, {5.5, 0.9659258262890681}, {5.200534679946088, 
       0.9659258262890681}, {5.200534679946088, 0.8660254037844384}}], 
      LineBox[{{5.200534679946088, 0.9659258262890681}, {5.5, 
       0.9659258262890681}, {5.5, 1.}, {5.200534679946088, 1.}, {
       5.200534679946088, 0.9659258262890681}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{10., 0.05}, {10., 0.2}, {10., 0.19318516525781368`}, {10., 
      0.04829629131445342}, {10., 0.05}}], 
     PolygonBox[{{10., 0.04829629131445342}, {10., 0.19318516525781368`}, {
      10., 0.17320508075688776`}, {10., 0.04330127018922194}, {10., 
      0.04829629131445342}}], 
     PolygonBox[{{10., 0.04330127018922194}, {10., 0.17320508075688776`}, {
      10., 0.14142135623730953`}, {10., 0.03535533905932738}, {10., 
      0.04330127018922194}}], 
     PolygonBox[{{10., 0.03535533905932738}, {10., 0.14142135623730953`}, {
      10., 0.10000000000000002`}, {10., 0.02500000000000001}, {10., 
      0.03535533905932738}}], 
     PolygonBox[{{10., 0.02500000000000001}, {10., 0.10000000000000002`}, {
      10., 0.05176380902050419}, {10., 0.012940952255126049`}, {10., 
      0.02500000000000001}}], 
     PolygonBox[{{10., 0.012940952255126049`}, {10., 0.05176380902050419}, {
      10., 5.665538897647979*^-17}, {10., 1.4163847244119948`*^-17}, {10., 
      0.012940952255126049`}}], 
     PolygonBox[{{10., 3.061616997868383*^-18}, {10., 
      1.2246467991473533`*^-17}, {10., -0.05176380902050413}, {
      10., -0.012940952255126032`}, {10., 3.061616997868383*^-18}}], 
     PolygonBox[{{10., -0.012940952255126032`}, {10., -0.05176380902050413}, {
      10., -0.09999999999999995}, {10., -0.02499999999999999}, {
      10., -0.012940952255126032`}}], 
     PolygonBox[{{10., -0.02499999999999999}, {10., -0.09999999999999995}, {
      10., -0.1414213562373095}, {10., -0.035355339059327376`}, {
      10., -0.02499999999999999}}], 
     PolygonBox[{{10., -0.035355339059327376`}, {10., -0.1414213562373095}, {
      10., -0.17320508075688776`}, {10., -0.04330127018922194}, {
      10., -0.035355339059327376`}}], 
     PolygonBox[{{10., -0.043301270189221926`}, {
      10., -0.17320508075688767`}, {10., -0.19318516525781365`}, {
      10., -0.04829629131445341}, {10., -0.043301270189221926`}}], 
     PolygonBox[{{10., -0.04829629131445341}, {10., -0.19318516525781365`}, {
      10., -0.2}, {10., -0.05}, {10., -0.04829629131445341}}], 
     PolygonBox[{{10., -0.05}, {10., -0.2}, {10., -0.19318516525781368`}, {
      10., -0.04829629131445342}, {10., -0.05}}], 
     PolygonBox[{{10., -0.04829629131445343}, {10., -0.19318516525781368`}, {
      10., -0.17320508075688776`}, {10., -0.043301270189221946`}, {
      10., -0.04829629131445343}}], 
     PolygonBox[{{10., -0.043301270189221946`}, {
      10., -0.17320508075688776`}, {10., -0.14142135623730953`}, {
      10., -0.03535533905932738}, {10., -0.043301270189221946`}}], 
     PolygonBox[{{10., -0.0353553390593274}, {10., -0.1414213562373096}, {
      10., -0.10000000000000009`}, {10., -0.025000000000000022`}, {
      10., -0.0353553390593274}}], 
     PolygonBox[{{10., -0.025000000000000022`}, {
      10., -0.10000000000000009`}, {10., -0.0517638090205043}, {
      10., -0.012940952255126077`}, {10., -0.025000000000000022`}}], 
     PolygonBox[{{10., -0.012940952255126077`}, {10., -0.0517638090205043}, {
      10., -2.1437508791444562`*^-16}, {10., -5.359377197861141*^-17}, {
      10., -0.012940952255126077`}}], 
     PolygonBox[{{10., -9.184850993605149*^-18}, {
      10., -3.6739403974420595`*^-17}, {10., 0.05176380902050406}, {10., 
      0.012940952255126016`}, {10., -9.184850993605149*^-18}}], 
     PolygonBox[{{10., 0.012940952255126016`}, {10., 0.05176380902050406}, {
      10., 0.09999999999999987}, {10., 0.024999999999999967`}, {10., 
      0.012940952255126016`}}], 
     PolygonBox[{{10., 0.024999999999999967`}, {10., 0.09999999999999987}, {
      10., 0.14142135623730936`}, {10., 0.03535533905932734}, {10., 
      0.024999999999999967`}}], 
     PolygonBox[{{10., 0.03535533905932737}, {10., 0.14142135623730948`}, {
      10., 0.17320508075688767`}, {10., 0.04330127018922192}, {10., 
      0.03535533905932737}}], 
     PolygonBox[{{10., 0.04330127018922192}, {10., 0.17320508075688767`}, {
      10., 0.1931851652578136}, {10., 0.048296291314453406`}, {10., 
      0.04330127018922192}}], 
     PolygonBox[{{10., 0.048296291314453406`}, {10., 0.1931851652578136}, {
      10., 0.2}, {10., 0.05}, {10., 0.048296291314453406`}}], 
     PolygonBox[{{10., 0.2}, {10., 0.35}, {10., 0.3380740392011739}, {10., 
      0.19318516525781368`}, {10., 0.2}}], 
     PolygonBox[{{10., 0.19318516525781368`}, {10., 0.3380740392011739}, {10.,
       0.30310889132455354`}, {10., 0.17320508075688776`}, {10., 
      0.19318516525781368`}}], 
     PolygonBox[{{10., 0.17320508075688776`}, {10., 0.30310889132455354`}, {
      10., 0.24748737341529167`}, {10., 0.14142135623730953`}, {10., 
      0.17320508075688776`}}], 
     PolygonBox[{{10., 0.14142135623730953`}, {10., 0.24748737341529167`}, {
      10., 0.17500000000000004`}, {10., 0.10000000000000002`}, {10., 
      0.14142135623730953`}}], 
     PolygonBox[{{10., 0.10000000000000002`}, {10., 0.17500000000000004`}, {
      10., 0.09058666578588233}, {10., 0.05176380902050419}, {10., 
      0.10000000000000002`}}], 
     PolygonBox[{{10., 0.05176380902050419}, {10., 0.09058666578588233}, {10.,
       9.914693070883965*^-17}, {10., 5.665538897647979*^-17}, {10., 
      0.05176380902050419}}], 
     PolygonBox[{{10., 1.2246467991473533`*^-17}, {10., 
      2.143131898507868*^-17}, {10., -0.09058666578588223}, {
      10., -0.05176380902050413}, {10., 1.2246467991473533`*^-17}}], 
     PolygonBox[{{10., -0.05176380902050413}, {10., -0.09058666578588223}, {
      10., -0.1749999999999999}, {10., -0.09999999999999995}, {
      10., -0.05176380902050413}}], 
     PolygonBox[{{10., -0.09999999999999995}, {10., -0.1749999999999999}, {
      10., -0.2474873734152916}, {10., -0.1414213562373095}, {
      10., -0.09999999999999995}}], 
     PolygonBox[{{10., -0.1414213562373095}, {10., -0.2474873734152916}, {
      10., -0.30310889132455354`}, {10., -0.17320508075688776`}, {
      10., -0.1414213562373095}}], 
     PolygonBox[{{10., -0.17320508075688767`}, {10., -0.30310889132455343`}, {
      10., -0.33807403920117385`}, {10., -0.19318516525781365`}, {
      10., -0.17320508075688767`}}], 
     PolygonBox[{{10., -0.19318516525781365`}, {10., -0.33807403920117385`}, {
      10., -0.35}, {10., -0.2}, {10., -0.19318516525781365`}}], 
     PolygonBox[{{10., -0.2}, {10., -0.35}, {10., -0.3380740392011739}, {
      10., -0.19318516525781368`}, {10., -0.2}}], 
     PolygonBox[{{10., -0.19318516525781368`}, {10., -0.33807403920117396`}, {
      10., -0.30310889132455354`}, {10., -0.17320508075688776`}, {
      10., -0.19318516525781368`}}], 
     PolygonBox[{{10., -0.17320508075688776`}, {10., -0.30310889132455354`}, {
      10., -0.2474873734152917}, {10., -0.14142135623730953`}, {
      10., -0.17320508075688776`}}], 
     PolygonBox[{{10., -0.1414213562373096}, {10., -0.24748737341529178`}, {
      10., -0.17500000000000016`}, {10., -0.10000000000000009`}, {
      10., -0.1414213562373096}}], 
     PolygonBox[{{10., -0.10000000000000009`}, {10., -0.17500000000000016`}, {
      10., -0.09058666578588252}, {10., -0.0517638090205043}, {
      10., -0.10000000000000009`}}], 
     PolygonBox[{{10., -0.0517638090205043}, {10., -0.09058666578588252}, {
      10., -3.751564038502798*^-16}, {10., -2.1437508791444562`*^-16}, {
      10., -0.0517638090205043}}], 
     PolygonBox[{{10., -3.6739403974420595`*^-17}, {
      10., -6.429395695523605*^-17}, {10., 0.09058666578588209}, {10., 
      0.05176380902050406}, {10., -3.6739403974420595`*^-17}}], 
     PolygonBox[{{10., 0.05176380902050406}, {10., 0.09058666578588209}, {10.,
       0.17499999999999977`}, {10., 0.09999999999999987}, {10., 
      0.05176380902050406}}], 
     PolygonBox[{{10., 0.09999999999999987}, {10., 0.17499999999999977`}, {
      10., 0.2474873734152914}, {10., 0.14142135623730936`}, {10., 
      0.09999999999999987}}], 
     PolygonBox[{{10., 0.14142135623730948`}, {10., 0.24748737341529156`}, {
      10., 0.30310889132455343`}, {10., 0.17320508075688767`}, {10., 
      0.14142135623730948`}}], 
     PolygonBox[{{10., 0.17320508075688767`}, {10., 0.30310889132455343`}, {
      10., 0.3380740392011738}, {10., 0.1931851652578136}, {10., 
      0.17320508075688767`}}], 
     PolygonBox[{{10., 0.1931851652578136}, {10., 0.3380740392011738}, {10., 
      0.35}, {10., 0.2}, {10., 0.1931851652578136}}], 
     PolygonBox[{{10., 0.35}, {10., 0.5}, {10., 0.48296291314453416`}, {10., 
      0.3380740392011739}, {10., 0.35}}], 
     PolygonBox[{{10., 0.3380740392011739}, {10., 0.48296291314453416`}, {10.,
       0.43301270189221935`}, {10., 0.30310889132455354`}, {10., 
      0.3380740392011739}}], 
     PolygonBox[{{10., 0.30310889132455354`}, {10., 0.43301270189221935`}, {
      10., 0.3535533905932738}, {10., 0.24748737341529167`}, {10., 
      0.30310889132455354`}}], 
     PolygonBox[{{10., 0.24748737341529167`}, {10., 0.3535533905932738}, {10.,
       0.25000000000000006`}, {10., 0.17500000000000004`}, {10., 
      0.24748737341529167`}}], 
     PolygonBox[{{10., 0.17500000000000004`}, {10., 0.25000000000000006`}, {
      10., 0.12940952255126048`}, {10., 0.09058666578588233}, {10., 
      0.17500000000000004`}}], 
     PolygonBox[{{10., 0.09058666578588233}, {10., 0.12940952255126048`}, {
      10., 1.416384724411995*^-16}, {10., 9.914693070883965*^-17}, {10., 
      0.09058666578588233}}], 
     PolygonBox[{{10., 2.143131898507868*^-17}, {10., 
      3.061616997868383*^-17}, {10., -0.12940952255126031`}, {
      10., -0.09058666578588223}, {10., 2.143131898507868*^-17}}], 
     PolygonBox[{{10., -0.09058666578588223}, {10., -0.12940952255126031`}, {
      10., -0.2499999999999999}, {10., -0.1749999999999999}, {
      10., -0.09058666578588223}}], 
     PolygonBox[{{10., -0.1749999999999999}, {10., -0.2499999999999999}, {
      10., -0.35355339059327373`}, {10., -0.2474873734152916}, {
      10., -0.1749999999999999}}], 
     PolygonBox[{{10., -0.2474873734152916}, {10., -0.35355339059327373`}, {
      10., -0.43301270189221935`}, {10., -0.30310889132455354`}, {
      10., -0.2474873734152916}}], 
     PolygonBox[{{10., -0.30310889132455343`}, {10., -0.43301270189221924`}, {
      10., -0.4829629131445341}, {10., -0.33807403920117385`}, {
      10., -0.30310889132455343`}}], 
     PolygonBox[{{10., -0.33807403920117385`}, {10., -0.4829629131445341}, {
      10., -0.5}, {10., -0.35}, {10., -0.33807403920117385`}}], 
     PolygonBox[{{10., -0.35}, {10., -0.5}, {10., -0.48296291314453416`}, {
      10., -0.3380740392011739}, {10., -0.35}}], 
     PolygonBox[{{10., -0.33807403920117396`}, {10., -0.4829629131445342}, {
      10., -0.4330127018922194}, {10., -0.30310889132455354`}, {
      10., -0.33807403920117396`}}], 
     PolygonBox[{{10., -0.30310889132455354`}, {10., -0.4330127018922194}, {
      10., -0.35355339059327384`}, {10., -0.2474873734152917}, {
      10., -0.30310889132455354`}}], 
     PolygonBox[{{10., -0.24748737341529178`}, {10., -0.353553390593274}, {
      10., -0.2500000000000002}, {10., -0.17500000000000016`}, {
      10., -0.24748737341529178`}}], 
     PolygonBox[{{10., -0.17500000000000016`}, {10., -0.2500000000000002}, {
      10., -0.12940952255126076`}, {10., -0.09058666578588252}, {
      10., -0.17500000000000016`}}], 
     PolygonBox[{{10., -0.09058666578588252}, {10., -0.12940952255126076`}, {
      10., -5.359377197861141*^-16}, {10., -3.751564038502798*^-16}, {
      10., -0.09058666578588252}}], 
     PolygonBox[{{10., -6.429395695523605*^-17}, {
      10., -9.18485099360515*^-17}, {10., 0.12940952255126015`}, {10., 
      0.09058666578588209}, {10., -6.429395695523605*^-17}}], 
     PolygonBox[{{10., 0.09058666578588209}, {10., 0.12940952255126015`}, {
      10., 0.24999999999999967`}, {10., 0.17499999999999977`}, {10., 
      0.09058666578588209}}], 
     PolygonBox[{{10., 0.17499999999999977`}, {10., 0.24999999999999967`}, {
      10., 0.35355339059327345`}, {10., 0.2474873734152914}, {10., 
      0.17499999999999977`}}], 
     PolygonBox[{{10., 0.24748737341529156`}, {10., 0.3535533905932737}, {10.,
       0.4330127018922192}, {10., 0.30310889132455343`}, {10., 
      0.24748737341529156`}}], 
     PolygonBox[{{10., 0.30310889132455343`}, {10., 0.4330127018922192}, {10.,
       0.48296291314453405`}, {10., 0.3380740392011738}, {10., 
      0.30310889132455343`}}], 
     PolygonBox[{{10., 0.3380740392011738}, {10., 0.48296291314453405`}, {10.,
       0.5}, {10., 0.35}, {10., 0.3380740392011738}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEqDrNmgsBKexh/dWrufK9dK+B8Za61bVO1l8H5
3Mn/AyWkFsH5c8D6Z8L57Vw7TE82dMH5RceCX3Pa+tjA+LUQ+f0w/nSIfjif
C2I+nK8IsR/OXwVxH5wPdT+cvwZNXgVNPy+a+QvQ7J+O5r6rV+oKjuum7oHx
S9D8NwHN/5xo4aOAFn4r0cIXFv4Adxxtzw==
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEqDhD6gT2ML7rfw/3ui3tw/mqfiBdV227D+Wet
69PmLbgG5zOC6Qtw/hS2yQdrJxyA89ljRIzVljXawPh9EPn9MP6f/yBwHs4/
AzEfzl8JsR/OF4G4D86Huh/OF0OTX4Om/wKa+SwQ98P589Dcx9U1z8eyctYe
GL8DzX9fIO6H80+jhc8KtPATRgtfWPgDADAvbjg=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{110., -25.}, {113.57802541904441`, -25.}, {
      117.24955116571522`, -16.66666666666667}, {
      110., -16.666666666666668`}, {110., -25.}}], 
     PolygonBox[{{110., -16.666666666666668`}, {
      117.24955116571522`, -16.66666666666667}, {
      119.32624200410794`, -8.333333333333336}, {110., -8.333333333333336}, {
      110., -16.666666666666668`}}], 
     PolygonBox[{{110., -8.333333333333336}, {
      119.32624200410794`, -8.333333333333336}, {
      120., -7.105427357601002*^-15}, {110., 0.}, {
      110., -8.333333333333336}}], 
     PolygonBox[{{110., 0.}, {120., 0.}, {119.32624200410794`, 
      8.333333333333332}, {110., 8.333333333333329}, {110., 0.}}], 
     PolygonBox[{{110., 8.333333333333329}, {119.32624200410794`, 
      8.333333333333332}, {117.24955116571522`, 16.666666666666664`}, {110., 
      16.666666666666664`}, {110., 8.333333333333329}}], 
     PolygonBox[{{110., 16.666666666666664`}, {117.24955116571522`, 
      16.666666666666664`}, {113.57802541904441`, 24.999999999999996`}, {110.,
       24.999999999999993`}, {110., 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{110., -25.}, {110., -16.666666666666668`}, {
       110., -8.333333333333336}, {110., -3.552713678800501*^-15}, {110., 
       8.333333333333329}, {110., 16.666666666666657`}, {110., 
       24.999999999999993`}, {113.57802541904441`, 25.}, {117.24955116571522`,
        16.666666666666668`}, {119.32624200410794`, 8.333333333333336}, {120.,
        3.552713678800501*^-15}, {119.32624200410794`, -8.333333333333329}, {
       117.24955116571522`, -16.666666666666657`}, {
       113.57802541904441`, -24.999999999999993`}, {110., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{110., 0.}, {113.57802541904441`, 
        3.061616997868383*^-15}, {117.24955116571522`, 
        2.551347498223653*^-15}, {110., 5.102694996447305*^-16}, {110., 0.}}],
        PolygonBox[{{110., 5.102694996447305*^-16}, {117.24955116571522`, 
        2.551347498223653*^-15}, {119.32624200410794`, 
        2.0410779985789223`*^-15}, {110., 1.020538999289461*^-15}, {110., 
        5.102694996447305*^-16}}], 
       PolygonBox[{{110., 1.020538999289461*^-15}, {119.32624200410794`, 
        2.0410779985789223`*^-15}, {120., 1.530808498934192*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.020538999289461*^-15}}], 
       PolygonBox[{{110., 1.5308084989341915`*^-15}, {120., 
        1.5308084989341915`*^-15}, {119.32624200410794`, 
        1.0205389992894611`*^-15}, {110., 2.041077998578922*^-15}, {110., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{110., 2.041077998578922*^-15}, {119.32624200410794`, 
        1.0205389992894611`*^-15}, {117.24955116571522`, 
        5.102694996447307*^-16}, {110., 2.5513474982236525`*^-15}, {110., 
        2.041077998578922*^-15}}], 
       PolygonBox[{{110., 2.5513474982236525`*^-15}, {117.24955116571522`, 
        5.102694996447308*^-16}, {113.57802541904441`, 
        2.5493082627129206`*^-31}, {110., 3.0616169978683826`*^-15}, {110., 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {
         110., 0.}, {110., 0.}, {113.57802541904441`, 0.}, {
         117.24955116571522`, 0.}, {119.32624200410794`, 0.}, {120., 0.}, {
         119.32624200410794`, 0.}, {117.24955116571522`, 0.}, {
         113.57802541904441`, 0.}, {110., 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{110., 25.}, {113.57802541904441`, 25.}, {113.57802541904441`, 
       24.148145657226706`}, {110., 24.148145657226706`}, {110., 25.}}], 
      LineBox[{{110., 24.148145657226706`}, {113.57802541904441`, 
       24.148145657226706`}, {113.57802541904441`, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 24.148145657226706`}}], 
      LineBox[{{110., 21.65063509461097}, {113.57802541904441`, 
       21.65063509461097}, {113.57802541904441`, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 21.65063509461097}}], 
      LineBox[{{110., 17.67766952966369}, {113.57802541904441`, 
       17.67766952966369}, {113.57802541904441`, 12.500000000000004`}, {110., 
       12.500000000000004`}, {110., 17.67766952966369}}], 
      LineBox[{{110., 12.500000000000004`}, {113.57802541904441`, 
       12.500000000000004`}, {113.57802541904441`, 6.470476127563024}, {110., 
       6.470476127563024}, {110., 12.500000000000004`}}], 
      LineBox[{{110., 6.470476127563024}, {113.57802541904441`, 
       6.470476127563024}, {113.57802541904441`, 7.0819236220599744`*^-15}, {
       110., 7.0819236220599744`*^-15}, {110., 6.470476127563024}}], 
      LineBox[{{110., 1.5308084989341915`*^-15}, {113.57802541904441`, 
       1.5308084989341915`*^-15}, {113.57802541904441`, -6.470476127563016}, {
       110., -6.470476127563016}, {110., 1.5308084989341915`*^-15}}], 
      LineBox[{{110., -6.470476127563016}, {
       113.57802541904441`, -6.470476127563016}, {
       113.57802541904441`, -12.499999999999995`}, {
       110., -12.499999999999995`}, {110., -6.470476127563016}}], 
      LineBox[{{110., -12.499999999999995`}, {
       113.57802541904441`, -12.499999999999995`}, {
       113.57802541904441`, -17.677669529663685`}, {
       110., -17.677669529663685`}, {110., -12.499999999999995`}}], 
      LineBox[{{110., -17.677669529663685`}, {
       113.57802541904441`, -17.677669529663685`}, {
       113.57802541904441`, -21.65063509461097}, {110., -21.65063509461097}, {
       110., -17.677669529663685`}}], 
      LineBox[{{110., -21.650635094610962`}, {
       113.5780254190444, -21.650635094610962`}, {
       113.57802541904441`, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -21.650635094610962`}}], 
      LineBox[{{110., -24.148145657226706`}, {
       113.57802541904441`, -24.148145657226706`}, {
       113.57802541904441`, -25.}, {110., -25.}, {
       110., -24.148145657226706`}}], 
      LineBox[{{110., -25.}, {113.57802541904441`, -25.}, {
       113.57802541904441`, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -25.}}], 
      LineBox[{{110., -24.14814565722671}, {
       113.57802541904441`, -24.14814565722671}, {
       113.57802541904441`, -21.65063509461097}, {110., -21.65063509461097}, {
       110., -24.14814565722671}}], 
      LineBox[{{110., -21.65063509461097}, {
       113.57802541904441`, -21.65063509461097}, {
       113.57802541904441`, -17.677669529663692`}, {
       110., -17.677669529663692`}, {110., -21.65063509461097}}], 
      LineBox[{{110., -17.677669529663696`}, {
       113.57802541904441`, -17.677669529663696`}, {
       113.57802541904441`, -12.50000000000001}, {110., -12.50000000000001}, {
       110., -17.677669529663696`}}], 
      LineBox[{{110., -12.50000000000001}, {
       113.57802541904441`, -12.50000000000001}, {
       113.57802541904441`, -6.470476127563038}, {110., -6.470476127563038}, {
       110., -12.50000000000001}}], 
      LineBox[{{110., -6.470476127563038}, {
       113.57802541904441`, -6.470476127563038}, {
       113.57802541904441`, -2.6796885989305705`*^-14}, {
       110., -2.6796885989305705`*^-14}, {110., -6.470476127563038}}], 
      LineBox[{{110., -4.592425496802574*^-15}, {
       113.57802541904441`, -4.592425496802574*^-15}, {113.57802541904441`, 
       6.470476127563007}, {110., 6.470476127563007}, {
       110., -4.592425496802574*^-15}}], 
      LineBox[{{110., 6.470476127563007}, {113.57802541904441`, 
       6.470476127563007}, {113.57802541904441`, 12.499999999999984`}, {110., 
       12.499999999999984`}, {110., 6.470476127563007}}], 
      LineBox[{{110., 12.499999999999984`}, {113.57802541904441`, 
       12.499999999999984`}, {113.5780254190444, 17.67766952966367}, {110., 
       17.67766952966367}, {110., 12.499999999999984`}}], 
      LineBox[{{110., 17.677669529663685`}, {113.57802541904441`, 
       17.677669529663685`}, {113.57802541904441`, 21.65063509461096}, {110., 
       21.65063509461096}, {110., 17.677669529663685`}}], 
      LineBox[{{110., 21.65063509461096}, {113.57802541904441`, 
       21.65063509461096}, {113.57802541904441`, 24.148145657226703`}, {110., 
       24.148145657226703`}, {110., 21.65063509461096}}], 
      LineBox[{{110., 24.148145657226703`}, {113.57802541904441`, 
       24.148145657226703`}, {113.57802541904441`, 25.}, {110., 25.}, {110., 
       24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 100.}, {150., -100.}, {150., -100.}, {150., 100.}, {
       150., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -100.}, {0., -100.}, {0., -100.}, {150., -100.}, {
       150., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -100}, {0, 100}, {0, 100}, {0, -100}, {0, -100}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 100.}, {150., 100.}, {150., 100.}, {0., 100.}, {0., 
       100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -100.}, {150., 100.}, {0., 100.}, {0., -100.}, {
       150., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 100.}, {150., -100.}, {0., -100.}, {0., 100.}, {150., 
       100.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -0.5}, {5.048651843044828, -0.5}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -0.33333333333333337`}, {
       5.021509426103136, -0.33333333333333337`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -0.16666666666666669`}, {
       5.005360598393839, -0.16666666666666669`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {5., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.16666666666666663`}, {5.005360598393839, 
       0.16666666666666663`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.33333333333333326`}, {5.021509426103136, 
       0.33333333333333326`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.5}, {5.048651843044828, 0.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.048651843044828, -0.5}, {5.5, -0.46982997724039294`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.021509426103136, -0.33333333333333337`}, {
       5.5, -0.31218421371718047`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.005360598393839, -0.16666666666666669`}, {
       5.5, -0.15578802396809338`}}]}, 
     {Arrowheads[Small], ArrowBox[{{5., 0.}, {5.5, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.005360598393839, 0.16666666666666663`}, {5.5, 
       0.15578802396809333`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.021509426103136, 0.33333333333333326`}, {5.5, 
       0.31218421371718036`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.048651843044828, 0.5}, {5.5, 0.46982997724039294`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, -0.46982997724039294`}, {110., 10.17229718329583}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, -0.31218421371718047`}, {110., 6.713140751170057}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, -0.15578802396809338`}, {110., 3.336543745516641}}]}, 
     {Arrowheads[Small], ArrowBox[{{5.5, 0.}, {110., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, 0.15578802396809333`}, {
       110., -3.3365437455166402`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, 0.31218421371718036`}, {110., -6.713140751170055}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.5, 0.46982997724039294`}, {110., -10.17229718329583}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 10.17229718329583}, {118.87062419306221`, 
       10.765247281069662`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 6.713140751170057}, {119.5071754327512, 
       7.133354651731334}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 3.336543745516641}, {119.87812019541987`, 
       3.5537940086186}}]}, 
     {Arrowheads[Small], ArrowBox[{{110., 0.}, {120., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -3.3365437455166402`}, {
       119.87812019541987`, -3.553794008618599}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -6.713140751170055}, {
       119.5071754327512, -7.133354651731333}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -10.17229718329583}, {
       118.87062419306221`, -10.765247281069662`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{118.87062419306221`, 10.765247281069662`}, {150., 
       10.513213780597138`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{119.5071754327512, 7.133354651731334}, {150., 
       6.987455142808589}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{119.87812019541987`, 3.5537940086186}, {150., 
       3.4869434273167403`}}]}, 
     {Arrowheads[Small], ArrowBox[{{120., 0.}, {150., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{119.87812019541987`, -3.553794008618599}, {
       150., -3.48694342731674}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{119.5071754327512, -7.133354651731333}, {
       150., -6.987455142808587}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{118.87062419306221`, -10.765247281069662`}, {
       150., -10.513213780597138`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQLSb0+uRFQxEHBjB4sH//GrWJbGIiDmGhIHB1f4n6
avtaVhj/6H6IOph6BgaYfAhE3h6mH8K/ao9mvj2EFnN4mbT7wEbBe/th/NJO
/vrLvy7D+VJT2Vbd+XAYzmdAAWIOEhB5uHnFEP3o5kP4DdEOi5/KhZlHqDjA
+H0P1010vCUF568Je3rDdiMXnI9iHZC/CiJ/AMbvgeg/gGb+gQPCnX47tsc6
KEjcrj3Xruog6PCpv/RBrEPNJX35vg4ZB9cgHnnjH7EOq57N7dXO44HaEwe3
Dya/AiJ/AKa/CqIf3XyI/QeSHO5xPf9ymE3VAcZnaX1UoP5ZGs6/Mq9qhtNT
bjgfxX9A/mWIPNw8Joh+dPMPAADDqquN
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L2\"\>", {115., -28.43060989124279}, {0., 0.}], 
    InsetBox["\<\"L1\"\>", {5.25, -4.430609891242787}, {0., 0.}], 
    InsetBox["\<\"PH\"\>", {10., -3.9306098912427867`}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317372737427`*^9},
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"},
 
 CellLabel->"During evaluation of In[26]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["In the picture shown above, the first two elements are too small \
to be clearly seen. We next zoom-in on the first two elements using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],

Cell[CellGroupData[{

Cell["ShowSystem[sys,ShowRange->{1,2}];", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"},
 
 CellLabel->"In[27]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.200534679946088, -1., 0.}, {5.5, -1., 
      2.4492935982947064`*^-16}, {5.5, -0.6666666666666667, 
      2.041077998578922*^-16}, {5.08714497247726, -0.6666666666666667, 0.}, {
      5.200534679946088, -1., 0.}}], 
     Polygon3DBox[{{5.08714497247726, -0.6666666666666667, 0.}, {
      5.5, -0.6666666666666667, 2.041077998578922*^-16}, {
      5.5, -0.3333333333333335, 1.6328623988631378`*^-16}, {
      5.021509426103136, -0.33333333333333337`, 0.}, {
      5.08714497247726, -0.6666666666666667, 0.}}], 
     Polygon3DBox[{{5.021509426103136, -0.33333333333333337`, 0.}, {
      5.5, -0.3333333333333335, 1.6328623988631378`*^-16}, {
      5.5, -2.220446049250313*^-16, 1.2246467991473535`*^-16}, {5., 0., 0.}, {
      5.021509426103136, -0.33333333333333337`, 0.}}], 
     Polygon3DBox[{{5., 0., 0.}, {5.5, 0., 1.2246467991473532`*^-16}, {5.5, 
      0.33333333333333326`, 8.164311994315689*^-17}, {5.021509426103136, 
      0.33333333333333326`, 0.}, {5., 0., 0.}}], 
     Polygon3DBox[{{5.021509426103136, 0.33333333333333326`, 0.}, {5.5, 
      0.33333333333333326`, 8.164311994315689*^-17}, {5.5, 0.6666666666666665,
       4.082155997157845*^-17}, {5.08714497247726, 0.6666666666666665, 0.}, {
      5.021509426103136, 0.33333333333333326`, 0.}}], 
     Polygon3DBox[{{5.08714497247726, 0.6666666666666665, 0.}, {5.5, 
      0.6666666666666665, 4.0821559971578457`*^-17}, {5.5, 0.9999999999999998,
       2.0394466101703364`*^-32}, {5.200534679946088, 0.9999999999999998, 
      0.}, {5.08714497247726, 0.6666666666666665, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYImfAt4qyIAwMYfNjPAAX3jKU7bCJFHMJCQeAp
XHz/GrWJbGIw8atwcQiAmYMAMPUhEPX26OZDxJ/CxdHcY49qmhhO8TA0c1DF
r+IwBx2Iwdy5H7v4UwxxqHvg4rjCEwAuiDu+
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{5.200534679946088, 0., -1.}, {5.5, 
        1.2246467991473532`*^-16, -1.}, {5.5, 
        1.020538999289461*^-16, -0.6666666666666667}, {5.08714497247726, 
        2.041077998578922*^-17, -0.6666666666666667}, {5.200534679946088, 
        0., -1.}}], 
       Polygon3DBox[{{5.08714497247726, 
        2.041077998578922*^-17, -0.6666666666666667}, {5.5, 
        1.020538999289461*^-16, -0.6666666666666667}, {5.5, 
        8.164311994315689*^-17, -0.3333333333333335}, {5.021509426103136, 
        4.082155997157844*^-17, -0.33333333333333337`}, {5.08714497247726, 
        2.041077998578922*^-17, -0.6666666666666667}}], 
       Polygon3DBox[{{5.021509426103136, 
        4.082155997157844*^-17, -0.33333333333333337`}, {5.5, 
        8.164311994315689*^-17, -0.3333333333333335}, {5.5, 
        6.123233995736767*^-17, -2.220446049250313*^-16}, {5., 
        6.123233995736766*^-17, 0.}, {5.021509426103136, 
        4.082155997157844*^-17, -0.33333333333333337`}}], 
       Polygon3DBox[{{5., 6.123233995736766*^-17, 0.}, {5.5, 
        6.123233995736766*^-17, 0.}, {5.5, 4.0821559971578444`*^-17, 
        0.33333333333333326`}, {5.021509426103136, 8.164311994315688*^-17, 
        0.33333333333333326`}, {5., 6.123233995736766*^-17, 0.}}], 
       Polygon3DBox[{{5.021509426103136, 8.164311994315688*^-17, 
        0.33333333333333326`}, {5.5, 4.0821559971578444`*^-17, 
        0.33333333333333326`}, {5.5, 2.0410779985789225`*^-17, 
        0.6666666666666665}, {5.08714497247726, 1.0205389992894609`*^-16, 
        0.6666666666666665}, {5.021509426103136, 8.164311994315688*^-17, 
        0.33333333333333326`}}], 
       Polygon3DBox[{{5.08714497247726, 1.0205389992894609`*^-16, 
        0.6666666666666665}, {5.5, 2.0410779985789228`*^-17, 
        0.6666666666666665}, {5.5, 1.0197233050851682`*^-32, 
        0.9999999999999998}, {5.200534679946088, 1.224646799147353*^-16, 
        0.9999999999999998}, {5.08714497247726, 1.0205389992894609`*^-16, 
        0.6666666666666665}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYImfAt4qyIAwMK+LD/nrF0h00kQjwsFASe7t+/
Rm0imxi6+NX9EB66OQwM6OpDIOrt0c2HiD+1x+EeewgtRlAc6k4c4ldxmAMD
CPEQFH+hiz/FEIe6Zz+u8AQAHKE7vg==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5.200534679946088, 1., 0.}, {5.5, 1., 0.}, {5.5, 
       0.9659258262890683, 0.25881904510252074`}, {5.200534679946088, 
       0.9659258262890683, 0.25881904510252074`}, {5.200534679946088, 1., 
       0.}}], Line3DBox[{{5.200534679946088, 0.9659258262890683, 
       0.25881904510252074`}, {5.5, 0.9659258262890683, 
       0.25881904510252074`}, {5.5, 0.8660254037844387, 
       0.49999999999999994`}, {5.200534679946088, 0.8660254037844387, 
       0.49999999999999994`}, {5.200534679946088, 0.9659258262890683, 
       0.25881904510252074`}}], 
      Line3DBox[{{5.200534679946088, 0.8660254037844387, 
       0.49999999999999994`}, {5.5, 0.8660254037844387, 
       0.49999999999999994`}, {5.5, 0.7071067811865476, 0.7071067811865475}, {
       5.200534679946088, 0.7071067811865476, 0.7071067811865475}, {
       5.200534679946088, 0.8660254037844387, 0.49999999999999994`}}], 
      Line3DBox[{{5.200534679946088, 0.7071067811865476, 
       0.7071067811865475}, {5.5, 0.7071067811865476, 0.7071067811865475}, {
       5.5, 0.5000000000000001, 0.8660254037844386}, {5.200534679946088, 
       0.5000000000000001, 0.8660254037844386}, {5.200534679946088, 
       0.7071067811865476, 0.7071067811865475}}], 
      Line3DBox[{{5.200534679946088, 0.5000000000000001, 
       0.8660254037844386}, {5.5, 0.5000000000000001, 0.8660254037844386}, {
       5.5, 0.25881904510252096`, 0.9659258262890682}, {5.200534679946088, 
       0.25881904510252096`, 0.9659258262890682}, {5.200534679946088, 
       0.5000000000000001, 0.8660254037844386}}], 
      Line3DBox[{{5.200534679946088, 0.25881904510252096`, 
       0.9659258262890682}, {5.5, 0.25881904510252096`, 0.9659258262890682}, {
       5.5, 2.83276944882399*^-16, 1.}, {5.200534679946088, 
       2.83276944882399*^-16, 1.}, {5.200534679946088, 0.25881904510252096`, 
       0.9659258262890682}}], 
      Line3DBox[{{5.200534679946088, 6.123233995736766*^-17, 1.}, {5.5, 
       6.123233995736766*^-17, 1.}, {5.5, -0.25881904510252063`, 
       0.9659258262890683}, {5.200534679946088, -0.25881904510252063`, 
       0.9659258262890683}, {5.200534679946088, 6.123233995736766*^-17, 1.}}],
       Line3DBox[{{5.200534679946088, -0.25881904510252063`, 
       0.9659258262890683}, {5.5, -0.25881904510252063`, 
       0.9659258262890683}, {5.5, -0.4999999999999998, 0.8660254037844387}, {
       5.200534679946088, -0.4999999999999998, 0.8660254037844387}, {
       5.200534679946088, -0.25881904510252063`, 0.9659258262890683}}], 
      Line3DBox[{{5.200534679946088, -0.4999999999999998, 
       0.8660254037844387}, {5.5, -0.4999999999999998, 0.8660254037844387}, {
       5.5, -0.7071067811865475, 0.7071067811865476}, {
       5.200534679946088, -0.7071067811865475, 0.7071067811865476}, {
       5.200534679946088, -0.4999999999999998, 0.8660254037844387}}], 
      Line3DBox[{{5.200534679946088, -0.7071067811865475, 
       0.7071067811865476}, {5.5, -0.7071067811865475, 0.7071067811865476}, {
       5.5, -0.8660254037844387, 0.49999999999999994`}, {
       5.200534679946088, -0.8660254037844387, 0.49999999999999994`}, {
       5.200534679946088, -0.7071067811865475, 0.7071067811865476}}], 
      Line3DBox[{{5.200534679946088, -0.8660254037844385, 
       0.5000000000000003}, {5.5, -0.8660254037844385, 0.5000000000000003}, {
       5.5, -0.9659258262890682, 0.258819045102521}, {
       5.200534679946088, -0.9659258262890682, 0.258819045102521}, {
       5.200534679946088, -0.8660254037844385, 0.5000000000000003}}], 
      Line3DBox[{{5.200534679946088, -0.9659258262890682, 
       0.258819045102521}, {5.5, -0.9659258262890682, 0.258819045102521}, {
       5.5, -1., 1.2246467991473532`*^-16}, {5.200534679946088, -1., 
       1.2246467991473532`*^-16}, {5.200534679946088, -0.9659258262890682, 
       0.258819045102521}}], 
      Line3DBox[{{5.200534679946088, -1., 1.2246467991473532`*^-16}, {
       5.5, -1., 1.2246467991473532`*^-16}, {
       5.5, -0.9659258262890683, -0.2588190451025208}, {
       5.200534679946088, -0.9659258262890683, -0.2588190451025208}, {
       5.200534679946088, -1., 1.2246467991473532`*^-16}}], 
      Line3DBox[{{
       5.200534679946088, -0.9659258262890684, -0.25881904510252035`}, {
       5.5, -0.9659258262890684, -0.25881904510252035`}, {
       5.5, -0.8660254037844388, -0.4999999999999997}, {
       5.200534679946088, -0.8660254037844388, -0.4999999999999997}, {
       5.200534679946088, -0.9659258262890684, -0.25881904510252035`}}], 
      Line3DBox[{{
       5.200534679946088, -0.8660254037844388, -0.4999999999999997}, {
       5.5, -0.8660254037844388, -0.4999999999999997}, {
       5.5, -0.7071067811865477, -0.7071067811865475}, {
       5.200534679946088, -0.7071067811865477, -0.7071067811865475}, {
       5.200534679946088, -0.8660254037844388, -0.4999999999999997}}], 
      Line3DBox[{{
       5.200534679946088, -0.7071067811865479, -0.7071067811865471}, {
       5.5, -0.7071067811865479, -0.7071067811865471}, {
       5.5, -0.5000000000000004, -0.8660254037844384}, {
       5.200534679946088, -0.5000000000000004, -0.8660254037844384}, {
       5.200534679946088, -0.7071067811865479, -0.7071067811865471}}], 
      Line3DBox[{{
       5.200534679946088, -0.5000000000000004, -0.8660254037844384}, {
       5.5, -0.5000000000000004, -0.8660254037844384}, {
       5.5, -0.2588190451025215, -0.9659258262890681}, {
       5.200534679946088, -0.2588190451025215, -0.9659258262890681}, {
       5.200534679946088, -0.5000000000000004, -0.8660254037844384}}], 
      Line3DBox[{{
       5.200534679946088, -0.2588190451025215, -0.9659258262890681}, {
       5.5, -0.2588190451025215, -0.9659258262890681}, {
       5.5, -1.0718754395722282`*^-15, -1.}, {
       5.200534679946088, -1.0718754395722282`*^-15, -1.}, {
       5.200534679946088, -0.2588190451025215, -0.9659258262890681}}], 
      Line3DBox[{{5.200534679946088, -1.8369701987210297`*^-16, -1.}, {
       5.5, -1.8369701987210297`*^-16, -1.}, {5.5, 
       0.2588190451025203, -0.9659258262890684}, {5.200534679946088, 
       0.2588190451025203, -0.9659258262890684}, {
       5.200534679946088, -1.8369701987210297`*^-16, -1.}}], 
      Line3DBox[{{5.200534679946088, 
       0.2588190451025203, -0.9659258262890684}, {5.5, 
       0.2588190451025203, -0.9659258262890684}, {5.5, 
       0.49999999999999933`, -0.866025403784439}, {5.200534679946088, 
       0.49999999999999933`, -0.866025403784439}, {5.200534679946088, 
       0.2588190451025203, -0.9659258262890684}}], 
      Line3DBox[{{5.200534679946088, 
       0.49999999999999933`, -0.866025403784439}, {5.5, 
       0.49999999999999933`, -0.866025403784439}, {5.5, 
       0.7071067811865468, -0.7071067811865483}, {5.200534679946088, 
       0.7071067811865468, -0.7071067811865483}, {5.200534679946088, 
       0.49999999999999933`, -0.866025403784439}}], 
      Line3DBox[{{5.200534679946088, 
       0.7071067811865474, -0.7071067811865477}, {5.5, 
       0.7071067811865474, -0.7071067811865477}, {5.5, 
       0.8660254037844384, -0.5000000000000004}, {5.200534679946088, 
       0.8660254037844384, -0.5000000000000004}, {5.200534679946088, 
       0.7071067811865474, -0.7071067811865477}}], 
      Line3DBox[{{5.200534679946088, 
       0.8660254037844384, -0.5000000000000004}, {5.5, 
       0.8660254037844384, -0.5000000000000004}, {5.5, 
       0.9659258262890681, -0.25881904510252157`}, {5.200534679946088, 
       0.9659258262890681, -0.25881904510252157`}, {5.200534679946088, 
       0.8660254037844384, -0.5000000000000004}}], 
      Line3DBox[{{5.200534679946088, 
       0.9659258262890681, -0.25881904510252157`}, {5.5, 
       0.9659258262890681, -0.25881904510252157`}, {5.5, 
       1., -1.133107779529596*^-15}, {5.200534679946088, 
       1., -1.133107779529596*^-15}, {5.200534679946088, 
       0.9659258262890681, -0.25881904510252157`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{10., 0.05, 0.}, {10., 0.2, 0.}, {10., 
      0.19318516525781368`, 0.05176380902050415}, {10., 0.04829629131445342, 
      0.012940952255126037`}, {10., 0.05, 0.}}], 
     Polygon3DBox[{{10., 0.04829629131445342, 0.012940952255126037`}, {10., 
      0.19318516525781368`, 0.05176380902050415}, {10., 0.17320508075688776`, 
      0.09999999999999998}, {10., 0.04330127018922194, 
      0.024999999999999998`}, {10., 0.04829629131445342, 
      0.012940952255126037`}}], 
     Polygon3DBox[{{10., 0.04330127018922194, 0.024999999999999998`}, {10., 
      0.17320508075688776`, 0.09999999999999998}, {10., 0.14142135623730953`, 
      0.1414213562373095}, {10., 0.03535533905932738, 
      0.035355339059327376`}, {10., 0.04330127018922194, 
      0.024999999999999998`}}], 
     Polygon3DBox[{{10., 0.03535533905932738, 0.035355339059327376`}, {10., 
      0.14142135623730953`, 0.1414213562373095}, {10., 0.10000000000000002`, 
      0.17320508075688773`}, {10., 0.02500000000000001, 
      0.04330127018922193}, {10., 0.03535533905932738, 
      0.035355339059327376`}}], 
     Polygon3DBox[{{10., 0.02500000000000001, 0.04330127018922193}, {10., 
      0.10000000000000002`, 0.17320508075688773`}, {10., 0.05176380902050419, 
      0.19318516525781365`}, {10., 0.012940952255126049`, 
      0.04829629131445341}, {10., 0.02500000000000001, 0.04330127018922193}}],
      Polygon3DBox[{{10., 0.012940952255126049`, 0.04829629131445341}, {10., 
      0.05176380902050419, 0.19318516525781365`}, {10., 
      5.665538897647979*^-17, 0.2}, {10., 1.4163847244119948`*^-17, 0.05}, {
      10., 0.012940952255126049`, 0.04829629131445341}}], 
     Polygon3DBox[{{10., 3.061616997868383*^-18, 0.05}, {10., 
      1.2246467991473533`*^-17, 0.2}, {10., -0.05176380902050413, 
      0.19318516525781368`}, {10., -0.012940952255126032`, 
      0.04829629131445342}, {10., 3.061616997868383*^-18, 0.05}}], 
     Polygon3DBox[{{10., -0.012940952255126032`, 0.04829629131445342}, {
      10., -0.05176380902050413, 0.19318516525781368`}, {
      10., -0.09999999999999995, 0.17320508075688776`}, {
      10., -0.02499999999999999, 0.04330127018922194}, {
      10., -0.012940952255126032`, 0.04829629131445342}}], 
     Polygon3DBox[{{10., -0.02499999999999999, 0.04330127018922194}, {
      10., -0.09999999999999995, 0.17320508075688776`}, {
      10., -0.1414213562373095, 0.14142135623730953`}, {
      10., -0.035355339059327376`, 0.03535533905932738}, {
      10., -0.02499999999999999, 0.04330127018922194}}], 
     Polygon3DBox[{{10., -0.035355339059327376`, 0.03535533905932738}, {
      10., -0.1414213562373095, 0.14142135623730953`}, {
      10., -0.17320508075688776`, 0.09999999999999998}, {
      10., -0.04330127018922194, 0.024999999999999998`}, {
      10., -0.035355339059327376`, 0.03535533905932738}}], 
     Polygon3DBox[{{10., -0.043301270189221926`, 0.02500000000000002}, {
      10., -0.17320508075688767`, 0.10000000000000006`}, {
      10., -0.19318516525781365`, 0.0517638090205042}, {
      10., -0.04829629131445341, 0.01294095225512605}, {
      10., -0.043301270189221926`, 0.02500000000000002}}], 
     Polygon3DBox[{{10., -0.04829629131445341, 0.01294095225512605}, {
      10., -0.19318516525781365`, 0.0517638090205042}, {10., -0.2, 
      2.4492935982947065`*^-17}, {10., -0.05, 6.123233995736766*^-18}, {
      10., -0.04829629131445341, 0.01294095225512605}}], 
     Polygon3DBox[{{10., -0.05, 6.123233995736766*^-18}, {10., -0.2, 
      2.4492935982947065`*^-17}, {
      10., -0.19318516525781368`, -0.05176380902050416}, {
      10., -0.04829629131445342, -0.01294095225512604}, {10., -0.05, 
      6.123233995736766*^-18}}], 
     Polygon3DBox[{{10., -0.04829629131445343, -0.012940952255126018`}, {
      10., -0.19318516525781368`, -0.05176380902050407}, {
      10., -0.17320508075688776`, -0.09999999999999995}, {
      10., -0.043301270189221946`, -0.024999999999999988`}, {
      10., -0.04829629131445343, -0.012940952255126018`}}], 
     Polygon3DBox[{{10., -0.043301270189221946`, -0.024999999999999988`}, {
      10., -0.17320508075688776`, -0.09999999999999995}, {
      10., -0.14142135623730953`, -0.1414213562373095}, {
      10., -0.03535533905932738, -0.035355339059327376`}, {
      10., -0.043301270189221946`, -0.024999999999999988`}}], 
     Polygon3DBox[{{10., -0.0353553390593274, -0.035355339059327355`}, {
      10., -0.1414213562373096, -0.14142135623730942`}, {
      10., -0.10000000000000009`, -0.17320508075688767`}, {
      10., -0.025000000000000022`, -0.04330127018922192}, {
      10., -0.0353553390593274, -0.035355339059327355`}}], 
     Polygon3DBox[{{10., -0.025000000000000022`, -0.04330127018922192}, {
      10., -0.10000000000000009`, -0.17320508075688767`}, {
      10., -0.0517638090205043, -0.1931851652578136}, {
      10., -0.012940952255126077`, -0.048296291314453406`}, {
      10., -0.025000000000000022`, -0.04330127018922192}}], 
     Polygon3DBox[{{10., -0.012940952255126077`, -0.048296291314453406`}, {
      10., -0.0517638090205043, -0.1931851652578136}, {
      10., -2.1437508791444562`*^-16, -0.2}, {
      10., -5.359377197861141*^-17, -0.05}, {
      10., -0.012940952255126077`, -0.048296291314453406`}}], 
     Polygon3DBox[{{10., -9.184850993605149*^-18, -0.05}, {
      10., -3.6739403974420595`*^-17, -0.2}, {10., 
      0.05176380902050406, -0.19318516525781368`}, {10., 
      0.012940952255126016`, -0.04829629131445343}, {
      10., -9.184850993605149*^-18, -0.05}}], 
     Polygon3DBox[{{10., 0.012940952255126016`, -0.04829629131445343}, {10., 
      0.05176380902050406, -0.19318516525781368`}, {10., 
      0.09999999999999987, -0.1732050807568878}, {10., 
      0.024999999999999967`, -0.04330127018922195}, {10., 
      0.012940952255126016`, -0.04829629131445343}}], 
     Polygon3DBox[{{10., 0.024999999999999967`, -0.04330127018922195}, {10., 
      0.09999999999999987, -0.1732050807568878}, {10., 
      0.14142135623730936`, -0.14142135623730967`}, {10., 
      0.03535533905932734, -0.03535533905932742}, {10., 
      0.024999999999999967`, -0.04330127018922195}}], 
     Polygon3DBox[{{10., 0.03535533905932737, -0.03535533905932738}, {10., 
      0.14142135623730948`, -0.14142135623730953`}, {10., 
      0.17320508075688767`, -0.10000000000000009`}, {10., 
      0.04330127018922192, -0.025000000000000022`}, {10., 
      0.03535533905932737, -0.03535533905932738}}], 
     Polygon3DBox[{{10., 0.04330127018922192, -0.025000000000000022`}, {10., 
      0.17320508075688767`, -0.10000000000000009`}, {10., 
      0.1931851652578136, -0.051763809020504314`}, {10., 
      0.048296291314453406`, -0.012940952255126079`}, {10., 
      0.04330127018922192, -0.025000000000000022`}}], 
     Polygon3DBox[{{10., 0.048296291314453406`, -0.012940952255126079`}, {10.,
       0.1931851652578136, -0.051763809020504314`}, {10., 
      0.2, -2.2662155590591917`*^-16}, {10., 0.05, -5.665538897647979*^-17}, {
      10., 0.048296291314453406`, -0.012940952255126079`}}], 
     Polygon3DBox[{{10., 0.2, 0.}, {10., 0.35, 0.}, {10., 0.3380740392011739, 
      0.09058666578588226}, {10., 0.19318516525781368`, 
      0.05176380902050415}, {10., 0.2, 0.}}], 
     Polygon3DBox[{{10., 0.19318516525781368`, 0.05176380902050415}, {10., 
      0.3380740392011739, 0.09058666578588226}, {10., 0.30310889132455354`, 
      0.17499999999999996`}, {10., 0.17320508075688776`, 
      0.09999999999999998}, {10., 0.19318516525781368`, 
      0.05176380902050415}}], 
     Polygon3DBox[{{10., 0.17320508075688776`, 0.09999999999999998}, {10., 
      0.30310889132455354`, 0.17499999999999996`}, {10., 0.24748737341529167`,
       0.2474873734152916}, {10., 0.14142135623730953`, 0.1414213562373095}, {
      10., 0.17320508075688776`, 0.09999999999999998}}], 
     Polygon3DBox[{{10., 0.14142135623730953`, 0.1414213562373095}, {10., 
      0.24748737341529167`, 0.2474873734152916}, {10., 0.17500000000000004`, 
      0.3031088913245535}, {10., 0.10000000000000002`, 
      0.17320508075688773`}, {10., 0.14142135623730953`, 
      0.1414213562373095}}], 
     Polygon3DBox[{{10., 0.10000000000000002`, 0.17320508075688773`}, {10., 
      0.17500000000000004`, 0.3031088913245535}, {10., 0.09058666578588233, 
      0.33807403920117385`}, {10., 0.05176380902050419, 
      0.19318516525781365`}, {10., 0.10000000000000002`, 
      0.17320508075688773`}}], 
     Polygon3DBox[{{10., 0.05176380902050419, 0.19318516525781365`}, {10., 
      0.09058666578588233, 0.33807403920117385`}, {10., 
      9.914693070883965*^-17, 0.35}, {10., 5.665538897647979*^-17, 0.2}, {10.,
       0.05176380902050419, 0.19318516525781365`}}], 
     Polygon3DBox[{{10., 1.2246467991473533`*^-17, 0.2}, {10., 
      2.143131898507868*^-17, 0.35}, {10., -0.09058666578588223, 
      0.3380740392011739}, {10., -0.05176380902050413, 
      0.19318516525781368`}, {10., 1.2246467991473533`*^-17, 0.2}}], 
     Polygon3DBox[{{10., -0.05176380902050413, 0.19318516525781368`}, {
      10., -0.09058666578588223, 0.3380740392011739}, {
      10., -0.1749999999999999, 0.30310889132455354`}, {
      10., -0.09999999999999995, 0.17320508075688776`}, {
      10., -0.05176380902050413, 0.19318516525781368`}}], 
     Polygon3DBox[{{10., -0.09999999999999995, 0.17320508075688776`}, {
      10., -0.1749999999999999, 0.30310889132455354`}, {
      10., -0.2474873734152916, 0.24748737341529167`}, {
      10., -0.1414213562373095, 0.14142135623730953`}, {
      10., -0.09999999999999995, 0.17320508075688776`}}], 
     Polygon3DBox[{{10., -0.1414213562373095, 0.14142135623730953`}, {
      10., -0.2474873734152916, 0.24748737341529167`}, {
      10., -0.30310889132455354`, 0.17499999999999996`}, {
      10., -0.17320508075688776`, 0.09999999999999998}, {
      10., -0.1414213562373095, 0.14142135623730953`}}], 
     Polygon3DBox[{{10., -0.17320508075688767`, 0.10000000000000006`}, {
      10., -0.30310889132455343`, 0.1750000000000001}, {
      10., -0.33807403920117385`, 0.09058666578588236}, {
      10., -0.19318516525781365`, 0.0517638090205042}, {
      10., -0.17320508075688767`, 0.10000000000000006`}}], 
     Polygon3DBox[{{10., -0.19318516525781365`, 0.0517638090205042}, {
      10., -0.33807403920117385`, 0.09058666578588236}, {10., -0.35, 
      4.286263797015736*^-17}, {10., -0.2, 2.4492935982947065`*^-17}, {
      10., -0.19318516525781365`, 0.0517638090205042}}], 
     Polygon3DBox[{{10., -0.2, 2.4492935982947065`*^-17}, {10., -0.35, 
      4.286263797015736*^-17}, {
      10., -0.3380740392011739, -0.09058666578588227}, {
      10., -0.19318516525781368`, -0.05176380902050416}, {10., -0.2, 
      2.4492935982947065`*^-17}}], 
     Polygon3DBox[{{10., -0.19318516525781368`, -0.05176380902050407}, {
      10., -0.33807403920117396`, -0.09058666578588213}, {
      10., -0.30310889132455354`, -0.1749999999999999}, {
      10., -0.17320508075688776`, -0.09999999999999995}, {
      10., -0.19318516525781368`, -0.05176380902050407}}], 
     Polygon3DBox[{{10., -0.17320508075688776`, -0.09999999999999995}, {
      10., -0.30310889132455354`, -0.1749999999999999}, {
      10., -0.2474873734152917, -0.2474873734152916}, {
      10., -0.14142135623730953`, -0.1414213562373095}, {
      10., -0.17320508075688776`, -0.09999999999999995}}], 
     Polygon3DBox[{{10., -0.1414213562373096, -0.14142135623730942`}, {
      10., -0.24748737341529178`, -0.24748737341529148`}, {
      10., -0.17500000000000016`, -0.30310889132455343`}, {
      10., -0.10000000000000009`, -0.17320508075688767`}, {
      10., -0.1414213562373096, -0.14142135623730942`}}], 
     Polygon3DBox[{{10., -0.10000000000000009`, -0.17320508075688767`}, {
      10., -0.17500000000000016`, -0.30310889132455343`}, {
      10., -0.09058666578588252, -0.3380740392011738}, {
      10., -0.0517638090205043, -0.1931851652578136}, {
      10., -0.10000000000000009`, -0.17320508075688767`}}], 
     Polygon3DBox[{{10., -0.0517638090205043, -0.1931851652578136}, {
      10., -0.09058666578588252, -0.3380740392011738}, {
      10., -3.751564038502798*^-16, -0.35}, {
      10., -2.1437508791444562`*^-16, -0.2}, {
      10., -0.0517638090205043, -0.1931851652578136}}], 
     Polygon3DBox[{{10., -3.6739403974420595`*^-17, -0.2}, {
      10., -6.429395695523605*^-17, -0.35}, {10., 
      0.09058666578588209, -0.33807403920117396`}, {10., 
      0.05176380902050406, -0.19318516525781368`}, {
      10., -3.6739403974420595`*^-17, -0.2}}], 
     Polygon3DBox[{{10., 0.05176380902050406, -0.19318516525781368`}, {10., 
      0.09058666578588209, -0.33807403920117396`}, {10., 
      0.17499999999999977`, -0.3031088913245537}, {10., 
      0.09999999999999987, -0.1732050807568878}, {10., 
      0.05176380902050406, -0.19318516525781368`}}], 
     Polygon3DBox[{{10., 0.09999999999999987, -0.1732050807568878}, {10., 
      0.17499999999999977`, -0.3031088913245537}, {10., 
      0.2474873734152914, -0.24748737341529192`}, {10., 
      0.14142135623730936`, -0.14142135623730967`}, {10., 
      0.09999999999999987, -0.1732050807568878}}], 
     Polygon3DBox[{{10., 0.14142135623730948`, -0.14142135623730953`}, {10., 
      0.24748737341529156`, -0.2474873734152917}, {10., 
      0.30310889132455343`, -0.17500000000000016`}, {10., 
      0.17320508075688767`, -0.10000000000000009`}, {10., 
      0.14142135623730948`, -0.14142135623730953`}}], 
     Polygon3DBox[{{10., 0.17320508075688767`, -0.10000000000000009`}, {10., 
      0.30310889132455343`, -0.17500000000000016`}, {10., 
      0.3380740392011738, -0.09058666578588255}, {10., 
      0.1931851652578136, -0.051763809020504314`}, {10., 
      0.17320508075688767`, -0.10000000000000009`}}], 
     Polygon3DBox[{{10., 0.1931851652578136, -0.051763809020504314`}, {10., 
      0.3380740392011738, -0.09058666578588255}, {10., 
      0.35, -3.965877228353586*^-16}, {10., 0.2, -2.2662155590591917`*^-16}, {
      10., 0.1931851652578136, -0.051763809020504314`}}], 
     Polygon3DBox[{{10., 0.35, 0.}, {10., 0.5, 0.}, {10., 
      0.48296291314453416`, 0.12940952255126037`}, {10., 0.3380740392011739, 
      0.09058666578588226}, {10., 0.35, 0.}}], 
     Polygon3DBox[{{10., 0.3380740392011739, 0.09058666578588226}, {10., 
      0.48296291314453416`, 0.12940952255126037`}, {10., 0.43301270189221935`,
       0.24999999999999997`}, {10., 0.30310889132455354`, 
      0.17499999999999996`}, {10., 0.3380740392011739, 0.09058666578588226}}],
      Polygon3DBox[{{10., 0.30310889132455354`, 0.17499999999999996`}, {10., 
      0.43301270189221935`, 0.24999999999999997`}, {10., 0.3535533905932738, 
      0.35355339059327373`}, {10., 0.24748737341529167`, 
      0.2474873734152916}, {10., 0.30310889132455354`, 
      0.17499999999999996`}}], 
     Polygon3DBox[{{10., 0.24748737341529167`, 0.2474873734152916}, {10., 
      0.3535533905932738, 0.35355339059327373`}, {10., 0.25000000000000006`, 
      0.4330127018922193}, {10., 0.17500000000000004`, 0.3031088913245535}, {
      10., 0.24748737341529167`, 0.2474873734152916}}], 
     Polygon3DBox[{{10., 0.17500000000000004`, 0.3031088913245535}, {10., 
      0.25000000000000006`, 0.4330127018922193}, {10., 0.12940952255126048`, 
      0.4829629131445341}, {10., 0.09058666578588233, 0.33807403920117385`}, {
      10., 0.17500000000000004`, 0.3031088913245535}}], 
     Polygon3DBox[{{10., 0.09058666578588233, 0.33807403920117385`}, {10., 
      0.12940952255126048`, 0.4829629131445341}, {10., 1.416384724411995*^-16,
       0.5}, {10., 9.914693070883965*^-17, 0.35}, {10., 0.09058666578588233, 
      0.33807403920117385`}}], 
     Polygon3DBox[{{10., 2.143131898507868*^-17, 0.35}, {10., 
      3.061616997868383*^-17, 0.5}, {10., -0.12940952255126031`, 
      0.48296291314453416`}, {10., -0.09058666578588223, 
      0.3380740392011739}, {10., 2.143131898507868*^-17, 0.35}}], 
     Polygon3DBox[{{10., -0.09058666578588223, 0.3380740392011739}, {
      10., -0.12940952255126031`, 0.48296291314453416`}, {
      10., -0.2499999999999999, 0.43301270189221935`}, {
      10., -0.1749999999999999, 0.30310889132455354`}, {
      10., -0.09058666578588223, 0.3380740392011739}}], 
     Polygon3DBox[{{10., -0.1749999999999999, 0.30310889132455354`}, {
      10., -0.2499999999999999, 0.43301270189221935`}, {
      10., -0.35355339059327373`, 0.3535533905932738}, {
      10., -0.2474873734152916, 0.24748737341529167`}, {
      10., -0.1749999999999999, 0.30310889132455354`}}], 
     Polygon3DBox[{{10., -0.2474873734152916, 0.24748737341529167`}, {
      10., -0.35355339059327373`, 0.3535533905932738}, {
      10., -0.43301270189221935`, 0.24999999999999997`}, {
      10., -0.30310889132455354`, 0.17499999999999996`}, {
      10., -0.2474873734152916, 0.24748737341529167`}}], 
     Polygon3DBox[{{10., -0.30310889132455343`, 0.1750000000000001}, {
      10., -0.43301270189221924`, 0.25000000000000017`}, {
      10., -0.4829629131445341, 0.1294095225512605}, {
      10., -0.33807403920117385`, 0.09058666578588236}, {
      10., -0.30310889132455343`, 0.1750000000000001}}], 
     Polygon3DBox[{{10., -0.33807403920117385`, 0.09058666578588236}, {
      10., -0.4829629131445341, 0.1294095225512605}, {10., -0.5, 
      6.123233995736766*^-17}, {10., -0.35, 4.286263797015736*^-17}, {
      10., -0.33807403920117385`, 0.09058666578588236}}], 
     Polygon3DBox[{{10., -0.35, 4.286263797015736*^-17}, {10., -0.5, 
      6.123233995736766*^-17}, {
      10., -0.48296291314453416`, -0.1294095225512604}, {
      10., -0.3380740392011739, -0.09058666578588227}, {10., -0.35, 
      4.286263797015736*^-17}}], 
     Polygon3DBox[{{10., -0.33807403920117396`, -0.09058666578588213}, {
      10., -0.4829629131445342, -0.12940952255126018`}, {
      10., -0.4330127018922194, -0.24999999999999986`}, {
      10., -0.30310889132455354`, -0.1749999999999999}, {
      10., -0.33807403920117396`, -0.09058666578588213}}], 
     Polygon3DBox[{{10., -0.30310889132455354`, -0.1749999999999999}, {
      10., -0.4330127018922194, -0.24999999999999986`}, {
      10., -0.35355339059327384`, -0.35355339059327373`}, {
      10., -0.2474873734152917, -0.2474873734152916}, {
      10., -0.30310889132455354`, -0.1749999999999999}}], 
     Polygon3DBox[{{10., -0.24748737341529178`, -0.24748737341529148`}, {
      10., -0.353553390593274, -0.35355339059327356`}, {
      10., -0.2500000000000002, -0.4330127018922192}, {
      10., -0.17500000000000016`, -0.30310889132455343`}, {
      10., -0.24748737341529178`, -0.24748737341529148`}}], 
     Polygon3DBox[{{10., -0.17500000000000016`, -0.30310889132455343`}, {
      10., -0.2500000000000002, -0.4330127018922192}, {
      10., -0.12940952255126076`, -0.48296291314453405`}, {
      10., -0.09058666578588252, -0.3380740392011738}, {
      10., -0.17500000000000016`, -0.30310889132455343`}}], 
     Polygon3DBox[{{10., -0.09058666578588252, -0.3380740392011738}, {
      10., -0.12940952255126076`, -0.48296291314453405`}, {
      10., -5.359377197861141*^-16, -0.5}, {
      10., -3.751564038502798*^-16, -0.35}, {
      10., -0.09058666578588252, -0.3380740392011738}}], 
     Polygon3DBox[{{10., -6.429395695523605*^-17, -0.35}, {
      10., -9.18485099360515*^-17, -0.5}, {10., 
      0.12940952255126015`, -0.4829629131445342}, {10., 
      0.09058666578588209, -0.33807403920117396`}, {
      10., -6.429395695523605*^-17, -0.35}}], 
     Polygon3DBox[{{10., 0.09058666578588209, -0.33807403920117396`}, {10., 
      0.12940952255126015`, -0.4829629131445342}, {10., 
      0.24999999999999967`, -0.4330127018922196}, {10., 
      0.17499999999999977`, -0.3031088913245537}, {10., 
      0.09058666578588209, -0.33807403920117396`}}], 
     Polygon3DBox[{{10., 0.17499999999999977`, -0.3031088913245537}, {10., 
      0.24999999999999967`, -0.4330127018922196}, {10., 
      0.35355339059327345`, -0.3535533905932742}, {10., 
      0.2474873734152914, -0.24748737341529192`}, {10., 
      0.17499999999999977`, -0.3031088913245537}}], 
     Polygon3DBox[{{10., 0.24748737341529156`, -0.2474873734152917}, {10., 
      0.3535533905932737, -0.35355339059327384`}, {10., 
      0.4330127018922192, -0.2500000000000002}, {10., 
      0.30310889132455343`, -0.17500000000000016`}, {10., 
      0.24748737341529156`, -0.2474873734152917}}], 
     Polygon3DBox[{{10., 0.30310889132455343`, -0.17500000000000016`}, {10., 
      0.4330127018922192, -0.2500000000000002}, {10., 
      0.48296291314453405`, -0.12940952255126079`}, {10., 
      0.3380740392011738, -0.09058666578588255}, {10., 
      0.30310889132455343`, -0.17500000000000016`}}], 
     Polygon3DBox[{{10., 0.3380740392011738, -0.09058666578588255}, {10., 
      0.48296291314453405`, -0.12940952255126079`}, {10., 
      0.5, -5.66553889764798*^-16}, {10., 0.35, -3.965877228353586*^-16}, {
      10., 0.3380740392011738, -0.09058666578588255}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhQcZg1EwRW2jOgABWH1am58712rbBv4NpherKh
yx4mrsy1tm2q9jL7mRAAF+dO/h8oIbXIngtKw8TnQNUpQfXBxNuh5q6C2gMT
LzoW/JrT1scG1V0qDrUQ9ftXo6mfDjF/vzKa+VB37OdGc48iRN3++Wjuh7pj
fweaf6Hu2A9xV4wNTHwNVH0p1F0wcRWo+dOg7oKJ80Ldww6lYeILoOoUoPrg
/oKauxJqD0z86pW6guO6qXtg7oKJl0DdvQZN/QSoP1XRzOeEhgs3mnug7rBf
gOZ+qDvsZ6D5FxZPkPDJ2QMASUjK7A==
       "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhQcYDQD+wZUICKg+h+D/e7L+7ZT2CbfLB2wgF7
mPhqn4gXVdtu2/8Hg/Nw8bPW9WnzFlyzPwOlYeKMYPqC/SqoPpj4FKi5IlB7
YOLsMSLGassabVDdpeLQB1G/XxRN/R+IO/avRjMf6o79Z9HcsxKibj8z1F0w
cag79k9F8y/UHfsh7ppoAxMXg6rvhLoLJr4Gav5vqLtg4heg7jkJpWHiLBB3
7F8B1QcTnwc1VxhqD0ycq2uej2XlrD0wd8HEO6DuFkNT/wUaT+vQzD8NDZdz
aO6BusMe5i6YONQd9vPR/AuLJ0j4LNwDAHiEzzQ=
       "]]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImIAaxUcGD/TCWmNDrkxcNRRzQxWEgLBQErsLF969R
m8gmJuKALo6q/ihcvER9tX0tK0z9UQz12AHMPZggBGKOPbr56OKo6q/CxWHu
RxdHBQ/g4mjhg0sczV9iDi+Tdh/YKHiPyHATcyjt5K+//OsykeEm5iA1lW3V
nQ+H0cRxhZsYhjj+cBNzkICYT2S4iTkUQ9xPMNxg6qHhAxcHAO/pcOY=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIBYTen3yoqGIAwMYPNjPAAX716hNZBMTcQgLBYGr
cPES9dX2taww8aNwcQiAmYMAMPUhEPX26OZDxK/CxdHcY49qmpjDy6TdBzYK
3tuPLl7ayV9/+ddlDHGpqWyr7nw4jCGO7k6YuAREPYa9xRDzcbkHLg4AfzdA
hQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731737361981*^9},
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"},
 
 CellLabel->"During evaluation of In[27]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" points to a list of one or more numbers. These numbers refer to \
the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ComponentNumber",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" of the elements to be displayed. Rays are displayed that contain \
the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ComponentNumber",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" parameters specified with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5 ColorView", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.5", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is a powerful visualization tool that chooses the ray parameter \
to be represented by the ray color. Normally, each ray is colored to \
represent its wavelength. You can use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to have ray colors associated with ray parameters in addition to \
wavelength. Here we define ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["\nColorView->",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["rayparameterlabel",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" is used to render rays with specified colors according to ",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[". \n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" works with both ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["TurboPlot", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[". ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" gives ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" to ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" for determining ray colors. As  examples: ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->WaveLength",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" attempts to match the color of the ray to the wavelength; ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->Automatic",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" displays the initial ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RGBColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" values assigned for the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayLineRGB",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ray parameter; ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" for any ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" other than ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["WaveLength",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" attempts to colorize each ray segment according to the rank of \
the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" value within the possible range of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" values, for the displayed rays selected by ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayChoice",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowRange",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". ",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["If more than one ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" is indicated or the parameter gives a vector of three elements, \
then each of three values is assigned to the red, green, and blue colors. ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" may also point to a list of three numbers representing the red, \
green, and blue colors used.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" uses the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" function for rendering rays in different formats. You can develop \
your own color mapping schemes with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". Section 6.10 discusses ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" in more detail.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[TextData[{
 StyleBox["Now we look at some examples using the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option. You can use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView -> Intensity", "Input"],
 StyleBox[" in order to have the ray color represent the relative intensity \
value of each ray segment.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
 AnalyzeSystem[{
\tMove[LineOfRays[40],{0,-5},5],
\tMove[PlanoConvexLens[100,50,10, FresnelReflections -> True],50],
\tBoundary[100]},
\tPlotType->TopView, ColorView -> Intensity];\
\>", "Input",
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"In[28]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.7431148549531632`, -24.92389396183491}, {
      54.15358479945905, -20.338571991624484`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -5.}, {50.00376827030235, -0.6252371427712431}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-1.7431148549531632`, 14.92389396183491}, {53.92523180426972,
        19.794243211748157`}}]}}, 
    {Hue[0.03521285537969845], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
      60., -19.171068189440202`}}]}, 
    {Hue[0.691958655485179], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
      20.235045606249336`, -50.}}]}, 
    {Hue[0.03110528324988858], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
      60., -0.009292879215369254}}]}, 
    {Hue[0.6960662276149894], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
      7.105427357601002*^-15, 2.5371555495783014`}}]}, 
    {Hue[0.0418173544971639], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.92523180426972, 19.794243211748157`}, {60., 
      19.286502990943365`}}]}, 
    {Hue[0.6853541563677141], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.92523180426972, 19.794243211748157`}, {28.458389529954687`,
       50.}}]}, 
    {Hue[0.06835065310901084], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -19.171068189440202`}, {100., -6.707767791388587}}]}, 
    {Hue[0.6940337131355653], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -19.171068189440202`}, {
      53.15089604404306, -17.803331784164836`}}]}, 
    {Hue[0.06100169782168199], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -0.009292879215369254}, {100., 3.744079102316289}}]}, 
    {Hue[0.6972750962930845], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -0.009292879215369254}, {50.00354772074953, 
      0.6066649740846766}}]}, 
    {Hue[0.07153975015015054], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 19.286502990943365`}, {100., 14.1845047352222}}]}, 
    {Hue[0.6974491152118912], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 19.286502990943365`}, {53.504851242997255`, 
      18.743626595040972`}}]}, 
    {Hue[0.6982970498652417], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.15089604404306, -17.803331784164836`}, {0., 
      15.636644356946643`}}]}, 
    {Hue[0.6985540754133713], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00354772074953, 0.6066649740846766}, {
      7.105427357601002*^-15, 4.990817736505169}}]}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.504851242997255`, 18.743626595040972`}, {
      7.105427357601002*^-15, -1.258326331242742}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{54.15358479945905, -20.338571991624484`}, {
      50.00376827030235, -0.6252371427712431}, {53.92523180426972, 
      19.794243211748157`}, {60., -19.171068189440202`}, {
      20.235045606249336`, -50.}, {60., -0.009292879215369254}, {
      7.105427357601002*^-15, 2.5371555495783014`}, {60., 
      19.286502990943365`}, {28.458389529954687`, 50.}, {
      100., -6.707767791388587}, {53.15089604404306, -17.803331784164836`}, {
      100., 3.744079102316289}, {50.00354772074953, 0.6066649740846766}, {
      100., 14.1845047352222}, {53.504851242997255`, 18.743626595040972`}, {
      0., 15.636644356946643`}, {7.105427357601002*^-15, 4.990817736505169}, {
      7.105427357601002*^-15, -1.258326331242742}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731737802724*^9},
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"During evaluation of In[28]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["You can also give expressions that contain different ray \
parameters to ColorView. Here we use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView -> Log[Intensity]", "Input"],
 StyleBox[" in order to have the ray color represent the natural log of its \
relative intensity value where red is the strongest intensity and dark blue \
is the weakest intensity value.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
 AnalyzeSystem[{
\tMove[LineOfRays[40],{0,-5},5],
\tMove[PlanoConvexLens[100,50,10, FresnelReflections -> True],50],
\tBoundary[100]},
\tPlotType->TopView, ColorView -> Log[Intensity]];\
\>", "Input",
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"In[29]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.7431148549531632`, -24.92389396183491}, {
      54.15358479945905, -20.338571991624484`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -5.}, {50.00376827030235, -0.6252371427712431}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-1.7431148549531632`, 14.92389396183491}, {53.92523180426972,
        19.794243211748157`}}]}}, 
    {Hue[0.010570544928081183`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
      60., -19.171068189440202`}}]}, 
    {Hue[0.6447916321835084], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
      20.235045606249336`, -50.}}]}, 
    {Hue[0.009310115812930052], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
      60., -0.009292879215369254}}]}, 
    {Hue[0.6712058868267312], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
      7.105427357601002*^-15, 2.5371555495783014`}}]}, 
    {Hue[0.012612940404906924`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.92523180426972, 19.794243211748157`}, {60., 
      19.286502990943365`}}]}, 
    {Hue[0.6081836647481003], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.92523180426972, 19.794243211748157`}, {28.458389529954687`,
       50.}}]}, 
    {Hue[0.021021489322473094`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -19.171068189440202`}, {100., -6.707767791388587}}]}, 
    {Hue[0.6577261483797173], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -19.171068189440202`}, {
      53.15089604404306, -17.803331784164836`}}]}, 
    {Hue[0.01865912731158933], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -0.009292879215369254}, {100., 3.744079102316289}}]}, 
    {Hue[0.6796474577802889], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -0.009292879215369254}, {50.00354772074953, 
      0.6066649740846766}}]}, 
    {Hue[0.022054852216717668`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 19.286502990943365`}, {100., 14.1845047352222}}]}, 
    {Hue[0.6808906652378333], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 19.286502990943365`}, {53.504851242997255`, 
      18.743626595040972`}}]}, 
    {Hue[0.6870544518243322], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.15089604404306, -17.803331784164836`}, {0., 
      15.636644356946643`}}]}, 
    {Hue[0.6889586044887597], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00354772074953, 0.6066649740846766}, {
      7.105427357601002*^-15, 4.990817736505169}}]}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.504851242997255`, 18.743626595040972`}, {
      7.105427357601002*^-15, -1.258326331242742}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{54.15358479945905, -20.338571991624484`}, {
      50.00376827030235, -0.6252371427712431}, {53.92523180426972, 
      19.794243211748157`}, {60., -19.171068189440202`}, {
      20.235045606249336`, -50.}, {60., -0.009292879215369254}, {
      7.105427357601002*^-15, 2.5371555495783014`}, {60., 
      19.286502990943365`}, {28.458389529954687`, 50.}, {
      100., -6.707767791388587}, {53.15089604404306, -17.803331784164836`}, {
      100., 3.744079102316289}, {50.00354772074953, 0.6066649740846766}, {
      100., 14.1845047352222}, {53.504851242997255`, 18.743626595040972`}, {
      0., 15.636644356946643`}, {7.105427357601002*^-15, 4.990817736505169}, {
      7.105427357601002*^-15, -1.258326331242742}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317384693832`*^9},
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"During evaluation of In[29]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Next we look at some examples using the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option with other ray parameters. First we use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" in the normal fashion.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
ill = AnalyzeSystem[{
\tConeOfRays[10,NumberOfRays->20],
\tMove[BiConvexLens[50,50,20],90,1],
\tMove[ThinBaffle[2],{197,0,0}]},PlotType->TopView];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"In[30]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{97.42621376635236, -24.874183157635187`}, {
      103.44336045863966`, -24.769153471438706`}, {
      107.31480480692527`, -16.366974425274172`}, {
      93.26389597744534, -16.612233951193208`}, {
      97.42621376635236, -24.874183157635187`}}], 
     PolygonBox[{{93.26389597744534, -16.612233951193208`}, {
      107.31480480692527`, -16.366974425274172`}, {
      109.41659696886857`, -7.9956847729226}, {
      90.87123037488065, -8.319395350938256}, {
      93.26389597744534, -16.612233951193208`}}], 
     PolygonBox[{{90.87123037488065, -8.319395350938256}, {
      109.41659696886857`, -7.9956847729226}, {109.99695390312783`, 
      0.34904812874566316`}, {90., 0.}, {
      90.87123037488065, -8.319395350938256}}], 
     PolygonBox[{{90., 0.}, {109.99695390312783`, 0.34904812874567026`}, {
      109.12572352824718`, 8.668443479683923}, {90.58035693425926, 
      8.344732901668264}, {90., 0.}}], 
     PolygonBox[{{90.58035693425926, 8.344732901668264}, {109.12572352824718`,
       8.668443479683923}, {106.73305792568249`, 16.961282079938876`}, {
      92.68214909620255, 16.716022554019837`}, {90.58035693425926, 
      8.344732901668264}}], 
     PolygonBox[{{92.68214909620255, 16.716022554019837`}, {
      106.73305792568249`, 16.961282079938876`}, {102.5707401367755, 
      25.223231286380855`}, {96.55359344448816, 25.11820160018437}, {
      92.68214909620255, 16.716022554019837`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       93.26389597744534, -16.612233951193208`}, {
       90.87123037488065, -8.319395350938256}, {
       90., -3.552713678800501*^-15}, {90.58035693425926, 
       8.344732901668264}, {92.68214909620255, 16.71602255401983}, {
       96.55359344448816, 25.11820160018437}, {102.57074013677548`, 
       25.22323128638086}, {106.73305792568249`, 16.96128207993888}, {
       109.12572352824718`, 8.668443479683926}, {109.99695390312783`, 
       0.3490481287456738}, {109.41659696886857`, -7.995684772922593}, {
       107.31480480692528`, -16.366974425274158`}, {
       103.44336045863966`, -24.7691534714387}, {
       97.42621376635236, -24.874183157635187`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{96.98990360542027, 0.1220092212745929}, {
        103.00705029770756`, 0.2270389074710804}, {107.02393136630388`, 
        0.2971538273323565}, {92.97302253682395, 0.05189430141331686}, {
        96.98990360542027, 0.1220092212745929}}], 
       PolygonBox[{{92.97302253682395, 0.05189430141331686}, {
        107.02393136630388`, 0.2971538273323565}, {109.27116024855788`, 
        0.3363793533806653}, {90.72579365456996, 0.01266877536500799}, {
        92.97302253682395, 0.05189430141331686}}], 
       PolygonBox[{{90.72579365456996, 0.01266877536500799}, {
        109.27116024855788`, 0.3363793533806653}, {109.99695390312783`, 
        0.3490481287456718}, {90., 1.5543122344752192`*^-15}, {
        90.72579365456996, 0.01266877536500799}}], 
       PolygonBox[{{90., 1.5543122344752192`*^-15}, {109.99695390312783`, 
        0.3490481287456718}, {109.27116024855788`, 0.33637935338066427`}, {
        90.72579365456996, 0.012668775365008988`}, {90., 
        1.5543122344752192`*^-15}}], 
       PolygonBox[{{90.72579365456996, 0.012668775365008988`}, {
        109.27116024855788`, 0.33637935338066427`}, {107.02393136630388`, 
        0.29715382733235446`}, {92.97302253682395, 0.051894301413318855`}, {
        90.72579365456996, 0.012668775365008988`}}], 
       PolygonBox[{{92.97302253682395, 0.051894301413318855`}, {
        107.02393136630388`, 0.29715382733235446`}, {103.00705029770758`, 
        0.22703890747107747`}, {96.98990360542025, 0.1220092212745959}, {
        92.97302253682395, 0.051894301413318855`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{96.98990360542027, 0.1220092212745929}, {92.97302253682395, 
         0.0518943014133163}, {90.72579365456996, 0.01266877536500699}, {90., 
         0.}, {90.72579365456996, 0.01266877536500699}, {92.97302253682395, 
         0.05189430141331619}, {96.98990360542025, 0.1220092212745928}, {
         103.00705029770756`, 0.22703890747107736`}, {107.02393136630388`, 
         0.29715382733235396`}, {109.27116024855788`, 0.33637935338066327`}, {
         109.99695390312783`, 0.34904812874567026`}, {109.27116024855788`, 
         0.33637935338066327`}, {107.02393136630388`, 0.29715382733235407`}, {
         103.00705029770758`, 0.22703890747107747`}, {96.98990360542027, 
         0.1220092212745929}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{96.55359344448817, 25.118201600184378`}, {102.57074013677548`,
        25.22323128638086}, {102.58560704499094`, 24.371506685150017`}, {
       96.56846035270361, 24.266476998953536`}, {96.55359344448817, 
       25.118201600184378`}}], 
      LineBox[{{96.56846035270361, 24.266476998953536`}, {102.58560704499094`,
        24.371506685150017`}, {102.6291946144111, 21.87437650548993}, {
       96.61204792212379, 21.76934681929345}, {96.56846035270361, 
       24.266476998953536`}}], 
      LineBox[{{96.61204792212379, 21.76934681929345}, {102.6291946144111, 
       21.87437650548993}, {102.69853242421189`, 17.902016042441684`}, {
       96.68138573192459, 17.796986356245203`}, {96.61204792212379, 
       21.76934681929345}}], 
      LineBox[{{96.68138573192459, 17.796986356245203`}, {102.69853242421189`,
        17.902016042441684`}, {102.78889521724153`, 12.725135096925971`}, {
       96.77174852495423, 12.620105410729488`}, {96.68138573192459, 
       17.796986356245203`}}], 
      LineBox[{{96.77174852495423, 12.620105410729488`}, {102.78889521724153`,
        12.725135096925971`}, {102.8941249184866, 6.696529550179418}, {
       96.8769782261993, 6.591499863982934}, {96.77174852495423, 
       12.620105410729488`}}], 
      LineBox[{{96.8769782261993, 6.591499863982934}, {102.8941249184866, 
       6.696529550179418}, {103.00705029770756`, 0.22703890747108446`}, {
       96.98990360542027, 0.12200922127460001`}, {96.8769782261993, 
       6.591499863982934}}], 
      LineBox[{{96.98990360542027, 0.12200922127459446`}, {
       103.00705029770756`, 0.2270389074710789}, {
       103.11997567692853`, -6.242451735237256}, {
       97.10282898464123, -6.3474814214337405`}, {96.98990360542027, 
       0.12200922127459446`}}], 
      LineBox[{{97.10282898464123, -6.3474814214337405`}, {
       103.11997567692853`, -6.242451735237256}, {
       103.22520537817361`, -12.27105728198381}, {
       97.2080586858863, -12.376086968180292`}, {
       97.10282898464123, -6.3474814214337405`}}], 
      LineBox[{{97.2080586858863, -12.376086968180292`}, {
       103.22520537817361`, -12.27105728198381}, {
       103.31556817120324`, -17.447938227499527`}, {
       97.29842147891594, -17.55296791369601}, {
       97.2080586858863, -12.376086968180292`}}], 
      LineBox[{{97.29842147891594, -17.55296791369601}, {
       103.31556817120324`, -17.447938227499527`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871674, -21.52532837674426}, {
       97.29842147891594, -17.55296791369601}}], 
      LineBox[{{97.36775928871674, -21.525328376744252`}, {
       103.38490598100404`, -21.42029869054777}, {
       103.42849355042421`, -23.917428870207864`}, {
       97.41134685813691, -24.022458556404345`}, {
       97.36775928871674, -21.525328376744252`}}], 
      LineBox[{{97.41134685813691, -24.022458556404345`}, {
       103.42849355042421`, -23.917428870207864`}, {
       103.44336045863966`, -24.769153471438706`}, {
       97.42621376635236, -24.874183157635187`}, {
       97.41134685813691, -24.022458556404345`}}], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       103.44336045863966`, -24.769153471438706`}, {
       103.42849355042422`, -23.917428870207864`}, {
       97.4113468581369, -24.022458556404345`}, {
       97.42621376635236, -24.874183157635187`}}], 
      LineBox[{{97.41134685813691, -24.02245855640435}, {
       103.42849355042421`, -23.917428870207868`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871673, -21.52532837674426}, {
       97.41134685813691, -24.02245855640435}}], 
      LineBox[{{97.36775928871673, -21.52532837674426}, {
       103.38490598100404`, -21.420298690547778`}, {
       103.31556817120324`, -17.447938227499534`}, {
       97.29842147891594, -17.552967913696016`}, {
       97.36775928871673, -21.52532837674426}}], 
      LineBox[{{97.29842147891594, -17.55296791369602}, {
       103.31556817120324`, -17.447938227499538`}, {
       103.22520537817363`, -12.271057281983826`}, {
       97.2080586858863, -12.376086968180308`}, {
       97.29842147891594, -17.55296791369602}}], 
      LineBox[{{97.2080586858863, -12.376086968180308`}, {
       103.22520537817363`, -12.271057281983826`}, {
       103.11997567692853`, -6.242451735237278}, {
       97.10282898464123, -6.347481421433763}, {
       97.2080586858863, -12.376086968180308`}}], 
      LineBox[{{97.10282898464123, -6.347481421433763}, {
       103.11997567692853`, -6.242451735237278}, {103.00705029770756`, 
       0.22703890747105054`}, {96.98990360542027, 0.12200922127456615`}, {
       97.10282898464123, -6.347481421433763}}], 
      LineBox[{{96.98990360542027, 0.12200922127458835`}, {
       103.00705029770756`, 0.22703890747107275`}, {102.8941249184866, 
       6.6965295501794015`}, {96.8769782261993, 6.591499863982917}, {
       96.98990360542027, 0.12200922127458835`}}], 
      LineBox[{{96.8769782261993, 6.591499863982917}, {102.8941249184866, 
       6.6965295501794015`}, {102.78889521724153`, 12.725135096925952`}, {
       96.77174852495423, 12.620105410729469`}, {96.8769782261993, 
       6.591499863982917}}], 
      LineBox[{{96.77174852495423, 12.620105410729469`}, {102.78889521724153`,
        12.725135096925952`}, {102.69853242421189`, 17.902016042441666`}, {
       96.68138573192459, 17.796986356245185`}, {96.77174852495423, 
       12.620105410729469`}}], 
      LineBox[{{96.68138573192459, 17.7969863562452}, {102.69853242421189`, 
       17.90201604244168}, {102.62919461441112`, 21.87437650548992}, {
       96.61204792212378, 21.76934681929344}, {96.68138573192459, 
       17.7969863562452}}], 
      LineBox[{{96.61204792212378, 21.76934681929344}, {102.62919461441112`, 
       21.87437650548992}, {102.58560704499092`, 24.371506685150013`}, {
       96.56846035270362, 24.266476998953532`}, {96.61204792212378, 
       21.76934681929344}}], 
      LineBox[{{96.56846035270362, 24.266476998953532`}, {102.58560704499092`,
        24.371506685150013`}, {102.57074013677548`, 25.22323128638086}, {
       96.55359344448817, 25.118201600184378`}, {96.56846035270362, 
       24.266476998953532`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{197., 0.}, {197., 0.3333333333333333}, {197., 
      0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3333333333333333}, {197., 0.6666666666666666}, {
      197., 0.6439505508593788}, {197., 0.3219752754296894}, {197., 
      0.3333333333333333}}], 
     PolygonBox[{{197., 0.6666666666666666}, {197., 1.}, {197., 
      0.9659258262890683}, {197., 0.6439505508593788}, {197., 
      0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., 0.3219752754296894}, {197., 
      0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3219752754296894}, {197., 0.6439505508593788}, {
      197., 0.5773502691896257}, {197., 0.28867513459481287`}, {197., 
      0.3219752754296894}}], 
     PolygonBox[{{197., 0.6439505508593788}, {197., 0.9659258262890683}, {
      197., 0.8660254037844387}, {197., 0.5773502691896257}, {197., 
      0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481287`}, {197., 
      0.23570226039551584`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481287`}, {197., 0.5773502691896257}, {
      197., 0.4714045207910317}, {197., 0.23570226039551584`}, {197., 
      0.28867513459481287`}}], 
     PolygonBox[{{197., 0.5773502691896257}, {197., 0.8660254037844387}, {
      197., 0.7071067811865476}, {197., 0.4714045207910317}, {197., 
      0.5773502691896257}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551584`}, {197., 
      0.16666666666666669`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551584`}, {197., 0.4714045207910317}, {
      197., 0.33333333333333337`}, {197., 0.16666666666666669`}, {197., 
      0.23570226039551584`}}], 
     PolygonBox[{{197., 0.4714045207910317}, {197., 0.7071067811865476}, {
      197., 0.5000000000000001}, {197., 0.33333333333333337`}, {197., 
      0.4714045207910317}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666669`}, {197., 
      0.08627301503417364}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666669`}, {197., 0.33333333333333337`}, {
      197., 0.1725460300683473}, {197., 0.08627301503417364}, {197., 
      0.16666666666666669`}}], 
     PolygonBox[{{197., 0.33333333333333337`}, {197., 0.5000000000000001}, {
      197., 0.25881904510252096`}, {197., 0.1725460300683473}, {197., 
      0.33333333333333337`}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417364}, {197., 
      9.442564829413299*^-17}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417364}, {197., 0.1725460300683473}, {
      197., 1.8885129658826599`*^-16}, {197., 9.442564829413299*^-17}, {197., 
      0.08627301503417364}}], 
     PolygonBox[{{197., 0.1725460300683473}, {197., 0.25881904510252096`}, {
      197., 2.83276944882399*^-16}, {197., 1.8885129658826599`*^-16}, {197., 
      0.1725460300683473}}], 
     PolygonBox[{{197., 0.}, {197., 2.041077998578922*^-17}, {
      197., -0.08627301503417353}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 2.041077998578922*^-17}, {197., 
      4.082155997157844*^-17}, {197., -0.17254603006834707`}, {
      197., -0.08627301503417353}, {197., 2.041077998578922*^-17}}], 
     PolygonBox[{{197., 4.082155997157844*^-17}, {197., 
      6.123233995736766*^-17}, {197., -0.25881904510252063`}, {
      197., -0.17254603006834707`}, {197., 4.082155997157844*^-17}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417353}, {
      197., -0.16666666666666657`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417353}, {
      197., -0.17254603006834707`}, {197., -0.33333333333333315`}, {
      197., -0.16666666666666657`}, {197., -0.08627301503417353}}], 
     PolygonBox[{{197., -0.17254603006834707`}, {
      197., -0.25881904510252063`}, {197., -0.4999999999999998}, {
      197., -0.33333333333333315`}, {197., -0.17254603006834707`}}], 
     PolygonBox[{{197., 0.}, {197., -0.16666666666666657`}, {
      197., -0.2357022603955158}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.16666666666666657`}, {
      197., -0.33333333333333315`}, {197., -0.4714045207910316}, {
      197., -0.2357022603955158}, {197., -0.16666666666666657`}}], 
     PolygonBox[{{197., -0.33333333333333315`}, {197., -0.4999999999999998}, {
      197., -0.7071067811865475}, {197., -0.4714045207910316}, {
      197., -0.33333333333333315`}}], 
     PolygonBox[{{197., 0.}, {197., -0.2357022603955158}, {
      197., -0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2357022603955158}, {197., -0.4714045207910316}, {
      197., -0.5773502691896257}, {197., -0.28867513459481287`}, {
      197., -0.2357022603955158}}], 
     PolygonBox[{{197., -0.4714045207910316}, {197., -0.7071067811865475}, {
      197., -0.8660254037844387}, {197., -0.5773502691896257}, {
      197., -0.4714045207910316}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948128}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948128}, {197., -0.5773502691896256}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.2886751345948128}}], 
     PolygonBox[{{197., -0.5773502691896256}, {197., -0.8660254037844385}, {
      197., -0.9659258262890682}, {197., -0.6439505508593788}, {
      197., -0.5773502691896256}}], 
     PolygonBox[{{197., 0.}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3219752754296894}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}}], 
     PolygonBox[{{197., -0.6439505508593788}, {197., -0.9659258262890682}, {
      197., -1.}, {197., -0.6666666666666666}, {197., -0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3333333333333333}, {197., -0.6666666666666666}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}}], 
     PolygonBox[{{197., -0.6666666666666666}, {197., -1.}, {
      197., -0.9659258262890683}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., -0.32197527542968946`}, {
      197., -0.2886751345948129}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.32197527542968946`}, {197., -0.6439505508593789}, {
      197., -0.5773502691896258}, {197., -0.2886751345948129}, {
      197., -0.32197527542968946`}}], 
     PolygonBox[{{197., -0.6439505508593789}, {197., -0.9659258262890684}, {
      197., -0.8660254037844388}, {197., -0.5773502691896258}, {
      197., -0.6439505508593789}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948129}, {
      197., -0.2357022603955159}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948129}, {197., -0.5773502691896258}, {
      197., -0.4714045207910318}, {197., -0.2357022603955159}, {
      197., -0.2886751345948129}}], 
     PolygonBox[{{197., -0.5773502691896258}, {197., -0.8660254037844388}, {
      197., -0.7071067811865477}, {197., -0.4714045207910318}, {
      197., -0.5773502691896258}}], 
     PolygonBox[{{197., 0.}, {197., -0.23570226039551595`}, {
      197., -0.1666666666666668}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.23570226039551595`}, {197., -0.4714045207910319}, {
      197., -0.3333333333333336}, {197., -0.1666666666666668}, {
      197., -0.23570226039551595`}}], 
     PolygonBox[{{197., -0.4714045207910319}, {197., -0.7071067811865479}, {
      197., -0.5000000000000004}, {197., -0.3333333333333336}, {
      197., -0.4714045207910319}}], 
     PolygonBox[{{197., 0.}, {197., -0.1666666666666668}, {
      197., -0.08627301503417384}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.1666666666666668}, {197., -0.3333333333333336}, {
      197., -0.17254603006834768`}, {197., -0.08627301503417384}, {
      197., -0.1666666666666668}}], 
     PolygonBox[{{197., -0.3333333333333336}, {197., -0.5000000000000004}, {
      197., -0.2588190451025215}, {197., -0.17254603006834768`}, {
      197., -0.3333333333333336}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417384}, {
      197., -3.572918131907427*^-16}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417384}, {
      197., -0.17254603006834768`}, {197., -7.145836263814854*^-16}, {
      197., -3.572918131907427*^-16}, {197., -0.08627301503417384}}], 
     PolygonBox[{{197., -0.17254603006834768`}, {197., -0.2588190451025215}, {
      197., -1.0718754395722282`*^-15}, {197., -7.145836263814854*^-16}, {
      197., -0.17254603006834768`}}], 
     PolygonBox[{{197., 0.}, {197., -6.123233995736765*^-17}, {197., 
      0.08627301503417342}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -6.123233995736765*^-17}, {
      197., -1.224646799147353*^-16}, {197., 0.17254603006834685`}, {197., 
      0.08627301503417342}, {197., -6.123233995736765*^-17}}], 
     PolygonBox[{{197., -1.224646799147353*^-16}, {
      197., -1.8369701987210297`*^-16}, {197., 0.2588190451025203}, {197., 
      0.17254603006834685`}, {197., -1.224646799147353*^-16}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417342}, {197., 
      0.16666666666666644`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417342}, {197., 0.17254603006834685`}, {
      197., 0.33333333333333287`}, {197., 0.16666666666666644`}, {197., 
      0.08627301503417342}}], 
     PolygonBox[{{197., 0.17254603006834685`}, {197., 0.2588190451025203}, {
      197., 0.49999999999999933`}, {197., 0.33333333333333287`}, {197., 
      0.17254603006834685`}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666644`}, {197., 
      0.2357022603955156}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666644`}, {197., 0.33333333333333287`}, {
      197., 0.4714045207910312}, {197., 0.2357022603955156}, {197., 
      0.16666666666666644`}}], 
     PolygonBox[{{197., 0.33333333333333287`}, {197., 0.49999999999999933`}, {
      197., 0.7071067811865468}, {197., 0.4714045207910312}, {197., 
      0.33333333333333287`}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551578`}, {197., 
      0.28867513459481275`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551578`}, {197., 0.47140452079103157`}, {
      197., 0.5773502691896255}, {197., 0.28867513459481275`}, {197., 
      0.23570226039551578`}}], 
     PolygonBox[{{197., 0.47140452079103157`}, {197., 0.7071067811865474}, {
      197., 0.8660254037844384}, {197., 0.5773502691896255}, {197., 
      0.47140452079103157`}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481275`}, {197., 
      0.32197527542968934`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481275`}, {197., 0.5773502691896255}, {
      197., 0.6439505508593787}, {197., 0.32197527542968934`}, {197., 
      0.28867513459481275`}}], 
     PolygonBox[{{197., 0.5773502691896255}, {197., 0.8660254037844384}, {
      197., 0.9659258262890681}, {197., 0.6439505508593787}, {197., 
      0.5773502691896255}}], 
     PolygonBox[{{197., 0.}, {197., 0.32197527542968934`}, {197., 
      0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.32197527542968934`}, {197., 0.6439505508593787}, {
      197., 0.6666666666666666}, {197., 0.3333333333333333}, {197., 
      0.32197527542968934`}}], 
     PolygonBox[{{197., 0.6439505508593787}, {197., 0.9659258262890681}, {
      197., 1.}, {197., 0.6666666666666666}, {197., 0.6439505508593787}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYLMhwgjA/2ML7ofg/3uy/ewfmrfSJeVG17Deef
ta5Pm7fgGZzPCGY8gPOnsE0+WDvhApzPHiNirLZsog2M3weR3w/j//kPAvfh
/DMQ8+H8lRD74XwRiPvgfKj74XwxNPk1aPovoJnPAnE/nD8PzX1cXfN8LCtX
7YHxO9D89wXifjj/NFr4rEALP2G08IWFPwABtIYM
       "]]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.80009348181466, -7.943978826752928}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.77288879312717, -6.4333356875055925`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434345`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.65721119927778, -5.655198531684391*^-16}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958244`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959733}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.54211377326678, 6.41697999814953}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5152130159867, 7.9190550155329955`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.54211377326678, 6.4169799981495315`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959736}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958266`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.65721119927778, 1.654926196081874*^-15}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434336`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.77288879312717, -6.433335687505591}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.80009348181466, -7.943978826752928}, {
       109.44332883697214`, -7.824068037519229}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.79312901185494, -7.557334749403953}, {
       109.43847763990019`, -7.437947703984694}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.77288879312717, -6.4333356875055925`}, {
       109.42437067823238`, -6.315339227036188}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.74129707055698, -4.677973313963376}, {
       109.4023271061959, -4.561755637786824}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.7014215775235, -2.4606245660434345`}, {
       109.37446007821904`, -2.345968868015016}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.65721119927778, -5.655198531684391*^-16}, {
       109.34350700631593`, 0.1138176793967933}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.61308582705088, 2.4582281193958244`}, {
       109.31255401389252`, 2.5721494318492497`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.5734322977125, 4.669319404959733}, {109.28468719339604`, 
       4.7841375091179374`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.54211377326678, 6.41697999814953}, {109.26264387662552`, 
       6.5330455770536915`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.5220936404668, 7.534774616794779}, {109.24853712051282`, 
       7.651887495337791}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.5152130159867, 7.9190550155329955`}, {109.24368600173067`,
        8.036572893976766}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.5220936404668, 7.534774616794779}, {109.24853712051282`, 
       7.651887495337791}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.54211377326678, 6.4169799981495315`}, {
       109.26264387662552`, 6.533045577053693}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.5734322977125, 4.669319404959736}, {109.28468719339604`, 
       4.78413750911794}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.61308582705088, 2.4582281193958266`}, {
       109.31255401389252`, 2.572149431849252}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.65721119927778, 1.654926196081874*^-15}, {
       109.34350700631593`, 0.11381767939679524`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.7014215775235, -2.4606245660434336`}, {
       109.37446007821904`, -2.345968868015015}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.74129707055698, -4.677973313963376}, {
       109.4023271061959, -4.561755637786824}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.77288879312717, -6.433335687505591}, {
       109.42437067823238`, -6.315339227036186}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.79312901185494, -7.557334749403953}, {
       109.43847763990019`, -7.437947703984694}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.44332883697214`, -7.824068037519229}, {197., 
       0.11368177879512942`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
       0.12400849836319239`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.42437067823238`, -6.315339227036188}, {197., 
       0.1544760906390117}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
       0.20338283108796773`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.37446007821904`, -2.345968868015016}, {197., 
       0.26745459900226276`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.34350700631593`, 0.1138176793967933}, {197., 
       0.34152645204915943`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.31255401389252`, 2.5721494318492497`}, {197., 
       0.4186157623140434}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.28468719339604`, 4.7841375091179374`}, {197., 
       0.4905667114836554}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.26264387662552`, 6.5330455770536915`}, {197., 
       0.5491716105006761}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
       0.5874521738586784}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.24368600173067`, 8.036572893976766}, {197., 
       0.6007554299801923}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
       0.5874521738586784}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.26264387662552`, 6.533045577053693}, {197., 
       0.5491716105006752}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.28468719339604`, 4.78413750911794}, {197., 
       0.4905667114836545}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.31255401389252`, 2.572149431849252}, {197., 
       0.41861576231404296`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.34350700631593`, 0.11381767939679524`}, {197., 
       0.34152645204915744`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.37446007821904`, -2.345968868015015}, {197., 
       0.26745459900226365`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
       0.2033828310879695}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.42437067823238`, -6.315339227036186}, {197., 
       0.1544760906390117}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
       0.12400849836319239`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQfaDDa7fJ5jCHwyJbkhYdkz/gcFt/waFNYQ4ipc++
brWSO+Ba3cdUvjHM4bLUjsg9uyUP5KxyySxcH+Zgp/Rmkd02oQOs3CHiT9YA
+Qrb30WvZz6w6G7/fv5VYQ4MIJBwZM9xk7AzNsvDHKR9xRuLVzE7+Homym5e
EuYQ0/paIGmtkIPYzu9/Ny4Kc9jY++fsn1WSDl4XCn9nLgxzcCpl/zpbWc5h
dwezw88FYQ5tB7kPyayVx5CH6d8M1Q8zPx5qPsx+Baj9KO67cNcG5n4bqPvR
/Qfz/0Wo/9HD5xLXq/r4mGiHI963a294yx9outnCIgDkP3n8PKb0gOyBNxKL
HmtERzvsFfD1fOEkeeD7TYNd+yOjHSJ6N92zsRc68CEtXf17eLSDaEVOcPcR
pgM7W86z/AmNdvBz3H5KXXmv/c6fPY8YQqIdSvdeFDk8mcWh3G9RgEVQtMPb
lyUfvygJO1SrOWucD4h2yHiitPmaopRDiYwtxwv/aIdN01xSO2bLObj/1u6d
AeTvl1y/bqeQAoY8TH8WVD/M/A9Q82H2V0Hth7nvFtR9MPcLQ92P7j+Y/3dD
/Y8ePuB4WJDhwNAofMheaq89nB//NIZ1/344v6Fmedz9o4cR/DncN4o4TsH5
Hzx/PPkpexHO7/CYeHji7atw/o5lekdmnroF5zuwT31dmHofzn+xLz78wqSH
cP6PP6ENGWcewfkRklOLky0f45R/gKbfAM38DWj2p6C5j8EL1f0H0PyH7n9Y
+AAA7yWRXA==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {100.50912757553334`, -29.080630589559114`}, \
{0., 0.}], InsetBox["\<\"B\"\>", {197., -5.259611034414593}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731739137501*^9},
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"During evaluation of In[30]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["By selecting ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["PlotType->Surface",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->OpticalLength",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", we monitor the variance in optical path length across the lens \
surface.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ill,PlotType->Surface,
\tRayChoice->{IntersectionNumber->3},
\tColorView->OpticalLength];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"In[31]:="],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.], AbsolutePointSize[2.], PointBox[{0.1136817787951303, 0}]}, 
    {Hue[0.025942290507504226`], AbsolutePointSize[2.], 
     PointBox[{0.12400849836319239`, -0.07138916797736528}]}, 
    {Hue[0.09881076898982433], AbsolutePointSize[2.], 
     PointBox[{0.1544760906390108, -0.137252602658263}]}, 
    {Hue[0.20504632107009468`], AbsolutePointSize[2.], 
     PointBox[{0.20338283108796773`, -0.19199041473032974`}]}, 
    {Hue[0.3261097970113084], AbsolutePointSize[2.], 
     PointBox[{0.26745459900226276`, -0.23013156735063856`}]}, 
    {Hue[0.4433797119624967], AbsolutePointSize[2.], 
     PointBox[{0.34152645204915943`, -0.24694893578754318`}]}, 
    {Hue[0.5426938847825323], AbsolutePointSize[2.], 
     PointBox[{0.4186157623140434, -0.23938011994015174`}]}, 
    {Hue[0.6168710224680184], AbsolutePointSize[2.], 
     PointBox[{0.4905667114836554, -0.20692661710588567`}]}, 
    {Hue[0.6653954782588124], AbsolutePointSize[2.], 
     PointBox[{0.5491716105006761, -0.15215400858213624`}]}, 
    {Hue[0.6917705830612175], AbsolutePointSize[2.], 
     PointBox[{0.5874521738586775, -0.08058141827709564}]}, 
    {Hue[0.7], AbsolutePointSize[2.], PointBox[{0.6007554299801914, 0}]}, 
    {Hue[0.6917705830612175], AbsolutePointSize[2.], 
     PointBox[{0.5874521738586775, 0.08058141827709653}]}, 
    {Hue[0.6653954782588124], AbsolutePointSize[2.], 
     PointBox[{0.5491716105006752, 0.15215400858213624`}]}, 
    {Hue[0.6168710224680184], AbsolutePointSize[2.], 
     PointBox[{0.4905667114836545, 0.20692661710588478`}]}, 
    {Hue[0.5426938847825323], AbsolutePointSize[2.], 
     PointBox[{0.4186157623140434, 0.23938011994015174`}]}, 
    {Hue[0.4433797119624967], AbsolutePointSize[2.], 
     PointBox[{0.34152645204915744`, 0.24694893578754318`}]}, 
    {Hue[0.3261097970113084], AbsolutePointSize[2.], 
     PointBox[{0.26745459900226365`, 0.23013156735063856`}]}, 
    {Hue[0.20504632107009468`], AbsolutePointSize[2.], 
     PointBox[{0.2033828310879704, 0.19199041473032974`}]}, 
    {Hue[0.09881076898982433], AbsolutePointSize[2.], 
     PointBox[{0.1544760906390108, 0.1372526026582639}]}, 
    {Hue[0.025942290507504226`], AbsolutePointSize[2.], 
     PointBox[{0.12400849836319239`, 0.07138916797736528}], 
     {RGBColor[0, 0, 0], Thickness[
       NCache[
        Rational[1, 5000], 0.0002]], LineBox[CompressedData["
1:eJxdUr1qgkEQPETSCDbWgqJNMPiVFhK28QFEU4lYBKKVWIllirxCIIUglr7F
NGIlWFibQoMgiFqkNxF3BOfg447bb35udrOvvdpbLITw+P9d9us6GU/Nn+gz
Pzxavz7pJB6mdn6ppJK9g1V3Uek4W1r36Tmd+dhb+K4UismVTX6/hoPNzlqN
fjy3WNu8/N4ejbe3nff8jzjykJc61KWPcLdOrIN1x4N45wf5XR/Ud1+gP78H
fToO9Om8oE/XBX26L0h+rEPwEH6IPsQfxD/kfZD3Q/KB5AfJF5I/pD+Q/kH6
C+k/ZD4g8wOZL+j8/QH6RCHB
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317394485207`*^9},
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"During evaluation of In[31]:="]
}, Open  ]],

Cell["\<\
Similarly, we can color-render the variance in tilt angles for the rays \
plotted in either two or three dimensions.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["ShowSystem[ill,PlotType->TopView,ColorView->RayTilt];", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"In[32]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{97.42621376635236, -24.874183157635187`}, {
      103.44336045863966`, -24.769153471438706`}, {
      107.31480480692527`, -16.366974425274172`}, {
      93.26389597744534, -16.612233951193208`}, {
      97.42621376635236, -24.874183157635187`}}], 
     PolygonBox[{{93.26389597744534, -16.612233951193208`}, {
      107.31480480692527`, -16.366974425274172`}, {
      109.41659696886857`, -7.9956847729226}, {
      90.87123037488065, -8.319395350938256}, {
      93.26389597744534, -16.612233951193208`}}], 
     PolygonBox[{{90.87123037488065, -8.319395350938256}, {
      109.41659696886857`, -7.9956847729226}, {109.99695390312783`, 
      0.34904812874566316`}, {90., 0.}, {
      90.87123037488065, -8.319395350938256}}], 
     PolygonBox[{{90., 0.}, {109.99695390312783`, 0.34904812874567026`}, {
      109.12572352824718`, 8.668443479683923}, {90.58035693425926, 
      8.344732901668264}, {90., 0.}}], 
     PolygonBox[{{90.58035693425926, 8.344732901668264}, {109.12572352824718`,
       8.668443479683923}, {106.73305792568249`, 16.961282079938876`}, {
      92.68214909620255, 16.716022554019837`}, {90.58035693425926, 
      8.344732901668264}}], 
     PolygonBox[{{92.68214909620255, 16.716022554019837`}, {
      106.73305792568249`, 16.961282079938876`}, {102.5707401367755, 
      25.223231286380855`}, {96.55359344448816, 25.11820160018437}, {
      92.68214909620255, 16.716022554019837`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       93.26389597744534, -16.612233951193208`}, {
       90.87123037488065, -8.319395350938256}, {
       90., -3.552713678800501*^-15}, {90.58035693425926, 
       8.344732901668264}, {92.68214909620255, 16.71602255401983}, {
       96.55359344448816, 25.11820160018437}, {102.57074013677548`, 
       25.22323128638086}, {106.73305792568249`, 16.96128207993888}, {
       109.12572352824718`, 8.668443479683926}, {109.99695390312783`, 
       0.3490481287456738}, {109.41659696886857`, -7.995684772922593}, {
       107.31480480692528`, -16.366974425274158`}, {
       103.44336045863966`, -24.7691534714387}, {
       97.42621376635236, -24.874183157635187`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{96.98990360542027, 0.1220092212745929}, {
        103.00705029770756`, 0.2270389074710804}, {107.02393136630388`, 
        0.2971538273323565}, {92.97302253682395, 0.05189430141331686}, {
        96.98990360542027, 0.1220092212745929}}], 
       PolygonBox[{{92.97302253682395, 0.05189430141331686}, {
        107.02393136630388`, 0.2971538273323565}, {109.27116024855788`, 
        0.3363793533806653}, {90.72579365456996, 0.01266877536500799}, {
        92.97302253682395, 0.05189430141331686}}], 
       PolygonBox[{{90.72579365456996, 0.01266877536500799}, {
        109.27116024855788`, 0.3363793533806653}, {109.99695390312783`, 
        0.3490481287456718}, {90., 1.5543122344752192`*^-15}, {
        90.72579365456996, 0.01266877536500799}}], 
       PolygonBox[{{90., 1.5543122344752192`*^-15}, {109.99695390312783`, 
        0.3490481287456718}, {109.27116024855788`, 0.33637935338066427`}, {
        90.72579365456996, 0.012668775365008988`}, {90., 
        1.5543122344752192`*^-15}}], 
       PolygonBox[{{90.72579365456996, 0.012668775365008988`}, {
        109.27116024855788`, 0.33637935338066427`}, {107.02393136630388`, 
        0.29715382733235446`}, {92.97302253682395, 0.051894301413318855`}, {
        90.72579365456996, 0.012668775365008988`}}], 
       PolygonBox[{{92.97302253682395, 0.051894301413318855`}, {
        107.02393136630388`, 0.29715382733235446`}, {103.00705029770758`, 
        0.22703890747107747`}, {96.98990360542025, 0.1220092212745959}, {
        92.97302253682395, 0.051894301413318855`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{96.98990360542027, 0.1220092212745929}, {92.97302253682395, 
         0.0518943014133163}, {90.72579365456996, 0.01266877536500699}, {90., 
         0.}, {90.72579365456996, 0.01266877536500699}, {92.97302253682395, 
         0.05189430141331619}, {96.98990360542025, 0.1220092212745928}, {
         103.00705029770756`, 0.22703890747107736`}, {107.02393136630388`, 
         0.29715382733235396`}, {109.27116024855788`, 0.33637935338066327`}, {
         109.99695390312783`, 0.34904812874567026`}, {109.27116024855788`, 
         0.33637935338066327`}, {107.02393136630388`, 0.29715382733235407`}, {
         103.00705029770758`, 0.22703890747107747`}, {96.98990360542027, 
         0.1220092212745929}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{96.55359344448817, 25.118201600184378`}, {102.57074013677548`,
        25.22323128638086}, {102.58560704499094`, 24.371506685150017`}, {
       96.56846035270361, 24.266476998953536`}, {96.55359344448817, 
       25.118201600184378`}}], 
      LineBox[{{96.56846035270361, 24.266476998953536`}, {102.58560704499094`,
        24.371506685150017`}, {102.6291946144111, 21.87437650548993}, {
       96.61204792212379, 21.76934681929345}, {96.56846035270361, 
       24.266476998953536`}}], 
      LineBox[{{96.61204792212379, 21.76934681929345}, {102.6291946144111, 
       21.87437650548993}, {102.69853242421189`, 17.902016042441684`}, {
       96.68138573192459, 17.796986356245203`}, {96.61204792212379, 
       21.76934681929345}}], 
      LineBox[{{96.68138573192459, 17.796986356245203`}, {102.69853242421189`,
        17.902016042441684`}, {102.78889521724153`, 12.725135096925971`}, {
       96.77174852495423, 12.620105410729488`}, {96.68138573192459, 
       17.796986356245203`}}], 
      LineBox[{{96.77174852495423, 12.620105410729488`}, {102.78889521724153`,
        12.725135096925971`}, {102.8941249184866, 6.696529550179418}, {
       96.8769782261993, 6.591499863982934}, {96.77174852495423, 
       12.620105410729488`}}], 
      LineBox[{{96.8769782261993, 6.591499863982934}, {102.8941249184866, 
       6.696529550179418}, {103.00705029770756`, 0.22703890747108446`}, {
       96.98990360542027, 0.12200922127460001`}, {96.8769782261993, 
       6.591499863982934}}], 
      LineBox[{{96.98990360542027, 0.12200922127459446`}, {
       103.00705029770756`, 0.2270389074710789}, {
       103.11997567692853`, -6.242451735237256}, {
       97.10282898464123, -6.3474814214337405`}, {96.98990360542027, 
       0.12200922127459446`}}], 
      LineBox[{{97.10282898464123, -6.3474814214337405`}, {
       103.11997567692853`, -6.242451735237256}, {
       103.22520537817361`, -12.27105728198381}, {
       97.2080586858863, -12.376086968180292`}, {
       97.10282898464123, -6.3474814214337405`}}], 
      LineBox[{{97.2080586858863, -12.376086968180292`}, {
       103.22520537817361`, -12.27105728198381}, {
       103.31556817120324`, -17.447938227499527`}, {
       97.29842147891594, -17.55296791369601}, {
       97.2080586858863, -12.376086968180292`}}], 
      LineBox[{{97.29842147891594, -17.55296791369601}, {
       103.31556817120324`, -17.447938227499527`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871674, -21.52532837674426}, {
       97.29842147891594, -17.55296791369601}}], 
      LineBox[{{97.36775928871674, -21.525328376744252`}, {
       103.38490598100404`, -21.42029869054777}, {
       103.42849355042421`, -23.917428870207864`}, {
       97.41134685813691, -24.022458556404345`}, {
       97.36775928871674, -21.525328376744252`}}], 
      LineBox[{{97.41134685813691, -24.022458556404345`}, {
       103.42849355042421`, -23.917428870207864`}, {
       103.44336045863966`, -24.769153471438706`}, {
       97.42621376635236, -24.874183157635187`}, {
       97.41134685813691, -24.022458556404345`}}], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       103.44336045863966`, -24.769153471438706`}, {
       103.42849355042422`, -23.917428870207864`}, {
       97.4113468581369, -24.022458556404345`}, {
       97.42621376635236, -24.874183157635187`}}], 
      LineBox[{{97.41134685813691, -24.02245855640435}, {
       103.42849355042421`, -23.917428870207868`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871673, -21.52532837674426}, {
       97.41134685813691, -24.02245855640435}}], 
      LineBox[{{97.36775928871673, -21.52532837674426}, {
       103.38490598100404`, -21.420298690547778`}, {
       103.31556817120324`, -17.447938227499534`}, {
       97.29842147891594, -17.552967913696016`}, {
       97.36775928871673, -21.52532837674426}}], 
      LineBox[{{97.29842147891594, -17.55296791369602}, {
       103.31556817120324`, -17.447938227499538`}, {
       103.22520537817363`, -12.271057281983826`}, {
       97.2080586858863, -12.376086968180308`}, {
       97.29842147891594, -17.55296791369602}}], 
      LineBox[{{97.2080586858863, -12.376086968180308`}, {
       103.22520537817363`, -12.271057281983826`}, {
       103.11997567692853`, -6.242451735237278}, {
       97.10282898464123, -6.347481421433763}, {
       97.2080586858863, -12.376086968180308`}}], 
      LineBox[{{97.10282898464123, -6.347481421433763}, {
       103.11997567692853`, -6.242451735237278}, {103.00705029770756`, 
       0.22703890747105054`}, {96.98990360542027, 0.12200922127456615`}, {
       97.10282898464123, -6.347481421433763}}], 
      LineBox[{{96.98990360542027, 0.12200922127458835`}, {
       103.00705029770756`, 0.22703890747107275`}, {102.8941249184866, 
       6.6965295501794015`}, {96.8769782261993, 6.591499863982917}, {
       96.98990360542027, 0.12200922127458835`}}], 
      LineBox[{{96.8769782261993, 6.591499863982917}, {102.8941249184866, 
       6.6965295501794015`}, {102.78889521724153`, 12.725135096925952`}, {
       96.77174852495423, 12.620105410729469`}, {96.8769782261993, 
       6.591499863982917}}], 
      LineBox[{{96.77174852495423, 12.620105410729469`}, {102.78889521724153`,
        12.725135096925952`}, {102.69853242421189`, 17.902016042441666`}, {
       96.68138573192459, 17.796986356245185`}, {96.77174852495423, 
       12.620105410729469`}}], 
      LineBox[{{96.68138573192459, 17.7969863562452}, {102.69853242421189`, 
       17.90201604244168}, {102.62919461441112`, 21.87437650548992}, {
       96.61204792212378, 21.76934681929344}, {96.68138573192459, 
       17.7969863562452}}], 
      LineBox[{{96.61204792212378, 21.76934681929344}, {102.62919461441112`, 
       21.87437650548992}, {102.58560704499092`, 24.371506685150013`}, {
       96.56846035270362, 24.266476998953532`}, {96.61204792212378, 
       21.76934681929344}}], 
      LineBox[{{96.56846035270362, 24.266476998953532`}, {102.58560704499092`,
        24.371506685150013`}, {102.57074013677548`, 25.22323128638086}, {
       96.55359344448817, 25.118201600184378`}, {96.56846035270362, 
       24.266476998953532`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{197., 0.}, {197., 0.3333333333333333}, {197., 
      0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3333333333333333}, {197., 0.6666666666666666}, {
      197., 0.6439505508593788}, {197., 0.3219752754296894}, {197., 
      0.3333333333333333}}], 
     PolygonBox[{{197., 0.6666666666666666}, {197., 1.}, {197., 
      0.9659258262890683}, {197., 0.6439505508593788}, {197., 
      0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., 0.3219752754296894}, {197., 
      0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3219752754296894}, {197., 0.6439505508593788}, {
      197., 0.5773502691896257}, {197., 0.28867513459481287`}, {197., 
      0.3219752754296894}}], 
     PolygonBox[{{197., 0.6439505508593788}, {197., 0.9659258262890683}, {
      197., 0.8660254037844387}, {197., 0.5773502691896257}, {197., 
      0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481287`}, {197., 
      0.23570226039551584`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481287`}, {197., 0.5773502691896257}, {
      197., 0.4714045207910317}, {197., 0.23570226039551584`}, {197., 
      0.28867513459481287`}}], 
     PolygonBox[{{197., 0.5773502691896257}, {197., 0.8660254037844387}, {
      197., 0.7071067811865476}, {197., 0.4714045207910317}, {197., 
      0.5773502691896257}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551584`}, {197., 
      0.16666666666666669`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551584`}, {197., 0.4714045207910317}, {
      197., 0.33333333333333337`}, {197., 0.16666666666666669`}, {197., 
      0.23570226039551584`}}], 
     PolygonBox[{{197., 0.4714045207910317}, {197., 0.7071067811865476}, {
      197., 0.5000000000000001}, {197., 0.33333333333333337`}, {197., 
      0.4714045207910317}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666669`}, {197., 
      0.08627301503417364}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666669`}, {197., 0.33333333333333337`}, {
      197., 0.1725460300683473}, {197., 0.08627301503417364}, {197., 
      0.16666666666666669`}}], 
     PolygonBox[{{197., 0.33333333333333337`}, {197., 0.5000000000000001}, {
      197., 0.25881904510252096`}, {197., 0.1725460300683473}, {197., 
      0.33333333333333337`}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417364}, {197., 
      9.442564829413299*^-17}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417364}, {197., 0.1725460300683473}, {
      197., 1.8885129658826599`*^-16}, {197., 9.442564829413299*^-17}, {197., 
      0.08627301503417364}}], 
     PolygonBox[{{197., 0.1725460300683473}, {197., 0.25881904510252096`}, {
      197., 2.83276944882399*^-16}, {197., 1.8885129658826599`*^-16}, {197., 
      0.1725460300683473}}], 
     PolygonBox[{{197., 0.}, {197., 2.041077998578922*^-17}, {
      197., -0.08627301503417353}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 2.041077998578922*^-17}, {197., 
      4.082155997157844*^-17}, {197., -0.17254603006834707`}, {
      197., -0.08627301503417353}, {197., 2.041077998578922*^-17}}], 
     PolygonBox[{{197., 4.082155997157844*^-17}, {197., 
      6.123233995736766*^-17}, {197., -0.25881904510252063`}, {
      197., -0.17254603006834707`}, {197., 4.082155997157844*^-17}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417353}, {
      197., -0.16666666666666657`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417353}, {
      197., -0.17254603006834707`}, {197., -0.33333333333333315`}, {
      197., -0.16666666666666657`}, {197., -0.08627301503417353}}], 
     PolygonBox[{{197., -0.17254603006834707`}, {
      197., -0.25881904510252063`}, {197., -0.4999999999999998}, {
      197., -0.33333333333333315`}, {197., -0.17254603006834707`}}], 
     PolygonBox[{{197., 0.}, {197., -0.16666666666666657`}, {
      197., -0.2357022603955158}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.16666666666666657`}, {
      197., -0.33333333333333315`}, {197., -0.4714045207910316}, {
      197., -0.2357022603955158}, {197., -0.16666666666666657`}}], 
     PolygonBox[{{197., -0.33333333333333315`}, {197., -0.4999999999999998}, {
      197., -0.7071067811865475}, {197., -0.4714045207910316}, {
      197., -0.33333333333333315`}}], 
     PolygonBox[{{197., 0.}, {197., -0.2357022603955158}, {
      197., -0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2357022603955158}, {197., -0.4714045207910316}, {
      197., -0.5773502691896257}, {197., -0.28867513459481287`}, {
      197., -0.2357022603955158}}], 
     PolygonBox[{{197., -0.4714045207910316}, {197., -0.7071067811865475}, {
      197., -0.8660254037844387}, {197., -0.5773502691896257}, {
      197., -0.4714045207910316}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948128}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948128}, {197., -0.5773502691896256}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.2886751345948128}}], 
     PolygonBox[{{197., -0.5773502691896256}, {197., -0.8660254037844385}, {
      197., -0.9659258262890682}, {197., -0.6439505508593788}, {
      197., -0.5773502691896256}}], 
     PolygonBox[{{197., 0.}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3219752754296894}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}}], 
     PolygonBox[{{197., -0.6439505508593788}, {197., -0.9659258262890682}, {
      197., -1.}, {197., -0.6666666666666666}, {197., -0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3333333333333333}, {197., -0.6666666666666666}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}}], 
     PolygonBox[{{197., -0.6666666666666666}, {197., -1.}, {
      197., -0.9659258262890683}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., -0.32197527542968946`}, {
      197., -0.2886751345948129}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.32197527542968946`}, {197., -0.6439505508593789}, {
      197., -0.5773502691896258}, {197., -0.2886751345948129}, {
      197., -0.32197527542968946`}}], 
     PolygonBox[{{197., -0.6439505508593789}, {197., -0.9659258262890684}, {
      197., -0.8660254037844388}, {197., -0.5773502691896258}, {
      197., -0.6439505508593789}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948129}, {
      197., -0.2357022603955159}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948129}, {197., -0.5773502691896258}, {
      197., -0.4714045207910318}, {197., -0.2357022603955159}, {
      197., -0.2886751345948129}}], 
     PolygonBox[{{197., -0.5773502691896258}, {197., -0.8660254037844388}, {
      197., -0.7071067811865477}, {197., -0.4714045207910318}, {
      197., -0.5773502691896258}}], 
     PolygonBox[{{197., 0.}, {197., -0.23570226039551595`}, {
      197., -0.1666666666666668}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.23570226039551595`}, {197., -0.4714045207910319}, {
      197., -0.3333333333333336}, {197., -0.1666666666666668}, {
      197., -0.23570226039551595`}}], 
     PolygonBox[{{197., -0.4714045207910319}, {197., -0.7071067811865479}, {
      197., -0.5000000000000004}, {197., -0.3333333333333336}, {
      197., -0.4714045207910319}}], 
     PolygonBox[{{197., 0.}, {197., -0.1666666666666668}, {
      197., -0.08627301503417384}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.1666666666666668}, {197., -0.3333333333333336}, {
      197., -0.17254603006834768`}, {197., -0.08627301503417384}, {
      197., -0.1666666666666668}}], 
     PolygonBox[{{197., -0.3333333333333336}, {197., -0.5000000000000004}, {
      197., -0.2588190451025215}, {197., -0.17254603006834768`}, {
      197., -0.3333333333333336}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417384}, {
      197., -3.572918131907427*^-16}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417384}, {
      197., -0.17254603006834768`}, {197., -7.145836263814854*^-16}, {
      197., -3.572918131907427*^-16}, {197., -0.08627301503417384}}], 
     PolygonBox[{{197., -0.17254603006834768`}, {197., -0.2588190451025215}, {
      197., -1.0718754395722282`*^-15}, {197., -7.145836263814854*^-16}, {
      197., -0.17254603006834768`}}], 
     PolygonBox[{{197., 0.}, {197., -6.123233995736765*^-17}, {197., 
      0.08627301503417342}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -6.123233995736765*^-17}, {
      197., -1.224646799147353*^-16}, {197., 0.17254603006834685`}, {197., 
      0.08627301503417342}, {197., -6.123233995736765*^-17}}], 
     PolygonBox[{{197., -1.224646799147353*^-16}, {
      197., -1.8369701987210297`*^-16}, {197., 0.2588190451025203}, {197., 
      0.17254603006834685`}, {197., -1.224646799147353*^-16}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417342}, {197., 
      0.16666666666666644`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417342}, {197., 0.17254603006834685`}, {
      197., 0.33333333333333287`}, {197., 0.16666666666666644`}, {197., 
      0.08627301503417342}}], 
     PolygonBox[{{197., 0.17254603006834685`}, {197., 0.2588190451025203}, {
      197., 0.49999999999999933`}, {197., 0.33333333333333287`}, {197., 
      0.17254603006834685`}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666644`}, {197., 
      0.2357022603955156}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666644`}, {197., 0.33333333333333287`}, {
      197., 0.4714045207910312}, {197., 0.2357022603955156}, {197., 
      0.16666666666666644`}}], 
     PolygonBox[{{197., 0.33333333333333287`}, {197., 0.49999999999999933`}, {
      197., 0.7071067811865468}, {197., 0.4714045207910312}, {197., 
      0.33333333333333287`}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551578`}, {197., 
      0.28867513459481275`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551578`}, {197., 0.47140452079103157`}, {
      197., 0.5773502691896255}, {197., 0.28867513459481275`}, {197., 
      0.23570226039551578`}}], 
     PolygonBox[{{197., 0.47140452079103157`}, {197., 0.7071067811865474}, {
      197., 0.8660254037844384}, {197., 0.5773502691896255}, {197., 
      0.47140452079103157`}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481275`}, {197., 
      0.32197527542968934`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481275`}, {197., 0.5773502691896255}, {
      197., 0.6439505508593787}, {197., 0.32197527542968934`}, {197., 
      0.28867513459481275`}}], 
     PolygonBox[{{197., 0.5773502691896255}, {197., 0.8660254037844384}, {
      197., 0.9659258262890681}, {197., 0.6439505508593787}, {197., 
      0.5773502691896255}}], 
     PolygonBox[{{197., 0.}, {197., 0.32197527542968934`}, {197., 
      0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.32197527542968934`}, {197., 0.6439505508593787}, {
      197., 0.6666666666666666}, {197., 0.3333333333333333}, {197., 
      0.32197527542968934`}}], 
     PolygonBox[{{197., 0.6439505508593787}, {197., 0.9659258262890681}, {
      197., 1.}, {197., 0.6666666666666666}, {197., 0.6439505508593787}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYLMhwgjA/2ML7ofg/3uy/ewfmrfSJeVG17Deef
ta5Pm7fgGZzPCGY8gPOnsE0+WDvhApzPHiNirLZsog2M3weR3w/j//kPAvfh
/DMQ8+H8lRD74XwRiPvgfKj74XwxNPk1aPovoJnPAnE/nD8PzX1cXfN8LCtX
7YHxO9D89wXifjj/NFr4rEALP2G08IWFPwABtIYM
       "]]}}, 
    {RGBColor[0.9313748722829585, 1., 0.5], AbsoluteThickness[0.5], 
     Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.80009348181466, -7.943978826752928}}]}, 
    {RGBColor[0.9313748722829585, 0.9761297695001183, 0.6536889725715616], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}, 
    {RGBColor[0.9313748722829585, 0.9067166552473702, 0.7926119711825902], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.77288879312717, -6.4333356875055925`}}]}, 
    {RGBColor[0.9313748722829585, 0.7982513915126817, 0.9032205977664665], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
    {RGBColor[0.9313748722829585, 0.6611315602838433, 0.9744672227857459], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434345`}}]}, 
    {RGBColor[0.9313748722829585, 0.508826462377227, 0.999066649721965], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.65721119927778, -5.655198531684391*^-16}}]}, 
    {RGBColor[0.9313748722829585, 0.35652136447061056`, 0.9744672227857459], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958244`}}]}, 
    {RGBColor[0.9313748722829585, 0.21940153324177236`, 0.9032205977664665], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959733}}]}, 
    {RGBColor[0.9313748722829585, 0.11093626950708368`, 0.7926119711825902], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.54211377326678, 6.41697999814953}}]}, 
    {RGBColor[0.9313748722829585, 0.0415231552543357, 0.6536889725715617], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
    {RGBColor[0.9313748722829585, 0.017652924754453903`, 0.5000000000000001], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.5152130159867, 7.9190550155329955`}}]}, 
    {RGBColor[0.9313748722829585, 0.0415231552543357, 0.34631102742843856`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
    {RGBColor[0.9313748722829585, 0.11093626950708357`, 0.20738802881741003`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.54211377326678, 6.4169799981495315`}}]}, 
    {RGBColor[0.9313748722829585, 0.21940153324177214`, 0.09677940223353365], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959736}}]}, 
    {RGBColor[
     0.9313748722829585, 0.35652136447061045`, 0.025532777214254176`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958266`}}]}, 
    {RGBColor[0.9313748722829585, 0.5088264623772268, 0.0009333502780349834], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.65721119927778, 1.654926196081874*^-15}}]}, 
    {RGBColor[0.9313748722829585, 0.6611315602838432, 0.025532777214254176`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434336`}}]}, 
    {RGBColor[0.9313748722829585, 0.7982513915126814, 0.09677940223353354], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
    {RGBColor[0.9313748722829585, 0.9067166552473701, 0.2073880288174098], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.77288879312717, -6.433335687505591}}]}, 
    {RGBColor[0.9313748722829585, 0.9761297695001183, 0.34631102742843844`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}, 
    {RGBColor[0.0005245323116921385, 0.4725798896212702, 0.5], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.80009348181466, -7.943978826752928}, {
      109.44332883697214`, -7.824068037519229}}]}, 
    {RGBColor[
     0.0004801655943936778, 0.47274229038805826`, 0.49945392330620286`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.79312901185494, -7.557334749403953}, {
      109.43847763990019`, -7.437947703984694}}]}, 
    {RGBColor[
     0.0003621789876110393, 0.47317429855893556`, 0.49908586692785517`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.77288879312717, -6.4333356875055925`}, {
      109.42437067823238`, -6.315339227036188}}]}, 
    {RGBColor[
     0.00021056578473932497`, 0.47372969644575236`, 0.499010177223876], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.74129707055698, -4.677973313963376}, {
      109.4023271061959, -4.561755637786824}}]}, 
    {RGBColor[
     0.00007576878498216644, 0.47422364888379276`, 0.4992356897293324], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.7014215775235, -2.4606245660434345`}, {
      109.37446007821904`, -2.345968868015016}}]}, 
    {RGBColor[0., 0.47450092042824277`, 0.49966247696678057`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.65721119927778, -5.655198531684391*^-16}, {
      109.34350700631593`, 0.1138176793967933}}]}, 
    {RGBColor[
     1.5026000264040107`*^-6, 0.47449386840965446`, 0.5001211481922994], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.61308582705088, 2.4582281193958244`}, {109.31255401389252`,
       2.5721494318492497`}}]}, 
    {RGBColor[
     0.00006847526796716075, 0.47424540794935177`, 0.5004401551149642], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.5734322977125, 4.669319404959733}, {109.28468719339604`, 
      4.7841375091179374`}}]}, 
    {RGBColor[
     0.00016520943913522768`, 0.47388702530778126`, 0.5005124920540295], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.54211377326678, 6.41697999814953}, {109.26264387662552`, 
      6.5330455770536915`}}]}, 
    {RGBColor[
     0.0002472928586663148, 0.47358289913122686`, 0.5003339568378333], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.5220936404668, 7.534774616794779}, {109.24853712051282`, 
      7.651887495337791}}]}, 
    {RGBColor[0.00027914707652243465`, 0.4734648567434733, 0.5], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.5152130159867, 7.9190550155329955`}, {109.24368600173067`, 
      8.036572893976766}}]}, 
    {RGBColor[
     0.0002472928586663148, 0.47358289913122686`, 0.4996660431621667], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.5220936404668, 7.534774616794779}, {109.24853712051282`, 
      7.651887495337791}}]}, 
    {RGBColor[
     0.00016520943913522768`, 0.47388702530778126`, 0.49948750794597063`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.54211377326678, 6.4169799981495315`}, {109.26264387662552`,
       6.533045577053693}}]}, 
    {RGBColor[0.00006847526796716075, 0.4742454079493519, 0.4995598448850359],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.5734322977125, 4.669319404959736}, {109.28468719339604`, 
      4.78413750911794}}]}, 
    {RGBColor[
     1.5026000264040107`*^-6, 0.47449386840965446`, 0.49987885180770075`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.61308582705088, 2.4582281193958266`}, {109.31255401389252`,
       2.572149431849252}}]}, 
    {RGBColor[0., 0.474500920428243, 0.5003375230332194], AbsoluteThickness[
     0.5], Arrowheads[Small], 
     ArrowBox[{{90.65721119927778, 1.654926196081874*^-15}, {
      109.34350700631593`, 0.11381767939679524`}}]}, 
    {RGBColor[
     0.00007576878498216644, 0.47422364888379276`, 0.5007643102706677], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.7014215775235, -2.4606245660434336`}, {
      109.37446007821904`, -2.345968868015015}}]}, 
    {RGBColor[
     0.00021056578473932497`, 0.47372969644575236`, 0.5009898227761241], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.74129707055698, -4.677973313963376}, {
      109.4023271061959, -4.561755637786824}}]}, 
    {RGBColor[
     0.0003621789876110393, 0.47317429855893556`, 0.5009141330721449], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.77288879312717, -6.433335687505591}, {
      109.42437067823238`, -6.315339227036186}}]}, 
    {RGBColor[
     0.0004801655943936778, 0.47274229038805826`, 0.5005460766937972], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{90.79312901185494, -7.557334749403953}, {
      109.43847763990019`, -7.437947703984694}}]}, 
    {RGBColor[1., 0., 0.5], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.44332883697214`, -7.824068037519229}, {197., 
      0.11368177879512942`}}]}, 
    {RGBColor[0.9968236625790436, 0.02410973194317656, 0.34544679089729835`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
      0.12400849836319239`}}]}, 
    {RGBColor[0.9876174720197024, 0.09416650864715714, 0.20590679811050727`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.42437067823238`, -6.315339227036188}, {197., 
      0.1544760906390117}}]}, 
    {RGBColor[0.9733221409547523, 0.20348078412086235`, 0.09509080170709228], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
      0.20338283108796773`}}]}, 
    {RGBColor[0.9554071372168748, 0.3414017123802341, 0.02406809668191834], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.37446007821904`, -2.345968868015016}, {197., 
      0.26745459900226276`}}]}, 
    {RGBColor[
     0.9357123423155576, 0.49424264687148534`, 1.1102230246251565`*^-16], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.34350700631593`, 0.1138176793967933}, {197., 
      0.34152645204915943`}}]}, 
    {RGBColor[0.9162310877912273, 0.6467137615484235, 0.02521984607149652], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.31255401389252`, 2.5721494318492497`}, {197., 
      0.4186157623140434}}]}, 
    {RGBColor[0.8988736774385201, 0.7836690283289621, 0.09695083458804932], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.28468719339604`, 4.7841375091179374`}, {197., 
      0.4905667114836554}}]}, 
    {RGBColor[0.8852646590055362, 0.8917947341256187, 0.20776247780251944`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.26264387662552`, 6.5330455770536915`}, {197., 
      0.5491716105006761}}]}, 
    {RGBColor[0.8766113665916477, 0.9608940011696515, 0.34659149662260547`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
      0.5874521738586784}}]}, 
    {RGBColor[0.8736456676923613, 0.9846389514651591, 0.5], AbsoluteThickness[
     0.5], Arrowheads[Small], 
     ArrowBox[{{109.24368600173067`, 8.036572893976766}, {197., 
      0.6007554299801923}}]}, 
    {RGBColor[0.8766113665916477, 0.9608940011696515, 0.6534085033773944], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
      0.5874521738586784}}]}, 
    {RGBColor[0.8852646590055362, 0.8917947341256189, 0.7922375221974806], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.26264387662552`, 6.533045577053693}, {197., 
      0.5491716105006752}}]}, 
    {RGBColor[0.8988736774385201, 0.7836690283289623, 0.9030491654119508], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.28468719339604`, 4.78413750911794}, {197., 
      0.4905667114836545}}]}, 
    {RGBColor[0.9162310877912273, 0.6467137615484237, 0.9747801539285035], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.31255401389252`, 2.572149431849252}, {197., 
      0.41861576231404296`}}]}, 
    {RGBColor[0.9357123423155576, 0.49424264687148556`, 1.], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.34350700631593`, 0.11381767939679524`}, {197., 
      0.34152645204915744`}}]}, 
    {RGBColor[0.9554071372168748, 0.3414017123802341, 0.9759319033180817], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.37446007821904`, -2.345968868015015}, {197., 
      0.26745459900226365`}}]}, 
    {RGBColor[0.9733221409547523, 0.20348078412086223`, 0.9049091982929078], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
      0.2033828310879695}}]}, 
    {RGBColor[0.9876174720197024, 0.09416650864715714, 0.7940932018894928], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.42437067823238`, -6.315339227036186}, {197., 
      0.1544760906390117}}]}, 
    {RGBColor[0.9968236625790436, 0.02410973194317656, 0.6545532091027018], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
      0.12400849836319239`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQfaDDa7fJ5jCHwyJbkhYdkz/gcFt/waFNYQ4ipc++
brWSO+Ba3cdUvjHM4bLUjsg9uyUP5KxyySxcH+Zgp/Rmkd02oQOs3CHiT9YA
+Qrb30WvZz6w6G7/fv5VYQ4MIJBwZM9xk7AzNsvDHKR9xRuLVzE7+Homym5e
EuYQ0/paIGmtkIPYzu9/Ny4Kc9jY++fsn1WSDl4XCn9nLgxzcCpl/zpbWc5h
dwezw88FYQ5tB7kPyayVx5CH6d8M1Q8zPx5qPsx+Baj9KO67cNcG5n4bqPvR
/Qfz/0Wo/9HD5xLXq/r4mGiHI963a294yx9outnCIgDkP3n8PKb0gOyBNxKL
HmtERzvsFfD1fOEkeeD7TYNd+yOjHSJ6N92zsRc68CEtXf17eLSDaEVOcPcR
pgM7W86z/AmNdvBz3H5KXXmv/c6fPY8YQqIdSvdeFDk8mcWh3G9RgEVQtMPb
lyUfvygJO1SrOWucD4h2yHiitPmaopRDiYwtxwv/aIdN01xSO2bLObj/1u6d
AeTvl1y/bqeQAoY8TH8WVD/M/A9Q82H2V0Hth7nvFtR9MPcLQ92P7j+Y/3dD
/Y8ePuB4WJDhwNAofMheaq89nB//NIZ1/344v6Fmedz9o4cR/DncN4o4TsH5
Hzx/PPkpexHO7/CYeHji7atw/o5lekdmnroF5zuwT31dmHofzn+xLz78wqSH
cP6PP6ENGWcewfkRklOLky0f45R/gKbfAM38DWj2p6C5j8EL1f0H0PyH7n9Y
+AAA7yWRXA==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {100.50912757553334`, -29.080630589559114`}, \
{0., 0.}], InsetBox["\<\"B\"\>", {197., -5.259611034414593}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731739591175*^9},
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"During evaluation of In[32]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[ill,ColorView->RayTilt];", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"In[33]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{97.42621376635236, -24.874183157635187`, 0.}, {
      103.44336045863966`, -24.769153471438706`, 6.123233995736766*^-15}, {
      107.31480480692527`, -16.366974425274172`, 5.102694996447306*^-15}, {
      93.26389597744534, -16.612233951193208`, 0.}, {
      97.42621376635236, -24.874183157635187`, 0.}}], 
     Polygon3DBox[{{93.26389597744534, -16.612233951193208`, 0.}, {
      107.31480480692527`, -16.366974425274172`, 5.102694996447306*^-15}, {
      109.41659696886857`, -7.9956847729226, 4.0821559971578446`*^-15}, {
      90.87123037488065, -8.319395350938256, 0.}, {
      93.26389597744534, -16.612233951193208`, 0.}}], 
     Polygon3DBox[{{90.87123037488065, -8.319395350938256, 0.}, {
      109.41659696886857`, -7.9956847729226, 4.0821559971578446`*^-15}, {
      109.99695390312783`, 0.34904812874566316`, 3.061616997868384*^-15}, {
      90., 0., 0.}, {90.87123037488065, -8.319395350938256, 0.}}], 
     Polygon3DBox[{{90., 0., 0.}, {109.99695390312783`, 0.34904812874567026`, 
      3.061616997868383*^-15}, {109.12572352824718`, 8.668443479683923, 
      2.0410779985789223`*^-15}, {90.58035693425926, 8.344732901668264, 0.}, {
      90., 0., 0.}}], 
     Polygon3DBox[{{90.58035693425926, 8.344732901668264, 0.}, {
      109.12572352824718`, 8.668443479683923, 2.0410779985789223`*^-15}, {
      106.73305792568249`, 16.961282079938876`, 1.0205389992894613`*^-15}, {
      92.68214909620255, 16.716022554019837`, 0.}, {90.58035693425926, 
      8.344732901668264, 0.}}], 
     Polygon3DBox[{{92.68214909620255, 16.716022554019837`, 0.}, {
      106.73305792568249`, 16.961282079938876`, 1.0205389992894615`*^-15}, {
      102.5707401367755, 25.223231286380855`, 5.098616525425841*^-31}, {
      96.55359344448816, 25.11820160018437, 0.}, {92.68214909620255, 
      16.716022554019837`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7xVErMPTrC4crBFeWn7lscYIACOe0vqx8HhDvo
PrCN3T3HAC5ufZPb9tD2MIfsnqkn2xcrwMXBoCHMAcL4sAcmNF8zc6LK0jCH
fK6tVxo2KDjAxJ+dXheyQjvcYc02Hkff7QZw8cvXjITzlCMcihSOlzrJWcLF
j9cuZmxfEumgVty0XtUSIR5gcSr71booh/qJ4lPFviHMMe7adIvbI9qB772H
pV2YIlw8L3mf+Ln6aIdlITnfzoZds4eJn7cMbVsZFe0w3Z/51JTf8nB/dUzn
P6x6JcohitWY81MsIhxm9XSzJNyJdFDIf2v7/Agi3HCFJwCps2lZ
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{96.98990360542027, 0.1220092212745929, -25.}, {
        103.00705029770756`, 0.2270389074710804, -25.}, {107.02393136630388`, 
        0.2971538273323565, -16.66666666666667}, {92.97302253682395, 
        0.05189430141331686, -16.666666666666668`}, {96.98990360542027, 
        0.1220092212745929, -25.}}], 
       Polygon3DBox[{{92.97302253682395, 
        0.05189430141331686, -16.666666666666668`}, {107.02393136630388`, 
        0.2971538273323565, -16.66666666666667}, {109.27116024855788`, 
        0.3363793533806653, -8.333333333333336}, {90.72579365456996, 
        0.01266877536500799, -8.333333333333336}, {92.97302253682395, 
        0.05189430141331686, -16.666666666666668`}}], 
       Polygon3DBox[{{90.72579365456996, 
        0.01266877536500799, -8.333333333333336}, {109.27116024855788`, 
        0.3363793533806653, -8.333333333333336}, {109.99695390312783`, 
        0.3490481287456718, -7.105427357601002*^-15}, {90., 
        1.5543122344752192`*^-15, 0.}, {90.72579365456996, 
        0.01266877536500799, -8.333333333333336}}], 
       Polygon3DBox[{{90., 1.5543122344752192`*^-15, 0.}, {
        109.99695390312783`, 0.3490481287456718, 0.}, {109.27116024855788`, 
        0.33637935338066427`, 8.333333333333332}, {90.72579365456996, 
        0.012668775365008988`, 8.333333333333329}, {90., 
        1.5543122344752192`*^-15, 0.}}], 
       Polygon3DBox[{{90.72579365456996, 0.012668775365008988`, 
        8.333333333333329}, {109.27116024855788`, 0.33637935338066427`, 
        8.333333333333332}, {107.02393136630388`, 0.29715382733235446`, 
        16.666666666666664`}, {92.97302253682395, 0.051894301413318855`, 
        16.666666666666664`}, {90.72579365456996, 0.012668775365008988`, 
        8.333333333333329}}], 
       Polygon3DBox[{{92.97302253682395, 0.051894301413318855`, 
        16.666666666666664`}, {107.02393136630388`, 0.29715382733235446`, 
        16.666666666666664`}, {103.00705029770758`, 0.22703890747107747`, 
        24.999999999999996`}, {96.98990360542025, 0.1220092212745959, 
        24.999999999999993`}, {92.97302253682395, 0.051894301413318855`, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILa7t2xKlH2EQ4C/Pv9/6/32DGBgeaCpOpDBzS7c
4UPjtXOPJ66yX70KBAwO5DZapRevC3Ng4P9jJ/ap034NWFzhAFhbA1AcBXzY
g65+BUS9A8z8B1DzIeIGDrZQ93hA3fPvPwhYOBi0ijcXH4h0UGF0TJ3Dfxbm
Toc3z3PEOw5GOWi0TKyZyHIZ5k4HxkfNG6ICox3eFZe42LZfhbnTIS95n/i5
+miHtJCcb2fDrkHN+WCDrh7qzgMw87Wg5kPdecAQ6h4NqHug7jyAKzwBmGib
tQ==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{96.55359344448817, 25.118201600184378`, 0.}, {
       102.57074013677548`, 25.22323128638086, 0.}, {102.58560704499094`, 
       24.371506685150017`, 6.4704761275630185`}, {96.56846035270361, 
       24.266476998953536`, 6.4704761275630185`}, {96.55359344448817, 
       25.118201600184378`, 0.}}], 
      Line3DBox[{{96.56846035270361, 24.266476998953536`, 
       6.4704761275630185`}, {102.58560704499094`, 24.371506685150017`, 
       6.4704761275630185`}, {102.6291946144111, 21.87437650548993, 
       12.499999999999998`}, {96.61204792212379, 21.76934681929345, 
       12.499999999999998`}, {96.56846035270361, 24.266476998953536`, 
       6.4704761275630185`}}], 
      Line3DBox[{{96.61204792212379, 21.76934681929345, 
       12.499999999999998`}, {102.6291946144111, 21.87437650548993, 
       12.499999999999998`}, {102.69853242421189`, 17.902016042441684`, 
       17.677669529663685`}, {96.68138573192459, 17.796986356245203`, 
       17.677669529663685`}, {96.61204792212379, 21.76934681929345, 
       12.499999999999998`}}], 
      Line3DBox[{{96.68138573192459, 17.796986356245203`, 
       17.677669529663685`}, {102.69853242421189`, 17.902016042441684`, 
       17.677669529663685`}, {102.78889521724153`, 12.725135096925971`, 
       21.650635094610966`}, {96.77174852495423, 12.620105410729488`, 
       21.650635094610966`}, {96.68138573192459, 17.796986356245203`, 
       17.677669529663685`}}], 
      Line3DBox[{{96.77174852495423, 12.620105410729488`, 
       21.650635094610966`}, {102.78889521724153`, 12.725135096925971`, 
       21.650635094610966`}, {102.8941249184866, 6.696529550179418, 
       24.148145657226706`}, {96.8769782261993, 6.591499863982934, 
       24.148145657226706`}, {96.77174852495423, 12.620105410729488`, 
       21.650635094610966`}}], 
      Line3DBox[{{96.8769782261993, 6.591499863982934, 24.148145657226706`}, {
       102.8941249184866, 6.696529550179418, 24.148145657226706`}, {
       103.00705029770756`, 0.22703890747108446`, 25.}, {96.98990360542027, 
       0.12200922127460001`, 25.}, {96.8769782261993, 6.591499863982934, 
       24.148145657226706`}}], 
      Line3DBox[{{96.98990360542027, 0.12200922127459446`, 25.}, {
       103.00705029770756`, 0.2270389074710789, 25.}, {
       103.11997567692853`, -6.242451735237256, 24.148145657226706`}, {
       97.10282898464123, -6.3474814214337405`, 24.148145657226706`}, {
       96.98990360542027, 0.12200922127459446`, 25.}}], 
      Line3DBox[{{97.10282898464123, -6.3474814214337405`, 
       24.148145657226706`}, {103.11997567692853`, -6.242451735237256, 
       24.148145657226706`}, {103.22520537817361`, -12.27105728198381, 
       21.65063509461097}, {97.2080586858863, -12.376086968180292`, 
       21.65063509461097}, {97.10282898464123, -6.3474814214337405`, 
       24.148145657226706`}}], 
      Line3DBox[{{97.2080586858863, -12.376086968180292`, 
       21.65063509461097}, {103.22520537817361`, -12.27105728198381, 
       21.65063509461097}, {103.31556817120324`, -17.447938227499527`, 
       17.67766952966369}, {97.29842147891594, -17.55296791369601, 
       17.67766952966369}, {97.2080586858863, -12.376086968180292`, 
       21.65063509461097}}], 
      Line3DBox[{{97.29842147891594, -17.55296791369601, 17.67766952966369}, {
       103.31556817120324`, -17.447938227499527`, 17.67766952966369}, {
       103.38490598100404`, -21.420298690547778`, 12.499999999999998`}, {
       97.36775928871674, -21.52532837674426, 12.499999999999998`}, {
       97.29842147891594, -17.55296791369601, 17.67766952966369}}], 
      Line3DBox[{{97.36775928871674, -21.525328376744252`, 
       12.500000000000009`}, {103.38490598100404`, -21.42029869054777, 
       12.500000000000009`}, {103.42849355042421`, -23.917428870207864`, 
       6.470476127563026}, {97.41134685813691, -24.022458556404345`, 
       6.470476127563026}, {97.36775928871674, -21.525328376744252`, 
       12.500000000000009`}}], 
      Line3DBox[{{97.41134685813691, -24.022458556404345`, 
       6.470476127563026}, {103.42849355042421`, -23.917428870207864`, 
       6.470476127563026}, {103.44336045863966`, -24.769153471438706`, 
       3.061616997868383*^-15}, {97.42621376635236, -24.874183157635187`, 
       3.061616997868383*^-15}, {97.41134685813691, -24.022458556404345`, 
       6.470476127563026}}], 
      Line3DBox[{{97.42621376635236, -24.874183157635187`, 
       3.061616997868383*^-15}, {103.44336045863966`, -24.769153471438706`, 
       3.061616997868383*^-15}, {
       103.42849355042422`, -23.917428870207864`, -6.47047612756302}, {
       97.4113468581369, -24.022458556404345`, -6.47047612756302}, {
       97.42621376635236, -24.874183157635187`, 3.061616997868383*^-15}}], 
      Line3DBox[{{
       97.41134685813691, -24.02245855640435, -6.470476127563009}, {
       103.42849355042421`, -23.917428870207868`, -6.470476127563009}, {
       103.38490598100404`, -21.420298690547778`, -12.499999999999993`}, {
       97.36775928871673, -21.52532837674426, -12.499999999999993`}, {
       97.41134685813691, -24.02245855640435, -6.470476127563009}}], 
      Line3DBox[{{
       97.36775928871673, -21.52532837674426, -12.499999999999993`}, {
       103.38490598100404`, -21.420298690547778`, -12.499999999999993`}, {
       103.31556817120324`, -17.447938227499534`, -17.677669529663685`}, {
       97.29842147891594, -17.552967913696016`, -17.677669529663685`}, {
       97.36775928871673, -21.52532837674426, -12.499999999999993`}}], 
      Line3DBox[{{
       97.29842147891594, -17.55296791369602, -17.677669529663678`}, {
       103.31556817120324`, -17.447938227499538`, -17.677669529663678`}, {
       103.22520537817363`, -12.271057281983826`, -21.65063509461096}, {
       97.2080586858863, -12.376086968180308`, -21.65063509461096}, {
       97.29842147891594, -17.55296791369602, -17.677669529663678`}}], 
      Line3DBox[{{
       97.2080586858863, -12.376086968180308`, -21.65063509461096}, {
       103.22520537817363`, -12.271057281983826`, -21.65063509461096}, {
       103.11997567692853`, -6.242451735237278, -24.148145657226703`}, {
       97.10282898464123, -6.347481421433763, -24.148145657226703`}, {
       97.2080586858863, -12.376086968180308`, -21.65063509461096}}], 
      Line3DBox[{{
       97.10282898464123, -6.347481421433763, -24.148145657226703`}, {
       103.11997567692853`, -6.242451735237278, -24.148145657226703`}, {
       103.00705029770756`, 0.22703890747105054`, -25.}, {96.98990360542027, 
       0.12200922127456615`, -25.}, {
       97.10282898464123, -6.347481421433763, -24.148145657226703`}}], 
      Line3DBox[{{96.98990360542027, 0.12200922127458835`, -25.}, {
       103.00705029770756`, 0.22703890747107275`, -25.}, {102.8941249184866, 
       6.6965295501794015`, -24.14814565722671}, {96.8769782261993, 
       6.591499863982917, -24.14814565722671}, {96.98990360542027, 
       0.12200922127458835`, -25.}}], 
      Line3DBox[{{96.8769782261993, 6.591499863982917, -24.14814565722671}, {
       102.8941249184866, 6.6965295501794015`, -24.14814565722671}, {
       102.78889521724153`, 12.725135096925952`, -21.650635094610976`}, {
       96.77174852495423, 12.620105410729469`, -21.650635094610976`}, {
       96.8769782261993, 6.591499863982917, -24.14814565722671}}], 
      Line3DBox[{{96.77174852495423, 
       12.620105410729469`, -21.650635094610976`}, {102.78889521724153`, 
       12.725135096925952`, -21.650635094610976`}, {102.69853242421189`, 
       17.902016042441666`, -17.67766952966371}, {96.68138573192459, 
       17.796986356245185`, -17.67766952966371}, {96.77174852495423, 
       12.620105410729469`, -21.650635094610976`}}], 
      Line3DBox[{{96.68138573192459, 
       17.7969863562452, -17.677669529663692`}, {102.69853242421189`, 
       17.90201604244168, -17.677669529663692`}, {102.62919461441112`, 
       21.87437650548992, -12.50000000000001}, {96.61204792212378, 
       21.76934681929344, -12.50000000000001}, {96.68138573192459, 
       17.7969863562452, -17.677669529663692`}}], 
      Line3DBox[{{96.61204792212378, 21.76934681929344, -12.50000000000001}, {
       102.62919461441112`, 21.87437650548992, -12.50000000000001}, {
       102.58560704499092`, 24.371506685150013`, -6.470476127563039}, {
       96.56846035270362, 24.266476998953532`, -6.470476127563039}, {
       96.61204792212378, 21.76934681929344, -12.50000000000001}}], 
      Line3DBox[{{96.56846035270362, 
       24.266476998953532`, -6.470476127563039}, {102.58560704499092`, 
       24.371506685150013`, -6.470476127563039}, {102.57074013677548`, 
       25.22323128638086, -2.8327694488239898`*^-14}, {96.55359344448817, 
       25.118201600184378`, -2.8327694488239898`*^-14}, {96.56846035270362, 
       24.266476998953532`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.3333333333333333, 0.}, {197., 
      0.3219752754296894, 0.08627301503417358}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{197., 0.3333333333333333, 0.}, {197., 
      0.6666666666666666, 0.}, {197., 0.6439505508593788, 
      0.17254603006834715`}, {197., 0.3219752754296894, 
      0.08627301503417358}, {197., 0.3333333333333333, 0.}}], 
     Polygon3DBox[{{197., 0.6666666666666666, 0.}, {197., 1., 0.}, {197., 
      0.9659258262890683, 0.25881904510252074`}, {197., 0.6439505508593788, 
      0.17254603006834715`}, {197., 0.6666666666666666, 0.}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.3219752754296894, 
      0.08627301503417358}, {197., 0.28867513459481287`, 
      0.16666666666666663`}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 0.3219752754296894, 0.08627301503417358}, {197., 
      0.6439505508593788, 0.17254603006834715`}, {197., 0.5773502691896257, 
      0.33333333333333326`}, {197., 0.28867513459481287`, 
      0.16666666666666663`}, {197., 0.3219752754296894, 
      0.08627301503417358}}], 
     Polygon3DBox[{{197., 0.6439505508593788, 0.17254603006834715`}, {197., 
      0.9659258262890683, 0.25881904510252074`}, {197., 0.8660254037844387, 
      0.49999999999999994`}, {197., 0.5773502691896257, 
      0.33333333333333326`}, {197., 0.6439505508593788, 
      0.17254603006834715`}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.28867513459481287`, 
      0.16666666666666663`}, {197., 0.23570226039551584`, 
      0.2357022603955158}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 0.28867513459481287`, 0.16666666666666663`}, {197., 
      0.5773502691896257, 0.33333333333333326`}, {197., 0.4714045207910317, 
      0.4714045207910316}, {197., 0.23570226039551584`, 0.2357022603955158}, {
      197., 0.28867513459481287`, 0.16666666666666663`}}], 
     Polygon3DBox[{{197., 0.5773502691896257, 0.33333333333333326`}, {197., 
      0.8660254037844387, 0.49999999999999994`}, {197., 0.7071067811865476, 
      0.7071067811865475}, {197., 0.4714045207910317, 0.4714045207910316}, {
      197., 0.5773502691896257, 0.33333333333333326`}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.23570226039551584`, 
      0.2357022603955158}, {197., 0.16666666666666669`, 
      0.28867513459481287`}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 0.23570226039551584`, 0.2357022603955158}, {197., 
      0.4714045207910317, 0.4714045207910316}, {197., 0.33333333333333337`, 
      0.5773502691896257}, {197., 0.16666666666666669`, 
      0.28867513459481287`}, {197., 0.23570226039551584`, 
      0.2357022603955158}}], 
     Polygon3DBox[{{197., 0.4714045207910317, 0.4714045207910316}, {197., 
      0.7071067811865476, 0.7071067811865475}, {197., 0.5000000000000001, 
      0.8660254037844386}, {197., 0.33333333333333337`, 0.5773502691896257}, {
      197., 0.4714045207910317, 0.4714045207910316}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.16666666666666669`, 
      0.28867513459481287`}, {197., 0.08627301503417364, 
      0.3219752754296894}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 0.16666666666666669`, 0.28867513459481287`}, {197., 
      0.33333333333333337`, 0.5773502691896257}, {197., 0.1725460300683473, 
      0.6439505508593788}, {197., 0.08627301503417364, 0.3219752754296894}, {
      197., 0.16666666666666669`, 0.28867513459481287`}}], 
     Polygon3DBox[{{197., 0.33333333333333337`, 0.5773502691896257}, {197., 
      0.5000000000000001, 0.8660254037844386}, {197., 0.25881904510252096`, 
      0.9659258262890682}, {197., 0.1725460300683473, 0.6439505508593788}, {
      197., 0.33333333333333337`, 0.5773502691896257}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 0.08627301503417364, 
      0.3219752754296894}, {197., 9.442564829413299*^-17, 
      0.3333333333333333}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 0.08627301503417364, 0.3219752754296894}, {197., 
      0.1725460300683473, 0.6439505508593788}, {197., 
      1.8885129658826599`*^-16, 0.6666666666666666}, {197., 
      9.442564829413299*^-17, 0.3333333333333333}, {197., 0.08627301503417364,
       0.3219752754296894}}], 
     Polygon3DBox[{{197., 0.1725460300683473, 0.6439505508593788}, {197., 
      0.25881904510252096`, 0.9659258262890682}, {197., 2.83276944882399*^-16,
       1.}, {197., 1.8885129658826599`*^-16, 0.6666666666666666}, {197., 
      0.1725460300683473, 0.6439505508593788}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 2.041077998578922*^-17, 
      0.3333333333333333}, {197., -0.08627301503417353, 0.3219752754296894}, {
      197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., 2.041077998578922*^-17, 0.3333333333333333}, {197., 
      4.082155997157844*^-17, 0.6666666666666666}, {
      197., -0.17254603006834707`, 0.6439505508593788}, {
      197., -0.08627301503417353, 0.3219752754296894}, {197., 
      2.041077998578922*^-17, 0.3333333333333333}}], 
     Polygon3DBox[{{197., 4.082155997157844*^-17, 0.6666666666666666}, {197., 
      6.123233995736766*^-17, 1.}, {197., -0.25881904510252063`, 
      0.9659258262890683}, {197., -0.17254603006834707`, 
      0.6439505508593788}, {197., 4.082155997157844*^-17, 
      0.6666666666666666}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.08627301503417353, 
      0.3219752754296894}, {197., -0.16666666666666657`, 
      0.28867513459481287`}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.08627301503417353, 0.3219752754296894}, {
      197., -0.17254603006834707`, 0.6439505508593788}, {
      197., -0.33333333333333315`, 0.5773502691896257}, {
      197., -0.16666666666666657`, 0.28867513459481287`}, {
      197., -0.08627301503417353, 0.3219752754296894}}], 
     Polygon3DBox[{{197., -0.17254603006834707`, 0.6439505508593788}, {
      197., -0.25881904510252063`, 0.9659258262890683}, {
      197., -0.4999999999999998, 0.8660254037844387}, {
      197., -0.33333333333333315`, 0.5773502691896257}, {
      197., -0.17254603006834707`, 0.6439505508593788}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.16666666666666657`, 
      0.28867513459481287`}, {197., -0.2357022603955158, 
      0.23570226039551584`}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.16666666666666657`, 0.28867513459481287`}, {
      197., -0.33333333333333315`, 0.5773502691896257}, {
      197., -0.4714045207910316, 0.4714045207910317}, {
      197., -0.2357022603955158, 0.23570226039551584`}, {
      197., -0.16666666666666657`, 0.28867513459481287`}}], 
     Polygon3DBox[{{197., -0.33333333333333315`, 0.5773502691896257}, {
      197., -0.4999999999999998, 0.8660254037844387}, {
      197., -0.7071067811865475, 0.7071067811865476}, {
      197., -0.4714045207910316, 0.4714045207910317}, {
      197., -0.33333333333333315`, 0.5773502691896257}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.2357022603955158, 
      0.23570226039551584`}, {197., -0.28867513459481287`, 
      0.16666666666666663`}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.2357022603955158, 0.23570226039551584`}, {
      197., -0.4714045207910316, 0.4714045207910317}, {
      197., -0.5773502691896257, 0.33333333333333326`}, {
      197., -0.28867513459481287`, 0.16666666666666663`}, {
      197., -0.2357022603955158, 0.23570226039551584`}}], 
     Polygon3DBox[{{197., -0.4714045207910316, 0.4714045207910317}, {
      197., -0.7071067811865475, 0.7071067811865476}, {
      197., -0.8660254037844387, 0.49999999999999994`}, {
      197., -0.5773502691896257, 0.33333333333333326`}, {
      197., -0.4714045207910316, 0.4714045207910317}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.2886751345948128, 
      0.16666666666666677`}, {197., -0.3219752754296894, 
      0.08627301503417367}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.2886751345948128, 0.16666666666666677`}, {
      197., -0.5773502691896256, 0.33333333333333354`}, {
      197., -0.6439505508593788, 0.17254603006834734`}, {
      197., -0.3219752754296894, 0.08627301503417367}, {
      197., -0.2886751345948128, 0.16666666666666677`}}], 
     Polygon3DBox[{{197., -0.5773502691896256, 0.33333333333333354`}, {
      197., -0.8660254037844385, 0.5000000000000003}, {
      197., -0.9659258262890682, 0.258819045102521}, {
      197., -0.6439505508593788, 0.17254603006834734`}, {
      197., -0.5773502691896256, 0.33333333333333354`}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.3219752754296894, 
      0.08627301503417367}, {197., -0.3333333333333333, 
      4.082155997157844*^-17}, {197., 0., 0.}, {197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.3219752754296894, 0.08627301503417367}, {
      197., -0.6439505508593788, 0.17254603006834734`}, {
      197., -0.6666666666666666, 8.164311994315688*^-17}, {
      197., -0.3333333333333333, 4.082155997157844*^-17}, {
      197., -0.3219752754296894, 0.08627301503417367}}], 
     Polygon3DBox[{{197., -0.6439505508593788, 0.17254603006834734`}, {
      197., -0.9659258262890682, 0.258819045102521}, {197., -1., 
      1.2246467991473532`*^-16}, {197., -0.6666666666666666, 
      8.164311994315688*^-17}, {197., -0.6439505508593788, 
      0.17254603006834734`}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., -0.3333333333333333, 
      4.082155997157844*^-17}, {
      197., -0.3219752754296894, -0.08627301503417359}, {197., 0., 0.}, {197.,
       0., 0.}}], 
     Polygon3DBox[{{197., -0.3333333333333333, 4.082155997157844*^-17}, {
      197., -0.6666666666666666, 8.164311994315688*^-17}, {
      197., -0.6439505508593788, -0.17254603006834718`}, {
      197., -0.3219752754296894, -0.08627301503417359}, {
      197., -0.3333333333333333, 4.082155997157844*^-17}}], 
     Polygon3DBox[{{197., -0.6666666666666666, 8.164311994315688*^-17}, {
      197., -1., 1.2246467991473532`*^-16}, {
      197., -0.9659258262890683, -0.2588190451025208}, {
      197., -0.6439505508593788, -0.17254603006834718`}, {
      197., -0.6666666666666666, 8.164311994315688*^-17}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -0.32197527542968946`, -0.08627301503417345}, {
      197., -0.2886751345948129, -0.16666666666666657`}, {197., 0., 0.}, {
      197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.32197527542968946`, -0.08627301503417345}, {
      197., -0.6439505508593789, -0.1725460300683469}, {
      197., -0.5773502691896258, -0.33333333333333315`}, {
      197., -0.2886751345948129, -0.16666666666666657`}, {
      197., -0.32197527542968946`, -0.08627301503417345}}], 
     Polygon3DBox[{{197., -0.6439505508593789, -0.1725460300683469}, {
      197., -0.9659258262890684, -0.25881904510252035`}, {
      197., -0.8660254037844388, -0.4999999999999997}, {
      197., -0.5773502691896258, -0.33333333333333315`}, {
      197., -0.6439505508593789, -0.1725460300683469}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -0.2886751345948129, -0.16666666666666657`}, {
      197., -0.2357022603955159, -0.2357022603955158}, {197., 0., 0.}, {197., 
      0., 0.}}], 
     Polygon3DBox[{{197., -0.2886751345948129, -0.16666666666666657`}, {
      197., -0.5773502691896258, -0.33333333333333315`}, {
      197., -0.4714045207910318, -0.4714045207910316}, {
      197., -0.2357022603955159, -0.2357022603955158}, {
      197., -0.2886751345948129, -0.16666666666666657`}}], 
     Polygon3DBox[{{197., -0.5773502691896258, -0.33333333333333315`}, {
      197., -0.8660254037844388, -0.4999999999999997}, {
      197., -0.7071067811865477, -0.7071067811865475}, {
      197., -0.4714045207910318, -0.4714045207910316}, {
      197., -0.5773502691896258, -0.33333333333333315`}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -0.23570226039551595`, -0.2357022603955157}, {
      197., -0.1666666666666668, -0.28867513459481275`}, {197., 0., 0.}, {
      197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.23570226039551595`, -0.2357022603955157}, {
      197., -0.4714045207910319, -0.4714045207910314}, {
      197., -0.3333333333333336, -0.5773502691896255}, {
      197., -0.1666666666666668, -0.28867513459481275`}, {
      197., -0.23570226039551595`, -0.2357022603955157}}], 
     Polygon3DBox[{{197., -0.4714045207910319, -0.4714045207910314}, {
      197., -0.7071067811865479, -0.7071067811865471}, {
      197., -0.5000000000000004, -0.8660254037844384}, {
      197., -0.3333333333333336, -0.5773502691896255}, {
      197., -0.4714045207910319, -0.4714045207910314}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -0.1666666666666668, -0.28867513459481275`}, {
      197., -0.08627301503417384, -0.32197527542968934`}, {197., 0., 0.}, {
      197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.1666666666666668, -0.28867513459481275`}, {
      197., -0.3333333333333336, -0.5773502691896255}, {
      197., -0.17254603006834768`, -0.6439505508593787}, {
      197., -0.08627301503417384, -0.32197527542968934`}, {
      197., -0.1666666666666668, -0.28867513459481275`}}], 
     Polygon3DBox[{{197., -0.3333333333333336, -0.5773502691896255}, {
      197., -0.5000000000000004, -0.8660254037844384}, {
      197., -0.2588190451025215, -0.9659258262890681}, {
      197., -0.17254603006834768`, -0.6439505508593787}, {
      197., -0.3333333333333336, -0.5773502691896255}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -0.08627301503417384, -0.32197527542968934`}, {
      197., -3.572918131907427*^-16, -0.3333333333333333}, {197., 0., 0.}, {
      197., 0., 0.}}], 
     Polygon3DBox[{{197., -0.08627301503417384, -0.32197527542968934`}, {
      197., -0.17254603006834768`, -0.6439505508593787}, {
      197., -7.145836263814854*^-16, -0.6666666666666666}, {
      197., -3.572918131907427*^-16, -0.3333333333333333}, {
      197., -0.08627301503417384, -0.32197527542968934`}}], 
     Polygon3DBox[{{197., -0.17254603006834768`, -0.6439505508593787}, {
      197., -0.2588190451025215, -0.9659258262890681}, {
      197., -1.0718754395722282`*^-15, -1.}, {
      197., -7.145836263814854*^-16, -0.6666666666666666}, {
      197., -0.17254603006834768`, -0.6439505508593787}}], 
     Polygon3DBox[{{197., 0., 0.}, {
      197., -6.123233995736765*^-17, -0.3333333333333333}, {197., 
      0.08627301503417342, -0.32197527542968946`}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{
      197., -6.123233995736765*^-17, -0.3333333333333333}, {
      197., -1.224646799147353*^-16, -0.6666666666666666}, {197., 
      0.17254603006834685`, -0.6439505508593789}, {197., 
      0.08627301503417342, -0.32197527542968946`}, {
      197., -6.123233995736765*^-17, -0.3333333333333333}}], 
     Polygon3DBox[{{197., -1.224646799147353*^-16, -0.6666666666666666}, {
      197., -1.8369701987210297`*^-16, -1.}, {197., 
      0.2588190451025203, -0.9659258262890684}, {197., 
      0.17254603006834685`, -0.6439505508593789}, {
      197., -1.224646799147353*^-16, -0.6666666666666666}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 
      0.08627301503417342, -0.32197527542968946`}, {197., 
      0.16666666666666644`, -0.288675134594813}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{197., 
      0.08627301503417342, -0.32197527542968946`}, {197., 
      0.17254603006834685`, -0.6439505508593789}, {197., 
      0.33333333333333287`, -0.577350269189626}, {197., 
      0.16666666666666644`, -0.288675134594813}, {197., 
      0.08627301503417342, -0.32197527542968946`}}], 
     Polygon3DBox[{{197., 0.17254603006834685`, -0.6439505508593789}, {197., 
      0.2588190451025203, -0.9659258262890684}, {197., 
      0.49999999999999933`, -0.866025403784439}, {197., 
      0.33333333333333287`, -0.577350269189626}, {197., 
      0.17254603006834685`, -0.6439505508593789}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 
      0.16666666666666644`, -0.288675134594813}, {197., 
      0.2357022603955156, -0.23570226039551612`}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{197., 0.16666666666666644`, -0.288675134594813}, {
      197., 0.33333333333333287`, -0.577350269189626}, {197., 
      0.4714045207910312, -0.47140452079103223`}, {197., 
      0.2357022603955156, -0.23570226039551612`}, {197., 
      0.16666666666666644`, -0.288675134594813}}], 
     Polygon3DBox[{{197., 0.33333333333333287`, -0.577350269189626}, {197., 
      0.49999999999999933`, -0.866025403784439}, {197., 
      0.7071067811865468, -0.7071067811865483}, {197., 
      0.4714045207910312, -0.47140452079103223`}, {197., 
      0.33333333333333287`, -0.577350269189626}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 
      0.23570226039551578`, -0.2357022603955159}, {197., 
      0.28867513459481275`, -0.1666666666666668}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{197., 
      0.23570226039551578`, -0.2357022603955159}, {197., 
      0.47140452079103157`, -0.4714045207910318}, {197., 
      0.5773502691896255, -0.3333333333333336}, {197., 
      0.28867513459481275`, -0.1666666666666668}, {197., 
      0.23570226039551578`, -0.2357022603955159}}], 
     Polygon3DBox[{{197., 0.47140452079103157`, -0.4714045207910318}, {197., 
      0.7071067811865474, -0.7071067811865477}, {197., 
      0.8660254037844384, -0.5000000000000004}, {197., 
      0.5773502691896255, -0.3333333333333336}, {197., 
      0.47140452079103157`, -0.4714045207910318}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 
      0.28867513459481275`, -0.1666666666666668}, {197., 
      0.32197527542968934`, -0.08627301503417385}, {197., 0., 0.}, {197., 0., 
      0.}}], Polygon3DBox[{{197., 
      0.28867513459481275`, -0.1666666666666668}, {197., 
      0.5773502691896255, -0.3333333333333336}, {197., 
      0.6439505508593787, -0.1725460300683477}, {197., 
      0.32197527542968934`, -0.08627301503417385}, {197., 
      0.28867513459481275`, -0.1666666666666668}}], 
     Polygon3DBox[{{197., 0.5773502691896255, -0.3333333333333336}, {197., 
      0.8660254037844384, -0.5000000000000004}, {197., 
      0.9659258262890681, -0.25881904510252157`}, {197., 
      0.6439505508593787, -0.1725460300683477}, {197., 
      0.5773502691896255, -0.3333333333333336}}], 
     Polygon3DBox[{{197., 0., 0.}, {197., 
      0.32197527542968934`, -0.08627301503417385}, {197., 
      0.3333333333333333, -3.7770259317653197`*^-16}, {197., 0., 0.}, {197., 
      0., 0.}}], 
     Polygon3DBox[{{197., 0.32197527542968934`, -0.08627301503417385}, {197., 
      0.6439505508593787, -0.1725460300683477}, {197., 
      0.6666666666666666, -7.554051863530639*^-16}, {197., 
      0.3333333333333333, -3.7770259317653197`*^-16}, {197., 
      0.32197527542968934`, -0.08627301503417385}}], 
     Polygon3DBox[{{197., 0.6439505508593787, -0.1725460300683477}, {197., 
      0.9659258262890681, -0.25881904510252157`}, {197., 
      1., -1.133107779529596*^-15}, {197., 
      0.6666666666666666, -7.554051863530639*^-16}, {197., 
      0.6439505508593787, -0.1725460300683477}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBihYkOEAYXywZ0AGQHHR/R7ud1+8s5/ANvlg7YQL
9jDx1T4RL6q2vbb/Dwb34eJnrevT5i14Zn8GSsPEGcGMB/aroPpg4lOg5opA
7YGJs8eIGKstm2iD4i6geB9E/X5RNPV/IO7YvxrNfKg79p9Fc89KiLr9zFB3
wcSh7tg/Fc2/UHfsh7hroQ1MXAyqvhPqLpj4Gqj5v6HugolfgLrnJJSGibNA
3LF/BVQfTHwe1FxhqD0wca6ueT6Wlav2wNwFE++AulsMTf0XaDytQzP/NDRc
zqG5B+oOe5i7YOJQd9jPR/MvLJ4g4bNxDwCZzuiI
       "]]}}, 
    {RGBColor[0.9313748722829585, 1., 0.5], AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.80009348181466, -7.943978826752928, 
      0.}}]}, 
    {RGBColor[0.9313748722829585, 0.9761297695001183, 0.6536889725715616], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      90.79312901185494, -7.557334749403953, -2.446182889866114}}]}, 
    {RGBColor[0.9313748722829585, 0.9067166552473702, 0.7926119711825902], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      90.77288879312717, -6.4333356875055925`, -4.656305642799752}}]}, 
    {RGBColor[0.9313748722829585, 0.7982513915126817, 0.9032205977664665], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      90.74129707055698, -4.677973313963376, -6.414176780509955}}]}, 
    {RGBColor[0.9313748722829585, 0.6611315602838433, 0.9744672227857459], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      90.7014215775235, -2.4606245660434345`, -7.54420607647521}}]}, 
    {RGBColor[0.9313748722829585, 0.508826462377227, 0.999066649721965], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      90.65721119927778, -5.655198531684391*^-16, -7.93147824681224}}]}, 
    {RGBColor[0.9313748722829585, 0.35652136447061056`, 0.9744672227857459], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.61308582705088, 
      2.4582281193958244`, -7.536858638101093}}]}, 
    {RGBColor[0.9313748722829585, 0.21940153324177236`, 0.9032205977664665], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.5734322977125, 
      4.669319404959733, -6.402311021886212}}]}, 
    {RGBColor[0.9313748722829585, 0.11093626950708368`, 0.7926119711825902], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.54211377326678, 
      6.41697999814953, -4.644467757705647}}]}, 
    {RGBColor[0.9313748722829585, 0.0415231552543357, 0.6536889725715617], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.5220936404668, 
      7.534774616794779, -2.4388805521754335`}}]}, 
    {RGBColor[0.9313748722829585, 0.017652924754453903`, 0.5000000000000001], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.5152130159867, 7.9190550155329955`, 
      0.}}]}, 
    {RGBColor[0.9313748722829585, 0.0415231552543357, 0.34631102742843856`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.5220936404668, 7.534774616794779, 
      2.4388805521754313`}}]}, 
    {RGBColor[0.9313748722829585, 0.11093626950708357`, 0.20738802881741003`],
      AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.54211377326678, 6.4169799981495315`, 
      4.6444677577056455`}}]}, 
    {RGBColor[0.9313748722829585, 0.21940153324177214`, 0.09677940223353365], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.5734322977125, 4.669319404959736, 
      6.40231102188621}}]}, 
    {RGBColor[
     0.9313748722829585, 0.35652136447061045`, 0.025532777214254176`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.61308582705088, 2.4582281193958266`, 
      7.536858638101093}}]}, 
    {RGBColor[0.9313748722829585, 0.5088264623772268, 0.0009333502780349834], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.65721119927778, 1.654926196081874*^-15, 
      7.93147824681224}}]}, 
    {RGBColor[0.9313748722829585, 0.6611315602838432, 0.025532777214254176`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.7014215775235, -2.4606245660434336`, 
      7.54420607647521}}]}, 
    {RGBColor[0.9313748722829585, 0.7982513915126814, 0.09677940223353354], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.74129707055698, -4.677973313963376, 
      6.414176780509955}}]}, 
    {RGBColor[0.9313748722829585, 0.9067166552473701, 0.2073880288174098], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.77288879312717, -6.433335687505591, 
      4.656305642799754}}]}, 
    {RGBColor[0.9313748722829585, 0.9761297695001183, 0.34631102742843844`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {90.79312901185494, -7.557334749403953, 
      2.4461828898661153`}}]}, 
    {RGBColor[0.0005245323116921385, 0.4725798896212702, 0.5], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.80009348181466, -7.943978826752928, 0.}, {
      109.44332883697214`, -7.824068037519229, 0.}}]}, 
    {RGBColor[
     0.0004801655943936778, 0.47274229038805826`, 0.49945392330620286`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.79312901185494, -7.557334749403953, -2.446182889866114}, {
      109.43847763990019`, -7.437947703984694, -2.444404731188004}}]}, 
    {RGBColor[
     0.0003621789876110393, 0.47317429855893556`, 0.49908586692785517`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      90.77288879312717, -6.4333356875055925`, -4.656305642799752}, {
      109.42437067823238`, -6.315339227036188, -4.653328025219981}}]}, 
    {RGBColor[
     0.00021056578473932497`, 0.47372969644575236`, 0.499010177223876], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.74129707055698, -4.677973313963376, -6.414176780509955}, {
      109.4023271061959, -4.561755637786824, -6.410950969330782}}]}, 
    {RGBColor[
     0.00007576878498216644, 0.47422364888379276`, 0.4992356897293324], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.7014215775235, -2.4606245660434345`, -7.54420607647521}, {
      109.37446007821904`, -2.345968868015016, -7.541713604188698}}]}, 
    {RGBColor[0., 0.47450092042824277`, 0.49966247696678057`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      90.65721119927778, -5.655198531684391*^-16, -7.93147824681224}, {
      109.34350700631593`, 0.1138176793967933, -7.930376778136588}}]}, 
    {RGBColor[
     1.5026000264040107`*^-6, 0.47449386840965446`, 0.5001211481922994], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.61308582705088, 
      2.4582281193958244`, -7.536858638101093}, {109.31255401389252`, 
      2.5721494318492497`, -7.5372542703751835`}}]}, 
    {RGBColor[
     0.00006847526796716075, 0.47424540794935177`, 0.5004401551149642], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.5734322977125, 4.669319404959733, -6.402311021886212}, {
      109.28468719339604`, 4.7841375091179374`, -6.403749337864676}}]}, 
    {RGBColor[
     0.00016520943913522768`, 0.47388702530778126`, 0.5005124920540295], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.54211377326678, 6.41697999814953, -4.644467757705647}, {
      109.26264387662552`, 6.5330455770536915`, -4.64614328337778}}]}, 
    {RGBColor[
     0.0002472928586663148, 0.47358289913122686`, 0.5003339568378333], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.5220936404668, 7.534774616794779, -2.4388805521754335`}, {
      109.24853712051282`, 7.651887495337791, -2.4399727255805335`}}]}, 
    {RGBColor[0.00027914707652243465`, 0.4734648567434733, 0.5], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.5152130159867, 7.9190550155329955`, 0.}, {
      109.24368600173067`, 8.036572893976766, 0.}}]}, 
    {RGBColor[
     0.0002472928586663148, 0.47358289913122686`, 0.4996660431621667], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.5220936404668, 7.534774616794779, 2.4388805521754313`}, {
      109.24853712051282`, 7.651887495337791, 2.4399727255805312`}}]}, 
    {RGBColor[
     0.00016520943913522768`, 0.47388702530778126`, 0.49948750794597063`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.54211377326678, 6.4169799981495315`, 
      4.6444677577056455`}, {109.26264387662552`, 6.533045577053693, 
      4.6461432833777785`}}]}, 
    {RGBColor[0.00006847526796716075, 0.4742454079493519, 0.4995598448850359],
      AbsoluteThickness[0.5], 
     Line3DBox[{{90.5734322977125, 4.669319404959736, 6.40231102188621}, {
      109.28468719339604`, 4.78413750911794, 6.403749337864674}}]}, 
    {RGBColor[
     1.5026000264040107`*^-6, 0.47449386840965446`, 0.49987885180770075`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.61308582705088, 2.4582281193958266`, 7.536858638101093}, {
      109.31255401389252`, 2.572149431849252, 7.5372542703751835`}}]}, 
    {RGBColor[0., 0.474500920428243, 0.5003375230332194], AbsoluteThickness[
     0.5], Line3DBox[{{90.65721119927778, 1.654926196081874*^-15, 
      7.93147824681224}, {109.34350700631593`, 0.11381767939679524`, 
      7.930376778136588}}]}, 
    {RGBColor[
     0.00007576878498216644, 0.47422364888379276`, 0.5007643102706677], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.7014215775235, -2.4606245660434336`, 7.54420607647521}, {
      109.37446007821904`, -2.345968868015015, 7.541713604188698}}]}, 
    {RGBColor[
     0.00021056578473932497`, 0.47372969644575236`, 0.5009898227761241], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.74129707055698, -4.677973313963376, 6.414176780509955}, {
      109.4023271061959, -4.561755637786824, 6.410950969330782}}]}, 
    {RGBColor[
     0.0003621789876110393, 0.47317429855893556`, 0.5009141330721449], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.77288879312717, -6.433335687505591, 4.656305642799754}, {
      109.42437067823238`, -6.315339227036186, 4.653328025219983}}]}, 
    {RGBColor[
     0.0004801655943936778, 0.47274229038805826`, 0.5005460766937972], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{90.79312901185494, -7.557334749403953, 
      2.4461828898661153`}, {109.43847763990019`, -7.437947703984694, 
      2.4444047311880053`}}]}, 
    {RGBColor[1., 0., 0.5], AbsoluteThickness[0.5], 
     Line3DBox[{{109.44332883697214`, -7.824068037519229, 0.}, {197., 
      0.11368177879512942`, 0.}}]}, 
    {RGBColor[0.9968236625790436, 0.02410973194317656, 0.34544679089729835`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      109.43847763990019`, -7.437947703984694, -2.444404731188004}, {197., 
      0.12400849836319239`, -0.07138916797736528}}]}, 
    {RGBColor[0.9876174720197024, 0.09416650864715714, 0.20590679811050727`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      109.42437067823238`, -6.315339227036188, -4.653328025219981}, {197., 
      0.1544760906390117, -0.137252602658263}}]}, 
    {RGBColor[0.9733221409547523, 0.20348078412086235`, 0.09509080170709228], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.4023271061959, -4.561755637786824, -6.410950969330782}, {
      197., 0.20338283108796773`, -0.19199041473032974`}}]}, 
    {RGBColor[0.9554071372168748, 0.3414017123802341, 0.02406809668191834], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      109.37446007821904`, -2.345968868015016, -7.541713604188698}, {197., 
      0.26745459900226276`, -0.23013156735063944`}}]}, 
    {RGBColor[
     0.9357123423155576, 0.49424264687148534`, 1.1102230246251565`*^-16], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.34350700631593`, 
      0.1138176793967933, -7.930376778136588}, {197., 
      0.34152645204915943`, -0.24694893578754318`}}]}, 
    {RGBColor[0.9162310877912273, 0.6467137615484235, 0.02521984607149652], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.31255401389252`, 
      2.5721494318492497`, -7.5372542703751835`}, {197., 
      0.4186157623140434, -0.23938011994015085`}}]}, 
    {RGBColor[0.8988736774385201, 0.7836690283289621, 0.09695083458804932], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.28468719339604`, 
      4.7841375091179374`, -6.403749337864676}, {197., 
      0.4905667114836554, -0.20692661710588567`}}]}, 
    {RGBColor[0.8852646590055362, 0.8917947341256187, 0.20776247780251944`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.26264387662552`, 
      6.5330455770536915`, -4.64614328337778}, {197., 
      0.5491716105006761, -0.15215400858213535`}}]}, 
    {RGBColor[0.8766113665916477, 0.9608940011696515, 0.34659149662260547`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.24853712051282`, 
      7.651887495337791, -2.4399727255805335`}, {197., 
      0.5874521738586784, -0.08058141827709608}}]}, 
    {RGBColor[0.8736456676923613, 0.9846389514651591, 0.5], AbsoluteThickness[
     0.5], Line3DBox[{{109.24368600173067`, 8.036572893976766, 0.}, {197., 
      0.6007554299801923, 0.}}]}, 
    {RGBColor[0.8766113665916477, 0.9608940011696515, 0.6534085033773944], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.24853712051282`, 7.651887495337791, 
      2.4399727255805312`}, {197., 0.5874521738586784, 
      0.08058141827709653}}]}, 
    {RGBColor[0.8852646590055362, 0.8917947341256189, 0.7922375221974806], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.26264387662552`, 6.533045577053693, 
      4.6461432833777785`}, {197., 0.5491716105006752, 
      0.15215400858213535`}}]}, 
    {RGBColor[0.8988736774385201, 0.7836690283289623, 0.9030491654119508], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.28468719339604`, 4.78413750911794, 6.403749337864674}, {
      197., 0.4905667114836545, 0.20692661710588567`}}]}, 
    {RGBColor[0.9162310877912273, 0.6467137615484237, 0.9747801539285035], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.31255401389252`, 2.572149431849252, 
      7.5372542703751835`}, {197., 0.41861576231404296`, 
      0.23938011994015085`}}]}, 
    {RGBColor[0.9357123423155576, 0.49424264687148556`, 1.], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.34350700631593`, 0.11381767939679524`, 
      7.930376778136588}, {197., 0.34152645204915744`, 
      0.24694893578754318`}}]}, 
    {RGBColor[0.9554071372168748, 0.3414017123802341, 0.9759319033180817], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.37446007821904`, -2.345968868015015, 
      7.541713604188698}, {197., 0.26745459900226365`, 
      0.23013156735063944`}}]}, 
    {RGBColor[0.9733221409547523, 0.20348078412086223`, 0.9049091982929078], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.4023271061959, -4.561755637786824, 6.410950969330782}, {
      197., 0.2033828310879695, 0.19199041473032974`}}]}, 
    {RGBColor[0.9876174720197024, 0.09416650864715714, 0.7940932018894928], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.42437067823238`, -6.315339227036186, 
      4.653328025219983}, {197., 0.1544760906390117, 0.1372526026582639}}]}, 
    {RGBColor[0.9968236625790436, 0.02410973194317656, 0.6545532091027018], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{109.43847763990019`, -7.437947703984694, 
      2.4444047311880053`}, {197., 0.12400849836319239`, 
      0.07138916797736528}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJx1kX1MTXEYx49u11tDbnk50b1XLzKv/dG8tMt5kKhWyL0n7TQlpdCQankn
k7WRVi2xaruuJmulV+lK7qN70ZreGEuhKIRKRqt2a3M595yczNl+/3z27Dnf
7+dZEHrIP9yCIAiF6YlMD5O8q9zKaNDblodqHsuQMH/QtkJdU0qDbdzHgTvu
Uuy1QVVtqgg3nbhsEV9Cw3O7ysD7VSRuF8uvTFdLMCrfY190EQ3rHHo06yok
OHelYsD+FoliK+WcrgITl9/tY4pEGG5MYzyWSVHzJkU3I5+GPz8LMdxvGTYe
fKGV4RM3+qkij4Z5vnMSYvJFkNKh3PTAWYq+Xrvty3JpCEr8ah1aKIEAr7wD
g1kkztYOjpZoaChJHqkfySchoNiO+ZYuQe+maOO+6zRsiJs0kOUoBXlyesPz
cyKsShLBsJqGCw+tauYXyoDrO35+HjsP3P4y834Vux+4PMHmPCo2D3D55cL8
IOjb9EZh7gucH4XQD/zHJ3D+m83+d7D+Yfy9+tl7wbOpX84EBzFg8Gk71eIz
dt9zr85bWpt4V+enoDi0x4ky1UynyyLsmavpXMQwUG3t69W9gUS3xEyxRY4E
B1+53tMFMrAzufStgpLgNKcKZVMuif17I1wGAxiYdTRqx0WDBRa6ZA5VLJai
9nyj5YiKAb/1d+tcHKup+lUFxeWVMtQOX3pPKBmIq2621adbgm+m3ui8UIrx
fpptq/0Z6P0c+/2ngw1450bEH84h8cTCjYsatzEQ2eVQ9nKBHfRdupdxM0OC
sfPXTu7eykDpFY/wpCwpGIjsA9aJItxsXJJ81cR1ZNFtrUTO33f8vI6dB27/
fvP+HnY/cHn6zXm2sHmAy39cmB+4vq3CvsD5sRH6gf/4BM5/ldn/StY/jL/X
FPZebD91JBAJNjWUXTVF/P395sEfgsQ6HUXswlMpnqU6jp89mber/ZGewhut
m0+nPhzj2VYtRybXUSEGN6VTei3P+72Guobtmyli6eOEH7H1PE/akqpPbXtB
EbdON4uzG3leeXO54VpdK0X4uY9OyG3gOUzK+Bod3k4RjmmeaSfreN79IDig
Ke0dhWGRqtpjep4PjajORj59T0Hg4tdGdTnPd5IZMXvWdP7Tl5sPYecpjncI
9/PcVZiH58XC/DwPE/blOeEt8MNzFPrkOee/g/U/tkd4L+oXXjBXPg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731739825205*^9},
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"During evaluation of In[33]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["We can change the rendering to a graylevel format using the \
option, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->{RayLength,GrayLevel}",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". ",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ill,PlotType->TopView,ShowRange->{2},\t
\tColorView->{RayLength,GrayLevel}];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"In[34]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{197., 0.}, {197., 0.3333333333333333}, {197., 
      0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3333333333333333}, {197., 0.6666666666666666}, {
      197., 0.6439505508593788}, {197., 0.3219752754296894}, {197., 
      0.3333333333333333}}], 
     PolygonBox[{{197., 0.6666666666666666}, {197., 1.}, {197., 
      0.9659258262890683}, {197., 0.6439505508593788}, {197., 
      0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., 0.3219752754296894}, {197., 
      0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3219752754296894}, {197., 0.6439505508593788}, {
      197., 0.5773502691896257}, {197., 0.28867513459481287`}, {197., 
      0.3219752754296894}}], 
     PolygonBox[{{197., 0.6439505508593788}, {197., 0.9659258262890683}, {
      197., 0.8660254037844387}, {197., 0.5773502691896257}, {197., 
      0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481287`}, {197., 
      0.23570226039551584`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481287`}, {197., 0.5773502691896257}, {
      197., 0.4714045207910317}, {197., 0.23570226039551584`}, {197., 
      0.28867513459481287`}}], 
     PolygonBox[{{197., 0.5773502691896257}, {197., 0.8660254037844387}, {
      197., 0.7071067811865476}, {197., 0.4714045207910317}, {197., 
      0.5773502691896257}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551584`}, {197., 
      0.16666666666666669`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551584`}, {197., 0.4714045207910317}, {
      197., 0.33333333333333337`}, {197., 0.16666666666666669`}, {197., 
      0.23570226039551584`}}], 
     PolygonBox[{{197., 0.4714045207910317}, {197., 0.7071067811865476}, {
      197., 0.5000000000000001}, {197., 0.33333333333333337`}, {197., 
      0.4714045207910317}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666669`}, {197., 
      0.08627301503417364}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666669`}, {197., 0.33333333333333337`}, {
      197., 0.1725460300683473}, {197., 0.08627301503417364}, {197., 
      0.16666666666666669`}}], 
     PolygonBox[{{197., 0.33333333333333337`}, {197., 0.5000000000000001}, {
      197., 0.25881904510252096`}, {197., 0.1725460300683473}, {197., 
      0.33333333333333337`}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417364}, {197., 
      9.442564829413299*^-17}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417364}, {197., 0.1725460300683473}, {
      197., 1.8885129658826599`*^-16}, {197., 9.442564829413299*^-17}, {197., 
      0.08627301503417364}}], 
     PolygonBox[{{197., 0.1725460300683473}, {197., 0.25881904510252096`}, {
      197., 2.83276944882399*^-16}, {197., 1.8885129658826599`*^-16}, {197., 
      0.1725460300683473}}], 
     PolygonBox[{{197., 0.}, {197., 2.041077998578922*^-17}, {
      197., -0.08627301503417353}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 2.041077998578922*^-17}, {197., 
      4.082155997157844*^-17}, {197., -0.17254603006834707`}, {
      197., -0.08627301503417353}, {197., 2.041077998578922*^-17}}], 
     PolygonBox[{{197., 4.082155997157844*^-17}, {197., 
      6.123233995736766*^-17}, {197., -0.25881904510252063`}, {
      197., -0.17254603006834707`}, {197., 4.082155997157844*^-17}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417353}, {
      197., -0.16666666666666657`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417353}, {
      197., -0.17254603006834707`}, {197., -0.33333333333333315`}, {
      197., -0.16666666666666657`}, {197., -0.08627301503417353}}], 
     PolygonBox[{{197., -0.17254603006834707`}, {
      197., -0.25881904510252063`}, {197., -0.4999999999999998}, {
      197., -0.33333333333333315`}, {197., -0.17254603006834707`}}], 
     PolygonBox[{{197., 0.}, {197., -0.16666666666666657`}, {
      197., -0.2357022603955158}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.16666666666666657`}, {
      197., -0.33333333333333315`}, {197., -0.4714045207910316}, {
      197., -0.2357022603955158}, {197., -0.16666666666666657`}}], 
     PolygonBox[{{197., -0.33333333333333315`}, {197., -0.4999999999999998}, {
      197., -0.7071067811865475}, {197., -0.4714045207910316}, {
      197., -0.33333333333333315`}}], 
     PolygonBox[{{197., 0.}, {197., -0.2357022603955158}, {
      197., -0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2357022603955158}, {197., -0.4714045207910316}, {
      197., -0.5773502691896257}, {197., -0.28867513459481287`}, {
      197., -0.2357022603955158}}], 
     PolygonBox[{{197., -0.4714045207910316}, {197., -0.7071067811865475}, {
      197., -0.8660254037844387}, {197., -0.5773502691896257}, {
      197., -0.4714045207910316}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948128}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948128}, {197., -0.5773502691896256}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.2886751345948128}}], 
     PolygonBox[{{197., -0.5773502691896256}, {197., -0.8660254037844385}, {
      197., -0.9659258262890682}, {197., -0.6439505508593788}, {
      197., -0.5773502691896256}}], 
     PolygonBox[{{197., 0.}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3219752754296894}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}}], 
     PolygonBox[{{197., -0.6439505508593788}, {197., -0.9659258262890682}, {
      197., -1.}, {197., -0.6666666666666666}, {197., -0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3333333333333333}, {197., -0.6666666666666666}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}}], 
     PolygonBox[{{197., -0.6666666666666666}, {197., -1.}, {
      197., -0.9659258262890683}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., -0.32197527542968946`}, {
      197., -0.2886751345948129}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.32197527542968946`}, {197., -0.6439505508593789}, {
      197., -0.5773502691896258}, {197., -0.2886751345948129}, {
      197., -0.32197527542968946`}}], 
     PolygonBox[{{197., -0.6439505508593789}, {197., -0.9659258262890684}, {
      197., -0.8660254037844388}, {197., -0.5773502691896258}, {
      197., -0.6439505508593789}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948129}, {
      197., -0.2357022603955159}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948129}, {197., -0.5773502691896258}, {
      197., -0.4714045207910318}, {197., -0.2357022603955159}, {
      197., -0.2886751345948129}}], 
     PolygonBox[{{197., -0.5773502691896258}, {197., -0.8660254037844388}, {
      197., -0.7071067811865477}, {197., -0.4714045207910318}, {
      197., -0.5773502691896258}}], 
     PolygonBox[{{197., 0.}, {197., -0.23570226039551595`}, {
      197., -0.1666666666666668}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.23570226039551595`}, {197., -0.4714045207910319}, {
      197., -0.3333333333333336}, {197., -0.1666666666666668}, {
      197., -0.23570226039551595`}}], 
     PolygonBox[{{197., -0.4714045207910319}, {197., -0.7071067811865479}, {
      197., -0.5000000000000004}, {197., -0.3333333333333336}, {
      197., -0.4714045207910319}}], 
     PolygonBox[{{197., 0.}, {197., -0.1666666666666668}, {
      197., -0.08627301503417384}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.1666666666666668}, {197., -0.3333333333333336}, {
      197., -0.17254603006834768`}, {197., -0.08627301503417384}, {
      197., -0.1666666666666668}}], 
     PolygonBox[{{197., -0.3333333333333336}, {197., -0.5000000000000004}, {
      197., -0.2588190451025215}, {197., -0.17254603006834768`}, {
      197., -0.3333333333333336}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417384}, {
      197., -3.572918131907427*^-16}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417384}, {
      197., -0.17254603006834768`}, {197., -7.145836263814854*^-16}, {
      197., -3.572918131907427*^-16}, {197., -0.08627301503417384}}], 
     PolygonBox[{{197., -0.17254603006834768`}, {197., -0.2588190451025215}, {
      197., -1.0718754395722282`*^-15}, {197., -7.145836263814854*^-16}, {
      197., -0.17254603006834768`}}], 
     PolygonBox[{{197., 0.}, {197., -6.123233995736765*^-17}, {197., 
      0.08627301503417342}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -6.123233995736765*^-17}, {
      197., -1.224646799147353*^-16}, {197., 0.17254603006834685`}, {197., 
      0.08627301503417342}, {197., -6.123233995736765*^-17}}], 
     PolygonBox[{{197., -1.224646799147353*^-16}, {
      197., -1.8369701987210297`*^-16}, {197., 0.2588190451025203}, {197., 
      0.17254603006834685`}, {197., -1.224646799147353*^-16}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417342}, {197., 
      0.16666666666666644`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417342}, {197., 0.17254603006834685`}, {
      197., 0.33333333333333287`}, {197., 0.16666666666666644`}, {197., 
      0.08627301503417342}}], 
     PolygonBox[{{197., 0.17254603006834685`}, {197., 0.2588190451025203}, {
      197., 0.49999999999999933`}, {197., 0.33333333333333287`}, {197., 
      0.17254603006834685`}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666644`}, {197., 
      0.2357022603955156}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666644`}, {197., 0.33333333333333287`}, {
      197., 0.4714045207910312}, {197., 0.2357022603955156}, {197., 
      0.16666666666666644`}}], 
     PolygonBox[{{197., 0.33333333333333287`}, {197., 0.49999999999999933`}, {
      197., 0.7071067811865468}, {197., 0.4714045207910312}, {197., 
      0.33333333333333287`}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551578`}, {197., 
      0.28867513459481275`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551578`}, {197., 0.47140452079103157`}, {
      197., 0.5773502691896255}, {197., 0.28867513459481275`}, {197., 
      0.23570226039551578`}}], 
     PolygonBox[{{197., 0.47140452079103157`}, {197., 0.7071067811865474}, {
      197., 0.8660254037844384}, {197., 0.5773502691896255}, {197., 
      0.47140452079103157`}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481275`}, {197., 
      0.32197527542968934`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481275`}, {197., 0.5773502691896255}, {
      197., 0.6439505508593787}, {197., 0.32197527542968934`}, {197., 
      0.28867513459481275`}}], 
     PolygonBox[{{197., 0.5773502691896255}, {197., 0.8660254037844384}, {
      197., 0.9659258262890681}, {197., 0.6439505508593787}, {197., 
      0.5773502691896255}}], 
     PolygonBox[{{197., 0.}, {197., 0.32197527542968934`}, {197., 
      0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.32197527542968934`}, {197., 0.6439505508593787}, {
      197., 0.6666666666666666}, {197., 0.3333333333333333}, {197., 
      0.32197527542968934`}}], 
     PolygonBox[{{197., 0.6439505508593787}, {197., 0.9659258262890681}, {
      197., 1.}, {197., 0.6666666666666666}, {197., 0.6439505508593787}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYLMhwgjA/2ML7ofg/3uy/ewfmrfSJeVG17Deef
ta5Pm7fgGZzPCGY8gPOnsE0+WDvhApzPHiNirLZsog2M3weR3w/j//kPAvfh
/DMQ8+H8lRD74XwRiPvgfKj74XwxNPk1aPovoJnPAnE/nD8PzX1cXfN8LCtX
7YHxO9D89wXifjj/NFr4rEALP2G08IWFPwABtIYM
       "]]}}, 
    {GrayLevel[1.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.44332883697214`, -7.824068037519229}, {197., 
      0.11368177879512942`}}]}, 
    {GrayLevel[0.9759338089820081], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
      0.12400849836319239`}}]}, 
    {GrayLevel[0.9058840940462928], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.42437067823238`, -6.315339227036188}, {197., 
      0.1544760906390117}}]}, 
    {GrayLevel[0.7962257155583099], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
      0.20338283108796773`}}]}, 
    {GrayLevel[0.6572528831579814], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.37446007821904`, -2.345968868015016}, {197., 
      0.26745459900226276`}}]}, 
    {GrayLevel[0.5024408680059917], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.34350700631593`, 0.1138176793967933}, {197., 
      0.34152645204915943`}}]}, 
    {GrayLevel[0.34715949125245305`], AbsoluteThickness[0.5], Arrowheads[
     Small], ArrowBox[{{109.31255401389252`, 2.5721494318492497`}, {197., 
      0.4186157623140434}}]}, 
    {GrayLevel[0.20696106735775532`], AbsoluteThickness[0.5], Arrowheads[
     Small], ArrowBox[{{109.28468719339604`, 4.7841375091179374`}, {197., 
      0.4905667114836554}}]}, 
    {GrayLevel[0.095794168974625], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.26264387662552`, 6.5330455770536915`}, {197., 
      0.5491716105006761}}]}, 
    {GrayLevel[0.02452917752733308], AbsoluteThickness[0.5], Arrowheads[
     Small], ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
      0.5874521738586784}}]}, 
    {GrayLevel[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     StyleBox[
      ArrowBox[{{109.24368600173067`, 8.036572893976766}, {197., 
       0.6007554299801923}}],
      FontColor->GrayLevel[0.]]}, 
    {GrayLevel[0.02452917752733308], AbsoluteThickness[0.5], Arrowheads[
     Small], ArrowBox[{{109.24853712051282`, 7.651887495337791}, {197., 
      0.5874521738586784}}]}, 
    {GrayLevel[0.095794168974625], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{109.26264387662552`, 6.533045577053693}, {197., 
      0.5491716105006752}}]}, 
    {GrayLevel[0.20696106735775532`], AbsoluteThickness[0.5], Arrowheads[
     Small], ArrowBox[{{109.28468719339604`, 4.78413750911794}, {197., 
      0.4905667114836545}}]}, 
    {GrayLevel[0.34715949125245305`], AbsoluteThickness[0.5], Arrowheads[
     Small], 
     ArrowBox[{{109.31255401389252`, 2.572149431849252}, {197., 
      0.41861576231404296`}}]}, 
    {GrayLevel[0.5024408680059917], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.34350700631593`, 0.11381767939679524`}, {197., 
      0.34152645204915744`}}]}, 
    {GrayLevel[0.6572528831579814], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.37446007821904`, -2.345968868015015}, {197., 
      0.26745459900226365`}}]}, 
    {GrayLevel[0.7962257155583099], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.4023271061959, -4.561755637786824}, {197., 
      0.2033828310879695}}]}, 
    {GrayLevel[0.9058840940462928], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.42437067823238`, -6.315339227036186}, {197., 
      0.1544760906390117}}]}, 
    {GrayLevel[0.9759338089820081], AbsoluteThickness[0.5], Arrowheads[Small],
      ArrowBox[{{109.43847763990019`, -7.437947703984694}, {197., 
      0.12400849836319239`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQYLMhwYGoUP2UvttYfz45/GsO7fD+c31CyPu3/0
MII/h/tGEccpOP+D548nP2UvwvkdHhMPT7x9Fc7fsUzvyMxTt+B8B/aprwtT
78P5L/bFh1+Y9BDO//EntCHjzCM4P0JyanGy5WOc8g/Q9Bugmb8Bzf4UNPcx
eKG6/wCa/9D9DwsfALcocCs=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731739920735*^9},
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"},
 
 CellLabel->"During evaluation of In[34]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["You can use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView -> RaySourceNumber", "Input"],
 StyleBox[" to assign distinctive colors on each ray trajectory. This is \
useful for tracking the path of individual rays through a system.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],

Cell[CellGroupData[{

Cell["\<\
 AnalyzeSystem[{
\tMove[LineOfRays[40,NumberOfRays->11],{0,-5},5],
\tMove[PlanoConvexLens[100,50,10, FresnelReflections -> True],50],
\tBoundary[150]},
\tPlotType->TopView,
\tColorView -> RaySourceNumber];\
\>", "Input",
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"In[35]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {150., -75.}, {150., 75.}, {150., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {0., -75.}, {0., -75.}, {150., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -75}, {0, 75}, {0, 75}, {0, -75}, {0, -75}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 75.}, {150., 75.}, {150., 75.}, {0., 75.}, {0., 75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {150., 75.}, {0., 75.}, {0., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {0., -75.}, {0., 75.}, {150., 
       75.}}]}}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.7431148549531632`, -24.92389396183491}, {
      54.15358479945905, -20.338571991624484`}}]}, 
    {Hue[0.63], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.3944918839625307`, -20.93911516946793}, {
      52.678258694525105`, -16.452366950636673`}}]}, 
    {Hue[0.5599999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{1.045868912971898, -16.954336377100947`}, {
      51.53780177605795, -12.536864652068868`}}]}, 
    {Hue[0.48999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0.6972459419812653, -12.969557584733964`}, {
      50.716769306552294`, -8.593416335363916}}]}, 
    {Hue[0.42], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0.34862297099063266`, -8.984778792366981}, {
      50.20639999320265, -4.6227885143201295`}}]}, 
    {Hue[0.35], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -5.}, {50.00376827030235, -0.6252371427712431}}]}, 
    {Hue[0.2799999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-0.34862297099063266`, -1.0152212076330178`}, {
      50.111513098815614`, 3.399468658450602}}]}, 
    {Hue[0.20999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-0.6972459419812653, 2.9695575847339644`}, {50.5380823378343, 
      7.452067981247007}}]}, 
    {Hue[0.13999999999999996`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-1.045868912971898, 6.954336377100947}, {51.298547518203875`, 
      11.53387941370893}}]}, 
    {Hue[0.06999999999999998], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-1.3944918839625307`, 10.939115169467929`}, {
      52.41618296796776, 15.646939195691358`}}]}, 
    {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-1.7431148549531632`, 14.92389396183491}, {53.92523180426972, 
      19.794243211748157`}}]}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
      60., -19.171068189440202`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{54.15358479945905, -20.338571991624484`}, {
       0., -67.69534781781275}}]}}, 
    {Hue[0.63], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{52.678258694525105`, -16.452366950636673`}, {
      60., -15.20648096619162}}], 
     {Arrowheads[Small], 
      ArrowBox[{{52.678258694525105`, -16.452366950636673`}, {
       0., -49.34893907197211}}]}}, 
    {Hue[0.5599999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{51.53780177605795, -12.536864652068868`}, {
      60., -11.334869955564942`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{51.53780177605795, -12.536864652068868`}, {
       0., -34.384086888833366`}}]}}, 
    {Hue[0.48999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.716769306552294`, -8.593416335363916}, {
      60., -7.527241808423948}}], 
     {Arrowheads[Small], 
      ArrowBox[{{50.716769306552294`, -8.593416335363916}, {
       7.105427357601002*^-15, -21.306069959914936`}}]}}, 
    {Hue[0.42], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.20639999320265, -4.6227885143201295`}, {
      60., -3.759312696702177}}], 
     {Arrowheads[Small], 
      ArrowBox[{{
       50.20639999320265, -4.6227885143201295`}, {-7.105427357601002*^-15, \
-9.214779766619795}}]}}, 
    {Hue[0.35], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
      60., -0.009292879215369254}}], 
     {Arrowheads[Small], 
      ArrowBox[{{50.00376827030235, -0.6252371427712431}, {
       7.105427357601002*^-15, 2.5371555495783014`}}]}}, 
    {Hue[0.2799999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.111513098815614`, 3.399468658450602}, {60., 
      3.743877727348856}}], 
     {Arrowheads[Small], 
      ArrowBox[{{50.111513098815614`, 3.399468658450602}, {0., 
       14.522891366190311`}}]}}, 
    {Hue[0.20999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.5380823378343, 7.452067981247007}, {60., 
      7.522192459759814}}], 
     {Arrowheads[Small], 
      ArrowBox[{{50.5380823378343, 7.452067981247007}, {0., 
       27.37959787968331}}]}}, 
    {Hue[0.13999999999999996`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{51.298547518203875`, 11.53387941370893}, {60., 
      11.350459202967173`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{51.298547518203875`, 11.53387941370893}, {0., 
       41.98606288126773}}]}}, 
    {Hue[0.06999999999999998], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{52.41618296796776, 15.646939195691358`}, {60., 
      15.258808523039711`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{52.41618296796776, 15.646939195691358`}, {0., 
       59.80558140664166}}]}}, 
    {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.92523180426972, 19.794243211748157`}, {60., 
      19.286502990943365`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{53.92523180426972, 19.794243211748157`}, {7.38058435125771, 
       75.}}]}}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -19.171068189440202`}, {150., 8.871357706175928}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -19.171068189440202`}, {
       53.15089604404306, -17.803331784164836`}}]}}, 
    {Hue[0.63], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -15.20648096619162}, {150., 8.510709482295933}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -15.20648096619162}, {
       51.87600747515083, -13.824081888956062`}}]}}, 
    {Hue[0.5599999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -11.334869955564942`}, {150., 8.345953090523066}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -11.334869955564942`}, {
       50.98370953473286, -10.054170421639178`}}]}}, 
    {Hue[0.48999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -7.527241808423948}, {150., 8.311669756443493}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -7.527241808423948}, {
       50.39939853319413, -6.424617402630002}}]}}, 
    {Hue[0.42], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -3.759312696702177}, {150., 8.356277519796606}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -3.759312696702177}, {
       50.080274805940874`, -2.884716754807401}}]}}, 
    {Hue[0.35], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -0.009292879215369254}, {150., 8.435794079230861}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., -0.009292879215369254}, {50.00354772074953, 
       0.6066649740846766}}]}}, 
    {Hue[0.2799999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 3.743877727348856}, {150., 8.509370006539427}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., 3.743877727348856}, {50.16122298610845, 
       4.0865554357094815`}}]}}, 
    {Hue[0.20999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 7.522192459759814}, {150., 8.535460641018767}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., 7.522192459759814}, {50.558615242206244`, 
       7.592164764129614}}]}}, 
    {Hue[0.13999999999999996`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 11.350459202967173`}, {150., 8.467755793301496}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., 11.350459202967173`}, {51.215898572441915`, 
       11.165296813309773`}}]}}, 
    {Hue[0.06999999999999998], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 15.258808523039711`}, {150., 8.249851178100531}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., 15.258808523039711`}, {52.17354284571014, 
       14.858259819538118`}}]}}, 
    {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 19.286502990943365`}, {150., 7.807006915570744}}], 
     {Arrowheads[Small], 
      ArrowBox[{{60., 19.286502990943365`}, {53.504851242997255`, 
       18.743626595040972`}}]}}, 
    {Hue[0.7], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.15089604404306, -17.803331784164836`}, {0., 
      15.636644356946643`}}]}, 
    {Hue[0.63], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{51.87600747515083, -13.824081888956062`}, {0., 
      10.022443966349101`}}]}, 
    {Hue[0.5599999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.98370953473286, -10.054170421639178`}, {
      7.105427357601002*^-15, 7.397110584516923}}]}, 
    {Hue[0.48999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.39939853319413, -6.424617402630002}, {0., 
      6.0650628523892784`}}]}, 
    {Hue[0.42], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.080274805940874`, -2.884716754807401}, {0., 
      5.375504449047547}}]}, 
    {Hue[0.35], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.00354772074953, 0.6066649740846766}, {
      7.105427357601002*^-15, 4.990817736505169}}]}, 
    {Hue[0.2799999999999999], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.16122298610845, 4.0865554357094815`}, {0., 
      4.68466612645266}}]}, 
    {Hue[0.20999999999999994`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.558615242206244`, 7.592164764129614}, {0., 
      4.255329013633993}}]}, 
    {Hue[0.13999999999999996`], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{51.215898572441915`, 11.165296813309773`}, {0., 
      3.4584879447806935`}}]}, 
    {Hue[0.06999999999999998], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{52.17354284571014, 
      14.858259819538118`}, {-7.105427357601002*^-15, 1.8998598407925709`}}]}, 
    {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.504851242997255`, 18.743626595040972`}, {
      7.105427357601002*^-15, -1.258326331242742}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJw90nlQjGEcB/C3iGi6ditdW++7siltK9mEyf5Kh+ftWq1pNkYiV1GbahLN
JlQIo5li1rVNTbVk5Ygitt6R2XFUNOIPjFzJrB1HalcjjRzv88w888z3+Tzn
PA+1QZG0yZIgiIjJ+qdVbLvYdI4bC5tTFRpt8kJm+enEwL5kGlT6mUm9efMZ
wfeYy8/uIoieXmAc4PgxKrHOtXMNgqsnOZH9Ioo5lVIn3eaOgF55Peq2ksNY
vajYXUQgUMXbyb5ZvO88ukxrH22HgF/dUeO5wAae63veDEQiWOKm/Wjo5UFm
sVtvSCOCrfqiermjL+QgfVGUmIYtvyRnl8aKYG2MYSLLREP4gU9lsofBQPwt
CTDL2uz9cF4wQ/wvuSH86hKjlGE91KlioC0jEPtq8awZTdoV2MdIX27+BQH2
uMCUO35B4dg97fuiBz28WA/b6t1/cnWCGPuoaOIgh2vHus40zDlrzuJjJw6W
8+dY7+9k5xPZuWLXuKn4/KHKXf4F322B3f957IPMGzZC7DsPd6lvunhhN7xS
y4Trl2K31hSnK1oE2F22jyUsmojEvrFr/Mi+0kDsssFamjcUj/1pQmWEHAUD
41w41FbG+9fPJP1vN4AUfVDxOyhYR3Udk1bREPPkpUDTE8Sw3qxQtRZZUVCa
IZ1CfUVw6vg1+88N87AnFud1kVdIyAvVBhmUCM60tC++7eGDvdC3UVhVQ8Jj
x1tK72AExuzyod6rbthJzSOLzFYS2t3f7IieieCdmUn7wJ2O/VBA92ZygASP
uBzIn/xvb6WG890Z7ySsv46TzOmeSsHelOyROicEARrTeK3cAd/P9lvToC+H
gmQ/+lpJDIIxr5qctFQv7P7K0UvKLyQ4DCsr604j6Fc136tdJcDOV68tNu4h
oS99qDHEhQaRnunPahNib3WRW6Ut8QaZpdCsZmiYNttSmtqxAL+H+tA9iSlK
hHOJsUKvtPFhcxh5XDy3/gQPu899z2c1Ea44qxqIsNISZzy+TN5uVJm42EMC
zDw3HQfnM562P/KtHHEePry8/WeTDZt1hRYt2U82TUjY9Riq/IE7f6TzNwbd
TC8=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731740639168*^9},
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"During evaluation of In[35]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 TurboPlot[{
\tMove[GridOfRays[{40,40},NumberOfRays->7],{0,-5},5],
\tMove[Screen[{45,45}],50]},
\tColorView -> RaySourceNumber];\
\>", "Input",
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"In[36]:="],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdABTDWYHGFAAVJxBD4e4HA5xdABX74BdXA+7
eIMZaeK4zMFpL053HsBhPnZxXOGGJA4A2s8VQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjwdGBABg1mB7CKM+jhEJfDIY7DfAY5BxzmYxdv
MCNNHJc5OO3F6c4DOMzHLo4r3IDiAH7fFUM=
       "], {{50., -22.5, -22.5}, {50., 
       22.5, -22.5}, {50., 22.5, 22.5}, {50., -22.5, 22.5}, {
       50., -22.5, -22.5}}}],
     FontColor->GrayLevel[0.]]}, 
   {Hue[0.7], AbsoluteThickness[0.5], 
    Line3DBox[{{1.7431148549531632`, -24.92389396183491, -20.}, {
     50., -20.701963574570748`, -20.}}]}, 
   {Hue[0.6854166666666666], AbsoluteThickness[0.5], 
    Line3DBox[{{1.1620765699687756`, -18.282595974556607`, -20.}, {
     50., -14.009831324281766`, -20.}}]}, 
   {Hue[0.6708333333333333], AbsoluteThickness[0.5], 
    Line3DBox[{{0.5810382849843879, -11.641297987278305`, -20.}, {
     50., -7.3176990739927845`, -20.}}]}, 
   {Hue[0.65625], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., -20.}, {50., -0.6255668237038003, -20.}}]}, 
   {Hue[0.6416666666666666], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 1.6412979872783016`, -20.}, {50., 
     6.06656542658518, -20.}}]}, 
   {Hue[0.6270833333333333], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 8.282595974556603, -20.}, {
     49.99999999999999, 12.75869767687416, -20.}}]}, 
   {Hue[0.6124999999999999], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 14.92389396183491, -20.}, {50., 
     19.45082992716315, -20.}}]}, 
   {Hue[0.5979166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{
     1.7431148549531632`, -24.92389396183491, -13.333333333333334`}, {
     50., -20.701963574570748`, -13.333333333333334`}}]}, 
   {Hue[0.5833333333333334], AbsoluteThickness[0.5], 
    Line3DBox[{{
     1.1620765699687756`, -18.282595974556607`, -13.333333333333334`}, {
     50., -14.009831324281766`, -13.333333333333334`}}]}, 
   {Hue[0.56875], AbsoluteThickness[0.5], 
    Line3DBox[{{
     0.5810382849843879, -11.641297987278305`, -13.333333333333334`}, {
     50., -7.3176990739927845`, -13.333333333333334`}}]}, 
   {Hue[0.5541666666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., -13.333333333333334`}, {
     50., -0.6255668237038003, -13.333333333333334`}}]}, 
   {Hue[0.5395833333333333], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 
     1.6412979872783016`, -13.333333333333334`}, {50., 
     6.06656542658518, -13.333333333333334`}}]}, 
   {Hue[0.5249999999999999], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 
     8.282595974556603, -13.333333333333334`}, {49.99999999999999, 
     12.75869767687416, -13.333333333333334`}}]}, 
   {Hue[0.5104166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 
     14.92389396183491, -13.333333333333334`}, {50., 
     19.45082992716315, -13.333333333333334`}}]}, 
   {Hue[0.49583333333333335`], AbsoluteThickness[0.5], 
    Line3DBox[{{
     1.7431148549531632`, -24.92389396183491, -6.666666666666668}, {
     50., -20.701963574570748`, -6.666666666666668}}]}, 
   {Hue[0.48124999999999996`], AbsoluteThickness[0.5], 
    Line3DBox[{{
     1.1620765699687756`, -18.282595974556607`, -6.666666666666668}, {
     50., -14.009831324281766`, -6.666666666666668}}]}, 
   {Hue[0.4666666666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{
     0.5810382849843879, -11.641297987278305`, -6.666666666666668}, {
     50., -7.3176990739927845`, -6.666666666666668}}]}, 
   {Hue[0.45208333333333334`], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., -6.666666666666668}, {
     50., -0.6255668237038003, -6.666666666666668}}]}, 
   {Hue[0.4375], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 
     1.6412979872783016`, -6.666666666666668}, {50., 
     6.06656542658518, -6.666666666666668}}]}, 
   {Hue[0.4229166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 
     8.282595974556603, -6.666666666666668}, {49.99999999999999, 
     12.75869767687416, -6.666666666666668}}]}, 
   {Hue[0.4083333333333333], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 
     14.92389396183491, -6.666666666666668}, {50., 
     19.45082992716315, -6.666666666666668}}]}, 
   {Hue[0.39375], AbsoluteThickness[0.5], 
    Line3DBox[{{1.7431148549531632`, -24.92389396183491, 0.}, {
     50., -20.701963574570748`, 0.}}]}, 
   {Hue[0.3791666666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{1.1620765699687756`, -18.282595974556607`, 0.}, {
     50., -14.009831324281766`, 0.}}]}, 
   {Hue[0.3645833333333333], AbsoluteThickness[0.5], 
    Line3DBox[{{0.5810382849843879, -11.641297987278305`, 0.}, {
     50., -7.3176990739927845`, 0.}}]}, 
   {Hue[0.35], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., 0.}, {50., -0.6255668237038003, 0.}}]}, 
   {Hue[0.3354166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 1.6412979872783016`, 0.}, {50., 
     6.06656542658518, 0.}}]}, 
   {Hue[0.32083333333333336`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 8.282595974556603, 0.}, {
     49.99999999999999, 12.75869767687416, 0.}}]}, 
   {Hue[0.30624999999999997`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 14.92389396183491, 0.}, {50., 
     19.45082992716315, 0.}}]}, 
   {Hue[0.2916666666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{1.7431148549531632`, -24.92389396183491, 6.666666666666664}, {
     50., -20.701963574570748`, 6.666666666666664}}]}, 
   {Hue[0.27708333333333335`], AbsoluteThickness[0.5], 
    Line3DBox[{{1.1620765699687756`, -18.282595974556607`, 
     6.666666666666664}, {50., -14.009831324281766`, 6.666666666666664}}]}, 
   {Hue[0.26249999999999996`], AbsoluteThickness[0.5], 
    Line3DBox[{{0.5810382849843879, -11.641297987278305`, 
     6.666666666666664}, {50., -7.3176990739927845`, 6.666666666666664}}]}, 
   {Hue[0.2479166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., 6.666666666666664}, {50., -0.6255668237038003, 
     6.666666666666664}}]}, 
   {Hue[0.23333333333333334`], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 1.6412979872783016`, 
     6.666666666666664}, {50., 6.06656542658518, 6.666666666666664}}]}, 
   {Hue[0.21875], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 8.282595974556603, 6.666666666666664}, {
     49.99999999999999, 12.75869767687416, 6.666666666666664}}]}, 
   {Hue[0.20416666666666672`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 14.92389396183491, 6.666666666666664}, {
     50., 19.45082992716315, 6.666666666666664}}]}, 
   {Hue[0.18958333333333335`], AbsoluteThickness[0.5], 
    Line3DBox[{{1.7431148549531632`, -24.92389396183491, 
     13.333333333333329`}, {50., -20.701963574570748`, 
     13.333333333333329`}}]}, 
   {Hue[0.175], AbsoluteThickness[0.5], 
    Line3DBox[{{1.1620765699687756`, -18.282595974556607`, 
     13.333333333333329`}, {50., -14.009831324281766`, 
     13.333333333333329`}}]}, 
   {Hue[0.1604166666666667], AbsoluteThickness[0.5], 
    Line3DBox[{{0.5810382849843879, -11.641297987278305`, 
     13.333333333333329`}, {50., -7.3176990739927845`, 
     13.333333333333329`}}]}, 
   {Hue[0.14583333333333334`], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., 13.333333333333329`}, {50., -0.6255668237038003, 
     13.333333333333329`}}]}, 
   {Hue[0.13124999999999998`], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 1.6412979872783016`, 
     13.333333333333329`}, {50., 6.06656542658518, 13.333333333333329`}}]}, 
   {Hue[0.11666666666666671`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 8.282595974556603, 
     13.333333333333329`}, {49.99999999999999, 12.75869767687416, 
     13.333333333333329`}}]}, 
   {Hue[0.10208333333333336`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 14.92389396183491, 
     13.333333333333329`}, {50., 19.45082992716315, 13.333333333333329`}}]}, 
   {Hue[0.0875], AbsoluteThickness[0.5], 
    Line3DBox[{{1.7431148549531632`, -24.92389396183491, 20.}, {
     50., -20.701963574570748`, 20.}}]}, 
   {Hue[0.07291666666666671], AbsoluteThickness[0.5], 
    Line3DBox[{{1.1620765699687756`, -18.282595974556607`, 20.}, {
     50., -14.009831324281766`, 20.}}]}, 
   {Hue[0.058333333333333355`], AbsoluteThickness[0.5], 
    Line3DBox[{{0.5810382849843879, -11.641297987278305`, 20.}, {
     50., -7.3176990739927845`, 20.}}]}, 
   {Hue[0.04375], AbsoluteThickness[0.5], 
    Line3DBox[{{0., -5., 20.}, {50., -0.6255668237038003, 20.}}]}, 
   {Hue[0.029166666666666716`], AbsoluteThickness[0.5], 
    Line3DBox[{{-0.5810382849843876, 1.6412979872783016`, 20.}, {50., 
     6.06656542658518, 20.}}]}, 
   {Hue[0.014583333333333358`], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.1620765699687752`, 8.282595974556603, 20.}, {
     49.99999999999999, 12.75869767687416, 20.}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    Line3DBox[{{-1.7431148549531632`, 14.92389396183491, 20.}, {50., 
     19.45082992716315, 20.}}], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJx1071qAkEUhuFBs5BWKxEs7HaHNBIbuykMqOVegmBhZWEqK0GLVLYpTBlI
MHZbCBYayJ0EQewEL8CfXT6G+Y4zsCzzcooHDlPtDuJeTilVu355hdM2m7/J
f5LUf7M7/m0zeht/PAZPoh+Lp338UhG99RWuPh92W+7lQ7iOmiWDfk5Py8yG
8+B1Ghme7zQK7/3hs+hw/ixuRwsndzi5w8kdTnR28jyc3OFcpr0snNzh5A4n
dzjR2cnzcHJ3947De7fd3bvt7t5td/eu1P2923l377bD+Z35DTu5w8kdTu5w
orOT5+Hk7jq1x6k9Tu1xao9Te5za49TCmd3rwsmd3rtwcqf3Lpw8T+/dXABe
O39a
      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.61473174094108*^9},
 CellTags->{"ColorView", "PR6.5"},
 CellLabel->"During evaluation of In[36]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.6 RayChoice", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.6", "RayChoice", "PR6.6"}],

Cell[TextData[{
 StyleBox["In many cases it is desirable to follow a group of rays through an \
optical system. You can use the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayChoice", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" option to selectively display a particular group of rays.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"RayChoice", "PR6.6"}],

Cell[CellGroupData[{

Cell["?RayChoice", "Input",
 CellTags->{"RayChoice", "PR6.6"},
 CellLabel->"In[37]:="],

Cell[BoxData[
 StyleBox["\<\"RayChoice -> selectionproperties that is used to selectively \
display ray segments in DrawSystem/AnalyzeSystem and ShowSystem. \\n\\nA \
typical option value of RayChoice would be RayChoice -> {ComponentNumber -> \
1, ConfinedPosition -> 2}. See RaySelect about how selectionproperties can be \
structured.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6147317411715183`*^9},
 CellTags->{"Info3614713740-8131145", "PR6.6", "RayChoice"}]
}, Open  ]],

Cell[TextData[{
 StyleBox["\n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["RayChoice -> selectionproperties", "Input"],
 " is used to selectively display ray segments in ",
 StyleBox["DrawSystem/AnalyzeSystem", "Input"],
 ", ",
 StyleBox["TurboPlot", "Input"],
 ",  and ",
 StyleBox["ShowSystem", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"RayChoice", "PR6.6"}],

Cell[TextData[{
 "A typical option value of ",
 StyleBox["RayChoice", "Input"],
 " would be ",
 StyleBox["RayChoice -> {ComponentNumber -> 1, SurfaceNumber -> 1}", 
  "Input"],
 "."
}], "Text",
 CellTags->{"RayChoice", "PR6.6"}],

Cell[CellGroupData[{

Cell[TextData[{
 "ill = AnalyzeSystem[{\n\tConeOfRays[10,NumberOfRays->20],\n\t\
Move[BiConvexLens[50,50,20],90,1],\n\tMove[ThinBaffle[2],{197,0,0}]}, \
RayChoice->",
 StyleBox["{ComponentNumber -> 1, SurfaceNumber -> 1}", "Input"],
 ", PlotType->TopView];"
}], "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"In[38]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{97.42621376635236, -24.874183157635187`}, {
      103.44336045863966`, -24.769153471438706`}, {
      107.31480480692527`, -16.366974425274172`}, {
      93.26389597744534, -16.612233951193208`}, {
      97.42621376635236, -24.874183157635187`}}], 
     PolygonBox[{{93.26389597744534, -16.612233951193208`}, {
      107.31480480692527`, -16.366974425274172`}, {
      109.41659696886857`, -7.9956847729226}, {
      90.87123037488065, -8.319395350938256}, {
      93.26389597744534, -16.612233951193208`}}], 
     PolygonBox[{{90.87123037488065, -8.319395350938256}, {
      109.41659696886857`, -7.9956847729226}, {109.99695390312783`, 
      0.34904812874566316`}, {90., 0.}, {
      90.87123037488065, -8.319395350938256}}], 
     PolygonBox[{{90., 0.}, {109.99695390312783`, 0.34904812874567026`}, {
      109.12572352824718`, 8.668443479683923}, {90.58035693425926, 
      8.344732901668264}, {90., 0.}}], 
     PolygonBox[{{90.58035693425926, 8.344732901668264}, {109.12572352824718`,
       8.668443479683923}, {106.73305792568249`, 16.961282079938876`}, {
      92.68214909620255, 16.716022554019837`}, {90.58035693425926, 
      8.344732901668264}}], 
     PolygonBox[{{92.68214909620255, 16.716022554019837`}, {
      106.73305792568249`, 16.961282079938876`}, {102.5707401367755, 
      25.223231286380855`}, {96.55359344448816, 25.11820160018437}, {
      92.68214909620255, 16.716022554019837`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       93.26389597744534, -16.612233951193208`}, {
       90.87123037488065, -8.319395350938256}, {
       90., -3.552713678800501*^-15}, {90.58035693425926, 
       8.344732901668264}, {92.68214909620255, 16.71602255401983}, {
       96.55359344448816, 25.11820160018437}, {102.57074013677548`, 
       25.22323128638086}, {106.73305792568249`, 16.96128207993888}, {
       109.12572352824718`, 8.668443479683926}, {109.99695390312783`, 
       0.3490481287456738}, {109.41659696886857`, -7.995684772922593}, {
       107.31480480692528`, -16.366974425274158`}, {
       103.44336045863966`, -24.7691534714387}, {
       97.42621376635236, -24.874183157635187`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{96.98990360542027, 0.1220092212745929}, {
        103.00705029770756`, 0.2270389074710804}, {107.02393136630388`, 
        0.2971538273323565}, {92.97302253682395, 0.05189430141331686}, {
        96.98990360542027, 0.1220092212745929}}], 
       PolygonBox[{{92.97302253682395, 0.05189430141331686}, {
        107.02393136630388`, 0.2971538273323565}, {109.27116024855788`, 
        0.3363793533806653}, {90.72579365456996, 0.01266877536500799}, {
        92.97302253682395, 0.05189430141331686}}], 
       PolygonBox[{{90.72579365456996, 0.01266877536500799}, {
        109.27116024855788`, 0.3363793533806653}, {109.99695390312783`, 
        0.3490481287456718}, {90., 1.5543122344752192`*^-15}, {
        90.72579365456996, 0.01266877536500799}}], 
       PolygonBox[{{90., 1.5543122344752192`*^-15}, {109.99695390312783`, 
        0.3490481287456718}, {109.27116024855788`, 0.33637935338066427`}, {
        90.72579365456996, 0.012668775365008988`}, {90., 
        1.5543122344752192`*^-15}}], 
       PolygonBox[{{90.72579365456996, 0.012668775365008988`}, {
        109.27116024855788`, 0.33637935338066427`}, {107.02393136630388`, 
        0.29715382733235446`}, {92.97302253682395, 0.051894301413318855`}, {
        90.72579365456996, 0.012668775365008988`}}], 
       PolygonBox[{{92.97302253682395, 0.051894301413318855`}, {
        107.02393136630388`, 0.29715382733235446`}, {103.00705029770758`, 
        0.22703890747107747`}, {96.98990360542025, 0.1220092212745959}, {
        92.97302253682395, 0.051894301413318855`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{96.98990360542027, 0.1220092212745929}, {92.97302253682395, 
         0.0518943014133163}, {90.72579365456996, 0.01266877536500699}, {90., 
         0.}, {90.72579365456996, 0.01266877536500699}, {92.97302253682395, 
         0.05189430141331619}, {96.98990360542025, 0.1220092212745928}, {
         103.00705029770756`, 0.22703890747107736`}, {107.02393136630388`, 
         0.29715382733235396`}, {109.27116024855788`, 0.33637935338066327`}, {
         109.99695390312783`, 0.34904812874567026`}, {109.27116024855788`, 
         0.33637935338066327`}, {107.02393136630388`, 0.29715382733235407`}, {
         103.00705029770758`, 0.22703890747107747`}, {96.98990360542027, 
         0.1220092212745929}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{96.55359344448817, 25.118201600184378`}, {102.57074013677548`,
        25.22323128638086}, {102.58560704499094`, 24.371506685150017`}, {
       96.56846035270361, 24.266476998953536`}, {96.55359344448817, 
       25.118201600184378`}}], 
      LineBox[{{96.56846035270361, 24.266476998953536`}, {102.58560704499094`,
        24.371506685150017`}, {102.6291946144111, 21.87437650548993}, {
       96.61204792212379, 21.76934681929345}, {96.56846035270361, 
       24.266476998953536`}}], 
      LineBox[{{96.61204792212379, 21.76934681929345}, {102.6291946144111, 
       21.87437650548993}, {102.69853242421189`, 17.902016042441684`}, {
       96.68138573192459, 17.796986356245203`}, {96.61204792212379, 
       21.76934681929345}}], 
      LineBox[{{96.68138573192459, 17.796986356245203`}, {102.69853242421189`,
        17.902016042441684`}, {102.78889521724153`, 12.725135096925971`}, {
       96.77174852495423, 12.620105410729488`}, {96.68138573192459, 
       17.796986356245203`}}], 
      LineBox[{{96.77174852495423, 12.620105410729488`}, {102.78889521724153`,
        12.725135096925971`}, {102.8941249184866, 6.696529550179418}, {
       96.8769782261993, 6.591499863982934}, {96.77174852495423, 
       12.620105410729488`}}], 
      LineBox[{{96.8769782261993, 6.591499863982934}, {102.8941249184866, 
       6.696529550179418}, {103.00705029770756`, 0.22703890747108446`}, {
       96.98990360542027, 0.12200922127460001`}, {96.8769782261993, 
       6.591499863982934}}], 
      LineBox[{{96.98990360542027, 0.12200922127459446`}, {
       103.00705029770756`, 0.2270389074710789}, {
       103.11997567692853`, -6.242451735237256}, {
       97.10282898464123, -6.3474814214337405`}, {96.98990360542027, 
       0.12200922127459446`}}], 
      LineBox[{{97.10282898464123, -6.3474814214337405`}, {
       103.11997567692853`, -6.242451735237256}, {
       103.22520537817361`, -12.27105728198381}, {
       97.2080586858863, -12.376086968180292`}, {
       97.10282898464123, -6.3474814214337405`}}], 
      LineBox[{{97.2080586858863, -12.376086968180292`}, {
       103.22520537817361`, -12.27105728198381}, {
       103.31556817120324`, -17.447938227499527`}, {
       97.29842147891594, -17.55296791369601}, {
       97.2080586858863, -12.376086968180292`}}], 
      LineBox[{{97.29842147891594, -17.55296791369601}, {
       103.31556817120324`, -17.447938227499527`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871674, -21.52532837674426}, {
       97.29842147891594, -17.55296791369601}}], 
      LineBox[{{97.36775928871674, -21.525328376744252`}, {
       103.38490598100404`, -21.42029869054777}, {
       103.42849355042421`, -23.917428870207864`}, {
       97.41134685813691, -24.022458556404345`}, {
       97.36775928871674, -21.525328376744252`}}], 
      LineBox[{{97.41134685813691, -24.022458556404345`}, {
       103.42849355042421`, -23.917428870207864`}, {
       103.44336045863966`, -24.769153471438706`}, {
       97.42621376635236, -24.874183157635187`}, {
       97.41134685813691, -24.022458556404345`}}], 
      LineBox[{{97.42621376635236, -24.874183157635187`}, {
       103.44336045863966`, -24.769153471438706`}, {
       103.42849355042422`, -23.917428870207864`}, {
       97.4113468581369, -24.022458556404345`}, {
       97.42621376635236, -24.874183157635187`}}], 
      LineBox[{{97.41134685813691, -24.02245855640435}, {
       103.42849355042421`, -23.917428870207868`}, {
       103.38490598100404`, -21.420298690547778`}, {
       97.36775928871673, -21.52532837674426}, {
       97.41134685813691, -24.02245855640435}}], 
      LineBox[{{97.36775928871673, -21.52532837674426}, {
       103.38490598100404`, -21.420298690547778`}, {
       103.31556817120324`, -17.447938227499534`}, {
       97.29842147891594, -17.552967913696016`}, {
       97.36775928871673, -21.52532837674426}}], 
      LineBox[{{97.29842147891594, -17.55296791369602}, {
       103.31556817120324`, -17.447938227499538`}, {
       103.22520537817363`, -12.271057281983826`}, {
       97.2080586858863, -12.376086968180308`}, {
       97.29842147891594, -17.55296791369602}}], 
      LineBox[{{97.2080586858863, -12.376086968180308`}, {
       103.22520537817363`, -12.271057281983826`}, {
       103.11997567692853`, -6.242451735237278}, {
       97.10282898464123, -6.347481421433763}, {
       97.2080586858863, -12.376086968180308`}}], 
      LineBox[{{97.10282898464123, -6.347481421433763}, {
       103.11997567692853`, -6.242451735237278}, {103.00705029770756`, 
       0.22703890747105054`}, {96.98990360542027, 0.12200922127456615`}, {
       97.10282898464123, -6.347481421433763}}], 
      LineBox[{{96.98990360542027, 0.12200922127458835`}, {
       103.00705029770756`, 0.22703890747107275`}, {102.8941249184866, 
       6.6965295501794015`}, {96.8769782261993, 6.591499863982917}, {
       96.98990360542027, 0.12200922127458835`}}], 
      LineBox[{{96.8769782261993, 6.591499863982917}, {102.8941249184866, 
       6.6965295501794015`}, {102.78889521724153`, 12.725135096925952`}, {
       96.77174852495423, 12.620105410729469`}, {96.8769782261993, 
       6.591499863982917}}], 
      LineBox[{{96.77174852495423, 12.620105410729469`}, {102.78889521724153`,
        12.725135096925952`}, {102.69853242421189`, 17.902016042441666`}, {
       96.68138573192459, 17.796986356245185`}, {96.77174852495423, 
       12.620105410729469`}}], 
      LineBox[{{96.68138573192459, 17.7969863562452}, {102.69853242421189`, 
       17.90201604244168}, {102.62919461441112`, 21.87437650548992}, {
       96.61204792212378, 21.76934681929344}, {96.68138573192459, 
       17.7969863562452}}], 
      LineBox[{{96.61204792212378, 21.76934681929344}, {102.62919461441112`, 
       21.87437650548992}, {102.58560704499092`, 24.371506685150013`}, {
       96.56846035270362, 24.266476998953532`}, {96.61204792212378, 
       21.76934681929344}}], 
      LineBox[{{96.56846035270362, 24.266476998953532`}, {102.58560704499092`,
        24.371506685150013`}, {102.57074013677548`, 25.22323128638086}, {
       96.55359344448817, 25.118201600184378`}, {96.56846035270362, 
       24.266476998953532`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{197., 0.}, {197., 0.3333333333333333}, {197., 
      0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3333333333333333}, {197., 0.6666666666666666}, {
      197., 0.6439505508593788}, {197., 0.3219752754296894}, {197., 
      0.3333333333333333}}], 
     PolygonBox[{{197., 0.6666666666666666}, {197., 1.}, {197., 
      0.9659258262890683}, {197., 0.6439505508593788}, {197., 
      0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., 0.3219752754296894}, {197., 
      0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.3219752754296894}, {197., 0.6439505508593788}, {
      197., 0.5773502691896257}, {197., 0.28867513459481287`}, {197., 
      0.3219752754296894}}], 
     PolygonBox[{{197., 0.6439505508593788}, {197., 0.9659258262890683}, {
      197., 0.8660254037844387}, {197., 0.5773502691896257}, {197., 
      0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481287`}, {197., 
      0.23570226039551584`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481287`}, {197., 0.5773502691896257}, {
      197., 0.4714045207910317}, {197., 0.23570226039551584`}, {197., 
      0.28867513459481287`}}], 
     PolygonBox[{{197., 0.5773502691896257}, {197., 0.8660254037844387}, {
      197., 0.7071067811865476}, {197., 0.4714045207910317}, {197., 
      0.5773502691896257}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551584`}, {197., 
      0.16666666666666669`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551584`}, {197., 0.4714045207910317}, {
      197., 0.33333333333333337`}, {197., 0.16666666666666669`}, {197., 
      0.23570226039551584`}}], 
     PolygonBox[{{197., 0.4714045207910317}, {197., 0.7071067811865476}, {
      197., 0.5000000000000001}, {197., 0.33333333333333337`}, {197., 
      0.4714045207910317}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666669`}, {197., 
      0.08627301503417364}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666669`}, {197., 0.33333333333333337`}, {
      197., 0.1725460300683473}, {197., 0.08627301503417364}, {197., 
      0.16666666666666669`}}], 
     PolygonBox[{{197., 0.33333333333333337`}, {197., 0.5000000000000001}, {
      197., 0.25881904510252096`}, {197., 0.1725460300683473}, {197., 
      0.33333333333333337`}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417364}, {197., 
      9.442564829413299*^-17}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417364}, {197., 0.1725460300683473}, {
      197., 1.8885129658826599`*^-16}, {197., 9.442564829413299*^-17}, {197., 
      0.08627301503417364}}], 
     PolygonBox[{{197., 0.1725460300683473}, {197., 0.25881904510252096`}, {
      197., 2.83276944882399*^-16}, {197., 1.8885129658826599`*^-16}, {197., 
      0.1725460300683473}}], 
     PolygonBox[{{197., 0.}, {197., 2.041077998578922*^-17}, {
      197., -0.08627301503417353}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 2.041077998578922*^-17}, {197., 
      4.082155997157844*^-17}, {197., -0.17254603006834707`}, {
      197., -0.08627301503417353}, {197., 2.041077998578922*^-17}}], 
     PolygonBox[{{197., 4.082155997157844*^-17}, {197., 
      6.123233995736766*^-17}, {197., -0.25881904510252063`}, {
      197., -0.17254603006834707`}, {197., 4.082155997157844*^-17}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417353}, {
      197., -0.16666666666666657`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417353}, {
      197., -0.17254603006834707`}, {197., -0.33333333333333315`}, {
      197., -0.16666666666666657`}, {197., -0.08627301503417353}}], 
     PolygonBox[{{197., -0.17254603006834707`}, {
      197., -0.25881904510252063`}, {197., -0.4999999999999998}, {
      197., -0.33333333333333315`}, {197., -0.17254603006834707`}}], 
     PolygonBox[{{197., 0.}, {197., -0.16666666666666657`}, {
      197., -0.2357022603955158}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.16666666666666657`}, {
      197., -0.33333333333333315`}, {197., -0.4714045207910316}, {
      197., -0.2357022603955158}, {197., -0.16666666666666657`}}], 
     PolygonBox[{{197., -0.33333333333333315`}, {197., -0.4999999999999998}, {
      197., -0.7071067811865475}, {197., -0.4714045207910316}, {
      197., -0.33333333333333315`}}], 
     PolygonBox[{{197., 0.}, {197., -0.2357022603955158}, {
      197., -0.28867513459481287`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2357022603955158}, {197., -0.4714045207910316}, {
      197., -0.5773502691896257}, {197., -0.28867513459481287`}, {
      197., -0.2357022603955158}}], 
     PolygonBox[{{197., -0.4714045207910316}, {197., -0.7071067811865475}, {
      197., -0.8660254037844387}, {197., -0.5773502691896257}, {
      197., -0.4714045207910316}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948128}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948128}, {197., -0.5773502691896256}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.2886751345948128}}], 
     PolygonBox[{{197., -0.5773502691896256}, {197., -0.8660254037844385}, {
      197., -0.9659258262890682}, {197., -0.6439505508593788}, {
      197., -0.5773502691896256}}], 
     PolygonBox[{{197., 0.}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3219752754296894}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}}], 
     PolygonBox[{{197., -0.6439505508593788}, {197., -0.9659258262890682}, {
      197., -1.}, {197., -0.6666666666666666}, {197., -0.6439505508593788}}], 
     PolygonBox[{{197., 0.}, {197., -0.3333333333333333}, {
      197., -0.3219752754296894}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.3333333333333333}, {197., -0.6666666666666666}, {
      197., -0.6439505508593788}, {197., -0.3219752754296894}, {
      197., -0.3333333333333333}}], 
     PolygonBox[{{197., -0.6666666666666666}, {197., -1.}, {
      197., -0.9659258262890683}, {197., -0.6439505508593788}, {
      197., -0.6666666666666666}}], 
     PolygonBox[{{197., 0.}, {197., -0.32197527542968946`}, {
      197., -0.2886751345948129}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.32197527542968946`}, {197., -0.6439505508593789}, {
      197., -0.5773502691896258}, {197., -0.2886751345948129}, {
      197., -0.32197527542968946`}}], 
     PolygonBox[{{197., -0.6439505508593789}, {197., -0.9659258262890684}, {
      197., -0.8660254037844388}, {197., -0.5773502691896258}, {
      197., -0.6439505508593789}}], 
     PolygonBox[{{197., 0.}, {197., -0.2886751345948129}, {
      197., -0.2357022603955159}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.2886751345948129}, {197., -0.5773502691896258}, {
      197., -0.4714045207910318}, {197., -0.2357022603955159}, {
      197., -0.2886751345948129}}], 
     PolygonBox[{{197., -0.5773502691896258}, {197., -0.8660254037844388}, {
      197., -0.7071067811865477}, {197., -0.4714045207910318}, {
      197., -0.5773502691896258}}], 
     PolygonBox[{{197., 0.}, {197., -0.23570226039551595`}, {
      197., -0.1666666666666668}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.23570226039551595`}, {197., -0.4714045207910319}, {
      197., -0.3333333333333336}, {197., -0.1666666666666668}, {
      197., -0.23570226039551595`}}], 
     PolygonBox[{{197., -0.4714045207910319}, {197., -0.7071067811865479}, {
      197., -0.5000000000000004}, {197., -0.3333333333333336}, {
      197., -0.4714045207910319}}], 
     PolygonBox[{{197., 0.}, {197., -0.1666666666666668}, {
      197., -0.08627301503417384}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.1666666666666668}, {197., -0.3333333333333336}, {
      197., -0.17254603006834768`}, {197., -0.08627301503417384}, {
      197., -0.1666666666666668}}], 
     PolygonBox[{{197., -0.3333333333333336}, {197., -0.5000000000000004}, {
      197., -0.2588190451025215}, {197., -0.17254603006834768`}, {
      197., -0.3333333333333336}}], 
     PolygonBox[{{197., 0.}, {197., -0.08627301503417384}, {
      197., -3.572918131907427*^-16}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -0.08627301503417384}, {
      197., -0.17254603006834768`}, {197., -7.145836263814854*^-16}, {
      197., -3.572918131907427*^-16}, {197., -0.08627301503417384}}], 
     PolygonBox[{{197., -0.17254603006834768`}, {197., -0.2588190451025215}, {
      197., -1.0718754395722282`*^-15}, {197., -7.145836263814854*^-16}, {
      197., -0.17254603006834768`}}], 
     PolygonBox[{{197., 0.}, {197., -6.123233995736765*^-17}, {197., 
      0.08627301503417342}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., -6.123233995736765*^-17}, {
      197., -1.224646799147353*^-16}, {197., 0.17254603006834685`}, {197., 
      0.08627301503417342}, {197., -6.123233995736765*^-17}}], 
     PolygonBox[{{197., -1.224646799147353*^-16}, {
      197., -1.8369701987210297`*^-16}, {197., 0.2588190451025203}, {197., 
      0.17254603006834685`}, {197., -1.224646799147353*^-16}}], 
     PolygonBox[{{197., 0.}, {197., 0.08627301503417342}, {197., 
      0.16666666666666644`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.08627301503417342}, {197., 0.17254603006834685`}, {
      197., 0.33333333333333287`}, {197., 0.16666666666666644`}, {197., 
      0.08627301503417342}}], 
     PolygonBox[{{197., 0.17254603006834685`}, {197., 0.2588190451025203}, {
      197., 0.49999999999999933`}, {197., 0.33333333333333287`}, {197., 
      0.17254603006834685`}}], 
     PolygonBox[{{197., 0.}, {197., 0.16666666666666644`}, {197., 
      0.2357022603955156}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.16666666666666644`}, {197., 0.33333333333333287`}, {
      197., 0.4714045207910312}, {197., 0.2357022603955156}, {197., 
      0.16666666666666644`}}], 
     PolygonBox[{{197., 0.33333333333333287`}, {197., 0.49999999999999933`}, {
      197., 0.7071067811865468}, {197., 0.4714045207910312}, {197., 
      0.33333333333333287`}}], 
     PolygonBox[{{197., 0.}, {197., 0.23570226039551578`}, {197., 
      0.28867513459481275`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.23570226039551578`}, {197., 0.47140452079103157`}, {
      197., 0.5773502691896255}, {197., 0.28867513459481275`}, {197., 
      0.23570226039551578`}}], 
     PolygonBox[{{197., 0.47140452079103157`}, {197., 0.7071067811865474}, {
      197., 0.8660254037844384}, {197., 0.5773502691896255}, {197., 
      0.47140452079103157`}}], 
     PolygonBox[{{197., 0.}, {197., 0.28867513459481275`}, {197., 
      0.32197527542968934`}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.28867513459481275`}, {197., 0.5773502691896255}, {
      197., 0.6439505508593787}, {197., 0.32197527542968934`}, {197., 
      0.28867513459481275`}}], 
     PolygonBox[{{197., 0.5773502691896255}, {197., 0.8660254037844384}, {
      197., 0.9659258262890681}, {197., 0.6439505508593787}, {197., 
      0.5773502691896255}}], 
     PolygonBox[{{197., 0.}, {197., 0.32197527542968934`}, {197., 
      0.3333333333333333}, {197., 0.}, {197., 0.}}], 
     PolygonBox[{{197., 0.32197527542968934`}, {197., 0.6439505508593787}, {
      197., 0.6666666666666666}, {197., 0.3333333333333333}, {197., 
      0.32197527542968934`}}], 
     PolygonBox[{{197., 0.6439505508593787}, {197., 0.9659258262890681}, {
      197., 1.}, {197., 0.6666666666666666}, {197., 0.6439505508593787}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYLMhwgjA/2ML7ofg/3uy/ewfmrfSJeVG17Deef
ta5Pm7fgGZzPCGY8gPOnsE0+WDvhApzPHiNirLZsog2M3weR3w/j//kPAvfh
/DMQ8+H8lRD74XwRiPvgfKj74XwxNPk1aPovoJnPAnE/nD8PzX1cXfN8LCtX
7YHxO9D89wXifjj/NFr4rEALP2G08IWFPwABtIYM
       "]]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {90.80009348181466, -7.943978826752928}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.77288879312717, -6.4333356875055925`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434345`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.65721119927778, -5.655198531684391*^-16}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958244`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959733}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.54211377326678, 6.41697999814953}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5152130159867, 7.9190550155329955`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5220936404668, 7.534774616794779}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.54211377326678, 6.4169799981495315`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.5734322977125, 4.669319404959736}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.61308582705088, 2.4582281193958266`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.65721119927778, 1.654926196081874*^-15}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.7014215775235, -2.4606245660434336`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.74129707055698, -4.677973313963376}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.77288879312717, -6.433335687505591}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {90.79312901185494, -7.557334749403953}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQfaDDa7fJ5jCHwyJbkhYdkz/gcFt/waFNYQ4ipc++
brWSO+Ba3cdUvjHM4bLUjsg9uyUP5KxyySxcH+Zgp/Rmkd02oQOs3CHiT9YA
+Qrb30WvZz6w6G7/fv5VYQ4MIJBwZM9xk7AzNsvDHKR9xRuLVzE7+Homym5e
EuYQ0/paIGmtkIPYzu9/Ny4Kc9jY++fsn1WSDl4XCn9nLgxzcCpl/zpbWc5h
dwezw88FYQ5tB7kPyayVx5CH6d8M1Q8zPx5qPsx+Baj9KO67cNcG5n4bqPvR
/Qfz/0Wo/9HDBwCDEpCs
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {100.50912757553334`, -29.080630589559114`}, \
{0., 0.}], InsetBox["\<\"B\"\>", {197., -5.259611034414593}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.61473174184181*^9},
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"During evaluation of In[38]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ill, PlotType->Surface, RayChoice->{ComponentNumber->2}];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"In[39]:="],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{0.1136817787951303, 0}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.12400849836319239`, -0.07138916797736528}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.1544760906390108, -0.137252602658263}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.20338283108796773`, -0.19199041473032974`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.26745459900226276`, -0.23013156735063856`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.34152645204915943`, -0.24694893578754318`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.4186157623140434, -0.23938011994015174`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.4905667114836554, -0.20692661710588567`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.5491716105006761, -0.15215400858213624`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.5874521738586775, -0.08058141827709564}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{0.6007554299801914, 0}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.5874521738586775, 0.08058141827709653}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.5491716105006752, 0.15215400858213624`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.4905667114836545, 0.20692661710588478`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.4186157623140434, 0.23938011994015174`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.34152645204915744`, 0.24694893578754318`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.26745459900226365`, 0.23013156735063856`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.2033828310879704, 0.19199041473032974`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.1544760906390108, 0.1372526026582639}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.12400849836319239`, 0.07138916797736528}], 
     {RGBColor[0, 0, 0], Thickness[
       NCache[
        Rational[1, 5000], 0.0002]], LineBox[CompressedData["
1:eJxdUr1qgkEQPETSCDbWgqJNMPiVFhK28QFEU4lYBKKVWIllirxCIIUglr7F
NGIlWFibQoMgiFqkNxF3BOfg447bb35udrOvvdpbLITw+P9d9us6GU/Nn+gz
Pzxavz7pJB6mdn6ppJK9g1V3Uek4W1r36Tmd+dhb+K4UismVTX6/hoPNzlqN
fjy3WNu8/N4ejbe3nff8jzjykJc61KWPcLdOrIN1x4N45wf5XR/Ud1+gP78H
fToO9Om8oE/XBX26L0h+rEPwEH6IPsQfxD/kfZD3Q/KB5AfJF5I/pD+Q/kH6
C+k/ZD4g8wOZL+j8/QH6RCHB
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731742105566*^9},
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"During evaluation of In[39]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "TurboPlot[{\n\tConeOfRays[10,NumberOfRays->20],\n\t\
Move[BiConvexLens[50,50,20],90,1],\n\tMove[ThinBaffle[2],{197,0,0}]}, \
RayChoice->",
 StyleBox["{IntersectionNumber -> 3}", "Input"],
 ", PlotType->TopView];"
}], "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"In[40]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYC4mVPpcTcoyMcrhxcUX7qvsWBmT3dLAl3Ih2U
8t/aPj9icaB9Ov9h1StRDnGsxpyfYg0OyGl/Wf04INxB94Ft7O45BgfQ9aPL
o+s/ZxnatjIq2mG+P/OpKb/lD1jf5LY9tD3MIbtn6sn2xQoY+tHl0fXnJe8T
P1cf7fAsOOfb2bBr9gwg0BDmwAAF6PrR5WH600Ig+o26Nt3i9oh24HnvYWkX
pugwXzNzosrSMId8rq1XGjYoOKDrR5dH1+9vcSr71booh7qJ4lPFvhk4PDu9
LmSFdrjDum08jr7bDTDMR5dH13+8djFj+5JIB9XipvWqlpYOl68ZCecpRzgU
KRwvdZKzxNBve2/ZlCj7CIcAf33+/9b77Q1axZuLD0Q6TGJ0TJ3Df9b+9fMc
8Y6DUQ5hLRNrJrJctm+qDmRwswt3cGi6du7xxFX26PrR5dH1Mzxq3hAVGO0g
WFLiYtt+1T630Sq9eF2YQ4PgHzuxT50Y+tHl0fXD4qcpBFv83rHB0I8mj6Ef
av6/YlT3HRDGrh9DHk0/zP+GaOGX0IzqP5h+dHl0/bD4UYHGjw00/DUCUMMf
ph8ACFCNVg==
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{97.42621376635233, -24.874183157635187`}, {
       93.26389597744534, -16.612233951193208`}, {
       90.87123037488065, -8.319395350938256}, {
       90., -3.552713678800501*^-15}, {90.58035693425926, 
       8.344732901668264}, {92.68214909620255, 16.71602255401983}, {
       96.55359344448816, 25.11820160018437}, {102.57074013677548`, 
       25.22323128638086}, {106.73305792568247`, 16.96128207993888}, {
       109.12572352824716`, 8.668443479683926}, {109.99695390312783`, 
       0.3490481287456738}, {109.41659696886856`, -7.995684772922593}, {
       107.31480480692527`, -16.366974425274158`}, {
       103.44336045863965`, -24.7691534714387}, {
       97.42621376635233, -24.874183157635187`}}, {{96.98990360542025, 
       0.1220092212745929}, {92.97302253682395, 0.0518943014133163}, {
       90.72579365456996, 0.012668775365007101`}, {90., 0.}, {
       90.72579365456996, 0.012668775365007101`}, {92.97302253682395, 
       0.0518943014133163}, {96.98990360542024, 0.1220092212745928}, {
       103.00705029770756`, 0.22703890747107736`}, {107.02393136630387`, 
       0.29715382733235396`}, {109.27116024855786`, 0.33637935338066316`}, {
       109.99695390312783`, 0.34904812874567026`}, {109.27116024855786`, 
       0.33637935338066316`}, {107.02393136630387`, 0.29715382733235396`}, {
       103.00705029770756`, 0.22703890747107747`}, {96.98990360542025, 
       0.1220092212745929}}, {{96.55359344448817, 25.118201600184378`}, {
       102.57074013677548`, 25.22323128638086}, {102.58560704499092`, 
       24.371506685150017`}, {96.56846035270361, 24.266476998953536`}, {
       96.55359344448817, 25.118201600184378`}}, {{96.56846035270361, 
       24.266476998953536`}, {102.58560704499092`, 24.371506685150017`}, {
       102.6291946144111, 21.87437650548993}, {96.61204792212379, 
       21.76934681929345}, {96.56846035270361, 24.266476998953536`}}, {{
       96.61204792212379, 21.76934681929345}, {102.6291946144111, 
       21.87437650548993}, {102.69853242421189`, 17.902016042441684`}, {
       96.68138573192458, 17.796986356245203`}, {96.61204792212379, 
       21.76934681929345}}, {{96.68138573192458, 17.796986356245203`}, {
       102.69853242421189`, 17.902016042441684`}, {102.78889521724152`, 
       12.725135096925971`}, {96.7717485249542, 12.620105410729487`}, {
       96.68138573192458, 17.796986356245203`}}, {{96.7717485249542, 
       12.620105410729487`}, {102.78889521724152`, 12.725135096925971`}, {
       102.8941249184866, 6.696529550179418}, {96.87697822619928, 
       6.591499863982934}, {96.7717485249542, 12.620105410729487`}}, {{
       96.87697822619928, 6.591499863982934}, {102.8941249184866, 
       6.696529550179418}, {103.00705029770756`, 0.22703890747108446`}, {
       96.98990360542025, 0.12200922127460001`}, {96.87697822619928, 
       6.591499863982934}}, {{96.98990360542025, 0.12200922127459446`}, {
       103.00705029770756`, 0.2270389074710789}, {
       103.11997567692853`, -6.242451735237256}, {
       97.10282898464122, -6.3474814214337405`}, {96.98990360542025, 
       0.12200922127459446`}}, {{97.10282898464122, -6.3474814214337405`}, {
       103.11997567692853`, -6.242451735237256}, {
       103.22520537817361`, -12.271057281983808`}, {
       97.2080586858863, -12.376086968180292`}, {
       97.10282898464122, -6.3474814214337405`}}, {{
       97.2080586858863, -12.376086968180292`}, {
       103.22520537817361`, -12.271057281983808`}, {
       103.31556817120324`, -17.447938227499527`}, {
       97.29842147891593, -17.55296791369601}, {
       97.2080586858863, -12.376086968180292`}}, {{
       97.29842147891593, -17.55296791369601}, {
       103.31556817120324`, -17.447938227499527`}, {
       103.38490598100402`, -21.420298690547778`}, {
       97.36775928871671, -21.52532837674426}, {
       97.29842147891593, -17.55296791369601}}, {{
       97.36775928871671, -21.525328376744252`}, {
       103.38490598100402`, -21.42029869054777}, {
       103.42849355042421`, -23.917428870207864`}, {
       97.4113468581369, -24.022458556404345`}, {
       97.36775928871671, -21.525328376744252`}}, {{
       97.4113468581369, -24.022458556404345`}, {
       103.42849355042421`, -23.917428870207864`}, {
       103.44336045863965`, -24.769153471438706`}, {
       97.42621376635233, -24.874183157635187`}, {
       97.4113468581369, -24.022458556404345`}}, {{
       97.42621376635233, -24.874183157635187`}, {
       103.44336045863965`, -24.769153471438706`}, {
       103.42849355042421`, -23.917428870207864`}, {
       97.4113468581369, -24.022458556404345`}, {
       97.42621376635233, -24.874183157635187`}}, {{
       97.4113468581369, -24.02245855640435}, {
       103.42849355042421`, -23.917428870207868`}, {
       103.38490598100402`, -21.420298690547778`}, {
       97.36775928871671, -21.52532837674426}, {
       97.4113468581369, -24.02245855640435}}, {{
       97.36775928871671, -21.52532837674426}, {
       103.38490598100402`, -21.420298690547778`}, {
       103.31556817120324`, -17.447938227499534`}, {
       97.29842147891593, -17.552967913696016`}, {
       97.36775928871671, -21.52532837674426}}, {{
       97.29842147891593, -17.55296791369602}, {
       103.31556817120324`, -17.447938227499538`}, {
       103.22520537817361`, -12.271057281983826`}, {
       97.2080586858863, -12.37608696818031}, {
       97.29842147891593, -17.55296791369602}}, {{
       97.2080586858863, -12.37608696818031}, {
       103.22520537817361`, -12.271057281983826`}, {
       103.11997567692853`, -6.242451735237278}, {
       97.10282898464122, -6.347481421433763}, {
       97.2080586858863, -12.37608696818031}}, {{
       97.10282898464122, -6.347481421433763}, {
       103.11997567692853`, -6.242451735237278}, {103.00705029770756`, 
       0.22703890747105054`}, {96.98990360542025, 0.12200922127456615`}, {
       97.10282898464122, -6.347481421433763}}, {{96.98990360542025, 
       0.12200922127458835`}, {103.00705029770756`, 0.22703890747107275`}, {
       102.8941249184866, 6.6965295501794015`}, {96.87697822619928, 
       6.591499863982917}, {96.98990360542025, 0.12200922127458835`}}, {{
       96.87697822619928, 6.591499863982917}, {102.8941249184866, 
       6.6965295501794015`}, {102.78889521724152`, 12.725135096925953`}, {
       96.7717485249542, 12.620105410729469`}, {96.87697822619928, 
       6.591499863982917}}, {{96.7717485249542, 12.620105410729469`}, {
       102.78889521724152`, 12.725135096925953`}, {102.69853242421189`, 
       17.902016042441666`}, {96.68138573192458, 17.796986356245185`}, {
       96.7717485249542, 12.620105410729469`}}, {{96.68138573192458, 
       17.7969863562452}, {102.69853242421189`, 17.90201604244168}, {
       102.6291946144111, 21.87437650548992}, {96.61204792212379, 
       21.76934681929344}, {96.68138573192458, 17.7969863562452}}, {{
       96.61204792212379, 21.76934681929344}, {102.6291946144111, 
       21.87437650548992}, {102.58560704499092`, 24.371506685150013`}, {
       96.56846035270361, 24.266476998953532`}, {96.61204792212379, 
       21.76934681929344}}, {{96.56846035270361, 24.266476998953532`}, {
       102.58560704499092`, 24.371506685150013`}, {102.57074013677548`, 
       25.22323128638086}, {96.55359344448817, 25.118201600184378`}, {
       96.56846035270361, 24.266476998953532`}}}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
    EdgeForm[None], PolygonBox[CompressedData["
1:eJyVmE9IFGEYh7etNupWuUZrHrqU0SHIQ0RL1iHyoATCLiLZQVQ2CTqGgeQl
sogw7CYsdumfHUNbWFo67IJUspUe3UQqhED20Cn6t+07zuSDL+83Cwt+MM/z
e386znwzB/uudg1sjUQi7bXv9to3GvE+U5kzkf8/tXWq/llsW1+/XLh57PTk
Qpt2vMXL+gt8n1W/xUtQ1V/HC+3nl1bXVP/mfDAv8w+0jp97PPzBuS955otv
RfVbPPtNd3SvXp/5pvrJc17mD/74vTRydN65L3nmi6+i+i2e/d6dujGYnfqq
+slzXuan6+dD0bkveeancb7Sb/Hst6X+w7LqJ895mZ+4tD/6Kz7j3Jc888VX
Uv0Wz34PYhOvR8bLqp8852V+91xsd9+JyaRrX/LMF990cuM68Fs8+0X3Fe/e
vvwiqfnJc96d5eLa8bFr/vF7JL+A40ddeVnfgq9U2LgO/Ba/42JD66FH9/31
Pelf0PzkOT/zu+T8svqqPPPFt6j6LZ79fv759/mk+slzXuYPyPXDuS955ouv
ovotnv3eyvVL9ZPnvMz37g/Ofckz37s/qH6LZz/v/qT6yXPeJuR793/nvuSb
kO/d/1W/xT9FvwbZf6h+8pyX+SnjfLB45nv7O9Vv8ewn8VXVT57zWvlWX/JW
vvX7Jc9+cePvuzkfzJtDfnPI/1/yOeQ34/yi3+Ib0e85zm/6yXNe5mdCXp/J
Mz+D6wf9Fs9+87h+0U+e8w4hvyfk/Zf8EPJ7cL7Sb/Fl9NtW/2FZ9ZPnvMxv
cdtfqTzzW3D/p9/i2S+L/Qf95Dkv89NXEiuVV7m8a1/yzBffXF7zWzz7nX0/
ceTwhY95zU+e88Zkf+ofv8vt+UjlZf0QvmD/Tr/J38l2nBx+5q/H8PxAP3nO
z/xOPJ8pfVWe+Z14PqPf4tnvu+wvVT95zsv83pDvN8gzvxfP3/RbPPuV8PxP
P3nO24/8RMj3V+T7kZ/A+xX6Lf4N+j3B+x36yXNe5s+GfD9JnvmzeH9Gv8Wz
3168v6OfPOdlfso4Hyye+d7+TvVbPPtJcFX1r/N/AeI9PFw=
     "]], 
    {GrayLevel[0.], AbsoluteThickness[0.5], 
     StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIIFGQ4Qxgd7GF90v4f73Rfv4PzVPhEvqra9
hvPPWtenzVvwDM5nBDMewPlT2CYfrJ1wAc5njxExVls20QbG74PI74fx//wH
gftw/hmI+XD+Soj9cL4IxH1wPtT9cL4YmvwaNP0X0Mxngbgfzp+H5j6urnk+
lpWr9sD4HWj++wJxP5x/Gi18VqCFnzBa+MLCHwALoIYO
       "]],
      FontColor->GrayLevel[0.]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGAQAWImKL7E9ao+Piba4ar37dob3vIHGEBgQYZDg5rwIXup
vfZNN1tYBIDyLx4/jyk9IAuXPxD6NIZ1/377NxKLHmtERzvsEvD1fOEkCZdX
mLE87v7Rw/Y/bhrs2h8Z7RDdu+mejb0QXH5BBfeNIo5T9h/S0tW/h0c7SFTk
BHcfYYLL/3D/8eSn7EX7nS3nWf6ERjtwOW4/pa681x4mH+8x8fDE21ftd/zs
ecQQEu0wbe9FkcOTWRxg8jO26R2ZeeqWfZnfogCLoGiHHy9LPn5REobLG/ye
8row9b59tZqzxvmAaIfMJ0qbrylKweUbDsaHX5j00L5ExpbjhX+0w6VpLqkd
s+Xg8hPYwhoyzjyyd/+t3TsDKH9Ccv26nUIKcHkFxanFyZaPceqvgOqH2Z+N
Zn8H1H6Y+3+juT8B6n6Y/2eh+f/FZoj/YeHHhhZ+UdDwg4W/GFr4f4CGPyz+
otDiL6ESEn+w+N+BFv8M0PgnlH4AWlMBlA==
      "]], 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQYLMhwa1IQP2UvttYfxD4Q+jWHdvx/OV5ixPO7+
0cNw/oIK7htFHKfg/B/uP578lL0I58d7TDw88fZVOH/GNr0jM0/dgvMNfk95
XZh6H85vOBgffmHSQzh/AltYQ8aZRwj7FacWJ1s+hvMr0OQ70PQnoJn/YjOq
/VFo7vuA5v6ESlT/MaD5HxY+AFu8b8w=
       "]]}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731742879129*^9},
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"},
 CellLabel->"During evaluation of In[40]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.7 OutputType", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}],

Cell[TextData[{
 StyleBox["It is sometimes desirable to create graphics in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 "Optica",
 StyleBox[" to be used in other ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" packages or displayed with non-",
  Evaluatable->False,
  AspectRatioFixed->True],
 "Optica",
 StyleBox[" produced images. These things can be done with the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OutputType",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".option of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.566158948747119*^9, 3.566158948863323*^9}},
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[TextData[{
 StyleBox["\nOutputType",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" specifies the final output form from ",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[". \n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[TextData[{
 StyleBox["OutputType",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" uses word values ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OpticalSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["StandardGraphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". If ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["StandardGraphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" mode is indicated, then ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" return a graphics object in the standard ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" format. In the default ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OpticalSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" mode, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" return component and ray information that can be analyzed and \
manipulated by ",
  Evaluatable->False,
  AspectRatioFixed->True],
 "Optica",
 StyleBox[". The following system will be used to demonstrate ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OutputType",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.566158948934401*^9},
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[CellGroupData[{

Cell["\<\
sys = AnalyzeSystem[{
\tWedgeOfRays[10],
\tMove[PlanoConvexLens[100,50,10],100],
\tBoundary[{-100,-100,-100},{200,100,100}]}, PlotType->TopView];
Head[sys]\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"In[41]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
      110., -16.66666666666667}, {
      102.75044883428481`, -16.666666666666668`}, {106.4219745809556, -25.}}],
      PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
      110., -16.66666666666667}, {110., -8.333333333333336}, {
      100.67375799589207`, -8.333333333333336}, {
      102.75044883428481`, -16.666666666666668`}}], 
     PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
      110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
      8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
      8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`, 
      16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
     PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
      16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556, 
      24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666668`}, {
       100.67375799589207`, -8.333333333333336}, {
       100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
       8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
       106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
       16.666666666666668`}, {110., 8.333333333333336}, {110., 
       3.552713678800501*^-15}, {110., -8.333333333333329}, {
       110., -16.666666666666657`}, {110., -24.999999999999993`}, {
       106.4219745809556, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, 0.}, {110., 3.061616997868383*^-15}, {
        110., 2.551347498223653*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}, {106.4219745809556, 0.}}], 
       PolygonBox[{{102.75044883428481`, 5.102694996447305*^-16}, {110., 
        2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {
        100.67375799589207`, 1.020538999289461*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{100.67375799589207`, 1.020538999289461*^-15}, {110., 
        2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15}, {100.67375799589207`, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{100.00000000000001`, 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {
        100.67375799589207`, 2.041077998578922*^-15}, {100.00000000000001`, 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{100.67375799589207`, 2.041077998578922*^-15}, {110., 
        1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {
        102.75044883428481`, 2.5513474982236525`*^-15}, {100.67375799589207`, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{102.75044883428481`, 2.5513474982236525`*^-15}, {110., 
        5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {
        106.4219745809556, 3.0616169978683826`*^-15}, {102.75044883428481`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
         100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
         100.67375799589207`, 0.}, {102.7504488342848, 0.}, {
         106.4219745809556, 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
         0.}, {110., 0.}, {110., 0.}, {110., 0.}, {106.4219745809556, 
         0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556, 
       12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000004`}, {110., 
       12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556, 
       6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
      LineBox[{{106.4219745809556, 6.470476127563024}, {110., 
       6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
       106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
       6.470476127563024}}], 
      LineBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       106.4219745809556, -6.470476127563016}, {106.4219745809556, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563016}, {
       110., -6.470476127563016}, {110., -12.499999999999995`}, {
       106.4219745809556, -12.499999999999995`}, {
       106.4219745809556, -6.470476127563016}}], 
      LineBox[{{106.4219745809556, -12.499999999999995`}, {
       110., -12.499999999999995`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999995`}}], 
      LineBox[{{106.4219745809556, -17.677669529663685`}, {
       110., -17.677669529663685`}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -17.677669529663685`}}], 
      LineBox[{{106.4219745809556, -21.650635094610962`}, {
       110., -21.650635094610962`}, {110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {
       106.4219745809556, -21.650635094610962`}}], 
      LineBox[{{106.4219745809556, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226706`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.65063509461097}, {
       110., -21.65063509461097}, {110., -17.677669529663692`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -21.65063509461097}}], 
      LineBox[{{106.4219745809556, -17.677669529663696`}, {
       110., -17.677669529663696`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663696`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563038}, {
       106.4219745809556, -6.470476127563038}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563038}, {
       110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
       106.4219745809556, -2.6796885989305705`*^-14}, {
       106.4219745809556, -6.470476127563038}}], 
      LineBox[{{106.4219745809556, -4.592425496802574*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
       106.4219745809556, 6.470476127563007}, {
       106.4219745809556, -4.592425496802574*^-15}}], 
      LineBox[{{106.4219745809556, 6.470476127563007}, {110., 
       6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556, 
       12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
      LineBox[{{106.4219745809556, 12.499999999999984`}, {110., 
       12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556, 
       17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556, 
       21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.65063509461096}, {110., 
       21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556, 
       24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
      LineBox[{{106.4219745809556, 24.148145657226703`}, {110., 
       24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {200., -100.}, {200., 100.}, {
       200., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {-100., -100.}, {-100., -100.}, {200., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-100., -100.}, {-100., 100.}, {-100., 
       100.}, {-100., -100.}, {-100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-100., 100.}, {200., 100.}, {200., 100.}, {-100., 
       100.}, {-100., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {200., 100.}, {-100., 100.}, {-100., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {-100., -100.}, {-100., 100.}, {
       200., 100.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {100.75446445332089`, 8.814873439291262}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {99.99999999999997, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {100.75446445332089`, -8.814873439291262}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100.75446445332089`, 8.814873439291262}, {110., 
       8.79656076531924}}]}, 
     {Arrowheads[Small], ArrowBox[{{99.99999999999997, 0.}, {110., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100.75446445332089`, -8.814873439291262}, {
       110., -8.79656076531924}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 8.79656076531924}, {200., 8.525766705171307}}]}, 
     {Arrowheads[Small], ArrowBox[{{110., 0.}, {200., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -8.79656076531924}, {200., -8.525766705171307}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{100.75446445332089`, 8.814873439291262}, {99.99999999999997, 
      0.}, {100.75446445332089`, -8.814873439291262}, {110., 
      8.79656076531924}, {110., 0.}, {110., -8.79656076531924}, {200., 
      8.525766705171307}, {200., 0.}, {200., -8.525766705171307}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731743390933*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"During evaluation of In[41]:="],

Cell[BoxData["OpticalSystem"], "Output",
 CellChangeTimes->{
  3.5633679291428337`*^9, 3.566158865575959*^9, 3.56615898860402*^9, 
   3.5672683167635517`*^9, {3.614729564807231*^9, 3.614729579220676*^9}, 
   3.61473056045439*^9, 3.614731743393754*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Here we see that an ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OpticalSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" object is returned from ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[". This ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OpticalSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" object contains all information to completely describe the system \
of rays and components. Even though the image displays a flattened \
two-dimensional view of the objects, we can quickly see the full \
three-dimensional view using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[sys];
Head[%]\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"In[43]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 100., -100.}, {200., -100., -100.}, {200., -100., 
       100.}, {200., 100., 100.}, {200., 100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -100., -100.}, {-100., -100., -100.}, {-100., -100., 
       100.}, {200., -100., 100.}, {200., -100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -100., -100.}, {-100., 100., -100.}, {-100., 100., 
       100.}, {-100., -100., 100.}, {-100., -100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -100.}, {200., 100., -100.}, {200., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -100., -100.}, {200., 100., -100.}, {-100., 
       100., -100.}, {-100., -100., -100.}, {200., -100., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 100., 100.}, {200., -100., 100.}, {-100., -100., 
       100.}, {-100., 100., 100.}, {200., 100., 100.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxcYF6BzdVT4NIBwXXDHHzhYoOeJSCwb//IBBB
UB0O8w8QZW9DtIP/Uo4L16YjxPHaC1RPrL1o5uMSRzMv02GFkIa3IS+mO7G6
B6gelzux2oswHy4OAOPYPV4=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     Point3DBox[{{100.75446445332089`, 8.814873439291262, 0.}, {
      99.99999999999997, 0., 0.}, {100.75446445332089`, -8.814873439291262, 
      0.}, {110., 8.79656076531924, 0.}, {110., 0., 0.}, {
      110., -8.79656076531924, 0.}, {200., 8.525766705171307, 0.}, {200., 0., 
      0.}, {200., -8.525766705171307, 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731743582399*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"During evaluation of In[43]:="],

Cell[BoxData["OpticalSystem"], "Output",
 CellChangeTimes->{
  3.5633679292085238`*^9, 3.5661588656089783`*^9, 3.566158988822213*^9, 
   3.5672683169347467`*^9, {3.61472956482408*^9, 3.6147295792692537`*^9}, 
   3.614730560493341*^9, 3.614731743584921*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Once again, an ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OpticalSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is returned by ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". We now set ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["OutputType->StandardGraphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[CellGroupData[{

Cell["\<\
standardgraphics = ShowSystem[sys,PlotType->TopView, \
OutputType->StandardGraphics];
Head[standardgraphics]\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"In[45]:="],

Cell[BoxData["Graphics"], "Output",
 CellChangeTimes->{
  3.5633679292615356`*^9, 3.5661588656423283`*^9, 3.566158989036721*^9, 
   3.567268317136866*^9, {3.614729564857354*^9, 3.6147295793086033`*^9}, 
   3.614730560527789*^9, 3.6147317437437983`*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["This time a ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Graphics", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" object is returned by ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". We can now display this object with other graphic objects in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" by using the standard ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Show",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" function. As an example, we make a standard plot of the parabola \
function.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[CellGroupData[{

Cell["plot = Plot[.01 x^2 - 25,{x,0,100}]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"In[47]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0gk01OsbB/ChsdTlhkZJLhNK/GXP/Ih+T6Hcsv5soySkTKGsZQ8hQoVK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 100}, {-24.999999999999957`, 74.99999591836739}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.563367929290403*^9, 3.566158865695448*^9, 3.566158989113925*^9, 
   3.567268317172432*^9, {3.614729564894596*^9, 3.6147295793398333`*^9}, 
   3.614730560563246*^9, 3.614731743822925*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"Out[47]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Next, we use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Show",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to merge the rendering of the parabola with the ray tracing of \
the lens. ",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[CellGroupData[{

Cell["Show[standardgraphics,plot]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"In[48]:="],

Cell[BoxData[
 GraphicsBox[{{
    {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -16.66666666666667}, {
       102.75044883428481`, -16.666666666666668`}, {
       106.4219745809556, -25.}}], 
      PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
       110., -16.66666666666667}, {110., -8.333333333333336}, {
       100.67375799589207`, -8.333333333333336}, {
       102.75044883428481`, -16.666666666666668`}}], 
      PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
       110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
       100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}], 
      PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
       8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
       100.00000000000001`, 0.}}], 
      PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
       8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`, 
       16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
      PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
       16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556, 
       24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{106.4219745809556, -25.}, {
        102.75044883428481`, -16.666666666666668`}, {
        100.67375799589207`, -8.333333333333336}, {
        100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
        8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
        106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
        16.666666666666668`}, {110., 8.333333333333336}, {110., 
        3.552713678800501*^-15}, {110., -8.333333333333329}, {
        110., -16.666666666666657`}, {110., -24.999999999999993`}, {
        106.4219745809556, -25.}}], 
       {GrayLevel[0.5], EdgeForm[None], 
        PolygonBox[{{106.4219745809556, 0.}, {110., 3.061616997868383*^-15}, {
         110., 2.551347498223653*^-15}, {102.75044883428481`, 
         5.102694996447305*^-16}, {106.4219745809556, 0.}}], 
        PolygonBox[{{102.75044883428481`, 5.102694996447305*^-16}, {110., 
         2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {
         100.67375799589207`, 1.020538999289461*^-15}, {102.75044883428481`, 
         5.102694996447305*^-16}}], 
        PolygonBox[{{100.67375799589207`, 1.020538999289461*^-15}, {110., 
         2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {
         100.00000000000001`, 1.5308084989341915`*^-15}, {100.67375799589207`,
          1.020538999289461*^-15}}], 
        PolygonBox[{{100.00000000000001`, 1.5308084989341915`*^-15}, {110., 
         1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {
         100.67375799589207`, 2.041077998578922*^-15}, {100.00000000000001`, 
         1.5308084989341915`*^-15}}], 
        PolygonBox[{{100.67375799589207`, 2.041077998578922*^-15}, {110., 
         1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {
         102.75044883428481`, 2.5513474982236525`*^-15}, {100.67375799589207`,
          2.041077998578922*^-15}}], 
        PolygonBox[{{102.75044883428481`, 2.5513474982236525`*^-15}, {110., 
         5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {
         106.4219745809556, 3.0616169978683826`*^-15}, {102.75044883428481`, 
         2.5513474982236525`*^-15}}], 
        {GrayLevel[0], AbsoluteThickness[0.5], 
         LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
          100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
          100.67375799589207`, 0.}, {102.7504488342848, 0.}, {
          106.4219745809556, 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
          0.}, {110., 0.}, {110., 0.}, {110., 0.}, {106.4219745809556, 
          0.}}]}}}}, {{}, {}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
        24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
        106.4219745809556, 25.}}], 
       LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
        24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
        21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
       LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
        21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
        17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
       LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
        17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556, 
        12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
       LineBox[{{106.4219745809556, 12.500000000000004`}, {110., 
        12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556, 
        6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
       LineBox[{{106.4219745809556, 6.470476127563024}, {110., 
        6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
        106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
        6.470476127563024}}], 
       LineBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
        106.4219745809556, -6.470476127563016}, {106.4219745809556, 
        1.5308084989341915`*^-15}}], 
       LineBox[{{106.4219745809556, -6.470476127563016}, {
        110., -6.470476127563016}, {110., -12.499999999999995`}, {
        106.4219745809556, -12.499999999999995`}, {
        106.4219745809556, -6.470476127563016}}], 
       LineBox[{{106.4219745809556, -12.499999999999995`}, {
        110., -12.499999999999995`}, {110., -17.677669529663685`}, {
        106.4219745809556, -17.677669529663685`}, {
        106.4219745809556, -12.499999999999995`}}], 
       LineBox[{{106.4219745809556, -17.677669529663685`}, {
        110., -17.677669529663685`}, {110., -21.65063509461097}, {
        106.4219745809556, -21.65063509461097}, {
        106.4219745809556, -17.677669529663685`}}], 
       LineBox[{{106.4219745809556, -21.650635094610962`}, {
        110., -21.650635094610962`}, {110., -24.148145657226706`}, {
        106.4219745809556, -24.148145657226706`}, {
        106.4219745809556, -21.650635094610962`}}], 
       LineBox[{{106.4219745809556, -24.148145657226706`}, {
        110., -24.148145657226706`}, {110., -25.}, {
        106.4219745809556, -25.}, {106.4219745809556, -24.148145657226706`}}],
        LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
        110., -24.148145657226706`}, {
        106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}}],
        LineBox[{{106.4219745809556, -24.14814565722671}, {
        110., -24.14814565722671}, {110., -21.65063509461097}, {
        106.4219745809556, -21.65063509461097}, {
        106.4219745809556, -24.14814565722671}}], 
       LineBox[{{106.4219745809556, -21.65063509461097}, {
        110., -21.65063509461097}, {110., -17.677669529663692`}, {
        106.4219745809556, -17.677669529663692`}, {
        106.4219745809556, -21.65063509461097}}], 
       LineBox[{{106.4219745809556, -17.677669529663696`}, {
        110., -17.677669529663696`}, {110., -12.50000000000001}, {
        106.4219745809556, -12.50000000000001}, {
        106.4219745809556, -17.677669529663696`}}], 
       LineBox[{{106.4219745809556, -12.50000000000001}, {
        110., -12.50000000000001}, {110., -6.470476127563038}, {
        106.4219745809556, -6.470476127563038}, {
        106.4219745809556, -12.50000000000001}}], 
       LineBox[{{106.4219745809556, -6.470476127563038}, {
        110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
        106.4219745809556, -2.6796885989305705`*^-14}, {
        106.4219745809556, -6.470476127563038}}], 
       LineBox[{{106.4219745809556, -4.592425496802574*^-15}, {
        110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
        106.4219745809556, 6.470476127563007}, {
        106.4219745809556, -4.592425496802574*^-15}}], 
       LineBox[{{106.4219745809556, 6.470476127563007}, {110., 
        6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556, 
        12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
       LineBox[{{106.4219745809556, 12.499999999999984`}, {110., 
        12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556, 
        17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
       LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
        17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556, 
        21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
       LineBox[{{106.4219745809556, 21.65063509461096}, {110., 
        21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556, 
        24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
       LineBox[{{106.4219745809556, 24.148145657226703`}, {110., 
        24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
        106.4219745809556, 24.148145657226703`}}]}}}, 
    {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{200., 100.}, {200., -100.}, {200., -100.}, {200., 100.}, {
        200., 100.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{200., -100.}, {-100., -100.}, {-100., -100.}, {
        200., -100.}, {200., -100.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{-100., -100.}, {-100., 100.}, {-100., 
        100.}, {-100., -100.}, {-100., -100.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{-100., 100.}, {200., 100.}, {200., 100.}, {-100., 
        100.}, {-100., 100.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{200., -100.}, {200., 100.}, {-100., 100.}, {-100., -100.}, {
        200., -100.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{200., 100.}, {200., -100.}, {-100., -100.}, {-100., 100.}, {
        200., 100.}}]}}, 
     {RGBColor[
      0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
      AbsoluteThickness[0.5], Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {100.75446445332089`, 8.814873439291262}}], 
      {Arrowheads[Small], ArrowBox[{{0., 0.}, {99.99999999999997, 0.}}]}, 
      {Arrowheads[Small], 
       ArrowBox[{{0., 0.}, {100.75446445332089`, -8.814873439291262}}]}, 
      {Arrowheads[Small], 
       ArrowBox[{{100.75446445332089`, 8.814873439291262}, {110., 
        8.79656076531924}}]}, 
      {Arrowheads[Small], ArrowBox[{{99.99999999999997, 0.}, {110., 0.}}]}, 
      {Arrowheads[Small], 
       ArrowBox[{{100.75446445332089`, -8.814873439291262}, {
        110., -8.79656076531924}}]}, 
      {Arrowheads[Small], 
       ArrowBox[{{110., 8.79656076531924}, {200., 8.525766705171307}}]}, 
      {Arrowheads[Small], ArrowBox[{{110., 0.}, {200., 0.}}]}, 
      {Arrowheads[Small], 
       ArrowBox[{{110., -8.79656076531924}, {200., -8.525766705171307}}]}}, 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
      PointBox[{{100.75446445332089`, 8.814873439291262}, {99.99999999999997, 
       0.}, {100.75446445332089`, -8.814873439291262}, {110., 
       8.79656076531924}, {110., 0.}, {110., -8.79656076531924}, {200., 
       8.525766705171307}, {200., 0.}, {200., -8.525766705171307}}]}}, 
    {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0gk01OsbB/ChsdTlhkZJLhNK/GXP/Ih+T6Hcsv5soySkTKGsZQ8hQoVK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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Output",
 CellChangeTimes->{
  3.563367929320751*^9, 3.5661588657561626`*^9, 3.566158989169734*^9, 
   3.567268317206396*^9, {3.6147295649526052`*^9, 3.6147295794063168`*^9}, 
   3.614730560617313*^9, 3.614731743882077*^9},
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"},
 CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
You can also work with three-dimensional rendering with Graphics3D in a \
similar fashion.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.8 LineStyle and FillStyle", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}],

Cell[TextData[{
 StyleBox["FillStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["LineStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" are options of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["TurboPlot", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" that give the component rendering styles.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],

Cell[TextData[{
 StyleBox["\nFillStyle",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" carries a list of graphics styles for rendering of filled \
surfaces.\n\n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["LineStyle",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" carries a list of graphics styles for rendering of edges and \
wire-framed surfaces.\n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],

Cell[TextData[{
 StyleBox["You can modify the thickness and color in rendered component lines \
with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["LineStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". The default option setting for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["LineStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is \n",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["LineStyle->{GrayLevel[0.],",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AbsoluteThickness[0.5]}",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". This means that component edges are rendered in black with a \
0.5-point line thickness.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],

Cell[TextData[{
 StyleBox["FillStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" lets you change the color of shaded component surfaces. The \
default option setting for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["FillStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["FillStyle->{GrayLevel[0.5]}",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". This means that shaded component surfaces are rendered in gray. \
However, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 "you can use the ",
 StyleBox["FillStyle", "Input"],
 " option to change the color of an optical component as follows:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{PlanoConvexLens[100,50,10,FillStyle->{RGBColor[1,0,0]}],
\tMove[PlanoConvexLens[100,50,10,FillStyle->{RGBColor[0,1,0]}],50]}, \
PlotType->TopView];\
\>", "Input",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"},
 CellLabel->"In[49]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {RGBColor[1, 0, 0], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
      10., -16.66666666666667}, {2.7504488342847893`, -16.666666666666668`}, {
      6.421974580955592, -25.}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
      10., -16.66666666666667}, {10., -8.333333333333336}, {
      0.6737579958920605, -8.333333333333336}, {
      2.7504488342847893`, -16.666666666666668`}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
      10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
      0.6737579958920605, -8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
      0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
      8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
      16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
      24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, -25.}, {
       2.7504488342847893`, -16.666666666666668`}, {
       0.6737579958920605, -8.333333333333336}, {
       0., -3.552713678800501*^-15}, {0.6737579958920605, 
       8.333333333333329}, {2.750448834284782, 16.666666666666657`}, {
       6.421974580955592, 24.999999999999993`}, {10., 25.}, {10., 
       16.666666666666668`}, {10., 8.333333333333336}, {10., 
       3.552713678800501*^-15}, {10., -8.333333333333329}, {
       10., -16.666666666666657`}, {10., -24.999999999999993`}, {
       6.421974580955592, -25.}}], 
      {RGBColor[1, 0, 0], EdgeForm[None], 
       PolygonBox[{{6.421974580955592, 0.}, {10., 3.061616997868383*^-15}, {
        10., 2.551347498223653*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}, {6.421974580955592, 0.}}], 
       PolygonBox[{{2.7504488342847893`, 5.102694996447305*^-16}, {10., 
        2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {
        0.6737579958920605, 1.020538999289461*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{0.6737579958920605, 1.020538999289461*^-15}, {10., 
        2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
        1.5308084989341915`*^-15}, {0.6737579958920605, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {
        0.6737579958920605, 2.041077998578922*^-15}, {0., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{0.6737579958920605, 2.041077998578922*^-15}, {10., 
        1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {
        2.7504488342847893`, 2.5513474982236525`*^-15}, {0.6737579958920605, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{2.7504488342847893`, 2.5513474982236525`*^-15}, {10., 
        5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {
        6.421974580955592, 3.0616169978683826`*^-15}, {2.7504488342847893`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
         0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
         2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
         0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
         6.421974580955592, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
       12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955592, 12.500000000000004`}, {10., 
       12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
       6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
      LineBox[{{6.421974580955592, 6.470476127563024}, {10., 
       6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
       6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
       6.470476127563024}}], 
      LineBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       6.421974580955592, -6.470476127563016}, {6.421974580955592, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563016}, {
       10., -6.470476127563016}, {10., -12.499999999999995`}, {
       6.421974580955592, -12.499999999999995`}, {
       6.421974580955592, -6.470476127563016}}], 
      LineBox[{{6.421974580955592, -12.499999999999995`}, {
       10., -12.499999999999995`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999995`}}], 
      LineBox[{{6.421974580955592, -17.677669529663685`}, {
       10., -17.677669529663685`}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -17.677669529663685`}}], 
      LineBox[{{6.421974580955599, -21.650635094610962`}, {
       10., -21.650635094610962`}, {10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {
       6.421974580955599, -21.650635094610962`}}], 
      LineBox[{{6.421974580955592, -24.148145657226706`}, {
       10., -24.148145657226706`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226706`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.65063509461097}, {
       10., -21.65063509461097}, {10., -17.677669529663692`}, {
       6.421974580955592, -17.677669529663692`}, {
       6.421974580955592, -21.65063509461097}}], 
      LineBox[{{6.421974580955592, -17.677669529663696`}, {
       10., -17.677669529663696`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663696`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563038}, {
       6.421974580955592, -6.470476127563038}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563038}, {
       10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
       6.421974580955592, -2.6796885989305705`*^-14}, {
       6.421974580955592, -6.470476127563038}}], 
      LineBox[{{6.421974580955592, -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
       6.421974580955592, 6.470476127563007}, {
       6.421974580955592, -4.592425496802574*^-15}}], 
      LineBox[{{6.421974580955592, 6.470476127563007}, {10., 
       6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
       12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
      LineBox[{{6.421974580955592, 12.499999999999984`}, {10., 
       12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
       17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
       21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.65063509461096}, {10., 
       21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
       24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
      LineBox[{{6.421974580955592, 24.148145657226703`}, {10., 
       24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {RGBColor[0, 1, 0], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {RGBColor[0, 1, 0], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L1\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"L2\"\>", {55., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317442006273`*^9},
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"},
 CellLabel->"During evaluation of In[49]:="]
}, Open  ]],

Cell[TextData[StyleBox["However, if you try this with a three-dimensional \
view, the effect no longer works.",
 Evaluatable->False,
 AspectRatioFixed->True]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8", "ColorComponents"}],

Cell[CellGroupData[{

Cell["\<\
DrawSystem[{PlanoConvexLens[100,50,10,FillStyle->{RGBColor[1,0,0]}],
\tMove[PlanoConvexLens[100,50,10,FillStyle->{RGBColor[0,1,0]}],50]}];\
\>", "Input",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"},
 CellLabel->"In[50]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {RGBColor[1, 0, 0], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {RGBColor[1, 0, 0], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {RGBColor[0, 1, 0], EdgeForm[None], 
     Polygon3DBox[{{56.42197458095559, -25., 0.}, {60., -25., 
      6.123233995736766*^-15}, {60., -16.66666666666667, 
      5.102694996447306*^-15}, {52.75044883428479, -16.666666666666668`, 
      0.}, {56.42197458095559, -25., 0.}}], 
     Polygon3DBox[{{52.75044883428479, -16.666666666666668`, 0.}, {
      60., -16.66666666666667, 5.102694996447306*^-15}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      50.67375799589206, -8.333333333333336, 0.}, {
      52.75044883428479, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{50.67375799589206, -8.333333333333336, 0.}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      60., -7.105427357601002*^-15, 3.061616997868384*^-15}, {50., 0., 0.}, {
      50.67375799589206, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{50., 0., 0.}, {60., 0., 3.061616997868383*^-15}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {50.67375799589206, 
      8.333333333333329, 0.}, {50., 0., 0.}}], 
     Polygon3DBox[{{50.67375799589206, 8.333333333333329, 0.}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {60., 16.666666666666664`,
       1.0205389992894613`*^-15}, {52.75044883428479, 16.666666666666664`, 
      0.}, {50.67375799589206, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{52.75044883428479, 16.666666666666664`, 0.}, {60., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {60., 
      24.999999999999996`, 5.098616525425841*^-31}, {56.42197458095559, 
      24.999999999999993`, 0.}, {52.75044883428479, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYAADywMMUNDpKbGVL8HLYfUqEDCA
ixs83rbZNszTYQ1YXAEuDgGeUHM+7EFXvwKi3gEm3gE1HyJuABeHuefffxCw
gItDgB/MnRjiq9HMgYmvQbMX1ZwPNujiK7D6CyZugCEOdSdcHFd4AgCmzVCy

       "]], 
      {RGBColor[0, 1, 0], EdgeForm[None], 
       Polygon3DBox[{{56.42197458095559, 0., -25.}, {60., 
        3.061616997868383*^-15, -25.}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {56.42197458095559, 
        0., -25.}}], 
       Polygon3DBox[{{52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {60., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {50., 
        1.5308084989341915`*^-15, 0.}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{50., 1.5308084989341915`*^-15, 0.}, {60., 
        1.5308084989341915`*^-15, 0.}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {50., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {60., 5.102694996447307*^-16, 
        16.666666666666664`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {60., 5.102694996447308*^-16, 
        16.666666666666664`}, {60., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {56.42197458095559, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYEABlgc6PSW28iV4wcVXrwIBgwMG
j7dttg3zhIuvAYsrHIDwPNHM+bAHXf0KiHqHDjTzIeIGDuju+fcfBCygfD90
d2KIQ92JIQ51Jw5zPtigi69A8Re6uAGGONSdB3CFJwDol1Cy
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{56.42197458095559, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 25., 
       0.}}], Line3DBox[{{56.42197458095559, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461097, 
       12.499999999999998`}, {60., 21.65063509461097, 12.499999999999998`}, {
       60., 17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{56.42197458095559, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{56.42197458095559, 12.500000000000004`, 
       21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563024, 
       24.148145657226706`}, {60., 6.470476127563024, 24.148145657226706`}, {
       60., 7.0819236220599744`*^-15, 25.}, {56.42197458095559, 
       7.0819236220599744`*^-15, 25.}, {56.42197458095559, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, 1.5308084989341915`*^-15, 25.}, {60., 
       1.5308084989341915`*^-15, 25.}, {60., -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, -12.499999999999995`, 
       21.65063509461097}, {60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{56.42197458095559, -17.677669529663685`, 
       17.67766952966369}, {60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{56.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {60., -21.650635094610962`, 
       12.500000000000009`}, {60., -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -24.148145657226706`, 6.470476127563026}, {
       56.4219745809556, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{56.42197458095559, -24.148145657226706`, 
       6.470476127563026}, {60., -24.148145657226706`, 6.470476127563026}, {
       60., -25., 3.061616997868383*^-15}, {56.42197458095559, -25., 
       3.061616997868383*^-15}, {56.42197458095559, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{56.42197458095559, -25., 3.061616997868383*^-15}, {
       60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       56.42197458095559, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{56.42197458095559, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}, {
       56.42197458095559, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563007, -24.14814565722671}, {
       60., 6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.4219745809556, 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461096, -12.50000000000001}, {
       60., 21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731744679532*^9},
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"},
 CellLabel->"During evaluation of In[50]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.9 Other Rendering Options", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
   "EdgeRendering", "PR6.9"}],

Cell[TextData[{
 StyleBox["In this section we examine the several options available for \
altering the graphical rendering of components and rays. The default \
rendering options of a ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Component",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" object can be identified by examining ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Options[",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["componentname",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". As an example, we examine ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Options[PlanoConvexLens]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[CellGroupData[{

Cell["Options[PlanoConvexLens]", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Component", "Other Rendering Options", "PR6.9"},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Labels", "\[Rule]", "\<\"L\"\>"}], ",", 
   RowBox[{"LabelPositions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentDescription", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
   RowBox[{"Temperature", "\[Rule]", "Temperature"}], ",", 
   RowBox[{"Tension", "\[Rule]", "Tension"}], ",", 
   RowBox[{"Transmittance", "\[Rule]", "Transmittance"}], ",", 
   RowBox[{"Reflectance", "\[Rule]", "Reflectance"}], ",", 
   RowBox[{"GraphicDesign", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"CurvatureDirection", "\[Rule]", "Front"}], ",", 
   RowBox[{"DesignWaveLength", "\[Rule]", "0.5461`"}], ",", 
   RowBox[{"OffAxis", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SwitchDirectionOnReflection", "\[Rule]", "False"}], ",", 
   RowBox[{"Resonate", "\[Rule]", "True"}], ",", 
   RowBox[{"Automatic", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Empty"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Sketch", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Empty"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Wire", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Solid", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Fill"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Empty"}]}], "}"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5633679301417723`*^9, 3.56615886589615*^9, 
  3.566158990482046*^9, 3.5672683487093487`*^9, 3.6147305606427727`*^9, 
  3.614731744997409*^9},
 CellTags->{"Component", "Other Rendering Options", "PR6.9"},
 CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Listed above are several graphics-related options. These options \
are given in a hierarchy of levels. At the top of the hierarchy is the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["\nGraphicDesign",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is an option of all rendered components indicating the style of \
rendering.\n",
  CellFrame->True,
  CellMargins->{{50, 154}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 154}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "GraphicDesign", 
   "CrossRendering", "SurfaceRendering", "EdgeRendering", 
   "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["The ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option uses ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Automatic",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Sketch",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Wire",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Solid",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to denote different rendering styles for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["PlanoConvexLens",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Automatic",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Sketch",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Wire",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Solid",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" are themselves options of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["PlanoConvexLens",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and can take a combination of the four word values defined \
below.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["Empty",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox[" indicates that no graphics will be created.\n",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontSize->12],
 StyleBox["Fill",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox[" denotes that the surface graphics should be filled with shaded \
areas.\n",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontSize->12],
 StyleBox["Mesh",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox[" designates that the surface graphics should be rendered with mesh \
outlines.\n",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontSize->12],
 StyleBox["Trace",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox[" specifies that surfaces are rendered with outlined borders and no \
shading.",
  CellFrame->True,
  CellMargins->{{50, 155}, {2, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True,
  FontSize->12]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 155}, {2, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
 AspectRatioFixed->True,
 FontSize->10,
 CellTags->{
  "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
   "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
   "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["Component", "Input",
  FontSlant->"Plain"],
 " ",
 StyleBox["rendering commands",
  FontSlant->"Plain"],
 "."
}], "Commentary",
 CellTags->{"Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["When specifying the graphical rendering of a component, it is \
possible to modify a particular ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option in two different ways. The broadest method is to simply \
change the definition of a particular suboption using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["SetOptions",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". The usual method, however, is to directly change the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" setting for a given component funciton.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["As an example, here are several ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" settings for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["PlanoConvexLens",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", starting with the default setting.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[PlanoConvexLens[100,50,10]];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"In[53]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.61473174513949*^9},
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"During evaluation of In[53]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[PlanoConvexLens[100,50,10, GraphicDesign -> Wire]];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"In[54]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 8.333333333333332, 0.}, {
       0.6737579958920605, 8.049381885742235, 2.156825375854339}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 8.333333333333332, 0.}, {
       2.7504488342847893`, 16.666666666666664`, 0.}, {2.7504488342847893`, 
       16.09876377148447, 4.313650751708678}, {0.6737579958920605, 
       8.049381885742235, 2.156825375854339}, {0.6737579958920605, 
       8.333333333333332, 0.}}], 
      Line3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {
       6.421974580955592, 25., 0.}, {6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {2.7504488342847893`, 16.09876377148447, 
       4.313650751708678}, {2.7504488342847893`, 16.666666666666664`, 0.}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 8.049381885742235, 
       2.156825375854339}, {0.6737579958920676, 7.216878364870323, 
       4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 8.049381885742235, 2.156825375854339}, {
       2.7504488342847893`, 16.09876377148447, 4.313650751708678}, {
       2.7504488342847893`, 14.433756729740645`, 8.333333333333332}, {
       0.6737579958920676, 7.216878364870323, 4.166666666666666}, {
       0.6737579958920605, 8.049381885742235, 2.156825375854339}}], 
      Line3DBox[{{2.7504488342847893`, 16.09876377148447, 
       4.313650751708678}, {6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {2.7504488342847893`, 14.433756729740645`, 
       8.333333333333332}, {2.7504488342847893`, 16.09876377148447, 
       4.313650751708678}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920676, 7.216878364870323, 
       4.166666666666666}, {0.6737579958920605, 5.892556509887896, 
       5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920676, 7.216878364870323, 4.166666666666666}, {
       2.7504488342847893`, 14.433756729740645`, 8.333333333333332}, {
       2.750448834284782, 11.785113019775793`, 11.785113019775789`}, {
       0.6737579958920605, 5.892556509887896, 5.8925565098878945`}, {
       0.6737579958920676, 7.216878364870323, 4.166666666666666}}], 
      Line3DBox[{{2.7504488342847893`, 14.433756729740645`, 
       8.333333333333332}, {6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {2.750448834284782, 11.785113019775793`, 
       11.785113019775789`}, {2.7504488342847893`, 14.433756729740645`, 
       8.333333333333332}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 5.892556509887896, 
       5.8925565098878945`}, {0.6737579958920676, 4.166666666666668, 
       7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 5.892556509887896, 
       5.8925565098878945`}, {2.750448834284782, 11.785113019775793`, 
       11.785113019775789`}, {2.7504488342847893`, 8.333333333333336, 
       14.433756729740644`}, {0.6737579958920676, 4.166666666666668, 
       7.216878364870322}, {0.6737579958920605, 5.892556509887896, 
       5.8925565098878945`}}], 
      Line3DBox[{{2.750448834284782, 11.785113019775793`, 
       11.785113019775789`}, {6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {2.7504488342847893`, 8.333333333333336, 
       14.433756729740644`}, {2.750448834284782, 11.785113019775793`, 
       11.785113019775789`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920676, 4.166666666666668, 
       7.216878364870322}, {0.6737579958920605, 2.156825375854341, 
       8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920676, 4.166666666666668, 7.216878364870322}, {
       2.7504488342847893`, 8.333333333333336, 14.433756729740644`}, {
       2.7504488342847893`, 4.313650751708682, 16.09876377148447}, {
       0.6737579958920605, 2.156825375854341, 8.049381885742235}, {
       0.6737579958920676, 4.166666666666668, 7.216878364870322}}], 
      Line3DBox[{{2.7504488342847893`, 8.333333333333336, 
       14.433756729740644`}, {6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {2.7504488342847893`, 4.313650751708682, 
       16.09876377148447}, {2.7504488342847893`, 8.333333333333336, 
       14.433756729740644`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 2.156825375854341, 
       8.049381885742235}, {0.6737579958920605, 2.3606412073533245`*^-15, 
       8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 2.156825375854341, 8.049381885742235}, {
       2.7504488342847893`, 4.313650751708682, 16.09876377148447}, {
       2.7504488342847893`, 4.721282414706649*^-15, 16.666666666666664`}, {
       0.6737579958920605, 2.3606412073533245`*^-15, 8.333333333333332}, {
       0.6737579958920605, 2.156825375854341, 8.049381885742235}}], 
      Line3DBox[{{2.7504488342847893`, 4.313650751708682, 
       16.09876377148447}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {6.421974580955592, 7.0819236220599744`*^-15, 
       25.}, {2.7504488342847893`, 4.721282414706649*^-15, 
       16.666666666666664`}, {2.7504488342847893`, 4.313650751708682, 
       16.09876377148447}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 5.102694996447305*^-16, 
       8.333333333333332}, {0.6737579958920605, -2.1568253758543383`, 
       8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 5.102694996447305*^-16, 
       8.333333333333332}, {2.7504488342847893`, 1.020538999289461*^-15, 
       16.666666666666664`}, {2.7504488342847893`, -4.313650751708677, 
       16.09876377148447}, {0.6737579958920605, -2.1568253758543383`, 
       8.049381885742235}, {0.6737579958920605, 5.102694996447305*^-16, 
       8.333333333333332}}], 
      Line3DBox[{{2.7504488342847893`, 1.020538999289461*^-15, 
       16.666666666666664`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}, {6.421974580955592, -6.470476127563016, 24.148145657226706`}, {
       2.7504488342847893`, -4.313650751708677, 16.09876377148447}, {
       2.7504488342847893`, 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, -2.1568253758543383`, 
       8.049381885742235}, {0.6737579958920676, -4.166666666666664, 
       7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, -2.1568253758543383`, 
       8.049381885742235}, {2.7504488342847893`, -4.313650751708677, 
       16.09876377148447}, {2.7504488342847893`, -8.333333333333329, 
       14.433756729740645`}, {0.6737579958920676, -4.166666666666664, 
       7.216878364870323}, {0.6737579958920605, -2.1568253758543383`, 
       8.049381885742235}}], 
      Line3DBox[{{2.7504488342847893`, -4.313650751708677, 
       16.09876377148447}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {2.7504488342847893`, -8.333333333333329, 
       14.433756729740645`}, {2.7504488342847893`, -4.313650751708677, 
       16.09876377148447}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920676, -4.166666666666664, 
       7.216878364870323}, {0.6737579958920605, -5.8925565098878945`, 
       5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920676, -4.166666666666664, 
       7.216878364870323}, {2.7504488342847893`, -8.333333333333329, 
       14.433756729740645`}, {2.750448834284782, -11.785113019775789`, 
       11.785113019775793`}, {0.6737579958920605, -5.8925565098878945`, 
       5.892556509887896}, {0.6737579958920676, -4.166666666666664, 
       7.216878364870323}}], 
      Line3DBox[{{2.7504488342847893`, -8.333333333333329, 
       14.433756729740645`}, {6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {2.750448834284782, -11.785113019775789`, 
       11.785113019775793`}, {2.7504488342847893`, -8.333333333333329, 
       14.433756729740645`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, -5.8925565098878945`, 
       5.892556509887896}, {0.6737579958920676, -7.216878364870323, 
       4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, -5.8925565098878945`, 
       5.892556509887896}, {2.750448834284782, -11.785113019775789`, 
       11.785113019775793`}, {2.7504488342847893`, -14.433756729740645`, 
       8.333333333333332}, {0.6737579958920676, -7.216878364870323, 
       4.166666666666666}, {0.6737579958920605, -5.8925565098878945`, 
       5.892556509887896}}], 
      Line3DBox[{{2.750448834284782, -11.785113019775789`, 
       11.785113019775793`}, {6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {6.421974580955592, -21.65063509461097, 
       12.499999999999998`}, {2.7504488342847893`, -14.433756729740645`, 
       8.333333333333332}, {2.750448834284782, -11.785113019775789`, 
       11.785113019775793`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920676, -7.21687836487032, 
       4.16666666666667}, {0.6737579958920605, -8.049381885742235, 
       2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920676, -7.21687836487032, 4.16666666666667}, {
       2.750448834284782, -14.43375672974064, 8.33333333333334}, {
       2.7504488342847893`, -16.09876377148447, 4.313650751708684}, {
       0.6737579958920605, -8.049381885742235, 2.156825375854342}, {
       0.6737579958920676, -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{2.750448834284782, -14.43375672974064, 8.33333333333334}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       2.7504488342847893`, -16.09876377148447, 4.313650751708684}, {
       2.750448834284782, -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, -8.049381885742235, 
       2.156825375854342}, {0.6737579958920605, -8.333333333333332, 
       1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, -8.049381885742235, 
       2.156825375854342}, {2.7504488342847893`, -16.09876377148447, 
       4.313650751708684}, {2.7504488342847893`, -16.666666666666664`, 
       2.041077998578922*^-15}, {0.6737579958920605, -8.333333333333332, 
       1.020538999289461*^-15}, {0.6737579958920605, -8.049381885742235, 
       2.156825375854342}}], 
      Line3DBox[{{2.7504488342847893`, -16.09876377148447, 
       4.313650751708684}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {2.7504488342847893`, -16.666666666666664`, 
       2.041077998578922*^-15}, {2.7504488342847893`, -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, -8.333333333333332, 
       1.020538999289461*^-15}, {
       0.6737579958920605, -8.049381885742235, -2.15682537585434}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, -8.333333333333332, 
       1.020538999289461*^-15}, {2.7504488342847893`, -16.666666666666664`, 
       2.041077998578922*^-15}, {
       2.7504488342847893`, -16.09876377148447, -4.31365075170868}, {
       0.6737579958920605, -8.049381885742235, -2.15682537585434}, {
       0.6737579958920605, -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{2.7504488342847893`, -16.666666666666664`, 
       2.041077998578922*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       2.7504488342847893`, -16.09876377148447, -4.31365075170868}, {
       2.7504488342847893`, -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920605, -8.049381885742235, -2.156825375854336}, {
       0.6737579958920676, -7.216878364870323, -4.166666666666664}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920605, -8.049381885742235, -2.156825375854336}, {
       2.7504488342847893`, -16.09876377148447, -4.313650751708672}, {
       2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
       0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
       0.6737579958920605, -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{
       2.7504488342847893`, -16.09876377148447, -4.313650751708672}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
       2.7504488342847893`, -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
       0.6737579958920605, -5.892556509887897, -5.8925565098878945`}, {0., 0.,
        0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
       2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
       2.7504488342847893`, -11.785113019775794`, -11.785113019775789`}, {
       0.6737579958920605, -5.892556509887897, -5.8925565098878945`}, {
       0.6737579958920676, -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{
       2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       2.7504488342847893`, -11.785113019775794`, -11.785113019775789`}, {
       2.7504488342847893`, -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920605, -5.892556509887898, -5.892556509887893}, {
       0.6737579958920676, -4.16666666666667, -7.216878364870319}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920605, -5.892556509887898, -5.892556509887893}, {
       2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}, {
       2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
       0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
       0.6737579958920605, -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{
       2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
       2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
       0.6737579958920605, -2.156825375854346, -8.049381885742234}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
       2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
       2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
       0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
       0.6737579958920676, -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{
       2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
       2.750448834284782, -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
       0.6737579958920605, -8.932295329768568*^-15, -8.333333333333332}, {0., 
       0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
       2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
       2.7504488342847893`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{0.6737579958920605, -8.932295329768568*^-15, -8.333333333333332}, {
       0.6737579958920605, -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{
       2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       2.7504488342847893`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{2.7504488342847893`, -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{0., 0., 0.}, {
       0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}, {
       0.6737579958920605, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
       0.}, {0., 0., 0.}}], 
      Line3DBox[{{
       0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}, {
       2.7504488342847893`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{2.7504488342847893`, 4.313650751708671, -16.09876377148447}, {
       0.6737579958920605, 2.1568253758543356`, -8.049381885742235}, {
       0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{
       2.7504488342847893`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{6.421974580955592, -4.592425496802574*^-15, -25.}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {2.7504488342847893`, 
       4.313650751708671, -16.09876377148447}, {
       2.7504488342847893`, -3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 
       2.1568253758543356`, -8.049381885742235}, {0.6737579958920605, 
       4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 
       2.1568253758543356`, -8.049381885742235}, {2.7504488342847893`, 
       4.313650751708671, -16.09876377148447}, {2.7504488342847893`, 
       8.333333333333321, -14.43375672974065}, {0.6737579958920605, 
       4.166666666666661, -7.216878364870325}, {0.6737579958920605, 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{2.7504488342847893`, 
       4.313650751708671, -16.09876377148447}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {2.7504488342847893`, 
       8.333333333333321, -14.43375672974065}, {2.7504488342847893`, 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 
       4.166666666666661, -7.216878364870325}, {0.6737579958920605, 
       5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 
       4.166666666666661, -7.216878364870325}, {2.7504488342847893`, 
       8.333333333333321, -14.43375672974065}, {2.7504488342847893`, 
       11.78511301977578, -11.785113019775807`}, {0.6737579958920605, 
       5.89255650988789, -5.892556509887903}, {0.6737579958920605, 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{2.7504488342847893`, 
       8.333333333333321, -14.43375672974065}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {2.7504488342847893`, 
       11.78511301977578, -11.785113019775807`}, {2.7504488342847893`, 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 
       5.8925565098878945`, -5.892556509887897}, {0.6737579958920676, 
       7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
      Line3DBox[{{0.6737579958920605, 
       5.8925565098878945`, -5.892556509887897}, {2.7504488342847893`, 
       11.785113019775789`, -11.785113019775794`}, {2.750448834284782, 
       14.433756729740638`, -8.33333333333334}, {0.6737579958920676, 
       7.216878364870319, -4.16666666666667}, {0.6737579958920605, 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{2.7504488342847893`, 
       11.785113019775789`, -11.785113019775794`}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {2.750448834284782, 
       14.433756729740638`, -8.33333333333334}, {2.7504488342847893`, 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920676, 
       7.216878364870319, -4.16666666666667}, {0.6737579958920605, 
       8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}],
       Line3DBox[{{0.6737579958920676, 
       7.216878364870319, -4.16666666666667}, {2.750448834284782, 
       14.433756729740638`, -8.33333333333334}, {2.7504488342847893`, 
       16.098763771484467`, -4.313650751708693}, {0.6737579958920605, 
       8.049381885742234, -2.1568253758543463`}, {0.6737579958920676, 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{2.750448834284782, 
       14.433756729740638`, -8.33333333333334}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {2.7504488342847893`, 
       16.098763771484467`, -4.313650751708693}, {2.750448834284782, 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{0., 0., 0.}, {0.6737579958920605, 
       8.049381885742234, -2.1568253758543463`}, {0.6737579958920605, 
       8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
       0.}}], Line3DBox[{{0.6737579958920605, 
       8.049381885742234, -2.1568253758543463`}, {2.7504488342847893`, 
       16.098763771484467`, -4.313650751708693}, {2.7504488342847893`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {0.6737579958920605, 
       8.333333333333332, -9.442564829413298*^-15}, {0.6737579958920605, 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{2.7504488342847893`, 
       16.098763771484467`, -4.313650751708693}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {2.7504488342847893`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {2.7504488342847893`, 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{10., 0., 0.}, {10., 8.333333333333332, 0.}, {10., 
       8.049381885742235, 2.156825375854339}, {10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., 8.333333333333332, 0.}, {10., 16.666666666666664`, 
       0.}, {10., 16.09876377148447, 4.313650751708678}, {10., 
       8.049381885742235, 2.156825375854339}, {10., 8.333333333333332, 0.}}], 
      Line3DBox[{{10., 16.666666666666664`, 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {10., 16.09876377148447, 
       4.313650751708678}, {10., 16.666666666666664`, 0.}}], 
      Line3DBox[{{10., 0., 0.}, {10., 8.049381885742235, 2.156825375854339}, {
       10., 7.216878364870323, 4.166666666666666}, {10., 0., 0.}, {10., 0., 
       0.}}], 
      Line3DBox[{{10., 8.049381885742235, 2.156825375854339}, {10., 
       16.09876377148447, 4.313650751708678}, {10., 14.433756729740645`, 
       8.333333333333332}, {10., 7.216878364870323, 4.166666666666666}, {10., 
       8.049381885742235, 2.156825375854339}}], 
      Line3DBox[{{10., 16.09876377148447, 4.313650751708678}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {10., 21.65063509461097, 
       12.499999999999998`}, {10., 14.433756729740645`, 8.333333333333332}, {
       10., 16.09876377148447, 4.313650751708678}}], 
      Line3DBox[{{10., 0., 0.}, {10., 7.216878364870323, 4.166666666666666}, {
       10., 5.892556509887896, 5.8925565098878945`}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., 7.216878364870323, 4.166666666666666}, {10., 
       14.433756729740645`, 8.333333333333332}, {10., 11.785113019775793`, 
       11.785113019775789`}, {10., 5.892556509887896, 5.8925565098878945`}, {
       10., 7.216878364870323, 4.166666666666666}}], 
      Line3DBox[{{10., 14.433756729740645`, 8.333333333333332}, {10., 
       21.65063509461097, 12.499999999999998`}, {10., 17.67766952966369, 
       17.677669529663685`}, {10., 11.785113019775793`, 
       11.785113019775789`}, {10., 14.433756729740645`, 8.333333333333332}}], 
      Line3DBox[{{10., 0., 0.}, {10., 5.892556509887896, 
       5.8925565098878945`}, {10., 4.166666666666668, 7.216878364870322}, {
       10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., 5.892556509887896, 5.8925565098878945`}, {10., 
       11.785113019775793`, 11.785113019775789`}, {10., 8.333333333333336, 
       14.433756729740644`}, {10., 4.166666666666668, 7.216878364870322}, {
       10., 5.892556509887896, 5.8925565098878945`}}], 
      Line3DBox[{{10., 11.785113019775793`, 11.785113019775789`}, {10., 
       17.67766952966369, 17.677669529663685`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 8.333333333333336, 14.433756729740644`}, {
       10., 11.785113019775793`, 11.785113019775789`}}], 
      Line3DBox[{{10., 0., 0.}, {10., 4.166666666666668, 7.216878364870322}, {
       10., 2.156825375854341, 8.049381885742235}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., 4.166666666666668, 7.216878364870322}, {10., 
       8.333333333333336, 14.433756729740644`}, {10., 4.313650751708682, 
       16.09876377148447}, {10., 2.156825375854341, 8.049381885742235}, {10., 
       4.166666666666668, 7.216878364870322}}], 
      Line3DBox[{{10., 8.333333333333336, 14.433756729740644`}, {10., 
       12.500000000000004`, 21.650635094610966`}, {10., 6.470476127563024, 
       24.148145657226706`}, {10., 4.313650751708682, 16.09876377148447}, {
       10., 8.333333333333336, 14.433756729740644`}}], 
      Line3DBox[{{10., 0., 0.}, {10., 2.156825375854341, 8.049381885742235}, {
       10., 2.3606412073533245`*^-15, 8.333333333333332}, {10., 0., 0.}, {10.,
        0., 0.}}], 
      Line3DBox[{{10., 2.156825375854341, 8.049381885742235}, {10., 
       4.313650751708682, 16.09876377148447}, {10., 4.721282414706649*^-15, 
       16.666666666666664`}, {10., 2.3606412073533245`*^-15, 
       8.333333333333332}, {10., 2.156825375854341, 8.049381885742235}}], 
      Line3DBox[{{10., 4.313650751708682, 16.09876377148447}, {10., 
       6.470476127563024, 24.148145657226706`}, {10., 
       7.0819236220599744`*^-15, 25.}, {10., 4.721282414706649*^-15, 
       16.666666666666664`}, {10., 4.313650751708682, 16.09876377148447}}], 
      Line3DBox[{{10., 0., 0.}, {10., 5.102694996447305*^-16, 
       8.333333333333332}, {10., -2.1568253758543383`, 8.049381885742235}, {
       10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., 5.102694996447305*^-16, 8.333333333333332}, {10., 
       1.020538999289461*^-15, 16.666666666666664`}, {10., -4.313650751708677,
        16.09876377148447}, {10., -2.1568253758543383`, 8.049381885742235}, {
       10., 5.102694996447305*^-16, 8.333333333333332}}], 
      Line3DBox[{{10., 1.020538999289461*^-15, 16.666666666666664`}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {10., -4.313650751708677, 16.09876377148447}, {
       10., 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{10., 0., 0.}, {10., -2.1568253758543383`, 
       8.049381885742235}, {10., -4.166666666666664, 7.216878364870323}, {10.,
        0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., -2.1568253758543383`, 8.049381885742235}, {
       10., -4.313650751708677, 16.09876377148447}, {10., -8.333333333333329, 
       14.433756729740645`}, {10., -4.166666666666664, 7.216878364870323}, {
       10., -2.1568253758543383`, 8.049381885742235}}], 
      Line3DBox[{{10., -4.313650751708677, 16.09876377148447}, {
       10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       10., -8.333333333333329, 14.433756729740645`}, {
       10., -4.313650751708677, 16.09876377148447}}], 
      Line3DBox[{{10., 0., 0.}, {10., -4.166666666666664, 
       7.216878364870323}, {10., -5.8925565098878945`, 5.892556509887896}, {
       10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., -4.166666666666664, 7.216878364870323}, {
       10., -8.333333333333329, 14.433756729740645`}, {
       10., -11.785113019775789`, 11.785113019775793`}, {
       10., -5.8925565098878945`, 5.892556509887896}, {
       10., -4.166666666666664, 7.216878364870323}}], 
      Line3DBox[{{10., -8.333333333333329, 14.433756729740645`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       10., -11.785113019775789`, 11.785113019775793`}, {
       10., -8.333333333333329, 14.433756729740645`}}], 
      Line3DBox[{{10., 0., 0.}, {10., -5.8925565098878945`, 
       5.892556509887896}, {10., -7.216878364870323, 4.166666666666666}, {10.,
        0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., -5.8925565098878945`, 5.892556509887896}, {
       10., -11.785113019775789`, 11.785113019775793`}, {
       10., -14.433756729740645`, 8.333333333333332}, {
       10., -7.216878364870323, 4.166666666666666}, {
       10., -5.8925565098878945`, 5.892556509887896}}], 
      Line3DBox[{{10., -11.785113019775789`, 11.785113019775793`}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       10., -14.433756729740645`, 8.333333333333332}, {
       10., -11.785113019775789`, 11.785113019775793`}}], 
      Line3DBox[{{10., 0., 0.}, {10., -7.21687836487032, 4.16666666666667}, {
       10., -8.049381885742235, 2.156825375854342}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., -7.21687836487032, 4.16666666666667}, {
       10., -14.43375672974064, 8.33333333333334}, {10., -16.09876377148447, 
       4.313650751708684}, {10., -8.049381885742235, 2.156825375854342}, {
       10., -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{10., -14.43375672974064, 8.33333333333334}, {
       10., -21.650635094610962`, 12.500000000000009`}, {
       10., -24.148145657226706`, 6.470476127563026}, {
       10., -16.09876377148447, 4.313650751708684}, {10., -14.43375672974064, 
       8.33333333333334}}], 
      Line3DBox[{{10., 0., 0.}, {10., -8.049381885742235, 
       2.156825375854342}, {10., -8.333333333333332, 
       1.020538999289461*^-15}, {10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., -8.049381885742235, 2.156825375854342}, {
       10., -16.09876377148447, 4.313650751708684}, {
       10., -16.666666666666664`, 2.041077998578922*^-15}, {
       10., -8.333333333333332, 1.020538999289461*^-15}, {
       10., -8.049381885742235, 2.156825375854342}}], 
      Line3DBox[{{10., -16.09876377148447, 4.313650751708684}, {
       10., -24.148145657226706`, 6.470476127563026}, {10., -25., 
       3.061616997868383*^-15}, {10., -16.666666666666664`, 
       2.041077998578922*^-15}, {10., -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{10., 0., 0.}, {10., -8.333333333333332, 
       1.020538999289461*^-15}, {
       10., -8.049381885742235, -2.15682537585434}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., -8.333333333333332, 1.020538999289461*^-15}, {
       10., -16.666666666666664`, 2.041077998578922*^-15}, {
       10., -16.09876377148447, -4.31365075170868}, {
       10., -8.049381885742235, -2.15682537585434}, {10., -8.333333333333332, 
       1.020538999289461*^-15}}], 
      Line3DBox[{{10., -16.666666666666664`, 2.041077998578922*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       10., -16.09876377148447, -4.31365075170868}, {
       10., -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -8.049381885742235, -2.156825375854336}, {
       10., -7.216878364870323, -4.166666666666664}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., -8.049381885742235, -2.156825375854336}, {
       10., -16.09876377148447, -4.313650751708672}, {
       10., -14.433756729740645`, -8.333333333333329}, {
       10., -7.216878364870323, -4.166666666666664}, {
       10., -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{10., -16.09876377148447, -4.313650751708672}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -14.433756729740645`, -8.333333333333329}, {
       10., -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -7.216878364870323, -4.166666666666664}, {
       10., -5.892556509887897, -5.8925565098878945`}, {10., 0., 0.}, {10., 
       0., 0.}}], 
      Line3DBox[{{10., -7.216878364870323, -4.166666666666664}, {
       10., -14.433756729740645`, -8.333333333333329}, {
       10., -11.785113019775794`, -11.785113019775789`}, {
       10., -5.892556509887897, -5.8925565098878945`}, {
       10., -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{10., -14.433756729740645`, -8.333333333333329}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       10., -11.785113019775794`, -11.785113019775789`}, {
       10., -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -5.892556509887898, -5.892556509887893}, {
       10., -4.16666666666667, -7.216878364870319}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., -5.892556509887898, -5.892556509887893}, {
       10., -11.785113019775796`, -11.785113019775785`}, {
       10., -8.33333333333334, -14.433756729740638`}, {
       10., -4.16666666666667, -7.216878364870319}, {
       10., -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{10., -11.785113019775796`, -11.785113019775785`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -8.33333333333334, -14.433756729740638`}, {
       10., -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -4.16666666666667, -7.216878364870319}, {
       10., -2.156825375854346, -8.049381885742234}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., -4.16666666666667, -7.216878364870319}, {
       10., -8.33333333333334, -14.433756729740638`}, {
       10., -4.313650751708692, -16.098763771484467`}, {
       10., -2.156825375854346, -8.049381885742234}, {
       10., -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{10., -8.33333333333334, -14.433756729740638`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -4.313650751708692, -16.098763771484467`}, {
       10., -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -2.156825375854346, -8.049381885742234}, {
       10., -8.932295329768568*^-15, -8.333333333333332}, {10., 0., 0.}, {10.,
        0., 0.}}], 
      Line3DBox[{{10., -2.156825375854346, -8.049381885742234}, {
       10., -4.313650751708692, -16.098763771484467`}, {
       10., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       10., -8.932295329768568*^-15, -8.333333333333332}, {
       10., -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{10., -4.313650751708692, -16.098763771484467`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       10., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       10., -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{10., 0., 0.}, {
       10., -1.5308084989341913`*^-15, -8.333333333333332}, {10., 
       2.1568253758543356`, -8.049381885742235}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{
       10., -1.5308084989341913`*^-15, -8.333333333333332}, {
       10., -3.0616169978683826`*^-15, -16.666666666666664`}, {10., 
       4.313650751708671, -16.09876377148447}, {10., 
       2.1568253758543356`, -8.049381885742235}, {
       10., -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{10., -3.0616169978683826`*^-15, -16.666666666666664`}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {10., 
       4.313650751708671, -16.09876377148447}, {
       10., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
      Line3DBox[{{10., 0., 0.}, {10., 
       2.1568253758543356`, -8.049381885742235}, {10., 
       4.166666666666661, -7.216878364870325}, {10., 0., 0.}, {10., 0., 0.}}],
       Line3DBox[{{10., 2.1568253758543356`, -8.049381885742235}, {10., 
       4.313650751708671, -16.09876377148447}, {10., 
       8.333333333333321, -14.43375672974065}, {10., 
       4.166666666666661, -7.216878364870325}, {10., 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{10., 4.313650751708671, -16.09876377148447}, {10., 
       6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       8.333333333333321, -14.43375672974065}, {10., 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{10., 0., 0.}, {10., 
       4.166666666666661, -7.216878364870325}, {10., 
       5.89255650988789, -5.892556509887903}, {10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., 4.166666666666661, -7.216878364870325}, {10., 
       8.333333333333321, -14.43375672974065}, {10., 
       11.78511301977578, -11.785113019775807`}, {10., 
       5.89255650988789, -5.892556509887903}, {10., 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{10., 8.333333333333321, -14.43375672974065}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {10., 
       11.78511301977578, -11.785113019775807`}, {10., 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{10., 0., 0.}, {10., 
       5.8925565098878945`, -5.892556509887897}, {10., 
       7.216878364870319, -4.16666666666667}, {10., 0., 0.}, {10., 0., 0.}}], 
      Line3DBox[{{10., 5.8925565098878945`, -5.892556509887897}, {10., 
       11.785113019775789`, -11.785113019775794`}, {10., 
       14.433756729740638`, -8.33333333333334}, {10., 
       7.216878364870319, -4.16666666666667}, {10., 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{10., 11.785113019775789`, -11.785113019775794`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {10., 
       14.433756729740638`, -8.33333333333334}, {10., 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{10., 0., 0.}, {10., 7.216878364870319, -4.16666666666667}, {
       10., 8.049381885742234, -2.1568253758543463`}, {10., 0., 0.}, {10., 0.,
        0.}}], Line3DBox[{{10., 7.216878364870319, -4.16666666666667}, {10., 
       14.433756729740638`, -8.33333333333334}, {10., 
       16.098763771484467`, -4.313650751708693}, {10., 
       8.049381885742234, -2.1568253758543463`}, {10., 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{10., 14.433756729740638`, -8.33333333333334}, {10., 
       21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       16.098763771484467`, -4.313650751708693}, {10., 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{10., 0., 0.}, {10., 
       8.049381885742234, -2.1568253758543463`}, {10., 
       8.333333333333332, -9.442564829413298*^-15}, {10., 0., 0.}, {10., 0., 
       0.}}], Line3DBox[{{10., 8.049381885742234, -2.1568253758543463`}, {10.,
        16.098763771484467`, -4.313650751708693}, {10., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {10., 
       8.333333333333332, -9.442564829413298*^-15}, {10., 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{10., 16.098763771484467`, -4.313650751708693}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {10., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {10., 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], 
      Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317453040323`*^9},
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"During evaluation of In[54]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[PlanoConvexLens[100,50,10, GraphicDesign -> Solid]];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"In[55]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 8.333333333333332, 
      0.}, {0.6737579958920605, 8.049381885742235, 2.156825375854339}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333332, 0.}, {
      2.7504488342847893`, 16.666666666666664`, 0.}, {2.7504488342847893`, 
      16.09876377148447, 4.313650751708678}, {0.6737579958920605, 
      8.049381885742235, 2.156825375854339}, {0.6737579958920605, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {
      6.421974580955592, 25., 0.}, {6.421974580955592, 24.148145657226706`, 
      6.4704761275630185`}, {2.7504488342847893`, 16.09876377148447, 
      4.313650751708678}, {2.7504488342847893`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 8.049381885742235, 
      2.156825375854339}, {0.6737579958920676, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.049381885742235, 
      2.156825375854339}, {2.7504488342847893`, 16.09876377148447, 
      4.313650751708678}, {2.7504488342847893`, 14.433756729740645`, 
      8.333333333333332}, {0.6737579958920676, 7.216878364870323, 
      4.166666666666666}, {0.6737579958920605, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.09876377148447, 
      4.313650751708678}, {6.421974580955592, 24.148145657226706`, 
      6.4704761275630185`}, {6.421974580955592, 21.65063509461097, 
      12.499999999999998`}, {2.7504488342847893`, 14.433756729740645`, 
      8.333333333333332}, {2.7504488342847893`, 16.09876377148447, 
      4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920676, 7.216878364870323, 
      4.166666666666666}, {0.6737579958920605, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920676, 7.216878364870323, 
      4.166666666666666}, {2.7504488342847893`, 14.433756729740645`, 
      8.333333333333332}, {2.750448834284782, 11.785113019775793`, 
      11.785113019775789`}, {0.6737579958920605, 5.892556509887896, 
      5.8925565098878945`}, {0.6737579958920676, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{2.7504488342847893`, 14.433756729740645`, 
      8.333333333333332}, {6.421974580955592, 21.65063509461097, 
      12.499999999999998`}, {6.421974580955592, 17.67766952966369, 
      17.677669529663685`}, {2.750448834284782, 11.785113019775793`, 
      11.785113019775789`}, {2.7504488342847893`, 14.433756729740645`, 
      8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 5.892556509887896, 
      5.8925565098878945`}, {0.6737579958920676, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 5.892556509887896, 
      5.8925565098878945`}, {2.750448834284782, 11.785113019775793`, 
      11.785113019775789`}, {2.7504488342847893`, 8.333333333333336, 
      14.433756729740644`}, {0.6737579958920676, 4.166666666666668, 
      7.216878364870322}, {0.6737579958920605, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{2.750448834284782, 11.785113019775793`, 
      11.785113019775789`}, {6.421974580955592, 17.67766952966369, 
      17.677669529663685`}, {6.421974580955592, 12.500000000000004`, 
      21.650635094610966`}, {2.7504488342847893`, 8.333333333333336, 
      14.433756729740644`}, {2.750448834284782, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920676, 4.166666666666668, 
      7.216878364870322}, {0.6737579958920605, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920676, 4.166666666666668, 
      7.216878364870322}, {2.7504488342847893`, 8.333333333333336, 
      14.433756729740644`}, {2.7504488342847893`, 4.313650751708682, 
      16.09876377148447}, {0.6737579958920605, 2.156825375854341, 
      8.049381885742235}, {0.6737579958920676, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{2.7504488342847893`, 8.333333333333336, 
      14.433756729740644`}, {6.421974580955592, 12.500000000000004`, 
      21.650635094610966`}, {6.421974580955592, 6.470476127563024, 
      24.148145657226706`}, {2.7504488342847893`, 4.313650751708682, 
      16.09876377148447}, {2.7504488342847893`, 8.333333333333336, 
      14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 2.156825375854341, 
      8.049381885742235}, {0.6737579958920605, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 2.156825375854341, 
      8.049381885742235}, {2.7504488342847893`, 4.313650751708682, 
      16.09876377148447}, {2.7504488342847893`, 4.721282414706649*^-15, 
      16.666666666666664`}, {0.6737579958920605, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0.6737579958920605, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.7504488342847893`, 4.313650751708682, 
      16.09876377148447}, {6.421974580955592, 6.470476127563024, 
      24.148145657226706`}, {6.421974580955592, 7.0819236220599744`*^-15, 
      25.}, {2.7504488342847893`, 4.721282414706649*^-15, 
      16.666666666666664`}, {2.7504488342847893`, 4.313650751708682, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 5.102694996447305*^-16, 
      8.333333333333332}, {0.6737579958920605, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 5.102694996447305*^-16, 
      8.333333333333332}, {2.7504488342847893`, 1.020538999289461*^-15, 
      16.666666666666664`}, {2.7504488342847893`, -4.313650751708677, 
      16.09876377148447}, {0.6737579958920605, -2.1568253758543383`, 
      8.049381885742235}, {0.6737579958920605, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{2.7504488342847893`, 1.020538999289461*^-15, 
      16.666666666666664`}, {6.421974580955592, 1.5308084989341915`*^-15, 
      25.}, {6.421974580955592, -6.470476127563016, 24.148145657226706`}, {
      2.7504488342847893`, -4.313650751708677, 16.09876377148447}, {
      2.7504488342847893`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, -2.1568253758543383`, 
      8.049381885742235}, {0.6737579958920676, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -2.1568253758543383`, 
      8.049381885742235}, {2.7504488342847893`, -4.313650751708677, 
      16.09876377148447}, {2.7504488342847893`, -8.333333333333329, 
      14.433756729740645`}, {0.6737579958920676, -4.166666666666664, 
      7.216878364870323}, {0.6737579958920605, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.7504488342847893`, -4.313650751708677, 
      16.09876377148447}, {6.421974580955592, -6.470476127563016, 
      24.148145657226706`}, {6.421974580955592, -12.499999999999995`, 
      21.65063509461097}, {2.7504488342847893`, -8.333333333333329, 
      14.433756729740645`}, {2.7504488342847893`, -4.313650751708677, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920676, -4.166666666666664, 
      7.216878364870323}, {0.6737579958920605, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920676, -4.166666666666664, 
      7.216878364870323}, {2.7504488342847893`, -8.333333333333329, 
      14.433756729740645`}, {2.750448834284782, -11.785113019775789`, 
      11.785113019775793`}, {0.6737579958920605, -5.8925565098878945`, 
      5.892556509887896}, {0.6737579958920676, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{2.7504488342847893`, -8.333333333333329, 
      14.433756729740645`}, {6.421974580955592, -12.499999999999995`, 
      21.65063509461097}, {6.421974580955592, -17.677669529663685`, 
      17.67766952966369}, {2.750448834284782, -11.785113019775789`, 
      11.785113019775793`}, {2.7504488342847893`, -8.333333333333329, 
      14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, -5.8925565098878945`, 
      5.892556509887896}, {0.6737579958920676, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -5.8925565098878945`, 
      5.892556509887896}, {2.750448834284782, -11.785113019775789`, 
      11.785113019775793`}, {2.7504488342847893`, -14.433756729740645`, 
      8.333333333333332}, {0.6737579958920676, -7.216878364870323, 
      4.166666666666666}, {0.6737579958920605, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{2.750448834284782, -11.785113019775789`, 
      11.785113019775793`}, {6.421974580955592, -17.677669529663685`, 
      17.67766952966369}, {6.421974580955592, -21.65063509461097, 
      12.499999999999998`}, {2.7504488342847893`, -14.433756729740645`, 
      8.333333333333332}, {2.750448834284782, -11.785113019775789`, 
      11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920676, -7.21687836487032, 
      4.16666666666667}, {0.6737579958920605, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920676, -7.21687836487032, 
      4.16666666666667}, {2.750448834284782, -14.43375672974064, 
      8.33333333333334}, {2.7504488342847893`, -16.09876377148447, 
      4.313650751708684}, {0.6737579958920605, -8.049381885742235, 
      2.156825375854342}, {0.6737579958920676, -7.21687836487032, 
      4.16666666666667}}], 
     Polygon3DBox[{{2.750448834284782, -14.43375672974064, 
      8.33333333333334}, {6.421974580955599, -21.650635094610962`, 
      12.500000000000009`}, {6.421974580955592, -24.148145657226706`, 
      6.470476127563026}, {2.7504488342847893`, -16.09876377148447, 
      4.313650751708684}, {2.750448834284782, -14.43375672974064, 
      8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, -8.049381885742235, 
      2.156825375854342}, {0.6737579958920605, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.049381885742235, 
      2.156825375854342}, {2.7504488342847893`, -16.09876377148447, 
      4.313650751708684}, {2.7504488342847893`, -16.666666666666664`, 
      2.041077998578922*^-15}, {0.6737579958920605, -8.333333333333332, 
      1.020538999289461*^-15}, {0.6737579958920605, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.09876377148447, 
      4.313650751708684}, {6.421974580955592, -24.148145657226706`, 
      6.470476127563026}, {6.421974580955592, -25., 3.061616997868383*^-15}, {
      2.7504488342847893`, -16.666666666666664`, 2.041077998578922*^-15}, {
      2.7504488342847893`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, -8.333333333333332, 
      1.020538999289461*^-15}, {
      0.6737579958920605, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333332, 
      1.020538999289461*^-15}, {2.7504488342847893`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      2.7504488342847893`, -16.09876377148447, -4.31365075170868}, {
      0.6737579958920605, -8.049381885742235, -2.15682537585434}, {
      0.6737579958920605, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666664`, 
      2.041077998578922*^-15}, {6.421974580955592, -25., 
      3.061616997868383*^-15}, {
      6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
      2.7504488342847893`, -16.09876377148447, -4.31365075170868}, {
      2.7504488342847893`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920605, -8.049381885742235, -2.156825375854336}, {
      0.6737579958920676, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920605, -8.049381885742235, -2.156825375854336}, {
      2.7504488342847893`, -16.09876377148447, -4.313650751708672}, {
      2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
      0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
      0.6737579958920605, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      2.7504488342847893`, -16.09876377148447, -4.313650751708672}, {
      6.421974580955592, -24.14814565722671, -6.470476127563009}, {
      6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
      2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
      2.7504488342847893`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
      0.6737579958920605, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920676, -7.216878364870323, -4.166666666666664}, {
      2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
      2.7504488342847893`, -11.785113019775794`, -11.785113019775789`}, {
      0.6737579958920605, -5.892556509887897, -5.8925565098878945`}, {
      0.6737579958920676, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      2.7504488342847893`, -14.433756729740645`, -8.333333333333329}, {
      6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
      6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
      2.7504488342847893`, -11.785113019775794`, -11.785113019775789`}, {
      2.7504488342847893`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920605, -5.892556509887898, -5.892556509887893}, {
      0.6737579958920676, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920605, -5.892556509887898, -5.892556509887893}, {
      2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}, {
      2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
      0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
      0.6737579958920605, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}, {
      6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
      6.421974580955592, -12.50000000000001, -21.65063509461096}, {
      2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
      2.7504488342847893`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
      0.6737579958920605, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920676, -4.16666666666667, -7.216878364870319}, {
      2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
      2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
      0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
      0.6737579958920676, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      2.750448834284782, -8.33333333333334, -14.433756729740638`}, {
      6.421974580955592, -12.50000000000001, -21.65063509461096}, {
      6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
      2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
      2.750448834284782, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
      0.6737579958920605, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920605, -2.156825375854346, -8.049381885742234}, {
      2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
      2.7504488342847893`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0.6737579958920605, -8.932295329768568*^-15, -8.333333333333332}, {
      0.6737579958920605, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      2.7504488342847893`, -4.313650751708692, -16.098763771484467`}, {
      6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
      6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
      2.7504488342847893`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      2.7504488342847893`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}, {
      0.6737579958920605, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}, {
      2.7504488342847893`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      2.7504488342847893`, 4.313650751708671, -16.09876377148447}, {
      0.6737579958920605, 2.1568253758543356`, -8.049381885742235}, {
      0.6737579958920605, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      2.7504488342847893`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      6.421974580955592, -4.592425496802574*^-15, -25.}, {6.421974580955592, 
      6.470476127563007, -24.14814565722671}, {2.7504488342847893`, 
      4.313650751708671, -16.09876377148447}, {
      2.7504488342847893`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 
      2.1568253758543356`, -8.049381885742235}, {0.6737579958920605, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 
      2.1568253758543356`, -8.049381885742235}, {2.7504488342847893`, 
      4.313650751708671, -16.09876377148447}, {2.7504488342847893`, 
      8.333333333333321, -14.43375672974065}, {0.6737579958920605, 
      4.166666666666661, -7.216878364870325}, {0.6737579958920605, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{2.7504488342847893`, 
      4.313650751708671, -16.09876377148447}, {6.421974580955592, 
      6.470476127563007, -24.14814565722671}, {6.421974580955592, 
      12.499999999999984`, -21.650635094610976`}, {2.7504488342847893`, 
      8.333333333333321, -14.43375672974065}, {2.7504488342847893`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 
      4.166666666666661, -7.216878364870325}, {0.6737579958920605, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 
      4.166666666666661, -7.216878364870325}, {2.7504488342847893`, 
      8.333333333333321, -14.43375672974065}, {2.7504488342847893`, 
      11.78511301977578, -11.785113019775807`}, {0.6737579958920605, 
      5.89255650988789, -5.892556509887903}, {0.6737579958920605, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{2.7504488342847893`, 
      8.333333333333321, -14.43375672974065}, {6.421974580955592, 
      12.499999999999984`, -21.650635094610976`}, {6.421974580955599, 
      17.67766952966367, -17.67766952966371}, {2.7504488342847893`, 
      11.78511301977578, -11.785113019775807`}, {2.7504488342847893`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 
      5.8925565098878945`, -5.892556509887897}, {0.6737579958920676, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 
      5.8925565098878945`, -5.892556509887897}, {2.7504488342847893`, 
      11.785113019775789`, -11.785113019775794`}, {2.750448834284782, 
      14.433756729740638`, -8.33333333333334}, {0.6737579958920676, 
      7.216878364870319, -4.16666666666667}, {0.6737579958920605, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{2.7504488342847893`, 
      11.785113019775789`, -11.785113019775794`}, {6.421974580955592, 
      17.677669529663685`, -17.677669529663692`}, {6.421974580955592, 
      21.65063509461096, -12.50000000000001}, {2.750448834284782, 
      14.433756729740638`, -8.33333333333334}, {2.7504488342847893`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920676, 
      7.216878364870319, -4.16666666666667}, {0.6737579958920605, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920676, 
      7.216878364870319, -4.16666666666667}, {2.750448834284782, 
      14.433756729740638`, -8.33333333333334}, {2.7504488342847893`, 
      16.098763771484467`, -4.313650751708693}, {0.6737579958920605, 
      8.049381885742234, -2.1568253758543463`}, {0.6737579958920676, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{2.750448834284782, 
      14.433756729740638`, -8.33333333333334}, {6.421974580955592, 
      21.65063509461096, -12.50000000000001}, {6.421974580955592, 
      24.148145657226703`, -6.470476127563039}, {2.7504488342847893`, 
      16.098763771484467`, -4.313650751708693}, {2.750448834284782, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.6737579958920605, 
      8.049381885742234, -2.1568253758543463`}, {0.6737579958920605, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0.6737579958920605, 
      8.049381885742234, -2.1568253758543463`}, {2.7504488342847893`, 
      16.098763771484467`, -4.313650751708693}, {2.7504488342847893`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0.6737579958920605, 
      8.333333333333332, -9.442564829413298*^-15}, {0.6737579958920605, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{2.7504488342847893`, 
      16.098763771484467`, -4.313650751708693}, {6.421974580955592, 
      24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
      25., -2.8327694488239898`*^-14}, {2.7504488342847893`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {2.7504488342847893`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIA44dVhKaoOkAwMYWEJphLjH1Q3336haODjuKq07
8lDSASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBDZV0+EpVB9M3B1q
LswemPjp8+fXz5582wbmLpi4HUT9AXT1fyHuOPAMzXyoOw7A3BUBFX8CUXeA
FeouNP8e8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZx
x4HHUH0w8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNO
NPdA3QF3Fzy+oOEegeZfWDxBwuf3HgDLHA04
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{10., 0., 0.}, {10., 8.333333333333332, 0.}, {10., 
        8.049381885742235, 2.156825375854339}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{10., 8.333333333333332, 0.}, {10., 16.666666666666664`,
         0.}, {10., 16.09876377148447, 4.313650751708678}, {10., 
        8.049381885742235, 2.156825375854339}, {10., 8.333333333333332, 0.}}],
        Polygon3DBox[{{10., 16.666666666666664`, 0.}, {10., 25., 0.}, {10., 
        24.148145657226706`, 6.4704761275630185`}, {10., 16.09876377148447, 
        4.313650751708678}, {10., 16.666666666666664`, 0.}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 8.049381885742235, 
        2.156825375854339}, {10., 7.216878364870323, 4.166666666666666}, {10.,
         0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 8.049381885742235, 2.156825375854339}, {10., 
        16.09876377148447, 4.313650751708678}, {10., 14.433756729740645`, 
        8.333333333333332}, {10., 7.216878364870323, 4.166666666666666}, {10.,
         8.049381885742235, 2.156825375854339}}], 
       Polygon3DBox[{{10., 16.09876377148447, 4.313650751708678}, {10., 
        24.148145657226706`, 6.4704761275630185`}, {10., 21.65063509461097, 
        12.499999999999998`}, {10., 14.433756729740645`, 8.333333333333332}, {
        10., 16.09876377148447, 4.313650751708678}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 7.216878364870323, 
        4.166666666666666}, {10., 5.892556509887896, 5.8925565098878945`}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 7.216878364870323, 4.166666666666666}, {10., 
        14.433756729740645`, 8.333333333333332}, {10., 11.785113019775793`, 
        11.785113019775789`}, {10., 5.892556509887896, 5.8925565098878945`}, {
        10., 7.216878364870323, 4.166666666666666}}], 
       Polygon3DBox[{{10., 14.433756729740645`, 8.333333333333332}, {10., 
        21.65063509461097, 12.499999999999998`}, {10., 17.67766952966369, 
        17.677669529663685`}, {10., 11.785113019775793`, 
        11.785113019775789`}, {10., 14.433756729740645`, 8.333333333333332}}],
        Polygon3DBox[{{10., 0., 0.}, {10., 5.892556509887896, 
        5.8925565098878945`}, {10., 4.166666666666668, 7.216878364870322}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 5.892556509887896, 5.8925565098878945`}, {10., 
        11.785113019775793`, 11.785113019775789`}, {10., 8.333333333333336, 
        14.433756729740644`}, {10., 4.166666666666668, 7.216878364870322}, {
        10., 5.892556509887896, 5.8925565098878945`}}], 
       Polygon3DBox[{{10., 11.785113019775793`, 11.785113019775789`}, {10., 
        17.67766952966369, 17.677669529663685`}, {10., 12.500000000000004`, 
        21.650635094610966`}, {10., 8.333333333333336, 14.433756729740644`}, {
        10., 11.785113019775793`, 11.785113019775789`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 4.166666666666668, 
        7.216878364870322}, {10., 2.156825375854341, 8.049381885742235}, {10.,
         0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 4.166666666666668, 7.216878364870322}, {10., 
        8.333333333333336, 14.433756729740644`}, {10., 4.313650751708682, 
        16.09876377148447}, {10., 2.156825375854341, 8.049381885742235}, {10.,
         4.166666666666668, 7.216878364870322}}], 
       Polygon3DBox[{{10., 8.333333333333336, 14.433756729740644`}, {10., 
        12.500000000000004`, 21.650635094610966`}, {10., 6.470476127563024, 
        24.148145657226706`}, {10., 4.313650751708682, 16.09876377148447}, {
        10., 8.333333333333336, 14.433756729740644`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 2.156825375854341, 
        8.049381885742235}, {10., 2.3606412073533245`*^-15, 
        8.333333333333332}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 2.156825375854341, 8.049381885742235}, {10., 
        4.313650751708682, 16.09876377148447}, {10., 4.721282414706649*^-15, 
        16.666666666666664`}, {10., 2.3606412073533245`*^-15, 
        8.333333333333332}, {10., 2.156825375854341, 8.049381885742235}}], 
       Polygon3DBox[{{10., 4.313650751708682, 16.09876377148447}, {10., 
        6.470476127563024, 24.148145657226706`}, {10., 
        7.0819236220599744`*^-15, 25.}, {10., 4.721282414706649*^-15, 
        16.666666666666664`}, {10., 4.313650751708682, 16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 5.102694996447305*^-16, 
        8.333333333333332}, {10., -2.1568253758543383`, 8.049381885742235}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., 5.102694996447305*^-16, 8.333333333333332}, {10., 
        1.020538999289461*^-15, 16.666666666666664`}, {
        10., -4.313650751708677, 16.09876377148447}, {
        10., -2.1568253758543383`, 8.049381885742235}, {10., 
        5.102694996447305*^-16, 8.333333333333332}}], 
       Polygon3DBox[{{10., 1.020538999289461*^-15, 16.666666666666664`}, {10.,
         1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
        24.148145657226706`}, {10., -4.313650751708677, 16.09876377148447}, {
        10., 1.020538999289461*^-15, 16.666666666666664`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -2.1568253758543383`, 
        8.049381885742235}, {10., -4.166666666666664, 7.216878364870323}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., -2.1568253758543383`, 8.049381885742235}, {
        10., -4.313650751708677, 16.09876377148447}, {10., -8.333333333333329,
         14.433756729740645`}, {10., -4.166666666666664, 7.216878364870323}, {
        10., -2.1568253758543383`, 8.049381885742235}}], 
       Polygon3DBox[{{10., -4.313650751708677, 16.09876377148447}, {
        10., -6.470476127563016, 24.148145657226706`}, {
        10., -12.499999999999995`, 21.65063509461097}, {
        10., -8.333333333333329, 14.433756729740645`}, {
        10., -4.313650751708677, 16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -4.166666666666664, 
        7.216878364870323}, {10., -5.8925565098878945`, 5.892556509887896}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., -4.166666666666664, 7.216878364870323}, {
        10., -8.333333333333329, 14.433756729740645`}, {
        10., -11.785113019775789`, 11.785113019775793`}, {
        10., -5.8925565098878945`, 5.892556509887896}, {
        10., -4.166666666666664, 7.216878364870323}}], 
       Polygon3DBox[{{10., -8.333333333333329, 14.433756729740645`}, {
        10., -12.499999999999995`, 21.65063509461097}, {
        10., -17.677669529663685`, 17.67766952966369}, {
        10., -11.785113019775789`, 11.785113019775793`}, {
        10., -8.333333333333329, 14.433756729740645`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -5.8925565098878945`, 
        5.892556509887896}, {10., -7.216878364870323, 4.166666666666666}, {
        10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., -5.8925565098878945`, 5.892556509887896}, {
        10., -11.785113019775789`, 11.785113019775793`}, {
        10., -14.433756729740645`, 8.333333333333332}, {
        10., -7.216878364870323, 4.166666666666666}, {
        10., -5.8925565098878945`, 5.892556509887896}}], 
       Polygon3DBox[{{10., -11.785113019775789`, 11.785113019775793`}, {
        10., -17.677669529663685`, 17.67766952966369}, {
        10., -21.65063509461097, 12.499999999999998`}, {
        10., -14.433756729740645`, 8.333333333333332}, {
        10., -11.785113019775789`, 11.785113019775793`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -7.21687836487032, 
        4.16666666666667}, {10., -8.049381885742235, 2.156825375854342}, {10.,
         0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., -7.21687836487032, 4.16666666666667}, {
        10., -14.43375672974064, 8.33333333333334}, {10., -16.09876377148447, 
        4.313650751708684}, {10., -8.049381885742235, 2.156825375854342}, {
        10., -7.21687836487032, 4.16666666666667}}], 
       Polygon3DBox[{{10., -14.43375672974064, 8.33333333333334}, {
        10., -21.650635094610962`, 12.500000000000009`}, {
        10., -24.148145657226706`, 6.470476127563026}, {
        10., -16.09876377148447, 4.313650751708684}, {10., -14.43375672974064,
         8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -8.049381885742235, 
        2.156825375854342}, {10., -8.333333333333332, 
        1.020538999289461*^-15}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{10., -8.049381885742235, 2.156825375854342}, {
        10., -16.09876377148447, 4.313650751708684}, {
        10., -16.666666666666664`, 2.041077998578922*^-15}, {
        10., -8.333333333333332, 1.020538999289461*^-15}, {
        10., -8.049381885742235, 2.156825375854342}}], 
       Polygon3DBox[{{10., -16.09876377148447, 4.313650751708684}, {
        10., -24.148145657226706`, 6.470476127563026}, {10., -25., 
        3.061616997868383*^-15}, {10., -16.666666666666664`, 
        2.041077998578922*^-15}, {10., -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., -8.333333333333332, 
        1.020538999289461*^-15}, {
        10., -8.049381885742235, -2.15682537585434}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{10., -8.333333333333332, 
        1.020538999289461*^-15}, {10., -16.666666666666664`, 
        2.041077998578922*^-15}, {
        10., -16.09876377148447, -4.31365075170868}, {
        10., -8.049381885742235, -2.15682537585434}, {10., -8.333333333333332,
         1.020538999289461*^-15}}], 
       Polygon3DBox[{{10., -16.666666666666664`, 2.041077998578922*^-15}, {
        10., -25., 3.061616997868383*^-15}, {
        10., -24.148145657226706`, -6.47047612756302}, {
        10., -16.09876377148447, -4.31365075170868}, {
        10., -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -8.049381885742235, -2.156825375854336}, {
        10., -7.216878364870323, -4.166666666666664}, {10., 0., 0.}, {10., 0.,
         0.}}], Polygon3DBox[{{10., -8.049381885742235, -2.156825375854336}, {
        10., -16.09876377148447, -4.313650751708672}, {
        10., -14.433756729740645`, -8.333333333333329}, {
        10., -7.216878364870323, -4.166666666666664}, {
        10., -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{10., -16.09876377148447, -4.313650751708672}, {
        10., -24.14814565722671, -6.470476127563009}, {
        10., -21.65063509461097, -12.499999999999993`}, {
        10., -14.433756729740645`, -8.333333333333329}, {
        10., -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -7.216878364870323, -4.166666666666664}, {
        10., -5.892556509887897, -5.8925565098878945`}, {10., 0., 0.}, {10., 
        0., 0.}}], 
       Polygon3DBox[{{10., -7.216878364870323, -4.166666666666664}, {
        10., -14.433756729740645`, -8.333333333333329}, {
        10., -11.785113019775794`, -11.785113019775789`}, {
        10., -5.892556509887897, -5.8925565098878945`}, {
        10., -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{10., -14.433756729740645`, -8.333333333333329}, {
        10., -21.65063509461097, -12.499999999999993`}, {
        10., -17.677669529663692`, -17.677669529663685`}, {
        10., -11.785113019775794`, -11.785113019775789`}, {
        10., -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -5.892556509887898, -5.892556509887893}, {
        10., -4.16666666666667, -7.216878364870319}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{10., -5.892556509887898, -5.892556509887893}, {
        10., -11.785113019775796`, -11.785113019775785`}, {
        10., -8.33333333333334, -14.433756729740638`}, {
        10., -4.16666666666667, -7.216878364870319}, {
        10., -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{10., -11.785113019775796`, -11.785113019775785`}, {
        10., -17.677669529663696`, -17.677669529663678`}, {
        10., -12.50000000000001, -21.65063509461096}, {
        10., -8.33333333333334, -14.433756729740638`}, {
        10., -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -4.16666666666667, -7.216878364870319}, {
        10., -2.156825375854346, -8.049381885742234}, {10., 0., 0.}, {10., 0.,
         0.}}], Polygon3DBox[{{10., -4.16666666666667, -7.216878364870319}, {
        10., -8.33333333333334, -14.433756729740638`}, {
        10., -4.313650751708692, -16.098763771484467`}, {
        10., -2.156825375854346, -8.049381885742234}, {
        10., -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{10., -8.33333333333334, -14.433756729740638`}, {
        10., -12.50000000000001, -21.65063509461096}, {
        10., -6.470476127563038, -24.148145657226703`}, {
        10., -4.313650751708692, -16.098763771484467`}, {
        10., -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -2.156825375854346, -8.049381885742234}, {
        10., -8.932295329768568*^-15, -8.333333333333332}, {10., 0., 0.}, {
        10., 0., 0.}}], 
       Polygon3DBox[{{10., -2.156825375854346, -8.049381885742234}, {
        10., -4.313650751708692, -16.098763771484467`}, {
        10., -1.7864590659537137`*^-14, -16.666666666666664`}, {
        10., -8.932295329768568*^-15, -8.333333333333332}, {
        10., -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{10., -4.313650751708692, -16.098763771484467`}, {
        10., -6.470476127563038, -24.148145657226703`}, {
        10., -2.6796885989305705`*^-14, -25.}, {
        10., -1.7864590659537137`*^-14, -16.666666666666664`}, {
        10., -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        10., -1.5308084989341913`*^-15, -8.333333333333332}, {10., 
        2.1568253758543356`, -8.049381885742235}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{
        10., -1.5308084989341913`*^-15, -8.333333333333332}, {
        10., -3.0616169978683826`*^-15, -16.666666666666664`}, {10., 
        4.313650751708671, -16.09876377148447}, {10., 
        2.1568253758543356`, -8.049381885742235}, {
        10., -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{10., -3.0616169978683826`*^-15, -16.666666666666664`}, {
        10., -4.592425496802574*^-15, -25.}, {10., 
        6.470476127563007, -24.14814565722671}, {10., 
        4.313650751708671, -16.09876377148447}, {
        10., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 
        2.1568253758543356`, -8.049381885742235}, {10., 
        4.166666666666661, -7.216878364870325}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{10., 2.1568253758543356`, -8.049381885742235}, {
        10., 4.313650751708671, -16.09876377148447}, {10., 
        8.333333333333321, -14.43375672974065}, {10., 
        4.166666666666661, -7.216878364870325}, {10., 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{10., 4.313650751708671, -16.09876377148447}, {10., 
        6.470476127563007, -24.14814565722671}, {10., 
        12.499999999999984`, -21.650635094610976`}, {10., 
        8.333333333333321, -14.43375672974065}, {10., 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 
        4.166666666666661, -7.216878364870325}, {10., 
        5.89255650988789, -5.892556509887903}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{10., 4.166666666666661, -7.216878364870325}, {10., 
        8.333333333333321, -14.43375672974065}, {10., 
        11.78511301977578, -11.785113019775807`}, {10., 
        5.89255650988789, -5.892556509887903}, {10., 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{10., 8.333333333333321, -14.43375672974065}, {10., 
        12.499999999999984`, -21.650635094610976`}, {10., 
        17.67766952966367, -17.67766952966371}, {10., 
        11.78511301977578, -11.785113019775807`}, {10., 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 
        5.8925565098878945`, -5.892556509887897}, {10., 
        7.216878364870319, -4.16666666666667}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{10., 5.8925565098878945`, -5.892556509887897}, {10., 
        11.785113019775789`, -11.785113019775794`}, {10., 
        14.433756729740638`, -8.33333333333334}, {10., 
        7.216878364870319, -4.16666666666667}, {10., 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{10., 11.785113019775789`, -11.785113019775794`}, {10., 
        17.677669529663685`, -17.677669529663692`}, {10., 
        21.65063509461096, -12.50000000000001}, {10., 
        14.433756729740638`, -8.33333333333334}, {10., 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 
        7.216878364870319, -4.16666666666667}, {10., 
        8.049381885742234, -2.1568253758543463`}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{10., 7.216878364870319, -4.16666666666667}, {
        10., 14.433756729740638`, -8.33333333333334}, {10., 
        16.098763771484467`, -4.313650751708693}, {10., 
        8.049381885742234, -2.1568253758543463`}, {10., 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{10., 14.433756729740638`, -8.33333333333334}, {10., 
        21.65063509461096, -12.50000000000001}, {10., 
        24.148145657226703`, -6.470476127563039}, {10., 
        16.098763771484467`, -4.313650751708693}, {10., 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {10., 
        8.049381885742234, -2.1568253758543463`}, {10., 
        8.333333333333332, -9.442564829413298*^-15}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{10., 8.049381885742234, -2.1568253758543463`}, {
        10., 16.098763771484467`, -4.313650751708693}, {10., 
        16.666666666666664`, -1.8885129658826596`*^-14}, {10., 
        8.333333333333332, -9.442564829413298*^-15}, {10., 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{10., 16.098763771484467`, -4.313650751708693}, {10., 
        24.148145657226703`, -6.470476127563039}, {10., 
        25., -2.8327694488239898`*^-14}, {10., 
        16.666666666666664`, -1.8885129658826596`*^-14}, {10., 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhhQcYDQlg4MKEDFwePqhvtvVC0cHHeV1h15KOkA
E3/2u4V1wjJTh/9goAEX35EmfKB6raHDdigNE2cC05oOT6H6YOLuUHNh9sDE
T58/v3725Ns2qO5ScbCDqD+Arv4vxB0HnqGZD3XHgR1o7nkCUXeAFeouNP8e
8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZxx4HHUH0w
8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNONPdA3QF3
Fzy+oOEegeZfWDxBwuf3HgC80slb
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
          24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
          24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
          0.}}], Polygon3DBox[{{6.421974580955592, 24.148145657226706`, 
          6.4704761275630185`}, {10., 24.148145657226706`, 
          6.4704761275630185`}, {10., 21.65063509461097, 
          12.499999999999998`}, {6.421974580955592, 21.65063509461097, 
          12.499999999999998`}, {6.421974580955592, 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{6.421974580955592, 21.65063509461097, 
          12.499999999999998`}, {10., 21.65063509461097, 
          12.499999999999998`}, {10., 17.67766952966369, 
          17.677669529663685`}, {6.421974580955592, 17.67766952966369, 
          17.677669529663685`}, {6.421974580955592, 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{6.421974580955592, 17.67766952966369, 
          17.677669529663685`}, {10., 17.67766952966369, 
          17.677669529663685`}, {10., 12.500000000000004`, 
          21.650635094610966`}, {6.421974580955592, 12.500000000000004`, 
          21.650635094610966`}, {6.421974580955592, 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{6.421974580955592, 12.500000000000004`, 
          21.650635094610966`}, {10., 12.500000000000004`, 
          21.650635094610966`}, {10., 6.470476127563024, 
          24.148145657226706`}, {6.421974580955592, 6.470476127563024, 
          24.148145657226706`}, {6.421974580955592, 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{6.421974580955592, 6.470476127563024, 
          24.148145657226706`}, {10., 6.470476127563024, 
          24.148145657226706`}, {10., 7.0819236220599744`*^-15, 25.}, {
          6.421974580955592, 7.0819236220599744`*^-15, 25.}, {
          6.421974580955592, 6.470476127563024, 24.148145657226706`}}], 
         Polygon3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {
          10., 1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
          24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
          24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
          25.}}], Polygon3DBox[{{6.421974580955592, -6.470476127563016, 
          24.148145657226706`}, {10., -6.470476127563016, 
          24.148145657226706`}, {10., -12.499999999999995`, 
          21.65063509461097}, {6.421974580955592, -12.499999999999995`, 
          21.65063509461097}, {6.421974580955592, -6.470476127563016, 
          24.148145657226706`}}], 
         Polygon3DBox[{{6.421974580955592, -12.499999999999995`, 
          21.65063509461097}, {10., -12.499999999999995`, 
          21.65063509461097}, {10., -17.677669529663685`, 
          17.67766952966369}, {6.421974580955592, -17.677669529663685`, 
          17.67766952966369}, {6.421974580955592, -12.499999999999995`, 
          21.65063509461097}}], 
         Polygon3DBox[{{6.421974580955592, -17.677669529663685`, 
          17.67766952966369}, {10., -17.677669529663685`, 
          17.67766952966369}, {10., -21.65063509461097, 
          12.499999999999998`}, {6.421974580955592, -21.65063509461097, 
          12.499999999999998`}, {6.421974580955592, -17.677669529663685`, 
          17.67766952966369}}], 
         Polygon3DBox[{{6.421974580955599, -21.650635094610962`, 
          12.500000000000009`}, {10., -21.650635094610962`, 
          12.500000000000009`}, {10., -24.148145657226706`, 
          6.470476127563026}, {6.421974580955592, -24.148145657226706`, 
          6.470476127563026}, {6.421974580955599, -21.650635094610962`, 
          12.500000000000009`}}], 
         Polygon3DBox[{{6.421974580955592, -24.148145657226706`, 
          6.470476127563026}, {10., -24.148145657226706`, 
          6.470476127563026}, {10., -25., 3.061616997868383*^-15}, {
          6.421974580955592, -25., 3.061616997868383*^-15}, {
          6.421974580955592, -24.148145657226706`, 6.470476127563026}}], 
         Polygon3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
          10., -25., 3.061616997868383*^-15}, {
          10., -24.148145657226706`, -6.47047612756302}, {
          6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
          6.421974580955592, -25., 3.061616997868383*^-15}}], 
         Polygon3DBox[{{
          6.421974580955592, -24.14814565722671, -6.470476127563009}, {
          10., -24.14814565722671, -6.470476127563009}, {
          10., -21.65063509461097, -12.499999999999993`}, {
          6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
          6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{
          6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
          10., -21.65063509461097, -12.499999999999993`}, {
          10., -17.677669529663692`, -17.677669529663685`}, {
          6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
          6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{
          6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
          10., -17.677669529663696`, -17.677669529663678`}, {
          10., -12.50000000000001, -21.65063509461096}, {
          6.421974580955592, -12.50000000000001, -21.65063509461096}, {
          6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{
          6.421974580955592, -12.50000000000001, -21.65063509461096}, {
          10., -12.50000000000001, -21.65063509461096}, {
          10., -6.470476127563038, -24.148145657226703`}, {
          6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
          6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{
          6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
          10., -6.470476127563038, -24.148145657226703`}, {
          10., -2.6796885989305705`*^-14, -25.}, {
          6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
          6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
          10., -4.592425496802574*^-15, -25.}, {10., 
          6.470476127563007, -24.14814565722671}, {6.421974580955592, 
          6.470476127563007, -24.14814565722671}, {
          6.421974580955592, -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{6.421974580955592, 
          6.470476127563007, -24.14814565722671}, {10., 
          6.470476127563007, -24.14814565722671}, {10., 
          12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
          12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{6.421974580955592, 
          12.499999999999984`, -21.650635094610976`}, {10., 
          12.499999999999984`, -21.650635094610976`}, {10., 
          17.67766952966367, -17.67766952966371}, {6.421974580955599, 
          17.67766952966367, -17.67766952966371}, {6.421974580955592, 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{6.421974580955592, 
          17.677669529663685`, -17.677669529663692`}, {10., 
          17.677669529663685`, -17.677669529663692`}, {10., 
          21.65063509461096, -12.50000000000001}, {6.421974580955592, 
          21.65063509461096, -12.50000000000001}, {6.421974580955592, 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{6.421974580955592, 
          21.65063509461096, -12.50000000000001}, {10., 
          21.65063509461096, -12.50000000000001}, {10., 
          24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
          24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{6.421974580955592, 
          24.148145657226703`, -6.470476127563039}, {10., 
          24.148145657226703`, -6.470476127563039}, {10., 
          25., -2.8327694488239898`*^-14}, {6.421974580955592, 
          25., -2.8327694488239898`*^-14}, {6.421974580955592, 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731745528097*^9},
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"During evaluation of In[55]:="]
}, Open  ]],

Cell[TextData[StyleBox["",
 Evaluatable->False,
 AspectRatioFixed->True]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[TextData[{
 StyleBox["An additional method is to directly include a suboption of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GraphicDesign", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" at the time of rendering. Here, we replace ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mesh",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" of the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["EdgeRendering",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" suboption with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Fill",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\tPlanoConvexLens[100,50,10,EdgeRendering->Fill]];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"In[56]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0.5], EdgeForm[None], 
      Polygon3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Polygon3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Polygon3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Polygon3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Polygon3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Polygon3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Polygon3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Polygon3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Polygon3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Polygon3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Polygon3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Polygon3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Polygon3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Polygon3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Polygon3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Polygon3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Polygon3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Polygon3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Polygon3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Polygon3DBox[{{6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {10., 
       6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Polygon3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Polygon3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Polygon3DBox[{{6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {10., 
       21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Polygon3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317456763*^9},
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"},
 CellLabel->"During evaluation of In[56]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["In this way we can custom-render various objects. Similarly, you \
can change the rendering options of rays. Ray-rendering options include ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayLineRGB",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayPointRGB",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayLineThickness",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayPointSize",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayLineStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayPointStyle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[". By including one or more of these options within a ray-source \
function, the rays from that source will be rendered accordingly. \
Ray-rendering options may also be inserted into ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox["and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ShowSystem",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to change the rendering effects, even after the ray tracing is \
completed. See Section 9.4 for details about ray-rendering parameters.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.10 ModelRayColor", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}],

Cell[TextData[{
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" determines the way rays get rendered including their colors. Here \
we define ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],

Cell[TextData[{
 StyleBox["\nModelRayColor[",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["rayparameterlabels",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["{",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["minvalue",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["maxvalue",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["}]",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["Function[",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["parametervalue",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["]",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" attempts to convert the ray parameters indicated by ",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabels",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" into rendered color values.\n",
  CellFrame->True,
  CellMargins->{{50, 153}, {Inherited, Inherited}},
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True]
}], "Text",
 CellFrame->True,
 CellMargins->{{50, 153}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],

Cell[TextData[{
 StyleBox["Custom ray-rendering schemes can be defined for various \
ray-parameter labels by using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor[",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["{",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["min_",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["max_",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["}]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Function[{",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["parametervalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["}",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["function",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["[",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["parametervalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["]",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", where ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["function",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["[",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["parametervalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["] returns graphics styles such as ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Hue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["GreyLevel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RGBColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  ",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],

Cell[TextData[{
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" uses the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rayparameterlabel",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" from the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["TurboPlot", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[". Arguments ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["minvalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["maxvalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" are calculated based on the minimum and maximum parameter values \
from the currently displayed rays, selected by the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["RayChoice",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option. As a default for undefined ray parameter labels given by \
the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" assigns a color ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Hue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to each ray according to the segment parameter's numerical \
position between ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["minvalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["maxvalue",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", with red being assigned to the maximum encountered parameter \
value. Parameters composed of three elements are evaluated by independently \
representing each element with a red, green, or blue value. Two-element \
parameters are assigned a red and a green value, each representing an \
element. ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" option ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ColorView->WaveLength",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" attempts to match the wavelength of the ray to the perceived \
visual color of that wavelength. Before the user can define new ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" functions, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ModelRayColor",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" must be unprotected.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],

Cell[TextData[{
 "In practice, however, ",
 StyleBox["ModelRayColor", "Input"],
 " is rarely altered or directly specified by the user."
}], "Text",
 CellTags->{"ModelRayColor", "ColorView", "PR6.10"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->"ColorView"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.11 Labelling of Components", "Section",
 CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}],

Cell["\<\
Another topic worthy of consideration is Optica's treatment of component \
labelling.  Basically, there are two ways of  using labels: in your graphics \
and in the printed output of your system, but  often, these two things go \
hand in hand.  Labels can be very important for  both illustrating and \
explaining your systems.  In this section, we will  examine Optica's use of \
labels with components.\
\>", "Text",
 CellChangeTimes->{{3.566158949019801*^9, 3.566158949114807*^9}},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],

Cell[CellGroupData[{

Cell["6.11.1 Labelling Your Printed Output", "Subsection",
 CellTags->{
  "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
   "PR6.11.1", "PR6.11"}],

Cell["\<\
Optica provides several approaches for attaching labels, but the most common  \
method is to include the label as a string for the last argument before the  \
options of your component function.\
\>", "Text",
 CellChangeTimes->{3.566158949213941*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],

Cell[CellGroupData[{

Cell["\<\
lens = PlanoConvexLens[100,50,10,\"lens\",GraphicDesign->Solid]
Move[lens,100]\
\>", "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"In[57]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox["\<\"lens\"\>",
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367930963839*^9, 3.566158866112567*^9, 
  3.5661589924580383`*^9, 3.5672683501063747`*^9, 3.614730560707608*^9, 
  3.614731745787269*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"Out[57]="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Move", "[", 
     RowBox[{"\<\"lens\"\>", ",", "100.`"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367930963839*^9, 3.566158866112567*^9, 
  3.5661589924580383`*^9, 3.5672683501063747`*^9, 3.614730560707608*^9, 
  3.6147317458156977`*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"Out[58]="]
}, Open  ]],

Cell["\<\
If no label is used, Optica simply echos the input function back in the \
printed output.\
\>", "Text",
 CellChangeTimes->{3.566158949314007*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],

Cell[CellGroupData[{

Cell["PlanoConvexLens[100,50,10,GraphicDesign->Solid]", "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"In[59]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"PlanoConvexLens", "[", 
     RowBox[{"100", ",", "50", ",", "10", ",", 
      RowBox[{"{", 
       RowBox[{"GraphicDesign", "\[Rule]", "Solid"}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5633679310975037`*^9, 3.566158866163813*^9, 
  3.5661589932147703`*^9, 3.567268350422474*^9, 3.6147305608856897`*^9, 
  3.614731745932053*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
It can be especially helpful to give the same names to your variables and \
labels.  This lets you keep better track of the different components in your \
system.  However, the label and variable don't always have to match each \
other:\
\>", "Text",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],

Cell[CellGroupData[{

Cell["\<\
differentlens = 
PlanoConvexLens[100,50,10,\"anotherlens\",GraphicDesign->Solid]\
\>", "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"In[60]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox["\<\"anotherlens\"\>",
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.56336793119482*^9, 3.566158866213728*^9, 
  3.566158993588773*^9, 3.567268350646474*^9, 3.614730560909924*^9, 
  3.6147317460518093`*^9},
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"},
 CellLabel->"Out[60]="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.11.2 Labelling Your Graphics", "Subsection",
 CellTags->{
  "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
   "PR6.11.2"}],

Cell["\<\
Optica uses the label not only in the printed output, but also in the display \
of  graphics.  Here two lenses together are rendered.\
\>", "Text",
 CellChangeTimes->{3.5661589494001904`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["\<\
lens = PlanoConvexLens[100,50,10,\"lens\",GraphicDesign->Solid];

AnalyzeSystem[{lens, Move[lens,100]},PlotType->TopView]\
\>", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[61]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.333333333333332}, {
      0.6737579958920605, 8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333332}, {
      2.7504488342847893`, 16.666666666666664`}, {2.7504488342847893`, 
      16.09876377148447}, {0.6737579958920605, 8.049381885742235}, {
      0.6737579958920605, 8.333333333333332}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {
      6.421974580955592, 25.}, {6.421974580955592, 24.148145657226706`}, {
      2.7504488342847893`, 16.09876377148447}, {2.7504488342847893`, 
      16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.049381885742235}, {
      0.6737579958920676, 7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.049381885742235}, {
      2.7504488342847893`, 16.09876377148447}, {2.7504488342847893`, 
      14.433756729740645`}, {0.6737579958920676, 7.216878364870323}, {
      0.6737579958920605, 8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, 16.09876377148447}, {6.421974580955592,
       24.148145657226706`}, {6.421974580955592, 21.65063509461097}, {
      2.7504488342847893`, 14.433756729740645`}, {2.7504488342847893`, 
      16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 7.216878364870323}, {
      0.6737579958920605, 5.892556509887896}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 7.216878364870323}, {
      2.7504488342847893`, 14.433756729740645`}, {2.750448834284782, 
      11.785113019775793`}, {0.6737579958920605, 5.892556509887896}, {
      0.6737579958920676, 7.216878364870323}}], 
     PolygonBox[{{2.7504488342847893`, 14.433756729740645`}, {
      6.421974580955592, 21.65063509461097}, {6.421974580955592, 
      17.67766952966369}, {2.750448834284782, 11.785113019775793`}, {
      2.7504488342847893`, 14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.892556509887896}, {
      0.6737579958920676, 4.166666666666668}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.892556509887896}, {2.750448834284782, 
      11.785113019775793`}, {2.7504488342847893`, 8.333333333333336}, {
      0.6737579958920676, 4.166666666666668}, {0.6737579958920605, 
      5.892556509887896}}], 
     PolygonBox[{{2.750448834284782, 11.785113019775793`}, {6.421974580955592,
       17.67766952966369}, {6.421974580955592, 12.500000000000004`}, {
      2.7504488342847893`, 8.333333333333336}, {2.750448834284782, 
      11.785113019775793`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 4.166666666666668}, {
      0.6737579958920605, 2.156825375854341}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 4.166666666666668}, {
      2.7504488342847893`, 8.333333333333336}, {2.7504488342847893`, 
      4.313650751708682}, {0.6737579958920605, 2.156825375854341}, {
      0.6737579958920676, 4.166666666666668}}], 
     PolygonBox[{{2.7504488342847893`, 8.333333333333336}, {6.421974580955592,
       12.500000000000004`}, {6.421974580955592, 6.470476127563024}, {
      2.7504488342847893`, 4.313650751708682}, {2.7504488342847893`, 
      8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 2.156825375854341}, {
      0.6737579958920605, 2.3606412073533245`*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 2.156825375854341}, {
      2.7504488342847893`, 4.313650751708682}, {2.7504488342847893`, 
      4.721282414706649*^-15}, {0.6737579958920605, 
      2.3606412073533245`*^-15}, {0.6737579958920605, 2.156825375854341}}], 
     PolygonBox[{{2.7504488342847893`, 4.313650751708682}, {6.421974580955592,
       6.470476127563024}, {6.421974580955592, 7.0819236220599744`*^-15}, {
      2.7504488342847893`, 4.721282414706649*^-15}, {2.7504488342847893`, 
      4.313650751708682}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.102694996447305*^-16}, {
      0.6737579958920605, -2.1568253758543383`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.102694996447305*^-16}, {
      2.7504488342847893`, 1.020538999289461*^-15}, {
      2.7504488342847893`, -4.313650751708677}, {
      0.6737579958920605, -2.1568253758543383`}, {0.6737579958920605, 
      5.102694996447305*^-16}}], 
     PolygonBox[{{2.7504488342847893`, 1.020538999289461*^-15}, {
      6.421974580955592, 1.5308084989341915`*^-15}, {
      6.421974580955592, -6.470476127563016}, {
      2.7504488342847893`, -4.313650751708677}, {2.7504488342847893`, 
      1.020538999289461*^-15}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -2.1568253758543383`}, {
      0.6737579958920676, -4.166666666666664}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -2.1568253758543383`}, {
      2.7504488342847893`, -4.313650751708677}, {
      2.7504488342847893`, -8.333333333333329}, {
      0.6737579958920676, -4.166666666666664}, {
      0.6737579958920605, -2.1568253758543383`}}], 
     PolygonBox[{{2.7504488342847893`, -4.313650751708677}, {
      6.421974580955592, -6.470476127563016}, {
      6.421974580955592, -12.499999999999995`}, {
      2.7504488342847893`, -8.333333333333329}, {
      2.7504488342847893`, -4.313650751708677}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -4.166666666666664}, {
      0.6737579958920605, -5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -4.166666666666664}, {
      2.7504488342847893`, -8.333333333333329}, {
      2.750448834284782, -11.785113019775789`}, {
      0.6737579958920605, -5.8925565098878945`}, {
      0.6737579958920676, -4.166666666666664}}], 
     PolygonBox[{{2.7504488342847893`, -8.333333333333329}, {
      6.421974580955592, -12.499999999999995`}, {
      6.421974580955592, -17.677669529663685`}, {
      2.750448834284782, -11.785113019775789`}, {
      2.7504488342847893`, -8.333333333333329}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -5.8925565098878945`}, {
      0.6737579958920676, -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -5.8925565098878945`}, {
      2.750448834284782, -11.785113019775789`}, {
      2.7504488342847893`, -14.433756729740645`}, {
      0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -5.8925565098878945`}}], 
     PolygonBox[{{2.750448834284782, -11.785113019775789`}, {
      6.421974580955592, -17.677669529663685`}, {
      6.421974580955592, -21.65063509461097}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.750448834284782, -11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -7.21687836487032}, {
      0.6737579958920605, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -7.21687836487032}, {
      2.750448834284782, -14.43375672974064}, {
      2.7504488342847893`, -16.09876377148447}, {
      0.6737579958920605, -8.049381885742235}, {
      0.6737579958920676, -7.21687836487032}}], 
     PolygonBox[{{2.750448834284782, -14.43375672974064}, {
      6.421974580955599, -21.650635094610962`}, {
      6.421974580955592, -24.148145657226706`}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.750448834284782, -14.43375672974064}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.049381885742235}, {
      0.6737579958920605, -8.333333333333332}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.049381885742235}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -16.666666666666664`}, {
      0.6737579958920605, -8.333333333333332}, {
      0.6737579958920605, -8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, -16.09876377148447}, {
      6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}, {
      2.7504488342847893`, -16.666666666666664`}, {
      2.7504488342847893`, -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.333333333333332}, {
      0.6737579958920605, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333332}, {
      2.7504488342847893`, -16.666666666666664`}, {
      2.7504488342847893`, -16.09876377148447}, {
      0.6737579958920605, -8.049381885742235}, {
      0.6737579958920605, -8.333333333333332}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666664`}, {
      6.421974580955592, -25.}, {6.421974580955592, -24.148145657226706`}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.049381885742235}, {
      0.6737579958920676, -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.049381885742235}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -14.433756729740645`}, {
      0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, -16.09876377148447}, {
      6.421974580955592, -24.14814565722671}, {
      6.421974580955592, -21.65063509461097}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.7504488342847893`, -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -5.892556509887897}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -7.216878364870323}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.7504488342847893`, -11.785113019775794`}, {
      0.6737579958920605, -5.892556509887897}, {
      0.6737579958920676, -7.216878364870323}}], 
     PolygonBox[{{2.7504488342847893`, -14.433756729740645`}, {
      6.421974580955592, -21.65063509461097}, {
      6.421974580955592, -17.677669529663692`}, {
      2.7504488342847893`, -11.785113019775794`}, {
      2.7504488342847893`, -14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -5.892556509887898}, {
      0.6737579958920676, -4.16666666666667}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -5.892556509887898}, {
      2.7504488342847893`, -11.785113019775796`}, {
      2.750448834284782, -8.33333333333334}, {
      0.6737579958920676, -4.16666666666667}, {
      0.6737579958920605, -5.892556509887898}}], 
     PolygonBox[{{2.7504488342847893`, -11.785113019775796`}, {
      6.421974580955592, -17.677669529663696`}, {
      6.421974580955592, -12.50000000000001}, {
      2.750448834284782, -8.33333333333334}, {
      2.7504488342847893`, -11.785113019775796`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -4.16666666666667}, {
      0.6737579958920605, -2.156825375854346}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -4.16666666666667}, {
      2.750448834284782, -8.33333333333334}, {
      2.7504488342847893`, -4.313650751708692}, {
      0.6737579958920605, -2.156825375854346}, {
      0.6737579958920676, -4.16666666666667}}], 
     PolygonBox[{{2.750448834284782, -8.33333333333334}, {
      6.421974580955592, -12.50000000000001}, {
      6.421974580955592, -6.470476127563038}, {
      2.7504488342847893`, -4.313650751708692}, {
      2.750448834284782, -8.33333333333334}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -2.156825375854346}, {
      0.6737579958920605, -8.932295329768568*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -2.156825375854346}, {
      2.7504488342847893`, -4.313650751708692}, {
      2.7504488342847893`, -1.7864590659537137`*^-14}, {
      0.6737579958920605, -8.932295329768568*^-15}, {
      0.6737579958920605, -2.156825375854346}}], 
     PolygonBox[{{2.7504488342847893`, -4.313650751708692}, {
      6.421974580955592, -6.470476127563038}, {
      6.421974580955592, -2.6796885989305705`*^-14}, {
      2.7504488342847893`, -1.7864590659537137`*^-14}, {
      2.7504488342847893`, -4.313650751708692}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -1.5308084989341913`*^-15}, {
      0.6737579958920605, 2.1568253758543356`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -1.5308084989341913`*^-15}, {
      2.7504488342847893`, -3.0616169978683826`*^-15}, {2.7504488342847893`, 
      4.313650751708671}, {0.6737579958920605, 2.1568253758543356`}, {
      0.6737579958920605, -1.5308084989341913`*^-15}}], 
     PolygonBox[{{2.7504488342847893`, -3.0616169978683826`*^-15}, {
      6.421974580955592, -4.592425496802574*^-15}, {6.421974580955592, 
      6.470476127563007}, {2.7504488342847893`, 4.313650751708671}, {
      2.7504488342847893`, -3.0616169978683826`*^-15}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 2.1568253758543356`}, {
      0.6737579958920605, 4.166666666666661}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 2.1568253758543356`}, {
      2.7504488342847893`, 4.313650751708671}, {2.7504488342847893`, 
      8.333333333333321}, {0.6737579958920605, 4.166666666666661}, {
      0.6737579958920605, 2.1568253758543356`}}], 
     PolygonBox[{{2.7504488342847893`, 4.313650751708671}, {6.421974580955592,
       6.470476127563007}, {6.421974580955592, 12.499999999999984`}, {
      2.7504488342847893`, 8.333333333333321}, {2.7504488342847893`, 
      4.313650751708671}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 4.166666666666661}, {
      0.6737579958920605, 5.89255650988789}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 4.166666666666661}, {
      2.7504488342847893`, 8.333333333333321}, {2.7504488342847893`, 
      11.78511301977578}, {0.6737579958920605, 5.89255650988789}, {
      0.6737579958920605, 4.166666666666661}}], 
     PolygonBox[{{2.7504488342847893`, 8.333333333333321}, {6.421974580955592,
       12.499999999999984`}, {6.421974580955599, 17.67766952966367}, {
      2.7504488342847893`, 11.78511301977578}, {2.7504488342847893`, 
      8.333333333333321}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.8925565098878945`}, {
      0.6737579958920676, 7.216878364870319}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.8925565098878945`}, {
      2.7504488342847893`, 11.785113019775789`}, {2.750448834284782, 
      14.433756729740638`}, {0.6737579958920676, 7.216878364870319}, {
      0.6737579958920605, 5.8925565098878945`}}], 
     PolygonBox[{{2.7504488342847893`, 11.785113019775789`}, {
      6.421974580955592, 17.677669529663685`}, {6.421974580955592, 
      21.65063509461096}, {2.750448834284782, 14.433756729740638`}, {
      2.7504488342847893`, 11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 7.216878364870319}, {
      0.6737579958920605, 8.049381885742234}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 7.216878364870319}, {2.750448834284782, 
      14.433756729740638`}, {2.7504488342847893`, 16.098763771484467`}, {
      0.6737579958920605, 8.049381885742234}, {0.6737579958920676, 
      7.216878364870319}}], 
     PolygonBox[{{2.750448834284782, 14.433756729740638`}, {6.421974580955592,
       21.65063509461096}, {6.421974580955592, 24.148145657226703`}, {
      2.7504488342847893`, 16.098763771484467`}, {2.750448834284782, 
      14.433756729740638`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.049381885742234}, {
      0.6737579958920605, 8.333333333333332}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.049381885742234}, {
      2.7504488342847893`, 16.098763771484467`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333332}, {
      0.6737579958920605, 8.049381885742234}}], 
     PolygonBox[{{2.7504488342847893`, 16.098763771484467`}, {
      6.421974580955592, 24.148145657226703`}, {6.421974580955592, 25.}, {
      2.7504488342847893`, 16.666666666666664`}, {2.7504488342847893`, 
      16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQHXDqsJTUBkkHBjCwdIDxPa5uuP9G1QLOf/a7hXXC
MlM4f0ea8IHqtYZwPhNYvyac776rtO7IQ0k4//T58+tnT75tA+PbQeQPwPh/
/4OABpy/HWL+gQgo/wnE/gNo7juA5n443xNN/hma/l1Q82F8Noj74fxwNPfd
uH378JZ1X/bA+CZo/vsOcb8Dmvvh/Mdo4eeOFr6w8AcAbgmunw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{10., 0.}, {10., 8.333333333333332}, {10., 
        8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.333333333333332}, {10., 16.666666666666664`}, {10.,
         16.09876377148447}, {10., 8.049381885742235}, {10., 
        8.333333333333332}}], 
       PolygonBox[{{10., 16.666666666666664`}, {10., 25.}, {10., 
        24.148145657226706`}, {10., 16.09876377148447}, {10., 
        16.666666666666664`}}], 
       PolygonBox[{{10., 0.}, {10., 8.049381885742235}, {10., 
        7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.049381885742235}, {10., 16.09876377148447}, {10., 
        14.433756729740645`}, {10., 7.216878364870323}, {10., 
        8.049381885742235}}], 
       PolygonBox[{{10., 16.09876377148447}, {10., 24.148145657226706`}, {10.,
         21.65063509461097}, {10., 14.433756729740645`}, {10., 
        16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., 7.216878364870323}, {10., 
        5.892556509887896}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 7.216878364870323}, {10., 14.433756729740645`}, {10.,
         11.785113019775793`}, {10., 5.892556509887896}, {10., 
        7.216878364870323}}], 
       PolygonBox[{{10., 14.433756729740645`}, {10., 21.65063509461097}, {10.,
         17.67766952966369}, {10., 11.785113019775793`}, {10., 
        14.433756729740645`}}], 
       PolygonBox[{{10., 0.}, {10., 5.892556509887896}, {10., 
        4.166666666666668}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.892556509887896}, {10., 11.785113019775793`}, {10.,
         8.333333333333336}, {10., 4.166666666666668}, {10., 
        5.892556509887896}}], 
       PolygonBox[{{10., 11.785113019775793`}, {10., 17.67766952966369}, {10.,
         12.500000000000004`}, {10., 8.333333333333336}, {10., 
        11.785113019775793`}}], 
       PolygonBox[{{10., 0.}, {10., 4.166666666666668}, {10., 
        2.156825375854341}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 4.166666666666668}, {10., 8.333333333333336}, {10., 
        4.313650751708682}, {10., 2.156825375854341}, {10., 
        4.166666666666668}}], 
       PolygonBox[{{10., 8.333333333333336}, {10., 12.500000000000004`}, {10.,
         6.470476127563024}, {10., 4.313650751708682}, {10., 
        8.333333333333336}}], 
       PolygonBox[{{10., 0.}, {10., 2.156825375854341}, {10., 
        2.3606412073533245`*^-15}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 2.156825375854341}, {10., 4.313650751708682}, {10., 
        4.721282414706649*^-15}, {10., 2.3606412073533245`*^-15}, {10., 
        2.156825375854341}}], 
       PolygonBox[{{10., 4.313650751708682}, {10., 6.470476127563024}, {10., 
        7.0819236220599744`*^-15}, {10., 4.721282414706649*^-15}, {10., 
        4.313650751708682}}], 
       PolygonBox[{{10., 0.}, {10., 5.102694996447305*^-16}, {
        10., -2.1568253758543383`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.102694996447305*^-16}, {10., 
        1.020538999289461*^-15}, {10., -4.313650751708677}, {
        10., -2.1568253758543383`}, {10., 5.102694996447305*^-16}}], 
       PolygonBox[{{10., 1.020538999289461*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
        10., -4.313650751708677}, {10., 1.020538999289461*^-15}}], 
       PolygonBox[{{10., 0.}, {10., -2.1568253758543383`}, {
        10., -4.166666666666664}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -2.1568253758543383`}, {10., -4.313650751708677}, {
        10., -8.333333333333329}, {10., -4.166666666666664}, {
        10., -2.1568253758543383`}}], 
       PolygonBox[{{10., -4.313650751708677}, {10., -6.470476127563016}, {
        10., -12.499999999999995`}, {10., -8.333333333333329}, {
        10., -4.313650751708677}}], 
       PolygonBox[{{10., 0.}, {10., -4.166666666666664}, {
        10., -5.8925565098878945`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -4.166666666666664}, {10., -8.333333333333329}, {
        10., -11.785113019775789`}, {10., -5.8925565098878945`}, {
        10., -4.166666666666664}}], 
       PolygonBox[{{10., -8.333333333333329}, {10., -12.499999999999995`}, {
        10., -17.677669529663685`}, {10., -11.785113019775789`}, {
        10., -8.333333333333329}}], 
       PolygonBox[{{10., 0.}, {10., -5.8925565098878945`}, {
        10., -7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -5.8925565098878945`}, {10., -11.785113019775789`}, {
        10., -14.433756729740645`}, {10., -7.216878364870323}, {
        10., -5.8925565098878945`}}], 
       PolygonBox[{{10., -11.785113019775789`}, {10., -17.677669529663685`}, {
        10., -21.65063509461097}, {10., -14.433756729740645`}, {
        10., -11.785113019775789`}}], 
       PolygonBox[{{10., 0.}, {10., -7.21687836487032}, {
        10., -8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -7.21687836487032}, {10., -14.43375672974064}, {
        10., -16.09876377148447}, {10., -8.049381885742235}, {
        10., -7.21687836487032}}], 
       PolygonBox[{{10., -14.43375672974064}, {10., -21.650635094610962`}, {
        10., -24.148145657226706`}, {10., -16.09876377148447}, {
        10., -14.43375672974064}}], 
       PolygonBox[{{10., 0.}, {10., -8.049381885742235}, {
        10., -8.333333333333332}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.049381885742235}, {10., -16.09876377148447}, {
        10., -16.666666666666664`}, {10., -8.333333333333332}, {
        10., -8.049381885742235}}], 
       PolygonBox[{{10., -16.09876377148447}, {10., -24.148145657226706`}, {
        10., -25.}, {10., -16.666666666666664`}, {10., -16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., -8.333333333333332}, {
        10., -8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.333333333333332}, {10., -16.666666666666664`}, {
        10., -16.09876377148447}, {10., -8.049381885742235}, {
        10., -8.333333333333332}}], 
       PolygonBox[{{10., -16.666666666666664`}, {10., -25.}, {
        10., -24.148145657226706`}, {10., -16.09876377148447}, {
        10., -16.666666666666664`}}], 
       PolygonBox[{{10., 0.}, {10., -8.049381885742235}, {
        10., -7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.049381885742235}, {10., -16.09876377148447}, {
        10., -14.433756729740645`}, {10., -7.216878364870323}, {
        10., -8.049381885742235}}], 
       PolygonBox[{{10., -16.09876377148447}, {10., -24.14814565722671}, {
        10., -21.65063509461097}, {10., -14.433756729740645`}, {
        10., -16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., -7.216878364870323}, {
        10., -5.892556509887897}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -7.216878364870323}, {10., -14.433756729740645`}, {
        10., -11.785113019775794`}, {10., -5.892556509887897}, {
        10., -7.216878364870323}}], 
       PolygonBox[{{10., -14.433756729740645`}, {10., -21.65063509461097}, {
        10., -17.677669529663692`}, {10., -11.785113019775794`}, {
        10., -14.433756729740645`}}], 
       PolygonBox[{{10., 0.}, {10., -5.892556509887898}, {
        10., -4.16666666666667}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -5.892556509887898}, {10., -11.785113019775796`}, {
        10., -8.33333333333334}, {10., -4.16666666666667}, {
        10., -5.892556509887898}}], 
       PolygonBox[{{10., -11.785113019775796`}, {10., -17.677669529663696`}, {
        10., -12.50000000000001}, {10., -8.33333333333334}, {
        10., -11.785113019775796`}}], 
       PolygonBox[{{10., 0.}, {10., -4.16666666666667}, {
        10., -2.156825375854346}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -4.16666666666667}, {10., -8.33333333333334}, {
        10., -4.313650751708692}, {10., -2.156825375854346}, {
        10., -4.16666666666667}}], 
       PolygonBox[{{10., -8.33333333333334}, {10., -12.50000000000001}, {
        10., -6.470476127563038}, {10., -4.313650751708692}, {
        10., -8.33333333333334}}], 
       PolygonBox[{{10., 0.}, {10., -2.156825375854346}, {
        10., -8.932295329768568*^-15}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -2.156825375854346}, {10., -4.313650751708692}, {
        10., -1.7864590659537137`*^-14}, {10., -8.932295329768568*^-15}, {
        10., -2.156825375854346}}], 
       PolygonBox[{{10., -4.313650751708692}, {10., -6.470476127563038}, {
        10., -2.6796885989305705`*^-14}, {10., -1.7864590659537137`*^-14}, {
        10., -4.313650751708692}}], 
       PolygonBox[{{10., 0.}, {10., -1.5308084989341913`*^-15}, {10., 
        2.1568253758543356`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -1.5308084989341913`*^-15}, {
        10., -3.0616169978683826`*^-15}, {10., 4.313650751708671}, {10., 
        2.1568253758543356`}, {10., -1.5308084989341913`*^-15}}], 
       PolygonBox[{{10., -3.0616169978683826`*^-15}, {
        10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {10., 
        4.313650751708671}, {10., -3.0616169978683826`*^-15}}], 
       PolygonBox[{{10., 0.}, {10., 2.1568253758543356`}, {10., 
        4.166666666666661}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 2.1568253758543356`}, {10., 4.313650751708671}, {10.,
         8.333333333333321}, {10., 4.166666666666661}, {10., 
        2.1568253758543356`}}], 
       PolygonBox[{{10., 4.313650751708671}, {10., 6.470476127563007}, {10., 
        12.499999999999984`}, {10., 8.333333333333321}, {10., 
        4.313650751708671}}], 
       PolygonBox[{{10., 0.}, {10., 4.166666666666661}, {10., 
        5.89255650988789}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 4.166666666666661}, {10., 8.333333333333321}, {10., 
        11.78511301977578}, {10., 5.89255650988789}, {10., 
        4.166666666666661}}], 
       PolygonBox[{{10., 8.333333333333321}, {10., 12.499999999999984`}, {10.,
         17.67766952966367}, {10., 11.78511301977578}, {10., 
        8.333333333333321}}], 
       PolygonBox[{{10., 0.}, {10., 5.8925565098878945`}, {10., 
        7.216878364870319}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.8925565098878945`}, {10., 11.785113019775789`}, {
        10., 14.433756729740638`}, {10., 7.216878364870319}, {10., 
        5.8925565098878945`}}], 
       PolygonBox[{{10., 11.785113019775789`}, {10., 17.677669529663685`}, {
        10., 21.65063509461096}, {10., 14.433756729740638`}, {10., 
        11.785113019775789`}}], 
       PolygonBox[{{10., 0.}, {10., 7.216878364870319}, {10., 
        8.049381885742234}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 7.216878364870319}, {10., 14.433756729740638`}, {10.,
         16.098763771484467`}, {10., 8.049381885742234}, {10., 
        7.216878364870319}}], 
       PolygonBox[{{10., 14.433756729740638`}, {10., 21.65063509461096}, {10.,
         24.148145657226703`}, {10., 16.098763771484467`}, {10., 
        14.433756729740638`}}], 
       PolygonBox[{{10., 0.}, {10., 8.049381885742234}, {10., 
        8.333333333333332}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.049381885742234}, {10., 16.098763771484467`}, {10.,
         16.666666666666664`}, {10., 8.333333333333332}, {10., 
        8.049381885742234}}], 
       PolygonBox[{{10., 16.098763771484467`}, {10., 24.148145657226703`}, {
        10., 25.}, {10., 16.666666666666664`}, {10., 16.098763771484467`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEqDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0A7YRq0Q==
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
          24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
          6.421974580955592, 25.}}], 
         PolygonBox[{{6.421974580955592, 24.148145657226706`}, {10., 
          24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
          21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
         PolygonBox[{{6.421974580955592, 21.65063509461097}, {10., 
          21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
          17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
         PolygonBox[{{6.421974580955592, 17.67766952966369}, {10., 
          17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
          12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
         PolygonBox[{{6.421974580955592, 12.500000000000004`}, {10., 
          12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
          6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
         PolygonBox[{{6.421974580955592, 6.470476127563024}, {10., 
          6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
          6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
          6.470476127563024}}], 
         PolygonBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
          1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
          6.421974580955592, -6.470476127563016}, {6.421974580955592, 
          1.5308084989341915`*^-15}}], 
         PolygonBox[{{6.421974580955592, -6.470476127563016}, {
          10., -6.470476127563016}, {10., -12.499999999999995`}, {
          6.421974580955592, -12.499999999999995`}, {
          6.421974580955592, -6.470476127563016}}], 
         PolygonBox[{{6.421974580955592, -12.499999999999995`}, {
          10., -12.499999999999995`}, {10., -17.677669529663685`}, {
          6.421974580955592, -17.677669529663685`}, {
          6.421974580955592, -12.499999999999995`}}], 
         PolygonBox[{{6.421974580955592, -17.677669529663685`}, {
          10., -17.677669529663685`}, {10., -21.65063509461097}, {
          6.421974580955592, -21.65063509461097}, {
          6.421974580955592, -17.677669529663685`}}], 
         PolygonBox[{{6.421974580955599, -21.650635094610962`}, {
          10., -21.650635094610962`}, {10., -24.148145657226706`}, {
          6.421974580955592, -24.148145657226706`}, {
          6.421974580955599, -21.650635094610962`}}], 
         PolygonBox[{{6.421974580955592, -24.148145657226706`}, {
          10., -24.148145657226706`}, {10., -25.}, {
          6.421974580955592, -25.}, {
          6.421974580955592, -24.148145657226706`}}], 
         PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
          10., -24.148145657226706`}, {
          6.421974580955592, -24.148145657226706`}, {
          6.421974580955592, -25.}}], 
         PolygonBox[{{6.421974580955592, -24.14814565722671}, {
          10., -24.14814565722671}, {10., -21.65063509461097}, {
          6.421974580955592, -21.65063509461097}, {
          6.421974580955592, -24.14814565722671}}], 
         PolygonBox[{{6.421974580955592, -21.65063509461097}, {
          10., -21.65063509461097}, {10., -17.677669529663692`}, {
          6.421974580955592, -17.677669529663692`}, {
          6.421974580955592, -21.65063509461097}}], 
         PolygonBox[{{6.421974580955592, -17.677669529663696`}, {
          10., -17.677669529663696`}, {10., -12.50000000000001}, {
          6.421974580955592, -12.50000000000001}, {
          6.421974580955592, -17.677669529663696`}}], 
         PolygonBox[{{6.421974580955592, -12.50000000000001}, {
          10., -12.50000000000001}, {10., -6.470476127563038}, {
          6.421974580955592, -6.470476127563038}, {
          6.421974580955592, -12.50000000000001}}], 
         PolygonBox[{{6.421974580955592, -6.470476127563038}, {
          10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
          6.421974580955592, -2.6796885989305705`*^-14}, {
          6.421974580955592, -6.470476127563038}}], 
         PolygonBox[{{6.421974580955592, -4.592425496802574*^-15}, {
          10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
          6.421974580955592, 6.470476127563007}, {
          6.421974580955592, -4.592425496802574*^-15}}], 
         PolygonBox[{{6.421974580955592, 6.470476127563007}, {10., 
          6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
          12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
         PolygonBox[{{6.421974580955592, 12.499999999999984`}, {10., 
          12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
          17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
         PolygonBox[{{6.421974580955592, 17.677669529663685`}, {10., 
          17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
          21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
         PolygonBox[{{6.421974580955592, 21.65063509461096}, {10., 
          21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
          24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
         PolygonBox[{{6.421974580955592, 24.148145657226703`}, {10., 
          24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
          6.421974580955592, 24.148145657226703`}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      8.333333333333332}, {100.67375799589207`, 8.049381885742235}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.333333333333332}, {
      102.75044883428481`, 16.666666666666664`}, {102.75044883428481`, 
      16.09876377148447}, {100.67375799589207`, 8.049381885742235}, {
      100.67375799589207`, 8.333333333333332}}], 
     PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {
      106.4219745809556, 25.}, {106.4219745809556, 24.148145657226706`}, {
      102.75044883428481`, 16.09876377148447}, {102.75044883428481`, 
      16.666666666666664`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      8.049381885742235}, {100.67375799589209`, 7.216878364870323}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.049381885742235}, {
      102.75044883428481`, 16.09876377148447}, {102.75044883428481`, 
      14.433756729740645`}, {100.67375799589209`, 7.216878364870323}, {
      100.67375799589207`, 8.049381885742235}}], 
     PolygonBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556,
       24.148145657226706`}, {106.4219745809556, 21.65063509461097}, {
      102.75044883428481`, 14.433756729740645`}, {102.75044883428481`, 
      16.09876377148447}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
      7.216878364870323}, {100.67375799589207`, 5.892556509887896}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, 7.216878364870323}, {
      102.75044883428481`, 14.433756729740645`}, {102.7504488342848, 
      11.785113019775793`}, {100.67375799589207`, 5.892556509887896}, {
      100.67375799589209`, 7.216878364870323}}], 
     PolygonBox[{{102.75044883428481`, 14.433756729740645`}, {
      106.4219745809556, 21.65063509461097}, {106.4219745809556, 
      17.67766952966369}, {102.7504488342848, 11.785113019775793`}, {
      102.75044883428481`, 14.433756729740645`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      5.892556509887896}, {100.67375799589209`, 4.166666666666668}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 5.892556509887896}, {102.7504488342848,
       11.785113019775793`}, {102.75044883428481`, 8.333333333333336}, {
      100.67375799589209`, 4.166666666666668}, {100.67375799589207`, 
      5.892556509887896}}], 
     PolygonBox[{{102.7504488342848, 11.785113019775793`}, {106.4219745809556,
       17.67766952966369}, {106.4219745809556, 12.500000000000004`}, {
      102.75044883428481`, 8.333333333333336}, {102.7504488342848, 
      11.785113019775793`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
      4.166666666666668}, {100.67375799589207`, 2.156825375854341}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, 4.166666666666668}, {
      102.75044883428481`, 8.333333333333336}, {102.75044883428481`, 
      4.313650751708682}, {100.67375799589207`, 2.156825375854341}, {
      100.67375799589209`, 4.166666666666668}}], 
     PolygonBox[{{102.75044883428481`, 8.333333333333336}, {106.4219745809556,
       12.500000000000004`}, {106.4219745809556, 6.470476127563024}, {
      102.75044883428481`, 4.313650751708682}, {102.75044883428481`, 
      8.333333333333336}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      2.156825375854341}, {100.67375799589207`, 2.3606412073533245`*^-15}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 2.156825375854341}, {
      102.75044883428481`, 4.313650751708682}, {102.75044883428481`, 
      4.721282414706649*^-15}, {100.67375799589207`, 
      2.3606412073533245`*^-15}, {100.67375799589207`, 2.156825375854341}}], 
     PolygonBox[{{102.75044883428481`, 4.313650751708682}, {106.4219745809556,
       6.470476127563024}, {106.4219745809556, 7.0819236220599744`*^-15}, {
      102.75044883428481`, 4.721282414706649*^-15}, {102.75044883428481`, 
      4.313650751708682}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      5.102694996447305*^-16}, {100.67375799589207`, -2.1568253758543383`}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 5.102694996447305*^-16}, {
      102.75044883428481`, 1.020538999289461*^-15}, {
      102.75044883428481`, -4.313650751708677}, {
      100.67375799589207`, -2.1568253758543383`}, {100.67375799589207`, 
      5.102694996447305*^-16}}], 
     PolygonBox[{{102.75044883428481`, 1.020538999289461*^-15}, {
      106.4219745809556, 1.5308084989341915`*^-15}, {
      106.4219745809556, -6.470476127563016}, {
      102.75044883428481`, -4.313650751708677}, {102.75044883428481`, 
      1.020538999289461*^-15}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -2.1568253758543383`}, {
      100.67375799589209`, -4.166666666666664}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -2.1568253758543383`}, {
      102.75044883428481`, -4.313650751708677}, {
      102.75044883428481`, -8.333333333333329}, {
      100.67375799589209`, -4.166666666666664}, {
      100.67375799589207`, -2.1568253758543383`}}], 
     PolygonBox[{{102.75044883428481`, -4.313650751708677}, {
      106.4219745809556, -6.470476127563016}, {
      106.4219745809556, -12.499999999999995`}, {
      102.75044883428481`, -8.333333333333329}, {
      102.75044883428481`, -4.313650751708677}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589209`, -4.166666666666664}, {
      100.67375799589207`, -5.8925565098878945`}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, -4.166666666666664}, {
      102.75044883428481`, -8.333333333333329}, {
      102.7504488342848, -11.785113019775789`}, {
      100.67375799589207`, -5.8925565098878945`}, {
      100.67375799589209`, -4.166666666666664}}], 
     PolygonBox[{{102.75044883428481`, -8.333333333333329}, {
      106.4219745809556, -12.499999999999995`}, {
      106.4219745809556, -17.677669529663685`}, {
      102.7504488342848, -11.785113019775789`}, {
      102.75044883428481`, -8.333333333333329}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -5.8925565098878945`}, {
      100.67375799589209`, -7.216878364870323}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -5.8925565098878945`}, {
      102.7504488342848, -11.785113019775789`}, {
      102.75044883428481`, -14.433756729740645`}, {
      100.67375799589209`, -7.216878364870323}, {
      100.67375799589207`, -5.8925565098878945`}}], 
     PolygonBox[{{102.7504488342848, -11.785113019775789`}, {
      106.4219745809556, -17.677669529663685`}, {
      106.4219745809556, -21.65063509461097}, {
      102.75044883428481`, -14.433756729740645`}, {
      102.7504488342848, -11.785113019775789`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589209`, -7.21687836487032}, {
      100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, -7.21687836487032}, {
      102.7504488342848, -14.43375672974064}, {
      102.75044883428481`, -16.09876377148447}, {
      100.67375799589207`, -8.049381885742235}, {
      100.67375799589209`, -7.21687836487032}}], 
     PolygonBox[{{102.7504488342848, -14.43375672974064}, {
      106.4219745809556, -21.650635094610962`}, {
      106.4219745809556, -24.148145657226706`}, {
      102.75044883428481`, -16.09876377148447}, {
      102.7504488342848, -14.43375672974064}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -8.049381885742235}, {
      100.67375799589207`, -8.333333333333332}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -8.049381885742235}, {
      102.75044883428481`, -16.09876377148447}, {
      102.75044883428481`, -16.666666666666664`}, {
      100.67375799589207`, -8.333333333333332}, {
      100.67375799589207`, -8.049381885742235}}], 
     PolygonBox[{{102.75044883428481`, -16.09876377148447}, {
      106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}, {
      102.75044883428481`, -16.666666666666664`}, {
      102.75044883428481`, -16.09876377148447}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -8.333333333333332}, {
      100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -8.333333333333332}, {
      102.75044883428481`, -16.666666666666664`}, {
      102.75044883428481`, -16.09876377148447}, {
      100.67375799589207`, -8.049381885742235}, {
      100.67375799589207`, -8.333333333333332}}], 
     PolygonBox[{{102.75044883428481`, -16.666666666666664`}, {
      106.4219745809556, -25.}, {106.4219745809556, -24.148145657226706`}, {
      102.75044883428481`, -16.09876377148447}, {
      102.75044883428481`, -16.666666666666664`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -8.049381885742235}, {
      100.67375799589209`, -7.216878364870323}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -8.049381885742235}, {
      102.75044883428481`, -16.09876377148447}, {
      102.75044883428481`, -14.433756729740645`}, {
      100.67375799589209`, -7.216878364870323}, {
      100.67375799589207`, -8.049381885742235}}], 
     PolygonBox[{{102.75044883428481`, -16.09876377148447}, {
      106.4219745809556, -24.14814565722671}, {
      106.4219745809556, -21.65063509461097}, {
      102.75044883428481`, -14.433756729740645`}, {
      102.75044883428481`, -16.09876377148447}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589209`, -7.216878364870323}, {
      100.67375799589207`, -5.892556509887897}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, -7.216878364870323}, {
      102.75044883428481`, -14.433756729740645`}, {
      102.75044883428481`, -11.785113019775794`}, {
      100.67375799589207`, -5.892556509887897}, {
      100.67375799589209`, -7.216878364870323}}], 
     PolygonBox[{{102.75044883428481`, -14.433756729740645`}, {
      106.4219745809556, -21.65063509461097}, {
      106.4219745809556, -17.677669529663692`}, {
      102.75044883428481`, -11.785113019775794`}, {
      102.75044883428481`, -14.433756729740645`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -5.892556509887898}, {
      100.67375799589209`, -4.16666666666667}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -5.892556509887898}, {
      102.75044883428481`, -11.785113019775796`}, {
      102.7504488342848, -8.33333333333334}, {
      100.67375799589209`, -4.16666666666667}, {
      100.67375799589207`, -5.892556509887898}}], 
     PolygonBox[{{102.75044883428481`, -11.785113019775796`}, {
      106.4219745809556, -17.677669529663696`}, {
      106.4219745809556, -12.50000000000001}, {
      102.7504488342848, -8.33333333333334}, {
      102.75044883428481`, -11.785113019775796`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589209`, -4.16666666666667}, {
      100.67375799589207`, -2.156825375854346}, {100.00000000000001`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, -4.16666666666667}, {
      102.7504488342848, -8.33333333333334}, {
      102.75044883428481`, -4.313650751708692}, {
      100.67375799589207`, -2.156825375854346}, {
      100.67375799589209`, -4.16666666666667}}], 
     PolygonBox[{{102.7504488342848, -8.33333333333334}, {
      106.4219745809556, -12.50000000000001}, {
      106.4219745809556, -6.470476127563038}, {
      102.75044883428481`, -4.313650751708692}, {
      102.7504488342848, -8.33333333333334}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -2.156825375854346}, {
      100.67375799589207`, -8.932295329768568*^-15}, {100.00000000000001`, 
      0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, -2.156825375854346}, {
      102.75044883428481`, -4.313650751708692}, {
      102.75044883428481`, -1.7864590659537137`*^-14}, {
      100.67375799589207`, -8.932295329768568*^-15}, {
      100.67375799589207`, -2.156825375854346}}], 
     PolygonBox[{{102.75044883428481`, -4.313650751708692}, {
      106.4219745809556, -6.470476127563038}, {
      106.4219745809556, -2.6796885989305705`*^-14}, {
      102.75044883428481`, -1.7864590659537137`*^-14}, {
      102.75044883428481`, -4.313650751708692}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {
      100.67375799589207`, -1.5308084989341913`*^-15}, {100.67375799589207`, 
      2.1568253758543356`}, {100.00000000000001`, 0.}, {100.00000000000001`, 
      0.}}], PolygonBox[{{100.67375799589207`, -1.5308084989341913`*^-15}, {
      102.75044883428481`, -3.0616169978683826`*^-15}, {102.75044883428481`, 
      4.313650751708671}, {100.67375799589207`, 2.1568253758543356`}, {
      100.67375799589207`, -1.5308084989341913`*^-15}}], 
     PolygonBox[{{102.75044883428481`, -3.0616169978683826`*^-15}, {
      106.4219745809556, -4.592425496802574*^-15}, {106.4219745809556, 
      6.470476127563007}, {102.75044883428481`, 4.313650751708671}, {
      102.75044883428481`, -3.0616169978683826`*^-15}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      2.1568253758543356`}, {100.67375799589207`, 4.166666666666661}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 2.1568253758543356`}, {
      102.75044883428481`, 4.313650751708671}, {102.75044883428481`, 
      8.333333333333321}, {100.67375799589207`, 4.166666666666661}, {
      100.67375799589207`, 2.1568253758543356`}}], 
     PolygonBox[{{102.75044883428481`, 4.313650751708671}, {106.4219745809556,
       6.470476127563007}, {106.4219745809556, 12.499999999999984`}, {
      102.75044883428481`, 8.333333333333321}, {102.75044883428481`, 
      4.313650751708671}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      4.166666666666661}, {100.67375799589207`, 5.89255650988789}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 4.166666666666661}, {
      102.75044883428481`, 8.333333333333321}, {102.75044883428481`, 
      11.78511301977578}, {100.67375799589207`, 5.89255650988789}, {
      100.67375799589207`, 4.166666666666661}}], 
     PolygonBox[{{102.75044883428481`, 8.333333333333321}, {106.4219745809556,
       12.499999999999984`}, {106.4219745809556, 17.67766952966367}, {
      102.75044883428481`, 11.78511301977578}, {102.75044883428481`, 
      8.333333333333321}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      5.8925565098878945`}, {100.67375799589209`, 7.216878364870319}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 5.8925565098878945`}, {
      102.75044883428481`, 11.785113019775789`}, {102.7504488342848, 
      14.433756729740638`}, {100.67375799589209`, 7.216878364870319}, {
      100.67375799589207`, 5.8925565098878945`}}], 
     PolygonBox[{{102.75044883428481`, 11.785113019775789`}, {
      106.4219745809556, 17.677669529663685`}, {106.4219745809556, 
      21.65063509461096}, {102.7504488342848, 14.433756729740638`}, {
      102.75044883428481`, 11.785113019775789`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
      7.216878364870319}, {100.67375799589207`, 8.049381885742234}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589209`, 7.216878364870319}, {102.7504488342848,
       14.433756729740638`}, {102.75044883428481`, 16.098763771484467`}, {
      100.67375799589207`, 8.049381885742234}, {100.67375799589209`, 
      7.216878364870319}}], 
     PolygonBox[{{102.7504488342848, 14.433756729740638`}, {106.4219745809556,
       21.65063509461096}, {106.4219745809556, 24.148145657226703`}, {
      102.75044883428481`, 16.098763771484467`}, {102.7504488342848, 
      14.433756729740638`}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
      8.049381885742234}, {100.67375799589207`, 8.333333333333332}, {
      100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.049381885742234}, {
      102.75044883428481`, 16.098763771484467`}, {102.75044883428481`, 
      16.666666666666664`}, {100.67375799589207`, 8.333333333333332}, {
      100.67375799589207`, 8.049381885742234}}], 
     PolygonBox[{{102.75044883428481`, 16.098763771484467`}, {
      106.4219745809556, 24.148145657226703`}, {106.4219745809556, 25.}, {
      102.75044883428481`, 16.666666666666664`}, {102.75044883428481`, 
      16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvcxmzULG2VEODGBg6QDje1zdcP+NqgWc/+x3C+uE
ZaZw/o404QPVaw3hfCawfk04331Xad2Rh5Jw/unz59fPnnzbBsa3g8gfgPH/
/gcBDTh/O8R8OP8JxP4DaO47gOZ+ON8TTf4Zmv5daOazQdwP54ejue/G7duH
t6z7sgfGN0Hz33eI+x3Q3A/nP0YLP3e08IWFPwAzEbXq
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{110., 0.}, {110., 8.333333333333332}, {110., 
        8.049381885742235}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 8.333333333333332}, {110., 16.666666666666664`}, {
        110., 16.09876377148447}, {110., 8.049381885742235}, {110., 
        8.333333333333332}}], 
       PolygonBox[{{110., 16.666666666666664`}, {110., 25.}, {110., 
        24.148145657226706`}, {110., 16.09876377148447}, {110., 
        16.666666666666664`}}], 
       PolygonBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
        7.216878364870323}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {
        110., 14.433756729740645`}, {110., 7.216878364870323}, {110., 
        8.049381885742235}}], 
       PolygonBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {
        110., 21.65063509461097}, {110., 14.433756729740645`}, {110., 
        16.09876377148447}}], 
       PolygonBox[{{110., 0.}, {110., 7.216878364870323}, {110., 
        5.892556509887896}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 7.216878364870323}, {110., 14.433756729740645`}, {
        110., 11.785113019775793`}, {110., 5.892556509887896}, {110., 
        7.216878364870323}}], 
       PolygonBox[{{110., 14.433756729740645`}, {110., 21.65063509461097}, {
        110., 17.67766952966369}, {110., 11.785113019775793`}, {110., 
        14.433756729740645`}}], 
       PolygonBox[{{110., 0.}, {110., 5.892556509887896}, {110., 
        4.166666666666668}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 5.892556509887896}, {110., 11.785113019775793`}, {
        110., 8.333333333333336}, {110., 4.166666666666668}, {110., 
        5.892556509887896}}], 
       PolygonBox[{{110., 11.785113019775793`}, {110., 17.67766952966369}, {
        110., 12.500000000000004`}, {110., 8.333333333333336}, {110., 
        11.785113019775793`}}], 
       PolygonBox[{{110., 0.}, {110., 4.166666666666668}, {110., 
        2.156825375854341}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 4.166666666666668}, {110., 8.333333333333336}, {
        110., 4.313650751708682}, {110., 2.156825375854341}, {110., 
        4.166666666666668}}], 
       PolygonBox[{{110., 8.333333333333336}, {110., 12.500000000000004`}, {
        110., 6.470476127563024}, {110., 4.313650751708682}, {110., 
        8.333333333333336}}], 
       PolygonBox[{{110., 0.}, {110., 2.156825375854341}, {110., 
        2.3606412073533245`*^-15}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 2.156825375854341}, {110., 4.313650751708682}, {
        110., 4.721282414706649*^-15}, {110., 2.3606412073533245`*^-15}, {
        110., 2.156825375854341}}], 
       PolygonBox[{{110., 4.313650751708682}, {110., 6.470476127563024}, {
        110., 7.0819236220599744`*^-15}, {110., 4.721282414706649*^-15}, {
        110., 4.313650751708682}}], 
       PolygonBox[{{110., 0.}, {110., 5.102694996447305*^-16}, {
        110., -2.1568253758543383`}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 5.102694996447305*^-16}, {110., 
        1.020538999289461*^-15}, {110., -4.313650751708677}, {
        110., -2.1568253758543383`}, {110., 5.102694996447305*^-16}}], 
       PolygonBox[{{110., 1.020538999289461*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
        110., -4.313650751708677}, {110., 1.020538999289461*^-15}}], 
       PolygonBox[{{110., 0.}, {110., -2.1568253758543383`}, {
        110., -4.166666666666664}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -2.1568253758543383`}, {110., -4.313650751708677}, {
        110., -8.333333333333329}, {110., -4.166666666666664}, {
        110., -2.1568253758543383`}}], 
       PolygonBox[{{110., -4.313650751708677}, {110., -6.470476127563016}, {
        110., -12.499999999999995`}, {110., -8.333333333333329}, {
        110., -4.313650751708677}}], 
       PolygonBox[{{110., 0.}, {110., -4.166666666666664}, {
        110., -5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -4.166666666666664}, {110., -8.333333333333329}, {
        110., -11.785113019775789`}, {110., -5.8925565098878945`}, {
        110., -4.166666666666664}}], 
       PolygonBox[{{110., -8.333333333333329}, {110., -12.499999999999995`}, {
        110., -17.677669529663685`}, {110., -11.785113019775789`}, {
        110., -8.333333333333329}}], 
       PolygonBox[{{110., 0.}, {110., -5.8925565098878945`}, {
        110., -7.216878364870323}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -5.8925565098878945`}, {
        110., -11.785113019775789`}, {110., -14.433756729740645`}, {
        110., -7.216878364870323}, {110., -5.8925565098878945`}}], 
       PolygonBox[{{110., -11.785113019775789`}, {
        110., -17.677669529663685`}, {110., -21.65063509461097}, {
        110., -14.433756729740645`}, {110., -11.785113019775789`}}], 
       PolygonBox[{{110., 0.}, {110., -7.21687836487032}, {
        110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -7.21687836487032}, {110., -14.43375672974064}, {
        110., -16.09876377148447}, {110., -8.049381885742235}, {
        110., -7.21687836487032}}], 
       PolygonBox[{{110., -14.43375672974064}, {110., -21.650635094610962`}, {
        110., -24.148145657226706`}, {110., -16.09876377148447}, {
        110., -14.43375672974064}}], 
       PolygonBox[{{110., 0.}, {110., -8.049381885742235}, {
        110., -8.333333333333332}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
        110., -16.666666666666664`}, {110., -8.333333333333332}, {
        110., -8.049381885742235}}], 
       PolygonBox[{{110., -16.09876377148447}, {110., -24.148145657226706`}, {
        110., -25.}, {110., -16.666666666666664`}, {
        110., -16.09876377148447}}], 
       PolygonBox[{{110., 0.}, {110., -8.333333333333332}, {
        110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -8.333333333333332}, {110., -16.666666666666664`}, {
        110., -16.09876377148447}, {110., -8.049381885742235}, {
        110., -8.333333333333332}}], 
       PolygonBox[{{110., -16.666666666666664`}, {110., -25.}, {
        110., -24.148145657226706`}, {110., -16.09876377148447}, {
        110., -16.666666666666664`}}], 
       PolygonBox[{{110., 0.}, {110., -8.049381885742235}, {
        110., -7.216878364870323}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
        110., -14.433756729740645`}, {110., -7.216878364870323}, {
        110., -8.049381885742235}}], 
       PolygonBox[{{110., -16.09876377148447}, {110., -24.14814565722671}, {
        110., -21.65063509461097}, {110., -14.433756729740645`}, {
        110., -16.09876377148447}}], 
       PolygonBox[{{110., 0.}, {110., -7.216878364870323}, {
        110., -5.892556509887897}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -7.216878364870323}, {110., -14.433756729740645`}, {
        110., -11.785113019775794`}, {110., -5.892556509887897}, {
        110., -7.216878364870323}}], 
       PolygonBox[{{110., -14.433756729740645`}, {110., -21.65063509461097}, {
        110., -17.677669529663692`}, {110., -11.785113019775794`}, {
        110., -14.433756729740645`}}], 
       PolygonBox[{{110., 0.}, {110., -5.892556509887898}, {
        110., -4.16666666666667}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -5.892556509887898}, {110., -11.785113019775796`}, {
        110., -8.33333333333334}, {110., -4.16666666666667}, {
        110., -5.892556509887898}}], 
       PolygonBox[{{110., -11.785113019775796`}, {
        110., -17.677669529663696`}, {110., -12.50000000000001}, {
        110., -8.33333333333334}, {110., -11.785113019775796`}}], 
       PolygonBox[{{110., 0.}, {110., -4.16666666666667}, {
        110., -2.156825375854346}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -4.16666666666667}, {110., -8.33333333333334}, {
        110., -4.313650751708692}, {110., -2.156825375854346}, {
        110., -4.16666666666667}}], 
       PolygonBox[{{110., -8.33333333333334}, {110., -12.50000000000001}, {
        110., -6.470476127563038}, {110., -4.313650751708692}, {
        110., -8.33333333333334}}], 
       PolygonBox[{{110., 0.}, {110., -2.156825375854346}, {
        110., -8.932295329768568*^-15}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -2.156825375854346}, {110., -4.313650751708692}, {
        110., -1.7864590659537137`*^-14}, {110., -8.932295329768568*^-15}, {
        110., -2.156825375854346}}], 
       PolygonBox[{{110., -4.313650751708692}, {110., -6.470476127563038}, {
        110., -2.6796885989305705`*^-14}, {110., -1.7864590659537137`*^-14}, {
        110., -4.313650751708692}}], 
       PolygonBox[{{110., 0.}, {110., -1.5308084989341913`*^-15}, {110., 
        2.1568253758543356`}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., -1.5308084989341913`*^-15}, {
        110., -3.0616169978683826`*^-15}, {110., 4.313650751708671}, {110., 
        2.1568253758543356`}, {110., -1.5308084989341913`*^-15}}], 
       PolygonBox[{{110., -3.0616169978683826`*^-15}, {
        110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {110., 
        4.313650751708671}, {110., -3.0616169978683826`*^-15}}], 
       PolygonBox[{{110., 0.}, {110., 2.1568253758543356`}, {110., 
        4.166666666666661}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 2.1568253758543356`}, {110., 4.313650751708671}, {
        110., 8.333333333333321}, {110., 4.166666666666661}, {110., 
        2.1568253758543356`}}], 
       PolygonBox[{{110., 4.313650751708671}, {110., 6.470476127563007}, {
        110., 12.499999999999984`}, {110., 8.333333333333321}, {110., 
        4.313650751708671}}], 
       PolygonBox[{{110., 0.}, {110., 4.166666666666661}, {110., 
        5.89255650988789}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 4.166666666666661}, {110., 8.333333333333321}, {
        110., 11.78511301977578}, {110., 5.89255650988789}, {110., 
        4.166666666666661}}], 
       PolygonBox[{{110., 8.333333333333321}, {110., 12.499999999999984`}, {
        110., 17.67766952966367}, {110., 11.78511301977578}, {110., 
        8.333333333333321}}], 
       PolygonBox[{{110., 0.}, {110., 5.8925565098878945`}, {110., 
        7.216878364870319}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 5.8925565098878945`}, {110., 11.785113019775789`}, {
        110., 14.433756729740638`}, {110., 7.216878364870319}, {110., 
        5.8925565098878945`}}], 
       PolygonBox[{{110., 11.785113019775789`}, {110., 17.677669529663685`}, {
        110., 21.65063509461096}, {110., 14.433756729740638`}, {110., 
        11.785113019775789`}}], 
       PolygonBox[{{110., 0.}, {110., 7.216878364870319}, {110., 
        8.049381885742234}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 7.216878364870319}, {110., 14.433756729740638`}, {
        110., 16.098763771484467`}, {110., 8.049381885742234}, {110., 
        7.216878364870319}}], 
       PolygonBox[{{110., 14.433756729740638`}, {110., 21.65063509461096}, {
        110., 24.148145657226703`}, {110., 16.098763771484467`}, {110., 
        14.433756729740638`}}], 
       PolygonBox[{{110., 0.}, {110., 8.049381885742234}, {110., 
        8.333333333333332}, {110., 0.}, {110., 0.}}], 
       PolygonBox[{{110., 8.049381885742234}, {110., 16.098763771484467`}, {
        110., 16.666666666666664`}, {110., 8.333333333333332}, {110., 
        8.049381885742234}}], 
       PolygonBox[{{110., 16.098763771484467`}, {110., 24.148145657226703`}, {
        110., 25.}, {110., 16.666666666666664`}, {110., 
        16.098763771484467`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYN0Q4QhqUDjO9xdcP9N6oWcP6z3y2sE5aZwvk7
0oQPVK81hPMhZmnC+e67SuuOPJSE80+fP79+9uTbNjC+HUT+AIz/9z8IaMD5
2yHmw/lPIPbD+VD3wflQ98P5nmjyz9D070Iznw3ifjg/HM19N27fPrxl3Zc9
ML4Jmv++Q9wP529HC5/HaOHnjha+sPAHABTbfLA=
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
          24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
          106.4219745809556, 25.}}], 
         PolygonBox[{{106.4219745809556, 24.148145657226706`}, {110., 
          24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556,
           21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
         PolygonBox[{{106.4219745809556, 21.65063509461097}, {110., 
          21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
          17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
         PolygonBox[{{106.4219745809556, 17.67766952966369}, {110., 
          17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556,
           12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
         PolygonBox[{{106.4219745809556, 12.500000000000004`}, {110., 
          12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556,
           6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
         PolygonBox[{{106.4219745809556, 6.470476127563024}, {110., 
          6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
          106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
          6.470476127563024}}], 
         PolygonBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
          1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
          106.4219745809556, -6.470476127563016}, {106.4219745809556, 
          1.5308084989341915`*^-15}}], 
         PolygonBox[{{106.4219745809556, -6.470476127563016}, {
          110., -6.470476127563016}, {110., -12.499999999999995`}, {
          106.4219745809556, -12.499999999999995`}, {
          106.4219745809556, -6.470476127563016}}], 
         PolygonBox[{{106.4219745809556, -12.499999999999995`}, {
          110., -12.499999999999995`}, {110., -17.677669529663685`}, {
          106.4219745809556, -17.677669529663685`}, {
          106.4219745809556, -12.499999999999995`}}], 
         PolygonBox[{{106.4219745809556, -17.677669529663685`}, {
          110., -17.677669529663685`}, {110., -21.65063509461097}, {
          106.4219745809556, -21.65063509461097}, {
          106.4219745809556, -17.677669529663685`}}], 
         PolygonBox[{{106.4219745809556, -21.650635094610962`}, {
          110., -21.650635094610962`}, {110., -24.148145657226706`}, {
          106.4219745809556, -24.148145657226706`}, {
          106.4219745809556, -21.650635094610962`}}], 
         PolygonBox[{{106.4219745809556, -24.148145657226706`}, {
          110., -24.148145657226706`}, {110., -25.}, {
          106.4219745809556, -25.}, {
          106.4219745809556, -24.148145657226706`}}], 
         PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
          110., -24.148145657226706`}, {
          106.4219745809556, -24.148145657226706`}, {
          106.4219745809556, -25.}}], 
         PolygonBox[{{106.4219745809556, -24.14814565722671}, {
          110., -24.14814565722671}, {110., -21.65063509461097}, {
          106.4219745809556, -21.65063509461097}, {
          106.4219745809556, -24.14814565722671}}], 
         PolygonBox[{{106.4219745809556, -21.65063509461097}, {
          110., -21.65063509461097}, {110., -17.677669529663692`}, {
          106.4219745809556, -17.677669529663692`}, {
          106.4219745809556, -21.65063509461097}}], 
         PolygonBox[{{106.4219745809556, -17.677669529663696`}, {
          110., -17.677669529663696`}, {110., -12.50000000000001}, {
          106.4219745809556, -12.50000000000001}, {
          106.4219745809556, -17.677669529663696`}}], 
         PolygonBox[{{106.4219745809556, -12.50000000000001}, {
          110., -12.50000000000001}, {110., -6.470476127563038}, {
          106.4219745809556, -6.470476127563038}, {
          106.4219745809556, -12.50000000000001}}], 
         PolygonBox[{{106.4219745809556, -6.470476127563038}, {
          110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
          106.4219745809556, -2.6796885989305705`*^-14}, {
          106.4219745809556, -6.470476127563038}}], 
         PolygonBox[{{106.4219745809556, -4.592425496802574*^-15}, {
          110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
          106.4219745809556, 6.470476127563007}, {
          106.4219745809556, -4.592425496802574*^-15}}], 
         PolygonBox[{{106.4219745809556, 6.470476127563007}, {110., 
          6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556,
           12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
         PolygonBox[{{106.4219745809556, 12.499999999999984`}, {110., 
          12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556,
           17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
         PolygonBox[{{106.4219745809556, 17.677669529663685`}, {110., 
          17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556,
           21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
         PolygonBox[{{106.4219745809556, 21.65063509461096}, {110., 
          21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556,
           24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
         PolygonBox[{{106.4219745809556, 24.148145657226703`}, {110., 
          24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
          106.4219745809556, 24.148145657226703`}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"lens1\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"lens2\"\>", {105., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731746291971*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[61]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"lens\"\>", ",", 
        RowBox[{"Move", "[", 
         RowBox[{"\<\"lens\"\>", ",", "100.`"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.6147317462968283`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[61]:="],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.563367931404748*^9, 3.566158866266121*^9, 
  3.566158994071986*^9, 3.5672683510897284`*^9, 3.614730560926655*^9, 
  3.614731746298008*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[63]="]
}, Open  ]],

Cell["\<\
The two lenses are each labeled with a unique number automatically attached \
by Optica.\
\>", "Commentary",
 CellChangeTimes->{3.5661589495019712`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell["\<\
The label lens appears both in the graphics as well as in the echoed  system \
output.  Note that Optica has automatically numbered the lens labels in the \
graphics.  However, in  the display of a single object, Optica automatically \
surpresses the graphical labelling altogether.\
\>", "Text",
 CellChangeTimes->{{3.566158949612178*^9, 3.566158949716679*^9}},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[lens, PlotType->TopView]", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[64]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.333333333333332}, {
      0.6737579958920605, 8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333332}, {
      2.7504488342847893`, 16.666666666666664`}, {2.7504488342847893`, 
      16.09876377148447}, {0.6737579958920605, 8.049381885742235}, {
      0.6737579958920605, 8.333333333333332}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {
      6.421974580955592, 25.}, {6.421974580955592, 24.148145657226706`}, {
      2.7504488342847893`, 16.09876377148447}, {2.7504488342847893`, 
      16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.049381885742235}, {
      0.6737579958920676, 7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.049381885742235}, {
      2.7504488342847893`, 16.09876377148447}, {2.7504488342847893`, 
      14.433756729740645`}, {0.6737579958920676, 7.216878364870323}, {
      0.6737579958920605, 8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, 16.09876377148447}, {6.421974580955592,
       24.148145657226706`}, {6.421974580955592, 21.65063509461097}, {
      2.7504488342847893`, 14.433756729740645`}, {2.7504488342847893`, 
      16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 7.216878364870323}, {
      0.6737579958920605, 5.892556509887896}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 7.216878364870323}, {
      2.7504488342847893`, 14.433756729740645`}, {2.750448834284782, 
      11.785113019775793`}, {0.6737579958920605, 5.892556509887896}, {
      0.6737579958920676, 7.216878364870323}}], 
     PolygonBox[{{2.7504488342847893`, 14.433756729740645`}, {
      6.421974580955592, 21.65063509461097}, {6.421974580955592, 
      17.67766952966369}, {2.750448834284782, 11.785113019775793`}, {
      2.7504488342847893`, 14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.892556509887896}, {
      0.6737579958920676, 4.166666666666668}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.892556509887896}, {2.750448834284782, 
      11.785113019775793`}, {2.7504488342847893`, 8.333333333333336}, {
      0.6737579958920676, 4.166666666666668}, {0.6737579958920605, 
      5.892556509887896}}], 
     PolygonBox[{{2.750448834284782, 11.785113019775793`}, {6.421974580955592,
       17.67766952966369}, {6.421974580955592, 12.500000000000004`}, {
      2.7504488342847893`, 8.333333333333336}, {2.750448834284782, 
      11.785113019775793`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 4.166666666666668}, {
      0.6737579958920605, 2.156825375854341}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 4.166666666666668}, {
      2.7504488342847893`, 8.333333333333336}, {2.7504488342847893`, 
      4.313650751708682}, {0.6737579958920605, 2.156825375854341}, {
      0.6737579958920676, 4.166666666666668}}], 
     PolygonBox[{{2.7504488342847893`, 8.333333333333336}, {6.421974580955592,
       12.500000000000004`}, {6.421974580955592, 6.470476127563024}, {
      2.7504488342847893`, 4.313650751708682}, {2.7504488342847893`, 
      8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 2.156825375854341}, {
      0.6737579958920605, 2.3606412073533245`*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 2.156825375854341}, {
      2.7504488342847893`, 4.313650751708682}, {2.7504488342847893`, 
      4.721282414706649*^-15}, {0.6737579958920605, 
      2.3606412073533245`*^-15}, {0.6737579958920605, 2.156825375854341}}], 
     PolygonBox[{{2.7504488342847893`, 4.313650751708682}, {6.421974580955592,
       6.470476127563024}, {6.421974580955592, 7.0819236220599744`*^-15}, {
      2.7504488342847893`, 4.721282414706649*^-15}, {2.7504488342847893`, 
      4.313650751708682}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.102694996447305*^-16}, {
      0.6737579958920605, -2.1568253758543383`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.102694996447305*^-16}, {
      2.7504488342847893`, 1.020538999289461*^-15}, {
      2.7504488342847893`, -4.313650751708677}, {
      0.6737579958920605, -2.1568253758543383`}, {0.6737579958920605, 
      5.102694996447305*^-16}}], 
     PolygonBox[{{2.7504488342847893`, 1.020538999289461*^-15}, {
      6.421974580955592, 1.5308084989341915`*^-15}, {
      6.421974580955592, -6.470476127563016}, {
      2.7504488342847893`, -4.313650751708677}, {2.7504488342847893`, 
      1.020538999289461*^-15}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -2.1568253758543383`}, {
      0.6737579958920676, -4.166666666666664}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -2.1568253758543383`}, {
      2.7504488342847893`, -4.313650751708677}, {
      2.7504488342847893`, -8.333333333333329}, {
      0.6737579958920676, -4.166666666666664}, {
      0.6737579958920605, -2.1568253758543383`}}], 
     PolygonBox[{{2.7504488342847893`, -4.313650751708677}, {
      6.421974580955592, -6.470476127563016}, {
      6.421974580955592, -12.499999999999995`}, {
      2.7504488342847893`, -8.333333333333329}, {
      2.7504488342847893`, -4.313650751708677}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -4.166666666666664}, {
      0.6737579958920605, -5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -4.166666666666664}, {
      2.7504488342847893`, -8.333333333333329}, {
      2.750448834284782, -11.785113019775789`}, {
      0.6737579958920605, -5.8925565098878945`}, {
      0.6737579958920676, -4.166666666666664}}], 
     PolygonBox[{{2.7504488342847893`, -8.333333333333329}, {
      6.421974580955592, -12.499999999999995`}, {
      6.421974580955592, -17.677669529663685`}, {
      2.750448834284782, -11.785113019775789`}, {
      2.7504488342847893`, -8.333333333333329}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -5.8925565098878945`}, {
      0.6737579958920676, -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -5.8925565098878945`}, {
      2.750448834284782, -11.785113019775789`}, {
      2.7504488342847893`, -14.433756729740645`}, {
      0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -5.8925565098878945`}}], 
     PolygonBox[{{2.750448834284782, -11.785113019775789`}, {
      6.421974580955592, -17.677669529663685`}, {
      6.421974580955592, -21.65063509461097}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.750448834284782, -11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -7.21687836487032}, {
      0.6737579958920605, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -7.21687836487032}, {
      2.750448834284782, -14.43375672974064}, {
      2.7504488342847893`, -16.09876377148447}, {
      0.6737579958920605, -8.049381885742235}, {
      0.6737579958920676, -7.21687836487032}}], 
     PolygonBox[{{2.750448834284782, -14.43375672974064}, {
      6.421974580955599, -21.650635094610962`}, {
      6.421974580955592, -24.148145657226706`}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.750448834284782, -14.43375672974064}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.049381885742235}, {
      0.6737579958920605, -8.333333333333332}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.049381885742235}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -16.666666666666664`}, {
      0.6737579958920605, -8.333333333333332}, {
      0.6737579958920605, -8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, -16.09876377148447}, {
      6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}, {
      2.7504488342847893`, -16.666666666666664`}, {
      2.7504488342847893`, -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.333333333333332}, {
      0.6737579958920605, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333332}, {
      2.7504488342847893`, -16.666666666666664`}, {
      2.7504488342847893`, -16.09876377148447}, {
      0.6737579958920605, -8.049381885742235}, {
      0.6737579958920605, -8.333333333333332}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666664`}, {
      6.421974580955592, -25.}, {6.421974580955592, -24.148145657226706`}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -8.049381885742235}, {
      0.6737579958920676, -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -8.049381885742235}, {
      2.7504488342847893`, -16.09876377148447}, {
      2.7504488342847893`, -14.433756729740645`}, {
      0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -8.049381885742235}}], 
     PolygonBox[{{2.7504488342847893`, -16.09876377148447}, {
      6.421974580955592, -24.14814565722671}, {
      6.421974580955592, -21.65063509461097}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.7504488342847893`, -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -7.216878364870323}, {
      0.6737579958920605, -5.892556509887897}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -7.216878364870323}, {
      2.7504488342847893`, -14.433756729740645`}, {
      2.7504488342847893`, -11.785113019775794`}, {
      0.6737579958920605, -5.892556509887897}, {
      0.6737579958920676, -7.216878364870323}}], 
     PolygonBox[{{2.7504488342847893`, -14.433756729740645`}, {
      6.421974580955592, -21.65063509461097}, {
      6.421974580955592, -17.677669529663692`}, {
      2.7504488342847893`, -11.785113019775794`}, {
      2.7504488342847893`, -14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -5.892556509887898}, {
      0.6737579958920676, -4.16666666666667}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -5.892556509887898}, {
      2.7504488342847893`, -11.785113019775796`}, {
      2.750448834284782, -8.33333333333334}, {
      0.6737579958920676, -4.16666666666667}, {
      0.6737579958920605, -5.892556509887898}}], 
     PolygonBox[{{2.7504488342847893`, -11.785113019775796`}, {
      6.421974580955592, -17.677669529663696`}, {
      6.421974580955592, -12.50000000000001}, {
      2.750448834284782, -8.33333333333334}, {
      2.7504488342847893`, -11.785113019775796`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, -4.16666666666667}, {
      0.6737579958920605, -2.156825375854346}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, -4.16666666666667}, {
      2.750448834284782, -8.33333333333334}, {
      2.7504488342847893`, -4.313650751708692}, {
      0.6737579958920605, -2.156825375854346}, {
      0.6737579958920676, -4.16666666666667}}], 
     PolygonBox[{{2.750448834284782, -8.33333333333334}, {
      6.421974580955592, -12.50000000000001}, {
      6.421974580955592, -6.470476127563038}, {
      2.7504488342847893`, -4.313650751708692}, {
      2.750448834284782, -8.33333333333334}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -2.156825375854346}, {
      0.6737579958920605, -8.932295329768568*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -2.156825375854346}, {
      2.7504488342847893`, -4.313650751708692}, {
      2.7504488342847893`, -1.7864590659537137`*^-14}, {
      0.6737579958920605, -8.932295329768568*^-15}, {
      0.6737579958920605, -2.156825375854346}}], 
     PolygonBox[{{2.7504488342847893`, -4.313650751708692}, {
      6.421974580955592, -6.470476127563038}, {
      6.421974580955592, -2.6796885989305705`*^-14}, {
      2.7504488342847893`, -1.7864590659537137`*^-14}, {
      2.7504488342847893`, -4.313650751708692}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, -1.5308084989341913`*^-15}, {
      0.6737579958920605, 2.1568253758543356`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, -1.5308084989341913`*^-15}, {
      2.7504488342847893`, -3.0616169978683826`*^-15}, {2.7504488342847893`, 
      4.313650751708671}, {0.6737579958920605, 2.1568253758543356`}, {
      0.6737579958920605, -1.5308084989341913`*^-15}}], 
     PolygonBox[{{2.7504488342847893`, -3.0616169978683826`*^-15}, {
      6.421974580955592, -4.592425496802574*^-15}, {6.421974580955592, 
      6.470476127563007}, {2.7504488342847893`, 4.313650751708671}, {
      2.7504488342847893`, -3.0616169978683826`*^-15}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 2.1568253758543356`}, {
      0.6737579958920605, 4.166666666666661}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 2.1568253758543356`}, {
      2.7504488342847893`, 4.313650751708671}, {2.7504488342847893`, 
      8.333333333333321}, {0.6737579958920605, 4.166666666666661}, {
      0.6737579958920605, 2.1568253758543356`}}], 
     PolygonBox[{{2.7504488342847893`, 4.313650751708671}, {6.421974580955592,
       6.470476127563007}, {6.421974580955592, 12.499999999999984`}, {
      2.7504488342847893`, 8.333333333333321}, {2.7504488342847893`, 
      4.313650751708671}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 4.166666666666661}, {
      0.6737579958920605, 5.89255650988789}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 4.166666666666661}, {
      2.7504488342847893`, 8.333333333333321}, {2.7504488342847893`, 
      11.78511301977578}, {0.6737579958920605, 5.89255650988789}, {
      0.6737579958920605, 4.166666666666661}}], 
     PolygonBox[{{2.7504488342847893`, 8.333333333333321}, {6.421974580955592,
       12.499999999999984`}, {6.421974580955599, 17.67766952966367}, {
      2.7504488342847893`, 11.78511301977578}, {2.7504488342847893`, 
      8.333333333333321}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 5.8925565098878945`}, {
      0.6737579958920676, 7.216878364870319}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 5.8925565098878945`}, {
      2.7504488342847893`, 11.785113019775789`}, {2.750448834284782, 
      14.433756729740638`}, {0.6737579958920676, 7.216878364870319}, {
      0.6737579958920605, 5.8925565098878945`}}], 
     PolygonBox[{{2.7504488342847893`, 11.785113019775789`}, {
      6.421974580955592, 17.677669529663685`}, {6.421974580955592, 
      21.65063509461096}, {2.750448834284782, 14.433756729740638`}, {
      2.7504488342847893`, 11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920676, 7.216878364870319}, {
      0.6737579958920605, 8.049381885742234}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920676, 7.216878364870319}, {2.750448834284782, 
      14.433756729740638`}, {2.7504488342847893`, 16.098763771484467`}, {
      0.6737579958920605, 8.049381885742234}, {0.6737579958920676, 
      7.216878364870319}}], 
     PolygonBox[{{2.750448834284782, 14.433756729740638`}, {6.421974580955592,
       21.65063509461096}, {6.421974580955592, 24.148145657226703`}, {
      2.7504488342847893`, 16.098763771484467`}, {2.750448834284782, 
      14.433756729740638`}}], 
     PolygonBox[{{0., 0.}, {0.6737579958920605, 8.049381885742234}, {
      0.6737579958920605, 8.333333333333332}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.049381885742234}, {
      2.7504488342847893`, 16.098763771484467`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333332}, {
      0.6737579958920605, 8.049381885742234}}], 
     PolygonBox[{{2.7504488342847893`, 16.098763771484467`}, {
      6.421974580955592, 24.148145657226703`}, {6.421974580955592, 25.}, {
      2.7504488342847893`, 16.666666666666664`}, {2.7504488342847893`, 
      16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQHXDqsJTUBkkHBjCwdIDxPa5uuP9G1QLOf/a7hXXC
MlM4f0ea8IHqtYZwPhNYvyac776rtO7IQ0k4//T58+tnT75tA+PbQeQPwPh/
/4OABpy/HWL+gQgo/wnE/gNo7juA5n443xNN/hma/l1Q82F8Noj74fxwNPfd
uH378JZ1X/bA+CZo/vsOcb8Dmvvh/Mdo4eeOFr6w8AcAbgmunw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{10., 0.}, {10., 8.333333333333332}, {10., 
        8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.333333333333332}, {10., 16.666666666666664`}, {10.,
         16.09876377148447}, {10., 8.049381885742235}, {10., 
        8.333333333333332}}], 
       PolygonBox[{{10., 16.666666666666664`}, {10., 25.}, {10., 
        24.148145657226706`}, {10., 16.09876377148447}, {10., 
        16.666666666666664`}}], 
       PolygonBox[{{10., 0.}, {10., 8.049381885742235}, {10., 
        7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.049381885742235}, {10., 16.09876377148447}, {10., 
        14.433756729740645`}, {10., 7.216878364870323}, {10., 
        8.049381885742235}}], 
       PolygonBox[{{10., 16.09876377148447}, {10., 24.148145657226706`}, {10.,
         21.65063509461097}, {10., 14.433756729740645`}, {10., 
        16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., 7.216878364870323}, {10., 
        5.892556509887896}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 7.216878364870323}, {10., 14.433756729740645`}, {10.,
         11.785113019775793`}, {10., 5.892556509887896}, {10., 
        7.216878364870323}}], 
       PolygonBox[{{10., 14.433756729740645`}, {10., 21.65063509461097}, {10.,
         17.67766952966369}, {10., 11.785113019775793`}, {10., 
        14.433756729740645`}}], 
       PolygonBox[{{10., 0.}, {10., 5.892556509887896}, {10., 
        4.166666666666668}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.892556509887896}, {10., 11.785113019775793`}, {10.,
         8.333333333333336}, {10., 4.166666666666668}, {10., 
        5.892556509887896}}], 
       PolygonBox[{{10., 11.785113019775793`}, {10., 17.67766952966369}, {10.,
         12.500000000000004`}, {10., 8.333333333333336}, {10., 
        11.785113019775793`}}], 
       PolygonBox[{{10., 0.}, {10., 4.166666666666668}, {10., 
        2.156825375854341}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 4.166666666666668}, {10., 8.333333333333336}, {10., 
        4.313650751708682}, {10., 2.156825375854341}, {10., 
        4.166666666666668}}], 
       PolygonBox[{{10., 8.333333333333336}, {10., 12.500000000000004`}, {10.,
         6.470476127563024}, {10., 4.313650751708682}, {10., 
        8.333333333333336}}], 
       PolygonBox[{{10., 0.}, {10., 2.156825375854341}, {10., 
        2.3606412073533245`*^-15}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 2.156825375854341}, {10., 4.313650751708682}, {10., 
        4.721282414706649*^-15}, {10., 2.3606412073533245`*^-15}, {10., 
        2.156825375854341}}], 
       PolygonBox[{{10., 4.313650751708682}, {10., 6.470476127563024}, {10., 
        7.0819236220599744`*^-15}, {10., 4.721282414706649*^-15}, {10., 
        4.313650751708682}}], 
       PolygonBox[{{10., 0.}, {10., 5.102694996447305*^-16}, {
        10., -2.1568253758543383`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.102694996447305*^-16}, {10., 
        1.020538999289461*^-15}, {10., -4.313650751708677}, {
        10., -2.1568253758543383`}, {10., 5.102694996447305*^-16}}], 
       PolygonBox[{{10., 1.020538999289461*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
        10., -4.313650751708677}, {10., 1.020538999289461*^-15}}], 
       PolygonBox[{{10., 0.}, {10., -2.1568253758543383`}, {
        10., -4.166666666666664}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -2.1568253758543383`}, {10., -4.313650751708677}, {
        10., -8.333333333333329}, {10., -4.166666666666664}, {
        10., -2.1568253758543383`}}], 
       PolygonBox[{{10., -4.313650751708677}, {10., -6.470476127563016}, {
        10., -12.499999999999995`}, {10., -8.333333333333329}, {
        10., -4.313650751708677}}], 
       PolygonBox[{{10., 0.}, {10., -4.166666666666664}, {
        10., -5.8925565098878945`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -4.166666666666664}, {10., -8.333333333333329}, {
        10., -11.785113019775789`}, {10., -5.8925565098878945`}, {
        10., -4.166666666666664}}], 
       PolygonBox[{{10., -8.333333333333329}, {10., -12.499999999999995`}, {
        10., -17.677669529663685`}, {10., -11.785113019775789`}, {
        10., -8.333333333333329}}], 
       PolygonBox[{{10., 0.}, {10., -5.8925565098878945`}, {
        10., -7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -5.8925565098878945`}, {10., -11.785113019775789`}, {
        10., -14.433756729740645`}, {10., -7.216878364870323}, {
        10., -5.8925565098878945`}}], 
       PolygonBox[{{10., -11.785113019775789`}, {10., -17.677669529663685`}, {
        10., -21.65063509461097}, {10., -14.433756729740645`}, {
        10., -11.785113019775789`}}], 
       PolygonBox[{{10., 0.}, {10., -7.21687836487032}, {
        10., -8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -7.21687836487032}, {10., -14.43375672974064}, {
        10., -16.09876377148447}, {10., -8.049381885742235}, {
        10., -7.21687836487032}}], 
       PolygonBox[{{10., -14.43375672974064}, {10., -21.650635094610962`}, {
        10., -24.148145657226706`}, {10., -16.09876377148447}, {
        10., -14.43375672974064}}], 
       PolygonBox[{{10., 0.}, {10., -8.049381885742235}, {
        10., -8.333333333333332}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.049381885742235}, {10., -16.09876377148447}, {
        10., -16.666666666666664`}, {10., -8.333333333333332}, {
        10., -8.049381885742235}}], 
       PolygonBox[{{10., -16.09876377148447}, {10., -24.148145657226706`}, {
        10., -25.}, {10., -16.666666666666664`}, {10., -16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., -8.333333333333332}, {
        10., -8.049381885742235}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.333333333333332}, {10., -16.666666666666664`}, {
        10., -16.09876377148447}, {10., -8.049381885742235}, {
        10., -8.333333333333332}}], 
       PolygonBox[{{10., -16.666666666666664`}, {10., -25.}, {
        10., -24.148145657226706`}, {10., -16.09876377148447}, {
        10., -16.666666666666664`}}], 
       PolygonBox[{{10., 0.}, {10., -8.049381885742235}, {
        10., -7.216878364870323}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -8.049381885742235}, {10., -16.09876377148447}, {
        10., -14.433756729740645`}, {10., -7.216878364870323}, {
        10., -8.049381885742235}}], 
       PolygonBox[{{10., -16.09876377148447}, {10., -24.14814565722671}, {
        10., -21.65063509461097}, {10., -14.433756729740645`}, {
        10., -16.09876377148447}}], 
       PolygonBox[{{10., 0.}, {10., -7.216878364870323}, {
        10., -5.892556509887897}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -7.216878364870323}, {10., -14.433756729740645`}, {
        10., -11.785113019775794`}, {10., -5.892556509887897}, {
        10., -7.216878364870323}}], 
       PolygonBox[{{10., -14.433756729740645`}, {10., -21.65063509461097}, {
        10., -17.677669529663692`}, {10., -11.785113019775794`}, {
        10., -14.433756729740645`}}], 
       PolygonBox[{{10., 0.}, {10., -5.892556509887898}, {
        10., -4.16666666666667}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -5.892556509887898}, {10., -11.785113019775796`}, {
        10., -8.33333333333334}, {10., -4.16666666666667}, {
        10., -5.892556509887898}}], 
       PolygonBox[{{10., -11.785113019775796`}, {10., -17.677669529663696`}, {
        10., -12.50000000000001}, {10., -8.33333333333334}, {
        10., -11.785113019775796`}}], 
       PolygonBox[{{10., 0.}, {10., -4.16666666666667}, {
        10., -2.156825375854346}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -4.16666666666667}, {10., -8.33333333333334}, {
        10., -4.313650751708692}, {10., -2.156825375854346}, {
        10., -4.16666666666667}}], 
       PolygonBox[{{10., -8.33333333333334}, {10., -12.50000000000001}, {
        10., -6.470476127563038}, {10., -4.313650751708692}, {
        10., -8.33333333333334}}], 
       PolygonBox[{{10., 0.}, {10., -2.156825375854346}, {
        10., -8.932295329768568*^-15}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -2.156825375854346}, {10., -4.313650751708692}, {
        10., -1.7864590659537137`*^-14}, {10., -8.932295329768568*^-15}, {
        10., -2.156825375854346}}], 
       PolygonBox[{{10., -4.313650751708692}, {10., -6.470476127563038}, {
        10., -2.6796885989305705`*^-14}, {10., -1.7864590659537137`*^-14}, {
        10., -4.313650751708692}}], 
       PolygonBox[{{10., 0.}, {10., -1.5308084989341913`*^-15}, {10., 
        2.1568253758543356`}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., -1.5308084989341913`*^-15}, {
        10., -3.0616169978683826`*^-15}, {10., 4.313650751708671}, {10., 
        2.1568253758543356`}, {10., -1.5308084989341913`*^-15}}], 
       PolygonBox[{{10., -3.0616169978683826`*^-15}, {
        10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {10., 
        4.313650751708671}, {10., -3.0616169978683826`*^-15}}], 
       PolygonBox[{{10., 0.}, {10., 2.1568253758543356`}, {10., 
        4.166666666666661}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 2.1568253758543356`}, {10., 4.313650751708671}, {10.,
         8.333333333333321}, {10., 4.166666666666661}, {10., 
        2.1568253758543356`}}], 
       PolygonBox[{{10., 4.313650751708671}, {10., 6.470476127563007}, {10., 
        12.499999999999984`}, {10., 8.333333333333321}, {10., 
        4.313650751708671}}], 
       PolygonBox[{{10., 0.}, {10., 4.166666666666661}, {10., 
        5.89255650988789}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 4.166666666666661}, {10., 8.333333333333321}, {10., 
        11.78511301977578}, {10., 5.89255650988789}, {10., 
        4.166666666666661}}], 
       PolygonBox[{{10., 8.333333333333321}, {10., 12.499999999999984`}, {10.,
         17.67766952966367}, {10., 11.78511301977578}, {10., 
        8.333333333333321}}], 
       PolygonBox[{{10., 0.}, {10., 5.8925565098878945`}, {10., 
        7.216878364870319}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 5.8925565098878945`}, {10., 11.785113019775789`}, {
        10., 14.433756729740638`}, {10., 7.216878364870319}, {10., 
        5.8925565098878945`}}], 
       PolygonBox[{{10., 11.785113019775789`}, {10., 17.677669529663685`}, {
        10., 21.65063509461096}, {10., 14.433756729740638`}, {10., 
        11.785113019775789`}}], 
       PolygonBox[{{10., 0.}, {10., 7.216878364870319}, {10., 
        8.049381885742234}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 7.216878364870319}, {10., 14.433756729740638`}, {10.,
         16.098763771484467`}, {10., 8.049381885742234}, {10., 
        7.216878364870319}}], 
       PolygonBox[{{10., 14.433756729740638`}, {10., 21.65063509461096}, {10.,
         24.148145657226703`}, {10., 16.098763771484467`}, {10., 
        14.433756729740638`}}], 
       PolygonBox[{{10., 0.}, {10., 8.049381885742234}, {10., 
        8.333333333333332}, {10., 0.}, {10., 0.}}], 
       PolygonBox[{{10., 8.049381885742234}, {10., 16.098763771484467`}, {10.,
         16.666666666666664`}, {10., 8.333333333333332}, {10., 
        8.049381885742234}}], 
       PolygonBox[{{10., 16.098763771484467`}, {10., 24.148145657226703`}, {
        10., 25.}, {10., 16.666666666666664`}, {10., 16.098763771484467`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEqDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0A7YRq0Q==
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
          24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
          6.421974580955592, 25.}}], 
         PolygonBox[{{6.421974580955592, 24.148145657226706`}, {10., 
          24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
          21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
         PolygonBox[{{6.421974580955592, 21.65063509461097}, {10., 
          21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
          17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
         PolygonBox[{{6.421974580955592, 17.67766952966369}, {10., 
          17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
          12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
         PolygonBox[{{6.421974580955592, 12.500000000000004`}, {10., 
          12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
          6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
         PolygonBox[{{6.421974580955592, 6.470476127563024}, {10., 
          6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
          6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
          6.470476127563024}}], 
         PolygonBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
          1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
          6.421974580955592, -6.470476127563016}, {6.421974580955592, 
          1.5308084989341915`*^-15}}], 
         PolygonBox[{{6.421974580955592, -6.470476127563016}, {
          10., -6.470476127563016}, {10., -12.499999999999995`}, {
          6.421974580955592, -12.499999999999995`}, {
          6.421974580955592, -6.470476127563016}}], 
         PolygonBox[{{6.421974580955592, -12.499999999999995`}, {
          10., -12.499999999999995`}, {10., -17.677669529663685`}, {
          6.421974580955592, -17.677669529663685`}, {
          6.421974580955592, -12.499999999999995`}}], 
         PolygonBox[{{6.421974580955592, -17.677669529663685`}, {
          10., -17.677669529663685`}, {10., -21.65063509461097}, {
          6.421974580955592, -21.65063509461097}, {
          6.421974580955592, -17.677669529663685`}}], 
         PolygonBox[{{6.421974580955599, -21.650635094610962`}, {
          10., -21.650635094610962`}, {10., -24.148145657226706`}, {
          6.421974580955592, -24.148145657226706`}, {
          6.421974580955599, -21.650635094610962`}}], 
         PolygonBox[{{6.421974580955592, -24.148145657226706`}, {
          10., -24.148145657226706`}, {10., -25.}, {
          6.421974580955592, -25.}, {
          6.421974580955592, -24.148145657226706`}}], 
         PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
          10., -24.148145657226706`}, {
          6.421974580955592, -24.148145657226706`}, {
          6.421974580955592, -25.}}], 
         PolygonBox[{{6.421974580955592, -24.14814565722671}, {
          10., -24.14814565722671}, {10., -21.65063509461097}, {
          6.421974580955592, -21.65063509461097}, {
          6.421974580955592, -24.14814565722671}}], 
         PolygonBox[{{6.421974580955592, -21.65063509461097}, {
          10., -21.65063509461097}, {10., -17.677669529663692`}, {
          6.421974580955592, -17.677669529663692`}, {
          6.421974580955592, -21.65063509461097}}], 
         PolygonBox[{{6.421974580955592, -17.677669529663696`}, {
          10., -17.677669529663696`}, {10., -12.50000000000001}, {
          6.421974580955592, -12.50000000000001}, {
          6.421974580955592, -17.677669529663696`}}], 
         PolygonBox[{{6.421974580955592, -12.50000000000001}, {
          10., -12.50000000000001}, {10., -6.470476127563038}, {
          6.421974580955592, -6.470476127563038}, {
          6.421974580955592, -12.50000000000001}}], 
         PolygonBox[{{6.421974580955592, -6.470476127563038}, {
          10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
          6.421974580955592, -2.6796885989305705`*^-14}, {
          6.421974580955592, -6.470476127563038}}], 
         PolygonBox[{{6.421974580955592, -4.592425496802574*^-15}, {
          10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
          6.421974580955592, 6.470476127563007}, {
          6.421974580955592, -4.592425496802574*^-15}}], 
         PolygonBox[{{6.421974580955592, 6.470476127563007}, {10., 
          6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
          12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
         PolygonBox[{{6.421974580955592, 12.499999999999984`}, {10., 
          12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
          17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
         PolygonBox[{{6.421974580955592, 17.677669529663685`}, {10., 
          17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
          21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
         PolygonBox[{{6.421974580955592, 21.65063509461096}, {10., 
          21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
          24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
         PolygonBox[{{6.421974580955592, 24.148145657226703`}, {10., 
          24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
          6.421974580955592, 24.148145657226703`}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.61473174637311*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[64]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", "\<\"lens\"\>", "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.614731746376054*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[64]:="],

Cell[BoxData["\<\"-rendered element-\"\>"], "Output",
 CellChangeTimes->{3.563367931475421*^9, 3.5661588662957897`*^9, 
  3.566158994268923*^9, 3.5672683513307467`*^9, 3.614730560944459*^9, 
  3.61473174637735*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[64]="]
}, Open  ]],

Cell["\<\
Optica has surpressed its graphical labelling for the single lens object.\
\>", "Commentary",
 CellChangeTimes->{3.566158949811845*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["Numbering Your Labels", "Subsubsection",
 CellTags->{
  "Numbering Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 StyleBox["W",
  FontSlant->"Italic"],
 "hen several identical labels appear in the graphics, ",
 "Optica",
 " automatically attaches a number to each duplicate label.  However, you  \
can over-ride the automatic numbering if you supply your own label numbers in \
 advance.  This can be important in order to keep a numbering correspondance  \
with your variable names."
}], "Text",
 CellChangeTimes->{3.5661589499173813`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["\<\
lens1 = PlanoConvexLens[100,50,10,\"lens1\"];

lens2 = PlanoConvexLens[100,50,10,\"lens2\"];

AnalyzeSystem[{lens2, Move[lens1,100]},PlotType->TopView]\
\>", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[65]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
      10., -16.66666666666667}, {2.7504488342847893`, -16.666666666666668`}, {
      6.421974580955592, -25.}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
      10., -16.66666666666667}, {10., -8.333333333333336}, {
      0.6737579958920605, -8.333333333333336}, {
      2.7504488342847893`, -16.666666666666668`}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
      10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
      0.6737579958920605, -8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
      0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
      8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
      16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
      24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, -25.}, {
       2.7504488342847893`, -16.666666666666668`}, {
       0.6737579958920605, -8.333333333333336}, {
       0., -3.552713678800501*^-15}, {0.6737579958920605, 
       8.333333333333329}, {2.750448834284782, 16.666666666666657`}, {
       6.421974580955592, 24.999999999999993`}, {10., 25.}, {10., 
       16.666666666666668`}, {10., 8.333333333333336}, {10., 
       3.552713678800501*^-15}, {10., -8.333333333333329}, {
       10., -16.666666666666657`}, {10., -24.999999999999993`}, {
       6.421974580955592, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{6.421974580955592, 0.}, {10., 3.061616997868383*^-15}, {
        10., 2.551347498223653*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}, {6.421974580955592, 0.}}], 
       PolygonBox[{{2.7504488342847893`, 5.102694996447305*^-16}, {10., 
        2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {
        0.6737579958920605, 1.020538999289461*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{0.6737579958920605, 1.020538999289461*^-15}, {10., 
        2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
        1.5308084989341915`*^-15}, {0.6737579958920605, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {
        0.6737579958920605, 2.041077998578922*^-15}, {0., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{0.6737579958920605, 2.041077998578922*^-15}, {10., 
        1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {
        2.7504488342847893`, 2.5513474982236525`*^-15}, {0.6737579958920605, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{2.7504488342847893`, 2.5513474982236525`*^-15}, {10., 
        5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {
        6.421974580955592, 3.0616169978683826`*^-15}, {2.7504488342847893`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
         0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
         2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
         0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
         6.421974580955592, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
       12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955592, 12.500000000000004`}, {10., 
       12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
       6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
      LineBox[{{6.421974580955592, 6.470476127563024}, {10., 
       6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
       6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
       6.470476127563024}}], 
      LineBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       6.421974580955592, -6.470476127563016}, {6.421974580955592, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563016}, {
       10., -6.470476127563016}, {10., -12.499999999999995`}, {
       6.421974580955592, -12.499999999999995`}, {
       6.421974580955592, -6.470476127563016}}], 
      LineBox[{{6.421974580955592, -12.499999999999995`}, {
       10., -12.499999999999995`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999995`}}], 
      LineBox[{{6.421974580955592, -17.677669529663685`}, {
       10., -17.677669529663685`}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -17.677669529663685`}}], 
      LineBox[{{6.421974580955599, -21.650635094610962`}, {
       10., -21.650635094610962`}, {10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {
       6.421974580955599, -21.650635094610962`}}], 
      LineBox[{{6.421974580955592, -24.148145657226706`}, {
       10., -24.148145657226706`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226706`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.65063509461097}, {
       10., -21.65063509461097}, {10., -17.677669529663692`}, {
       6.421974580955592, -17.677669529663692`}, {
       6.421974580955592, -21.65063509461097}}], 
      LineBox[{{6.421974580955592, -17.677669529663696`}, {
       10., -17.677669529663696`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663696`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563038}, {
       6.421974580955592, -6.470476127563038}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563038}, {
       10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
       6.421974580955592, -2.6796885989305705`*^-14}, {
       6.421974580955592, -6.470476127563038}}], 
      LineBox[{{6.421974580955592, -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
       6.421974580955592, 6.470476127563007}, {
       6.421974580955592, -4.592425496802574*^-15}}], 
      LineBox[{{6.421974580955592, 6.470476127563007}, {10., 
       6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
       12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
      LineBox[{{6.421974580955592, 12.499999999999984`}, {10., 
       12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
       17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
       21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.65063509461096}, {10., 
       21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
       24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
      LineBox[{{6.421974580955592, 24.148145657226703`}, {10., 
       24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
      110., -16.66666666666667}, {
      102.75044883428481`, -16.666666666666668`}, {106.4219745809556, -25.}}],
      PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
      110., -16.66666666666667}, {110., -8.333333333333336}, {
      100.67375799589207`, -8.333333333333336}, {
      102.75044883428481`, -16.666666666666668`}}], 
     PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
      110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
      8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
      8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`, 
      16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
     PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
      16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556, 
      24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666668`}, {
       100.67375799589207`, -8.333333333333336}, {
       100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
       8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
       106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
       16.666666666666668`}, {110., 8.333333333333336}, {110., 
       3.552713678800501*^-15}, {110., -8.333333333333329}, {
       110., -16.666666666666657`}, {110., -24.999999999999993`}, {
       106.4219745809556, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, 0.}, {110., 3.061616997868383*^-15}, {
        110., 2.551347498223653*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}, {106.4219745809556, 0.}}], 
       PolygonBox[{{102.75044883428481`, 5.102694996447305*^-16}, {110., 
        2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {
        100.67375799589207`, 1.020538999289461*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{100.67375799589207`, 1.020538999289461*^-15}, {110., 
        2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15}, {100.67375799589207`, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{100.00000000000001`, 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {
        100.67375799589207`, 2.041077998578922*^-15}, {100.00000000000001`, 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{100.67375799589207`, 2.041077998578922*^-15}, {110., 
        1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {
        102.75044883428481`, 2.5513474982236525`*^-15}, {100.67375799589207`, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{102.75044883428481`, 2.5513474982236525`*^-15}, {110., 
        5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {
        106.4219745809556, 3.0616169978683826`*^-15}, {102.75044883428481`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
         100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
         100.67375799589207`, 0.}, {102.7504488342848, 0.}, {
         106.4219745809556, 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
         0.}, {110., 0.}, {110., 0.}, {110., 0.}, {106.4219745809556, 
         0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556, 
       12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000004`}, {110., 
       12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556, 
       6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
      LineBox[{{106.4219745809556, 6.470476127563024}, {110., 
       6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
       106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
       6.470476127563024}}], 
      LineBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       106.4219745809556, -6.470476127563016}, {106.4219745809556, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563016}, {
       110., -6.470476127563016}, {110., -12.499999999999995`}, {
       106.4219745809556, -12.499999999999995`}, {
       106.4219745809556, -6.470476127563016}}], 
      LineBox[{{106.4219745809556, -12.499999999999995`}, {
       110., -12.499999999999995`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999995`}}], 
      LineBox[{{106.4219745809556, -17.677669529663685`}, {
       110., -17.677669529663685`}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -17.677669529663685`}}], 
      LineBox[{{106.4219745809556, -21.650635094610962`}, {
       110., -21.650635094610962`}, {110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {
       106.4219745809556, -21.650635094610962`}}], 
      LineBox[{{106.4219745809556, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226706`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.65063509461097}, {
       110., -21.65063509461097}, {110., -17.677669529663692`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -21.65063509461097}}], 
      LineBox[{{106.4219745809556, -17.677669529663696`}, {
       110., -17.677669529663696`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663696`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563038}, {
       106.4219745809556, -6.470476127563038}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563038}, {
       110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
       106.4219745809556, -2.6796885989305705`*^-14}, {
       106.4219745809556, -6.470476127563038}}], 
      LineBox[{{106.4219745809556, -4.592425496802574*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
       106.4219745809556, 6.470476127563007}, {
       106.4219745809556, -4.592425496802574*^-15}}], 
      LineBox[{{106.4219745809556, 6.470476127563007}, {110., 
       6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556, 
       12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
      LineBox[{{106.4219745809556, 12.499999999999984`}, {110., 
       12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556, 
       17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556, 
       21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.65063509461096}, {110., 
       21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556, 
       24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
      LineBox[{{106.4219745809556, 24.148145657226703`}, {110., 
       24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"lens2\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"lens1\"\>", {105., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731746787361*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[65]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"lens2\"\>", ",", 
        RowBox[{"Move", "[", 
         RowBox[{"\<\"lens1\"\>", ",", "100.`"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.614731746818932*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[65]:="],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.5633679317789173`*^9, 3.566158866380184*^9, 
  3.5661589951045923`*^9, 3.567268351948485*^9, 3.6147305609640837`*^9, 
  3.614731746821097*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[69]="]
}, Open  ]],

Cell["\<\
The labels are numbered in advance by the user.  This time each of the \
variable names, graphical labels, and printed output uses the same numbering \
convention.\
\>", "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Optica's Default Treatment of Labels", "Subsubsection",
 CellChangeTimes->{3.566158950004718*^9},
 CellTags->{
  "Rayica's Default Treatment of Labels", "Labelling of Components", "PR6.11",
    "PR6.11.2"}],

Cell["\<\
Many times, you might not want to bother with labeling of components.   This \
is OK because the labels are always optional and not required by any Optica \
function.  If object labels are not given explicitly by the user, Optica will \
automatically assign a default label name to each component in the  graphics.\
\
\>", "Text",
 CellChangeTimes->{{3.566158950117812*^9, 3.5661589502120953`*^9}},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defaultSystem", "=", 
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"PlanoConvexLens", "[", 
       RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Prism", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
          RowBox[{"Centered", "\[Rule]", "True"}]}], "]"}], ",", "50"}], 
       "]"}], ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "100"}], "]"}], 
      ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Mirror", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"50", ",", "50"}], "}"}], ",", "5"}], "]"}], ",", "150", 
        ",", "30"}], "]"}]}], "}"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}]}]], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[70]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
      10., -16.66666666666667}, {2.7504488342847893`, -16.666666666666668`}, {
      6.421974580955592, -25.}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
      10., -16.66666666666667}, {10., -8.333333333333336}, {
      0.6737579958920605, -8.333333333333336}, {
      2.7504488342847893`, -16.666666666666668`}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
      10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
      0.6737579958920605, -8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
      0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
      8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
      16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
      24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, -25.}, {
       2.7504488342847893`, -16.666666666666668`}, {
       0.6737579958920605, -8.333333333333336}, {
       0., -3.552713678800501*^-15}, {0.6737579958920605, 
       8.333333333333329}, {2.750448834284782, 16.666666666666657`}, {
       6.421974580955592, 24.999999999999993`}, {10., 25.}, {10., 
       16.666666666666668`}, {10., 8.333333333333336}, {10., 
       3.552713678800501*^-15}, {10., -8.333333333333329}, {
       10., -16.666666666666657`}, {10., -24.999999999999993`}, {
       6.421974580955592, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{6.421974580955592, 0.}, {10., 3.061616997868383*^-15}, {
        10., 2.551347498223653*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}, {6.421974580955592, 0.}}], 
       PolygonBox[{{2.7504488342847893`, 5.102694996447305*^-16}, {10., 
        2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {
        0.6737579958920605, 1.020538999289461*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{0.6737579958920605, 1.020538999289461*^-15}, {10., 
        2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
        1.5308084989341915`*^-15}, {0.6737579958920605, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {
        0.6737579958920605, 2.041077998578922*^-15}, {0., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{0.6737579958920605, 2.041077998578922*^-15}, {10., 
        1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {
        2.7504488342847893`, 2.5513474982236525`*^-15}, {0.6737579958920605, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{2.7504488342847893`, 2.5513474982236525`*^-15}, {10., 
        5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {
        6.421974580955592, 3.0616169978683826`*^-15}, {2.7504488342847893`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
         0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
         2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
         0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
         6.421974580955592, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
       12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955592, 12.500000000000004`}, {10., 
       12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
       6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
      LineBox[{{6.421974580955592, 6.470476127563024}, {10., 
       6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
       6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
       6.470476127563024}}], 
      LineBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       6.421974580955592, -6.470476127563016}, {6.421974580955592, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563016}, {
       10., -6.470476127563016}, {10., -12.499999999999995`}, {
       6.421974580955592, -12.499999999999995`}, {
       6.421974580955592, -6.470476127563016}}], 
      LineBox[{{6.421974580955592, -12.499999999999995`}, {
       10., -12.499999999999995`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999995`}}], 
      LineBox[{{6.421974580955592, -17.677669529663685`}, {
       10., -17.677669529663685`}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -17.677669529663685`}}], 
      LineBox[{{6.421974580955599, -21.650635094610962`}, {
       10., -21.650635094610962`}, {10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {
       6.421974580955599, -21.650635094610962`}}], 
      LineBox[{{6.421974580955592, -24.148145657226706`}, {
       10., -24.148145657226706`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226706`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.65063509461097}, {
       10., -21.65063509461097}, {10., -17.677669529663692`}, {
       6.421974580955592, -17.677669529663692`}, {
       6.421974580955592, -21.65063509461097}}], 
      LineBox[{{6.421974580955592, -17.677669529663696`}, {
       10., -17.677669529663696`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663696`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563038}, {
       6.421974580955592, -6.470476127563038}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563038}, {
       10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
       6.421974580955592, -2.6796885989305705`*^-14}, {
       6.421974580955592, -6.470476127563038}}], 
      LineBox[{{6.421974580955592, -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
       6.421974580955592, 6.470476127563007}, {
       6.421974580955592, -4.592425496802574*^-15}}], 
      LineBox[{{6.421974580955592, 6.470476127563007}, {10., 
       6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
       12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
      LineBox[{{6.421974580955592, 12.499999999999984`}, {10., 
       12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
       17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
       21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.65063509461096}, {10., 
       21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
       24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
      LineBox[{{6.421974580955592, 24.148145657226703`}, {10., 
       24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {62.5, 21.650635094610966`}, {
       62.5, 21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {62.5, 21.650635094610966`}, {
       62.5, 21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, -21.657851972975834`}, {62.5, 21.665068851340703`}, {
       87.5125, -21.657851972975838`}, {37.4875, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, -21.657851972975834`}, {62.5, 21.665068851340703`}, {
       87.5125, -21.657851972975838`}, {37.4875, -21.657851972975834`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
      110., -16.66666666666667}, {
      102.75044883428481`, -16.666666666666668`}, {106.4219745809556, -25.}}],
      PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
      110., -16.66666666666667}, {110., -8.333333333333336}, {
      100.67375799589207`, -8.333333333333336}, {
      102.75044883428481`, -16.666666666666668`}}], 
     PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
      110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
      8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
      8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`, 
      16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
     PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
      16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556, 
      24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666668`}, {
       100.67375799589207`, -8.333333333333336}, {
       100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
       8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
       106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
       16.666666666666668`}, {110., 8.333333333333336}, {110., 
       3.552713678800501*^-15}, {110., -8.333333333333329}, {
       110., -16.666666666666657`}, {110., -24.999999999999993`}, {
       106.4219745809556, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, 0.}, {110., 3.061616997868383*^-15}, {
        110., 2.551347498223653*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}, {106.4219745809556, 0.}}], 
       PolygonBox[{{102.75044883428481`, 5.102694996447305*^-16}, {110., 
        2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {
        100.67375799589207`, 1.020538999289461*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{100.67375799589207`, 1.020538999289461*^-15}, {110., 
        2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15}, {100.67375799589207`, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{100.00000000000001`, 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {
        100.67375799589207`, 2.041077998578922*^-15}, {100.00000000000001`, 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{100.67375799589207`, 2.041077998578922*^-15}, {110., 
        1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {
        102.75044883428481`, 2.5513474982236525`*^-15}, {100.67375799589207`, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{102.75044883428481`, 2.5513474982236525`*^-15}, {110., 
        5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {
        106.4219745809556, 3.0616169978683826`*^-15}, {102.75044883428481`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
         100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
         100.67375799589207`, 0.}, {102.7504488342848, 0.}, {
         106.4219745809556, 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
         0.}, {110., 0.}, {110., 0.}, {110., 0.}, {106.4219745809556, 
         0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556, 
       12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000004`}, {110., 
       12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556, 
       6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
      LineBox[{{106.4219745809556, 6.470476127563024}, {110., 
       6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
       106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
       6.470476127563024}}], 
      LineBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       106.4219745809556, -6.470476127563016}, {106.4219745809556, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563016}, {
       110., -6.470476127563016}, {110., -12.499999999999995`}, {
       106.4219745809556, -12.499999999999995`}, {
       106.4219745809556, -6.470476127563016}}], 
      LineBox[{{106.4219745809556, -12.499999999999995`}, {
       110., -12.499999999999995`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999995`}}], 
      LineBox[{{106.4219745809556, -17.677669529663685`}, {
       110., -17.677669529663685`}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -17.677669529663685`}}], 
      LineBox[{{106.4219745809556, -21.650635094610962`}, {
       110., -21.650635094610962`}, {110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {
       106.4219745809556, -21.650635094610962`}}], 
      LineBox[{{106.4219745809556, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226706`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.65063509461097}, {
       110., -21.65063509461097}, {110., -17.677669529663692`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -21.65063509461097}}], 
      LineBox[{{106.4219745809556, -17.677669529663696`}, {
       110., -17.677669529663696`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663696`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563038}, {
       106.4219745809556, -6.470476127563038}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563038}, {
       110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
       106.4219745809556, -2.6796885989305705`*^-14}, {
       106.4219745809556, -6.470476127563038}}], 
      LineBox[{{106.4219745809556, -4.592425496802574*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
       106.4219745809556, 6.470476127563007}, {
       106.4219745809556, -4.592425496802574*^-15}}], 
      LineBox[{{106.4219745809556, 6.470476127563007}, {110., 
       6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556, 
       12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
      LineBox[{{106.4219745809556, 12.499999999999984`}, {110., 
       12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556, 
       17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556, 
       21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.65063509461096}, {110., 
       21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556, 
       24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
      LineBox[{{106.4219745809556, 24.148145657226703`}, {110., 
       24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{162.5, -21.650635094610966`}, {
      166.83012701892218`, -19.150635094610966`}, {
      162.66346035225553`, -11.933756729740647`}, {
      158.33333333333334`, -14.433756729740644`}, {
      162.5, -21.650635094610966`}}], 
     PolygonBox[{{158.33333333333334`, -14.433756729740644`}, {
      162.66346035225553`, -11.933756729740647`}, {
      158.49679368558884`, -4.716878364870324}, {
      154.16666666666666`, -7.216878364870324}, {
      158.33333333333334`, -14.433756729740644`}}], 
     PolygonBox[{{154.16666666666666`, -7.216878364870324}, {
      158.49679368558884`, -4.716878364870324}, {154.33012701892218`, 
      2.499999999999994}, {150., 0.}, {
      154.16666666666666`, -7.216878364870324}}], 
     PolygonBox[{{150., 0.}, {154.33012701892218`, 2.5}, {150.16346035225553`,
       9.716878364870322}, {145.83333333333334`, 7.216878364870317}, {150., 
      0.}}], PolygonBox[{{145.83333333333334`, 7.216878364870317}, {
      150.16346035225553`, 9.716878364870322}, {145.99679368558884`, 
      16.933756729740644`}, {141.66666666666666`, 14.433756729740642`}, {
      145.83333333333334`, 7.216878364870317}}], 
     PolygonBox[{{141.66666666666666`, 14.433756729740642`}, {
      145.99679368558884`, 16.933756729740644`}, {141.83012701892218`, 
      24.150635094610962`}, {137.5, 21.65063509461096}, {141.66666666666666`, 
      14.433756729740642`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, -21.650635094610966`}, {
       158.33333333333334`, -14.433756729740644`}, {
       154.16666666666666`, -7.216878364870324}, {
       150., -3.076740298213702*^-15}, {145.83333333333334`, 
       7.216878364870317}, {141.66666666666669`, 14.433756729740635`}, {137.5,
        21.65063509461096}, {141.83012701892218`, 24.150635094610966`}, {
       145.99679368558884`, 16.933756729740644`}, {150.16346035225553`, 
       9.716878364870324}, {154.33012701892218`, 2.500000000000003}, {
       158.49679368558884`, -4.716878364870317}, {
       162.66346035225553`, -11.933756729740635`}, {
       166.83012701892218`, -19.15063509461096}, {
       162.5, -21.650635094610966`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{150., 0.}, {154.33012701892218`, 2.5000000000000027`}, {
        154.33012701892218`, 2.500000000000002}, {150., 
        4.4190634946871114`*^-16}, {150., 0.}}], 
       PolygonBox[{{150., 4.4190634946871114`*^-16}, {154.33012701892218`, 
        2.500000000000002}, {154.33012701892218`, 2.5000000000000018`}, {150.,
         8.838126989374223*^-16}, {150., 4.4190634946871114`*^-16}}], 
       PolygonBox[{{150., 8.838126989374223*^-16}, {154.33012701892218`, 
        2.5000000000000018`}, {154.33012701892218`, 2.5000000000000013`}, {
        150., 1.3257190484061335`*^-15}, {150., 8.838126989374223*^-16}}], 
       PolygonBox[{{150., 1.3257190484061335`*^-15}, {154.33012701892218`, 
        2.5000000000000013`}, {154.33012701892218`, 2.500000000000001}, {150.,
         1.7676253978748445`*^-15}, {150., 1.3257190484061335`*^-15}}], 
       PolygonBox[{{150., 1.7676253978748445`*^-15}, {154.33012701892218`, 
        2.500000000000001}, {154.33012701892218`, 2.5000000000000004`}, {150.,
         2.2095317473435558`*^-15}, {150., 1.7676253978748445`*^-15}}], 
       PolygonBox[{{150., 2.2095317473435558`*^-15}, {154.33012701892218`, 
        2.5000000000000004`}, {154.33012701892218`, 2.5}, {150., 
        2.6514380968122666`*^-15}, {150., 2.2095317473435558`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {
         150., 0.}, {150., 0.}, {154.33012701892218`, 2.5}, {
         154.33012701892218`, 2.5}, {154.33012701892218`, 2.5}, {
         154.33012701892218`, 2.5}, {154.33012701892218`, 2.5}, {
         154.33012701892218`, 2.5}, {154.33012701892218`, 2.5}, {150., 
         0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{162.5, -21.650635094610966`}, {137.5, 
      21.650635094610966`}, {137.5, 21.650635094610966`}, {
      162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, -21.650635094610966`}, {137.5, 21.650635094610966`}, {
       137.5, 21.650635094610966`}, {162.5, -21.650635094610966`}, {
       162.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{166.83012701892218`, -19.150635094610966`}, {
       141.83012701892218`, 24.150635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.66346035225553`, -11.933756729740644`}, {
       158.33333333333334`, -14.433756729740644`}, {
       162.5, -21.650635094610966`}}], 
      LineBox[{{158.33333333333334`, -14.433756729740644`}, {
       162.66346035225553`, -11.933756729740644`}, {
       158.49679368558884`, -4.716878364870324}, {
       154.16666666666666`, -7.216878364870324}, {
       158.33333333333334`, -14.433756729740644`}}], 
      LineBox[{{154.16666666666666`, -7.216878364870322}, {
       158.49679368558884`, -4.716878364870322}, {154.33012701892218`, 
       2.4999999999999987`}, {150., -1.2018516789897274`*^-15}, {
       154.16666666666666`, -7.216878364870322}}], 
      LineBox[{{150., 0.}, {154.33012701892218`, 2.5}, {150.16346035225553`, 
       9.716878364870322}, {145.83333333333334`, 7.216878364870321}, {150., 
       0.}}], LineBox[{{145.83333333333334`, 7.216878364870321}, {
       150.16346035225553`, 9.716878364870322}, {145.99679368558884`, 
       16.933756729740644`}, {141.66666666666666`, 14.433756729740642`}, {
       145.83333333333334`, 7.216878364870321}}], 
      LineBox[{{141.66666666666666`, 14.433756729740642`}, {
       145.99679368558884`, 16.933756729740644`}, {141.83012701892218`, 
       24.15063509461096}, {137.5, 21.65063509461096}, {141.66666666666666`, 
       14.433756729740642`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {141.83012701892218`, 24.150635094610966`}, {
       137.5, 21.650635094610966`}, {137.5, 21.650635094610966`}}], 
      LineBox[{{137.5, 21.650635094610966`}, {141.83012701892218`, 
       24.150635094610966`}, {145.99679368558884`, 16.933756729740644`}, {
       141.66666666666666`, 14.433756729740644`}, {137.5, 
       21.650635094610966`}}], 
      LineBox[{{141.66666666666666`, 14.433756729740644`}, {
       145.99679368558884`, 16.933756729740644`}, {150.16346035225553`, 
       9.716878364870324}, {145.83333333333334`, 7.216878364870324}, {
       141.66666666666666`, 14.433756729740644`}}], 
      LineBox[{{145.83333333333334`, 7.216878364870322}, {150.16346035225553`,
        9.716878364870322}, {154.33012701892218`, 2.5000000000000013`}, {150.,
        1.2018516789897274`*^-15}, {145.83333333333334`, 7.216878364870322}}],
       LineBox[{{150., 0.}, {154.33012701892218`, 2.5}, {
       158.49679368558884`, -4.716878364870321}, {
       154.16666666666666`, -7.216878364870321}, {150., 0.}}], 
      LineBox[{{154.16666666666666`, -7.216878364870321}, {
       158.49679368558884`, -4.716878364870321}, {
       162.66346035225553`, -11.933756729740642`}, {
       158.33333333333334`, -14.433756729740642`}, {
       154.16666666666666`, -7.216878364870321}}], 
      LineBox[{{158.33333333333334`, -14.433756729740642`}, {
       162.66346035225553`, -11.933756729740642`}, {
       166.83012701892218`, -19.15063509461096}, {
       162.5, -21.65063509461096}, {
       158.33333333333334`, -14.433756729740642`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}], 
      LineBox[{{162.5, -21.650635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       166.83012701892218`, -19.150635094610966`}, {
       162.5, -21.650635094610966`}, {162.5, -21.650635094610966`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L1\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"Prism\"\>", {24., -1.}, {0., 0.}], 
    InsetBox["\<\"L2\"\>", {105., -26.}, {0., 0.}], 
    InsetBox["\<\"M\"\>", {165.1650635094611, -21.2666604983954}, {0., 0.}]}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317476877623`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[70]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Prism", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
            RowBox[{"{", 
             RowBox[{"Centered", "\[Rule]", "True"}], "}"}]}], "]"}], ",", 
          "50.`"}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "100.`"}], 
         "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Mirror", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"50", ",", "50"}], "}"}], ",", "5"}], "]"}], ",", 
          "150.`", ",", "30.000000000000004`"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.614731747723686*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[70]:="],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.563367932590921*^9, 3.5661588664126587`*^9, 
  3.566158996910472*^9, 3.567268353502305*^9, 3.614730560991418*^9, 
  3.614731747725597*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[70]="]
}, Open  ]],

Cell["\<\
Optica gives default labels automatically, while the printed output shows the \
 full function names.\
\>", "Commentary",
 CellChangeTimes->{3.5661589503001947`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "In general, component labelling works for any two-dimensional ",
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " setting but gets surpressed with three-dimensional plots."
}], "Text",
 PageBreakAbove->True,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ShowSystem", "[", 
   RowBox[{"defaultSystem", ",", 
    RowBox[{"PlotType", "\[Rule]", "SideView"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ShowSystem", "[", 
   RowBox[{"defaultSystem", ",", 
    RowBox[{"PlotType", "\[Rule]", "Full3D"}]}], "]"}], ";"}]}], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[71]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, 0.}, {10., 6.123233995736766*^-15}, {10.,
       5.102694996447306*^-15}, {2.7504488342847893`, 0.}, {6.421974580955592,
       0.}}], PolygonBox[{{2.7504488342847893`, 0.}, {10., 
      5.102694996447306*^-15}, {10., 4.0821559971578446`*^-15}, {
      0.6737579958920605, 0.}, {2.7504488342847893`, 0.}}], 
     PolygonBox[{{0.6737579958920605, 0.}, {10., 4.0821559971578446`*^-15}, {
      10., 3.061616997868384*^-15}, {0., 0.}, {0.6737579958920605, 0.}}], 
     PolygonBox[{{0., 0.}, {10., 3.061616997868383*^-15}, {10., 
      2.0410779985789223`*^-15}, {0.6737579958920605, 0.}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 0.}, {10., 2.0410779985789223`*^-15}, {
      10., 1.0205389992894613`*^-15}, {2.7504488342847893`, 0.}, {
      0.6737579958920605, 0.}}], 
     PolygonBox[{{2.7504488342847893`, 0.}, {10., 1.0205389992894615`*^-15}, {
      10., 5.098616525425841*^-31}, {6.421974580955592, 0.}, {
      2.7504488342847893`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
       0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
       2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
       0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
       6.421974580955592, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
        10., -16.66666666666667}, {
        2.7504488342847893`, -16.666666666666668`}, {
        6.421974580955592, -25.}}], 
       PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
        10., -16.66666666666667}, {10., -8.333333333333336}, {
        0.6737579958920605, -8.333333333333336}, {
        2.7504488342847893`, -16.666666666666668`}}], 
       PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
        10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
        0.6737579958920605, -8.333333333333336}}], 
       PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
        0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
       PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
        8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
        16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
       PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
        16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
        24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.421974580955592, -25.}, {
         2.7504488342847893`, -16.666666666666668`}, {
         0.6737579958920605, -8.333333333333336}, {
         0., -3.552713678800501*^-15}, {0.6737579958920605, 
         8.333333333333329}, {2.750448834284782, 16.666666666666657`}, {
         6.421974580955592, 24.999999999999993`}, {10., 25.}, {10., 
         16.666666666666668`}, {10., 8.333333333333336}, {10., 
         3.552713678800501*^-15}, {10., -8.333333333333329}, {
         10., -16.666666666666657`}, {10., -24.999999999999993`}, {
         6.421974580955592, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 0.}, {10., 0.}, {10., 
       6.4704761275630185`}, {6.421974580955592, 6.4704761275630185`}, {
       6.421974580955592, 0.}}], 
      LineBox[{{6.421974580955592, 6.4704761275630185`}, {10., 
       6.4704761275630185`}, {10., 12.499999999999998`}, {6.421974580955592, 
       12.499999999999998`}, {6.421974580955592, 6.4704761275630185`}}], 
      LineBox[{{6.421974580955592, 12.499999999999998`}, {10., 
       12.499999999999998`}, {10., 17.677669529663685`}, {6.421974580955592, 
       17.677669529663685`}, {6.421974580955592, 12.499999999999998`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.650635094610966`}, {6.421974580955592, 
       21.650635094610966`}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.650635094610966`}, {10., 
       21.650635094610966`}, {10., 24.148145657226706`}, {6.421974580955592, 
       24.148145657226706`}, {6.421974580955592, 21.650635094610966`}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.499999999999998`}, {6.421974580955592, 
       12.499999999999998`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955599, 12.500000000000009`}, {10., 
       12.500000000000009`}, {10., 6.470476127563026}, {6.421974580955592, 
       6.470476127563026}, {6.421974580955599, 12.500000000000009`}}], 
      LineBox[{{6.421974580955592, 6.470476127563026}, {10., 
       6.470476127563026}, {10., 3.061616997868383*^-15}, {6.421974580955592, 
       3.061616997868383*^-15}, {6.421974580955592, 6.470476127563026}}], 
      LineBox[{{6.421974580955592, 3.061616997868383*^-15}, {10., 
       3.061616997868383*^-15}, {10., -6.47047612756302}, {
       6.421974580955592, -6.47047612756302}, {6.421974580955592, 
       3.061616997868383*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563009}, {
       10., -6.470476127563009}, {10., -12.499999999999993`}, {
       6.421974580955592, -12.499999999999993`}, {
       6.421974580955592, -6.470476127563009}}], 
      LineBox[{{6.421974580955592, -12.499999999999993`}, {
       10., -12.499999999999993`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999993`}}], 
      LineBox[{{6.421974580955592, -17.677669529663678`}, {
       10., -17.677669529663678`}, {10., -21.65063509461096}, {
       6.421974580955592, -21.65063509461096}, {
       6.421974580955592, -17.677669529663678`}}], 
      LineBox[{{6.421974580955592, -21.65063509461096}, {
       10., -21.65063509461096}, {10., -24.148145657226703`}, {
       6.421974580955592, -24.148145657226703`}, {
       6.421974580955592, -21.65063509461096}}], 
      LineBox[{{6.421974580955592, -24.148145657226703`}, {
       10., -24.148145657226703`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226703`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.14814565722671}, {6.421974580955592, -24.14814565722671}, {
       6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.650635094610976`}, {
       6.421974580955592, -21.650635094610976`}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.650635094610976`}, {
       10., -21.650635094610976`}, {10., -17.67766952966371}, {
       6.421974580955599, -17.67766952966371}, {
       6.421974580955592, -21.650635094610976`}}], 
      LineBox[{{6.421974580955592, -17.677669529663692`}, {
       10., -17.677669529663692`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663692`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563039}, {
       6.421974580955592, -6.470476127563039}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563039}, {
       10., -6.470476127563039}, {10., -2.8327694488239898`*^-14}, {
       6.421974580955592, -2.8327694488239898`*^-14}, {
       6.421974580955592, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -25.}, {62.5, -25.}, {62.5, 25.}, {37.5, 25.}, {
       37.5, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -25.}, {62.5, -25.}, {62.5, 25.}, {87.5, 25.}, {
       87.5, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -25.}, {87.5, -25.}, {87.5, 25.}, {37.5, 25.}, {
       37.5, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, -25.}, {62.5, -25.}, {87.5125, -25.}, {
       37.4875, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, 25.}, {62.5, 25.}, {87.5125, 25.}, {37.4875, 
       25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, 0.}, {110., 6.123233995736766*^-15}, {
      110., 5.102694996447306*^-15}, {102.75044883428481`, 0.}, {
      106.4219745809556, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 5.102694996447306*^-15}, {
      110., 4.0821559971578446`*^-15}, {100.67375799589207`, 0.}, {
      102.75044883428481`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      4.0821559971578446`*^-15}, {110., 3.061616997868384*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 3.061616997868383*^-15}, {
      110., 2.0410779985789223`*^-15}, {100.67375799589207`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      2.0410779985789223`*^-15}, {110., 1.0205389992894613`*^-15}, {
      102.75044883428481`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 
      1.0205389992894615`*^-15}, {110., 5.098616525425841*^-31}, {
      106.4219745809556, 0.}, {102.75044883428481`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
       100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
       100.67375799589207`, 0.}, {102.7504488342848, 0.}, {106.4219745809556, 
       0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110.,
        0.}, {110., 0.}, {106.4219745809556, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
        110., -16.66666666666667}, {
        102.75044883428481`, -16.666666666666668`}, {
        106.4219745809556, -25.}}], 
       PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
        110., -16.66666666666667}, {110., -8.333333333333336}, {
        100.67375799589207`, -8.333333333333336}, {
        102.75044883428481`, -16.666666666666668`}}], 
       PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
        110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
        100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}],
        PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
        8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
        100.00000000000001`, 0.}}], 
       PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
        8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`,
         16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
       PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
        16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556,
         24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, -25.}, {
         102.75044883428481`, -16.666666666666668`}, {
         100.67375799589207`, -8.333333333333336}, {
         100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
         8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
         106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
         16.666666666666668`}, {110., 8.333333333333336}, {110., 
         3.552713678800501*^-15}, {110., -8.333333333333329}, {
         110., -16.666666666666657`}, {110., -24.999999999999993`}, {
         106.4219745809556, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {110., 0.}, {110., 
       6.4704761275630185`}, {106.4219745809556, 6.4704761275630185`}, {
       106.4219745809556, 0.}}], 
      LineBox[{{106.4219745809556, 6.4704761275630185`}, {110., 
       6.4704761275630185`}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 6.4704761275630185`}}], 
      LineBox[{{106.4219745809556, 12.499999999999998`}, {110., 
       12.499999999999998`}, {110., 17.677669529663685`}, {106.4219745809556, 
       17.677669529663685`}, {106.4219745809556, 12.499999999999998`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.650635094610966`}, {106.4219745809556, 
       21.650635094610966`}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.650635094610966`}, {110., 
       21.650635094610966`}, {110., 24.148145657226706`}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.650635094610966`}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000009`}, {110., 
       12.500000000000009`}, {110., 6.470476127563026}, {106.4219745809556, 
       6.470476127563026}, {106.4219745809556, 12.500000000000009`}}], 
      LineBox[{{106.4219745809556, 6.470476127563026}, {110., 
       6.470476127563026}, {110., 3.061616997868383*^-15}, {106.4219745809556,
        3.061616997868383*^-15}, {106.4219745809556, 6.470476127563026}}], 
      LineBox[{{106.4219745809556, 3.061616997868383*^-15}, {110., 
       3.061616997868383*^-15}, {110., -6.47047612756302}, {
       106.4219745809556, -6.47047612756302}, {106.4219745809556, 
       3.061616997868383*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563009}, {
       110., -6.470476127563009}, {110., -12.499999999999993`}, {
       106.4219745809556, -12.499999999999993`}, {
       106.4219745809556, -6.470476127563009}}], 
      LineBox[{{106.4219745809556, -12.499999999999993`}, {
       110., -12.499999999999993`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999993`}}], 
      LineBox[{{106.4219745809556, -17.677669529663678`}, {
       110., -17.677669529663678`}, {110., -21.65063509461096}, {
       106.4219745809556, -21.65063509461096}, {
       106.4219745809556, -17.677669529663678`}}], 
      LineBox[{{106.4219745809556, -21.65063509461096}, {
       110., -21.65063509461096}, {110., -24.148145657226703`}, {
       106.4219745809556, -24.148145657226703`}, {
       106.4219745809556, -21.65063509461096}}], 
      LineBox[{{106.4219745809556, -24.148145657226703`}, {
       110., -24.148145657226703`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226703`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.14814565722671}, {106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.650635094610976`}, {
       106.4219745809556, -21.650635094610976`}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.650635094610976`}, {
       110., -21.650635094610976`}, {110., -17.67766952966371}, {
       106.4219745809556, -17.67766952966371}, {
       106.4219745809556, -21.650635094610976`}}], 
      LineBox[{{106.4219745809556, -17.677669529663692`}, {
       110., -17.677669529663692`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663692`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563039}, {
       106.4219745809556, -6.470476127563039}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563039}, {
       110., -6.470476127563039}, {110., -2.8327694488239898`*^-14}, {
       106.4219745809556, -2.8327694488239898`*^-14}, {
       106.4219745809556, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{162.5, 0.}, {166.83012701892218`, 6.123233995736766*^-15}, {
      162.66346035225553`, 5.102694996447306*^-15}, {158.33333333333334`, 
      0.}, {162.5, 0.}}], 
     PolygonBox[{{158.33333333333334`, 0.}, {162.66346035225553`, 
      5.102694996447306*^-15}, {158.49679368558884`, 
      4.0821559971578446`*^-15}, {154.16666666666666`, 0.}, {
      158.33333333333334`, 0.}}], 
     PolygonBox[{{154.16666666666666`, 0.}, {158.49679368558884`, 
      4.0821559971578446`*^-15}, {154.33012701892218`, 
      3.061616997868384*^-15}, {150., 0.}, {154.16666666666666`, 0.}}], 
     PolygonBox[{{150., 0.}, {154.33012701892218`, 3.061616997868383*^-15}, {
      150.16346035225553`, 2.0410779985789223`*^-15}, {145.83333333333334`, 
      0.}, {150., 0.}}], 
     PolygonBox[{{145.83333333333334`, 0.}, {150.16346035225553`, 
      2.0410779985789223`*^-15}, {145.99679368558884`, 
      1.0205389992894613`*^-15}, {141.66666666666666`, 0.}, {
      145.83333333333334`, 0.}}], 
     PolygonBox[{{141.66666666666666`, 0.}, {145.99679368558884`, 
      1.0205389992894615`*^-15}, {141.83012701892218`, 
      5.098616525425841*^-31}, {137.5, 0.}, {141.66666666666666`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, 0.}, {158.33333333333334`, 0.}, {154.16666666666666`, 
       0.}, {150., 0.}, {145.83333333333334`, 0.}, {141.66666666666669`, 
       0.}, {137.5, 0.}, {141.83012701892218`, 0.}, {145.99679368558884`, 
       0.}, {150.16346035225553`, 0.}, {154.33012701892218`, 0.}, {
       158.49679368558884`, 0.}, {162.66346035225553`, 0.}, {
       166.83012701892218`, 0.}, {162.5, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{150., -25.}, {154.33012701892218`, -25.}, {
        154.33012701892218`, -16.66666666666667}, {
        150., -16.666666666666668`}, {150., -25.}}], 
       PolygonBox[{{150., -16.666666666666668`}, {
        154.33012701892218`, -16.66666666666667}, {
        154.33012701892218`, -8.333333333333336}, {
        150., -8.333333333333336}, {150., -16.666666666666668`}}], 
       PolygonBox[{{150., -8.333333333333336}, {
        154.33012701892218`, -8.333333333333336}, {
        154.33012701892218`, -7.105427357601002*^-15}, {150., 0.}, {
        150., -8.333333333333336}}], 
       PolygonBox[{{150., 0.}, {154.33012701892218`, 0.}, {
        154.33012701892218`, 8.333333333333332}, {150., 8.333333333333329}, {
        150., 0.}}], 
       PolygonBox[{{150., 8.333333333333329}, {154.33012701892218`, 
        8.333333333333332}, {154.33012701892218`, 16.666666666666664`}, {150.,
         16.666666666666664`}, {150., 8.333333333333329}}], 
       PolygonBox[{{150., 16.666666666666664`}, {154.33012701892218`, 
        16.666666666666664`}, {154.33012701892218`, 24.999999999999996`}, {
        150., 24.999999999999993`}, {150., 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{150., -25.}, {150., -16.666666666666668`}, {
         150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
         8.333333333333329}, {150., 16.666666666666657`}, {150., 
         24.999999999999993`}, {154.33012701892218`, 25.}, {
         154.33012701892218`, 16.666666666666668`}, {154.33012701892218`, 
         8.333333333333336}, {154.33012701892218`, 3.552713678800501*^-15}, {
         154.33012701892218`, -8.333333333333329}, {
         154.33012701892218`, -16.666666666666657`}, {
         154.33012701892218`, -24.999999999999993`}, {150., -25.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{162.5, -25.}, {137.5, -25.}, {137.5, 25.}, {162.5, 25.}, {
      162.5, -25.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, -25.}, {137.5, -25.}, {137.5, 25.}, {162.5, 25.}, {
       162.5, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{166.83012701892218`, -25.}, {141.83012701892218`, -25.}, {
       141.83012701892218`, 25.}, {166.83012701892218`, 25.}, {
       166.83012701892218`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{162.5, 25.}, {166.83012701892218`, 25.}, {162.66346035225553`,
        25.}, {158.33333333333334`, 25.}, {162.5, 25.}}], 
      LineBox[{{158.33333333333334`, 25.}, {162.66346035225553`, 25.}, {
       158.49679368558884`, 25.}, {154.16666666666666`, 25.}, {
       158.33333333333334`, 25.}}], 
      LineBox[{{154.16666666666666`, 25.}, {158.49679368558884`, 25.}, {
       154.33012701892218`, 25.}, {150., 25.}, {154.16666666666666`, 25.}}], 
      LineBox[{{150., 25.}, {154.33012701892218`, 25.}, {150.16346035225553`, 
       25.}, {145.83333333333334`, 25.}, {150., 25.}}], 
      LineBox[{{145.83333333333334`, 25.}, {150.16346035225553`, 25.}, {
       145.99679368558884`, 25.}, {141.66666666666666`, 25.}, {
       145.83333333333334`, 25.}}], 
      LineBox[{{141.66666666666666`, 25.}, {145.99679368558884`, 25.}, {
       141.83012701892218`, 25.}, {137.5, 25.}, {141.66666666666666`, 25.}}], 
      LineBox[{{137.5, 25.}, {141.83012701892218`, 25.}, {141.83012701892218`,
        16.666666666666668`}, {137.5, 16.666666666666668`}, {137.5, 25.}}], 
      LineBox[{{137.5, 16.666666666666668`}, {141.83012701892218`, 
       16.666666666666668`}, {141.83012701892218`, 8.333333333333336}, {137.5,
        8.333333333333336}, {137.5, 16.666666666666668`}}], 
      LineBox[{{137.5, 8.333333333333334}, {141.83012701892218`, 
       8.333333333333334}, {141.83012701892218`, 1.3877787807814457`*^-15}, {
       137.5, 1.3877787807814457`*^-15}, {137.5, 8.333333333333334}}], 
      LineBox[{{137.5, 0.}, {141.83012701892218`, 0.}, {
       141.83012701892218`, -8.333333333333332}, {
       137.5, -8.333333333333332}, {137.5, 0.}}], 
      LineBox[{{137.5, -8.333333333333332}, {
       141.83012701892218`, -8.333333333333332}, {
       141.83012701892218`, -16.666666666666664`}, {
       137.5, -16.666666666666664`}, {137.5, -8.333333333333332}}], 
      LineBox[{{137.5, -16.666666666666664`}, {
       141.83012701892218`, -16.666666666666664`}, {
       141.83012701892218`, -24.999999999999993`}, {
       137.5, -24.999999999999993`}, {137.5, -16.666666666666664`}}], 
      LineBox[{{137.5, -25.}, {141.83012701892218`, -25.}, {
       145.99679368558884`, -25.}, {141.66666666666666`, -25.}, {
       137.5, -25.}}], 
      LineBox[{{141.66666666666666`, -25.}, {145.99679368558884`, -25.}, {
       150.16346035225553`, -25.}, {145.83333333333334`, -25.}, {
       141.66666666666666`, -25.}}], 
      LineBox[{{145.83333333333334`, -25.}, {150.16346035225553`, -25.}, {
       154.33012701892218`, -25.}, {150., -25.}, {
       145.83333333333334`, -25.}}], 
      LineBox[{{150., -25.}, {154.33012701892218`, -25.}, {
       158.49679368558884`, -25.}, {154.16666666666666`, -25.}, {
       150., -25.}}], 
      LineBox[{{154.16666666666666`, -25.}, {158.49679368558884`, -25.}, {
       162.66346035225553`, -25.}, {158.33333333333334`, -25.}, {
       154.16666666666666`, -25.}}], 
      LineBox[{{158.33333333333334`, -25.}, {162.66346035225553`, -25.}, {
       166.83012701892218`, -25.}, {162.5, -25.}, {
       158.33333333333334`, -25.}}], 
      LineBox[{{162.5, -25.}, {166.83012701892218`, -25.}, {
       166.83012701892218`, -16.666666666666668`}, {
       162.5, -16.666666666666668`}, {162.5, -25.}}], 
      LineBox[{{162.5, -16.666666666666668`}, {
       166.83012701892218`, -16.666666666666668`}, {
       166.83012701892218`, -8.333333333333336}, {
       162.5, -8.333333333333336}, {162.5, -16.666666666666668`}}], 
      LineBox[{{162.5, -8.333333333333334}, {
       166.83012701892218`, -8.333333333333334}, {
       166.83012701892218`, -1.3877787807814457`*^-15}, {
       162.5, -1.3877787807814457`*^-15}, {162.5, -8.333333333333334}}], 
      LineBox[{{162.5, 0.}, {166.83012701892218`, 0.}, {166.83012701892218`, 
       8.333333333333332}, {162.5, 8.333333333333332}, {162.5, 0.}}], 
      LineBox[{{162.5, 8.333333333333332}, {166.83012701892218`, 
       8.333333333333332}, {166.83012701892218`, 16.666666666666664`}, {162.5,
        16.666666666666664`}, {162.5, 8.333333333333332}}], 
      LineBox[{{162.5, 16.666666666666664`}, {166.83012701892218`, 
       16.666666666666664`}, {166.83012701892218`, 24.999999999999993`}, {
       162.5, 24.999999999999993`}, {162.5, 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L1\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"Prism\"\>", {24., -26.}, {0., 0.}], 
    InsetBox["\<\"L2\"\>", {105., -26.}, {0., 0.}], 
    InsetBox["\<\"M\"\>", {165.1650635094611, -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731747916155*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[71]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{37.5, -21.650635094610966`, -25.}, {62.5, 
       21.650635094610966`, -25.}, {62.5, 21.650635094610966`, 25.}, {
       37.5, -21.650635094610966`, 25.}, {
       37.5, -21.650635094610966`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{87.5, -21.650635094610966`, -25.}, {62.5, 
       21.650635094610966`, -25.}, {62.5, 21.650635094610966`, 25.}, {
       87.5, -21.650635094610966`, 25.}, {
       87.5, -21.650635094610966`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{37.5, -21.650635094610966`, -25.}, {
       87.5, -21.650635094610966`, -25.}, {87.5, -21.650635094610966`, 25.}, {
       37.5, -21.650635094610966`, 25.}, {
       37.5, -21.650635094610966`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{37.4875, -21.657851972975834`, -25.}, {62.5, 
       21.665068851340703`, -25.}, {87.5125, -21.657851972975838`, -25.}, {
       37.4875, -21.657851972975834`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{37.4875, -21.657851972975834`, 25.}, {62.5, 
       21.665068851340703`, 25.}, {87.5125, -21.657851972975838`, 25.}, {
       37.4875, -21.657851972975834`, 25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{162.5, -21.650635094610966`, 0.}, {
      166.83012701892218`, -19.150635094610966`, 6.123233995736766*^-15}, {
      162.66346035225553`, -11.933756729740647`, 5.102694996447306*^-15}, {
      158.33333333333334`, -14.433756729740644`, 0.}, {
      162.5, -21.650635094610966`, 0.}}], 
     Polygon3DBox[{{158.33333333333334`, -14.433756729740644`, 0.}, {
      162.66346035225553`, -11.933756729740647`, 5.102694996447306*^-15}, {
      158.49679368558884`, -4.716878364870324, 4.0821559971578446`*^-15}, {
      154.16666666666666`, -7.216878364870324, 0.}, {
      158.33333333333334`, -14.433756729740644`, 0.}}], 
     Polygon3DBox[{{154.16666666666666`, -7.216878364870324, 0.}, {
      158.49679368558884`, -4.716878364870324, 4.0821559971578446`*^-15}, {
      154.33012701892218`, 2.499999999999994, 3.061616997868384*^-15}, {150., 
      0., 0.}, {154.16666666666666`, -7.216878364870324, 0.}}], 
     Polygon3DBox[{{150., 0., 0.}, {154.33012701892218`, 2.5, 
      3.061616997868383*^-15}, {150.16346035225553`, 9.716878364870322, 
      2.0410779985789223`*^-15}, {145.83333333333334`, 7.216878364870317, 
      0.}, {150., 0., 0.}}], 
     Polygon3DBox[{{145.83333333333334`, 7.216878364870317, 0.}, {
      150.16346035225553`, 9.716878364870322, 2.0410779985789223`*^-15}, {
      145.99679368558884`, 16.933756729740644`, 1.0205389992894613`*^-15}, {
      141.66666666666666`, 14.433756729740642`, 0.}, {145.83333333333334`, 
      7.216878364870317, 0.}}], 
     Polygon3DBox[{{141.66666666666666`, 14.433756729740642`, 0.}, {
      145.99679368558884`, 16.933756729740644`, 1.0205389992894615`*^-15}, {
      141.83012701892218`, 24.150635094610962`, 5.098616525425841*^-31}, {
      137.5, 21.65063509461096, 0.}, {141.66666666666666`, 
      14.433756729740642`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBigISHF4+ruFdcIy0wMwodWrgOBUssMd/40xovd0
4OKhIOCa7HAPLC4DFweDA0kOq3wiXlRte70HxRyrJIfrEPUOMPEwkDlbE6Hi
Og4o5hgkOjyGuAcuXr+zM23CrkSIO9Us4OJX+O7vfmqf5PBuecQ6rvcGcHGt
FBNB66NJDu9B4vnKqOZ4JTuwg3ksqOacT4a6R+gAijmhKVBx9QMo5txKgbhT
zRg1HLCEJwDRImbD
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{150., 0., -25.}, {154.33012701892218`, 
        2.5000000000000027`, -25.}, {154.33012701892218`, 
        2.500000000000002, -16.66666666666667}, {150., 
        4.4190634946871114`*^-16, -16.666666666666668`}, {150., 0., -25.}}], 
       Polygon3DBox[{{150., 4.4190634946871114`*^-16, -16.666666666666668`}, {
        154.33012701892218`, 2.500000000000002, -16.66666666666667}, {
        154.33012701892218`, 2.5000000000000018`, -8.333333333333336}, {150., 
        8.838126989374223*^-16, -8.333333333333336}, {150., 
        4.4190634946871114`*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{150., 8.838126989374223*^-16, -8.333333333333336}, {
        154.33012701892218`, 2.5000000000000018`, -8.333333333333336}, {
        154.33012701892218`, 2.5000000000000013`, -7.105427357601002*^-15}, {
        150., 1.3257190484061335`*^-15, 0.}, {150., 
        8.838126989374223*^-16, -8.333333333333336}}], 
       Polygon3DBox[{{150., 1.3257190484061335`*^-15, 0.}, {
        154.33012701892218`, 2.5000000000000013`, 0.}, {154.33012701892218`, 
        2.500000000000001, 8.333333333333332}, {150., 
        1.7676253978748445`*^-15, 8.333333333333329}, {150., 
        1.3257190484061335`*^-15, 0.}}], 
       Polygon3DBox[{{150., 1.7676253978748445`*^-15, 8.333333333333329}, {
        154.33012701892218`, 2.500000000000001, 8.333333333333332}, {
        154.33012701892218`, 2.5000000000000004`, 16.666666666666664`}, {150.,
         2.2095317473435558`*^-15, 16.666666666666664`}, {150., 
        1.7676253978748445`*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{150., 2.2095317473435558`*^-15, 16.666666666666664`}, {
        154.33012701892218`, 2.5000000000000004`, 16.666666666666664`}, {
        154.33012701892218`, 2.5, 24.999999999999996`}, {150., 
        2.6514380968122666`*^-15, 24.999999999999993`}, {150., 
        2.2095317473435558`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOTAgAIsD6CLr14FAgYY4mvA4goY4hDwYQ+6
+AqIegfs4gYY4v/+g4CFQ/3OzrQJXslQcRYobYkhDnUnhjjUnTjM+WCDLg51
5wHs4gYY4lB34ggHywMAGDNf6Q==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{162.5, -21.650635094610966`, -25.}, {137.5, 
      21.650635094610966`, -25.}, {137.5, 21.650635094610966`, 25.}, {
      162.5, -21.650635094610966`, 25.}, {
      162.5, -21.650635094610966`, -25.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{162.5, -21.650635094610966`, -25.}, {137.5, 
       21.650635094610966`, -25.}, {137.5, 21.650635094610966`, 25.}, {
       162.5, -21.650635094610966`, 25.}, {
       162.5, -21.650635094610966`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{166.83012701892218`, -19.150635094610966`, -25.}, {
       141.83012701892218`, 24.150635094610966`, -25.}, {141.83012701892218`, 
       24.150635094610966`, 25.}, {166.83012701892218`, -19.150635094610966`, 
       25.}, {166.83012701892218`, -19.150635094610966`, -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{162.5, -21.650635094610966`, 25.}, {
       166.83012701892218`, -19.150635094610966`, 25.}, {
       162.66346035225553`, -11.933756729740644`, 25.}, {
       158.33333333333334`, -14.433756729740644`, 25.}, {
       162.5, -21.650635094610966`, 25.}}], 
      Line3DBox[{{158.33333333333334`, -14.433756729740644`, 25.}, {
       162.66346035225553`, -11.933756729740644`, 25.}, {
       158.49679368558884`, -4.716878364870324, 25.}, {
       154.16666666666666`, -7.216878364870324, 25.}, {
       158.33333333333334`, -14.433756729740644`, 25.}}], 
      Line3DBox[{{154.16666666666666`, -7.216878364870322, 25.}, {
       158.49679368558884`, -4.716878364870322, 25.}, {154.33012701892218`, 
       2.4999999999999987`, 25.}, {150., -1.2018516789897274`*^-15, 25.}, {
       154.16666666666666`, -7.216878364870322, 25.}}], 
      Line3DBox[{{150., 0., 25.}, {154.33012701892218`, 2.5, 25.}, {
       150.16346035225553`, 9.716878364870322, 25.}, {145.83333333333334`, 
       7.216878364870321, 25.}, {150., 0., 25.}}], 
      Line3DBox[{{145.83333333333334`, 7.216878364870321, 25.}, {
       150.16346035225553`, 9.716878364870322, 25.}, {145.99679368558884`, 
       16.933756729740644`, 25.}, {141.66666666666666`, 14.433756729740642`, 
       25.}, {145.83333333333334`, 7.216878364870321, 25.}}], 
      Line3DBox[{{141.66666666666666`, 14.433756729740642`, 25.}, {
       145.99679368558884`, 16.933756729740644`, 25.}, {141.83012701892218`, 
       24.15063509461096, 25.}, {137.5, 21.65063509461096, 25.}, {
       141.66666666666666`, 14.433756729740642`, 25.}}], 
      Line3DBox[{{137.5, 21.650635094610966`, 25.}, {141.83012701892218`, 
       24.150635094610966`, 25.}, {141.83012701892218`, 24.150635094610966`, 
       16.666666666666668`}, {137.5, 21.650635094610966`, 
       16.666666666666668`}, {137.5, 21.650635094610966`, 25.}}], 
      Line3DBox[{{137.5, 21.650635094610966`, 16.666666666666668`}, {
       141.83012701892218`, 24.150635094610966`, 16.666666666666668`}, {
       141.83012701892218`, 24.150635094610966`, 8.333333333333336}, {137.5, 
       21.650635094610966`, 8.333333333333336}, {137.5, 21.650635094610966`, 
       16.666666666666668`}}], 
      Line3DBox[{{137.5, 21.650635094610966`, 8.333333333333334}, {
       141.83012701892218`, 24.150635094610966`, 8.333333333333334}, {
       141.83012701892218`, 24.150635094610966`, 1.3877787807814457`*^-15}, {
       137.5, 21.650635094610966`, 1.3877787807814457`*^-15}, {137.5, 
       21.650635094610966`, 8.333333333333334}}], 
      Line3DBox[{{137.5, 21.650635094610966`, 0.}, {141.83012701892218`, 
       24.150635094610966`, 0.}, {141.83012701892218`, 
       24.150635094610966`, -8.333333333333332}, {137.5, 
       21.650635094610966`, -8.333333333333332}, {137.5, 21.650635094610966`, 
       0.}}], Line3DBox[{{137.5, 21.650635094610966`, -8.333333333333332}, {
       141.83012701892218`, 24.150635094610966`, -8.333333333333332}, {
       141.83012701892218`, 24.150635094610966`, -16.666666666666664`}, {
       137.5, 21.650635094610966`, -16.666666666666664`}, {137.5, 
       21.650635094610966`, -8.333333333333332}}], 
      Line3DBox[{{137.5, 21.650635094610966`, -16.666666666666664`}, {
       141.83012701892218`, 24.150635094610966`, -16.666666666666664`}, {
       141.83012701892218`, 24.150635094610966`, -24.999999999999993`}, {
       137.5, 21.650635094610966`, -24.999999999999993`}, {137.5, 
       21.650635094610966`, -16.666666666666664`}}], 
      Line3DBox[{{137.5, 21.650635094610966`, -25.}, {141.83012701892218`, 
       24.150635094610966`, -25.}, {145.99679368558884`, 
       16.933756729740644`, -25.}, {141.66666666666666`, 
       14.433756729740644`, -25.}, {137.5, 21.650635094610966`, -25.}}], 
      Line3DBox[{{141.66666666666666`, 14.433756729740644`, -25.}, {
       145.99679368558884`, 16.933756729740644`, -25.}, {150.16346035225553`, 
       9.716878364870324, -25.}, {145.83333333333334`, 
       7.216878364870324, -25.}, {141.66666666666666`, 
       14.433756729740644`, -25.}}], 
      Line3DBox[{{145.83333333333334`, 7.216878364870322, -25.}, {
       150.16346035225553`, 9.716878364870322, -25.}, {154.33012701892218`, 
       2.5000000000000013`, -25.}, {150., 1.2018516789897274`*^-15, -25.}, {
       145.83333333333334`, 7.216878364870322, -25.}}], 
      Line3DBox[{{150., 0., -25.}, {154.33012701892218`, 2.5, -25.}, {
       158.49679368558884`, -4.716878364870321, -25.}, {
       154.16666666666666`, -7.216878364870321, -25.}, {150., 0., -25.}}], 
      Line3DBox[{{154.16666666666666`, -7.216878364870321, -25.}, {
       158.49679368558884`, -4.716878364870321, -25.}, {
       162.66346035225553`, -11.933756729740642`, -25.}, {
       158.33333333333334`, -14.433756729740642`, -25.}, {
       154.16666666666666`, -7.216878364870321, -25.}}], 
      Line3DBox[{{158.33333333333334`, -14.433756729740642`, -25.}, {
       162.66346035225553`, -11.933756729740642`, -25.}, {
       166.83012701892218`, -19.15063509461096, -25.}, {
       162.5, -21.65063509461096, -25.}, {
       158.33333333333334`, -14.433756729740642`, -25.}}], 
      Line3DBox[{{162.5, -21.650635094610966`, -25.}, {
       166.83012701892218`, -19.150635094610966`, -25.}, {
       166.83012701892218`, -19.150635094610966`, -16.666666666666668`}, {
       162.5, -21.650635094610966`, -16.666666666666668`}, {
       162.5, -21.650635094610966`, -25.}}], 
      Line3DBox[{{162.5, -21.650635094610966`, -16.666666666666668`}, {
       166.83012701892218`, -19.150635094610966`, -16.666666666666668`}, {
       166.83012701892218`, -19.150635094610966`, -8.333333333333336}, {
       162.5, -21.650635094610966`, -8.333333333333336}, {
       162.5, -21.650635094610966`, -16.666666666666668`}}], 
      Line3DBox[{{162.5, -21.650635094610966`, -8.333333333333334}, {
       166.83012701892218`, -19.150635094610966`, -8.333333333333334}, {
       166.83012701892218`, -19.150635094610966`, -1.3877787807814457`*^-15}, \
{162.5, -21.650635094610966`, -1.3877787807814457`*^-15}, {
       162.5, -21.650635094610966`, -8.333333333333334}}], 
      Line3DBox[{{162.5, -21.650635094610966`, 0.}, {
       166.83012701892218`, -19.150635094610966`, 0.}, {
       166.83012701892218`, -19.150635094610966`, 8.333333333333332}, {
       162.5, -21.650635094610966`, 8.333333333333332}, {
       162.5, -21.650635094610966`, 0.}}], 
      Line3DBox[{{162.5, -21.650635094610966`, 8.333333333333332}, {
       166.83012701892218`, -19.150635094610966`, 8.333333333333332}, {
       166.83012701892218`, -19.150635094610966`, 16.666666666666664`}, {
       162.5, -21.650635094610966`, 16.666666666666664`}, {
       162.5, -21.650635094610966`, 8.333333333333332}}], 
      Line3DBox[{{162.5, -21.650635094610966`, 16.666666666666664`}, {
       166.83012701892218`, -19.150635094610966`, 16.666666666666664`}, {
       166.83012701892218`, -19.150635094610966`, 24.999999999999993`}, {
       162.5, -21.650635094610966`, 24.999999999999993`}, {
       162.5, -21.650635094610966`, 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317479958963`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[71]:="]
}, Open  ]],

Cell[TextData[{
 "The labels work with ",
 StyleBox["PlotType\[Rule]SideView", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 " but gets surpressed with ",
 StyleBox["PlotType\[Rule]Full3D", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 "."
}], "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Placement of Your Labels", "Subsubsection",
 PageBreakAbove->Automatic,
 CellTags->{
  "Placement of Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}
  ],

Cell[TextData[{
 "Sometimes, you might not like the way that ",
 "Optica",
 " has automatically placed a label within the graphics.  You can change the  \
label placement with the ",
 StyleBox["LabelPositions", "Input",
  FontFamily->"Courier"],
 " option."
}], "Text",
 PageBreakAbove->Automatic,
 CellChangeTimes->{3.5661589504058323`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["?LabelPositions", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[73]:="],

Cell[BoxData[
 StyleBox["\<\"LabelPositions -> {{xpos, ypos, zpos}, ...} is an option of \
Component that indicates the rendering positions of one or more label names \
in the rendered Component. \\n\\nNote that the specified values are \
automatically updated with subsequent Move operations. See also: Labels, \
Offx, Offy, Offz.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614731748360918*^9},
 CellTags->{
  "Info3614713748-8131145", "Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Prism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
        RowBox[{"Centered", "\[Rule]", "True"}], ",", " ", 
        RowBox[{"LabelPositions", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "5"}], ",", "0"}], "}"}], "}"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Prism", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
          RowBox[{"Centered", "\[Rule]", "True"}], ",", " ", 
          RowBox[{"LabelPositions", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"0", ",", "Offy", ",", "0"}], "}"}], "}"}]}]}], "]"}], 
        ",", "100"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}], ";"}]], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[74]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5, -21.650635094610966`}, {12.5, 21.650635094610966`}, {
       12.5, 21.650635094610966`}, {-12.5, -21.650635094610966`}, {-12.5, \
-21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {12.5, 21.650635094610966`}, {
       12.5, 21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5, -21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}, {-12.5, -21.650635094610966`}, {-12.5, \
-21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5125, -21.657851972975834`}, {12.5, 
       21.665068851340703`}, {
       37.5125, -21.657851972975838`}, {-12.5125, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5125, -21.657851972975834`}, {12.5, 
       21.665068851340703`}, {
       37.5125, -21.657851972975838`}, {-12.5125, -21.657851972975834`}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {112.5, 21.650635094610966`}, {
       112.5, 21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{137.5, -21.650635094610966`}, {112.5, 21.650635094610966`}, {
       112.5, 21.650635094610966`}, {137.5, -21.650635094610966`}, {
       137.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {137.5, -21.650635094610966`}, {
       137.5, -21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.4875, -21.657851972975834`}, {112.5, 
       21.665068851340703`}, {137.5125, -21.657851972975838`}, {
       87.4875, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.4875, -21.657851972975834`}, {112.5, 
       21.665068851340703`}, {137.5125, -21.657851972975838`}, {
       87.4875, -21.657851972975834`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"Prism1\"\>", {0., -5.}, {0., 0.}], 
    InsetBox["\<\"Prism2\"\>", {100., 1.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731749907331*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[74]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["These Prisms use ",
  FontSlant->"Italic"],
 StyleBox["LabelPositions", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 StyleBox[" to locate their labels.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 StyleBox["LabelPositions", "Input",
  FontFamily->"Courier"],
 " always works in the local relative coordinates of each object.  For the  \
second p",
 StyleBox["rism", "Input",
  FontFamily->"Courier",
  FontWeight->"Plain"],
 ", ",
 StyleBox["Offy", "Input",
  FontFamily->"Courier"],
 " was used to provide a scaled distance relative to the y-axis plot  \
dimensions."
}], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "A related option is ",
 StyleBox["LabelOffset", "Input"],
 "."
}], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["?LabelOffset", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[75]:="],

Cell[BoxData[
 StyleBox["\<\"LabelOffset is an option of DrawSystem/AnalyzeSystem and \
ShowSystem that scales the label offset-positions according to the overall \
dimensions of the system rendering. \\n\\nSee also: ShiftLabels, AddLabels, \
and RenameLabels.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614731750194026*^9},
 CellTags->{
  "Info3614713750-8131145", "Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[TextData[{
 "You can use ",
 StyleBox["LabelOffset", "Input"],
 " to change the relative distance of the labels to each component graphic."
}], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "Optica",
 "'s default value for ",
 StyleBox["LabelOffset", "Input"],
 " is given by:"
}], "Text",
 CellChangeTimes->{3.566158950507234*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["LabelOffset/.Options[AnalyzeSystem]", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[76]:="],

Cell[BoxData["0.04`"], "Output",
 CellChangeTimes->{3.563367934388404*^9, 3.5661588671807632`*^9, 
  3.566159004411726*^9, 3.5672683588062468`*^9, 3.6147305611485023`*^9, 
  3.6147317503588552`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[76]="]
}, Open  ]],

Cell[TextData[{
 "Therefore, we can use ",
 StyleBox["LabelOffset -> .1", "Input"],
 " to increase label to component distance."
}], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Prism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
        RowBox[{"Centered", "\[Rule]", "True"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Prism", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
          RowBox[{"Centered", "\[Rule]", "True"}]}], "]"}], ",", "100"}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", " ", 
    RowBox[{"LabelOffset", " ", "\[Rule]", ".1"}]}], "]"}], ";"}]], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[77]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5, -21.650635094610966`}, {12.5, 21.650635094610966`}, {
       12.5, 21.650635094610966`}, {-12.5, -21.650635094610966`}, {-12.5, \
-21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {12.5, 21.650635094610966`}, {
       12.5, 21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5, -21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}, {-12.5, -21.650635094610966`}, {-12.5, \
-21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5125, -21.657851972975834`}, {12.5, 
       21.665068851340703`}, {
       37.5125, -21.657851972975838`}, {-12.5125, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-12.5125, -21.657851972975834`}, {12.5, 
       21.665068851340703`}, {
       37.5125, -21.657851972975838`}, {-12.5125, -21.657851972975834`}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {112.5, 21.650635094610966`}, {
       112.5, 21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{137.5, -21.650635094610966`}, {112.5, 21.650635094610966`}, {
       112.5, 21.650635094610966`}, {137.5, -21.650635094610966`}, {
       137.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {137.5, -21.650635094610966`}, {
       137.5, -21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.4875, -21.657851972975834`}, {112.5, 
       21.665068851340703`}, {137.5125, -21.657851972975838`}, {
       87.4875, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.4875, -21.657851972975834`}, {112.5, 
       21.665068851340703`}, {137.5125, -21.657851972975838`}, {
       87.4875, -21.657851972975834`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"Prism1\"\>", {-26., -1.}, {0., 0.}], 
    InsetBox["\<\"Prism2\"\>", {74., -1.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6147317511387243`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[77]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Labels with Resonate", "Subsubsection",
 CellTags->{
  "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "Every component function as well as every genetic function of Optica can \
take a label.  In previous versions of Optica",
 StyleBox[",",
  FontSlant->"Italic"],
 " some functions like ",
 StyleBox["Resonate", "Input",
  FontFamily->"Courier"],
 " used to require a specified label.  Today this is no longer the case, and  \
labels may always be given optionally to any component function of Optica.  \
If a label is not indicated by the user, then ",
 "Optica",
 " assigns a built-in default label for the object.  If a label is not  \
assigned to ",
 StyleBox["Resonate", "Input",
  FontFamily->"Courier"],
 ", then the resulting graphics continues to display a distinct label for  \
each component inside the ",
 StyleBox["Resonate", "Input",
  FontFamily->"Courier"],
 " function."
}], "Text",
 PageBreakAbove->Automatic,
 CellChangeTimes->{{3.566158950608582*^9, 3.566158950921122*^9}},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnalyzeSystem", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{"45", ",", 
         RowBox[{"NumberOfRays", "\[Rule]", "8"}]}], "]"}], ",", "5"}], "]"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"Resonate", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "25"}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Mirror", "[", 
           RowBox[{"50", ",", "5"}], "]"}], ",", "60"}], "]"}]}], "}"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Boundary", "[", 
      RowBox[{"70", ",", "60"}], "]"}]}], "}"}], ",", 
   RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}]], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[78]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{31.42197458095559, -25.}, {35., -25.}, {
      35., -16.66666666666667}, {27.75044883428479, -16.666666666666668`}, {
      31.42197458095559, -25.}}], 
     PolygonBox[{{27.75044883428479, -16.666666666666668`}, {
      35., -16.66666666666667}, {35., -8.333333333333336}, {
      25.67375799589206, -8.333333333333336}, {
      27.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{25.67375799589206, -8.333333333333336}, {
      35., -8.333333333333336}, {35., -7.105427357601002*^-15}, {25., 0.}, {
      25.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{25., 0.}, {35., 0.}, {35., 8.333333333333332}, {
      25.67375799589206, 8.333333333333329}, {25., 0.}}], 
     PolygonBox[{{25.67375799589206, 8.333333333333329}, {35., 
      8.333333333333332}, {35., 16.666666666666664`}, {27.75044883428479, 
      16.666666666666664`}, {25.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{27.75044883428479, 16.666666666666664`}, {35., 
      16.666666666666664`}, {35., 24.999999999999996`}, {31.42197458095559, 
      24.999999999999993`}, {27.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, -25.}, {
       27.75044883428479, -16.666666666666668`}, {
       25.67375799589206, -8.333333333333336}, {
       25., -3.552713678800501*^-15}, {25.67375799589206, 
       8.333333333333329}, {27.750448834284782`, 16.666666666666657`}, {
       31.42197458095559, 24.999999999999993`}, {35., 25.}, {35., 
       16.666666666666668`}, {35., 8.333333333333336}, {35., 
       3.552713678800501*^-15}, {35., -8.333333333333329}, {
       35., -16.666666666666657`}, {35., -24.999999999999993`}, {
       31.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{31.42197458095559, 0.}, {35., 3.061616997868383*^-15}, {
        35., 2.551347498223653*^-15}, {27.75044883428479, 
        5.102694996447305*^-16}, {31.42197458095559, 0.}}], 
       PolygonBox[{{27.75044883428479, 5.102694996447305*^-16}, {35., 
        2.551347498223653*^-15}, {35., 2.0410779985789223`*^-15}, {
        25.67375799589206, 1.020538999289461*^-15}, {27.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{25.67375799589206, 1.020538999289461*^-15}, {35., 
        2.0410779985789223`*^-15}, {35., 1.530808498934192*^-15}, {25., 
        1.5308084989341915`*^-15}, {25.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{25., 1.5308084989341915`*^-15}, {35., 
        1.5308084989341915`*^-15}, {35., 1.0205389992894611`*^-15}, {
        25.67375799589206, 2.041077998578922*^-15}, {25., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{25.67375799589206, 2.041077998578922*^-15}, {35., 
        1.0205389992894611`*^-15}, {35., 5.102694996447307*^-16}, {
        27.75044883428479, 2.5513474982236525`*^-15}, {25.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{27.75044883428479, 2.5513474982236525`*^-15}, {35., 
        5.102694996447308*^-16}, {35., 2.5493082627129206`*^-31}, {
        31.42197458095559, 3.0616169978683826`*^-15}, {27.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{31.42197458095559, 0.}, {27.75044883428479, 0.}, {
         25.67375799589206, 0.}, {25., 0.}, {25.67375799589206, 0.}, {
         27.750448834284782`, 0.}, {31.42197458095559, 0.}, {35., 0.}, {35., 
         0.}, {35., 0.}, {35., 0.}, {35., 0.}, {35., 0.}, {35., 0.}, {
         31.42197458095559, 0.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{60., -25.}, {65., -25.}, {65., -16.66666666666667}, {
          60., -16.666666666666668`}, {60., -25.}}], 
         PolygonBox[{{60., -16.666666666666668`}, {65., -16.66666666666667}, {
          65., -8.333333333333336}, {60., -8.333333333333336}, {
          60., -16.666666666666668`}}], 
         PolygonBox[{{60., -8.333333333333336}, {65., -8.333333333333336}, {
          65., -7.105427357601002*^-15}, {60., 0.}, {
          60., -8.333333333333336}}], 
         PolygonBox[{{60., 0.}, {65., 0.}, {65., 8.333333333333332}, {60., 
          8.333333333333329}, {60., 0.}}], 
         PolygonBox[{{60., 8.333333333333329}, {65., 8.333333333333332}, {65.,
           16.666666666666664`}, {60., 16.666666666666664`}, {60., 
          8.333333333333329}}], 
         PolygonBox[{{60., 16.666666666666664`}, {65., 16.666666666666664`}, {
          65., 24.999999999999996`}, {60., 24.999999999999993`}, {60., 
          16.666666666666664`}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{60., -25.}, {60., -16.666666666666668`}, {
           60., -8.333333333333336}, {60., -3.552713678800501*^-15}, {60., 
           8.333333333333329}, {60., 16.666666666666657`}, {60., 
           24.999999999999993`}, {65., 25.}, {65., 16.666666666666668`}, {65.,
            8.333333333333336}, {65., 3.552713678800501*^-15}, {
           65., -8.333333333333329}, {65., -16.666666666666657`}, {
           65., -24.999999999999993`}, {60., -25.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           PolygonBox[{{60., 0.}, {65., 3.061616997868383*^-15}, {65., 
            2.551347498223653*^-15}, {60., 5.102694996447305*^-16}, {60., 
            0.}}], PolygonBox[{{60., 5.102694996447305*^-16}, {65., 
            2.551347498223653*^-15}, {65., 2.0410779985789223`*^-15}, {60., 
            1.020538999289461*^-15}, {60., 5.102694996447305*^-16}}], 
           PolygonBox[{{60., 1.020538999289461*^-15}, {65., 
            2.0410779985789223`*^-15}, {65., 1.530808498934192*^-15}, {60., 
            1.5308084989341915`*^-15}, {60., 1.020538999289461*^-15}}], 
           PolygonBox[{{60., 1.5308084989341915`*^-15}, {65., 
            1.5308084989341915`*^-15}, {65., 1.0205389992894611`*^-15}, {60., 
            2.041077998578922*^-15}, {60., 1.5308084989341915`*^-15}}], 
           PolygonBox[{{60., 2.041077998578922*^-15}, {65., 
            1.0205389992894611`*^-15}, {65., 5.102694996447307*^-16}, {60., 
            2.5513474982236525`*^-15}, {60., 2.041077998578922*^-15}}], 
           PolygonBox[{{60., 2.5513474982236525`*^-15}, {65., 
            5.102694996447308*^-16}, {65., 2.5493082627129206`*^-31}, {60., 
            3.0616169978683826`*^-15}, {60., 2.5513474982236525`*^-15}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            LineBox[{{60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
             60., 0.}, {60., 0.}, {65., 0.}, {65., 0.}, {65., 0.}, {65., 
             0.}, {65., 0.}, {65., 0.}, {65., 0.}, {60., 
             0.}}]}}}}}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 25.}, {35., 25.}, {35., 
       24.148145657226706`}, {31.42197458095559, 24.148145657226706`}, {
       31.42197458095559, 25.}}], 
      LineBox[{{31.42197458095559, 24.148145657226706`}, {35., 
       24.148145657226706`}, {35., 21.65063509461097}, {31.42197458095559, 
       21.65063509461097}, {31.42197458095559, 24.148145657226706`}}], 
      LineBox[{{31.42197458095559, 21.65063509461097}, {35., 
       21.65063509461097}, {35., 17.67766952966369}, {31.42197458095559, 
       17.67766952966369}, {31.42197458095559, 21.65063509461097}}], 
      LineBox[{{31.42197458095559, 17.67766952966369}, {35., 
       17.67766952966369}, {35., 12.500000000000004`}, {31.42197458095559, 
       12.500000000000004`}, {31.42197458095559, 17.67766952966369}}], 
      LineBox[{{31.42197458095559, 12.500000000000004`}, {35., 
       12.500000000000004`}, {35., 6.470476127563024}, {31.42197458095559, 
       6.470476127563024}, {31.42197458095559, 12.500000000000004`}}], 
      LineBox[{{31.42197458095559, 6.470476127563024}, {35., 
       6.470476127563024}, {35., 7.0819236220599744`*^-15}, {
       31.42197458095559, 7.0819236220599744`*^-15}, {31.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{31.42197458095559, 1.5308084989341915`*^-15}, {35., 
       1.5308084989341915`*^-15}, {35., -6.470476127563016}, {
       31.42197458095559, -6.470476127563016}, {31.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{31.42197458095559, -6.470476127563016}, {
       35., -6.470476127563016}, {35., -12.499999999999995`}, {
       31.42197458095559, -12.499999999999995`}, {
       31.42197458095559, -6.470476127563016}}], 
      LineBox[{{31.42197458095559, -12.499999999999995`}, {
       35., -12.499999999999995`}, {35., -17.677669529663685`}, {
       31.42197458095559, -17.677669529663685`}, {
       31.42197458095559, -12.499999999999995`}}], 
      LineBox[{{31.42197458095559, -17.677669529663685`}, {
       35., -17.677669529663685`}, {35., -21.65063509461097}, {
       31.42197458095559, -21.65063509461097}, {
       31.42197458095559, -17.677669529663685`}}], 
      LineBox[{{31.4219745809556, -21.650635094610962`}, {
       35., -21.650635094610962`}, {35., -24.148145657226706`}, {
       31.42197458095559, -24.148145657226706`}, {
       31.4219745809556, -21.650635094610962`}}], 
      LineBox[{{31.42197458095559, -24.148145657226706`}, {
       35., -24.148145657226706`}, {35., -25.}, {31.42197458095559, -25.}, {
       31.42197458095559, -24.148145657226706`}}], 
      LineBox[{{31.42197458095559, -25.}, {35., -25.}, {
       35., -24.148145657226706`}, {
       31.42197458095559, -24.148145657226706`}, {31.42197458095559, -25.}}], 
      LineBox[{{31.42197458095559, -24.14814565722671}, {
       35., -24.14814565722671}, {35., -21.65063509461097}, {
       31.42197458095559, -21.65063509461097}, {
       31.42197458095559, -24.14814565722671}}], 
      LineBox[{{31.42197458095559, -21.65063509461097}, {
       35., -21.65063509461097}, {35., -17.677669529663692`}, {
       31.42197458095559, -17.677669529663692`}, {
       31.42197458095559, -21.65063509461097}}], 
      LineBox[{{31.42197458095559, -17.677669529663696`}, {
       35., -17.677669529663696`}, {35., -12.50000000000001}, {
       31.42197458095559, -12.50000000000001}, {
       31.42197458095559, -17.677669529663696`}}], 
      LineBox[{{31.42197458095559, -12.50000000000001}, {
       35., -12.50000000000001}, {35., -6.470476127563038}, {
       31.42197458095559, -6.470476127563038}, {
       31.42197458095559, -12.50000000000001}}], 
      LineBox[{{31.42197458095559, -6.470476127563038}, {
       35., -6.470476127563038}, {35., -2.6796885989305705`*^-14}, {
       31.42197458095559, -2.6796885989305705`*^-14}, {
       31.42197458095559, -6.470476127563038}}], 
      LineBox[{{31.42197458095559, -4.592425496802574*^-15}, {
       35., -4.592425496802574*^-15}, {35., 6.470476127563007}, {
       31.42197458095559, 6.470476127563007}, {
       31.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{31.42197458095559, 6.470476127563007}, {35., 
       6.470476127563007}, {35., 12.499999999999984`}, {31.42197458095559, 
       12.499999999999984`}, {31.42197458095559, 6.470476127563007}}], 
      LineBox[{{31.42197458095559, 12.499999999999984`}, {35., 
       12.499999999999984`}, {35., 17.67766952966367}, {31.4219745809556, 
       17.67766952966367}, {31.42197458095559, 12.499999999999984`}}], 
      LineBox[{{31.42197458095559, 17.677669529663685`}, {35., 
       17.677669529663685`}, {35., 21.65063509461096}, {31.42197458095559, 
       21.65063509461096}, {31.42197458095559, 17.677669529663685`}}], 
      LineBox[{{31.42197458095559, 21.65063509461096}, {35., 
       21.65063509461096}, {35., 24.148145657226703`}, {31.42197458095559, 
       24.148145657226703`}, {31.42197458095559, 21.65063509461096}}], 
      LineBox[{{31.42197458095559, 24.148145657226703`}, {35., 
       24.148145657226703`}, {35., 25.}, {31.42197458095559, 25.}, {
       31.42197458095559, 24.148145657226703`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{60., 0.}, {60., 8.333333333333332}, {60., 
        8.049381885742235}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 8.333333333333332}, {60., 16.666666666666664`}, {60.,
         16.09876377148447}, {60., 8.049381885742235}, {60., 
        8.333333333333332}}], 
       PolygonBox[{{60., 16.666666666666664`}, {60., 25.}, {60., 
        24.148145657226706`}, {60., 16.09876377148447}, {60., 
        16.666666666666664`}}], 
       PolygonBox[{{60., 0.}, {60., 8.049381885742235}, {60., 
        7.216878364870323}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 8.049381885742235}, {60., 16.09876377148447}, {60., 
        14.433756729740645`}, {60., 7.216878364870323}, {60., 
        8.049381885742235}}], 
       PolygonBox[{{60., 16.09876377148447}, {60., 24.148145657226706`}, {60.,
         21.65063509461097}, {60., 14.433756729740645`}, {60., 
        16.09876377148447}}], 
       PolygonBox[{{60., 0.}, {60., 7.216878364870323}, {60., 
        5.892556509887896}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 7.216878364870323}, {60., 14.433756729740645`}, {60.,
         11.785113019775793`}, {60., 5.892556509887896}, {60., 
        7.216878364870323}}], 
       PolygonBox[{{60., 14.433756729740645`}, {60., 21.65063509461097}, {60.,
         17.67766952966369}, {60., 11.785113019775793`}, {60., 
        14.433756729740645`}}], 
       PolygonBox[{{60., 0.}, {60., 5.892556509887896}, {60., 
        4.166666666666668}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 5.892556509887896}, {60., 11.785113019775793`}, {60.,
         8.333333333333336}, {60., 4.166666666666668}, {60., 
        5.892556509887896}}], 
       PolygonBox[{{60., 11.785113019775793`}, {60., 17.67766952966369}, {60.,
         12.500000000000004`}, {60., 8.333333333333336}, {60., 
        11.785113019775793`}}], 
       PolygonBox[{{60., 0.}, {60., 4.166666666666668}, {60., 
        2.156825375854341}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 4.166666666666668}, {60., 8.333333333333336}, {60., 
        4.313650751708682}, {60., 2.156825375854341}, {60., 
        4.166666666666668}}], 
       PolygonBox[{{60., 8.333333333333336}, {60., 12.500000000000004`}, {60.,
         6.470476127563024}, {60., 4.313650751708682}, {60., 
        8.333333333333336}}], 
       PolygonBox[{{60., 0.}, {60., 2.156825375854341}, {60., 
        2.3606412073533245`*^-15}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 2.156825375854341}, {60., 4.313650751708682}, {60., 
        4.721282414706649*^-15}, {60., 2.3606412073533245`*^-15}, {60., 
        2.156825375854341}}], 
       PolygonBox[{{60., 4.313650751708682}, {60., 6.470476127563024}, {60., 
        7.0819236220599744`*^-15}, {60., 4.721282414706649*^-15}, {60., 
        4.313650751708682}}], 
       PolygonBox[{{60., 0.}, {60., 5.102694996447305*^-16}, {
        60., -2.1568253758543383`}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 5.102694996447305*^-16}, {60., 
        1.020538999289461*^-15}, {60., -4.313650751708677}, {
        60., -2.1568253758543383`}, {60., 5.102694996447305*^-16}}], 
       PolygonBox[{{60., 1.020538999289461*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
        60., -4.313650751708677}, {60., 1.020538999289461*^-15}}], 
       PolygonBox[{{60., 0.}, {60., -2.1568253758543383`}, {
        60., -4.166666666666664}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -2.1568253758543383`}, {60., -4.313650751708677}, {
        60., -8.333333333333329}, {60., -4.166666666666664}, {
        60., -2.1568253758543383`}}], 
       PolygonBox[{{60., -4.313650751708677}, {60., -6.470476127563016}, {
        60., -12.499999999999995`}, {60., -8.333333333333329}, {
        60., -4.313650751708677}}], 
       PolygonBox[{{60., 0.}, {60., -4.166666666666664}, {
        60., -5.8925565098878945`}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -4.166666666666664}, {60., -8.333333333333329}, {
        60., -11.785113019775789`}, {60., -5.8925565098878945`}, {
        60., -4.166666666666664}}], 
       PolygonBox[{{60., -8.333333333333329}, {60., -12.499999999999995`}, {
        60., -17.677669529663685`}, {60., -11.785113019775789`}, {
        60., -8.333333333333329}}], 
       PolygonBox[{{60., 0.}, {60., -5.8925565098878945`}, {
        60., -7.216878364870323}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -5.8925565098878945`}, {60., -11.785113019775789`}, {
        60., -14.433756729740645`}, {60., -7.216878364870323}, {
        60., -5.8925565098878945`}}], 
       PolygonBox[{{60., -11.785113019775789`}, {60., -17.677669529663685`}, {
        60., -21.65063509461097}, {60., -14.433756729740645`}, {
        60., -11.785113019775789`}}], 
       PolygonBox[{{60., 0.}, {60., -7.21687836487032}, {
        60., -8.049381885742235}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -7.21687836487032}, {60., -14.43375672974064}, {
        60., -16.09876377148447}, {60., -8.049381885742235}, {
        60., -7.21687836487032}}], 
       PolygonBox[{{60., -14.43375672974064}, {60., -21.650635094610962`}, {
        60., -24.148145657226706`}, {60., -16.09876377148447}, {
        60., -14.43375672974064}}], 
       PolygonBox[{{60., 0.}, {60., -8.049381885742235}, {
        60., -8.333333333333332}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -8.049381885742235}, {60., -16.09876377148447}, {
        60., -16.666666666666664`}, {60., -8.333333333333332}, {
        60., -8.049381885742235}}], 
       PolygonBox[{{60., -16.09876377148447}, {60., -24.148145657226706`}, {
        60., -25.}, {60., -16.666666666666664`}, {60., -16.09876377148447}}], 
       PolygonBox[{{60., 0.}, {60., -8.333333333333332}, {
        60., -8.049381885742235}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -8.333333333333332}, {60., -16.666666666666664`}, {
        60., -16.09876377148447}, {60., -8.049381885742235}, {
        60., -8.333333333333332}}], 
       PolygonBox[{{60., -16.666666666666664`}, {60., -25.}, {
        60., -24.148145657226706`}, {60., -16.09876377148447}, {
        60., -16.666666666666664`}}], 
       PolygonBox[{{60., 0.}, {60., -8.049381885742235}, {
        60., -7.216878364870323}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -8.049381885742235}, {60., -16.09876377148447}, {
        60., -14.433756729740645`}, {60., -7.216878364870323}, {
        60., -8.049381885742235}}], 
       PolygonBox[{{60., -16.09876377148447}, {60., -24.14814565722671}, {
        60., -21.65063509461097}, {60., -14.433756729740645`}, {
        60., -16.09876377148447}}], 
       PolygonBox[{{60., 0.}, {60., -7.216878364870323}, {
        60., -5.892556509887897}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -7.216878364870323}, {60., -14.433756729740645`}, {
        60., -11.785113019775794`}, {60., -5.892556509887897}, {
        60., -7.216878364870323}}], 
       PolygonBox[{{60., -14.433756729740645`}, {60., -21.65063509461097}, {
        60., -17.677669529663692`}, {60., -11.785113019775794`}, {
        60., -14.433756729740645`}}], 
       PolygonBox[{{60., 0.}, {60., -5.892556509887898}, {
        60., -4.16666666666667}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -5.892556509887898}, {60., -11.785113019775796`}, {
        60., -8.33333333333334}, {60., -4.16666666666667}, {
        60., -5.892556509887898}}], 
       PolygonBox[{{60., -11.785113019775796`}, {60., -17.677669529663696`}, {
        60., -12.50000000000001}, {60., -8.33333333333334}, {
        60., -11.785113019775796`}}], 
       PolygonBox[{{60., 0.}, {60., -4.16666666666667}, {
        60., -2.156825375854346}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -4.16666666666667}, {60., -8.33333333333334}, {
        60., -4.313650751708692}, {60., -2.156825375854346}, {
        60., -4.16666666666667}}], 
       PolygonBox[{{60., -8.33333333333334}, {60., -12.50000000000001}, {
        60., -6.470476127563038}, {60., -4.313650751708692}, {
        60., -8.33333333333334}}], 
       PolygonBox[{{60., 0.}, {60., -2.156825375854346}, {
        60., -8.932295329768568*^-15}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -2.156825375854346}, {60., -4.313650751708692}, {
        60., -1.7864590659537137`*^-14}, {60., -8.932295329768568*^-15}, {
        60., -2.156825375854346}}], 
       PolygonBox[{{60., -4.313650751708692}, {60., -6.470476127563038}, {
        60., -2.6796885989305705`*^-14}, {60., -1.7864590659537137`*^-14}, {
        60., -4.313650751708692}}], 
       PolygonBox[{{60., 0.}, {60., -1.5308084989341913`*^-15}, {60., 
        2.1568253758543356`}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., -1.5308084989341913`*^-15}, {
        60., -3.0616169978683826`*^-15}, {60., 4.313650751708671}, {60., 
        2.1568253758543356`}, {60., -1.5308084989341913`*^-15}}], 
       PolygonBox[{{60., -3.0616169978683826`*^-15}, {
        60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {60., 
        4.313650751708671}, {60., -3.0616169978683826`*^-15}}], 
       PolygonBox[{{60., 0.}, {60., 2.1568253758543356`}, {60., 
        4.166666666666661}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 2.1568253758543356`}, {60., 4.313650751708671}, {60.,
         8.333333333333321}, {60., 4.166666666666661}, {60., 
        2.1568253758543356`}}], 
       PolygonBox[{{60., 4.313650751708671}, {60., 6.470476127563007}, {60., 
        12.499999999999984`}, {60., 8.333333333333321}, {60., 
        4.313650751708671}}], 
       PolygonBox[{{60., 0.}, {60., 4.166666666666661}, {60., 
        5.89255650988789}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 4.166666666666661}, {60., 8.333333333333321}, {60., 
        11.78511301977578}, {60., 5.89255650988789}, {60., 
        4.166666666666661}}], 
       PolygonBox[{{60., 8.333333333333321}, {60., 12.499999999999984`}, {60.,
         17.67766952966367}, {60., 11.78511301977578}, {60., 
        8.333333333333321}}], 
       PolygonBox[{{60., 0.}, {60., 5.8925565098878945`}, {60., 
        7.216878364870319}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 5.8925565098878945`}, {60., 11.785113019775789`}, {
        60., 14.433756729740638`}, {60., 7.216878364870319}, {60., 
        5.8925565098878945`}}], 
       PolygonBox[{{60., 11.785113019775789`}, {60., 17.677669529663685`}, {
        60., 21.65063509461096}, {60., 14.433756729740638`}, {60., 
        11.785113019775789`}}], 
       PolygonBox[{{60., 0.}, {60., 7.216878364870319}, {60., 
        8.049381885742234}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 7.216878364870319}, {60., 14.433756729740638`}, {60.,
         16.098763771484467`}, {60., 8.049381885742234}, {60., 
        7.216878364870319}}], 
       PolygonBox[{{60., 14.433756729740638`}, {60., 21.65063509461096}, {60.,
         24.148145657226703`}, {60., 16.098763771484467`}, {60., 
        14.433756729740638`}}], 
       PolygonBox[{{60., 0.}, {60., 8.049381885742234}, {60., 
        8.333333333333332}, {60., 0.}, {60., 0.}}], 
       PolygonBox[{{60., 8.049381885742234}, {60., 16.098763771484467`}, {60.,
         16.666666666666664`}, {60., 8.333333333333332}, {60., 
        8.049381885742234}}], 
       PolygonBox[{{60., 16.098763771484467`}, {60., 24.148145657226703`}, {
        60., 25.}, {60., 16.666666666666664`}, {60., 16.098763771484467`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQF+DhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AKkRu6w==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYOAQ4QhqUDjO9xdcP9N6oWcP6z3y2sE5aZwvk7
0oQPVK81hPMhZmnC+e67SuuOPJSE80+fP79+9uTbNjC+HUT+AIz/9z8IaMD5
2yHmw/lPIPbD+VD3wflQ98P5nmjyz9D070Iznw3ifjg/HM19N27fPrxl3Zc9
ML4Jmv++Q9wP529HC5/HaOHnjha+sPAHAEbDdV0=
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{60., 25.}, {65., 25.}, {65., 24.148145657226706`}, {60., 
         24.148145657226706`}, {60., 25.}}], 
        LineBox[{{60., 24.148145657226706`}, {65., 24.148145657226706`}, {65.,
          21.65063509461097}, {60., 21.65063509461097}, {60., 
         24.148145657226706`}}], 
        LineBox[{{60., 21.65063509461097}, {65., 21.65063509461097}, {65., 
         17.67766952966369}, {60., 17.67766952966369}, {60., 
         21.65063509461097}}], 
        LineBox[{{60., 17.67766952966369}, {65., 17.67766952966369}, {65., 
         12.500000000000004`}, {60., 12.500000000000004`}, {60., 
         17.67766952966369}}], 
        LineBox[{{60., 12.500000000000004`}, {65., 12.500000000000004`}, {65.,
          6.470476127563024}, {60., 6.470476127563024}, {60., 
         12.500000000000004`}}], 
        LineBox[{{60., 6.470476127563024}, {65., 6.470476127563024}, {65., 
         7.0819236220599744`*^-15}, {60., 7.0819236220599744`*^-15}, {60., 
         6.470476127563024}}], 
        LineBox[{{60., 1.5308084989341915`*^-15}, {65., 
         1.5308084989341915`*^-15}, {65., -6.470476127563016}, {
         60., -6.470476127563016}, {60., 1.5308084989341915`*^-15}}], 
        LineBox[{{60., -6.470476127563016}, {65., -6.470476127563016}, {
         65., -12.499999999999995`}, {60., -12.499999999999995`}, {
         60., -6.470476127563016}}], 
        LineBox[{{60., -12.499999999999995`}, {65., -12.499999999999995`}, {
         65., -17.677669529663685`}, {60., -17.677669529663685`}, {
         60., -12.499999999999995`}}], 
        LineBox[{{60., -17.677669529663685`}, {65., -17.677669529663685`}, {
         65., -21.65063509461097}, {60., -21.65063509461097}, {
         60., -17.677669529663685`}}], 
        LineBox[{{60., -21.650635094610962`}, {65., -21.650635094610962`}, {
         65., -24.148145657226706`}, {60., -24.148145657226706`}, {
         60., -21.650635094610962`}}], 
        LineBox[{{60., -24.148145657226706`}, {65., -24.148145657226706`}, {
         65., -25.}, {60., -25.}, {60., -24.148145657226706`}}], 
        LineBox[{{60., -25.}, {65., -25.}, {65., -24.148145657226706`}, {
         60., -24.148145657226706`}, {60., -25.}}], 
        LineBox[{{60., -24.14814565722671}, {65., -24.14814565722671}, {
         65., -21.65063509461097}, {60., -21.65063509461097}, {
         60., -24.14814565722671}}], 
        LineBox[{{60., -21.65063509461097}, {65., -21.65063509461097}, {
         65., -17.677669529663692`}, {60., -17.677669529663692`}, {
         60., -21.65063509461097}}], 
        LineBox[{{60., -17.677669529663696`}, {65., -17.677669529663696`}, {
         65., -12.50000000000001}, {60., -12.50000000000001}, {
         60., -17.677669529663696`}}], 
        LineBox[{{60., -12.50000000000001}, {65., -12.50000000000001}, {
         65., -6.470476127563038}, {60., -6.470476127563038}, {
         60., -12.50000000000001}}], 
        LineBox[{{60., -6.470476127563038}, {65., -6.470476127563038}, {
         65., -2.6796885989305705`*^-14}, {60., -2.6796885989305705`*^-14}, {
         60., -6.470476127563038}}], 
        LineBox[{{60., -4.592425496802574*^-15}, {
         65., -4.592425496802574*^-15}, {65., 6.470476127563007}, {60., 
         6.470476127563007}, {60., -4.592425496802574*^-15}}], 
        LineBox[{{60., 6.470476127563007}, {65., 6.470476127563007}, {65., 
         12.499999999999984`}, {60., 12.499999999999984`}, {60., 
         6.470476127563007}}], 
        LineBox[{{60., 12.499999999999984`}, {65., 12.499999999999984`}, {65.,
          17.67766952966367}, {60., 17.67766952966367}, {60., 
         12.499999999999984`}}], 
        LineBox[{{60., 17.677669529663685`}, {65., 17.677669529663685`}, {65.,
          21.65063509461096}, {60., 21.65063509461096}, {60., 
         17.677669529663685`}}], 
        LineBox[{{60., 21.65063509461096}, {65., 21.65063509461096}, {65., 
         24.148145657226703`}, {60., 24.148145657226703`}, {60., 
         21.65063509461096}}], 
        LineBox[{{60., 24.148145657226703`}, {65., 24.148145657226703`}, {65.,
          25.}, {60., 25.}, {60., 24.148145657226703`}}]}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{70., 30.}, {70., -30.}, {70., -30.}, {70., 30.}, {70., 
       30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{70., -30.}, {0., -30.}, {0., -30.}, {70., -30.}, {
       70., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -30}, {0, 30}, {0, 30}, {0, -30}, {0, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 30.}, {70., 30.}, {70., 30.}, {0., 30.}, {0., 30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{70., -30.}, {70., 30.}, {0., 30.}, {0., -30.}, {70., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{70., 30.}, {70., -30.}, {0., -30.}, {0., 30.}, {70., 30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{5., -22.5}, {30.133849362371713`, -22.5}}], 
     {Arrowheads[Small], 
      ArrowBox[{{5., -16.071428571428573`}, {
       27.55249333957549, -16.071428571428573`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., -9.642857142857144}, {
       25.90416945774902, -9.642857142857144}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., -3.2142857142857153`}, {
       25.099683478826236`, -3.2142857142857153`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., 3.2142857142857117`}, {25.099683478826236`, 
       3.2142857142857117`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., 9.642857142857139}, {25.90416945774902, 
       9.642857142857139}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., 16.07142857142857}, {27.55249333957549, 
       16.07142857142857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5., 22.499999999999993`}, {30.133849362371713`, 
       22.499999999999993`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{30.133849362371713`, -22.5}, {35., -21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.55249333957549, -16.071428571428573`}, {
       35., -15.25181416035819}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.90416945774902, -9.642857142857144}, {
       35., -9.057177857850736}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.099683478826236`, -3.2142857142857153`}, {
       35., -3.0043473057903327`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.099683478826236`, 3.2142857142857117`}, {35., 
       3.0043473057903296`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.90416945774902, 9.642857142857139}, {35., 
       9.05717785785073}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.55249333957549, 16.07142857142857}, {35., 
       15.251814160358187`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{30.133849362371713`, 22.499999999999993`}, {35., 
       21.719260792539394`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -21.7192607925394}, {60., -15.520982855817795`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -15.25181416035819}, {60., -11.038916922425756`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -9.057177857850736}, {60., -6.605215892774371}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -3.0043473057903327`}, {60., -2.1988086982979302`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 3.0043473057903296`}, {60., 2.198808698297928}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 9.05717785785073}, {60., 6.605215892774368}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 15.251814160358187`}, {60., 11.038916922425752`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 21.719260792539394`}, {60., 15.520982855817792`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -15.520982855817795`}, {35., -9.32270491909619}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -11.038916922425756`}, {35., -6.82601968449332}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -6.605215892774371}, {35., -4.153253927698007}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -2.1988086982979302`}, {35., -1.3932700908055278`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 2.198808698297928}, {35., 1.3932700908055264`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 6.605215892774368}, {35., 4.153253927698005}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 11.038916922425752`}, {35., 6.8260196844933185`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 15.520982855817792`}, {35., 9.32270491909619}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -9.32270491909619}, {
       25.591809925576555`, -7.813227837654242}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -6.82601968449332}, {
       25.320885059564443`, -5.760811897067798}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -4.153253927698007}, {
       25.11936903923673, -3.5170414510438497`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., -1.3932700908055278`}, {
       25.01345745407955, -1.1815032403237211`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 1.3932700908055264`}, {25.01345745407955, 
       1.18150324032372}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 4.153253927698005}, {25.11936903923673, 
       3.5170414510438484`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 6.8260196844933185`}, {25.32088505956444, 
       5.760811897067796}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35., 9.32270491909619}, {25.591809925576563`, 
       7.813227837654244}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.591809925576555`, -7.813227837654242}, {0., 
       0.9840955459206704}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.320885059564443`, -5.760811897067798}, {0., 
       0.11511706136095956`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.11936903923673, -3.5170414510438497`}, {
       0., -0.13904875161843178`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.01345745407955, -1.1815032403237211`}, {
       0., -0.07871353911697931}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.01345745407955, 1.18150324032372}, {0., 
       0.07871353911697976}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.11936903923673, 3.5170414510438484`}, {0., 
       0.13904875161843178`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.32088505956444, 
       5.760811897067796}, {-3.552713678800501*^-15, \
-0.11511706136095512`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{25.591809925576563`, 7.813227837654244}, {
       3.552713678800501*^-15, -0.9840955459206704}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQLfVr5WdnJTsHBhBoMDvAs0fCpKDX2kHVc5KKp5DB
gR9C3svKn1s6TFYBCSgfmNPkeLtF0tKh4Pa23NvbOOH8DAjfAaZ+AkS9A8w8
FYh5DjD7/v0HgnozqL2ODiUOaysVd5gegPG/XZA7+bZBD87P4unOcpNVgvMP
9DfaPufggPN3Qvhw89Ih6uH8LxDz4PwiiH0QPoOfgxX7eed9XPoHYPwDGlav
3wirwfksHzm3782WgvPXnTnFrDmdEc5fCeHDzWOAqIfz90HMg/MtIPbB3dPT
6zzFcinCf8KMq6Vu+ErD+SYn/854N0cAzrcQ1phy1evbfhjfCMK3h/Mh6uHm
C0LMQ7fPYc2Zz7capls6PFkffWafg/yBzbO+tKoGWToUOSq6CXGLH7BZq/6j
T87SQdr9+oJnSjwHdmnM/VTIbOng8F7kY/7zT/thfGsI3x6mXgKi3mET1LwC
iHnAcIPY9wxiHzQ8GBgUTlt/3Fr73h7Gdzh+8Kx/xV44/4NkQkXkmYP7YXyB
VieeSWpb4HwDCB9dPZT/YQ/DMbB5UPUfbKD27QcAZnr9YA==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {30., -27.1}, {0., 0.}], 
    InsetBox["\<\"M\"\>", {62.5, -27.1}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731752196528*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[78]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"LineOfRays", "[", 
           RowBox[{"45", ",", 
            RowBox[{"NumberOfRays", "\[Rule]", "8"}]}], "]"}], ",", "5.`"}], 
         "]"}], ",", 
        RowBox[{"Resonate", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"PlanoConvexLens", "[", 
              RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "25.`"}], 
            "]"}], ",", 
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Mirror", "[", 
              RowBox[{"50", ",", "5"}], "]"}], ",", "60.`"}], "]"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "30"}], ",", 
            RowBox[{"-", "30"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"70", ",", "30", ",", "30"}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.6147317522034063`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[78]:="],

Cell[BoxData["\<\"-48 ray/surface intersections-\"\>"], "Output",
 CellChangeTimes->{3.563367935814782*^9, 3.566158867264694*^9, 
  3.5661590074908037`*^9, 3.567268361690234*^9, 3.614730561189764*^9, 
  3.614731752204731*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[78]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Resonate", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 StyleBox[" now works without a specified label.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Labels Option", "Subsubsection",
 CellTags->{
  "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "A different method of attaching graphical labels to your components is  \
with the ",
 StyleBox["Labels", "Input",
  FontFamily->"Courier"],
 " option.  This way, you can affect only the graphical rendering without  \
replacing the printed output."
}], "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[TextData[{
 "mirror = Mirror[50,10",
 StyleBox[",Labels->\"mirror\"", "Input"],
 "]"
}], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[79]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Mirror", "[", 
     RowBox[{"50", ",", "10", ",", 
      RowBox[{"{", 
       RowBox[{"Labels", "\[Rule]", "\<\"mirror\"\>"}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5633679358918743`*^9, 3.566158867297683*^9, 
  3.5661590077612753`*^9, 3.5672683619886017`*^9, 3.614730561210585*^9, 
  3.614731752432979*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[79]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

AnalyzeSystem[{mirror, Move[mirror, 100]}, PlotType->TopView]
\
\>", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[80]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0., -25.}, {10., -25.}, {10., -16.66666666666667}, {
      0., -16.666666666666668`}, {0., -25.}}], 
     PolygonBox[{{0., -16.666666666666668`}, {10., -16.66666666666667}, {
      10., -8.333333333333336}, {0., -8.333333333333336}, {
      0., -16.666666666666668`}}], 
     PolygonBox[{{0., -8.333333333333336}, {10., -8.333333333333336}, {
      10., -7.105427357601002*^-15}, {0., 0.}, {0., -8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {0., 
      8.333333333333329}, {0., 0.}}], 
     PolygonBox[{{0., 8.333333333333329}, {10., 8.333333333333332}, {10., 
      16.666666666666664`}, {0., 16.666666666666664`}, {0., 
      8.333333333333329}}], 
     PolygonBox[{{0., 16.666666666666664`}, {10., 16.666666666666664`}, {10., 
      24.999999999999996`}, {0., 24.999999999999993`}, {0., 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -25.}, {0., -16.666666666666668`}, {
       0., -8.333333333333336}, {0., -3.552713678800501*^-15}, {0., 
       8.333333333333329}, {0., 16.666666666666657`}, {0., 
       24.999999999999993`}, {10., 25.}, {10., 16.666666666666668`}, {10., 
       8.333333333333336}, {10., 3.552713678800501*^-15}, {
       10., -8.333333333333329}, {10., -16.666666666666657`}, {
       10., -24.999999999999993`}, {0., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0., 0.}, {10., 3.061616997868383*^-15}, {10., 
        2.551347498223653*^-15}, {0., 5.102694996447305*^-16}, {0., 0.}}], 
       PolygonBox[{{0., 5.102694996447305*^-16}, {10., 
        2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {0., 
        1.020538999289461*^-15}, {0., 5.102694996447305*^-16}}], 
       PolygonBox[{{0., 1.020538999289461*^-15}, {10., 
        2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
        1.5308084989341915`*^-15}, {0., 1.020538999289461*^-15}}], 
       PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {0., 
        2.041077998578922*^-15}, {0., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{0., 2.041077998578922*^-15}, {10., 
        1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {0., 
        2.5513474982236525`*^-15}, {0., 2.041077998578922*^-15}}], 
       PolygonBox[{{0., 2.5513474982236525`*^-15}, {10., 
        5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {0., 
        3.0616169978683826`*^-15}, {0., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {
         0., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10.,
          0.}, {10., 0.}, {0., 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0., 0.}, {0., 8.333333333333332}, {0., 8.049381885742235}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 8.333333333333332}, {0., 16.666666666666664`}, {0., 
      16.09876377148447}, {0., 8.049381885742235}, {0., 8.333333333333332}}], 
     PolygonBox[{{0., 16.666666666666664`}, {0., 25.}, {0., 
      24.148145657226706`}, {0., 16.09876377148447}, {0., 
      16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0., 8.049381885742235}, {0., 7.216878364870323}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 8.049381885742235}, {0., 16.09876377148447}, {0., 
      14.433756729740645`}, {0., 7.216878364870323}, {0., 
      8.049381885742235}}], 
     PolygonBox[{{0., 16.09876377148447}, {0., 24.148145657226706`}, {0., 
      21.65063509461097}, {0., 14.433756729740645`}, {0., 
      16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0., 7.216878364870323}, {0., 5.892556509887896}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 7.216878364870323}, {0., 14.433756729740645`}, {0., 
      11.785113019775793`}, {0., 5.892556509887896}, {0., 
      7.216878364870323}}], 
     PolygonBox[{{0., 14.433756729740645`}, {0., 21.65063509461097}, {0., 
      17.67766952966369}, {0., 11.785113019775793`}, {0., 
      14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0., 5.892556509887896}, {0., 4.166666666666668}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 5.892556509887896}, {0., 11.785113019775793`}, {0., 
      8.333333333333336}, {0., 4.166666666666668}, {0., 5.892556509887896}}], 
     PolygonBox[{{0., 11.785113019775793`}, {0., 17.67766952966369}, {0., 
      12.500000000000004`}, {0., 8.333333333333336}, {0., 
      11.785113019775793`}}], 
     PolygonBox[{{0., 0.}, {0., 4.166666666666668}, {0., 2.156825375854341}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 4.166666666666668}, {0., 8.333333333333336}, {0., 
      4.313650751708682}, {0., 2.156825375854341}, {0., 4.166666666666668}}], 
     PolygonBox[{{0., 8.333333333333336}, {0., 12.500000000000004`}, {0., 
      6.470476127563024}, {0., 4.313650751708682}, {0., 8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {0., 2.156825375854341}, {0., 
      2.3606412073533245`*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 2.156825375854341}, {0., 4.313650751708682}, {0., 
      4.721282414706649*^-15}, {0., 2.3606412073533245`*^-15}, {0., 
      2.156825375854341}}], 
     PolygonBox[{{0., 4.313650751708682}, {0., 6.470476127563024}, {0., 
      7.0819236220599744`*^-15}, {0., 4.721282414706649*^-15}, {0., 
      4.313650751708682}}], 
     PolygonBox[{{0., 0.}, {0., 5.102694996447305*^-16}, {
      0., -2.1568253758543383`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 5.102694996447305*^-16}, {0., 1.020538999289461*^-15}, {
      0., -4.313650751708677}, {0., -2.1568253758543383`}, {0., 
      5.102694996447305*^-16}}], 
     PolygonBox[{{0., 1.020538999289461*^-15}, {0., 
      1.5308084989341915`*^-15}, {0., -6.470476127563016}, {
      0., -4.313650751708677}, {0., 1.020538999289461*^-15}}], 
     PolygonBox[{{0., 0.}, {0., -2.1568253758543383`}, {
      0., -4.166666666666664}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -2.1568253758543383`}, {0., -4.313650751708677}, {
      0., -8.333333333333329}, {0., -4.166666666666664}, {
      0., -2.1568253758543383`}}], 
     PolygonBox[{{0., -4.313650751708677}, {0., -6.470476127563016}, {
      0., -12.499999999999995`}, {0., -8.333333333333329}, {
      0., -4.313650751708677}}], 
     PolygonBox[{{0., 0.}, {0., -4.166666666666664}, {
      0., -5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -4.166666666666664}, {0., -8.333333333333329}, {
      0., -11.785113019775789`}, {0., -5.8925565098878945`}, {
      0., -4.166666666666664}}], 
     PolygonBox[{{0., -8.333333333333329}, {0., -12.499999999999995`}, {
      0., -17.677669529663685`}, {0., -11.785113019775789`}, {
      0., -8.333333333333329}}], 
     PolygonBox[{{0., 0.}, {0., -5.8925565098878945`}, {
      0., -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -5.8925565098878945`}, {0., -11.785113019775789`}, {
      0., -14.433756729740645`}, {0., -7.216878364870323}, {
      0., -5.8925565098878945`}}], 
     PolygonBox[{{0., -11.785113019775789`}, {0., -17.677669529663685`}, {
      0., -21.65063509461097}, {0., -14.433756729740645`}, {
      0., -11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0., -7.21687836487032}, {
      0., -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -7.21687836487032}, {0., -14.43375672974064}, {
      0., -16.09876377148447}, {0., -8.049381885742235}, {
      0., -7.21687836487032}}], 
     PolygonBox[{{0., -14.43375672974064}, {0., -21.650635094610962`}, {
      0., -24.148145657226706`}, {0., -16.09876377148447}, {
      0., -14.43375672974064}}], 
     PolygonBox[{{0., 0.}, {0., -8.049381885742235}, {
      0., -8.333333333333332}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -8.049381885742235}, {0., -16.09876377148447}, {
      0., -16.666666666666664`}, {0., -8.333333333333332}, {
      0., -8.049381885742235}}], 
     PolygonBox[{{0., -16.09876377148447}, {0., -24.148145657226706`}, {
      0., -25.}, {0., -16.666666666666664`}, {0., -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0., -8.333333333333332}, {
      0., -8.049381885742235}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -8.333333333333332}, {0., -16.666666666666664`}, {
      0., -16.09876377148447}, {0., -8.049381885742235}, {
      0., -8.333333333333332}}], 
     PolygonBox[{{0., -16.666666666666664`}, {0., -25.}, {
      0., -24.148145657226706`}, {0., -16.09876377148447}, {
      0., -16.666666666666664`}}], 
     PolygonBox[{{0., 0.}, {0., -8.049381885742235}, {
      0., -7.216878364870323}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -8.049381885742235}, {0., -16.09876377148447}, {
      0., -14.433756729740645`}, {0., -7.216878364870323}, {
      0., -8.049381885742235}}], 
     PolygonBox[{{0., -16.09876377148447}, {0., -24.14814565722671}, {
      0., -21.65063509461097}, {0., -14.433756729740645`}, {
      0., -16.09876377148447}}], 
     PolygonBox[{{0., 0.}, {0., -7.216878364870323}, {
      0., -5.892556509887897}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -7.216878364870323}, {0., -14.433756729740645`}, {
      0., -11.785113019775794`}, {0., -5.892556509887897}, {
      0., -7.216878364870323}}], 
     PolygonBox[{{0., -14.433756729740645`}, {0., -21.65063509461097}, {
      0., -17.677669529663692`}, {0., -11.785113019775794`}, {
      0., -14.433756729740645`}}], 
     PolygonBox[{{0., 0.}, {0., -5.892556509887898}, {
      0., -4.16666666666667}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -5.892556509887898}, {0., -11.785113019775796`}, {
      0., -8.33333333333334}, {0., -4.16666666666667}, {
      0., -5.892556509887898}}], 
     PolygonBox[{{0., -11.785113019775796`}, {0., -17.677669529663696`}, {
      0., -12.50000000000001}, {0., -8.33333333333334}, {
      0., -11.785113019775796`}}], 
     PolygonBox[{{0., 0.}, {0., -4.16666666666667}, {
      0., -2.156825375854346}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -4.16666666666667}, {0., -8.33333333333334}, {
      0., -4.313650751708692}, {0., -2.156825375854346}, {
      0., -4.16666666666667}}], 
     PolygonBox[{{0., -8.33333333333334}, {0., -12.50000000000001}, {
      0., -6.470476127563038}, {0., -4.313650751708692}, {
      0., -8.33333333333334}}], 
     PolygonBox[{{0., 0.}, {0., -2.156825375854346}, {
      0., -8.932295329768568*^-15}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -2.156825375854346}, {0., -4.313650751708692}, {
      0., -1.7864590659537137`*^-14}, {0., -8.932295329768568*^-15}, {
      0., -2.156825375854346}}], 
     PolygonBox[{{0., -4.313650751708692}, {0., -6.470476127563038}, {
      0., -2.6796885989305705`*^-14}, {0., -1.7864590659537137`*^-14}, {
      0., -4.313650751708692}}], 
     PolygonBox[{{0., 0.}, {0., -1.5308084989341913`*^-15}, {0., 
      2.1568253758543356`}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., -1.5308084989341913`*^-15}, {
      0., -3.0616169978683826`*^-15}, {0., 4.313650751708671}, {0., 
      2.1568253758543356`}, {0., -1.5308084989341913`*^-15}}], 
     PolygonBox[{{0., -3.0616169978683826`*^-15}, {
      0., -4.592425496802574*^-15}, {0., 6.470476127563007}, {0., 
      4.313650751708671}, {0., -3.0616169978683826`*^-15}}], 
     PolygonBox[{{0., 0.}, {0., 2.1568253758543356`}, {0., 
      4.166666666666661}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 2.1568253758543356`}, {0., 4.313650751708671}, {0., 
      8.333333333333321}, {0., 4.166666666666661}, {0., 
      2.1568253758543356`}}], 
     PolygonBox[{{0., 4.313650751708671}, {0., 6.470476127563007}, {0., 
      12.499999999999984`}, {0., 8.333333333333321}, {0., 
      4.313650751708671}}], 
     PolygonBox[{{0., 0.}, {0., 4.166666666666661}, {0., 5.89255650988789}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 4.166666666666661}, {0., 8.333333333333321}, {0., 
      11.78511301977578}, {0., 5.89255650988789}, {0., 4.166666666666661}}], 
     PolygonBox[{{0., 8.333333333333321}, {0., 12.499999999999984`}, {0., 
      17.67766952966367}, {0., 11.78511301977578}, {0., 8.333333333333321}}], 
     PolygonBox[{{0., 0.}, {0., 5.8925565098878945`}, {0., 
      7.216878364870319}, {0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 5.8925565098878945`}, {0., 11.785113019775789`}, {0., 
      14.433756729740638`}, {0., 7.216878364870319}, {0., 
      5.8925565098878945`}}], 
     PolygonBox[{{0., 11.785113019775789`}, {0., 17.677669529663685`}, {0., 
      21.65063509461096}, {0., 14.433756729740638`}, {0., 
      11.785113019775789`}}], 
     PolygonBox[{{0., 0.}, {0., 7.216878364870319}, {0., 8.049381885742234}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 7.216878364870319}, {0., 14.433756729740638`}, {0., 
      16.098763771484467`}, {0., 8.049381885742234}, {0., 
      7.216878364870319}}], 
     PolygonBox[{{0., 14.433756729740638`}, {0., 21.65063509461096}, {0., 
      24.148145657226703`}, {0., 16.098763771484467`}, {0., 
      14.433756729740638`}}], 
     PolygonBox[{{0., 0.}, {0., 8.049381885742234}, {0., 8.333333333333332}, {
      0., 0.}, {0., 0.}}], 
     PolygonBox[{{0., 8.049381885742234}, {0., 16.098763771484467`}, {0., 
      16.666666666666664`}, {0., 8.333333333333332}, {0., 
      8.049381885742234}}], 
     PolygonBox[{{0., 16.098763771484467`}, {0., 24.148145657226703`}, {0., 
      25.}, {0., 16.666666666666664`}, {0., 16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQosHWAsj6sb7r9RtYDzn/1uYZ2wzBTO35EmfKB6
rSGcDzFLE85331Vad+ShJJx/+vz59bMn37aB8e0g8gdg/L//QUADzt8OMR/O
fwKxH86Hug/Oh7ofzvdEk3+Gpn8XmvlsEPfD+eFo7rtx+/bhLeu+7IHxTdD8
9x3ifjh/O1r4PEYLP3e08IW63wEAPrNhDQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEqDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0A7YRq0Q==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 25.}, {10., 25.}, {10., 24.148145657226706`}, {0., 
       24.148145657226706`}, {0., 25.}}], 
      LineBox[{{0., 24.148145657226706`}, {10., 24.148145657226706`}, {10., 
       21.65063509461097}, {0., 21.65063509461097}, {0., 
       24.148145657226706`}}], 
      LineBox[{{0., 21.65063509461097}, {10., 21.65063509461097}, {10., 
       17.67766952966369}, {0., 17.67766952966369}, {0., 21.65063509461097}}],
       LineBox[{{0., 17.67766952966369}, {10., 17.67766952966369}, {10., 
       12.500000000000004`}, {0., 12.500000000000004`}, {0., 
       17.67766952966369}}], 
      LineBox[{{0., 12.500000000000004`}, {10., 12.500000000000004`}, {10., 
       6.470476127563024}, {0., 6.470476127563024}, {0., 
       12.500000000000004`}}], 
      LineBox[{{0., 6.470476127563024}, {10., 6.470476127563024}, {10., 
       7.0819236220599744`*^-15}, {0., 7.0819236220599744`*^-15}, {0., 
       6.470476127563024}}], 
      LineBox[{{0., 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       0., -6.470476127563016}, {0., 1.5308084989341915`*^-15}}], 
      LineBox[{{0., -6.470476127563016}, {10., -6.470476127563016}, {
       10., -12.499999999999995`}, {0., -12.499999999999995`}, {
       0., -6.470476127563016}}], 
      LineBox[{{0., -12.499999999999995`}, {10., -12.499999999999995`}, {
       10., -17.677669529663685`}, {0., -17.677669529663685`}, {
       0., -12.499999999999995`}}], 
      LineBox[{{0., -17.677669529663685`}, {10., -17.677669529663685`}, {
       10., -21.65063509461097}, {0., -21.65063509461097}, {
       0., -17.677669529663685`}}], 
      LineBox[{{0., -21.650635094610962`}, {10., -21.650635094610962`}, {
       10., -24.148145657226706`}, {0., -24.148145657226706`}, {
       0., -21.650635094610962`}}], 
      LineBox[{{0., -24.148145657226706`}, {10., -24.148145657226706`}, {
       10., -25.}, {0., -25.}, {0., -24.148145657226706`}}], 
      LineBox[{{0., -25.}, {10., -25.}, {10., -24.148145657226706`}, {
       0., -24.148145657226706`}, {0., -25.}}], 
      LineBox[{{0., -24.14814565722671}, {10., -24.14814565722671}, {
       10., -21.65063509461097}, {0., -21.65063509461097}, {
       0., -24.14814565722671}}], 
      LineBox[{{0., -21.65063509461097}, {10., -21.65063509461097}, {
       10., -17.677669529663692`}, {0., -17.677669529663692`}, {
       0., -21.65063509461097}}], 
      LineBox[{{0., -17.677669529663696`}, {10., -17.677669529663696`}, {
       10., -12.50000000000001}, {0., -12.50000000000001}, {
       0., -17.677669529663696`}}], 
      LineBox[{{0., -12.50000000000001}, {10., -12.50000000000001}, {
       10., -6.470476127563038}, {0., -6.470476127563038}, {
       0., -12.50000000000001}}], 
      LineBox[{{0., -6.470476127563038}, {10., -6.470476127563038}, {
       10., -2.6796885989305705`*^-14}, {0., -2.6796885989305705`*^-14}, {
       0., -6.470476127563038}}], 
      LineBox[{{0., -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {0., 
       6.470476127563007}, {0., -4.592425496802574*^-15}}], 
      LineBox[{{0., 6.470476127563007}, {10., 6.470476127563007}, {10., 
       12.499999999999984`}, {0., 12.499999999999984`}, {0., 
       6.470476127563007}}], 
      LineBox[{{0., 12.499999999999984`}, {10., 12.499999999999984`}, {10., 
       17.67766952966367}, {0., 17.67766952966367}, {0., 
       12.499999999999984`}}], 
      LineBox[{{0., 17.677669529663685`}, {10., 17.677669529663685`}, {10., 
       21.65063509461096}, {0., 21.65063509461096}, {0., 
       17.677669529663685`}}], 
      LineBox[{{0., 21.65063509461096}, {10., 21.65063509461096}, {10., 
       24.148145657226703`}, {0., 24.148145657226703`}, {0., 
       21.65063509461096}}], 
      LineBox[{{0., 24.148145657226703`}, {10., 24.148145657226703`}, {10., 
       25.}, {0., 25.}, {0., 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100., -25.}, {110., -25.}, {110., -16.66666666666667}, {
      100., -16.666666666666668`}, {100., -25.}}], 
     PolygonBox[{{100., -16.666666666666668`}, {110., -16.66666666666667}, {
      110., -8.333333333333336}, {100., -8.333333333333336}, {
      100., -16.666666666666668`}}], 
     PolygonBox[{{100., -8.333333333333336}, {110., -8.333333333333336}, {
      110., -7.105427357601002*^-15}, {100., 0.}, {
      100., -8.333333333333336}}], 
     PolygonBox[{{100., 0.}, {110., 0.}, {110., 8.333333333333332}, {100., 
      8.333333333333329}, {100., 0.}}], 
     PolygonBox[{{100., 8.333333333333329}, {110., 8.333333333333332}, {110., 
      16.666666666666664`}, {100., 16.666666666666664`}, {100., 
      8.333333333333329}}], 
     PolygonBox[{{100., 16.666666666666664`}, {110., 16.666666666666664`}, {
      110., 24.999999999999996`}, {100., 24.999999999999993`}, {100., 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -25.}, {100., -16.666666666666668`}, {
       100., -8.333333333333336}, {100., -3.552713678800501*^-15}, {100., 
       8.333333333333329}, {100., 16.666666666666657`}, {100., 
       24.999999999999993`}, {110., 25.}, {110., 16.666666666666668`}, {110., 
       8.333333333333336}, {110., 3.552713678800501*^-15}, {
       110., -8.333333333333329}, {110., -16.666666666666657`}, {
       110., -24.999999999999993`}, {100., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., 0.}, {110., 3.061616997868383*^-15}, {110., 
        2.551347498223653*^-15}, {100., 5.102694996447305*^-16}, {100., 0.}}],
        PolygonBox[{{100., 5.102694996447305*^-16}, {110., 
        2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {100., 
        1.020538999289461*^-15}, {100., 5.102694996447305*^-16}}], 
       PolygonBox[{{100., 1.020538999289461*^-15}, {110., 
        2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {100., 
        1.5308084989341915`*^-15}, {100., 1.020538999289461*^-15}}], 
       PolygonBox[{{100., 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {100., 
        2.041077998578922*^-15}, {100., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{100., 2.041077998578922*^-15}, {110., 
        1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {100., 
        2.5513474982236525`*^-15}, {100., 2.041077998578922*^-15}}], 
       PolygonBox[{{100., 2.5513474982236525`*^-15}, {110., 
        5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {100., 
        3.0616169978683826`*^-15}, {100., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {
         100., 0.}, {100., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
         0.}, {110., 0.}, {110., 0.}, {110., 0.}, {100., 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100., 0.}, {100., 8.333333333333332}, {100., 
      8.049381885742235}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 8.333333333333332}, {100., 16.666666666666664`}, {
      100., 16.09876377148447}, {100., 8.049381885742235}, {100., 
      8.333333333333332}}], 
     PolygonBox[{{100., 16.666666666666664`}, {100., 25.}, {100., 
      24.148145657226706`}, {100., 16.09876377148447}, {100., 
      16.666666666666664`}}], 
     PolygonBox[{{100., 0.}, {100., 8.049381885742235}, {100., 
      7.216878364870323}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 8.049381885742235}, {100., 16.09876377148447}, {100., 
      14.433756729740645`}, {100., 7.216878364870323}, {100., 
      8.049381885742235}}], 
     PolygonBox[{{100., 16.09876377148447}, {100., 24.148145657226706`}, {
      100., 21.65063509461097}, {100., 14.433756729740645`}, {100., 
      16.09876377148447}}], 
     PolygonBox[{{100., 0.}, {100., 7.216878364870323}, {100., 
      5.892556509887896}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 7.216878364870323}, {100., 14.433756729740645`}, {
      100., 11.785113019775793`}, {100., 5.892556509887896}, {100., 
      7.216878364870323}}], 
     PolygonBox[{{100., 14.433756729740645`}, {100., 21.65063509461097}, {
      100., 17.67766952966369}, {100., 11.785113019775793`}, {100., 
      14.433756729740645`}}], 
     PolygonBox[{{100., 0.}, {100., 5.892556509887896}, {100., 
      4.166666666666668}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 5.892556509887896}, {100., 11.785113019775793`}, {
      100., 8.333333333333336}, {100., 4.166666666666668}, {100., 
      5.892556509887896}}], 
     PolygonBox[{{100., 11.785113019775793`}, {100., 17.67766952966369}, {
      100., 12.500000000000004`}, {100., 8.333333333333336}, {100., 
      11.785113019775793`}}], 
     PolygonBox[{{100., 0.}, {100., 4.166666666666668}, {100., 
      2.156825375854341}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 4.166666666666668}, {100., 8.333333333333336}, {100., 
      4.313650751708682}, {100., 2.156825375854341}, {100., 
      4.166666666666668}}], 
     PolygonBox[{{100., 8.333333333333336}, {100., 12.500000000000004`}, {
      100., 6.470476127563024}, {100., 4.313650751708682}, {100., 
      8.333333333333336}}], 
     PolygonBox[{{100., 0.}, {100., 2.156825375854341}, {100., 
      2.3606412073533245`*^-15}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 2.156825375854341}, {100., 4.313650751708682}, {100., 
      4.721282414706649*^-15}, {100., 2.3606412073533245`*^-15}, {100., 
      2.156825375854341}}], 
     PolygonBox[{{100., 4.313650751708682}, {100., 6.470476127563024}, {100., 
      7.0819236220599744`*^-15}, {100., 4.721282414706649*^-15}, {100., 
      4.313650751708682}}], 
     PolygonBox[{{100., 0.}, {100., 5.102694996447305*^-16}, {
      100., -2.1568253758543383`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 5.102694996447305*^-16}, {100., 
      1.020538999289461*^-15}, {100., -4.313650751708677}, {
      100., -2.1568253758543383`}, {100., 5.102694996447305*^-16}}], 
     PolygonBox[{{100., 1.020538999289461*^-15}, {100., 
      1.5308084989341915`*^-15}, {100., -6.470476127563016}, {
      100., -4.313650751708677}, {100., 1.020538999289461*^-15}}], 
     PolygonBox[{{100., 0.}, {100., -2.1568253758543383`}, {
      100., -4.166666666666664}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -2.1568253758543383`}, {100., -4.313650751708677}, {
      100., -8.333333333333329}, {100., -4.166666666666664}, {
      100., -2.1568253758543383`}}], 
     PolygonBox[{{100., -4.313650751708677}, {100., -6.470476127563016}, {
      100., -12.499999999999995`}, {100., -8.333333333333329}, {
      100., -4.313650751708677}}], 
     PolygonBox[{{100., 0.}, {100., -4.166666666666664}, {
      100., -5.8925565098878945`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -4.166666666666664}, {100., -8.333333333333329}, {
      100., -11.785113019775789`}, {100., -5.8925565098878945`}, {
      100., -4.166666666666664}}], 
     PolygonBox[{{100., -8.333333333333329}, {100., -12.499999999999995`}, {
      100., -17.677669529663685`}, {100., -11.785113019775789`}, {
      100., -8.333333333333329}}], 
     PolygonBox[{{100., 0.}, {100., -5.8925565098878945`}, {
      100., -7.216878364870323}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -5.8925565098878945`}, {100., -11.785113019775789`}, {
      100., -14.433756729740645`}, {100., -7.216878364870323}, {
      100., -5.8925565098878945`}}], 
     PolygonBox[{{100., -11.785113019775789`}, {100., -17.677669529663685`}, {
      100., -21.65063509461097}, {100., -14.433756729740645`}, {
      100., -11.785113019775789`}}], 
     PolygonBox[{{100., 0.}, {100., -7.21687836487032}, {
      100., -8.049381885742235}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -7.21687836487032}, {100., -14.43375672974064}, {
      100., -16.09876377148447}, {100., -8.049381885742235}, {
      100., -7.21687836487032}}], 
     PolygonBox[{{100., -14.43375672974064}, {100., -21.650635094610962`}, {
      100., -24.148145657226706`}, {100., -16.09876377148447}, {
      100., -14.43375672974064}}], 
     PolygonBox[{{100., 0.}, {100., -8.049381885742235}, {
      100., -8.333333333333332}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -8.049381885742235}, {100., -16.09876377148447}, {
      100., -16.666666666666664`}, {100., -8.333333333333332}, {
      100., -8.049381885742235}}], 
     PolygonBox[{{100., -16.09876377148447}, {100., -24.148145657226706`}, {
      100., -25.}, {100., -16.666666666666664`}, {100., -16.09876377148447}}],
      PolygonBox[{{100., 0.}, {100., -8.333333333333332}, {
      100., -8.049381885742235}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -8.333333333333332}, {100., -16.666666666666664`}, {
      100., -16.09876377148447}, {100., -8.049381885742235}, {
      100., -8.333333333333332}}], 
     PolygonBox[{{100., -16.666666666666664`}, {100., -25.}, {
      100., -24.148145657226706`}, {100., -16.09876377148447}, {
      100., -16.666666666666664`}}], 
     PolygonBox[{{100., 0.}, {100., -8.049381885742235}, {
      100., -7.216878364870323}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -8.049381885742235}, {100., -16.09876377148447}, {
      100., -14.433756729740645`}, {100., -7.216878364870323}, {
      100., -8.049381885742235}}], 
     PolygonBox[{{100., -16.09876377148447}, {100., -24.14814565722671}, {
      100., -21.65063509461097}, {100., -14.433756729740645`}, {
      100., -16.09876377148447}}], 
     PolygonBox[{{100., 0.}, {100., -7.216878364870323}, {
      100., -5.892556509887897}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -7.216878364870323}, {100., -14.433756729740645`}, {
      100., -11.785113019775794`}, {100., -5.892556509887897}, {
      100., -7.216878364870323}}], 
     PolygonBox[{{100., -14.433756729740645`}, {100., -21.65063509461097}, {
      100., -17.677669529663692`}, {100., -11.785113019775794`}, {
      100., -14.433756729740645`}}], 
     PolygonBox[{{100., 0.}, {100., -5.892556509887898}, {
      100., -4.16666666666667}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -5.892556509887898}, {100., -11.785113019775796`}, {
      100., -8.33333333333334}, {100., -4.16666666666667}, {
      100., -5.892556509887898}}], 
     PolygonBox[{{100., -11.785113019775796`}, {100., -17.677669529663696`}, {
      100., -12.50000000000001}, {100., -8.33333333333334}, {
      100., -11.785113019775796`}}], 
     PolygonBox[{{100., 0.}, {100., -4.16666666666667}, {
      100., -2.156825375854346}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -4.16666666666667}, {100., -8.33333333333334}, {
      100., -4.313650751708692}, {100., -2.156825375854346}, {
      100., -4.16666666666667}}], 
     PolygonBox[{{100., -8.33333333333334}, {100., -12.50000000000001}, {
      100., -6.470476127563038}, {100., -4.313650751708692}, {
      100., -8.33333333333334}}], 
     PolygonBox[{{100., 0.}, {100., -2.156825375854346}, {
      100., -8.932295329768568*^-15}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -2.156825375854346}, {100., -4.313650751708692}, {
      100., -1.7864590659537137`*^-14}, {100., -8.932295329768568*^-15}, {
      100., -2.156825375854346}}], 
     PolygonBox[{{100., -4.313650751708692}, {100., -6.470476127563038}, {
      100., -2.6796885989305705`*^-14}, {100., -1.7864590659537137`*^-14}, {
      100., -4.313650751708692}}], 
     PolygonBox[{{100., 0.}, {100., -1.5308084989341913`*^-15}, {100., 
      2.1568253758543356`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -1.5308084989341913`*^-15}, {
      100., -3.0616169978683826`*^-15}, {100., 4.313650751708671}, {100., 
      2.1568253758543356`}, {100., -1.5308084989341913`*^-15}}], 
     PolygonBox[{{100., -3.0616169978683826`*^-15}, {
      100., -4.592425496802574*^-15}, {100., 6.470476127563007}, {100., 
      4.313650751708671}, {100., -3.0616169978683826`*^-15}}], 
     PolygonBox[{{100., 0.}, {100., 2.1568253758543356`}, {100., 
      4.166666666666661}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 2.1568253758543356`}, {100., 4.313650751708671}, {
      100., 8.333333333333321}, {100., 4.166666666666661}, {100., 
      2.1568253758543356`}}], 
     PolygonBox[{{100., 4.313650751708671}, {100., 6.470476127563007}, {100., 
      12.499999999999984`}, {100., 8.333333333333321}, {100., 
      4.313650751708671}}], 
     PolygonBox[{{100., 0.}, {100., 4.166666666666661}, {100., 
      5.89255650988789}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 4.166666666666661}, {100., 8.333333333333321}, {100., 
      11.78511301977578}, {100., 5.89255650988789}, {100., 
      4.166666666666661}}], 
     PolygonBox[{{100., 8.333333333333321}, {100., 12.499999999999984`}, {
      100., 17.67766952966367}, {100., 11.78511301977578}, {100., 
      8.333333333333321}}], 
     PolygonBox[{{100., 0.}, {100., 5.8925565098878945`}, {100., 
      7.216878364870319}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 5.8925565098878945`}, {100., 11.785113019775789`}, {
      100., 14.433756729740638`}, {100., 7.216878364870319}, {100., 
      5.8925565098878945`}}], 
     PolygonBox[{{100., 11.785113019775789`}, {100., 17.677669529663685`}, {
      100., 21.65063509461096}, {100., 14.433756729740638`}, {100., 
      11.785113019775789`}}], 
     PolygonBox[{{100., 0.}, {100., 7.216878364870319}, {100., 
      8.049381885742234}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 7.216878364870319}, {100., 14.433756729740638`}, {
      100., 16.098763771484467`}, {100., 8.049381885742234}, {100., 
      7.216878364870319}}], 
     PolygonBox[{{100., 14.433756729740638`}, {100., 21.65063509461096}, {
      100., 24.148145657226703`}, {100., 16.098763771484467`}, {100., 
      14.433756729740638`}}], 
     PolygonBox[{{100., 0.}, {100., 8.049381885742234}, {100., 
      8.333333333333332}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 8.049381885742234}, {100., 16.098763771484467`}, {
      100., 16.666666666666664`}, {100., 8.333333333333332}, {100., 
      8.049381885742234}}], 
     PolygonBox[{{100., 16.098763771484467`}, {100., 24.148145657226703`}, {
      100., 25.}, {100., 16.666666666666664`}, {100., 
      16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGRDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AA1Fv/g==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYN0Q4QhqUDjO9xdcP9N6oWcP6z3y2sE5aZwvk7
0oQPVK81hPMhZmnC+e67SuuOPJSE80+fP79+9uTbNjC+HUT+AIz/9z8IaMD5
2yHmw/lPIPbD+VD3wflQ98P5nmjyz9D070Iznw3ifjg/HM19N27fPrxl3Zc9
ML4Jmv++Q9wP529HC5/HaOHnjha+sPAHABTbfLA=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 25.}, {110., 25.}, {110., 24.148145657226706`}, {100., 
       24.148145657226706`}, {100., 25.}}], 
      LineBox[{{100., 24.148145657226706`}, {110., 24.148145657226706`}, {
       110., 21.65063509461097}, {100., 21.65063509461097}, {100., 
       24.148145657226706`}}], 
      LineBox[{{100., 21.65063509461097}, {110., 21.65063509461097}, {110., 
       17.67766952966369}, {100., 17.67766952966369}, {100., 
       21.65063509461097}}], 
      LineBox[{{100., 17.67766952966369}, {110., 17.67766952966369}, {110., 
       12.500000000000004`}, {100., 12.500000000000004`}, {100., 
       17.67766952966369}}], 
      LineBox[{{100., 12.500000000000004`}, {110., 12.500000000000004`}, {
       110., 6.470476127563024}, {100., 6.470476127563024}, {100., 
       12.500000000000004`}}], 
      LineBox[{{100., 6.470476127563024}, {110., 6.470476127563024}, {110., 
       7.0819236220599744`*^-15}, {100., 7.0819236220599744`*^-15}, {100., 
       6.470476127563024}}], 
      LineBox[{{100., 1.5308084989341915`*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       100., -6.470476127563016}, {100., 1.5308084989341915`*^-15}}], 
      LineBox[{{100., -6.470476127563016}, {110., -6.470476127563016}, {
       110., -12.499999999999995`}, {100., -12.499999999999995`}, {
       100., -6.470476127563016}}], 
      LineBox[{{100., -12.499999999999995`}, {110., -12.499999999999995`}, {
       110., -17.677669529663685`}, {100., -17.677669529663685`}, {
       100., -12.499999999999995`}}], 
      LineBox[{{100., -17.677669529663685`}, {110., -17.677669529663685`}, {
       110., -21.65063509461097}, {100., -21.65063509461097}, {
       100., -17.677669529663685`}}], 
      LineBox[{{100., -21.650635094610962`}, {110., -21.650635094610962`}, {
       110., -24.148145657226706`}, {100., -24.148145657226706`}, {
       100., -21.650635094610962`}}], 
      LineBox[{{100., -24.148145657226706`}, {110., -24.148145657226706`}, {
       110., -25.}, {100., -25.}, {100., -24.148145657226706`}}], 
      LineBox[{{100., -25.}, {110., -25.}, {110., -24.148145657226706`}, {
       100., -24.148145657226706`}, {100., -25.}}], 
      LineBox[{{100., -24.14814565722671}, {110., -24.14814565722671}, {
       110., -21.65063509461097}, {100., -21.65063509461097}, {
       100., -24.14814565722671}}], 
      LineBox[{{100., -21.65063509461097}, {110., -21.65063509461097}, {
       110., -17.677669529663692`}, {100., -17.677669529663692`}, {
       100., -21.65063509461097}}], 
      LineBox[{{100., -17.677669529663696`}, {110., -17.677669529663696`}, {
       110., -12.50000000000001}, {100., -12.50000000000001}, {
       100., -17.677669529663696`}}], 
      LineBox[{{100., -12.50000000000001}, {110., -12.50000000000001}, {
       110., -6.470476127563038}, {100., -6.470476127563038}, {
       100., -12.50000000000001}}], 
      LineBox[{{100., -6.470476127563038}, {110., -6.470476127563038}, {
       110., -2.6796885989305705`*^-14}, {100., -2.6796885989305705`*^-14}, {
       100., -6.470476127563038}}], 
      LineBox[{{100., -4.592425496802574*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {100., 
       6.470476127563007}, {100., -4.592425496802574*^-15}}], 
      LineBox[{{100., 6.470476127563007}, {110., 6.470476127563007}, {110., 
       12.499999999999984`}, {100., 12.499999999999984`}, {100., 
       6.470476127563007}}], 
      LineBox[{{100., 12.499999999999984`}, {110., 12.499999999999984`}, {
       110., 17.67766952966367}, {100., 17.67766952966367}, {100., 
       12.499999999999984`}}], 
      LineBox[{{100., 17.677669529663685`}, {110., 17.677669529663685`}, {
       110., 21.65063509461096}, {100., 21.65063509461096}, {100., 
       17.677669529663685`}}], 
      LineBox[{{100., 21.65063509461096}, {110., 21.65063509461096}, {110., 
       24.148145657226703`}, {100., 24.148145657226703`}, {100., 
       21.65063509461096}}], 
      LineBox[{{100., 24.148145657226703`}, {110., 24.148145657226703`}, {
       110., 25.}, {100., 25.}, {100., 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"mirror1\"\>", {5., -26.}, {0., 0.}], 
    InsetBox["\<\"mirror2\"\>", {105., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731752529076*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[80]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Mirror", "[", 
         RowBox[{"50", ",", "10", ",", 
          RowBox[{"{", 
           RowBox[{"Labels", "\[Rule]", "\<\"mirror\"\>"}], "}"}]}], "]"}], 
        ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Mirror", "[", 
           RowBox[{"50", ",", "10", ",", 
            RowBox[{"{", 
             RowBox[{"Labels", "\[Rule]", "\<\"mirror\"\>"}], "}"}]}], "]"}], 
          ",", "100.`"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.614731752533449*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[80]:="],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.563367935991639*^9, 3.566158867350264*^9, 
  3.56615900794801*^9, 3.5672683622218113`*^9, 3.614730561227982*^9, 
  3.614731752534686*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[81]="]
}, Open  ]],

Cell["\<\
Optica uses your labels in the graphics, but the printed output shows the \
full  function names.\
\>", "Commentary",
 CellChangeTimes->{3.566158951003517*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "A ",
 StyleBox["Labels", "Input",
  FontFamily->"Courier"],
 " option is always in the default ",
 StyleBox["Options", "Input",
  FontFamily->"Courier"],
 " settings of every component."
}], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell["Labels/.Options[Mirror]//InputForm", "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[83]:="],

Cell["\"M\"", "Output",
 CellChangeTimes->{3.5633679360613127`*^9, 3.566158867380205*^9, 
  3.5661590079920473`*^9, 3.567268362255629*^9, 3.6147305612441874`*^9, 
  3.614731752567568*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[83]//InputForm="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Surpressing Labels", "Subsubsection",
 CellTags->{
  "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[{
 "There are two methods for surpressing labels.  In order to surpress all  \
labelling, you simply pass the option ",
 StyleBox["ShowLabels->False", "Input"],
 " to ",
 StyleBox["AnalyzeSystem", "Input"],
 " or ",
 StyleBox["ShowSystem", "Input"],
 ".  However, you can otherwise supply an empty string as a label to  \
suppress the automatic labelling of an individual component graphic."
}], "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defaultSystem", "=", 
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"PlanoConvexLens", "[", 
       RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Prism", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
          "\"\<\>\"", ",", 
          RowBox[{"Centered", "\[Rule]", "True"}]}], "]"}], ",", "50"}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}]}], "]"}]}]], "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"In[84]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
      10., -16.66666666666667}, {2.7504488342847893`, -16.666666666666668`}, {
      6.421974580955592, -25.}}], 
     PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
      10., -16.66666666666667}, {10., -8.333333333333336}, {
      0.6737579958920605, -8.333333333333336}, {
      2.7504488342847893`, -16.666666666666668`}}], 
     PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
      10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
      0.6737579958920605, -8.333333333333336}}], 
     PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
      0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
     PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
      8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
      16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
     PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
      16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
      24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, -25.}, {
       2.7504488342847893`, -16.666666666666668`}, {
       0.6737579958920605, -8.333333333333336}, {
       0., -3.552713678800501*^-15}, {0.6737579958920605, 
       8.333333333333329}, {2.750448834284782, 16.666666666666657`}, {
       6.421974580955592, 24.999999999999993`}, {10., 25.}, {10., 
       16.666666666666668`}, {10., 8.333333333333336}, {10., 
       3.552713678800501*^-15}, {10., -8.333333333333329}, {
       10., -16.666666666666657`}, {10., -24.999999999999993`}, {
       6.421974580955592, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{6.421974580955592, 0.}, {10., 3.061616997868383*^-15}, {
        10., 2.551347498223653*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}, {6.421974580955592, 0.}}], 
       PolygonBox[{{2.7504488342847893`, 5.102694996447305*^-16}, {10., 
        2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {
        0.6737579958920605, 1.020538999289461*^-15}, {2.7504488342847893`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{0.6737579958920605, 1.020538999289461*^-15}, {10., 
        2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
        1.5308084989341915`*^-15}, {0.6737579958920605, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
        1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {
        0.6737579958920605, 2.041077998578922*^-15}, {0., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{0.6737579958920605, 2.041077998578922*^-15}, {10., 
        1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {
        2.7504488342847893`, 2.5513474982236525`*^-15}, {0.6737579958920605, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{2.7504488342847893`, 2.5513474982236525`*^-15}, {10., 
        5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {
        6.421974580955592, 3.0616169978683826`*^-15}, {2.7504488342847893`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
         0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
         2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
         0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
         6.421974580955592, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
       12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955592, 12.500000000000004`}, {10., 
       12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
       6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
      LineBox[{{6.421974580955592, 6.470476127563024}, {10., 
       6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
       6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
       6.470476127563024}}], 
      LineBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       6.421974580955592, -6.470476127563016}, {6.421974580955592, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563016}, {
       10., -6.470476127563016}, {10., -12.499999999999995`}, {
       6.421974580955592, -12.499999999999995`}, {
       6.421974580955592, -6.470476127563016}}], 
      LineBox[{{6.421974580955592, -12.499999999999995`}, {
       10., -12.499999999999995`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999995`}}], 
      LineBox[{{6.421974580955592, -17.677669529663685`}, {
       10., -17.677669529663685`}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -17.677669529663685`}}], 
      LineBox[{{6.421974580955599, -21.650635094610962`}, {
       10., -21.650635094610962`}, {10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {
       6.421974580955599, -21.650635094610962`}}], 
      LineBox[{{6.421974580955592, -24.148145657226706`}, {
       10., -24.148145657226706`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226706`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.65063509461097}, {
       10., -21.65063509461097}, {10., -17.677669529663692`}, {
       6.421974580955592, -17.677669529663692`}, {
       6.421974580955592, -21.65063509461097}}], 
      LineBox[{{6.421974580955592, -17.677669529663696`}, {
       10., -17.677669529663696`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663696`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563038}, {
       6.421974580955592, -6.470476127563038}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563038}, {
       10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
       6.421974580955592, -2.6796885989305705`*^-14}, {
       6.421974580955592, -6.470476127563038}}], 
      LineBox[{{6.421974580955592, -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
       6.421974580955592, 6.470476127563007}, {
       6.421974580955592, -4.592425496802574*^-15}}], 
      LineBox[{{6.421974580955592, 6.470476127563007}, {10., 
       6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
       12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
      LineBox[{{6.421974580955592, 12.499999999999984`}, {10., 
       12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
       17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
       21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.65063509461096}, {10., 
       21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
       24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
      LineBox[{{6.421974580955592, 24.148145657226703`}, {10., 
       24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {62.5, 21.650635094610966`}, {
       62.5, 21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{87.5, -21.650635094610966`}, {62.5, 21.650635094610966`}, {
       62.5, 21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.5, -21.650635094610966`}, {87.5, -21.650635094610966`}, {
       87.5, -21.650635094610966`}, {37.5, -21.650635094610966`}, {
       37.5, -21.650635094610966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, -21.657851972975834`}, {62.5, 21.665068851340703`}, {
       87.5125, -21.657851972975838`}, {37.4875, -21.657851972975834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{37.4875, -21.657851972975834`}, {62.5, 21.665068851340703`}, {
       87.5125, -21.657851972975838`}, {37.4875, -21.657851972975834`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.614731753126405*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[84]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Prism", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"60", ",", "50", ",", "60"}], "}"}], ",", "50", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Labels", "\[Rule]", "\<\"\"\>"}], ",", 
              RowBox[{"Centered", "\[Rule]", "True"}]}], "}"}]}], "]"}], ",", 
          "50.`"}], "]"}]}], "}"}], ",", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.6147317531285963`*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"During evaluation of In[84]:="],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.563367936860057*^9, 3.566158867438308*^9, 
  3.5661590089994717`*^9, 3.567268363295459*^9, 3.614730561260812*^9, 
  3.614731753129877*^9},
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"},
 CellLabel->"Out[84]="]
}, Open  ]],

Cell["\<\
The prism label was surpressed with \"\".  The plano-convex lens label \"L\" \
still automatically appears.\
\>", "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 6 topics"]], "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1169, 786},
WindowMargins->{{Automatic, 56}, {-185, Automatic}},
ShowSelection->True,
ShowCellTags->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "chapter 6 topics"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}]},
 "6.1 Introduction"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[4383, 155, 107, 2, 71, "Section",
   PageBreakAbove->True,
   CellTags->{"6.1", "6.1 Introduction", "PR6.1"}],
  Cell[4493, 159, 494, 8, 44, "Text",
   CellTags->{"6.1 Introduction", "PR6.1"}],
  Cell[4990, 169, 1587, 53, 62, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6602, 226, 176, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6781, 232, 2959, 61, 168, "Output",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[9755, 296, 1062, 35, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}]},
 "Adjusting Graphics"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[1138, 37, 200, 4, 31, "Outline2",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[1341, 43, 527, 18, 66, "Outline3",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[10972, 340, 103, 1, 71, "Section",
   CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11078, 343, 647, 15, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11750, 362, 966, 23, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[12719, 387, 23284, 424, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36018, 814, 298, 10, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36319, 826, 356, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36700, 839, 898, 22, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[37601, 863, 10534, 201, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48150, 1067, 382, 11, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48535, 1080, 333, 6, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48871, 1088, 808, 27, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[49682, 1117, 218, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[49903, 1123, 159, 3, 31, "Text",
   CellTags->{"PR6.2", "Adjusting Graphics"}],
  Cell[50087, 1130, 111, 1, 46, "Subsection",
   CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50201, 1133, 397, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50601, 1144, 183, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50809, 1152, 1189, 35, 100, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[52001, 1189, 22255, 384, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74271, 1576, 307, 7, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74603, 1587, 962, 27, 52, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[75568, 1616, 24039, 424, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[99622, 2043, 602, 12, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[100227, 2057, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[100423, 2065, 149, 3, 46, "Subsection",
   CellTags->{
    "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
     "PR6.2.2"}],
  Cell[100575, 2070, 325, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[100903, 2081, 417, 7, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101323, 2090, 508, 15, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101834, 2107, 687, 19, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102524, 2128, 412, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102961, 2145, 162, 4, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[103126, 2151, 15926, 264, 408, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119067, 2418, 174, 4, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119244, 2424, 258, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119505, 2434, 263, 5, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119771, 2441, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[119967, 2449, 129, 2, 46, "Subsection",
   CellTags->{
    "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120099, 2453, 454, 13, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120556, 2468, 393, 12, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120974, 2484, 627, 19, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[121604, 2505, 9754, 169, 236, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131373, 2677, 154, 5, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131530, 2684, 689, 21, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132222, 2707, 482, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132729, 2724, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132873, 2729, 298, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133186, 2737, 352, 10, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133541, 2749, 119, 1, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133685, 2754, 146, 3, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133834, 2759, 19889, 299, 2417, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[153738, 3061, 412, 11, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154153, 3074, 293, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154449, 3084, 943, 28, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155417, 3116, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155561, 3121, 300, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155876, 3129, 374, 13, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[156253, 3144, 484, 16, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[156740, 3162, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[156936, 3170, 189, 3, 46, "Subsection",
   CellTags->{
    "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
     "Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157128, 3175, 811, 19, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157942, 3196, 158, 2, 31, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[158125, 3202, 1580, 43, 160, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[159708, 3247, 45366, 736, 395, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[205089, 3986, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}]},
 "ShowText"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[205297, 3995, 118, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"ShowText", "6.3", "PR6.3"}],
  Cell[205440, 4002, 84, 2, 35, "Input",
   CellTags->{"ShowText", "PR6.3"}],
  Cell[205527, 4006, 2182, 30, 311, "Print",
   CellTags->{"Info3614713735-8131145", "PR6.3", "ShowText"}],
  Cell[207746, 4041, 262, 8, 100, "Input",
   CellTags->{"ShowText", "PR6.3"}],
  Cell[208011, 4051, 14597, 259, 371, "Print",
   CellTags->{"ShowText", "PR6.3"}]},
 "ShowRange"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[222775, 4320, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.4", "ShowRange", "PR6.4"}],
  Cell[222898, 4325, 929, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[223830, 4359, 1273, 43, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225106, 4404, 750, 28, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225881, 4436, 405, 12, 133, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[226289, 4450, 36395, 632, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[262699, 5085, 532, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263256, 5105, 180, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263439, 5111, 34894, 578, 216, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[298348, 5692, 1062, 38, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}]},
 "ColorView"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[299565, 5739, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.5", "ColorView", "PR6.5"}],
  Cell[299688, 5744, 969, 31, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[300660, 5777, 1248, 41, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[301911, 5820, 3620, 137, 74, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[305534, 5959, 815, 24, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[306352, 5985, 1047, 37, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[307402, 6024, 658, 20, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[308085, 6048, 264, 8, 100, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[308352, 6058, 13784, 235, 371, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[322151, 6296, 600, 14, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[322776, 6314, 269, 8, 100, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[323048, 6324, 13817, 235, 371, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[336880, 6562, 607, 19, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337512, 6585, 301, 9, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337816, 6596, 31736, 574, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[369567, 7173, 694, 24, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370286, 7201, 255, 8, 68, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370544, 7211, 3178, 60, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[373737, 7274, 265, 6, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374027, 7284, 200, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374230, 7290, 37563, 648, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[411830, 7943, 182, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[412015, 7949, 49192, 848, 236, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461222, 8800, 491, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461738, 8820, 242, 7, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461983, 8829, 16264, 278, 94, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478262, 9110, 470, 12, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478757, 9126, 289, 9, 117, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[479049, 9137, 21194, 381, 372, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[500280, 9523, 212, 7, 84, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[500495, 9532, 9761, 189, 387, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[512491, 9803, 418, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[512912, 9816, 26001, 447, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[538950, 10268, 241, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[539194, 10277, 4473, 101, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[543704, 10383, 391, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[544098, 10396, 11048, 193, 193, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[809847, 15497, 144, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}],
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[820958, 15917, 201, 5, 32, "Text",
   CellTags->{"ModelRayColor", "ColorView", "PR6.10"}],
  Cell[821162, 15924, 139, 3, 31, "Text",
   CellTags->"ColorView"]},
 "RayChoice"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[510423, 9731, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.6", "RayChoice", "PR6.6"}],
  Cell[510546, 9736, 473, 14, 32, "Text",
   Evaluatable->False,
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[511044, 9754, 86, 2, 35, "Input",
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[511133, 9758, 479, 7, 84, "Print",
   CellTags->{"Info3614713740-8131145", "PR6.6", "RayChoice"}],
  Cell[511627, 9768, 608, 21, 73, "Text",
   Evaluatable->False,
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[512238, 9791, 228, 8, 32, "Text",
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[512491, 9803, 418, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[512912, 9816, 26001, 447, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[538950, 10268, 241, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[539194, 10277, 4473, 101, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[543704, 10383, 391, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[544098, 10396, 11048, 193, 193, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}]},
 "OutputType"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[555313, 10599, 142, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}],
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}]},
 "LineStyle"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[613749, 11841, 147, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}],
  Cell[613899, 11846, 847, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[614749, 11880, 1180, 39, 134, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[615932, 11921, 1197, 43, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[617132, 11966, 1028, 35, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}]},
 "Other Rendering Options"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[663941, 12819, 181, 4, 35, "Input",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
  Cell[664125, 12825, 2561, 60, 131, "Output",
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673358, 13124, 203, 8, 38, "Commentary",
   CellTags->{"Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "ModelRayColor"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[809847, 15497, 144, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}],
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[820958, 15917, 201, 5, 32, "Text",
   CellTags->{"ModelRayColor", "ColorView", "PR6.10"}]},
 "Labelling of Components"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[2789, 102, 213, 4, 31, "Outline2",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[3005, 108, 223, 4, 27, "Outline3",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[3253, 116, 229, 4, 27, "Outline3",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[3485, 122, 849, 27, 86, "Outline4",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[821338, 15932, 117, 1, 71, "Section",
   CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[821458, 15935, 556, 9, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822039, 15948, 170, 3, 46, "Subsection",
   CellTags->{
    "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
     "PR6.11.1", "PR6.11"}],
  Cell[822212, 15953, 322, 6, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822559, 15963, 189, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822751, 15970, 393, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823147, 15983, 458, 13, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823620, 15999, 217, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823862, 16008, 150, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824015, 16012, 555, 15, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824585, 16030, 322, 6, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824932, 16040, 191, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[825126, 16047, 397, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[825538, 16061, 165, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[825740, 16069, 158, 3, 46, "Subsection",
   CellTags->{
    "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[825901, 16074, 263, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826189, 16083, 232, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826424, 16091, 69219, 1158, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[895646, 17251, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896264, 17270, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896590, 17278, 224, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896817, 17285, 434, 7, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897276, 17296, 141, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897420, 17300, 33705, 564, 449, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931128, 17866, 503, 14, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931634, 17882, 300, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931949, 17890, 207, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932159, 17896, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932361, 17903, 136, 2, 42, "Subsubsection",
   CellTags->{
    "Numbering Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932500, 17907, 505, 11, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933030, 17922, 262, 8, 100, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933295, 17932, 18574, 307, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[951872, 18241, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952490, 18260, 315, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952820, 18268, 255, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953078, 18275, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953292, 18283, 212, 4, 42, "Subsubsection",
   CellTags->{
    "Rayica's Default Treatment of Labels", "Labelling of Components", 
     "PR6.11", "PR6.11.2"}],
  Cell[953507, 18289, 470, 8, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[954002, 18301, 1094, 30, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[955099, 18333, 30175, 498, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[985277, 18833, 1388, 38, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986668, 18873, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986994, 18881, 237, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987234, 18888, 298, 7, 32, "Text",
   PageBreakAbove->True,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987557, 18899, 414, 11, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987974, 18912, 27016, 450, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1014993, 19364, 38716, 631, 251, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1053724, 19998, 343, 11, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054070, 20011, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054284, 20019, 173, 4, 42, "Subsubsection",
   PageBreakAbove->Automatic,
   CellTags->{
    "Placement of Your Labels", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1054460, 20025, 403, 11, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054888, 20040, 118, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1055009, 20044, 502, 8, 84, "Print",
   CellTags->{
    "Info3614713748-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1055548, 20057, 1224, 31, 84, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1056775, 20090, 2913, 56, 131, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1059703, 20149, 296, 9, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060002, 20160, 462, 14, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060467, 20176, 154, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060646, 20185, 115, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060764, 20189, 431, 7, 84, "Print",
   CellTags->{
    "Info3614713750-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1061210, 20199, 218, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061431, 20206, 220, 7, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061676, 20217, 138, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061817, 20221, 284, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062116, 20229, 202, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062343, 20238, 894, 23, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1063240, 20263, 2917, 56, 121, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066172, 20322, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066386, 20330, 134, 2, 42, "Subsubsection",
   CellTags->{
    "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  
  Cell[1066523, 20334, 971, 24, 65, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1067519, 20362, 1083, 28, 129, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1068605, 20392, 35798, 635, 327, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1104406, 21029, 1476, 42, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1105885, 21073, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106211, 21081, 248, 7, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106462, 21090, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106676, 21098, 128, 2, 42, "Subsubsection",
   CellTags->{
    "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106807, 21102, 368, 9, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107200, 21115, 188, 6, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107391, 21123, 536, 15, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107964, 21143, 174, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1108141, 21151, 37727, 646, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1145871, 21799, 955, 27, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1146829, 21828, 310, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147154, 21836, 231, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147388, 21843, 278, 9, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147691, 21856, 137, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147831, 21860, 284, 5, 44, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148130, 21868, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148344, 21876, 130, 2, 42, "Subsubsection",
   CellTags->{
    "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148477, 21880, 507, 12, 45, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149009, 21896, 772, 20, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149784, 21918, 10418, 175, 229, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1160205, 22095, 1029, 28, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161237, 22125, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161563, 22133, 199, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161765, 22139, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]},
 "PR6.2"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[1138, 37, 200, 4, 31, "Outline2",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[1341, 43, 527, 18, 66, "Outline3",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[10972, 340, 103, 1, 71, "Section",
   CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11078, 343, 647, 15, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11750, 362, 966, 23, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[12719, 387, 23284, 424, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36018, 814, 298, 10, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36319, 826, 356, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36700, 839, 898, 22, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[37601, 863, 10534, 201, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48150, 1067, 382, 11, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48535, 1080, 333, 6, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48871, 1088, 808, 27, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[49682, 1117, 218, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[49903, 1123, 159, 3, 31, "Text",
   CellTags->{"PR6.2", "Adjusting Graphics"}],
  Cell[50087, 1130, 111, 1, 46, "Subsection",
   CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50201, 1133, 397, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50601, 1144, 183, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50809, 1152, 1189, 35, 100, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[52001, 1189, 22255, 384, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74271, 1576, 307, 7, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74603, 1587, 962, 27, 52, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[75568, 1616, 24039, 424, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[99622, 2043, 602, 12, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[100227, 2057, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[100423, 2065, 149, 3, 46, "Subsection",
   CellTags->{
    "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
     "PR6.2.2"}],
  Cell[100575, 2070, 325, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[100903, 2081, 417, 7, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101323, 2090, 508, 15, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101834, 2107, 687, 19, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102524, 2128, 412, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102961, 2145, 162, 4, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[103126, 2151, 15926, 264, 408, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119067, 2418, 174, 4, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119244, 2424, 258, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119505, 2434, 263, 5, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119771, 2441, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[119967, 2449, 129, 2, 46, "Subsection",
   CellTags->{
    "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120099, 2453, 454, 13, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120556, 2468, 393, 12, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120974, 2484, 627, 19, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[121604, 2505, 9754, 169, 236, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131373, 2677, 154, 5, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131530, 2684, 689, 21, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132222, 2707, 482, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132729, 2724, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132873, 2729, 298, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133186, 2737, 352, 10, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133541, 2749, 119, 1, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133685, 2754, 146, 3, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133834, 2759, 19889, 299, 2417, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[153738, 3061, 412, 11, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154153, 3074, 293, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154449, 3084, 943, 28, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155417, 3116, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155561, 3121, 300, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155876, 3129, 374, 13, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[156253, 3144, 484, 16, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[156740, 3162, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}],
  Cell[156936, 3170, 189, 3, 46, "Subsection",
   CellTags->{
    "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
     "Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157128, 3175, 811, 19, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157942, 3196, 158, 2, 31, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[158125, 3202, 1580, 43, 160, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[159708, 3247, 45366, 736, 395, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[205089, 3986, 159, 3, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2"}]},
 "PR6.11"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[2789, 102, 213, 4, 31, "Outline2",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[3005, 108, 223, 4, 27, "Outline3",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[3253, 116, 229, 4, 27, "Outline3",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[3485, 122, 849, 27, 86, "Outline4",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[821338, 15932, 117, 1, 71, "Section",
   CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[821458, 15935, 556, 9, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822039, 15948, 170, 3, 46, "Subsection",
   CellTags->{
    "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
     "PR6.11.1", "PR6.11"}],
  Cell[822212, 15953, 322, 6, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822559, 15963, 189, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822751, 15970, 393, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823147, 15983, 458, 13, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823620, 15999, 217, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823862, 16008, 150, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824015, 16012, 555, 15, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824585, 16030, 322, 6, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824932, 16040, 191, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[825126, 16047, 397, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[825538, 16061, 165, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11"}],
  Cell[825740, 16069, 158, 3, 46, "Subsection",
   CellTags->{
    "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[825901, 16074, 263, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826189, 16083, 232, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826424, 16091, 69219, 1158, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[895646, 17251, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896264, 17270, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896590, 17278, 224, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896817, 17285, 434, 7, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897276, 17296, 141, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897420, 17300, 33705, 564, 449, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931128, 17866, 503, 14, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931634, 17882, 300, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931949, 17890, 207, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932159, 17896, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932361, 17903, 136, 2, 42, "Subsubsection",
   CellTags->{
    "Numbering Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932500, 17907, 505, 11, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933030, 17922, 262, 8, 100, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933295, 17932, 18574, 307, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[951872, 18241, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952490, 18260, 315, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952820, 18268, 255, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953078, 18275, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953292, 18283, 212, 4, 42, "Subsubsection",
   CellTags->{
    "Rayica's Default Treatment of Labels", "Labelling of Components", 
     "PR6.11", "PR6.11.2"}],
  Cell[953507, 18289, 470, 8, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[954002, 18301, 1094, 30, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[955099, 18333, 30175, 498, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[985277, 18833, 1388, 38, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986668, 18873, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986994, 18881, 237, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987234, 18888, 298, 7, 32, "Text",
   PageBreakAbove->True,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987557, 18899, 414, 11, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987974, 18912, 27016, 450, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1014993, 19364, 38716, 631, 251, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1053724, 19998, 343, 11, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054070, 20011, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054284, 20019, 173, 4, 42, "Subsubsection",
   PageBreakAbove->Automatic,
   CellTags->{
    "Placement of Your Labels", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1054460, 20025, 403, 11, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054888, 20040, 118, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1055009, 20044, 502, 8, 84, "Print",
   CellTags->{
    "Info3614713748-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1055548, 20057, 1224, 31, 84, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1056775, 20090, 2913, 56, 131, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1059703, 20149, 296, 9, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060002, 20160, 462, 14, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060467, 20176, 154, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060646, 20185, 115, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060764, 20189, 431, 7, 84, "Print",
   CellTags->{
    "Info3614713750-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1061210, 20199, 218, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061431, 20206, 220, 7, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061676, 20217, 138, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061817, 20221, 284, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062116, 20229, 202, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062343, 20238, 894, 23, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1063240, 20263, 2917, 56, 121, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066172, 20322, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066386, 20330, 134, 2, 42, "Subsubsection",
   CellTags->{
    "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  
  Cell[1066523, 20334, 971, 24, 65, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1067519, 20362, 1083, 28, 129, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1068605, 20392, 35798, 635, 327, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1104406, 21029, 1476, 42, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1105885, 21073, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106211, 21081, 248, 7, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106462, 21090, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106676, 21098, 128, 2, 42, "Subsubsection",
   CellTags->{
    "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106807, 21102, 368, 9, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107200, 21115, 188, 6, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107391, 21123, 536, 15, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107964, 21143, 174, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1108141, 21151, 37727, 646, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1145871, 21799, 955, 27, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1146829, 21828, 310, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147154, 21836, 231, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147388, 21843, 278, 9, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147691, 21856, 137, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147831, 21860, 284, 5, 44, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148130, 21868, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148344, 21876, 130, 2, 42, "Subsubsection",
   CellTags->{
    "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148477, 21880, 507, 12, 45, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149009, 21896, 772, 20, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149784, 21918, 10418, 175, 229, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1160205, 22095, 1029, 28, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161237, 22125, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161563, 22133, 199, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161765, 22139, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]},
 "PR6.1"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[4383, 155, 107, 2, 71, "Section",
   PageBreakAbove->True,
   CellTags->{"6.1", "6.1 Introduction", "PR6.1"}],
  Cell[4493, 159, 494, 8, 44, "Text",
   CellTags->{"6.1 Introduction", "PR6.1"}],
  Cell[4990, 169, 1587, 53, 62, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6602, 226, 176, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6781, 232, 2959, 61, 168, "Output",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[9755, 296, 1062, 35, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}]},
 "PR6.3"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[205297, 3995, 118, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"ShowText", "6.3", "PR6.3"}],
  Cell[205440, 4002, 84, 2, 35, "Input",
   CellTags->{"ShowText", "PR6.3"}],
  Cell[205527, 4006, 2182, 30, 311, "Print",
   CellTags->{"Info3614713735-8131145", "PR6.3", "ShowText"}],
  Cell[207746, 4041, 262, 8, 100, "Input",
   CellTags->{"ShowText", "PR6.3"}],
  Cell[208011, 4051, 14597, 259, 371, "Print",
   CellTags->{"ShowText", "PR6.3"}]},
 "PR6.4"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[222775, 4320, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.4", "ShowRange", "PR6.4"}],
  Cell[222898, 4325, 929, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[223830, 4359, 1273, 43, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225106, 4404, 750, 28, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225881, 4436, 405, 12, 133, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[226289, 4450, 36395, 632, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[262699, 5085, 532, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263256, 5105, 180, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263439, 5111, 34894, 578, 216, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[298348, 5692, 1062, 38, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}]},
 "PR6.5"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[299565, 5739, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.5", "ColorView", "PR6.5"}],
  Cell[299688, 5744, 969, 31, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[300660, 5777, 1248, 41, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[301911, 5820, 3620, 137, 74, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[305534, 5959, 815, 24, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[306352, 5985, 1047, 37, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[307402, 6024, 658, 20, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[308085, 6048, 264, 8, 100, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[308352, 6058, 13784, 235, 371, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[322151, 6296, 600, 14, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[322776, 6314, 269, 8, 100, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[323048, 6324, 13817, 235, 371, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[336880, 6562, 607, 19, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337512, 6585, 301, 9, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337816, 6596, 31736, 574, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[369567, 7173, 694, 24, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370286, 7201, 255, 8, 68, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370544, 7211, 3178, 60, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[373737, 7274, 265, 6, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374027, 7284, 200, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374230, 7290, 37563, 648, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[411830, 7943, 182, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[412015, 7949, 49192, 848, 236, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461222, 8800, 491, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461738, 8820, 242, 7, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461983, 8829, 16264, 278, 94, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478262, 9110, 470, 12, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478757, 9126, 289, 9, 117, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[479049, 9137, 21194, 381, 372, "Print",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[500280, 9523, 212, 7, 84, "Input",
   CellTags->{"ColorView", "PR6.5"}],
  Cell[500495, 9532, 9761, 189, 387, "Print",
   CellTags->{"ColorView", "PR6.5"}]},
 "PR6.6"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[510423, 9731, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.6", "RayChoice", "PR6.6"}],
  Cell[510546, 9736, 473, 14, 32, "Text",
   Evaluatable->False,
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[511044, 9754, 86, 2, 35, "Input",
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[511133, 9758, 479, 7, 84, "Print",
   CellTags->{"Info3614713740-8131145", "PR6.6", "RayChoice"}],
  Cell[511627, 9768, 608, 21, 73, "Text",
   Evaluatable->False,
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[512238, 9791, 228, 8, 32, "Text",
   CellTags->{"RayChoice", "PR6.6"}],
  Cell[512491, 9803, 418, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[512912, 9816, 26001, 447, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[538950, 10268, 241, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[539194, 10277, 4473, 101, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[543704, 10383, 391, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[544098, 10396, 11048, 193, 193, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}]},
 "PR6.7"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[555313, 10599, 142, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}],
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}]},
 "PR6.8"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[613749, 11841, 147, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}],
  Cell[613899, 11846, 847, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[614749, 11880, 1180, 39, 134, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[615932, 11921, 1197, 43, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[617132, 11966, 1028, 35, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}]},
 "PR6.10"->{
  Cell[579, 22, 381, 6, 71, "Subtitle",
   CellTags->{
    "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
     "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
     "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
     "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
     "PR6.8", "PR6.10"}],
  Cell[809847, 15497, 144, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}],
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[820958, 15917, 201, 5, 32, "Text",
   CellTags->{"ModelRayColor", "ColorView", "PR6.10"}]},
 "PR6.11.2"->{
  Cell[3253, 116, 229, 4, 27, "Outline3",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[3485, 122, 849, 27, 86, "Outline4",
   CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
  Cell[825740, 16069, 158, 3, 46, "Subsection",
   CellTags->{
    "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[825901, 16074, 263, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826189, 16083, 232, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[826424, 16091, 69219, 1158, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[895646, 17251, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896264, 17270, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896590, 17278, 224, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[896817, 17285, 434, 7, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897276, 17296, 141, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[897420, 17300, 33705, 564, 449, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931128, 17866, 503, 14, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931634, 17882, 300, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[931949, 17890, 207, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932159, 17896, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932361, 17903, 136, 2, 42, "Subsubsection",
   CellTags->{
    "Numbering Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[932500, 17907, 505, 11, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933030, 17922, 262, 8, 100, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[933295, 17932, 18574, 307, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[951872, 18241, 615, 17, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952490, 18260, 315, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[952820, 18268, 255, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953078, 18275, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[953292, 18283, 212, 4, 42, "Subsubsection",
   CellTags->{
    "Rayica's Default Treatment of Labels", "Labelling of Components", 
     "PR6.11", "PR6.11.2"}],
  Cell[953507, 18289, 470, 8, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[954002, 18301, 1094, 30, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[955099, 18333, 30175, 498, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[985277, 18833, 1388, 38, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986668, 18873, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[986994, 18881, 237, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987234, 18888, 298, 7, 32, "Text",
   PageBreakAbove->True,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987557, 18899, 414, 11, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[987974, 18912, 27016, 450, 137, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1014993, 19364, 38716, 631, 251, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1053724, 19998, 343, 11, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054070, 20011, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054284, 20019, 173, 4, 42, "Subsubsection",
   PageBreakAbove->Automatic,
   CellTags->{
    "Placement of Your Labels", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1054460, 20025, 403, 11, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1054888, 20040, 118, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1055009, 20044, 502, 8, 84, "Print",
   CellTags->{
    "Info3614713748-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1055548, 20057, 1224, 31, 84, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1056775, 20090, 2913, 56, 131, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1059703, 20149, 296, 9, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060002, 20160, 462, 14, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060467, 20176, 154, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060646, 20185, 115, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1060764, 20189, 431, 7, 84, "Print",
   CellTags->{
    "Info3614713750-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}],
  Cell[1061210, 20199, 218, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061431, 20206, 220, 7, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061676, 20217, 138, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1061817, 20221, 284, 5, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062116, 20229, 202, 5, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1062343, 20238, 894, 23, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1063240, 20263, 2917, 56, 121, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066172, 20322, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1066386, 20330, 134, 2, 42, "Subsubsection",
   CellTags->{
    "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  
  Cell[1066523, 20334, 971, 24, 65, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1067519, 20362, 1083, 28, 129, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1068605, 20392, 35798, 635, 327, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1104406, 21029, 1476, 42, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1105885, 21073, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106211, 21081, 248, 7, 38, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106462, 21090, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106676, 21098, 128, 2, 42, "Subsubsection",
   CellTags->{
    "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1106807, 21102, 368, 9, 32, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107200, 21115, 188, 6, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107391, 21123, 536, 15, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1107964, 21143, 174, 6, 68, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1108141, 21151, 37727, 646, 192, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1145871, 21799, 955, 27, 31, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1146829, 21828, 310, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147154, 21836, 231, 5, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147388, 21843, 278, 9, 32, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147691, 21856, 137, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1147831, 21860, 284, 5, 44, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148130, 21868, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148344, 21876, 130, 2, 42, "Subsubsection",
   CellTags->{
    "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1148477, 21880, 507, 12, 45, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149009, 21896, 772, 20, 83, "Input",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1149784, 21918, 10418, 175, 229, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1160205, 22095, 1029, 28, 47, "Print",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161237, 22125, 311, 5, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161563, 22133, 199, 4, 37, "Commentary",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
  Cell[1161765, 22139, 177, 3, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]},
 "6.1"->{
  Cell[4383, 155, 107, 2, 71, "Section",
   PageBreakAbove->True,
   CellTags->{"6.1", "6.1 Introduction", "PR6.1"}]},
 "component rendering"->{
  Cell[4990, 169, 1587, 53, 62, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6602, 226, 176, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6781, 232, 2959, 61, 168, "Output",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[9755, 296, 1062, 35, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[222898, 4325, 929, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[223830, 4359, 1273, 43, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225106, 4404, 750, 28, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225881, 4436, 405, 12, 133, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[226289, 4450, 36395, 632, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[262699, 5085, 532, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263256, 5105, 180, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263439, 5111, 34894, 578, 216, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[298348, 5692, 1062, 38, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[299688, 5744, 969, 31, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[300660, 5777, 1248, 41, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[301911, 5820, 3620, 137, 74, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[305534, 5959, 815, 24, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[306352, 5985, 1047, 37, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[307402, 6024, 658, 20, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[322151, 6296, 600, 14, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[336880, 6562, 607, 19, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337512, 6585, 301, 9, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337816, 6596, 31736, 574, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[369567, 7173, 694, 24, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370286, 7201, 255, 8, 68, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370544, 7211, 3178, 60, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[373737, 7274, 265, 6, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374027, 7284, 200, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374230, 7290, 37563, 648, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[411830, 7943, 182, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[412015, 7949, 49192, 848, 236, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461222, 8800, 491, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461738, 8820, 242, 7, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461983, 8829, 16264, 278, 94, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478262, 9110, 470, 12, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[512491, 9803, 418, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[512912, 9816, 26001, 447, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[538950, 10268, 241, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[539194, 10277, 4473, 101, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[543704, 10383, 391, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[544098, 10396, 11048, 193, 193, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613899, 11846, 847, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[614749, 11880, 1180, 39, 134, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[615932, 11921, 1197, 43, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[617132, 11966, 1028, 35, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "rendering options"->{
  Cell[4990, 169, 1587, 53, 62, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6602, 226, 176, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[6781, 232, 2959, 61, 168, "Output",
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[9755, 296, 1062, 35, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
  
  Cell[222898, 4325, 929, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[223830, 4359, 1273, 43, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225106, 4404, 750, 28, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[225881, 4436, 405, 12, 133, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[226289, 4450, 36395, 632, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[262699, 5085, 532, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263256, 5105, 180, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[263439, 5111, 34894, 578, 216, "Print",
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[298348, 5692, 1062, 38, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ShowRange", "PR6.4"}],
  Cell[299688, 5744, 969, 31, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[300660, 5777, 1248, 41, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[301911, 5820, 3620, 137, 74, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[305534, 5959, 815, 24, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[306352, 5985, 1047, 37, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[307402, 6024, 658, 20, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[322151, 6296, 600, 14, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[336880, 6562, 607, 19, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337512, 6585, 301, 9, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[337816, 6596, 31736, 574, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[369567, 7173, 694, 24, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370286, 7201, 255, 8, 68, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[370544, 7211, 3178, 60, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[373737, 7274, 265, 6, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374027, 7284, 200, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[374230, 7290, 37563, 648, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[411830, 7943, 182, 4, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[412015, 7949, 49192, 848, 236, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461222, 8800, 491, 16, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461738, 8820, 242, 7, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[461983, 8829, 16264, 278, 94, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[478262, 9110, 470, 12, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "ColorView", "PR6.5"}],
  Cell[512491, 9803, 418, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[512912, 9816, 26001, 447, 127, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[538950, 10268, 241, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[539194, 10277, 4473, 101, 376, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[543704, 10383, 391, 11, 84, "Input",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[544098, 10396, 11048, 193, 193, "Print",
   CellTags->{
    "component rendering", "rendering options", "ColorView", "RayChoice", 
     "PR6.6"}],
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613899, 11846, 847, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[614749, 11880, 1180, 39, 134, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[615932, 11921, 1197, 43, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[617132, 11966, 1028, 35, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "6.2"->{
  Cell[10972, 340, 103, 1, 71, "Section",
   CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}]},
 "PR6.2.0"->{
  Cell[10972, 340, 103, 1, 71, "Section",
   CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11078, 343, 647, 15, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[11750, 362, 966, 23, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[12719, 387, 23284, 424, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36018, 814, 298, 10, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36319, 826, 356, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[36700, 839, 898, 22, 132, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[37601, 863, 10534, 201, 376, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48150, 1067, 382, 11, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48535, 1080, 333, 6, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[48871, 1088, 808, 27, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
  Cell[49682, 1117, 218, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}]},
 "6.2.1"->{
  Cell[50087, 1130, 111, 1, 46, "Subsection",
   CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}]},
 "PR6.2.1"->{
  Cell[50087, 1130, 111, 1, 46, "Subsection",
   CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50201, 1133, 397, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50601, 1144, 183, 4, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[50809, 1152, 1189, 35, 100, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[52001, 1189, 22255, 384, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74271, 1576, 307, 7, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[74603, 1587, 962, 27, 52, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[75568, 1616, 24039, 424, 370, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
  Cell[99622, 2043, 602, 12, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}]},
 "6.2.2"->{
  Cell[100423, 2065, 149, 3, 46, "Subsection",
   CellTags->{
    "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
     "PR6.2.2"}]},
 "Manual Graphics Control"->{
  Cell[100423, 2065, 149, 3, 46, "Subsection",
   CellTags->{
    "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
     "PR6.2.2"}]},
 "PR6.2.2"->{
  Cell[100423, 2065, 149, 3, 46, "Subsection",
   CellTags->{
    "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
     "PR6.2.2"}],
  Cell[100575, 2070, 325, 9, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[100903, 2081, 417, 7, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101323, 2090, 508, 15, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[101834, 2107, 687, 19, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102524, 2128, 412, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[102961, 2145, 162, 4, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[103126, 2151, 15926, 264, 408, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119067, 2418, 174, 4, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119244, 2424, 258, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
  Cell[119505, 2434, 263, 5, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}]},
 "6.2.3"->{
  Cell[119967, 2449, 129, 2, 46, "Subsection",
   CellTags->{
    "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}]},
 "Custom Graphics"->{
  Cell[119967, 2449, 129, 2, 46, "Subsection",
   CellTags->{
    "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}]},
 "PR6.2.3"->{
  Cell[119967, 2449, 129, 2, 46, "Subsection",
   CellTags->{
    "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120099, 2453, 454, 13, 44, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120556, 2468, 393, 12, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[120974, 2484, 627, 19, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[121604, 2505, 9754, 169, 236, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131373, 2677, 154, 5, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[131530, 2684, 689, 21, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132222, 2707, 482, 13, 45, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132729, 2724, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[132873, 2729, 298, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133186, 2737, 352, 10, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133541, 2749, 119, 1, 31, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133685, 2754, 146, 3, 36, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[133834, 2759, 19889, 299, 2417, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[153738, 3061, 412, 11, 46, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154153, 3074, 293, 8, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[154449, 3084, 943, 28, 84, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155417, 3116, 141, 3, 35, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155561, 3121, 300, 5, 35, "Output",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[155876, 3129, 374, 13, 38, "Commentary",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
  Cell[156253, 3144, 484, 16, 32, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}]},
 "6.2.4"->{
  Cell[156936, 3170, 189, 3, 46, "Subsection",
   CellTags->{
    "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
     "Adjusting Graphics", "PR6.2", "PR6.2.4"}]},
 "Interactive 3D Graphics and Stereo Graphics"->{
  Cell[156936, 3170, 189, 3, 46, "Subsection",
   CellTags->{
    "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
     "Adjusting Graphics", "PR6.2", "PR6.2.4"}]},
 "PR6.2.4"->{
  Cell[156936, 3170, 189, 3, 46, "Subsection",
   CellTags->{
    "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
     "Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157128, 3175, 811, 19, 59, "Text",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[157942, 3196, 158, 2, 31, "Text",
   PageBreakAbove->Automatic,
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[158125, 3202, 1580, 43, 160, "Input",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
  Cell[159708, 3247, 45366, 736, 395, "Print",
   CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}]},
 "6.3"->{
  Cell[205297, 3995, 118, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"ShowText", "6.3", "PR6.3"}]},
 "Info3614713735-8131145"->{
  Cell[205527, 4006, 2182, 30, 311, "Print",
   CellTags->{"Info3614713735-8131145", "PR6.3", "ShowText"}]},
 "6.4"->{
  Cell[222775, 4320, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.4", "ShowRange", "PR6.4"}]},
 "6.5"->{
  Cell[299565, 5739, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.5", "ColorView", "PR6.5"}]},
 "6.6"->{
  Cell[510423, 9731, 120, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.6", "RayChoice", "PR6.6"}]},
 "Info3614713740-8131145"->{
  Cell[511133, 9758, 479, 7, 84, "Print",
   CellTags->{"Info3614713740-8131145", "PR6.6", "RayChoice"}]},
 "6.7"->{
  Cell[555313, 10599, 142, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}]},
 "StandardGraphics"->{
  Cell[555313, 10599, 142, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}],
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}]},
 "OpticalSystem option"->{
  Cell[555458, 10604, 1276, 45, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[556737, 10651, 1297, 44, 94, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[558037, 10697, 2429, 91, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560491, 10792, 360, 11, 100, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[560854, 10805, 11836, 203, 262, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[572693, 11010, 406, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[573114, 11021, 1208, 40, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574347, 11065, 229, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[574579, 11075, 14673, 246, 349, "Print",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589255, 11323, 411, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[589681, 11334, 1030, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[590736, 11377, 313, 9, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591052, 11388, 407, 8, 35, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[591474, 11399, 1127, 39, 45, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592626, 11442, 232, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[592861, 11449, 4066, 76, 237, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[596942, 11528, 532, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597499, 11550, 224, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[597726, 11557, 15562, 264, 266, "Output",
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}],
  Cell[613303, 11824, 291, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "OutputType", 
     "StandardGraphics", "OpticalSystem option", "PR6.7"}]},
 "6.8"->{
  Cell[613749, 11841, 147, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}]},
 "FillStyle"->{
  Cell[613749, 11841, 147, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}],
  Cell[613899, 11846, 847, 32, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[614749, 11880, 1180, 39, 134, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[615932, 11921, 1197, 43, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[617132, 11966, 1028, 35, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8"}],
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}]},
 "ColorComponents"->{
  Cell[618185, 12005, 326, 8, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[618514, 12015, 18343, 307, 325, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[636872, 12325, 331, 8, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "LineStyle", "FillStyle", 
     "PR6.8", "ColorComponents"}],
  Cell[637228, 12337, 305, 7, 52, "Input",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}],
  Cell[637536, 12346, 24715, 408, 381, "Print",
   CellTags->{
    "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
     "rendering options", "FillStyle"}]},
 "6.9"->{
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}]},
 "CrossRendering"->{
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "SurfaceRendering"->{
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "EdgeRendering"->{
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "PR6.9"->{
  Cell[662418, 12764, 210, 5, 71, "Section",
   Evaluatable->False,
   CellTags->{
    "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
     "EdgeRendering", "PR6.9"}],
  Cell[662631, 12771, 1285, 44, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[663941, 12819, 181, 4, 35, "Input",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
  Cell[664125, 12825, 2561, 60, 131, "Output",
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
  Cell[666701, 12888, 622, 18, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[668132, 12935, 2461, 98, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}],
  Cell[673358, 13124, 203, 8, 38, "Commentary",
   CellTags->{"Other Rendering Options", "PR6.9"}],
  Cell[673564, 13134, 1118, 33, 49, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[674685, 13169, 708, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675418, 13196, 263, 5, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[675684, 13203, 12620, 210, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688341, 13418, 294, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[688638, 13427, 53195, 863, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[741870, 14295, 295, 7, 35, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[742168, 14304, 50833, 827, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793016, 15134, 283, 7, 31, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[793302, 15143, 1106, 39, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794433, 15186, 294, 8, 52, "Input",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[794730, 15196, 12701, 212, 449, "Print",
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
  Cell[807446, 15411, 2246, 77, 63, "Text",
   Evaluatable->False,
   CellTags->{
    "component rendering", "rendering options", "CrossRendering", 
     "SurfaceRendering", "EdgeRendering", "Other Rendering Options", 
     "PR6.9"}]},
 "Component"->{
  Cell[663941, 12819, 181, 4, 35, "Input",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
  Cell[664125, 12825, 2561, 60, 131, "Output",
   CellTags->{"Component", "Other Rendering Options", "PR6.9"}]},
 "GraphicDesign"->{
  Cell[667326, 12908, 803, 25, 91, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "GraphicDesign", 
     "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}]},
 "Empty"->{
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}]},
 "Fill"->{
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}]},
 "Mesh"->{
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}]},
 "Trace"->{
  Cell[670596, 13035, 2759, 87, 116, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
     "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
     "Other Rendering Options", "PR6.9"}]},
 "6.10"->{
  Cell[809847, 15497, 144, 3, 71, "Section",
   Evaluatable->False,
   CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}]},
 "user defined models"->{
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}]},
 "Hue"->{
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}]},
 "GrayLevel"->{
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}]},
 "RGBColor"->{
  Cell[809994, 15502, 639, 23, 32, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[810636, 15527, 3538, 126, 104, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[814177, 15655, 2969, 123, 46, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}],
  Cell[817149, 15780, 3806, 135, 90, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
     "ColorView", "PR6.10"}]},
 "6.11"->{
  Cell[821338, 15932, 117, 1, 71, "Section",
   CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}]},
 "PR6.11.1"->{
  Cell[821338, 15932, 117, 1, 71, "Section",
   CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[821458, 15935, 556, 9, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822039, 15948, 170, 3, 46, "Subsection",
   CellTags->{
    "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
     "PR6.11.1", "PR6.11"}],
  Cell[822212, 15953, 322, 6, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822559, 15963, 189, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[822751, 15970, 393, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823147, 15983, 458, 13, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823620, 15999, 217, 5, 31, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[823862, 16008, 150, 2, 35, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824015, 16012, 555, 15, 35, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824585, 16030, 322, 6, 44, "Text",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[824932, 16040, 191, 5, 52, "Input",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
  Cell[825126, 16047, 397, 11, 34, "Output",
   CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}]},
 "6.11.1"->{
  Cell[822039, 15948, 170, 3, 46, "Subsection",
   CellTags->{
    "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
     "PR6.11.1", "PR6.11"}]},
 "Labelling Your Printed Output"->{
  Cell[822039, 15948, 170, 3, 46, "Subsection",
   CellTags->{
    "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
     "PR6.11.1", "PR6.11"}]},
 "6.11.2"->{
  Cell[825740, 16069, 158, 3, 46, "Subsection",
   CellTags->{
    "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Labelling Your Graphics"->{
  Cell[825740, 16069, 158, 3, 46, "Subsection",
   CellTags->{
    "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Numbering Your Labels"->{
  Cell[932361, 17903, 136, 2, 42, "Subsubsection",
   CellTags->{
    "Numbering Your Labels", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Rayica's Default Treatment of Labels"->{
  Cell[953292, 18283, 212, 4, 42, "Subsubsection",
   CellTags->{
    "Rayica's Default Treatment of Labels", "Labelling of Components", 
     "PR6.11", "PR6.11.2"}]},
 "Placement of Your Labels"->{
  Cell[1054284, 20019, 173, 4, 42, "Subsubsection",
   PageBreakAbove->Automatic,
   CellTags->{
    "Placement of Your Labels", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Info3614713748-8131145"->{
  Cell[1055009, 20044, 502, 8, 84, "Print",
   CellTags->{
    "Info3614713748-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Info3614713750-8131145"->{
  Cell[1060764, 20189, 431, 7, 84, "Print",
   CellTags->{
    "Info3614713750-8131145", "Labelling of Components", "PR6.11", 
     "PR6.11.2"}]},
 "Labels with Resonate"->{
  Cell[1066386, 20330, 134, 2, 42, "Subsubsection",
   CellTags->{
    "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}]},
 "The Labels Option"->{
  Cell[1106676, 21098, 128, 2, 42, "Subsubsection",
   CellTags->{
    "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}]},
 "Surpressing Labels"->{
  Cell[1148344, 21876, 130, 2, 42, "Subsubsection",
   CellTags->{
    "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"chapter 6 topics", 1162392, 22162},
 {"6.1 Introduction", 1162804, 22170},
 {"Adjusting Graphics", 1164012, 22200},
 {"ShowText", 1171091, 22344},
 {"ShowRange", 1171957, 22363},
 {"ColorView", 1173791, 22407},
 {"RayChoice", 1180129, 22565},
 {"OutputType", 1182025, 22612},
 {"LineStyle", 1186425, 22712},
 {"Other Rendering Options", 1188561, 22765},
 {"ModelRayColor", 1193583, 22872},
 {"Labelling of Components", 1195018, 22906},
 {"PR6.2", 1207079, 23139},
 {"PR6.11", 1214156, 23283},
 {"PR6.1", 1226217, 23516},
 {"PR6.3", 1227412, 23546},
 {"PR6.4", 1228274, 23565},
 {"PR6.5", 1230104, 23609},
 {"PR6.6", 1234445, 23715},
 {"PR6.7", 1236336, 23762},
 {"PR6.8", 1240732, 23862},
 {"PR6.10", 1242851, 23915},
 {"PR6.11.2", 1244271, 23949},
 {"6.1", 1254180, 24141},
 {"component rendering", 1254325, 24145},
 {"rendering options", 1269858, 24518},
 {"6.2", 1285377, 24891},
 {"PR6.2.0", 1285499, 24894},
 {"6.2.1", 1286724, 24919},
 {"PR6.2.1", 1286852, 24922},
 {"6.2.2", 1287781, 24941},
 {"Manual Graphics Control", 1287964, 24946},
 {"PR6.2.2", 1288131, 24951},
 {"6.2.3", 1289303, 24976},
 {"Custom Graphics", 1289464, 24980},
 {"PR6.2.3", 1289617, 24984},
 {"6.2.4", 1291793, 25028},
 {"Interactive 3D Graphics and Stereo Graphics", 1292016, 25033},
 {"PR6.2.4", 1292203, 25038},
 {"6.3", 1292823, 25052},
 {"Info3614713735-8131145", 1292964, 25056},
 {"6.4", 1293083, 25059},
 {"6.5", 1293206, 25063},
 {"6.6", 1293329, 25067},
 {"Info3614713740-8131145", 1293471, 25071},
 {"6.7", 1293588, 25074},
 {"StandardGraphics", 1293746, 25078},
 {"OpticalSystem option", 1297769, 25171},
 {"6.8", 1301641, 25261},
 {"FillStyle", 1301784, 25265},
 {"ColorComponents", 1303524, 25311},
 {"6.9", 1304407, 25333},
 {"CrossRendering", 1304622, 25339},
 {"SurfaceRendering", 1308908, 25432},
 {"EdgeRendering", 1313191, 25525},
 {"PR6.9", 1317466, 25618},
 {"Component", 1322096, 25718},
 {"GraphicDesign", 1322368, 25724},
 {"Empty", 1322659, 25732},
 {"Fill", 1322968, 25740},
 {"Mesh", 1323277, 25748},
 {"Trace", 1323587, 25756},
 {"6.10", 1323896, 25764},
 {"user defined models", 1324055, 25768},
 {"Hue", 1324852, 25790},
 {"GrayLevel", 1325655, 25812},
 {"RGBColor", 1326457, 25834},
 {"6.11", 1327255, 25856},
 {"PR6.11.1", 1327389, 25859},
 {"6.11.1", 1328880, 25888},
 {"Labelling Your Printed Output", 1329084, 25893},
 {"6.11.2", 1329265, 25898},
 {"Labelling Your Graphics", 1329457, 25903},
 {"Numbering Your Labels", 1329647, 25908},
 {"Rayica's Default Treatment of Labels", 1329843, 25913},
 {"Placement of Your Labels", 1330042, 25918},
 {"Info3614713748-8131145", 1330258, 25924},
 {"Info3614713750-8131145", 1330434, 25929},
 {"Labels with Resonate", 1330608, 25934},
 {"The Labels Option", 1330779, 25938},
 {"Surpressing Labels", 1330948, 25942}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 381, 6, 71, "Subtitle",
 CellTags->{
  "chapter 6 topics", "6.1 Introduction", "Adjusting Graphics", "ShowText", 
   "ShowRange", "ColorView", "RayChoice", "OutputType", "LineStyle", 
   "Other Rendering Options", "ModelRayColor", "Labelling of Components", 
   "PR6.2", "PR6.11", "PR6.1", "PR6.3", "PR6.4", "PR6.5", "PR6.6", "PR6.7", 
   "PR6.8", "PR6.10"}],
Cell[963, 30, 150, 3, 20, "Outline2"],
Cell[CellGroupData[{
Cell[1138, 37, 200, 4, 31, "Outline2",
 CellTags->{"Adjusting Graphics", "PR6.2"}],
Cell[1341, 43, 527, 18, 66, "Outline3",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],
Cell[1883, 64, 881, 34, 139, "Outline2"],
Cell[CellGroupData[{
Cell[2789, 102, 213, 4, 31, "Outline2",
 CellTags->{"Labelling of Components", "PR6.11"}],
Cell[3005, 108, 223, 4, 27, "Outline3",
 CellTags->{"Labelling of Components", "PR6.11"}],
Cell[CellGroupData[{
Cell[3253, 116, 229, 4, 27, "Outline3",
 CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}],
Cell[3485, 122, 849, 27, 86, "Outline4",
 CellTags->{"Labelling of Components", "PR6.11.2", "PR6.11"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4383, 155, 107, 2, 71, "Section",
 PageBreakAbove->True,
 CellTags->{"6.1", "6.1 Introduction", "PR6.1"}],
Cell[4493, 159, 494, 8, 44, "Text",
 CellTags->{"6.1 Introduction", "PR6.1"}],
Cell[4990, 169, 1587, 53, 62, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
Cell[CellGroupData[{
Cell[6602, 226, 176, 4, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
Cell[6781, 232, 2959, 61, 168, "Output",
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}]
}, Open  ]],
Cell[9755, 296, 1062, 35, 45, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "6.1 Introduction", "PR6.1"}],
Cell[10820, 333, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10972, 340, 103, 1, 71, "Section",
 CellTags->{"6.2", "Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[11078, 343, 647, 15, 59, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[CellGroupData[{
Cell[11750, 362, 966, 23, 132, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[12719, 387, 23284, 424, 376, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}]
}, Open  ]],
Cell[36018, 814, 298, 10, 38, "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[36319, 826, 356, 9, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[CellGroupData[{
Cell[36700, 839, 898, 22, 132, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[37601, 863, 10534, 201, 376, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}]
}, Open  ]],
Cell[48150, 1067, 382, 11, 38, "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[48535, 1080, 333, 6, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[48871, 1088, 808, 27, 59, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[49682, 1117, 218, 4, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.0"}],
Cell[49903, 1123, 159, 3, 31, "Text",
 CellTags->{"PR6.2", "Adjusting Graphics"}],
Cell[CellGroupData[{
Cell[50087, 1130, 111, 1, 46, "Subsection",
 CellTags->{"6.2.1", "Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[50201, 1133, 397, 9, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[50601, 1144, 183, 4, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[CellGroupData[{
Cell[50809, 1152, 1189, 35, 100, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[52001, 1189, 22255, 384, 370, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}]
}, Open  ]],
Cell[74271, 1576, 307, 7, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[CellGroupData[{
Cell[74603, 1587, 962, 27, 52, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[75568, 1616, 24039, 424, 370, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}]
}, Open  ]],
Cell[99622, 2043, 602, 12, 45, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.1"}],
Cell[100227, 2057, 159, 3, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[100423, 2065, 149, 3, 46, "Subsection",
 CellTags->{
  "6.2.2", "Manual Graphics Control", "Adjusting Graphics", "PR6.2", 
   "PR6.2.2"}],
Cell[100575, 2070, 325, 9, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[100903, 2081, 417, 7, 44, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[101323, 2090, 508, 15, 45, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[101834, 2107, 687, 19, 84, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[102524, 2128, 412, 13, 45, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[CellGroupData[{
Cell[102961, 2145, 162, 4, 36, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[103126, 2151, 15926, 264, 408, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}]
}, Open  ]],
Cell[119067, 2418, 174, 4, 38, "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[119244, 2424, 258, 8, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[119505, 2434, 263, 5, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.2"}],
Cell[119771, 2441, 159, 3, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[119967, 2449, 129, 2, 46, "Subsection",
 CellTags->{
  "6.2.3", "Custom Graphics", "Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[120099, 2453, 454, 13, 44, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[120556, 2468, 393, 12, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[CellGroupData[{
Cell[120974, 2484, 627, 19, 36, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[121604, 2505, 9754, 169, 236, "Output",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}]
}, Open  ]],
Cell[131373, 2677, 154, 5, 38, "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[131530, 2684, 689, 21, 46, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[132222, 2707, 482, 13, 45, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[CellGroupData[{
Cell[132729, 2724, 141, 3, 35, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[132873, 2729, 298, 5, 35, "Output",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}]
}, Open  ]],
Cell[133186, 2737, 352, 10, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[133541, 2749, 119, 1, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[CellGroupData[{
Cell[133685, 2754, 146, 3, 36, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[133834, 2759, 19889, 299, 2417, "Output",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}]
}, Open  ]],
Cell[153738, 3061, 412, 11, 46, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[154153, 3074, 293, 8, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[154449, 3084, 943, 28, 84, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[CellGroupData[{
Cell[155417, 3116, 141, 3, 35, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[155561, 3121, 300, 5, 35, "Output",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}]
}, Open  ]],
Cell[155876, 3129, 374, 13, 38, "Commentary",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[156253, 3144, 484, 16, 32, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.3"}],
Cell[156740, 3162, 159, 3, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[156936, 3170, 189, 3, 46, "Subsection",
 CellTags->{
  "6.2.4", "Interactive 3D Graphics and Stereo Graphics", 
   "Adjusting Graphics", "PR6.2", "PR6.2.4"}],
Cell[157128, 3175, 811, 19, 59, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
Cell[157942, 3196, 158, 2, 31, "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
Cell[CellGroupData[{
Cell[158125, 3202, 1580, 43, 160, "Input",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}],
Cell[159708, 3247, 45366, 736, 395, "Print",
 CellTags->{"Adjusting Graphics", "PR6.2", "PR6.2.4"}]
}, Open  ]],
Cell[205089, 3986, 159, 3, 31, "Text",
 CellTags->{"Adjusting Graphics", "PR6.2"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[205297, 3995, 118, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"ShowText", "6.3", "PR6.3"}],
Cell[CellGroupData[{
Cell[205440, 4002, 84, 2, 35, "Input",
 CellTags->{"ShowText", "PR6.3"}],
Cell[205527, 4006, 2182, 30, 311, "Print",
 CellTags->{"Info3614713735-8131145", "PR6.3", "ShowText"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[207746, 4041, 262, 8, 100, "Input",
 CellTags->{"ShowText", "PR6.3"}],
Cell[208011, 4051, 14597, 259, 371, "Print",
 CellTags->{"ShowText", "PR6.3"}]
}, Open  ]],
Cell[222623, 4313, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222775, 4320, 120, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.4", "ShowRange", "PR6.4"}],
Cell[222898, 4325, 929, 32, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[223830, 4359, 1273, 43, 91, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[225106, 4404, 750, 28, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[CellGroupData[{
Cell[225881, 4436, 405, 12, 133, "Input",
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[226289, 4450, 36395, 632, 449, "Print",
 CellTags->{
  "component rendering", "rendering options", "ShowRange", "PR6.4"}]
}, Open  ]],
Cell[262699, 5085, 532, 16, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[CellGroupData[{
Cell[263256, 5105, 180, 4, 35, "Input",
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[263439, 5111, 34894, 578, 216, "Print",
 CellTags->{
  "component rendering", "rendering options", "ShowRange", "PR6.4"}]
}, Open  ]],
Cell[298348, 5692, 1062, 38, 46, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ShowRange", "PR6.4"}],
Cell[299413, 5732, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299565, 5739, 120, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.5", "ColorView", "PR6.5"}],
Cell[299688, 5744, 969, 31, 46, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[300660, 5777, 1248, 41, 91, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[301911, 5820, 3620, 137, 74, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[305534, 5959, 815, 24, 45, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[306352, 5985, 1047, 37, 45, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[307402, 6024, 658, 20, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[308085, 6048, 264, 8, 100, "Input",
 CellTags->{"ColorView", "PR6.5"}],
Cell[308352, 6058, 13784, 235, 371, "Print",
 CellTags->{"ColorView", "PR6.5"}]
}, Open  ]],
Cell[322151, 6296, 600, 14, 45, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[322776, 6314, 269, 8, 100, "Input",
 CellTags->{"ColorView", "PR6.5"}],
Cell[323048, 6324, 13817, 235, 371, "Print",
 CellTags->{"ColorView", "PR6.5"}]
}, Open  ]],
Cell[336880, 6562, 607, 19, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[337512, 6585, 301, 9, 84, "Input",
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[337816, 6596, 31736, 574, 127, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "PR6.5"}]
}, Open  ]],
Cell[369567, 7173, 694, 24, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[370286, 7201, 255, 8, 68, "Input",
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[370544, 7211, 3178, 60, 376, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "PR6.5"}]
}, Open  ]],
Cell[373737, 7274, 265, 6, 31, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[374027, 7284, 200, 4, 35, "Input",
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[374230, 7290, 37563, 648, 127, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "PR6.5"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[411830, 7943, 182, 4, 35, "Input",
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[412015, 7949, 49192, 848, 236, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "PR6.5"}]
}, Open  ]],
Cell[461222, 8800, 491, 16, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[461738, 8820, 242, 7, 52, "Input",
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[461983, 8829, 16264, 278, 94, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "PR6.5"}]
}, Open  ]],
Cell[478262, 9110, 470, 12, 32, "Text",
 Evaluatable->False,
 CellTags->{"component rendering", "rendering options", "ColorView", "PR6.5"}],
Cell[CellGroupData[{
Cell[478757, 9126, 289, 9, 117, "Input",
 CellTags->{"ColorView", "PR6.5"}],
Cell[479049, 9137, 21194, 381, 372, "Print",
 CellTags->{"ColorView", "PR6.5"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[500280, 9523, 212, 7, 84, "Input",
 CellTags->{"ColorView", "PR6.5"}],
Cell[500495, 9532, 9761, 189, 387, "Print",
 CellTags->{"ColorView", "PR6.5"}]
}, Open  ]],
Cell[510271, 9724, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510423, 9731, 120, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.6", "RayChoice", "PR6.6"}],
Cell[510546, 9736, 473, 14, 32, "Text",
 Evaluatable->False,
 CellTags->{"RayChoice", "PR6.6"}],
Cell[CellGroupData[{
Cell[511044, 9754, 86, 2, 35, "Input",
 CellTags->{"RayChoice", "PR6.6"}],
Cell[511133, 9758, 479, 7, 84, "Print",
 CellTags->{"Info3614713740-8131145", "PR6.6", "RayChoice"}]
}, Open  ]],
Cell[511627, 9768, 608, 21, 73, "Text",
 Evaluatable->False,
 CellTags->{"RayChoice", "PR6.6"}],
Cell[512238, 9791, 228, 8, 32, "Text",
 CellTags->{"RayChoice", "PR6.6"}],
Cell[CellGroupData[{
Cell[512491, 9803, 418, 11, 84, "Input",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}],
Cell[512912, 9816, 26001, 447, 127, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[538950, 10268, 241, 7, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}],
Cell[539194, 10277, 4473, 101, 376, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[543704, 10383, 391, 11, 84, "Input",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}],
Cell[544098, 10396, 11048, 193, 193, "Print",
 CellTags->{
  "component rendering", "rendering options", "ColorView", "RayChoice", 
   "PR6.6"}]
}, Open  ]],
Cell[555161, 10592, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555313, 10599, 142, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.7", "OutputType", "StandardGraphics", "PR6.7"}],
Cell[555458, 10604, 1276, 45, 49, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[556737, 10651, 1297, 44, 94, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[558037, 10697, 2429, 91, 63, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[CellGroupData[{
Cell[560491, 10792, 360, 11, 100, "Input",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[560854, 10805, 11836, 203, 262, "Print",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[572693, 11010, 406, 8, 35, "Output",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}]
}, Open  ]],
Cell[573114, 11021, 1208, 40, 46, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[CellGroupData[{
Cell[574347, 11065, 229, 8, 52, "Input",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[574579, 11075, 14673, 246, 349, "Print",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[589255, 11323, 411, 8, 35, "Output",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}]
}, Open  ]],
Cell[589681, 11334, 1030, 39, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[CellGroupData[{
Cell[590736, 11377, 313, 9, 52, "Input",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[591052, 11388, 407, 8, 35, "Output",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}]
}, Open  ]],
Cell[591474, 11399, 1127, 39, 45, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[CellGroupData[{
Cell[592626, 11442, 232, 5, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[592861, 11449, 4066, 76, 237, "Output",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}]
}, Open  ]],
Cell[596942, 11528, 532, 18, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[CellGroupData[{
Cell[597499, 11550, 224, 5, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[597726, 11557, 15562, 264, 266, "Output",
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}]
}, Open  ]],
Cell[613303, 11824, 291, 8, 31, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "OutputType", 
   "StandardGraphics", "OpticalSystem option", "PR6.7"}],
Cell[613597, 11834, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613749, 11841, 147, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.8", "LineStyle", "FillStyle", "PR6.8"}],
Cell[613899, 11846, 847, 32, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],
Cell[614749, 11880, 1180, 39, 134, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],
Cell[615932, 11921, 1197, 43, 54, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],
Cell[617132, 11966, 1028, 35, 49, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8"}],
Cell[CellGroupData[{
Cell[618185, 12005, 326, 8, 52, "Input",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"}],
Cell[618514, 12015, 18343, 307, 325, "Print",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"}]
}, Open  ]],
Cell[636872, 12325, 331, 8, 31, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "LineStyle", "FillStyle", 
   "PR6.8", "ColorComponents"}],
Cell[CellGroupData[{
Cell[637228, 12337, 305, 7, 52, "Input",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"}],
Cell[637536, 12346, 24715, 408, 381, "Print",
 CellTags->{
  "ColorComponents", "LineStyle", "PR6.8", "component rendering", 
   "rendering options", "FillStyle"}]
}, Open  ]],
Cell[662266, 12757, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662418, 12764, 210, 5, 71, "Section",
 Evaluatable->False,
 CellTags->{
  "6.9", "Other Rendering Options", "CrossRendering", "SurfaceRendering", 
   "EdgeRendering", "PR6.9"}],
Cell[662631, 12771, 1285, 44, 46, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[CellGroupData[{
Cell[663941, 12819, 181, 4, 35, "Input",
 PageBreakWithin->Automatic,
 CellTags->{"Component", "Other Rendering Options", "PR6.9"}],
Cell[664125, 12825, 2561, 60, 131, "Output",
 CellTags->{"Component", "Other Rendering Options", "PR6.9"}]
}, Open  ]],
Cell[666701, 12888, 622, 18, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[667326, 12908, 803, 25, 91, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "component rendering", "rendering options", "GraphicDesign", 
   "CrossRendering", "SurfaceRendering", "EdgeRendering", 
   "Other Rendering Options", "PR6.9"}],
Cell[668132, 12935, 2461, 98, 46, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[670596, 13035, 2759, 87, 116, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "component rendering", "rendering options", "Empty", "Fill", "Mesh", 
   "Trace", "CrossRendering", "SurfaceRendering", "EdgeRendering", 
   "Other Rendering Options", "PR6.9"}],
Cell[673358, 13124, 203, 8, 38, "Commentary",
 CellTags->{"Other Rendering Options", "PR6.9"}],
Cell[673564, 13134, 1118, 33, 49, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[674685, 13169, 708, 23, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[CellGroupData[{
Cell[675418, 13196, 263, 5, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[675684, 13203, 12620, 210, 449, "Print",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[688341, 13418, 294, 7, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[688638, 13427, 53195, 863, 449, "Print",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[741870, 14295, 295, 7, 35, "Input",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[742168, 14304, 50833, 827, 449, "Print",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}]
}, Open  ]],
Cell[793016, 15134, 283, 7, 31, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[793302, 15143, 1106, 39, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[CellGroupData[{
Cell[794433, 15186, 294, 8, 52, "Input",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[794730, 15196, 12701, 212, 449, "Print",
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}]
}, Open  ]],
Cell[807446, 15411, 2246, 77, 63, "Text",
 Evaluatable->False,
 CellTags->{
  "component rendering", "rendering options", "CrossRendering", 
   "SurfaceRendering", "EdgeRendering", "Other Rendering Options", "PR6.9"}],
Cell[809695, 15490, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[809847, 15497, 144, 3, 71, "Section",
 Evaluatable->False,
 CellTags->{"6.10", "ModelRayColor", "ColorView", "PR6.10"}],
Cell[809994, 15502, 639, 23, 32, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],
Cell[810636, 15527, 3538, 126, 104, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],
Cell[814177, 15655, 2969, 123, 46, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],
Cell[817149, 15780, 3806, 135, 90, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelRayColor", "Hue", "GrayLevel", "RGBColor", 
   "ColorView", "PR6.10"}],
Cell[820958, 15917, 201, 5, 32, "Text",
 CellTags->{"ModelRayColor", "ColorView", "PR6.10"}],
Cell[821162, 15924, 139, 3, 31, "Text",
 CellTags->"ColorView"]
}, Open  ]],
Cell[CellGroupData[{
Cell[821338, 15932, 117, 1, 71, "Section",
 CellTags->{"6.11", "Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[821458, 15935, 556, 9, 44, "Text",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[CellGroupData[{
Cell[822039, 15948, 170, 3, 46, "Subsection",
 CellTags->{
  "6.11.1", "Labelling Your Printed Output", "Labelling of Components", 
   "PR6.11.1", "PR6.11"}],
Cell[822212, 15953, 322, 6, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[CellGroupData[{
Cell[822559, 15963, 189, 5, 52, "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[822751, 15970, 393, 11, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[823147, 15983, 458, 13, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}]
}, Open  ]],
Cell[823620, 15999, 217, 5, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[CellGroupData[{
Cell[823862, 16008, 150, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[824015, 16012, 555, 15, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}]
}, Open  ]],
Cell[824585, 16030, 322, 6, 44, "Text",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[CellGroupData[{
Cell[824932, 16040, 191, 5, 52, "Input",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}],
Cell[825126, 16047, 397, 11, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11.1", "PR6.11"}]
}, Open  ]],
Cell[825538, 16061, 165, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[825740, 16069, 158, 3, 46, "Subsection",
 CellTags->{
  "6.11.2", "Labelling Your Graphics", "Labelling of Components", "PR6.11", 
   "PR6.11.2"}],
Cell[825901, 16074, 263, 5, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[826189, 16083, 232, 6, 68, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[826424, 16091, 69219, 1158, 192, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[895646, 17251, 615, 17, 31, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[896264, 17270, 311, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[896590, 17278, 224, 5, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[896817, 17285, 434, 7, 44, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[897276, 17296, 141, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[897420, 17300, 33705, 564, 449, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[931128, 17866, 503, 14, 31, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[931634, 17882, 300, 5, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[931949, 17890, 207, 4, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[932159, 17896, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[932361, 17903, 136, 2, 42, "Subsubsection",
 CellTags->{
  "Numbering Your Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[932500, 17907, 505, 11, 44, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[933030, 17922, 262, 8, 100, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[933295, 17932, 18574, 307, 192, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[951872, 18241, 615, 17, 31, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[952490, 18260, 315, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[952820, 18268, 255, 5, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[953078, 18275, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[953292, 18283, 212, 4, 42, "Subsubsection",
 CellTags->{
  "Rayica's Default Treatment of Labels", "Labelling of Components", "PR6.11",
    "PR6.11.2"}],
Cell[953507, 18289, 470, 8, 44, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[954002, 18301, 1094, 30, 68, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[955099, 18333, 30175, 498, 137, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[985277, 18833, 1388, 38, 47, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[986668, 18873, 311, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[986994, 18881, 237, 5, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[987234, 18888, 298, 7, 32, "Text",
 PageBreakAbove->True,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[987557, 18899, 414, 11, 52, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[987974, 18912, 27016, 450, 137, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1014993, 19364, 38716, 631, 251, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1053724, 19998, 343, 11, 38, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1054070, 20011, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1054284, 20019, 173, 4, 42, "Subsubsection",
 PageBreakAbove->Automatic,
 CellTags->{
  "Placement of Your Labels", "Labelling of Components", "PR6.11", 
   "PR6.11.2"}],
Cell[1054460, 20025, 403, 11, 32, "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1054888, 20040, 118, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1055009, 20044, 502, 8, 84, "Print",
 CellTags->{
  "Info3614713748-8131145", "Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1055548, 20057, 1224, 31, 84, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1056775, 20090, 2913, 56, 131, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1059703, 20149, 296, 9, 38, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1060002, 20160, 462, 14, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1060467, 20176, 154, 5, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1060646, 20185, 115, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1060764, 20189, 431, 7, 84, "Print",
 CellTags->{
  "Info3614713750-8131145", "Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1061210, 20199, 218, 5, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1061431, 20206, 220, 7, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1061676, 20217, 138, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1061817, 20221, 284, 5, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1062116, 20229, 202, 5, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1062343, 20238, 894, 23, 83, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1063240, 20263, 2917, 56, 121, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1066172, 20322, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1066386, 20330, 134, 2, 42, "Subsubsection",
 CellTags->{
  "Labels with Resonate", "Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1066523, 20334, 971, 24, 65, "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1067519, 20362, 1083, 28, 129, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1068605, 20392, 35798, 635, 327, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1104406, 21029, 1476, 42, 47, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1105885, 21073, 311, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1106211, 21081, 248, 7, 38, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1106462, 21090, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1106676, 21098, 128, 2, 42, "Subsubsection",
 CellTags->{
  "The Labels Option", "Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1106807, 21102, 368, 9, 32, "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1107200, 21115, 188, 6, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1107391, 21123, 536, 15, 34, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1107964, 21143, 174, 6, 68, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1108141, 21151, 37727, 646, 192, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1145871, 21799, 955, 27, 31, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1146829, 21828, 310, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1147154, 21836, 231, 5, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1147388, 21843, 278, 9, 32, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1147691, 21856, 137, 2, 35, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1147831, 21860, 284, 5, 44, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1148130, 21868, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1148344, 21876, 130, 2, 42, "Subsubsection",
 CellTags->{
  "Surpressing Labels", "Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1148477, 21880, 507, 12, 45, "Text",
 PageBreakAbove->Automatic,
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[CellGroupData[{
Cell[1149009, 21896, 772, 20, 83, "Input",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1149784, 21918, 10418, 175, 229, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1160205, 22095, 1029, 28, 47, "Print",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1161237, 22125, 311, 5, 35, "Output",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]],
Cell[1161563, 22133, 199, 4, 37, "Commentary",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}],
Cell[1161765, 22139, 177, 3, 31, "Text",
 CellTags->{"Labelling of Components", "PR6.11", "PR6.11.2"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
