(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1524214,      63178]*)
(*NotebookOutlinePosition[   1524892,      63201]*)
(*  CellTagsIndexPosition[   1524848,      63197]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["AbbeVNumber", "Subsection"],

Cell[TextData[{
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  " is a rule name that specifies the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number, Vd ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (nd",
  StyleBox["-",
    FontWeight->"Bold"],
  "1) ",
  StyleBox["/",
    FontWeight->"Bold"],
  " (nf",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc",
  ")",
  ", and is a measure of the chromatic aberration of an optical material.\n\
\[InvisibleSpace]Here, nf, nd, and nc are the refractive index values for \
three different wavelengths specified by the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option. See also: ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ABCDMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["ABCDMatrix[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", {{",
    FontWeight->"Bold"],
  StyleBox["M1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["M2",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["M3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["M4",
    FontSlant->"Italic"],
  StyleBox["}}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that produces scattered rays according to the \
ABCD matrix law.\n\[InvisibleSpace]",
  StyleBox["ABCDMatrix",
    FontWeight->"Bold"],
  " is also a rule that specifies ABCD",
  StyleBox["-",
    FontWeight->"Bold"],
  "matrix data.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["ExitPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ThinLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ThickLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ABCDOptic",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ABCDOptic", "Subsection"],

Cell[TextData[{
  StyleBox["ABCDOptic[",
    FontWeight->"Bold"],
  StyleBox["abcdmatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced planar component that scatters rays using the ",
  StyleBox["abcdmatrix",
    FontSlant->"Italic"],
  " specified with an entrance plane and an exit plane separated by the \
indicated ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter specifies either a number or a surface function of two \
variables. ",
  StyleBox["ABCDOptic",
    FontWeight->"Bold"],
  " is intended for simple two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing procedures. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ABCDMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ThinLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ThickLens",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbsoluteSizeComponentOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["AbsoluteSizeComponentOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  ", that determines the absolute length of lines. ",
  StyleBox["SizeComponentOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeComponentOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbsoluteSizeRayOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["AbsoluteSizeRayOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  " that determines the absolute length of lines. ",
  StyleBox["SizeRayOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeRayOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbsoluteSizeSurfaceOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["AbsoluteSizeSurfaceOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  " that determines the absolute length of lines. ",
  StyleBox["SizeSurfaceOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeSurfaceOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbsoluteStepSize", "Subsection"],

Cell[TextData[{
  StyleBox["AbsoluteStepSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["increment",
    FontSlant->"Italic"],
  StyleBox["/Automatic",
    FontWeight->"Bold"],
  " gives the absolute rate of ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " used to step through numeric solutions.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["AbsoluteStepSize",
    FontWeight->"Bold"],
  " works in tandom with ",
  StyleBox["StepSize",
    FontWeight->"Bold"],
  ". ",
  StyleBox["AbsoluteStepSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " indicates that the relative ",
  StyleBox["StepSize",
    FontWeight->"Bold"],
  " will be used instead. See also",
  ":",
  " ",
  StyleBox["StepSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Absorption", "Subsection"],

Cell[TextData[{
  StyleBox["Absorption[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that creates a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function to absorb the intensity of rays hitting the optical \
surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acetone", "Subsection"],

Cell[TextData[{
  StyleBox["Acetone",
    FontWeight->"Bold"],
  " specifies the use of an acetone liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Acetone",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .43 microns to .66 microns. \
",
  StyleBox["Acetone",
    FontWeight->"Bold"],
  " has a density of 0.791, relative to the density of water",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AcidResistance", "Subsection"],

Cell[TextData[{
  StyleBox["AcidResistance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the acid resistance of a \
material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ActiveComponent", "Subsection"],

Cell[TextData[{
  StyleBox["ActiveComponent",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option that designates whether the component contains active \
surfaces where rays can interact.\n\[InvisibleSpace]",
  StyleBox["ActiveComponent",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is used when constructing inactive components made up of only graphical \
information. ",
  StyleBox["ActiveComponent",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ActiveRegion", "Subsection"],

Cell[TextData[{
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " functions that determines which side of the optical surface shall be \
modeled for approaching rays by ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]For single surfaces, ",
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " or 0 is active on both sides of the surface. ",
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1 specifies rays approaching the surface from the negative optical axis, \
while ",
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 1 indicates rays approaching from the positive optical axis.\n\
\[InvisibleSpace]For double surfaces, ",
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " or 0 specifies the region between the two surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ActiveScattering", "Subsection"],

Cell[TextData[{
  StyleBox["ActiveScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic/True/False",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " that indicates whether seed",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattering sources are dynamically refreshed during the trace.\n\
\[InvisibleSpace]",
  StyleBox["ActiveScattering",
    FontWeight->"Bold"],
  " has an important effect on randomized seed sources, which use ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/Stratified",
    FontWeight->"Bold"],
  ", since each scatter site will display an identical scattering behavior \
with ",
  StyleBox["ActiveScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ActiveScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["True",
    FontWeight->"Bold"],
  " setting with the ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/Stratified",
    FontWeight->"Bold"],
  " seed",
  StyleBox["-",
    FontWeight->"Bold"],
  "source settings and ",
  StyleBox["False",
    FontWeight->"Bold"],
  " otherwise. An additional option, ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", can be used to conserve memory during ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations by inhibiting ",
  StyleBox["ActiveScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Add", "Subsection"],

Cell[TextData[{
  StyleBox["Add",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["newobjects",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that inserts new components and rays within an existing system.\n\
\[InvisibleSpace]",
  StyleBox["Add",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the final location of the inserted objects. A second \
coordinate point is used to indicate the previous element of the optical \
system. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Add",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddDeflection", "Subsection"],

Cell[TextData[{
  StyleBox["AddDeflection[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used to append elements to ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["buildingblockname",
    FontSlant->"Italic"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " creates ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " with ",
  StyleBox["buildingblockname",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " for every ",
  StyleBox["buildingblockname",
    FontSlant->"Italic"],
  " element. These deflections are appended to those inside ",
  StyleBox["component",
    FontSlant->"Italic"],
  ", but not connected to any of the surfaces. ",
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  " passes ",
  StyleBox["options",
    FontSlant->"Italic"],
  " and ",
  StyleBox["component",
    FontSlant->"Italic"],
  " as list of rules to genetic.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InsertDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RemoveDeflection",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RemoveSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddLabels", "Subsection"],

Cell[TextData[{
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["listoflabels",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["listofpositions",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that adds one or more labels to the system rendering.\n\
\[InvisibleSpace]",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  " uses two lists to indicate the label names and label positions. See \
also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddRandomRayTilt", "Subsection"],

Cell[TextData[{
  StyleBox["AddRandomRayTilt[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", {{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that introduces a random factor to the tilt \
direction of each propagated ray.\n\[InvisibleSpace]Here, the ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " parameters specify the angular ranges of the ray tilt fluctuations along \
the horizontal and vertical directions. When the random behavior is symmetric \
about the surface normal, then the single",
  StyleBox["-",
    FontWeight->"Bold"],
  "valued full",
  StyleBox["-",
    FontWeight->"Bold"],
  "angles x and y can be specified in place of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". When the random factor is non",
  StyleBox["-",
    FontWeight->"Bold"],
  "isotropic and only varies in x, then the y parameters can be omitted. \
Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " option is also used by ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ". For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddSurface", "Subsection"],

Cell[TextData[{
  StyleBox["AddSurface[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block used to insert surfaces between existing \
ones.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The new surfaces are not related to a deflection and they are not an \
entrance surface, but they are inserted in ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ". ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " controls the insertion place, ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " between which surfaces to insert. Allowed values in (the list) ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " are between 0 and 1, describing the fraction of the distance between \
adjacent surfaces. Alternatively a surface can be directly specified. ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " can be a list of numbers or a word ",
  StyleBox["value",
    FontSlant->"Italic"],
  " (except slot specifications",
  ")",
  ". ",
  StyleBox["SimpleSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " tries to generate simple shapes for the new surfaces. ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " passes ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["InsertDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RemoveDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SortSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SimpleSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RemoveSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddSurfaceRoughness", "Subsection"],

Cell[TextData[{
  StyleBox["AddSurfaceRoughness[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", {{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block that introduces a random factor to the \
surface normals of one or more optical surfaces in the ",
  StyleBox["component",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]Here, the ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " parameters specify the angular ranges of the tilt fluctuations along the \
horizontal and vertical directions. When the random behavior is symmetric \
about the surface normal, then the single",
  StyleBox["-",
    FontWeight->"Bold"],
  "valued full",
  StyleBox["-",
    FontWeight->"Bold"],
  "angles x and y can be specified in place of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". When the surface roughness is non",
  StyleBox["-",
    FontWeight->"Bold"],
  "isotropic and only varies in x, then the y parameters can be omitted. \
Three examples of this are",
  ":",
  " 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["AddSurfaceRoughness",
    FontWeight->"Bold"],
  " inserts a ",
  StyleBox["Random",
    FontWeight->"Bold"],
  " function within the ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AffectedSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that specifies which surfaces of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " are to be affected by a newly introduced ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function.\n\[InvisibleSpace]",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " carries a list of numbers and word values that denotes the surfaces \
inheriting a new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait. As an example, ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  "1",
  StyleBox["}",
    FontWeight->"Bold"],
  " specifies that the first surface function slotted in ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " is to inherit the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait.\n\[InvisibleSpace]If a list element of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " is a list, it specifies a pathnumber, pathslot and deflectionslot inside \
",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ". The new deflection is inserted in the list of ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " at position deflectionslot, but only in pathslot slot of pathnumber path \
of ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ". This type of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " is used for example to put a grating on a refractive surface.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Air", "Subsection"],

Cell[TextData[{
  StyleBox["Air",
    FontWeight->"Bold"],
  " denotes the use of an air medium with a refractive index of 1.00027 at \
the 0.5876 micron wavelength. The refractive index data were calculated for a \
temperature of 20 degrees Celsius, a pressure of 100 kPa, 50% air humidity, \
and 450 ppm of carbon dioxide. The refractive index model for ",
  StyleBox["Air",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of 0.3 microns to 1.7 microns. \
The data for this ",
  StyleBox["Air",
    FontWeight->"Bold"],
  " model was provided by Dr. ir. Hedser van Brug",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Align", "Subsection"],

Cell[TextData[{
  StyleBox["Align",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that automatically aligns the components and rays along an optical axis. \
The axis is three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional and defined by the closest neighboring objects, or two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional and defined as points.\n\[InvisibleSpace]",
  StyleBox["Align",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the start point of the axis, the objects getting aligned, and \
the end point of the axis. An optional point before the last one specifies \
the position along the axis. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["Align",
    FontWeight->"Bold"],
  " does essentially the same as ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", but it uses another order of coordinate points.\n\[InvisibleSpace]See \
also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AlkaliResistance", "Subsection"],

Cell[TextData[{
  StyleBox["AlkaliResistance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the alkali resistance of a \
material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllCreatedAmplitudes", "Subsection"],

Cell[TextData[{
  StyleBox["AllCreatedAmplitudes",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["ax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ay",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["az",
    FontSlant->"Italic"],
  StyleBox["},",
    FontWeight->"Bold"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is used within ",
  StyleBox["HeldDeflectionKernel",
    FontWeight->"Bold"],
  " functions to specify new electric",
  StyleBox["-",
    FontWeight->"Bold"],
  "field vectors of one or more outgoing rays.\n\[InvisibleSpace]In general, \
",
  StyleBox["ax",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ay",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["az",
    FontSlant->"Italic"],
  " are complex numbers that indicate absolute field directions.  ",
  StyleBox["AllCreatedAmplitudes",
    FontWeight->"Bold"],
  " is generated by some ",
  StyleBox["HeldDeflectionKernel",
    FontWeight->"Bold"],
  " functions to specify electric",
  StyleBox["-",
    FontWeight->"Bold"],
  "field information. ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " later converts the reported ",
  StyleBox["AllCreatedAmplitudes",
    FontWeight->"Bold"],
  " into ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " for storage in ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllCreatedRays", "Subsection"],

Cell[TextData[{
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and specifies that all ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects returned by previous ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function calculations are passed to or returned from ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " is listed by ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " is included as an input to the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function calculation. If ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " is listed by ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", then the elements of ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " replace the previous ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]Currently, only ",
  StyleBox["Transmission",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " are designed to use ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllDeflections", "Subsection"],

Cell[TextData[{
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " that denotes that the added genetic ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function slot number is interlaced throughout the listing of ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " values.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllowZeroRayLength", "Subsection"],

Cell[TextData[{
  StyleBox["AllowZeroRayLength",
    FontWeight->"Bold"],
  " is an unauthorized rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that specifies whether the ray segment is permitted to have a zero length \
during a surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersection calculation.\n\[InvisibleSpace]",
  StyleBox["AllowZeroRayLength",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["True",
    FontWeight->"Bold"],
  " when the ray is crossing between two distinct optical surfaces. ",
  StyleBox["AllowZeroRayLength",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  " during a repeated surface interaction. ",
  StyleBox["AllowZeroRayLength",
    FontWeight->"Bold"],
  " is only created when ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " is invoked. See also",
  ":",
  " ",
  StyleBox["RayHistory",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that specifies that the added ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function slot number is appended to all ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " values.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnalyzeSystem", "Subsection"],

Cell[TextData[{
  StyleBox["AnalyzeSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements defined by a mixed list of ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, traces the rays through the components, and renders the results \
according to the ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["AnalyzeSystem",
    FontWeight->"Bold"],
  " is an alias name for ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ". See also ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnamorphicPrisms", "Subsection"],

Cell[TextData[{
  StyleBox["AnamorphicPrisms[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bigedgethickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["firstangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prismspacing",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["secondangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitoffset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " specifies a pair of wedge",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped prism elements that are commonly used to correct the asymmetric \
beam shape of a laser diode",
  StyleBox["-",
    FontWeight->"Bold"],
  " from elliptical to near circular in shape.\n\[InvisibleSpace]",
  StyleBox["AnamorphicPrisms",
    FontWeight->"Bold"],
  " is created with the first prism surface positioned at the origin with a \
tilt given by ",
  StyleBox["firstangle",
    FontSlant->"Italic"],
  " and the second prism located offset along the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis with the lateral offset given by ",
  StyleBox["exitoffset",
    FontSlant->"Italic"],
  " and tilted by ",
  StyleBox["secondangle",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The ",
  StyleBox["bigedgethickness",
    FontSlant->"Italic"],
  " specifies the thickness of the larger prism edge. The ",
  StyleBox["firstangle",
    FontSlant->"Italic"],
  " and ",
  StyleBox["secondangle",
    FontSlant->"Italic"],
  " parameters denote the amount of tilt in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane given to the first and second prism elements. The ",
  StyleBox["prismspacing",
    FontSlant->"Italic"],
  " argument gives the gap between the two prism elements. Finally, the ",
  StyleBox["exitoffset",
    FontSlant->"Italic"],
  " parameter indicates the distance between the last prism",
  StyleBox["'",
    FontWeight->"Bold"],
  "s exit surface center and the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis (incoming optical axis). The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AngleTolerance", "Subsection"],

Cell[TextData[{
  StyleBox["AngleTolerance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the manufacturing angular \
tolerances of an optical component expressed in units of ",
  StyleBox["+-",
    FontWeight->"Bold"],
  " seconds of arc. See also",
  ":",
  " ",
  StyleBox["ThicknessTolerance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DimensionalTolerance",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Anisotropic", "Subsection"],

Cell[TextData[{
  StyleBox["Anisotropic",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " to characterize an anisotropic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AntireflectionCoating", "Subsection"],

Cell[TextData[{
  StyleBox["AntireflectionCoating",
    FontWeight->"Bold"],
  " is part of the pattern ",
  StyleBox["ModelCoating[AntireflectionCoating, ",
    FontWeight->"Bold"],
  StyleBox["substrate",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["reflectivity",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " that is used to define a coating which reflects on every ",
  StyleBox["substrate",
    FontSlant->"Italic"],
  " ",
  StyleBox["reflectivity",
    FontSlant->"Italic"],
  " percent",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ApertureQ", "Subsection"],

Cell[TextData[{
  StyleBox["ApertureQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a valid aperture specification for an optical element. The result is \
",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ApertureStop", "Subsection"],

Cell[TextData[{
  StyleBox["ApertureStop[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ApertureStop[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a planar component with a hole created in its middle.\n\
\[InvisibleSpace]",
  StyleBox["ApertureStop",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " and ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " arguments may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AppendGraphics", "Subsection"],

Cell[TextData[{
  StyleBox["AppendGraphics",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["primitiveslist",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that gives a list of ",
  "graphics",
  " to be rendered after those of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["PrependGraphics",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arrange", "Subsection"],

Cell[TextData[{
  StyleBox["Arrange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that rearranges the ordering of components and rays in the optical \
system.\n\[InvisibleSpace]",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to specify a new sequence order for the selected objects. Normally, the \
first coordinate point indicates the point of insertion to the list of \
objects. If the first coordinate corresponds to an empty point in space then \
the listed objects will be inserted at the beginning of the optical system \
sequence. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AsphericLens", "Subsection"],

Cell[TextData[{
  StyleBox["AsphericLens[{",
    FontWeight->"Bold"],
  StyleBox["curvature1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conic1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["insideaperture1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["curvature2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conic2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced lens both having aspherical surfaces.\n\[InvisibleSpace]The \
centerline curvature, conicconstant, and aspheric polynomialcoefficients for \
an aspheric lens prescription are all required. An optional specification for \
an insideaperture to each surface may also be given. ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order term. Otherwise, both even and \
odd power terms will be used. ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. (Inspired by William Cottingame, \
UCLA.)\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AsphericLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["AsphericLensSurface[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens component that has an aspheric shape.\n\
\[InvisibleSpace]The centerline ",
  StyleBox["curvature",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  " for an aspheric lens prescription are all required. Optional \
specifications for , the aspheric ",
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  " and ",
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  " to the surface may also be given. ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order. Otherwise, both even and odd \
power terms will be used. ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. (Inspired by William Cottingame, \
UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AsphericMirror", "Subsection"],

Cell[TextData[{
  StyleBox["AsphericMirror[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AsphericMirror[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a mirror component that has an aspheric reflective shape.\n\
\[InvisibleSpace]The centerline ",
  StyleBox["curvature",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  " for an aspheric mirror prescription are all required. Optional \
specifications for the aspheric ",
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  " and ",
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  " to the surface may also be given. The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates the mirror on a flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "backed substrate. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order. Otherwise, both even and odd \
power terms will be used. (Inspired by Dave Whiteman, NASA.)\n\
\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AssignRay", "Subsection"],

Cell[TextData[{
  StyleBox["AssignRay",
    FontWeight->"Bold"],
  " is a placeholder inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that designate an assignment of ray values in a ",
  StyleBox["Map",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AttenuationIndex", "Subsection"],

Cell[TextData[{
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the imaginary part of the refractive index divided by the real \
part for the ray segment in the local environment. The effective refractive \
index for Snells law is defined by ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " ",
  StyleBox["+",
    FontWeight->"Bold"],
  " ",
  StyleBox["I*AttenuationIndex",
    FontWeight->"Bold"],
  ". ",
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to calculate its value. In the case of a birefringent material, the value \
is a 3x3 tensor with components relative to the coordinate system passed as \
variable to the function ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AttenuationIndexFunction", "Subsection"],

Cell[TextData[{
  StyleBox["AttenuationIndexFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that designates the functions for the attenuation indices on both sides \
of a surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AuthorizeNewOptions", "Subsection"],

Cell[TextData[{
  StyleBox["AuthorizeNewOptions[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["optionlabels",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used for adding new ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " option labels that are authorized to be carried within ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects across multiple ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface generations.\n\[InvisibleSpace]",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " parameters created by ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions that are not listed in ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " or included in the ",
  StyleBox["NewAuthorizedOptions",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object parameter are removed after the following surface encounter. \
Contents of ",
  StyleBox["optionlabels",
    FontSlant->"Italic"],
  " are added to ",
  StyleBox["NewAuthorizedOptions",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Note that ",
  StyleBox["AuthorizeNewOptions",
    FontWeight->"Bold"],
  " is only used in ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", which limits its usefulness in the present ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " version."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Back", "Subsection"],

Cell[TextData[{
  StyleBox["Back",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["CurvatureDirection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BackFacetDiameter", "Subsection"],

Cell[TextData[{
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that denotes the diameter of the back half",
  StyleBox["-",
    FontWeight->"Bold"],
  "facets (below the girdle",
  ")",
  " as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter.\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BackFocalLength", "Subsection"],

Cell[TextData[{
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  " indicates the distance between the ",
  StyleBox["FocalPoint",
    FontWeight->"Bold"],
  " position and the chief center of the last optical surface.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Baffle", "Subsection"],

Cell[TextData[{
  StyleBox["Baffle[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Baffle[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a planar, component having only absorbing sides.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Baffle",
    FontWeight->"Bold"],
  " is created centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Baffled", "Subsection"],

Cell[TextData[{
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " is an option of some built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in component functions that specifies whether there are absorbing surfaces \
present.\n\[InvisibleSpace]Normally, ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " indicates that the effected surfaces are made as absorbers and ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " indicates that the effected surfaces are refractive surfaces. ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is also used to specify each absorbing surface by the surface number",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BaffleSpan", "Subsection"],

Cell[TextData[{
  StyleBox["BaffleSpan[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BaffleSpan[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is similar to ",
  StyleBox["Baffle",
    FontWeight->"Bold"],
  " except that its size and placement are specified by the two two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinates ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["BaffleSpan",
    FontWeight->"Bold"],
  " spans the specified coordinates in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y",
  StyleBox["-",
    FontWeight->"Bold"],
  "plane and has the specified ",
  StyleBox["height",
    FontSlant->"Italic"],
  " in z",
  StyleBox["-",
    FontWeight->"Bold"],
  "direction.. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BaffleWithHole", "Subsection"],

Cell[TextData[{
  StyleBox["BaffleWithHole[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BaffleWithHole[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a planar component with a hole created in its middle.\n\
\[InvisibleSpace]",
  StyleBox["BaffleWithHole",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " and ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " arguments may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BaK1", "Subsection"],

Cell[TextData[{
  StyleBox["BaK1",
    FontWeight->"Bold"],
  " specifies the use of the ",
  StyleBox["BaK1",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["BaK1",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BalanceIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["BalanceIntensity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of some angular ray sources that adjusts the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " value of the rays.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "However, ",
  StyleBox["BalanceIntensity",
    FontWeight->"Bold"],
  " is presently only used with ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " source functions. In particular, for ",
  StyleBox["BalanceIntensity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and non",
  StyleBox["-",
    FontWeight->"Bold"],
  "zero ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " settings, the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " value of each ray is adjusted to maintain a uniform wavefront intensity \
across angular space. In addition, with regards to ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BalanceIntensity",
    FontWeight->"Bold"],
  " only works for rectangular (and not circular",
  ")",
  " lighting patterns.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BalancePhaseFront", "Subsection"],

Cell[TextData[{
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of most ray sources that controls the starting point of the \
rays.\n\[InvisibleSpace]For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the starting point of each ray is adjusted to maintain a uniform \
transverse phasefront for the light source. This is particularly important in \
wavefront calculations, where uniform transverse phasefronts are required. ",
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  " works closely with the ",
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " and ",
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BallBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["BallBaffle[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an entire spherical absorbing surface.\n\[InvisibleSpace]",
  StyleBox["BallBaffle",
    FontWeight->"Bold"],
  " is created with its center at the origin of the coordinate system. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BallLens", "Subsection"],

Cell[TextData[{
  StyleBox["BallLens[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an entire spherical refractive component.\n\[InvisibleSpace]With \
the option setting ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BallLens",
    FontWeight->"Bold"],
  " is created with its center of mass at the coordinate origin. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BallLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BallMirror", "Subsection"],

Cell[TextData[{
  StyleBox["BallMirror[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an entire spherical mirror.\n\[InvisibleSpace]With the option \
setting ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BallMirror",
    FontWeight->"Bold"],
  " is created with its center of mass at the coordinate origin. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BallMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Base", "Subsection"],

Cell[TextData[{
  StyleBox["Base",
    FontWeight->"Bold"],
  " is a value that indicates the base surface of an optical component",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamCurvature", "Subsection"],

Cell[TextData[{
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the radius of phase curvature in a particular transverse \
plane for a Gaussian beam.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamDivergence", "Subsection"],

Cell[TextData[{
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  " is an rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that specifies the far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field full angle of divergence (in radians",
  ")",
  " of a Gaussian beam.\n\[InvisibleSpace]See also: ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamScaleLength", "Subsection"],

Cell[TextData[{
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that is directly related to the beam waist spot size and is the axial \
scale length given for the particular Gaussian beam waist.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["BeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a planar component that has a partially reflective",
  StyleBox["/",
    FontWeight->"Bold"],
  "transmissive side with a ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " specified and a refractive side.\n\[InvisibleSpace]",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " is created with its splitting surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamSplitterCube", "Subsection"],

Cell[TextData[{
  StyleBox["BeamSplitterCube[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a solid cube beam splitter that has a partially reflective",
  StyleBox["/",
    FontWeight->"Bold"],
  "refractive surface across its diagonal.\n\[InvisibleSpace]",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " is created with one face centered about the origin and the opposite face \
positioned down the positive x axis. The ",
  StyleBox["side",
    FontSlant->"Italic"],
  " parameter specifies the edge dimension of a cube. ",
  StyleBox["Baffled->True",
    FontWeight->"Bold"],
  " is used to create absorbing surfaces at the top of the bottom of the \
cube. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeBeamSplitter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConjugateBeamSplitter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamSpotSize", "Subsection"],

Cell[TextData[{
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the Gaussian beam radius (at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of its amplitude peak",
  ")",
  " in a particular transverse plane.\n\[InvisibleSpace]See also: ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BeamWaist", "Subsection"],

Cell[TextData[{
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the minimum radius size (at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of its amplitude peak",
  ")",
  " at the waist position of a particular Gaussian beam.\n\
\[InvisibleSpace]See also: ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BiConcaveCylindricalLens", "Subsection"],

Cell[TextData[{
  StyleBox["BiConcaveCylindricalLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a lens with two equally concave cylindrical surfaces.\n\
\[InvisibleSpace]",
  StyleBox["BiConcaveCylindricalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BiConcaveLens", "Subsection"],

Cell[TextData[{
  StyleBox["BiConcaveLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a lens with two equally concave spherical surfaces.\n\
\[InvisibleSpace]",
  StyleBox["BiConcaveLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BiConvexCylindricalLens", "Subsection"],

Cell[TextData[{
  StyleBox["BiConvexCylindricalLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens with two equally convex cylindrical surfaces.\n\
\[InvisibleSpace]",
  StyleBox["BiConvexCylindricalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BiConvexLens", "Subsection"],

Cell[TextData[{
  StyleBox["BiConvexLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens with two equally convex spherical surfaces.\n\
\[InvisibleSpace]",
  StyleBox["BiConvexLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BirefringentLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["BirefringentLensSurface[",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a planar component that models the index boundary between a \
birefringent",
  StyleBox["-",
    FontWeight->"Bold"],
  "refractive material and an isotropic",
  StyleBox["-",
    FontWeight->"Bold"],
  "refractive material.\n\[InvisibleSpace]",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " component types to create a complete optical element such as a prism. ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " to designate the type of birefringent optical material with the alignment \
axis of materialO given by ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  ". Otherwise, ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["isotropicmedium",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specifies the interface with an isotropic material other than the default \
",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " setting. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["CustomBirefringentLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BirthPoint", "Subsection"],

Cell[TextData[{
  StyleBox["BirthPoint->",
    FontWeight->"Bold"],
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " is an option of ray sources that gives the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional spatial ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " of the light source. ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " yields an on",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis source at the origin. ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " option to specify whether its arguments shall be given in rectangular ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " (",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["CartesianCoordinates",
    FontWeight->"Bold"],
  ") or spherical ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " (",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["PolarCoordinates",
    FontWeight->"Bold"],
  ")",
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["SymbolicBirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BalanceIntensity",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BK7", "Subsection"],

Cell[TextData[{
  StyleBox["BK7",
    FontWeight->"Bold"],
  " indicates the use of the ",
  StyleBox["BK7",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["BK7",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary", "Subsection"],

Cell[TextData[{
  StyleBox["Boundary[",
    FontWeight->"Bold"],
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a rectangular box that absorbs rays intercepted by its walls.\n\
\[InvisibleSpace] Here, the user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. There are four methods for specifying ",
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  ": ",
  StyleBox["Boundary[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z2",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " uses the coordinates of top and bottom opposite corners of a rectangular \
box, ",
  StyleBox["Boundary[",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a cube boundary, ",
  StyleBox["Boundary[",
    FontWeight->"Bold"],
  StyleBox["xside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a length specified by ",
  StyleBox["xside",
    FontSlant->"Italic"],
  ", a width specified by ",
  StyleBox["yside",
    FontSlant->"Italic"],
  ", and a height specified by ",
  StyleBox["zside",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Boundary[",
    FontWeight->"Bold"],
  StyleBox["aside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a length specified by ",
  StyleBox["aside",
    FontSlant->"Italic"],
  ", a width specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ", and a height specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "l systems usually have at least one boundary component listed at the end. \
By default, ",
  StyleBox["Boundary",
    FontWeight->"Bold"],
  " is not rendered. See also: ",
  StyleBox["ClearBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundaryChecked", "Subsection"],

Cell[TextData[{
  StyleBox["BoundaryChecked",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " indicates whether ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  " has automatically incorporated the ",
  StyleBox["InsideSurfaceBoundaryQ",
    FontWeight->"Bold"],
  " information into the ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["BoundaryChecked",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " are both returned by ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  " and embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["InsideSurfaceBoundaryQ",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundaryFactor", "Subsection"],

Cell[TextData[{
  StyleBox["BoundaryFactor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["factor",
    FontSlant->"Italic"],
  " determines a ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  " scaling ",
  StyleBox["factor",
    FontSlant->"Italic"],
  " to be used during the construction of ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " models.\n\[InvisibleSpace]",
  StyleBox["BoundaryFactor",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ". ",
  StyleBox["BoundaryFactor",
    FontWeight->"Bold"],
  " is also used in ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundaryLabel", "Subsection"],

Cell[TextData[{
  StyleBox["BoundaryLabel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["label",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that designates a boundary type",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundingBox", "Subsection"],

Cell[TextData[{
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["component",
    FontSlant->"Italic"],
  " is an option of custom optical elements that specifies a ",
  StyleBox["component",
    FontSlant->"Italic"],
  " shape whose one or more surfaces span the customized surface volume.\n\
\[InvisibleSpace]In addition to directly accepting a ",
  StyleBox["component",
    FontSlant->"Italic"],
  " or list of components, ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " can also take one or more numerical values to describe its form. ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmin",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmax",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " may be used instead of a ",
  StyleBox["component",
    FontSlant->"Italic"],
  " to specify a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional rectangular volume. ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  " specifies a spherical volume of the given ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  ". Otherwise, ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["aside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bside",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " assumes a centred three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a length specified by ",
  StyleBox["aside",
    FontSlant->"Italic"],
  ", a width specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ", and a height specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ". Finally, ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " automatically determines a rectangular volume boundary from the ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " information when ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is invoked.\n\[InvisibleSpace]In general, the ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " information need not be rectangular and can be defined by any set of one \
or more analytic surfaces (passed in the ",
  StyleBox["component",
    FontSlant->"Italic"],
  ".",
  ")",
  " ",
  StyleBox["In",
    FontWeight->"Bold"],
  " addition, the ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " need not define a closed volume. The ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " option is used internally by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  " to construct the ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " function. ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " is defined relative to the local coordinate system of the optical \
surface.\n\[InvisibleSpace]See also: ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BoundaryFactor",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundingBoxQ", "Subsection"],

Cell[TextData[{
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " if the ray intercepts one or more of the ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " surfaces.\n\[InvisibleSpace]",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " is used to speed nonsequential ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations in which specialized custom surfaces are involved. The \
",
  StyleBox["function",
    FontSlant->"Italic"],
  " of ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " takes the parameters: ",
  StyleBox["RSx",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RSy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RSz",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RTx",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RTy",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RTz",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["{RSx, RSy, RSz}",
    FontWeight->"Bold"],
  " is the ray starting point and ",
  StyleBox["{RTx, RTy, RTz}",
    FontWeight->"Bold"],
  " is the unit ray tilt vector. For iterative or open",
  StyleBox["-",
    FontWeight->"Bold"],
  "form ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " settings (such as ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  "), ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " is automatically created from ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  " and embedded within the ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ". ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " is also located within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. ",
  StyleBox["BoundingBoxQ",
    FontWeight->"Bold"],
  " is only created for custom",
  StyleBox["-",
    FontWeight->"Bold"],
  "component shapes and is not generally included in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox["'",
    FontWeight->"Bold"],
  "s standard components.\n\[InvisibleSpace]See also: ",
  StyleBox["BoundingBox",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoxGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["BoxGraphic[{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmin",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmax",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " specifies a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional rectangular box with its diagonally opposite corners placed at \
",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmin",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zmax",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["BoxGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but can be listed with active \
components or with other graphic components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BranchingSurface", "Subsection"],

Cell[TextData[{
  StyleBox["BranchingSurface[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentincrement",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a planar component that causes intersecting rays to branch to a \
different component position relative to the list position held by ",
  StyleBox["BranchingSurface",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["BranchingSurface",
    FontWeight->"Bold"],
  " is usually employed after a beam",
  StyleBox["-",
    FontWeight->"Bold"],
  "splitter",
  StyleBox["-",
    FontWeight->"Bold"],
  "type component, in order to redirect split rays down a different \
component",
  StyleBox["-",
    FontWeight->"Bold"],
  "listing pathway, thereby shortening ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculation times. ",
  StyleBox["BranchingSurface",
    FontWeight->"Bold"],
  " is not visually rendered, but can be used to sample the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface positions. ",
  StyleBox["BranchingSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. Because ",
  StyleBox["BranchingSurface",
    FontWeight->"Bold"],
  " is not supported by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", it now has limited application with the new version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". As such it is recommended to use the ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " function instead.\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BubbleClass", "Subsection"],

Cell[TextData[{
  StyleBox["BubbleClass",
    FontWeight->"Bold"],
  " is a database rule name that specifies the bubble class of a material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BuildComponent", "Subsection"],

Cell[TextData[{
  StyleBox["BuildComponent[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " synthesizes generic traits from several ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects into a single ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]While ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " is usually used by generic building block functions, ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " may also be used as an external function to combine several ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects into a single ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " unit. See also",
  ":",
  " ",
  StyleBox["GroupDescription",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BuildingBlockFunctions", "Subsection"],

Cell[TextData[{
  StyleBox["BuildingBlockFunctions",
    FontWeight->"Bold"],
  " generates a hyperlinked listing of the common low",
  StyleBox["-",
    FontWeight->"Bold"],
  "level functions used to construct optical component models in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BundleOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["BundleOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", {{",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an alias of ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " for a more complete description",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalciteE", "Subsection"],

Cell[TextData[{
  StyleBox["CalciteE",
    FontWeight->"Bold"],
  " is a default material of ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " to be defined by ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " later."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CalciteO", "Subsection"],

Cell[TextData[{
  StyleBox["CalciteO",
    FontWeight->"Bold"],
  " is a default material of ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " to be defined by ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " later."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CartesianCoordinates", "Subsection"],

Cell[TextData[{
  StyleBox["CartesianCoordinates",
    FontWeight->"Bold"],
  " is a value of the option ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CatalogFocalLength", "Subsection"],

Cell[TextData[{
  StyleBox["CatalogFocalLength",
    FontWeight->"Bold"],
  " is a database rule name for a lens that specifies the approximate \
effective focal length as written in the catalog.\n\[InvisibleSpace]The \
actual effective focal length is given by the ",
  StyleBox["FocalLength",
    FontWeight->"Bold"],
  " name. See also",
  ":",
  " ",
  StyleBox["FrontFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FocalLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CatalogInformation", "Subsection"],

Cell[TextData[{
  StyleBox["CatalogInformation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["database",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["entry",
    FontSlant->"Italic"],
  StyleBox["},",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that supplies ",
  StyleBox["database",
    FontSlant->"Italic"],
  " information about the characteristics of a manufactured component.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["CatalogInformation",
    FontWeight->"Bold"],
  " contains nested lists of rules with labels such as",
  ":",
  " ComponentName, SerialNumber, ",
  StyleBox["Price",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Date",
    FontWeight->"Bold"],
  ". Each ",
  StyleBox["entry",
    FontSlant->"Italic"],
  " of the outer list represents one component. If no catalog information is \
available, an empty list is inserted. Otherwise the ",
  StyleBox["entry",
    FontSlant->"Italic"],
  " contains a list of lists with each sublist having information of one \
component ",
  StyleBox["database",
    FontSlant->"Italic"],
  " ",
  StyleBox["entry",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Centered", "Subsection"],

Cell[TextData[{
  StyleBox["Centered",
    FontWeight->"Bold"],
  " is an option of component functions that can have values of ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", or a ",
  StyleBox["number",
    FontSlant->"Italic"],
  ", depending on the particular component function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In some functions, ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", specifies that the component is to be centered on the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. In other functions, ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", indicates that an active surface is centered between two refractive \
surfaces. ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " usually specifies a ",
  StyleBox["number",
    FontSlant->"Italic"],
  " between 0 and 1 to indicate the fractional distance of the active surface \
between two refractive surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CenteringTolerance", "Subsection"],

Cell[TextData[{
  StyleBox["CenteringTolerance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the manufacturing angular \
tolerances of an optical component in units of ",
  StyleBox["+-",
    FontWeight->"Bold"],
  " seconds of arc",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CenterThickness", "Subsection"],

Cell[TextData[{
  StyleBox["CenterThickness",
    FontWeight->"Bold"],
  " is a database rule name that specifies the center thickness of a lens",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangedComponent", "Subsection"],

Cell[TextData[{
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and specifies that the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object may be passed to or returned from ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  " contains all of the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object",
  StyleBox["'",
    FontWeight->"Bold"],
  "s contents, including changed parameters. The contents of ",
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  " are used to replace the original ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object. See also",
  ":",
  " ",
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangedRay", "Subsection"],

Cell[TextData[{
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and indicates that the modified ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects returned by previous ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function calculations are passed to or returned from the current \
",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  " results contain only modifications made to the original ray entering the \
surface. Note that ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " contains the unmodified ray parameters entering the surface. See also",
  ":",
  " ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangedSurface", "Subsection"],

Cell[TextData[{
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and specifies that a slotted element from ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " may be passed to or returned from ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Normally the contents indicated by ",
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  " is slotted inside the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", replacing the slot",
  StyleBox["'",
    FontWeight->"Bold"],
  "s previous contents. See also",
  ":",
  " ",
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangeRay", "Subsection"],

Cell[TextData[{
  StyleBox["ChangeRay",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  " that is used internally.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It specifies whether a ray object should be changed, if all necessary \
rules for beam propagation are already present. Internally ",
  StyleBox["ChangeRay",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is used to speed up calls to ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  ". If in the ray object a necessary rule is missed, ",
  StyleBox["ChangeRay",
    FontWeight->"Bold"],
  " has no effect",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangeSurfaceIncrement", "Subsection"],

Cell[TextData[{
  StyleBox["ChangeSurfaceIncrement[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newincrement",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that changes the value of ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ChangeSurfaceIncrement",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["ChangeSurfaceIncrement",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ChangeSurfacePosition", "Subsection"],

Cell[TextData[{
  StyleBox["ChangeSurfacePosition[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newsurfaceposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that changes ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " to a new value indicated by ",
  StyleBox["newsurfaceposition",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["ChangeSurfacePosition",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["ChangeSurfacePosition",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CheckLimits", "Subsection"],

Cell[TextData[{
  StyleBox["CheckLimits",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]It initiates a check for limits of ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ". Zero denominators are checked as well as infinite values of logarithm \
and trigonometric functions. Due to the complexity of automatic limit \
detection, the user should investigate the created component. ",
  StyleBox["SurfaceFunction/",
    FontWeight->"Bold"],
  ".(",
  StyleBox["Surfaces/",
    FontWeight->"Bold"],
  ".(created component)) and ",
  StyleBox["SurfaceNormalFunction/",
    FontWeight->"Bold"],
  ".(",
  StyleBox["Surfaces/",
    FontWeight->"Bold"],
  ".(created component)",
  ")",
  " return the checked functions. See also: ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CircleGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["CircleGraphic[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " relates to a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional circle, ellipse, rectangle, or polygon lying in the horizontal \
x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane, depending on the designation of ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["CircleGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but can be listed with active \
components or with other graphics components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CircleOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["CircleOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays distributed on the surface of a tube that \
points down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a list of two positive numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then the tube has rectangular shape of dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a single number, then the tube has a circular shape of a diameter \
dictated by ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a list of two negative numbers ",
  StyleBox["{-",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then the tube has elliptical dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["CreateRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CircumscribeBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that directs the triangular net of ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " to circumscribe the surface boundary.\n\[InvisibleSpace]",
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " directs the ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " to inscribe the surface boundary. ",
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  " works in conjunction with ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ", and SurfaceRayIntersection."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClearAperture", "Subsection"],

Cell[TextData[{
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  " is a database rule name that specifies the minimum clear aperture \
diameter of a lens.\n\[InvisibleSpace] Note that ",
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  " only gives the smallest side dimension for rectangular",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped lenses See also",
  ":",
  " ",
  StyleBox["WindowParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClearBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["ClearBoundary[",
    FontWeight->"Bold"],
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a rectangular box that terminates rays intercepted by its \
walls.\n\[InvisibleSpace]",
  StyleBox["ClearBoundary",
    FontWeight->"Bold"],
  " does not set the value of ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " to zero, and therefore is useful for defining modular optical subunits to \
be pieced into a larger system. Here, the user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. There are three methods for specifying ",
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  ": ",
  StyleBox["ClearBoundary[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z2",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " uses the coordinates of top and bottom opposite corners of a rectangular \
box, ",
  StyleBox["ClearBoundary[",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a cube boundary, ",
  StyleBox["ClearBoundary[",
    FontWeight->"Bold"],
  StyleBox["xside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a length specified by ",
  StyleBox["xside",
    FontSlant->"Italic"],
  ", a width specified by ",
  StyleBox["yside",
    FontSlant->"Italic"],
  ", and a height specified by ",
  StyleBox["zside",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["ClearBoundary[",
    FontWeight->"Bold"],
  StyleBox["aside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a length specified by ",
  StyleBox["aside",
    FontSlant->"Italic"],
  ", a width specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ", and a height specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "l systems usually have at least one boundary component listed at the end. \
By default, ",
  StyleBox["ClearBoundary",
    FontWeight->"Bold"],
  " is not rendered. See also: ",
  StyleBox["Boundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClearOpticaCache", "Subsection"],

Cell[TextData[{
  StyleBox["Clear",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Cache[]",
    FontWeight->"Bold"],
  " clears special ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " caches. Deleted caches are restored automatically by using ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", but a few that can be restored with ",
  StyleBox["Restore",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Cache",
    FontWeight->"Bold"],
  ". Any missing cache only affects the calculation time, not the results.\n\
\[InvisibleSpace]See also: ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Restore",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Cache",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClimaticResistance", "Subsection"],

Cell[TextData[{
  StyleBox["ClimaticResistance",
    FontWeight->"Bold"],
  " is a database rule name that gives an indication of the climatic \
resistance of a material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClonePosition", "Subsection"],

Cell[TextData[{
  StyleBox["ClonePosition",
    FontWeight->"Bold"],
  " indicates the origin of the local coordinate system of a cloned element \
generated from ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " data in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ClonePosition",
    FontWeight->"Bold"],
  " is internally used by some ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " definitions during ray traces involving ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CloneScale",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CloneRotation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CloneRotation", "Subsection"],

Cell[TextData[{
  StyleBox["CloneRotation",
    FontWeight->"Bold"],
  " indicates a rotation matrix transformation for the local coordinate \
system of a cloned element generated from ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " data in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["CloneRotation",
    FontWeight->"Bold"],
  " is internally used by some ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " definitions during ray traces involving ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CloneScale",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ClonePosition",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CloneScale", "Subsection"],

Cell[TextData[{
  StyleBox["CloneScale",
    FontWeight->"Bold"],
  " indicates a scaling transformation for the local coordinate system of a \
cloned element generated from ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " data in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["CloneScale",
    FontWeight->"Bold"],
  " is internally used by some ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " definitions during ray traces involving ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CloneRotation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ClonePosition",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CloneSortLength", "Subsection"],

Cell[TextData[{
  StyleBox["CloneSortLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["numberofelements",
    FontSlant->"Italic"],
  " determines the number of neighboring phantom optical components to be \
tested for closest intersection during the ray trace.\n\[InvisibleSpace]As \
the ",
  StyleBox["numberofelements",
    FontSlant->"Italic"],
  " setting is increased, the trace becomes more robust at the cost of \
diminished speed and increased memory consumption. See also",
  ":",
  " ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CloneSortMethod",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CloneSortMethod", "Subsection"],

Cell[TextData[{
  StyleBox["CloneSortMethod",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["method",
    FontSlant->"Italic"],
  " determines the ",
  StyleBox["method",
    FontSlant->"Italic"],
  " used for sorting the phantom optical components to be tested for closest \
intersection during ray tracing.\n\[InvisibleSpace]Alteration of ",
  StyleBox["CloneSortMethod",
    FontWeight->"Bold"],
  " is normally not required unless the default ray trace ",
  StyleBox["method",
    FontSlant->"Italic"],
  " produces erroneous results. Presently, ",
  StyleBox["CloneSortMethod",
    FontWeight->"Bold"],
  " accepts four different settings: 1, 2, 3, and 4. Here, methods 1 and 3 \
are the fastest, but methods 2 and 4 are the most robust. Methods 1 and 2 are \
faster than methods 3 and 4 when the ",
  StyleBox["CloneSortLength",
    FontWeight->"Bold"],
  " value is significantly less than the total number of phantom elements. \
Methods 3 and 4 are most useful when the total number of cloned elements \
remains small. See also",
  ":",
  " ",
  StyleBox["CloneSortLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CO550", "Subsection"],

Cell[TextData[{
  StyleBox["CO550",
    FontWeight->"Bold"],
  " indicates the use of the Corning Glass Code ",
  StyleBox["CO550",
    FontWeight->"Bold"],
  " molded glass.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The refractive index model for ",
  StyleBox["CO550",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of 0.365 microns to 1.55 \
microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoatedRefraction", "Subsection"],

Cell[TextData[{
  StyleBox["CoatedRefraction",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a refractive medium with coated surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoatingDirectory", "Subsection"],

Cell[TextData[{
  StyleBox["CoatingDirectory",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a directory.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "This directory contains data on optical coatings",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoatingFiles", "Subsection"],

Cell[TextData[{
  StyleBox["CoatingFiles",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a list of file names to be loaded.\n\[InvisibleSpace]These \
files contain information on optical coatings",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoatingMedium", "Subsection"],

Cell[TextData[{
  StyleBox["CoatingMedium",
    FontWeight->"Bold"],
  " is an option of component functions that indicates the type of material \
used in the fabrication of the coating of the component. Instead of a name a \
",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " can be given as percentage.\n\[InvisibleSpace]This label is used by ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " in calculating the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter. ",
  StyleBox["CoatingMedium",
    FontWeight->"Bold"],
  " is an option of all refractive components such as the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " genetic building block. See also",
  ":",
  " ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoatingSpecification", "Subsection"],

Cell[TextData[{
  StyleBox["CoatingSpecification",
    FontWeight->"Bold"],
  " is an option of component functions that indicates the \"thickness\" of \
the coating of the component.\n\[InvisibleSpace]This label is used by ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " in calculating the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter, and can be e. g. a thickness or a wavelength in microns. ",
  StyleBox["CoatingSpecification",
    FontWeight->"Bold"],
  " is an option of all refractive components such as the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " genetic building block. See also",
  ":",
  " ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CoatingMedium",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CodeVToData", "Subsection"],

Cell[TextData[{
  StyleBox["CodeVToData[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import CodeV lens data into ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox["'",
    FontWeight->"Bold"],
  "s database format.\n\[InvisibleSpace]",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  " requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished by directly copying and pasting the CodeV data from a text \
editor into a Mathematica notebook with double quotation marks placed \
manually on either side of the pasted data. ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  " then converts this string information into a rule",
  StyleBox["-",
    FontWeight->"Bold"],
  "based, list format that is recognized by Mathematica. The translation \
process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  ". Once converted, the new information can be edited further with ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  ", saved to disk with ",
  StyleBox["SaveData",
    FontWeight->"Bold"],
  ", and converted to optical component models with ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  " is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. Code V is a Trademark of ",
  "Optica",
  "l Research Associates, Pasadena, CA. See also: ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "CodeV",
  StyleBox["To",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import and convert CodeV refractive lens data into one or more \
optical lens models for ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished either by opening the CodeV data file inside Mathematica or by \
manually copying and pasting the relevant data into an existing Mathematica \
notebook and, as a final last step, creating a string object by manually \
placing double",
  StyleBox["-",
    FontWeight->"Bold"],
  "quotation marks on either side of the data. ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " then converts this string information into one or more optical lens \
models that work with ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". The conversion process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " (that get passed internally to ",
  StyleBox["StringReplace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  "). ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " makes internal calls to ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. Code V is a Trademark of",
  " Optica",
  "l Research Associates, Pasadena, CA. See also: ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coherent", "Subsection"],

Cell[TextData[{
  StyleBox["Coherent",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  " that specifies, that the values are added together with the assumption, \
that all rays are mutually coherent.See also",
  ":",
  " ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorCode", "Subsection"],

Cell[TextData[{
  StyleBox["ColorCode",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["wavelength2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name for a material that gives a quick reference to \
where the UV absorption begins and how steep the edge is.\n\
\[InvisibleSpace]The ",
  StyleBox["wavelength1",
    FontSlant->"Italic"],
  " gives the wavelength in nm for 0.80 transmittance through 10 millimeters \
of the material. The ",
  StyleBox["wavelength2",
    FontSlant->"Italic"],
  " gives the wavelength in nm for 0.05 transmittance through 10 millimeters \
of the material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorView", "Subsection"],

Cell[TextData[{
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that is used to specify the colors of rays.\n\[InvisibleSpace]",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " gives ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " to ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  " for determining ray colors. As examples: you can use ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Black",
    FontWeight->"Bold"],
  " to render the rays in black",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " attempts to match the color of the ray to the wavelength",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " displays the initial ",
  StyleBox["RGBColor",
    FontWeight->"Bold"],
  " values assigned for the ",
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  " ray parameter",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " for any ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " other than ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " attempts to colorize each ray segment according to the rank of the ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " value within the possible range of ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " values, for the displayed rays selected by ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  ". If more than one ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " is indicated or the parameter contains a vector of three elements, then \
each of three values is assigned to the red, green, and blue colors. ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " may also point to a list of three numbers representing the red, green, \
and blue colors used. See also",
  ":",
  " ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllColors",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompiledCoating", "Subsection"],

Cell[TextData[{
  StyleBox["CompiledCoating",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " is a rule returned by ",
  StyleBox["GetCoatingRules",
    FontWeight->"Bold"],
  ", which describes the coating. The function ",
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["[]",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["PrecisionFunction",
    FontWeight->"Bold"],
  ", which depends on ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ". The result of this ",
  StyleBox["PrecisionFunction",
    FontWeight->"Bold"],
  " is a flattened list with ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " for transmission, ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " for transmission, ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " for ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " for reflection.",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompiledIndices", "Subsection"],

Cell[TextData[{
  StyleBox["CompiledIndices",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " is a rule returned by ",
  StyleBox["GetMaterialRules",
    FontWeight->"Bold"],
  ", which describes the material. The function ",
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["[]",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["PrecisionFunction",
    FontWeight->"Bold"],
  ", which depends on ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  ", MaterialSpecification, ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ". The order is fixed and automatically created. ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " as well ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  " are used in connection with birefringent or structured media. The result \
of this ",
  StyleBox["PrecisionFunction",
    FontWeight->"Bold"],
  " is a list with a content controlled by the second argument to ",
  StyleBox["GetMaterialRules",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompiledSurfaceApproximation", "Subsection"],

Cell[TextData[{
  StyleBox["CompiledSurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["code",
    FontSlant->"Italic"],
  " is a rule within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component that gives the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " being used by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " to approximate a surface.\n\[InvisibleSpace]This approximation is used \
for custom surface functions to generate automatically start values to find a \
ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection. See also: ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompiledSurfaceIntersectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["CompiledSurfaceIntersectionFunction[",
    FontWeight->"Bold"],
  StyleBox["compiledfunction",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to designate a compiled function that calculates surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersections.\n\[InvisibleSpace]",
  StyleBox["CompiledSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " replaces the ",
  StyleBox["CompiledFunction",
    FontWeight->"Bold"],
  " head and is always used in connection with the ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " rule embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. The function takes the ray start and tilt in local \
surface coordinates as a sequence of six real values and returns a list of \
all the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional parametric intersection coordinates, ray length and two \
surface coordinates. If no intersection is found, the function returns ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}}",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompletedRay", "Subsection"],

Cell[TextData[{
  StyleBox["CompletedRay",
    FontWeight->"Bold"],
  " is a placeholder inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " for a variable that holds the ray object after a new surface \
intersection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComplexBeamParameter", "Subsection"],

Cell[TextData[{
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  " is an rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that provides the complex beam parameter q of a Gaussian beam at a \
particular transverse plane.\n\[InvisibleSpace]",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  " is returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Component", "Subsection"],

Cell[TextData[{
  StyleBox["Component[",
    FontWeight->"Bold"],
  StyleBox["genetic",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["traits",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object made up of ",
  StyleBox["genetic",
    FontSlant->"Italic"],
  " ",
  StyleBox["traits",
    FontSlant->"Italic"],
  " that define the properties of an optical component.\n\
\[InvisibleSpace]These ",
  StyleBox["genetic",
    FontSlant->"Italic"],
  " ",
  StyleBox["traits",
    FontSlant->"Italic"],
  " describe the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing behavior as well as the rendering of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " may actively interact with rays, or may be purely graphical in content. \
Any of the ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " functions may be nested around ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " to change its position and orientation",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentBoundary",
    FontWeight->"Bold"],
  " is a database rule name that specifies the entrance dimensions for a lens \
and the overall dimensions for a prism.\n\[InvisibleSpace]",
  StyleBox["ComponentBoundary",
    FontWeight->"Bold"],
  " may follow the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " convention for lens apertures, where a single number indicates the \
diameter of a circular shape and a list of two numbers indicate a rectangular \
shaped boundary. However, ",
  StyleBox["ComponentBoundary",
    FontWeight->"Bold"],
  " can also be used to specify the shapes of prisms and other object forms. \
See also: ",
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HousingBoundary",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentDescription", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentDescription",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["ComponentDescription[",
    FontWeight->"Bold"],
  StyleBox["descriptionlist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", made up of a description that identifies the optical component. Creating \
the component with the option ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " places in the ",
  StyleBox["descriptionlist",
    FontSlant->"Italic"],
  " all of the genetic building blocks used to create the component",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentFoundation", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentFoundation[{",
    FontWeight->"Bold"],
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentFoundation[",
    FontWeight->"Bold"],
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " create the initial ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object data structure that defines either a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced or single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced optical element in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  " parameters usually specify the curvature of the surface. The types of \
surface shapes used in ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " are given by the ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " identifies the surface types as either ",
  StyleBox["SphericalShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OtherShape",
    FontWeight->"Bold"],
  ", or a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined shape label. ",
  StyleBox["SphericalShape",
    FontWeight->"Bold"],
  " designates a spherical radius of curvature for ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ParabolicShape",
    FontWeight->"Bold"],
  " specifies a parabolic focal length for ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " can be set to planar shapes either by using ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " in ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  " or by using ",
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  " in ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  ". Users can add new surface definitions by assigning new functions to ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " with an accompanying ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " value as an argument. Otherwise, user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined, parametric surface functions can be directly specified by \
selecting ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["OtherShape",
    FontWeight->"Bold"],
  " and using three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional pure functions of two variables in ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  ". An example of such a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined, parametric surface function is: ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["+",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects are built by nesting ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " at the center of the various other generic building blocks that give \
additional attributes to the component. ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " defines the overall shape of the optic while other building blocks either \
determine how the element is graphically rendered, such as ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  ", or give the optical properties of the different internal surfaces, such \
as ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["OffAxis",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ActiveComponent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentFunctions", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentFunctions",
    FontWeight->"Bold"],
  " generates a hyperlinked listing of the common optical component models \
available in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentID", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentID",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies a unique identification number.\n\[InvisibleSpace]",
  StyleBox["ComponentID",
    FontWeight->"Bold"],
  " is usually determined by the function ",
  StyleBox["Unique",
    FontWeight->"Bold"],
  " during the creation of a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object. As a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentID",
    FontWeight->"Bold"],
  " indicates the component encountered by the ray segment. See also",
  ":",
  " ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentIncrement", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that forces a change in the next generated ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object",
  StyleBox["'",
    FontWeight->"Bold"],
  "s component target.\n\[InvisibleSpace]",
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " to proceed in the same direction through the component listing according \
to ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  ", a related parameter. ",
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " forces an immediate change of the component targeted by ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", by the amount given by ",
  StyleBox["integer",
    FontSlant->"Italic"],
  ". As an example, ",
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["-",
    FontWeight->"Bold"],
  "2, would cause ",
  StyleBox["-",
    FontWeight->"Bold"],
  "2 to be subtracted from the ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  " parameter in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  " parameter reverts back to the ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " setting after one propagation iteration. See also",
  ":",
  " ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentMedium", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " is an option of component functions that indicates the type of material \
used in the fabrication of the component.\n\[InvisibleSpace]This label is \
used by ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " in calculating the ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " parameter, but can be used by other material",
  StyleBox["-",
    FontWeight->"Bold"],
  "related models as well as ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " is an option of all refractive components such as the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " genetic building block. See also: ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["lMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentNumber", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that indicates the slot position of the affected component encountered by \
the ray segment.\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentQ", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object. The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentRendering", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentRendering[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that contructs information about the \
rendering of a ",
  StyleBox["component",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " defines how each surface within ",
  StyleBox["component",
    FontSlant->"Italic"],
  " is graphically rendered. If the ",
  StyleBox["component",
    FontSlant->"Italic"],
  " parameter contains multiple surfaces, then ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " also graphically connects the edges of the different surfaces together. \
",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that characterizes the ",
  StyleBox["component",
    FontSlant->"Italic"],
  " rendering. ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " has possible five styles. These are ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Sketch",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wire",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solid",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ". These styles are also ",
  StyleBox["options",
    FontSlant->"Italic"],
  " of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that characterize the rendering at a primitive level and are further \
defined with ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  ", although ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  " does not apply to single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced components. The ",
  StyleBox["component",
    FontSlant->"Italic"],
  " rendering can be controlled either by giving separate rendering commands \
for each suboption or by using the ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " option. See also",
  ":",
  " ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentSelect", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentSelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes an object set composed of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, and returns a filtered list of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects that shares the common set of traits specified in ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]There are two ways of specifying ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ":",
  " the first way is to give a list of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " rules selected. The second way is to give a function that takes ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " rules as inputs and returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". An example of the first method is ",
  StyleBox["{TranslationVector -> {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, ComponentNumber -> ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}",
    FontWeight->"Bold"],
  ". An example of the second method is ",
  StyleBox["Function[{ComponentNumber, TranslationVector}, ComponentNumber == \
",
    FontWeight->"Bold"],
  "2",
  StyleBox[" && TranslationVector[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]] > ",
    FontWeight->"Bold"],
  "0",
  StyleBox["]",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " ",
  StyleBox["===",
    FontWeight->"Bold"],
  " ",
  StyleBox["All",
    FontWeight->"Bold"],
  " or ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is left out, then all ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects are passed back. ",
  StyleBox["ComponentSelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns an unfiltered list of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects. ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  " can also be used to translate ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " data into ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object format."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentSelectComponentOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentSelectComponentOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  " that determines the numbers of components, for which an orientation \
should be drawn. See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ComponentTransformation", "Subsection"],

Cell[TextData[{
  StyleBox["ComponentTransformation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["translationvector",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the original position and orientation of the parent \
component of the surface. Functions grouping components together, like ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  ", do not change ",
  StyleBox["ComponentTransformation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompoundLens", "Subsection"],

Cell[TextData[{
  StyleBox["CompoundLens[",
    FontWeight->"Bold"],
  StyleBox["curvatures",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfaceboundaries",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfaceseparations",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["opticalmediumlist",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a lens assembly that consists of spherical and aspherical \
refracting surfaces.\n\[InvisibleSpace]The ",
  StyleBox["curvatures",
    FontSlant->"Italic"],
  " can be specified either by radiusofcurvatures, inverse \
radiusofcurvatures, and aspheric polynomial coefficients (see also: ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  "), where either ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " or 0 can be used to indicate planar surfaces. In addition, ",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  " is specified by a list of surface separations. The ",
  StyleBox["opticalmediumlist",
    FontSlant->"Italic"],
  " must also be specified either as a list of symbols to identify built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in index functions, a list of numbers to define refractive index values, \
or as a list of functions. ",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and the \
remaining surfaces positioned down the x axis. The ",
  StyleBox["surfaceboundaries",
    FontSlant->"Italic"],
  " parameter gives a list of apertures that correspond to each surface, \
where an aperture may indicate a circle, rectangle, or polygon depending on \
the number and type of elements listed by it.\n\[InvisibleSpace]",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  " may also include pinhole surfaces to provide field stops. Such a pinhole \
is detected by ",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  " where ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " is listed twice consecutively or is given as the first element within ",
  StyleBox["opticalmediumlist",
    FontSlant->"Italic"],
  ". In such a case, the inside hole boundary is taken from corresponding \
aperture in ",
  StyleBox["surfaceboundaries",
    FontSlant->"Italic"],
  " and the outside boundary of the pinhole is taken from the average \
aperture size of the next neighboring lens surface(s). The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. See also: ",
  StyleBox["LensDoublet",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LensTriplet",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conductive", "Subsection"],

Cell[TextData[{
  StyleBox["Conductive",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a conductive, nonmagnetic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conductivity", "Subsection"],

Cell[TextData[{
  StyleBox["Conductivity",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the conductivity value for the ray segment in the local \
environment. The effective relative permittivity is calculated with the \
conductivity as (relative permittivity ",
  StyleBox["+",
    FontWeight->"Bold"],
  " ",
  StyleBox["I",
    FontWeight->"Bold"],
  " ",
  StyleBox["*",
    FontWeight->"Bold"],
  " (wavelength ",
  StyleBox["*",
    FontWeight->"Bold"],
  " conductivity) ",
  StyleBox["/",
    FontWeight->"Bold"],
  " (2 ",
  StyleBox["*",
    FontWeight->"Bold"],
  " ",
  StyleBox["Pi",
    FontWeight->"Bold"],
  " ",
  StyleBox["*",
    FontWeight->"Bold"],
  " vacuum speed of light ",
  StyleBox["*",
    FontWeight->"Bold"],
  " permittivity free space)",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConeOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["ConeOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["spread",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays distributed along a funnel",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped surface that is oriented down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter is taken as the full cone angle, in degrees units, for the \
default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting of ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ". However, for other ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " settings, the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter specifies the intercept spatial dimensions, at the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane, of the ray set. If ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a list of two positive numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then the cone has rectangular shaped cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "section. If ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a single number, then the cone has a circular shaped cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "section. If ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a list of two negative numbers ",
  StyleBox["{-",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then the cone has elliptical shape given by ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Confine", "Subsection"],

Cell[TextData[{
  StyleBox["Confine[",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["entrancesurfacenumbers",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used to encapsulate the list of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects into a single ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object that allows rays to enter the component only through surfaces \
specified by ",
  StyleBox["entrancesurfacenumbers",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["Confine",
    FontWeight->"Bold"],
  " is used in conjunction with the ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " generic building block to create arrays of multiple",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced elements, such as fiber optic bundles. ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  " passes ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Unconfine",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConfinedNumber", "Subsection"],

Cell[TextData[{
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the present slot position of the outermost nested element \
within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConfinedPaths", "Subsection"],

Cell[TextData[{
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that indicates a nested list of rules that define the confined \
propagation behavior of a ray migrating through the component.\n\
\[InvisibleSpace]",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " lists all of the confined migration pathways available for the impinging \
ray. ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " contains lists including ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " rules. See also",
  ":",
  " ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConfinedPosition", "Subsection"],

Cell[TextData[{
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the present slot position of the innermost nested element \
within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConjugateBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["ConjugateBeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ConjugateBeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a planar component that has a partially conjugate",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflective",
  StyleBox["/",
    FontWeight->"Bold"],
  "transmissive side and, with a ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " specified, a refractive side.\n\[InvisibleSpace]",
  StyleBox["ConjugateBeamSplitter",
    FontWeight->"Bold"],
  " is created with its splitting surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConjugateMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ConjugateMirror[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ConjugateMirror[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refer to a planar, phase",
  StyleBox["-",
    FontWeight->"Bold"],
  "conjugate reflective mirror.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["ConjugateMirror",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConjugateReflection", "Subsection"],

Cell[TextData[{
  StyleBox["ConjugateReflection[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block produces conjugate",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflected rays from optical surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConnectSelectedPoints", "Subsection"],

Cell[TextData[{
  StyleBox["ConnectSelectedPoints",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowSelectedPoints",
    FontWeight->"Bold"],
  " that allows connection of points See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConserveEnergy", "Subsection"],

Cell[TextData[{
  StyleBox["ConserveEnergy",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " that indicates whether ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values in the scattered rays should be reduced to conserve overall \
energy",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constrain", "Subsection"],

Cell[TextData[{
  StyleBox["Constrain",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that repositions components and rays along a constrained horizontal or \
vertical axis of movement.\n\[InvisibleSpace]",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the objects getting translated and the new translation \
coordinates. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConstructMeritFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ConstructMeritFunction[",
    FontWeight->"Bold"],
  StyleBox["opticalsystem",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " constructs a ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " that calculates the performance of an optical system for a specified set \
of input parameters.\n\[InvisibleSpace]",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to create the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " according to the ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " option setting. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " is internally converted by ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " into particular settings for the ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". As an alternative to using the ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " option, the user can instead work directly with the ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConvertOptics", "Subsection"],

Cell[TextData[{
  StyleBox["ConvertOptics[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["outputtype",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes an ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " composed of rays and",
  StyleBox["/",
    FontWeight->"Bold"],
  "or components, and returns an ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " in the different format given by the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " setting.\n\[InvisibleSpace]The function is called at the beginning and \
end of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". In ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReadComponents",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " option is passed to ",
  StyleBox["ConvertOptics",
    FontWeight->"Bold"],
  " to change object formats. ",
  StyleBox["ConvertOptics",
    FontWeight->"Bold"],
  " uses the following ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " settings: ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoordinateSystem", "Subsection"],

Cell[TextData[{
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["coordinatesystem",
    FontSlant->"Italic"],
  " is an option of geometric sources and some utility functions that gives \
the coordinate system being used for points.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It may take the values ",
  StyleBox["PolarCoordinates",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CartesianCoordinates",
    FontWeight->"Bold"],
  " or a list thereof. ",
  StyleBox["Sources",
    FontWeight->"Bold"],
  " apply only the first the value in combination with ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copy", "Subsection"],

Cell[TextData[{
  StyleBox["Copy",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that duplicates and moves the new components and rays.\n\
\[InvisibleSpace]",
  StyleBox["Copy",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to select objects and produce a copy of objects relative to the last \
indicated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CosineCompensation", "Subsection"],

Cell[TextData[{
  StyleBox["CosineCompensation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " that specifies whether the ray intensities are weighted by the Cosine of \
their angle of incidence with the surface normal. See also",
  ":",
  " ",
  StyleBox["SequentialRead",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoupledWaveTheory", "Subsection"],

Cell[TextData[{
  StyleBox["CoupledWaveTheory->True/False",
    FontWeight->"Bold"],
  " is an option that indicates whether a specialized form of couple",
  StyleBox["-",
    FontWeight->"Bold"],
  "wave theory is used for calculating the diffraction efficiency of \
gratings.\n\[InvisibleSpace]",
  StyleBox["CoupledWaveTheory->True",
    FontWeight->"Bold"],
  " accurately describes the polarization",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent behavior of a volumetic phase grating with a cosine index \
profile and two deflected waves without absorption. The present \
implementation of ",
  StyleBox["CoupledWaveTheory->True",
    FontWeight->"Bold"],
  " can only model the zero and first diffracted orders and cannot be applied \
to higher order terms of diffraction. Otherwise, ",
  StyleBox["CoupledWaveTheory->False",
    FontWeight->"Bold"],
  " can be used to model any combination of diffracted orders. The \
diffraction efficiency of diffracted terms in ",
  StyleBox["CoupledWaveTheory->False",
    FontWeight->"Bold"],
  " is based on the combined settings of the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " options. Although ",
  StyleBox["CoupledWaveTheory->False",
    FontWeight->"Bold"],
  " accurately models optical path length and diffraction directions, it does \
not incorporate polarization effects or model diffraction efficiency in the \
precise manner of ",
  StyleBox["CoupledWaveTheory->True",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreateClones", "Subsection"],

Cell[TextData[{
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["coordinates",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scale",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " specifies the placement of one or more phantom optical components to be \
used during the ray trace. These component aliases exhibit the raytrace \
behavior of the original component members but do not consume additional \
computer memory. This permits the efficient nonsequential ray tracing of \
large arrays of optical elements.\n\[InvisibleSpace]In the specification of \
",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " parameter gives the two or three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional location of the cloned object, ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  " provides the cloned optic orientation, ",
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  " denotes which component in the optical system list will be cloned, and ",
  StyleBox["scale",
    FontSlant->"Italic"],
  " indicates the relative size of the new clone. In addition to taking a \
single numeric value, the ",
  StyleBox["scale",
    FontSlant->"Italic"],
  " parameter can also take a list of three numbers to specify three separate \
coordinate scales. If no twisting about the rotation axis is required, the \
unit",
  StyleBox["-",
    FontWeight->"Bold"],
  "direction vector (the first ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  " element",
  ")",
  " can be used on its own and the remaining ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  " elements will be internally calculated. During the specification of ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ", ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  ", ",
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["scale",
    FontSlant->"Italic"],
  " are all optional parameters that can be selectively omitted or mixed",
  StyleBox["-",
    FontWeight->"Bold"],
  "in, however, ",
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  " must also be present before a ",
  StyleBox["scale",
    FontSlant->"Italic"],
  " can be specified. When not present, ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  ", ",
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["scale",
    FontSlant->"Italic"],
  " will assume the respective values of: ",
  StyleBox["{{",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "1",
  StyleBox["}}",
    FontWeight->"Bold"],
  ", 1, and 1.\n\[InvisibleSpace]",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " permits a wide variety of input data formats. For very large systems of \
specified elements, ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " also permits the use of packed arrays. In such a case, each set of \
parameters in the element listing is presented as a flattened list of real \
numbers. ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " also permits the specification of multiple sets of optical arrays. This \
is accomplished with an additional nesting of the data: ",
  StyleBox["{{{",
    FontWeight->"Bold"],
  StyleBox["coordinates",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentnumber",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scale",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["},",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  ". Here, the rays are nonsequentially traced within each array, but are \
sequentially traced between the array data sets.\n\[InvisibleSpace]Although \
",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " only operates within the ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " engine, ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " may also be specified for ",
  StyleBox["AnalyzeSystem/DrawSystem",
    FontWeight->"Bold"],
  ". In such an event, ",
  StyleBox["TracingEngine->TurboTrace",
    FontWeight->"Bold"],
  " is automatically used instead of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CloneSortLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CloneSortMethod",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreatedRay", "Subsection"],

Cell[TextData[{
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and denotes that the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects created by previous ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function calculations are passed to or returned from ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " is listed by ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " is sequentially fed as an input to the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function, with each sequential result creating a different output. \
The elements of ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " are inserted into the previous ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects generated at this surface if ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " is listed by ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreateFiberShape", "Subsection"],

Cell[TextData[{
  StyleBox["CreateFiberShape[",
    FontWeight->"Bold"],
  StyleBox["points",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " uses a list of two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional ",
  StyleBox["points",
    FontSlant->"Italic"],
  " to create a set of fitted parametric",
  StyleBox["-",
    FontWeight->"Bold"],
  "functions along with the fiber length.\n\[InvisibleSpace]",
  StyleBox["CreateFiberShape",
    FontWeight->"Bold"],
  " is designed to work with ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomFiberMirror",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Fiber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomFiberMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreateRay", "Subsection"],

Cell[TextData[{
  StyleBox["CreateRay[",
    FontWeight->"Bold"],
  StyleBox["source",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to generate either ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects or a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object that represents a set of rays for the given ",
  StyleBox["source",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In addition, ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  " fills in any essential ray parameters missing from the specified ",
  StyleBox["source",
    FontSlant->"Italic"],
  " by taking default values from ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  ". Check ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " for default settings. The option ",
  StyleBox["ChangeRay",
    FontWeight->"Bold"],
  " can be used suppress changes, if the ray contains all necessary rules for \
propagation. The ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ray/TurboRays",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  " is used internally by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to determine the ray object",
  StyleBox["-",
    FontWeight->"Bold"],
  "type that is generated. See also",
  ":",
  " ",
  StyleBox["CreateRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreateRays", "Subsection"],

Cell[TextData[{
  StyleBox["CreateRays[",
    FontWeight->"Bold"],
  StyleBox["source",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to generate either ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects or a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object that represents a set of rays for the given ",
  StyleBox["source",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In addition, ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  " fills in any essential ray parameters missing from the specified ",
  StyleBox["source",
    FontSlant->"Italic"],
  " by taking default values from ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  ". Check ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " for default settings. The option ",
  StyleBox["ChangeRay",
    FontWeight->"Bold"],
  " can be used suppress changes, if the ray contains all necessary rules for \
propagation. The ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ray/TurboRays",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  " is used internally by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to determine the ray object",
  StyleBox["-",
    FontWeight->"Bold"],
  "type that is generated. ",
  StyleBox["CreateRays",
    FontWeight->"Bold"],
  " is an alias of ",
  StyleBox["CreateRay",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CreateRefractiveIndexModel", "Subsection"],

Cell[TextData[{
  StyleBox["CreateRefractiveIndexModel[",
    FontWeight->"Bold"],
  StyleBox["datalist",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["materiallabel",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " creates a wavelength",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent model that is fitted to the data for the index model specified \
by the ",
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["Function",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]Note that the ",
  StyleBox["materiallabel",
    FontSlant->"Italic"],
  " is used for the purposes of referencing the particular material within ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". Although ",
  StyleBox["materiallabel",
    FontSlant->"Italic"],
  " can be given as a string (such as \"NewName\"), it is often given as a \
symbolic object (such as NewName). The ",
  StyleBox["datalist",
    FontSlant->"Italic"],
  " should have the following format: ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["wavelength1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["wavelength2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index2",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["wavelength3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index3",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  " plots the data points against the fitted function, revealing model \
deficiencies. Finally, ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  " defines the refractive model in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". With the ",
  StyleBox["SaveData->True",
    FontWeight->"Bold"],
  " setting, this model is also stored in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox["'",
    FontWeight->"Bold"],
  "s database on disk for future retrieval and use. See also: ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CrossRendering", "Subsection"],

Cell[TextData[{
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that designates the graphical rendering of a cross that bridges the \
interior of a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component and forms crossed lines on a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component.\n\[InvisibleSpace]",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  " may take the values: ",
  StyleBox["Fill",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Trace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mesh",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Empty",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{Fill, Mesh}",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CrossStyle", "Subsection"],

Cell[TextData[{
  StyleBox["CrossStyle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that designates the graphical primitives to be inserted before the \
rendering of a cross that bridges the interior of a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component and forms crossed lines on a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It is a list of two rules: ",
  StyleBox["LineStyle",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FillStyle",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["DefaultStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CrownAngle", "Subsection"],

Cell[TextData[{
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that denotes the angle (in degrees) that the Crown facet makes with \
respect to the girdle waist. Note that ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  " are complementary ways of fixing the bezel facet geometry on the crown \
(above the girdle",
  ")",
  ".\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CrownGlass", "Subsection"],

Cell[TextData[{
  StyleBox["CrownGlass",
    FontWeight->"Bold"],
  " designates the use of a crown glass medium.\n\[InvisibleSpace]The \
refractive index model for ",
  StyleBox["CrownGlass",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .44 microns to .66 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CrownHeight", "Subsection"],

Cell[TextData[{
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that indicates the vertical distance from the girdle waist to the \
top table facet as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter. Note that ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  " are complementary ways of fixing the bezel facet geometry on the crown \
(above the girdle",
  ")",
  ".\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CuletAngle", "Subsection"],

Cell[TextData[{
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that denotes the full angle (in degrees) spanned by the solitaire \
vertex (culet). Note that ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  " are all complementary ways of defining the facet dimensions on the \
pavilion (below the girdle",
  ")",
  ".\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CuletDiameter", "Subsection"],

Cell[TextData[{
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that indicates the diameter of the solitaire vertex (culet",
  ")",
  " facet as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter.\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CurvatureDirection", "Subsection"],

Cell[TextData[{
  StyleBox["CurvatureDirection",
    FontWeight->"Bold"],
  " is an option of convex and concave lenses that specifies which side of \
the created lens is curved as indicated by word values ",
  StyleBox["Front",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Back",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If ",
  StyleBox["Front",
    FontWeight->"Bold"],
  " is used, then the curved side is placed at the origin and the planar side \
is created one thickness position down the x axis",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CurvatureTolerance", "Subsection"],

Cell[TextData[{
  StyleBox["CurvatureTolerance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the manufacturing radius",
  StyleBox["-",
    FontWeight->"Bold"],
  "of",
  StyleBox["-",
    FontWeight->"Bold"],
  "curvature tolerances of an optical component expressed as a percentage.\n\
\[InvisibleSpace]",
  StyleBox["CurvatureTolerance",
    FontWeight->"Bold"],
  " can also apply to non",
  StyleBox["-",
    FontWeight->"Bold"],
  "spherical, curved components such as parabolic mirrors",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["CustomBaffle[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomBaffle[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "absorbing component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Here, the user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression. The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomBaffle",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["CustomBeamSplitter[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomBeamSplitter[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a component that partially reflects and partially transmits rays \
of light that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " is created with its splitting surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomBirefringentLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CustomBirefringentLensSurface[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " that models the refractive index boundary.\n\[InvisibleSpace]",
  StyleBox["CustomBirefringentLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  " component types to create a complete optical element. The component \
shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomBirefringentLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. ",
  StyleBox["CustomBirefringentLensSurface",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["mediumA",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumB",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " to designate the type of birefringent optical material with the alignment \
axis of materialA given by ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  ". Otherwise, ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["isotropicmedium",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specifies the interface with an isotropic material other than the default \
",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " setting. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomBranchingSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CustomBranchingSurface[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentincrement",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a component that causes intersecting rays to branch to a \
different component position relative to the list position held by ",
  StyleBox["CustomBranchingSurface",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomBranchingSurface",
    FontWeight->"Bold"],
  " is usually employed after a beam",
  StyleBox["-",
    FontWeight->"Bold"],
  "splitter",
  StyleBox["-",
    FontWeight->"Bold"],
  "type component, in order to redirect split rays down a different \
component",
  StyleBox["-",
    FontWeight->"Bold"],
  "listing pathway, thereby shortening ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculation times. ",
  StyleBox["CustomBranchingSurface",
    FontWeight->"Bold"],
  " is not visually rendered, but can be used to sample the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface positions. ",
  StyleBox["CustomBranchingSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. Because ",
  StyleBox["CustomBranchingSurface",
    FontWeight->"Bold"],
  " is not supported by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", it now has limited application with the new version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". As such it is recommended to use the ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " function instead.\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomConjugateBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["CustomConjugateBeamSplitter[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomConjugateBeamSplitter[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a component that partially conjugate",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflects and partially transmits rays of light that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " is created with its splitting surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomConjugateMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CustomConjugateMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomConjugateMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a phase",
  StyleBox["-",
    FontWeight->"Bold"],
  "conjugate mirror that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomConjugateMirror",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the maximum edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " option can be used to change substrate rear surface position in off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis parabolic mirrors. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " indicates that the substrate rear surface is located directly behind and \
parallel with the local off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis mirror surface. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " only ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is recognized. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the substrate orientation remains fixed with the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and parallel with the parabolic vertex. In addition, ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " changes the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken for the projected boundary shape onto the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane (as seen from projection down the primary optical (x) axis). For \
",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken as the actual boundary shape of the off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis surface (as seen by projection down the local surface normal). The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " option automatically changes its value to fit best with other ",
  StyleBox["options",
    FontSlant->"Italic"],
  " settings of ",
  StyleBox["CustomConjugateMirror",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomDeflectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["CustomDeflectionFunction",
    FontWeight->"Bold"],
  " is a label of ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " that designates a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined deflection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomDeflections", "Subsection"],

Cell[TextData[{
  StyleBox["CustomDeflections[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["raydeflectfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["functionlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that allows the user to create custom ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomDiffuser", "Subsection"],

Cell[TextData[{
  StyleBox["CustomDiffuser[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuser[{",
    FontWeight->"Bold"],
  StyleBox["surfacefunction1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a custom",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped component that splits incoming rays into diffused rays rays using \
the ray scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser.\n\[InvisibleSpace]",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  " refers to a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalDiffuserMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomDiffuserMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CustomDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror[{",
    FontWeight->"Bold"],
  StyleBox["surfacefunction1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a custom",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped component that splits incoming rays into diffused rays reflected \
rays using the ray scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  " refers to a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalDiffuserMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomFiber", "Subsection"],

Cell[TextData[{
  StyleBox["CustomFiber[{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["corediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["claddingdiameter",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a curved, stepped",
  StyleBox["-",
    FontWeight->"Bold"],
  "index optical fiber that follows a curve specified in the parametric \
functions, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The refractive core and cladding materials are given \
by the option, ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["corematerial",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["claddingmaterial",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CustomFiber[{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["corediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a bare optical fiber. ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  " can also have an elliptical cross section with the option ",
  StyleBox["EllipseRatio",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Fiber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomFiberMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CreateFiberShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomFiberMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CustomFiberMirror[{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a curved, reflective, fiber",
  StyleBox["-",
    FontWeight->"Bold"],
  "like tube that follows a curve specified in the parametric functions, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["CustomFiberMirror",
    FontWeight->"Bold"],
  " can also have an elliptical cross section with the option ",
  StyleBox["EllipseRatio",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Fiber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CreateFiberShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomGeneticFunction", "Subsection"],

Cell[TextData[{
  StyleBox["CustomGeneticFunction",
    FontWeight->"Bold"],
  " is now replaced by ",
  StyleBox["CustomDeflections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomGrating", "Subsection"],

Cell[TextData[{
  StyleBox["CustomGrating[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomGrating[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a diffractive component that splits incoming rays into multiple \
diffracted orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the grating. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided grating. According to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, a refractive part may be present in the grating.\n\
\[InvisibleSpace]",
  StyleBox["CustomGrating",
    FontWeight->"Bold"],
  " refers to a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. For double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided components a list of two surfacefunctions is used. The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter indicates a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers designates a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GratingMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalGratingMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomGratingMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CustomGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a diffractive, reflective component that splits incoming rays \
into multiple diffracted, reflected orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the grating. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided grating. According to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, a refractive part may be present in the grating.  ",
  StyleBox["CustomGratingMirror",
    FontWeight->"Bold"],
  " refers to a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter indicates a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers relates to a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GratingMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomGratingSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CustomGratingSurface",
    FontWeight->"Bold"],
  " is obsolete. Please use ",
  StyleBox["CustomGrating",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomIntrinsicSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CustomIntrinsicSurface[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " that models the refractive index boundary between two different \
refractive mediums.\n\[InvisibleSpace]The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. Refractive components encountered by rays that have \
previously encountered ",
  StyleBox["CustomIntrinsicSurface",
    FontWeight->"Bold"],
  " are refracted using the new ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " value given by ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CustomIntrinsicSurface",
    FontWeight->"Bold"],
  " uses parameters ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " to obtain intrinsic index functions on each side of the fluid boundary. \
If the ray is coming from an environment that has an intrinsic index given by \
",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ". Likewise, if the ray is coming from an environment that has an intrinsic \
index given by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CustomIntrinsicSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. Please mote that all ",
  StyleBox["IntrinsicSurface-",
    FontWeight->"Bold"],
  "related functions are only intended for very specialized applications that \
involve changing the surrounding ambient environment of an optical system and \
are seldom ever used. For most applications involving refractive surfaces, a \
",
  StyleBox["LensSurface-",
    FontWeight->"Bold"],
  "type function should be used instead.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: the ",
  StyleBox["SwitchIntrinsicMedium",
    FontWeight->"Bold"],
  " genetic building block. ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " are all related components."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomJonesMatrixOptic", "Subsection"],

Cell[TextData[{
  StyleBox["CustomJonesMatrixOptic[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Jonesmatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is the underlying function of ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  " to create curved optics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomLens", "Subsection"],

Cell[TextData[{
  StyleBox["CustomLens[",
    FontWeight->"Bold"],
  StyleBox["f1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["f2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced refractive component having user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined surface functions.\n\[InvisibleSpace]The surfaces are given by ",
  StyleBox["f1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["f2",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["f1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["f2",
    FontSlant->"Italic"],
  " are three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface equations, and ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to specify planar surfaces. ",
  StyleBox["CustomLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CustomLensSurface[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " that models the refractive index boundary at a lens surface.\n\
\[InvisibleSpace]",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. The component shape, \
given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomLinearPolarizer", "Subsection"],

Cell[TextData[{
  StyleBox["CustomLinearPolarizer[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is the underlying function of ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  " to create curved optics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CustomMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomMirror[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a mirror that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", and a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["objectlabel",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. ",
  StyleBox["CustomMirror",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the maximum edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " option can be used to change substrate rear surface position in off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis parabolic mirrors. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " indicates that the substrate rear surface is located directly behind and \
parallel with the local off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis mirror surface. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " only ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is recognized. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the substrate orientation remains fixed with the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and parallel with the parabolic vertex. In addition, ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " changes the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken for the projected boundary shape onto the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane (as seen from projection down the primary optical (x) axis). For \
",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken as the actual boundary shape of the off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis surface (as seen by projection down the local surface normal). The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " option automatically changes its value to fit best with other ",
  StyleBox["options",
    FontSlant->"Italic"],
  " settings of ",
  StyleBox["CustomMirror",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named label parameter is optional and can be omitted. When it is present, \
its text content is used to identify the object in both the rendered graphics \
and the output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomPrism", "Subsection"],

Cell[TextData[{
  StyleBox["CustomPrism[",
    FontWeight->"Bold"],
  StyleBox["facetpointlisting",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " creates a multi",
  StyleBox["-",
    FontWeight->"Bold"],
  "faceted prism with user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified optical properties.\n\[InvisibleSpace]As its first parameter, ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  " accepts either a ",
  StyleBox["Graphics3D",
    FontWeight->"Bold"],
  " object or a nested list of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional points to describe the facet vertices. The optical properties \
of ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  " are specified by the ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " option. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomRays", "Subsection"],

Cell[TextData[{
  StyleBox["CustomRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", {{",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined rays.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["name",
    FontSlant->"Italic"],
  " parameter designates an optionname of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " contains the corresponding values. For example ",
  StyleBox["{RayStart, Flatten[Table[{",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["i",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["j",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["i",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  "3",
  StyleBox[", ",
    FontWeight->"Bold"],
  "3",
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["j",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  "2",
  StyleBox[", ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}], ",
    FontWeight->"Bold"],
  "1",
  StyleBox["]}",
    FontWeight->"Bold"],
  " can be used to define a planar equidistant grid of rays. All ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " parameters must have the same dimension or an integer multiple of the \
shortest ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". For ",
  StyleBox["ResolvePoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", every data point that generates a ray is considered to be an independent \
source.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " instead.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomRetardationPlate", "Subsection"],

Cell[TextData[{
  StyleBox["CustomRetardationPlate[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["wavedifference",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is the underlying function of ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  " to create curved optics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CustomScreen", "Subsection"],

Cell[TextData[{
  StyleBox["CustomScreen[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a component that intersects rays without disturbing them.\n\
\[InvisibleSpace]",
  StyleBox["CustomScreen",
    FontWeight->"Bold"],
  " denotes a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced component that has a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The component shape, given by ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ", is specified either by a function of two variables or by ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "0.",
  StyleBox["]",
    FontWeight->"Bold"],
  " for planar surfaces. Although ",
  StyleBox["CustomScreen",
    FontWeight->"Bold"],
  " is usually not rendered, the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "screen intersections can be rendered by using the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["PlotType->Surface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CustomScreen",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylinderGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["CylinderGraphic[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional cylinder with one circular center placed at the origin and its \
",
  StyleBox["length",
    FontSlant->"Italic"],
  " directed down the positive x axis.\n\[InvisibleSpace]",
  StyleBox["CylinderGraphic",
    FontWeight->"Bold"],
  " can be created with a partially opened side wall, using the option ",
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " from ",
  StyleBox["Options[CylinderGraphic]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " takes values ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["startangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["finishangle",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CylinderGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but can be listed with active \
components or with other graphics components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalBaffle[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CylindricalBaffle[",
    FontWeight->"Bold"],
  StyleBox["radii",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refer to a cylindrical component that absorbs light.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["CylindricalBaffle",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalDiffuser", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalDiffuser[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CylindricalDiffuser[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffusing, component that splits incoming rays into \
diffused rays rays after an optical surface using the ray scattering \
distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["CylindricalDiffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalDiffuserMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CylindricalDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffusing, reflective, component that splits incoming \
rays into diffused rays reflected rays after an optical surface using the ray \
scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser.\n\[InvisibleSpace]",
  StyleBox["CylindricalDiffuserMirror",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalGratingMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CylindricalGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffractive, reflective, component that splits \
incoming rays into multiple diffracted, reflected orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the grating. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided grating. According to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, a refractive part may be present in the grating. The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter denotes a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers indicates a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalLens", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalLens[",
    FontWeight->"Bold"],
  StyleBox["r1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " specifies a lens having cylindrical surfaces.\n\[InvisibleSpace]The radii \
of curvatures are specified by ",
  StyleBox["r1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["r2",
    FontSlant->"Italic"],
  " where ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " is used to specify planar surfaces. ",
  StyleBox["CylindricalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalLensSurface[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a cylindrical component occupying half a complete cylinder that \
models the refractive index boundary at a lens surface.\n\[InvisibleSpace]",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalMirror", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CylindricalMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refer to a cylindrical mirror.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["CylindricalMirror",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates the mirror on a flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "backed substrate. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalScreen", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalScreen[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a cylindrical component that intersects rays without \
disturbing them.\n\[InvisibleSpace]Although ",
  StyleBox["CylindricalScreen",
    FontWeight->"Bold"],
  " is usually not rendered, the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "screen intersections can be rendered by using the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["PlotType->Surface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CylindricalScreen",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CylindricalShape", "Subsection"],

Cell[TextData[{
  StyleBox["CylindricalShape",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that denotes the cylindrical ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToOptica", "Subsection"],

Cell[TextData[{
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["databaselist",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to build models in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " of optical components, light sources, coatings, and materials from the \
information given in ",
  StyleBox["databaselist",
    FontSlant->"Italic"],
  ". ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["databaselist",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " first calls ",
  StyleBox["SearchData",
    FontWeight->"Bold"],
  " to select for specific data items.\n\[InvisibleSpace]",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " automatically recognizes the appropriate model format for each type of \
data entry. ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " first passes ",
  StyleBox["databaselist",
    FontSlant->"Italic"],
  " and ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " to ",
  StyleBox["SearchData",
    FontWeight->"Bold"],
  ". If no ",
  StyleBox["databaselist",
    FontSlant->"Italic"],
  " is directly given, ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " uses the internally loaded catalog database according to the specified ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["ReportedInterval",
    FontWeight->"Bold"],
  " option to restrict the maximum number of models created at one time. Note \
that ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " may not use all present database information within the actual optical \
component models. See also: ",
  StyleBox["SearchData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReadData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SaveData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataToExcel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DefaultAngleSetting", "Subsection"],

Cell[TextData[{
  StyleBox["DefaultAngleSetting",
    FontWeight->"Bold"],
  " is an option of some built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in component functions that specifies one or more default settings for \
internal angles of the component",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DefaultGRINIndex", "Subsection"],

Cell[TextData[{
  StyleBox["DefaultGRINIndex",
    FontWeight->"Bold"],
  " specifys an spatial",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent, axial",
  StyleBox["-",
    FontWeight->"Bold"],
  "symmetric refractive index model that is given by the function: ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "(2.5",
  StyleBox["-",
    FontWeight->"Bold"],
  ".04",
  StyleBox["*Dot[SurfaceCoordinates,SurfaceCoordinates]",
    FontWeight->"Bold"],
  ")",
  StyleBox["/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  ". This is used by ",
  StyleBox["GRINLens",
    FontWeight->"Bold"],
  " when no other index model has been specified by the user. See also: ",
  StyleBox["GRINLens",
    FontWeight->"Bold"],
  ", GradeRefraction."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DefaultStyle", "Subsection"],

Cell[TextData[{
  StyleBox["DefaultStyle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["primitiveslist",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that gives a list of graphic primitives to be prepended to every \
component rendering and component label. See also",
  ":",
  " ",
  StyleBox["EdgeStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrossStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeflectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  " denotes the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing behavior at component surfaces.\n\[InvisibleSpace]",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " is used both as a function and as a rule parameter label in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". As a rule parameter label, ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  " is contained within the ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  " can be in a direct or indirect form. In the direct form, the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function is explicitly defined by the ",
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  ". In this case, ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[#]",
    FontWeight->"Bold"],
  " specifies a pure function that uses in its input a list of objects \
specified by ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " and returns its results to the objects specified by ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " as a list of modified ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects carrying only the ray or component parameters being modified. In \
the indirect form, the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function is defined elsewhere, and only parameter values are \
passed, rather than the actual ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function definition in the ",
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  ". In this case, ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["deflectionlabel",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["inputparameters",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["deflectionlabel",
    FontSlant->"Italic"],
  " as an identifying label to call up the appropriate external ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function. In the case of indirect ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function definitions, ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " also plays a role as the external function head. Here, ",
  StyleBox["DeflectionFunction[",
    FontWeight->"Bold"],
  StyleBox["deflectionlabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["inputparameters",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[#]",
    FontWeight->"Bold"],
  " denotes the external ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function identified by ",
  StyleBox["deflectionlabel",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionLabel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeflectionID", "Subsection"],

Cell[TextData[{
  StyleBox["DeflectionID",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies a unique identification number.\n\[InvisibleSpace]",
  StyleBox["DeflectionID",
    FontWeight->"Bold"],
  " is usually determined by the function ",
  StyleBox["Unique",
    FontWeight->"Bold"],
  " during the creation of a deflection. As a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionID",
    FontWeight->"Bold"],
  " indicates the deflection encountered by the ray segment. See also",
  ":",
  " ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Component",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeflectionLabel", "Subsection"],

Cell[TextData[{
  StyleBox["DeflectionLabel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["functionname",
    FontSlant->"Italic"],
  " denotes the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing behavior at component surfaces with the function that created the \
",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " parameter. See also",
  ":",
  " ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeflectionNumber", "Subsection"],

Cell[TextData[{
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the slot positions of ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions listed in ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " designates all ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions used when a ray hits the given surface. Each ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function is called up in sequence with its list position in ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Deflections", "Subsection"],

Cell[TextData[{
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["functionelement1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["functionelement2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "...",
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule giving a list of elements that define the various functions \
used in tracing rays within a component.\n\[InvisibleSpace]Each \
functionelement of ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " follows a standard format.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["{TakeFrom -> {",
    FontWeight->"Bold"],
  StyleBox["takefromobjects",
    FontSlant->"Italic"],
  StyleBox["}, AddTo -> {",
    FontWeight->"Bold"],
  StyleBox["addtoobjects",
    FontSlant->"Italic"],
  StyleBox["}, DeflectionFunction -> ",
    FontWeight->"Bold"],
  StyleBox["functionlisting",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "\n\[InvisibleSpace]Here ",
  StyleBox["takefromobjects",
    FontSlant->"Italic"],
  " denotes the objects used by ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["addtoobjects",
    FontSlant->"Italic"],
  " specifies the objects given by ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ". In some cases, ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " is used instead of ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DegreeUnits", "Subsection"],

Cell[TextData[{
  StyleBox["DegreeUnits",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that determines whether angular parameters have units of \
degrees or radians",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DeleteRecoveredOptions", "Subsection"],

Cell[TextData[{
  StyleBox["DeleteRecoveredOptions",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  " that indicates whether echoed input system expression is stripped of \
system options.\n\[InvisibleSpace]The ",
  StyleBox["DeleteRecoveredOptions",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is be used to delete all options from the echoed input system. This gives \
an much shorter expression with incomplete information that is easier to \
read. ",
  StyleBox["DeleteRecoveredOptions",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is the default setting that retains all of relevant option settings. ",
  StyleBox["DeleteRecoveredOptions->True",
    FontWeight->"Bold"],
  " is used in conjunction with the ",
  StyleBox["BuildComponent->True",
    FontWeight->"Bold"],
  " to study the internal working structure of a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " definition",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DensityValues", "Subsection"],

Cell[TextData[{
  StyleBox["DensityValues",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  " that scales the plotted values with the number of all source rays, so \
that the plot is independent of this number. ",
  StyleBox["DensityValues",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " leads to plots increasing in z values with the number of source rays.See \
also",
  ":",
  " ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DesignRefractiveIndex", "Subsection"],

Cell[TextData[{
  StyleBox["DesignRefractiveIndex",
    FontWeight->"Bold"],
  " is a database rule name that specifies a refractive index of a lens \
element at the design wavelength.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DesignWaveLength", "Subsection"],

Cell[TextData[{
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " is an option of most built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in lens functions that indicates the design wavelength value used in \
calculating the lens curvatures from the focal length specified",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dielectric", "Subsection"],

Cell[TextData[{
  StyleBox["Dielectric",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a dielectric medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DielectricTensor", "Subsection"],

Cell[TextData[{
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["PhaseRetardation",
    FontWeight->"Bold"],
  " function that defines a 3x3 matrix of dielectric values for the optical \
material.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  " works in combination with ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  ". For example, a typical setting for a biaxial material would be ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["nx",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["ny",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["nz",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["}}",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["nx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["ny",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["nz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " are three values of refractive index in the ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " directions. If ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["nx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["ny",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["nz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is specified together with ",
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " then the dielectric tensor is automatically generated from the ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " results. However, if both a ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  " are specified, then the ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " results are used to construct a base tensor which is subsequently added \
to the ",
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  " specification. ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " defines a dielectric coordinate system relative to the surface coordinate \
system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiffractedOrders", "Subsection"],

Cell[TextData[{
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " is an option that indicates the number of diffracted orders generated \
during diffraction.\n\[InvisibleSpace]",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " uses a list of ordered paired numbers that has a length of any size. The \
left number in each pair is an integer that specifies the diffracted order. \
The right number in each pair has a value between 0.0 and 1.0 that denotes \
the relative order strength. ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " is an option of all grating components, as well as the ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " genetic building block. However, it is only active with ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diffraction", "Subsection"],

Cell[TextData[{
  StyleBox["Diffraction[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block that produces diffracted rays through optical \
surfaces according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  " plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter refers to a uniformly distributed grating vector pointing \
horizontally with the surface. A list of two numbers indicates a uniformly \
distributed grating vector whose direction lies within the surface plane. An \
example of a functional grating parameter is ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  "0.",
  StyleBox[",",
    FontWeight->"Bold"],
  "1500.",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.",
  StyleBox["}]",
    FontWeight->"Bold"],
  ", which creates a uniform grating vector having 1500 lines per millimeter, \
pointing horizontally down the ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The gratingvector may depend on the values of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  ": ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " (as sequence",
  ")",
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ". Initially the grating vector starts in global ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " coordinates. The final orientation of the grating depends on three \
coordinate transformations. First, the gratingvector is transformed to the \
system given in the ",
  StyleBox["GratingRotationMatrix",
    FontWeight->"Bold"],
  " option. For ",
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  " set to ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", this is transformed into the system given by the local surface curvature \
direction. Finally, the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the surface transforms the gratingvector into global coordinates. The \
\"bending\" of the grating, the second transformation, does not take into \
account any strain of the grating.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " creates multiple diffracted rays according to the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option or according to the ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " does not take into account any refraction. For a thick grating, ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " must be placed both before and after ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " to get physically correct results.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", MaterialSpecification and ",
  StyleBox["DiffractionOrderNumber",
    FontWeight->"Bold"],
  " as ray parameters.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ". See also ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiffractionLimitedRange", "Subsection"],

Cell[TextData[{
  StyleBox["DiffractionLimitedRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["lowwavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["highwavelength",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name for a lens that specifies the range of \
wavelengths in microns for which the lens is diffraction limited.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["TransmissionRange",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WaveLengthRange",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiffractionMismatch", "Subsection"],

Cell[TextData[{
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " returned by diffractive components that denotes the mismatch fraction of \
the diffracted ray.\n\[InvisibleSpace]The mismatch fraction is defined as the \
difference in magnitude between the incident wave vector and the diffracted \
wave vector divided by the magnitude of the incident wave vector. ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  " can take on both positive and negative values. See also",
  ":",
  " ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GratingSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GratingMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiffractionOrderNumber", "Subsection"],

Cell[TextData[{
  StyleBox["DiffractionOrderNumber",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " returned by diffractive components that relates to the diffraction order \
of the ray.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GratingSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GratingMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diffuser", "Subsection"],

Cell[TextData[{
  StyleBox["Diffuser[",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Diffuser[",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a planar component that splits incoming rays into diffused rays \
using the ray scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalDiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DiffuserMirror", "Subsection"],

Cell[TextData[{
  StyleBox["DiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a planar component that splits incoming rays into diffused rays \
reflected rays after an optical surface using the ray scattering distribution \
pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalDiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DimensionalTolerance", "Subsection"],

Cell[TextData[{
  StyleBox["DimensionalTolerance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the manufacturing dimensional \
tolerances of an optical component expressed in units of either ",
  StyleBox["+-",
    FontWeight->"Bold"],
  " mm or as a percentage of the overall dimensions (indicated by a % sign",
  ")",
  ". See also: ",
  StyleBox["ThicknessTolerance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AngleTolerance",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DirectionChange", "Subsection"],

Cell[TextData[{
  StyleBox["DirectionChange",
    FontWeight->"Bold"],
  " is an unauthorized rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is an internal flag variable. It is used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " to indicate a reflection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DirectVisionPrism", "Subsection"],

Cell[TextData[{
  StyleBox["DirectVisionPrism[",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is constructed from three prisms cemented together that act as a \
dispersing element where spectral separation is required without any \
additional deviation of the beam.\n\[InvisibleSpace]The outer elements of ",
  StyleBox["DirectVisionPrism",
    FontWeight->"Bold"],
  " are commonly made from crown glass while the center element is made from \
flint glass. The ",
  StyleBox["length",
    FontSlant->"Italic"],
  " parameter gives the overall ",
  StyleBox["length",
    FontSlant->"Italic"],
  " of the component",
  StyleBox["'",
    FontWeight->"Bold"],
  "s base. ",
  StyleBox["DirectVisionPrism",
    FontWeight->"Bold"],
  " is normally aligned with its entrance face at x ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0 and the exit face positioned along the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dispersion", "Subsection"],

Cell[TextData[{
  StyleBox["Dispersion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["vd",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["ne",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ve",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["nf",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["nc",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nfprime",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["ncprime",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that specifies a traditional set of numbers to \
indicate how dispersive a given glass is",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DistortionGrid", "Subsection"],

Cell[TextData[{
  StyleBox["DistortionGrid[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gridsize",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gridpoints",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " creates a grid of rays to display the image distortion of an optical \
system.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The grid is rectangular in shape, where its dimensions are given by the ",
  StyleBox["gridsize",
    FontSlant->"Italic"],
  " parameter and the number of points along each grid dimension is specified \
by the ",
  StyleBox["gridpoints",
    FontSlant->"Italic"],
  " parameter. Both ",
  StyleBox["gridsize",
    FontSlant->"Italic"],
  " and ",
  StyleBox["gridpoints",
    FontSlant->"Italic"],
  " parameters may be given either as a single numeric value (to create a \
one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional set of points) or as a list of two numeric values (to create a \
two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional array of points",
  ")",
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["DistortionGrid",
    FontWeight->"Bold"],
  " result. However, when ",
  StyleBox["DistortionGrid",
    FontWeight->"Bold"],
  " is used in conjunction with ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter should be included using a point",
  StyleBox["-",
    FontWeight->"Bold"],
  "source function, such as ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DistortionGrid",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " internally and is principally used by ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DistributeValues", "Subsection"],

Cell[TextData[{
  StyleBox["DistributeValues",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  " that specifies, that a ray is distributed over all adjacent elements, \
taking into account its distance to the elements.See also",
  ":",
  " ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DonorSurfaceNumber", "Subsection"],

Cell[TextData[{
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["surfacenumber",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " that specifies which surface of the donor component gets its traits \
transferred to the recipient component.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  " can pass either: a single integer, ",
  StyleBox["First",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Last",
    FontWeight->"Bold"],
  " as a setting. See also",
  ":",
  " ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceBoundary",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DoubleSubstrate", "Subsection"],

Cell[TextData[{
  StyleBox["DoubleSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " indicates that the optical component consists of two thick optical \
substrates that are sandwiched together.\n\[InvisibleSpace]At the moment, ",
  StyleBox["DoubleSubstrate",
    FontWeight->"Bold"],
  " is only implemented with flat ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  " functions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DovePrism", "Subsection"],

Cell[TextData[{
  StyleBox["DovePrism[",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a six",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided prism having trapezoidal dimensions on two sides and rectangular \
dimensions on the remaining sides.\n\[InvisibleSpace]",
  StyleBox["DovePrism[",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["slantlength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is another pattern for ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  " is commonly used as an image rotator. As the prism is rotated, the image \
that passes through it will rotate at twice the angular rate of the prism. ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  " uses internal reflection off the hypotenuse face to rotate the image. The \
hypotenuse face of a dove prism is the face of the largest area. If the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, a reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surface is placed on the reflecting face of the prism. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DovePrismMirrored", "Subsection"],

Cell[TextData[{
  StyleBox["DovePrismMirrored",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DrawSystem", "Subsection"],

Cell[TextData[{
  StyleBox["DrawSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements defined by a mixed list of ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, traces the rays through the components, and renders the results \
according to the ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The option ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " can be used to suppress rendering and return an ",
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["lSystem",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " passes ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["Graphics",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Graphics3D",
    FontWeight->"Bold"],
  ". See also ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AnalyzeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTIRCLens", "Subsection"],

Cell[TextData[{
  StyleBox["DTIRCLens[",
    FontWeight->"Bold"],
  StyleBox["cf",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " defines a ",
  StyleBox["Dielectric",
    FontWeight->"Bold"],
  " Total Internal Reflecting Concentrator (DTIRC) having a spherical \
entrance surface, functionally defined tapered sides, and a planar exit \
surface.\n\[InvisibleSpace]Parameters for the functional shape are contained \
in ",
  StyleBox["cf",
    FontSlant->"Italic"],
  ", i.e., ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["C0",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["C1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["C2",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["C3",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["C4",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["r",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["ap",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["C0",
    FontSlant->"Italic"],
  " through ",
  StyleBox["C4",
    FontSlant->"Italic"],
  " are coefficients for a fourth order polynomial defining the shape of the \
sides, r1 is the radius of the spherical surface, and ",
  StyleBox["ap",
    FontSlant->"Italic"],
  " is the maximum diameter of the ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  " at the intersection of the sides and spherical entrance surface. The \
variable ",
  StyleBox["exitaperture",
    FontSlant->"Italic"],
  " is used to scale the specified ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  " shape to provide the desired aperture for the planar exit surface.\n\
\[InvisibleSpace]",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  " is created with the center of the spherical lens centered at the origin \
and the center of the planar exit surface positioned down the positive x \
axis. ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by William Cottingame, UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DTIRCLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["DTIRCLensSurface[",
    FontWeight->"Bold"],
  StyleBox["entranceaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["cf",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a functionally defined tapered surface to describe a ",
  StyleBox["Dielectric",
    FontWeight->"Bold"],
  " Total Internal Reflecting Concentrator (DTIRC).\n\[InvisibleSpace]",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  " is used internally by ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", but is not normally ever used directly and has only been made public for \
experimental purposes. Coefficients of a fourth order polnominal, contained \
in ",
  StyleBox["cf",
    FontSlant->"Italic"],
  ", have been optimized for a specific case, are calculated elsewhere, and \
are of a different form from the ",
  StyleBox["cf",
    FontSlant->"Italic"],
  " parameter defined for ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  " is created with its entrance aperture centered about the origin and its \
exit aperture positioned down the positive x axis. ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by William Cottingame, UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DummyRay", "Subsection"],

Cell[TextData[{
  StyleBox["DummyRay",
    FontWeight->"Bold"],
  " is a placeholder inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that designates a temporary ray object that is deleted before the ray \
trace is completed",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EdgeRendering", "Subsection"],

Cell[TextData[{
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that indicates the graphical rendering of an annular surface that joins \
the two outer perimeters of a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component. In the prism component, ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  " is used to define the two triangular faces of the prism.\n\
\[InvisibleSpace]",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  " may take the values: ",
  StyleBox["Fill",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Trace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mesh",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Empty",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{Fill, Mesh}",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EdgeStyle", "Subsection"],

Cell[TextData[{
  StyleBox["EdgeStyle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that indicates the graphical primitives to be inserted before the \
graphical rendering of an annular surface that joins the two outer perimeters \
of a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It is a list of two rules: ",
  StyleBox["LineStyle",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FillStyle",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["DefaultStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrossStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EdgeThickness", "Subsection"],

Cell[TextData[{
  StyleBox["EdgeThickness",
    FontWeight->"Bold"],
  " is a database rule name that gives the edge thickness of a lens",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EfficiencyFunction", "Subsection"],

Cell[TextData[{
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " is an option that indicates the diffraction efficiency of the grating \
component as a function of the ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  " parameter.\n\[InvisibleSpace]",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " uses a real function that scales ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " according to the value indicated by ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  ". ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " is initially set to return 1.0 for all input values",
  StyleBox[";",
    FontWeight->"Bold"],
  " however, the user can reset ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " for modeling the behavior of particular grating structures. ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " is an option of all grating components, as well as the ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " genetic building block. However, ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  " is largely not used anymore since it is used only  with the option ",
  StyleBox["CoupledWaveTheory->False",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ElasticModulus", "Subsection"],

Cell[TextData[{
  StyleBox["ElasticModulus",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["MegaPascals",
    FontSlant->"Italic"],
  " is a database rule name that indicates the modulus of elasticity for a \
material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ElementDirectory", "Subsection"],

Cell[TextData[{
  StyleBox["ElementDirectory",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a directory.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "This directory contains data on manufactured optical components",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ElementFiles", "Subsection"],

Cell[TextData[{
  StyleBox["ElementFiles",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a list of file names to be loaded.\n\[InvisibleSpace]These \
files contain information on manufactured optical components",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ellipse", "Subsection"],

Cell[TextData[{
  StyleBox["Ellipse",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["BoundaryLabel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HoleBoundaryLabel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EllipseAngle", "Subsection"],

Cell[TextData[{
  StyleBox["EllipseAngle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  " and FiberMirror that determines the angle of the elliptical long",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis in the fiber cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "section.\n\[InvisibleSpace]",
  StyleBox["EllipseAngle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 90 denotes a vertical",
  StyleBox["-",
    FontWeight->"Bold"],
  "oriented axis. See also",
  ":",
  " ",
  StyleBox["EllipseRatio",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EllipseRatio", "Subsection"],

Cell[TextData[{
  StyleBox["EllipseRatio",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  " and FiberMirror that determines the level of ellipticity in the fiber \
cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "section.\n\[InvisibleSpace]",
  StyleBox["EllipseRatio",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 1 denotes a circular cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "section. See also",
  ":",
  " ",
  StyleBox["EllipseAngle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EmbedGenerationLimit", "Subsection"],

Cell[TextData[{
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that fixes the ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  " information within ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " at the time of the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code creation.\n\[InvisibleSpace]",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " leaves the ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  " information as one of the input parameters of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ". ",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses the setting of ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["False",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["$generationlimit",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EmbedRays", "Subsection"],

Cell[TextData[{
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that fixes the geometric ray source information within ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " at the time of the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code creation.\n\[InvisibleSpace]",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " leaves the geometric ray information as one of the input parameters of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ". ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses the setting of ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["False",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is especially useful for repetitive ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace problems such as lens optimization and imaging problems where a \
component or light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source parameter is varied between each trace. ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " can greatly speed such problems where the system initialization consumes \
a significant fraction of the calculation time. In this instance, any \
symbolic parameter information passed with the light source is automatically \
included as an input parameter of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["$inputrays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EmbedThresholdIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that fixes the ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  " information within ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " at the time of the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code creation.\n\[InvisibleSpace]",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " leaves the ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  " information as one of the input parameters of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ". ",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses the setting of ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["False",
    FontWeight->"Bold"],
  " with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["$thresholdintensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy", "Subsection"],

Cell[TextData[{
  StyleBox["Energy",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["energy",
    FontSlant->"Italic"],
  " specifies the amount of integrated ",
  StyleBox["energy",
    FontSlant->"Italic"],
  " present either on a surface or in a system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EntranceCoordinates", "Subsection"],

Cell[TextData[{
  StyleBox["EntranceCoordinates",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the center coordinates of the first surface encountered within \
each confined migration pathway.\n\[InvisibleSpace]The slot position of the \
each ",
  StyleBox["EntranceCoordinates",
    FontWeight->"Bold"],
  " element corresponds with a slot position within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ". ",
  StyleBox["EntranceCoordinates",
    FontWeight->"Bold"],
  " is used in constructing ",
  StyleBox["UnconfinedPath",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " and ",
  StyleBox["UnconfinedPath",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EquivalentMagnification", "Subsection"],

Cell[TextData[{
  StyleBox["EquivalentMagnification",
    FontWeight->"Bold"],
  " is a database rule name that indicates the equivalent microscope \
objective magnification value.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Magnification",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EscapeComponent", "Subsection"],

Cell[TextData[{
  StyleBox["EscapeComponent[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that forces an increment to a new optical \
element after the ray encounters the specified surface given in the ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]",
  StyleBox["EscapeComponent",
    FontWeight->"Bold"],
  " preserves the initial increment direction of ray propagation through the \
",
  StyleBox["component",
    FontSlant->"Italic"],
  " listing. An earlier nested ",
  StyleBox["FreezeIncrement",
    FontWeight->"Bold"],
  " generic building block may be used to enable multiple ray interactions at \
the surface site before escaping.\n\[InvisibleSpace]",
  StyleBox["EscapeComponent",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["EscapeComponent",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ethanol", "Subsection"],

Cell[TextData[{
  StyleBox["Ethanol",
    FontWeight->"Bold"],
  " specifies the use of an ethanol liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Ethanol",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .43 microns to .66 microns. \
",
  StyleBox["Ethanol",
    FontWeight->"Bold"],
  " has a density of 0.800, relative to the density of water",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EvenFunction", "Subsection"],

Cell[TextData[{
  StyleBox["EvenFunction",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  " that indicates the use of even power polynomial terms as coefficients.\n\
\[InvisibleSpace]",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " indicates that the polynomial terms start with the second order power and \
followed with higher order even",
  StyleBox["-",
    FontWeight->"Bold"],
  "powered terms. For ",
  StyleBox["EvenFunction->False",
    FontWeight->"Bold"],
  ", the polynomial starts with the first order term and is followed by \
monotonically increasing power terms",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExcelToOptica", "Subsection"],

Cell[TextData[{
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import and convert Excel spreadsheet data into one or more \
optical lens models for ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]Normally, the number of columns is automatically \
determined by ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". As an alternative, ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["numberofcolumns",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " can be used to specify the number of filled spreadsheet columns. ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished by directly copying and pasting the data from Excel into \
Mathematica with double quotation marks placed manually on either side of the \
pasted data. The first row in the copied spreadsheet matrix must contain \
valid Mathematica option names that are used to identify the corresponding \
columns of information. Provided that the correct database information is \
present, ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " then converts this information into one or more optical lens models that \
work with ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". The conversion process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " (that get passed internally to ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  "). Note that ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " requires ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " to originate from a filled matrix in the spreadsheet. ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " makes internal calls to ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. Excel is a Trademark of Microsoft Corporation, \
Redmond WA. See also: ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExitPosition", "Subsection"],

Cell[TextData[{
  StyleBox["ExitPosition",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ABCDMatrix",
    FontWeight->"Bold"],
  " that denotes the starting position of the exiting ray from the component.\
\n\[InvisibleSpace]",
  StyleBox["ExitPosition",
    FontWeight->"Bold"],
  " uses either a number or a surface function of two variables",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExternalDeflectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ExternalDeflectionFunction[",
    FontWeight->"Bold"],
  StyleBox["deflectionid",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a global function used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to calculate ray deflections.\n\[InvisibleSpace]",
  StyleBox["ExternalDeflectionFunction",
    FontWeight->"Bold"],
  " is uniquely created for specific component ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " (identified by ",
  StyleBox["DeflectionID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["deflectionid",
    FontSlant->"Italic"],
  ")",
  " and provides a compile interface to uncompilable aspects of \
DeflectionFunctions in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExternalSurfaceIntersectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ExternalSurfaceIntersectionFunction[",
    FontWeight->"Bold"],
  StyleBox["surfaceid",
    FontSlant->"Italic"],
  StyleBox[", RSx, RSy, RSz, RTx, RTy, RTz]",
    FontWeight->"Bold"],
  " is a global function used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to calculate surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersections.\n\[InvisibleSpace]",
  StyleBox["ExternalSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " is uniquely created for specific component surfaces (identified by ",
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["surfaceid",
    FontSlant->"Italic"],
  ")",
  " and provides a compile interface to uncompilable \
SurfaceIntersectionFunctions in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In particular, ",
  StyleBox["ExternalSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ", since these cannot be directly compiled by Mathematica. See also: ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExtrapolateSurfaceFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ExtrapolateSurfaceFunction",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that specifies whether the surface function is continued automatically \
outside the aperture of the surface.\n\[InvisibleSpace]Some numeric \
functions, like ",
  StyleBox["InterpolatingFunction",
    FontWeight->"Bold"],
  ", are restricted to a parameter range. During the process of finding ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersections, the surface parameters can bounce off this range \
although the intersection is within the surface boundary. For ",
  StyleBox["ExtrapolateSurfaceFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", a continuation is generated and the calculation can succeed. ",
  StyleBox["ExtrapolateSurfaceFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " together with ",
  StyleBox["SurfaceNormalCalculations",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  " acts as the setting ",
  StyleBox["True",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]In order to generate an extrapolation, a parametric \
point outside the aperture of the surface is projected onto the aperture. The \
value of the surface function at this aperture point is then added to the \
derivative times the distance of the parametric and aperture points",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FarField", "Subsection"],

Cell[TextData[{
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that controls the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace modelling of ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " sources.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the rays are constructed to accurately simulate the divergence in the \
far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field of the beam waist. Any measurement taken near the beam waist, \
however, will not be accurately modelled with this setting. ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " accurately represents the spot size and divergence of Gaussian sources in \
the vicinity of the beam waist. For Gaussian beams that originate close to \
their beam waist position, however, ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " will not accurately model the far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field beam behavior. Nevertheless, for sources that do not originate close \
to their beam waist positions, both the far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field and near field behavior can be modelled by either ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " or ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ". In this situation, the results of ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " settings will be similar although ",
  StyleBox["FarField->True",
    FontWeight->"Bold"],
  " will be the most accurate for far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field measurements.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Note that the ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " option only affects the numerical ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace properties of ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " functions but has no effect on symbolic",
  StyleBox["-",
    FontWeight->"Bold"],
  "related calculations",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fiber", "Subsection"],

Cell[TextData[{
  StyleBox["Fiber[",
    FontWeight->"Bold"],
  StyleBox["corediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["claddingdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Fiber[",
    FontWeight->"Bold"],
  StyleBox["corediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a straight",
  StyleBox["-",
    FontWeight->"Bold"],
  "lined, stepped",
  StyleBox["-",
    FontWeight->"Bold"],
  "index optical fiber.\n\[InvisibleSpace]The refractive core and cladding \
materials are given by the option, ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["corematerial",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["claddingmaterial",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Fiber",
    FontWeight->"Bold"],
  " is created with an end located at x ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0 and with its ",
  StyleBox["length",
    FontSlant->"Italic"],
  " oriented along the x axis. When no ",
  StyleBox["claddingdiameter",
    FontSlant->"Italic"],
  " parameter is given, then the fiber is assumed to be uncladded with its \
outer surfaces exposed to the ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the environment. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  "Optica",
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["CustomFiber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomFiberMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FiberFunctionQ", "Subsection"],

Cell[TextData[{
  StyleBox["FiberFunctionQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FiberFunctionQ[{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " test whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " indicates one or more ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " objects that evalue to numerical result or a numerical value. The result \
is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field", "Subsection"],

Cell[TextData[{
  StyleBox["Field",
    FontWeight->"Bold"],
  " is a pattern of ",
  StyleBox["RayParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FieldOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["FieldOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of overlapping rays that point down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis (for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting",
  ")",
  " and are distributed over the specified range of ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " polarizations.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " parameter specifies the scaled ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " polarization between 0 and 1. It can be a single value or a range of two \
values. The vertical polarization is set to ",
  StyleBox["Sqrt[",
    FontWeight->"Bold"],
  "1",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["]",
    FontWeight->"Bold"],
  ". The number of ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " polarizations is given by the first number of the option ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", the number of polarization angles by the second.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PhaseAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FieldOfView", "Subsection"],

Cell[TextData[{
  StyleBox["FieldOfView",
    FontWeight->"Bold"],
  " is a database rule name that specifies the half",
  StyleBox["-",
    FontWeight->"Bold"],
  "angle field of view for a lens in degrees",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FieldStopLocation", "Subsection"],

Cell[TextData[{
  StyleBox["FieldStopLocation",
    FontWeight->"Bold"],
  " is a database rule name that provides the field stop surface number of a \
compound lens",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fill", "Subsection"],

Cell[TextData[{
  StyleBox["Fill",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates that the surface ",
  "graphics",
  " should be filled with shaded areas."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FillOffset", "Subsection"],

Cell[TextData[{
  StyleBox["FillOffset",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["percentage",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " and a rule embedded within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies the separation of the rendered surface net from the \
surface outline.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["percentage",
    FontSlant->"Italic"],
  " may also be a list, each entry corresponding to one surface. If the lines \
of the outline are partly covered by the surface net, this option can be used \
to artificially reduce the fill factor of the surface net",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FillStyle", "Subsection"],

Cell[TextData[{
  StyleBox["FillStyle",
    FontWeight->"Bold"],
  " is an option of optical components that carries a list of ",
  "graphics",
  " styles for the rendering of filled surfaces. See also: ",
  StyleBox["LineStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FilterAllCreatedRays", "Subsection"],

Cell[TextData[{
  StyleBox["FilterAllCreatedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a rule sometimes embedded within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " being used to filter the input to the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing ",
  StyleBox["function",
    FontSlant->"Italic"],
  " calculation.\n\[InvisibleSpace]The ",
  StyleBox["function",
    FontSlant->"Italic"],
  " takes as arguments the rays corresponding to the ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " and ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " rules and must return a single ray.\n\[InvisibleSpace]As word value of ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FilterAllCreatedRays",
    FontWeight->"Bold"],
  " acts on the filtered rays returned by ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FilterTrace", "Subsection"],

Cell[TextData[{
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that determines which rays are retained from a trace.\n\
\[InvisibleSpace]This option is used to discard certain types of surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray interactions during the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace process. This is used in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " during the scout trace process (for ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  "). In the case where multiple rays are generated at a optical surface, \
such as with diffraction gratings and ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " reflections, ",
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " retains only the strongest ray generated at each surface encounter. ",
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " passes all of the generated rays from the trace.\n\[InvisibleSpace]In \
addition to ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " settings, ",
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["orderfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectfunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to determine the ray selection criteria. The rays are ordered \
by using ",
  StyleBox["orderfunction",
    FontSlant->"Italic"],
  " inside ",
  StyleBox["OrderedQ",
    FontWeight->"Bold"],
  ". Then, the ray list is scanned with ",
  StyleBox["selectfunction",
    FontSlant->"Italic"],
  " to select rays. Both functions take a deflected ray as argument, the ",
  StyleBox["selectfunction",
    FontSlant->"Italic"],
  " takes additionally the slot number of the ray in the ordered ray sequence \
and the total number of rays created by the deflection. Examples of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["orderfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectfunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " include ",
  StyleBox["{",
    FontWeight->"Bold"],
  "(",
  StyleBox["Intensity/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#",
    FontWeight->"Bold"],
  "1)",
  StyleBox["&, ",
    FontWeight->"Bold"],
  "(",
  StyleBox["#",
    FontWeight->"Bold"],
  "2",
  StyleBox["===#",
    FontWeight->"Bold"],
  "3)",
  StyleBox["&}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  "1",
  StyleBox["&, ",
    FontWeight->"Bold"],
  "(",
  StyleBox["#",
    FontWeight->"Bold"],
  "2",
  StyleBox["===",
    FontWeight->"Bold"],
  "1",
  ")",
  StyleBox["&}",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FinalMerit", "Subsection"],

Cell[TextData[{
  StyleBox["FinalMerit",
    FontWeight->"Bold"],
  " returns the final performance value found by a minimization calculation \
in ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFocalSurface", "Subsection"],

Cell[TextData[{
  StyleBox["FindFocalSurface[",
    FontWeight->"Bold"],
  StyleBox["opticalsystem",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " determines the image surface of best focus in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space for an array of focus points that result from the ",
  StyleBox["DistortionGrid",
    FontWeight->"Bold"],
  " light source function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Internally, ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " to determine the foci positions. If the ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option setting is used, then ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  " returns a single ray for each foci position. Otherwise, ",
  StyleBox["FindFocalSurface",
    FontWeight->"Bold"],
  " returns a cluster of rays for each foci position according to the input \
source function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DistortionGrid",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFocus", "Subsection"],

Cell[TextData[{
  StyleBox["FindFocus[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " determines the minimum spot size for a locus of rays at the last reported \
surface in the system and plots the results.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The focus search is started at the last reported surface.  ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " returns a list of rules containing ",
  StyleBox["FocalPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocalPlaneTilt",
    FontWeight->"Bold"],
  ". Although ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " can use previously ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced results in ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  ", ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " need not be ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced in advance. To catch all rays of nonsequential optical systems, use \
a ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TracingEngine",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " (the default",
  ")",
  " for untraced systems or ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " when generating the system.\n\[InvisibleSpace]",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " minimizes the maximum distance from the first ray in ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  ". See also: ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFocusFast", "Subsection"],

Cell[TextData[{
  StyleBox["FindFocusFast[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " determines the minimum spot size for a locus of rays at the last reported \
surface in the system without plotting the results.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " returns a list of rules including ",
  StyleBox["FocalPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocalPlaneTilt",
    FontWeight->"Bold"],
  ". The focus search is started at the last reported surface. If necessary, \
the ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " is traced and",
  StyleBox["/",
    FontWeight->"Bold"],
  "or converted with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "To catch all rays of nonsequential optical systems, use a ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TracingEngine",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " (the default",
  ")",
  " for untraced systems or ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " when generating the system.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["delta",
    FontSlant->"Italic"],
  " suppresses optimization and assumes the focus to have the perpendicular \
distance ",
  StyleBox["delta",
    FontSlant->"Italic"],
  " from the last reported surface. ",
  StyleBox["IndependentSources",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " allows to find one focus for each source. ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " also returns a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object with ray ends corresponding to the ray segments from the before \
last surface to the focus. With ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " returns only one ray for each focus.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["TracingEngine",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindGlassNumbers", "Subsection"],

Cell[TextData[{
  StyleBox["FindGlassNumbers[",
    FontWeight->"Bold"],
  StyleBox["opticalmediumlist",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " calculates five important parameters traditionally used to characterize \
optical glasses: the refractive value, the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number, the mean dispersion value, the glasscodenumber, and the partial \
dispersion ratio.\n\[InvisibleSpace]The ",
  StyleBox["opticalmediumlist",
    FontSlant->"Italic"],
  " contains labels used to identify optical materials. If an optical \
material definition exists in the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " database but has not yet been created in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " to build a refractive index model corresponding to the opticalmedium \
label. ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option to specify the wavelength lines for its calculations. See also: ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["FindIntensity[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " calculates the intensity function for each optical surface that gets \
reported from the ray trace of the ",
  StyleBox["system",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For its input, ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " works best with either an untraced, raw, optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " or a previously calculated result of ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ". However, when necessary, ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " can also work with externally generated trace results. ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " works equally well for surfaces that either are close to a focal plane or \
far from any focus. If a light sheet light source is used (ie. ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  " or ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  "), then a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional intensity function is automatically calculated. If a volume",
  StyleBox["-",
    FontWeight->"Bold"],
  "filling light source is used (ie. ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ")",
  ", then the intensity calculations are automatically carried out for each \
reported surface in two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to specify a Gaussian smoothing kernel that gets convolved with the \
intensity data. This smoothing kernel can be set to the diffraction",
  StyleBox["-",
    FontWeight->"Bold"],
  "limited spot",
  StyleBox["-",
    FontWeight->"Bold"],
  "size of the systen in order to incorporate the diffraction",
  StyleBox["-",
    FontWeight->"Bold"],
  "limited behavior with the geometric ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace data.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " option to specify spatial scaling of the ",
  StyleBox["system",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["Energy",
    FontWeight->"Bold"],
  " option to manually specify the total integrated energy at the surface. \
With the default ",
  StyleBox["Energy->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " setting, the integrated energy is automatically determined from the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace information. However, ",
  StyleBox["Energy",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is used to manually specify a constant value for the total integrated \
energy. See also: ",
  StyleBox["IntensitySetting",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SmoothKernelRange",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindNumericNormalToDerivativePartials", "Subsection"],

Cell[TextData[{
  StyleBox["FindNumericNormalToDerivativePartials[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", {SCx,SCy}]",
    FontWeight->"Bold"],
  " finds the surface normal vector of a numeric ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " for the specific parametric coordinates given by ",
  StyleBox["{SCx,SCy}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Note that ",
  StyleBox["FindNumericNormalToDerivativePartials",
    FontWeight->"Bold"],
  " is not designed for high accuracy and is only used by \
FindExtrapolatedFunction to get an approximate result",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindSpotSize", "Subsection"],

Cell[TextData[{
  StyleBox["FindSpotSize[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes an object set containing ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects, and returns the diameter and position of a circle enclosing the \
locus of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection points that shares the common set of traits specified \
in ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  " works with either ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " or ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " results. If the ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " has not been ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced, then ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  " will first run ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". If no ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " are given, then the intersection points at the last surface are used. \
However, for ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " results, ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  " reveals only the spot size on the last surface and ignores any specified \
",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FinishPoint", "Subsection"],

Cell[TextData[{
  StyleBox["FinishPoint",
    FontWeight->"Bold"],
  " is a rule nested within ",
  StyleBox["RenderedPolygons",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional ending coordinate on a surface indicated by ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["FinishPoint",
    FontWeight->"Bold"],
  " is used for creating the sides of a polygon that span several surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FirstSlot", "Subsection"],

Cell[TextData[{
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " and indicates that the first slot position within each confined path in \
",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " inherits the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FlatSubstrate", "Subsection"],

Cell[TextData[{
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option that denotes that a curved mirror has a flat substrate back.\
\n\[InvisibleSpace]",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " creates a curved mirror substrate backing that is adjusted to maintain an \
equal thickness throughout the mirror. See also",
  ":",
  " ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FNumber", "Subsection"],

Cell[TextData[{
  StyleBox["FNumber",
    FontWeight->"Bold"],
  " is a database rule name that specifies the f",
  StyleBox["-",
    FontWeight->"Bold"],
  "number (also called f",
  StyleBox["/#",
    FontWeight->"Bold"],
  " or speed) of a lens.\n\[InvisibleSpace]The f",
  StyleBox["/#",
    FontWeight->"Bold"],
  " is defined by: (focal length)",
  StyleBox["/",
    FontWeight->"Bold"],
  "(clear aperture diameter",
  ")",
  ". See also: ",
  StyleBox["NA",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocalLength", "Subsection"],

Cell[TextData[{
  StyleBox["FocalLength",
    FontWeight->"Bold"],
  " is a database rule name that specifies the effective focal length of a \
lens.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FrontFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CatalogFocalLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocalPlaneTilt", "Subsection"],

Cell[TextData[{
  StyleBox["FocalPlaneTilt",
    FontWeight->"Bold"],
  " labels the unit vector that denotes the direction of the ray bundle",
  StyleBox["'",
    FontWeight->"Bold"],
  "s optical axis.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocalPoint", "Subsection"],

Cell[TextData[{
  StyleBox["FocalPoint",
    FontWeight->"Bold"],
  " indicates the point of focus in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocusDiameter", "Subsection"],

Cell[TextData[{
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " that specifies that the focus diameter is to be minimized. It is slower \
and more accurate than ",
  StyleBox["FocusRadius",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocusRadius", "Subsection"],

Cell[TextData[{
  StyleBox["FocusRadius",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " that specifies that the focus radius is to be minimized. It is faster and \
less accurate than ",
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocusRays", "Subsection"],

Cell[TextData[{
  StyleBox["FocusRays[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["focalpoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["efficiency",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that focuses the rays from the ",
  StyleBox["component",
    FontSlant->"Italic"],
  " surface to a chosen focal point in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space.\n\[InvisibleSpace]The ",
  StyleBox["efficiency",
    FontSlant->"Italic"],
  " parameter alters the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " value of the propagated rays and can be either a number or a held \
expression that evaluates to a value between zero and one",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FocusType", "Subsection"],

Cell[TextData[{
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  " is an option that specifies what is considered to be the focus. Allowed \
values are",
  ":",
  " ",
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocusRadius",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FollowContour", "Subsection"],

Cell[TextData[{
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " that indicates whether the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shape of the surface is taken into account in the ray \
scattering calculation.\n\[InvisibleSpace]In ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " indicates whether the scattering profile of non",
  StyleBox["-",
    FontWeight->"Bold"],
  "point seed",
  StyleBox["-",
    FontWeight->"Bold"],
  "sources take into account the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shape of the surface. ",
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " adjusts the starting points of displaced rays to fit the local surface \
contour. ",
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " does not use the surface contour information to construct displaced ray \
scattering.\n\[InvisibleSpace]In ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " indicates whether the grating vector is oriented with respect to the \
localized surface normal direction and follows the contour of the grating \
surface. Note that ",
  StyleBox["FollowContour",
    FontWeight->"Bold"],
  " with ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " is currently only implemented for ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and not with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ForwardDirection", "Subsection"],

Cell[TextData[{
  StyleBox["ForwardDirection",
    FontWeight->"Bold"],
  " is an unauthorized rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is an internal flag variable. It is used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " to indicate the propagation direction",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FreezeIncrement", "Subsection"],

Cell[TextData[{
  StyleBox["FreezeIncrement[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that causes the ray to remain targeted to the \
same surface for successive propagation generations.\n\[InvisibleSpace]This \
effect enables successive ray interactions with the same surface to occur. \
The ray is allowed to continue propagating to other surfaces once the current \
surface is no longer in its trajectory path. In ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FreezeIncrement",
    FontWeight->"Bold"],
  " is also an unauthorized option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". The ray parameter ",
  StyleBox["FreezeIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " causes rays not to increment to other surfaces until no intersection is \
found with the current surface.\n\[InvisibleSpace]",
  StyleBox["FreezeIncrement",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["FreezeIncrement",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrequencyCutoff", "Subsection"],

Cell[TextData[{
  StyleBox["FrequencyCutoff",
    FontWeight->"Bold"],
  " is a rule that gives the highest coherent spatial frequency present from \
the center frequency in the optical signal",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fresnel", "Subsection"],

Cell[TextData[{
  StyleBox["Fresnel[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["groovespacing",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used for transforming a regular optical \
element into a flattened ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " equivalent.\n\[InvisibleSpace]The ",
  StyleBox["groovespacing",
    FontSlant->"Italic"],
  " argument specifies the width of the ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " grooves and the groove direction is specified by the ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  " option. If ",
  StyleBox["SagFit->True",
    FontWeight->"Bold"],
  " is used then the ",
  StyleBox["groovespacing",
    FontSlant->"Italic"],
  " parameter denotes the depth of each groove and the groove width is varied \
to match the specified sag. ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " option to specify the ",
  StyleBox["component",
    FontSlant->"Italic"],
  " surfaces affected by ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " does not specify a number or list of numbers, ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " will transform all surfaces present. See also",
  ":",
  " ",
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SmoothKernelRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SagFit",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelReflections", "Subsection"],

Cell[TextData[{
  StyleBox["FresnelReflections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " that is used to suppress ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface reflections at a refractive interface.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Otherwise, ",
  StyleBox["FresnelReflections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " generates a reflected ray at the refractive interface that has an ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " value determined by the ray ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " state",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelRefraction", "Subsection"],

Cell[TextData[{
  StyleBox["FresnelRefraction",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a medium with normal ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " refraction",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelRhomb", "Subsection"],

Cell[TextData[{
  StyleBox["FresnelRhomb[",
    FontWeight->"Bold"],
  StyleBox["entranceface",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a special construction of ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  " that uses total",
  StyleBox["-",
    FontWeight->"Bold"],
  "internal ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " reflections to perform an achromatic retardation of either 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "4 wave or 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "2 wave on the incident light for polarization applications.\n\
\[InvisibleSpace]The ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " option is used to switch between half",
  StyleBox["-",
    FontWeight->"Bold"],
  "wave and quarter",
  StyleBox["-",
    FontWeight->"Bold"],
  "wave prism models. The default setting of ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " gives a 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "4 wave retardation by modeling a single ",
  StyleBox["RhomboidPrism-",
    FontWeight->"Bold"],
  "type object to create two internal reflections. ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " gives a 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "2 wave retardation by modeling a joined pair of ",
  StyleBox["RhomboidPrism-",
    FontWeight->"Bold"],
  "type objects to create four internal reflections. ",
  StyleBox["FresnelRhomb",
    FontWeight->"Bold"],
  " is aligned with its entrance face at x ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0 and located in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane to maintain a parallel exit beam with the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The ",
  StyleBox["entranceface",
    FontSlant->"Italic"],
  " specifies the smaller thickness dimension of the entrance face (the \
longer slant dimension is then internally calculated). ",
  StyleBox["FresnelRhomb",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["DefaultAngleSetting",
    FontWeight->"Bold"],
  " option to set the entrance angle. ",
  StyleBox["DefaultAngleSetting",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " calculates the angle based on the given ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ".  The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FresnelSymmetry", "Subsection"],

Cell[TextData[{
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " that indicates the groove symmetry of the ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " surface.\n\[InvisibleSpace]",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  " can be set to ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RadialSymmetry",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HorizontalSymmetry",
    FontWeight->"Bold"],
  ", ",
  StyleBox["VerticalSymmetry",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["OtherSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Front", "Subsection"],

Cell[TextData[{
  StyleBox["Front",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["CurvatureDirection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrontFocalLength", "Subsection"],

Cell[TextData[{
  StyleBox["FrontFocalLength",
    FontWeight->"Bold"],
  " is a database rule name for a lens that specifies the distance between \
the front focal point and the front lens surface.\n\[InvisibleSpace]See \
also",
  ":",
  " ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocalLength",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CatalogFocalLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrontSurface", "Subsection"],

Cell[TextData[{
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option that denotes that the first side of a mirror is reflective. \
This sometimes allows a simpler mirror model to be implemented.\n\
\[InvisibleSpace]",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " replaces a refractive surface at the front and a reflective surface at \
the back of the mirror. This incorporates a more complex refractive",
  StyleBox["/",
    FontWeight->"Bold"],
  "reflective propagation model into the component",
  StyleBox["'",
    FontWeight->"Bold"],
  "s description. ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  " is an option of all double",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided, built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in mirrors, except for conjugate mirrors. See also",
  ":",
  " ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrontView", "Subsection"],

Cell[TextData[{
  StyleBox["FrontView",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " that gives a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional orthoscopic rendering showing a projection onto the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane of the optical system.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full3D", "Subsection"],

Cell[TextData[{
  StyleBox["Full3D",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " that gives the full three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional rendering of the optical system.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Off",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FullPlotRange", "Subsection"],

Cell[TextData[{
  StyleBox["FullPlotRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["values",
    FontSlant->"Italic"],
  " is a rule sometimes embedded inside the ",
  StyleBox["Options",
    FontWeight->"Bold"],
  " rule of an optical system.\n\[InvisibleSpace]The ",
  StyleBox["values",
    FontSlant->"Italic"],
  " are number pairs specifying the minimum and maximum coordinates in each \
direction of the global coordinate system. The component ",
  "graphics",
  " as well as the rays are taken into account. The option does not depend on \
the option ",
  StyleBox["PlotRange",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FunctionCenter", "Subsection"],

Cell[TextData[{
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that gives the values of the component surface functions at the function \
origin.\n\[InvisibleSpace]Well",
  StyleBox["-",
    FontWeight->"Bold"],
  "behaved surface functions have finite values at their origin and the \
default setting ",
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is used. However, some custom",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined functions, whose limits approach infinity at their function \
origin, need to be manually set to some finite value, ",
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " where typically xi ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0. For a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced component, use ",
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["x",
    FontSlant->"Italic"],
  " where typically ",
  StyleBox["x",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0. See also",
  ":",
  " ",
  StyleBox["SurfaceCenter",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EntranceCoordinates",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FunnelLens", "Subsection"],

Cell[TextData[{
  StyleBox["FunnelLens[",
    FontWeight->"Bold"],
  StyleBox["domeradius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["entrancediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " defines a lens having a spherical entrance surface with the specified \
radius, parabolic tapered side walls defined by the entrance and exit \
aperture along with the ",
  StyleBox["length",
    FontSlant->"Italic"],
  ", and a planar exit surface.\n\[InvisibleSpace]",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  " is created with the center of the spherical lens centered at the origin \
and the center of the planar exit surface positioned down the positive x \
axis. ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by William Cottingame, UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FunnelLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["FunnelLensSurface[",
    FontWeight->"Bold"],
  StyleBox["entrancediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a parabolic tapered surface defined by entrance and exit \
aperture along with an overall ",
  StyleBox["length",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  " is used internally by ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", but is not normally ever used directly and has only been made public for \
experimental purposes. ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  " is created with its entrance aperture centered about the origin and its \
exit aperture positioned down the positive x axis. ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by William Cottingame, UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FusedSilica", "Subsection"],

Cell[TextData[{
  StyleBox["FusedSilica",
    FontWeight->"Bold"],
  " indicates the use of a fused silica medium.\n\[InvisibleSpace]The \
refractive index model for ",
  StyleBox["FusedSilica",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .18 microns to 2.0 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianBeam", "Subsection"],

Cell[TextData[{
  StyleBox["GaussianBeam[",
    FontWeight->"Bold"],
  StyleBox["beamspotsize",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fulldivergence",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GaussianBeam[",
    FontWeight->"Bold"],
  StyleBox["complexbeamparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a light source that takes either the output beam spotsize radius \
(specified at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e",
  StyleBox["^",
    FontWeight->"Bold"],
  "2 of the power density peak or 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of the electric field amplitude peak in the starting plane) and far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field beam ",
  StyleBox["fulldivergence",
    FontSlant->"Italic"],
  " (specified as the full angle in radians at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e",
  StyleBox["^",
    FontWeight->"Bold"],
  "2 of the power density peak or 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of the electric field) or the complex beam parameter as input and \
creates an extended point source ray model of a Gaussian laser beam.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " option to switch between observations carried out in the near",
  StyleBox["-",
    FontWeight->"Bold"],
  "field and far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field. Its default setting of ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " assumes that the divergence is low and the optical system is in the \
nearfield of the light source. However, this setting must be carefully \
examined for every optical arrangement.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In addition, ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " option to determine whether a uniform grid of rays are created or two \
distinct fans of rays are instead constructed. For ",
  StyleBox["FullForm->False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " creates either a single two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional fan of rays in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane or two cross",
  StyleBox["-",
    FontWeight->"Bold"],
  "hatched fans of rays that lie in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y and x",
  StyleBox["-",
    FontWeight->"Bold"],
  "z planes, depending on whether the spotsize and ",
  StyleBox["fulldivergence",
    FontSlant->"Italic"],
  " or ",
  StyleBox["complexbeamparameter",
    FontSlant->"Italic"],
  " contains single numbers or sets of two numbers. For ",
  StyleBox["FullForm->True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " attempts to construct a uniform three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional grid of rays to model the spot size and beam divergence \
behavior. In some instances, however, when the two transverse beam waists \
occur at different locations along the optical axis, then ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " cannot presently construct a full three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional model. In this event, it reverts to the ",
  StyleBox["FullForm->False",
    FontWeight->"Bold"],
  " behavior.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In order to generate an elliptical Gaussian beam, one needs to specify ",
  StyleBox["FullForm->True",
    FontWeight->"Bold"],
  ", provide a list of two values for the horizontal and vertical components \
of either ",
  StyleBox["beamspotsize",
    FontSlant->"Italic"],
  " or ",
  StyleBox["fulldivergence",
    FontSlant->"Italic"],
  ", and specify only the horizontal component of the remaining ",
  StyleBox["beamspotsize",
    FontSlant->"Italic"],
  " or ",
  StyleBox["fulldivergence",
    FontSlant->"Italic"],
  " parameter. In this instance, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " will automatically calculate the value of the remaining unspecified \
vertical component.\n\[InvisibleSpace]",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  " option to determine the spatial units of the ",
  StyleBox["beamspotsize",
    FontSlant->"Italic"],
  " input parameter. In its default setting, ",
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 1, the units are taken in millimeters. Note, however, that the ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " option is not affected by ",
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  " and always takes units of microns.\n\[InvisibleSpace]Each input parameter \
may also take a ",
  StyleBox["symbolic",
    FontSlant->"Italic"],
  " setting in addition to a ",
  StyleBox["numeric",
    FontSlant->"Italic"],
  " value. In such an event, a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "element list of terms, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["symbolic",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["numeric",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", is given for each ",
  StyleBox["symbolic",
    FontSlant->"Italic"],
  " parameter setting. In addition to geometric ray tracing, ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " is also used in ",
  StyleBox["symbolic",
    FontSlant->"Italic"],
  " Gaussian beam propagation calculations.\n\[InvisibleSpace]Note that the \
",
  StyleBox["RunningCommentary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/All",
    FontWeight->"Bold"],
  " option can be included with ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " to observe the internal processes involved.\n\[InvisibleSpace]See also: \
",
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FarField",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpotSizeFactor",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GenerationLimit", "Subsection"],

Cell[TextData[{
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that determines the maximum number of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface interactions permitted before the ray propagation is discontinued.\
\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GenerationNumber", "Subsection"],

Cell[TextData[{
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that specifies the maximum",
  StyleBox["-",
    FontWeight->"Bold"],
  "valued ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  " found within the global system of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects at the creation of the specified ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometry", "Subsection"],

Cell[TextData[{
  StyleBox["Geometry",
    FontWeight->"Bold"],
  " is a pattern of ",
  StyleBox["RayParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GetCoatingRules", "Subsection"],

Cell[TextData[{
  StyleBox["GetCoatingRules[",
    FontWeight->"Bold"],
  StyleBox["coatingmedium",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["deflectiontype",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["compiled",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["check",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns a list of two rules: ",
  StyleBox["CompiledCoating",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["coating",
    FontSlant->"Italic"],
  ", and a new ",
  StyleBox["deflectiontype",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The values of ",
  StyleBox["coating",
    FontSlant->"Italic"],
  StyleBox["[]",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["PrecisionFunction",
    FontWeight->"Bold"],
  " depending on",
  ":",
  " ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ". The order is fixed and automatically created from ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ". Inside a ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", the values are calculated by calling the function with all parameters. \
",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " as well ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  " are used in connection with birefringent or structured media.\n\
\[InvisibleSpace]For ",
  StyleBox["compiled",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the index functions are not ",
  StyleBox["compiled",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["check",
    FontSlant->"Italic"],
  " being ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the range checks. The ",
  StyleBox["options",
    FontSlant->"Italic"],
  " as well as ",
  StyleBox["coatingmedium",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  " are passed directly to ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GetMaterialRules", "Subsection"],

Cell[TextData[{
  StyleBox["GetMaterialRules[",
    FontWeight->"Bold"],
  StyleBox["medium",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["indices",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["materialrotation",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["temperature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["tension",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacenormalfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["compiled",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["check",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["theorymodifications",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns a list of rules, designating the ",
  StyleBox["medium",
    FontSlant->"Italic"],
  " used. Inside a ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["indices",
    FontSlant->"Italic"],
  " are calculated by calling the function with all parameters.\n\
\[InvisibleSpace]The second parameter gives a list of names to designate the \
",
  StyleBox["indices",
    FontSlant->"Italic"],
  " of interest and may contain ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermittivity",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Conductivity",
    FontWeight->"Bold"],
  ". For ",
  StyleBox["compiled",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the index functions are not ",
  StyleBox["compiled",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["check",
    FontSlant->"Italic"],
  " being ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the range checks. The ",
  StyleBox["theorymodifications",
    FontSlant->"Italic"],
  " can contain up to two elements, that describe the calculation method to \
be forced and are given as values or the rules ",
  StyleBox["FresnelReflections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " and DirectionCalculations ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  ". The rest of this parameter is a list of rules and passed directly to ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GetRealRefractiveIndex", "Subsection"],

Cell[TextData[{
  StyleBox["GetRealRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["medium",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["listofrules",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns the refractive index of ",
  StyleBox["medium",
    FontSlant->"Italic"],
  " using ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  ". If the material model does not return a number, the index is set to 1, \
an imaginary part is set to zero. The function is designed for fast \
calculations that cope only with a real refractive index",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GirdleThickness", "Subsection"],

Cell[TextData[{
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that specifies the thickness of the girdle (solitaire waist",
  ")",
  " as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter.\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GlassCodeFunction", "Subsection"],

Cell[TextData[{
  StyleBox["GlassCodeFunction[",
    FontWeight->"Bold"],
  StyleBox["input",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes variety of ",
  StyleBox["input",
    FontSlant->"Italic"],
  " formats and creates linear or second",
  StyleBox["-",
    FontWeight->"Bold"],
  "order, wavelength",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent, refractive index functions used in ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations.\n\[InvisibleSpace]",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " is used together with ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to designate a new material model. There are four basic ",
  StyleBox["input",
    FontSlant->"Italic"],
  " formats recognized by ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ". If the ",
  StyleBox["input",
    FontSlant->"Italic"],
  " is a number less than 100, then the ",
  StyleBox["input",
    FontSlant->"Italic"],
  " is assumed to be a fixed refractive index and ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " creates a constant refractive index function. If the ",
  StyleBox["input",
    FontSlant->"Italic"],
  " is a number greater than 100, then ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " recognizes this to be a glass code number and creates a linear glass \
dispersion model for it. Alternatively, when the ",
  StyleBox["input",
    FontSlant->"Italic"],
  " is a list of either two or three numbers: ",
  StyleBox["GlassCodeFunction[{",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Vd",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " (as well as ",
  StyleBox["GlassCodeFunction[{",
    FontWeight->"Bold"],
  StyleBox["Vd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  ") generates a linear glass dispersion model function and ",
  StyleBox["GlassCodeFunction[{",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Vd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Pdc",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " generates a second",
  StyleBox["-",
    FontWeight->"Bold"],
  "order glass dispersion model, where ",
  StyleBox["Vd",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (",
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "1)",
  StyleBox["/",
    FontWeight->"Bold"],
  "(nf",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc) is the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number, and ",
  StyleBox["Pdc",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (",
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "nc)",
  StyleBox["/",
    FontWeight->"Bold"],
  "(nf",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc) is the relative partial dispersion for the refractive material. Here, \
nf, ",
  StyleBox["nd",
    FontSlant->"Italic"],
  ", and nc are the refractive index values for three different wavelengths \
specified by the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ". In the case of ",
  StyleBox["GlassCodeFunction[{",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Vd",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GlassCodeFunction[{",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Vd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Pdc",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  ", the order of ",
  StyleBox["Vd",
    FontSlant->"Italic"],
  " and ",
  StyleBox["nd",
    FontSlant->"Italic"],
  " is automatically detected. The ",
  StyleBox["input",
    FontSlant->"Italic"],
  " parameters of ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " have long been associated with optical glasses. However, the ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " can be used to model any optical material.\n\[InvisibleSpace]",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  " is automatically called by ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to generate the index function if a single number or list of numbers is \
specified by the ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " option of a component function. In such cases, the default ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option setting is used. See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", IndexChart, PartialDispersionChart, and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GlassCodeNumber", "Subsection"],

Cell[TextData[{
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " (",
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "1",
  ")",
  ":",
  StyleBox["Vd",
    FontSlant->"Italic"],
  " is a rule name that specifies the standard six digit glass identification \
number of an optical glass.\n\[InvisibleSpace]The first three digits indicate \
the refractive index minus one of the material. The last three digits provide \
the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number of the material times a factor of ten. For example, a glass with an \
Nd of 1.517 and a V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number of 64.5 would be identified as 517645. Note: in rare cases where \
the refractive index reach a value of 2, the ",
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  " will contain seven digits. See also: ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GlassMap", "Subsection"],

Cell[TextData[{
  StyleBox["GlassMap[",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to illustrate dispersive properties of optical materials and to \
select new material models from the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " database.\n\[InvisibleSpace]",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["ReadData",
    FontWeight->"Bold"],
  " internally to select the optical data for display. If no ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " are given, then all loaded optical materials are displayed. ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " to specify the plotted parameters. In all cases, the optical materials \
are represented by distinct points on a graph. As an example of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", with either ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " or ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " gives a plot of the refractive index, ",
  StyleBox["nd",
    FontSlant->"Italic"],
  ", versus the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number for the selected database",
  StyleBox["-",
    FontWeight->"Bold"],
  "stored optical materials. The Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number, Vd ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (",
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "1) ",
  StyleBox["/",
    FontWeight->"Bold"],
  " (",
  StyleBox["nf",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["nc",
    FontSlant->"Italic"],
  "), is a measure of the chromatic aberration of the specified material in a \
lens component. The smaller the Abbe number, the greater will be the \
chromatic aberration contribution of the material to a lens. Here, ",
  StyleBox["nf",
    FontSlant->"Italic"],
  ", ",
  StyleBox["nd",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["nc",
    FontSlant->"Italic"],
  " are the refractive index values for three different wavelengths specified \
in the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ". As an alternative, ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{RefractiveIndex, AbbeVNumber}",
    FontWeight->"Bold"],
  " can also be used for the same effect.\n\[InvisibleSpace]Depending on the \
",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " values given, ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " gives a number of different point",
  StyleBox["-",
    FontWeight->"Bold"],
  "like representations for the refractive index and dispersive properties of \
optical materials. ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " can hold either one or a list of two values. If a single value is given, \
then the chosen value is plotted on the vertical axis, and the horizontal \
axis shows the ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ". Otherwise, ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["value1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to directly indicate the horizontal and vertical display \
parameters. ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " values can include: ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["nf",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nc",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["F",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["nf",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nc",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontWeight->"Bold"],
  " where ",
  StyleBox["F",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["nf",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nd",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["nc",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined expression. When ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " holds a list of two values, the value list order is usually not \
important. In particular, the ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  " parameters always take the horizontal axis regardless of their specified \
positions in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", unless both get specified simultaneously. In such a case, the ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  " parameter gets plotted on the vertical axis and the ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  " parameter remains plotted on the horizontal axis. However, in the case of \
two user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " parameters, the first ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " parameter takes the horizontal axis while the second ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " parameter takes the vertical axis.\n\[InvisibleSpace]",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " has two different modes of operation: rendering of data and creation of \
new optical material models. ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " is initially used to create a plot of optical material points. In its \
plotting mode, ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " to indicate display of the Schott glass boundaries and ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " to indicate display of the material names with their corresponding \
points. Finally, ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " can be used to create new refractive index models in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " for specific selected materials. Once a plot has been generated in any ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " format by one ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " function, the mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "sampled coordinate points can then be copied and pasted as ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " into a second ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " function having the same ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " setting to generate new optical material models. When ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " receives one or more sets of coordinate points in ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " identifies the corresponding optical material types and calls ",
  StyleBox["Data",
    FontWeight->"Bold"],
  StyleBox["To",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  " names of each identified material. ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "then creates a new refractive index model for each material and ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  " reports a message about each newly defined material.\n\
\[InvisibleSpace]See also: ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SearchData",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReadData",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Glycerine", "Subsection"],

Cell[TextData[{
  StyleBox["Glycerine",
    FontWeight->"Bold"],
  " indicates the use of a glycerine liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Glycerine",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .43 microns to .66 microns. \
",
  StyleBox["Glycerine",
    FontWeight->"Bold"],
  " has a density of 1.260, relative to the density of water",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GradedRefraction", "Subsection"],

Cell[TextData[{
  StyleBox["GradedRefraction[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that traces rays through a curved tragectory \
within a graded",
  StyleBox["-",
    FontWeight->"Bold"],
  "index material that lies between two surfaces.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Note that ",
  StyleBox["GradedRefraction",
    FontWeight->"Bold"],
  " requires two surfaces to be present. Also note that GradeRefraction still \
requires the separate application of the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " function to model external refractive surfaces in the system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GraphicalOutput", "Subsection"],

Cell[TextData[{
  StyleBox["GraphicalOutput[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  "graphics",
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object carrying the listing of graphics primitives for the \
rendering of components.\n\[InvisibleSpace]In general, the list order of ",
  StyleBox["component",
    FontSlant->"Italic"],
  "graphics",
  " corresponds with the list order of the specified component elements."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GraphicDesign", "Subsection"],

Cell[TextData[{
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " is an option of all rendered components that specifies the style of \
rendering.\n\[InvisibleSpace]",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " can be set to ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Sketch",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wire",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solid",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]It can also be used ss an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". In the form ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["name",
    FontSlant->"Italic"],
  ", it changes the rendering of all components, ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " or ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " changes the rendering of the ",
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "th component. ",
  StyleBox["Components",
    FontWeight->"Bold"],
  " with no rendering information, even not ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", are not changed",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grating", "Subsection"],

Cell[TextData[{
  StyleBox["Grating[",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating[",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Grating[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a diffractive component that splits incoming rays into multiple \
diffracted orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter refers to the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " dimension of the grating substrate. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is assumed to have no substrate. According \
to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, the physical grating material may also have a physical ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " within a separate refractive emulsion layer. Note that the total ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  " is given by the substrate ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " in addition to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " parameter. When ",
  StyleBox["DoubleSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is specified, the grating is sandwiched between two substrates of equal \
",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". (Note that ",
  StyleBox["DoubleSubstrate",
    FontWeight->"Bold"],
  " only applies to flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced gratings).",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter indicates a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers designates a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". Note that ",
  StyleBox["VacuumFrequency->False",
    FontWeight->"Bold"],
  " assumes the grating function has already incorporated the refractive \
index of the grating material. However, if ",
  StyleBox["VacuumFrequency->False",
    FontWeight->"Bold"],
  " is specified, then ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " will include an additional refractive index factor to the grating \
magnitude.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GratingMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalGratingMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingFunction", "Subsection"],

Cell[TextData[{
  StyleBox["GratingFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a rule that designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " describing the grating vector.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingFunctionQ", "Subsection"],

Cell[TextData[{
  StyleBox["GratingFunctionQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingFunctionQ[{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " test whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " indicates one or more ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " objects that evalue to numerical result or a numerical value. The result \
is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingMedium", "Subsection"],

Cell[TextData[{
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  " is an option that indicates the material of the grating. It is specified \
as the option ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " for refractive components. For surface gratings it affects only the \
grating vector, if ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is specified.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingMirror", "Subsection"],

Cell[TextData[{
  StyleBox["GratingMirror[",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMirror[",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicate a planar, diffractive, reflective component that splits incoming \
rays into multiple diffracted, reflected orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the grating. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided grating. According to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, a refractive part may be present in the grating. The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter designates a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers specifies a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingModulation", "Subsection"],

Cell[TextData[{
  StyleBox["GratingModulation",
    FontWeight->"Bold"],
  " is an option that indicates the modulation of the grating. A single \
value, or the first value in a list, refers to the given grating function, \
from the second value on, harmonics of the grating function are specified. \
For phase gratings, each entry in the list is a list of two values: the \
medium used for modelling and two functions describing the modulation of the \
refractive and attenuation index. The attenuation is yet not used in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " is compiled internally and may take additional arguments in the same \
order as used by the indices returned by ",
  StyleBox["GetMaterialRules",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ". An example: ",
  StyleBox["{BK7, Function[",
    FontWeight->"Bold"],
  "0.02",
  StyleBox["*#",
    FontWeight->"Bold"],
  "1",
  StyleBox["*",
    FontWeight->"Bold"],
  "(1",
  StyleBox["-",
    FontWeight->"Bold"],
  "(",
  StyleBox["#",
    FontWeight->"Bold"],
  "5",
  StyleBox["-",
    FontWeight->"Bold"],
  "20)",
  StyleBox["/",
    FontWeight->"Bold"],
  "1000)",
  StyleBox["], Function[#",
    FontWeight->"Bold"],
  "1",
  StyleBox["], Function[#",
    FontWeight->"Bold"],
  "1",
  StyleBox["]}",
    FontWeight->"Bold"],
  " for a modulation with 2% of the refractive index of ",
  StyleBox["BK7",
    FontWeight->"Bold"],
  ", slightly depending on temperature.\n\[InvisibleSpace]See also: ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingRotationMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["GratingRotationMatrix",
    FontWeight->"Bold"],
  " is an option that indicates the orientation of the given gratingfunctions \
in the same way as ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". The orientation is relative to the surface, on which the grating is.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingStrength", "Subsection"],

Cell[TextData[{
  StyleBox["GratingStrength",
    FontWeight->"Bold"],
  " is an unauthorized rule of ray that denotes the local strength of a \
grating. It is defined as ",
  StyleBox["Pi*",
    FontWeight->"Bold"],
  "n1",
  StyleBox["*",
    FontWeight->"Bold"],
  "d",
  StyleBox["/WaveLength/Sqrt[",
    FontWeight->"Bold"],
  StyleBox["cR",
    FontSlant->"Italic"],
  StyleBox["*",
    FontWeight->"Bold"],
  StyleBox["cS",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ", with n1 as first ",
  StyleBox["Fourier",
    FontWeight->"Bold"],
  " coefficient of the square of the refractive index modulation, d grating \
thickness, ",
  StyleBox["cR",
    FontSlant->"Italic"],
  " and ",
  StyleBox["cS",
    FontSlant->"Italic"],
  " direction cosine of the incident and the diffracted wave.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingSurface", "Subsection"],

Cell[TextData[{
  StyleBox["GratingSurface",
    FontWeight->"Bold"],
  " is obsolete. Please use ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  " with no thickness instead",
  ".",
  " "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GratingThickness", "Subsection"],

Cell[TextData[{
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " is an option that indicates the thickness of the grating in microns.\n\
\[InvisibleSpace]It may be a function of the values of the options ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " (as sequence), ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ". The function is compiled internally and used for volume gratings (",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ")",
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["GridOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays distributed within a tube",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped volume that points down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a list of two positive numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " forms a rectangular grid of dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a single number, then ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " forms a circular grid of rays that has a diameter dictated by ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["size",
    FontSlant->"Italic"],
  " is a list of two negative numbers ",
  StyleBox["{-",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " forms an elliptical grid of elliptical dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The number of rays in each of the grid dimensions is given in the option \
",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ". ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " may also point to a list of two numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rays1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rays2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " for each direction of the grid of starting points. For circular and \
elliptical shapes the total number of rays is (",
  StyleBox["rays1",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "1",
  ")",
  StyleBox["*",
    FontWeight->"Bold"],
  StyleBox["rays2",
    FontSlant->"Italic"],
  StyleBox["+",
    FontWeight->"Bold"],
  "1 to get a single ray at the center.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridSize", "Subsection"],

Cell[TextData[{
  StyleBox["GridSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["spacings",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that indicates the spacing of ruled lines.\n\[InvisibleSpace]",
  StyleBox["GridSize",
    FontWeight->"Bold"],
  " can accept one, two, or three number values for indicating different ",
  StyleBox["spacings",
    FontSlant->"Italic"],
  " in each measurement direction. ",
  StyleBox["GridSize",
    FontWeight->"Bold"],
  " works with ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " and supplies information for the standard ",
  StyleBox["GridLines",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FaceGrids",
    FontWeight->"Bold"],
  " options",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridSpacing", "Subsection"],

Cell[TextData[{
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  " is an option of ray sources that designates the spacing of rays to be \
generated by a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "source function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  " takes a coordinate parameter as an argument that changes with both the \
source function type and the ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " setting. With ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["CartesianCoordinates",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  " often takes the projected grid in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z",
  StyleBox["-",
    FontWeight->"Bold"],
  "plane with unity dimensions. However, with ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["PolarCoordinates",
    FontWeight->"Bold"],
  ", the coordinate parameters are usually angles in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y and x",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane.\n\[InvisibleSpace]In general, ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " must yield a compilable expression. For ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  " returns the wavelength and intensity distribution. For two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional sources as well as for ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  " is a list of two functions. In general, each ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "source function type can have a different ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " format requirement. For example, with ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[Log[#]]",
    FontWeight->"Bold"],
  " produces a logarithmic spacing. With ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " ",
  StyleBox["->{Function[#], Function[Exp[-",
    FontWeight->"Bold"],
  "1000",
  StyleBox["*",
    FontWeight->"Bold"],
  "(",
  StyleBox["#-",
    FontWeight->"Bold"],
  "0.6",
  ")",
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["]]}",
    FontWeight->"Bold"],
  " produces a broad spectral line at 0.6 microns. The default translation is \
",
  StyleBox["Function[#]",
    FontWeight->"Bold"],
  ", the default for ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  " is ",
  StyleBox["{Function[#], Function[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]}",
    FontWeight->"Bold"],
  ". Internally a gridpoint is calculated as ",
  StyleBox["spacingfunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The argument of ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " changes for each type of source function. Here are several examples:",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ": y",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ":",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ":",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  ":",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Here, the circumference position can be either a length or an angle with \
different the light source shapes. Correspondingly, x, y, and radius \
coordinates can be either lengths or opening angles."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GrinLens", "Subsection"],

Cell[TextData[{
  StyleBox["GrinLens",
    FontWeight->"Bold"],
  " designates an unimplemented component that focuses rays according to a \
gradient index profile",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GRINLens", "Subsection"],

Cell[TextData[{
  StyleBox["GRINLens[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " defines an  optical lens component that incorporates the behavior of \
graded",
  StyleBox["-",
    FontWeight->"Bold"],
  "index refraction. When the ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter is a single number, the ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " specifies a circular boundary and the lens is constructed with a \
cylindrical refractive surface model for its edges. For shaps, the edge \
surfaces of the lens are not presently modeled. ",
  StyleBox["GRINLens[",
    FontWeight->"Bold"],
  StyleBox["radius1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["radius2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GRINLens[",
    FontWeight->"Bold"],
  StyleBox["function1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["function2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " are also supported by ",
  StyleBox["GRINLens",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["DefaultGRINIndex",
    FontWeight->"Bold"],
  ", GradeRefraction."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Group", "Subsection"],

Cell[TextData[{
  StyleBox["Group",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that identifies a group of objects. ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objectnumber",
    FontSlant->"Italic"],
  " selects an object representing the group, ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["groupposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["grouprotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " sets the group in the global coordinates. If the option ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " is not present or its values are not valid, the orientation and position \
of a group is given by its first object. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GroupDescription", "Subsection"],

Cell[TextData[{
  StyleBox["GroupDescription",
    FontWeight->"Bold"],
  " is an obsolete option of that is no longer in use",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GroupLabels", "Subsection"],

Cell[TextData[{
  StyleBox["GroupLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["labelnames",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that replaces the previously defined values of ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " with one or more new label names.\n\[InvisibleSpace]",
  StyleBox["GroupLabels",
    FontWeight->"Bold"],
  " is usually accompanied with a new specification for ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GroupMagnification", "Subsection"],

Cell[TextData[{
  StyleBox["GroupMagnification",
    FontWeight->"Bold"],
  " is a database rule name that specifies the overall magnification of a \
lens system.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Magnification",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HalfBallLens", "Subsection"],

Cell[TextData[{
  StyleBox["HalfBallLens[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an hemispherical refractive component.\n\[InvisibleSpace]With the \
option setting ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HalfBallLens",
    FontWeight->"Bold"],
  " is created with its flat, second surface at the coordinate origin. With \
",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BallLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldAxesCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldAxesCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " calculating the local coordinates of a ray.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Axes",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the calculation of the local values. A three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional local coordinate system is given by the XAxis parallel to the \
surface in ray direction, the YAxis perpendicular to the ray and the plane of \
incidence, and the ZAxis perpendicular to the surface in ray direction. The \
PAxis is perpendicular to the ray in the plane of incidence. The amplitude of \
the incident ray is given by ",
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  ", the projection on the YAxis and PAxis as perpendicularamplitude and \
parallelamplitude. The ray tilt projections on XAxis and ZAxis are raytiltz, \
raytiltx.\n\[InvisibleSpace]",
  StyleBox["HeldAxesCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". Some building blocks combine the geometry and wave calculations to get \
faster ",
  StyleBox["code",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldAxesList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldAxesList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with code to define some values in local \
surface coordinates.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldAxesList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldBoundaryCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldBoundaryCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " checking intersections for validity.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldBoundaryCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldBoundaryList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldBoundaryList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code checking intersections for \
validity.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldBoundaryList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldComponent", "Subsection"],

Cell[TextData[{
  StyleBox["HeldComponent[",
    FontWeight->"Bold"],
  StyleBox["genetic",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["traits",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object that has the ",
  StyleBox["HoldAll",
    FontWeight->"Bold"],
  " attribute set. See also",
  ":",
  " ",
  StyleBox["Component",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldDeflectionInitialization", "Subsection"],

Cell[TextData[{
  StyleBox["HeldDeflectionInitialization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " initializing the deflection calculation.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A surface normal matrix, component and surface number as well as the ray \
before the deflection are assigned. ",
  StyleBox["HeldDeflectionInitialization",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldDeflectionInitializationList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldDeflectionInitializationList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with code to initialize symbols before the \
deflection calculation.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldDeflectionInitializationList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldDeflectionList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldDeflectionList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code calculating the deflection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldDeflectionList",
    FontWeight->"Bold"],
  " is created automatically or may be given by a user with the function ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  ". ",
  StyleBox["HeldDeflectionList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldGeometryCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldGeometryCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " calculating the new ray directions returning a list of rays.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "This ",
  StyleBox["code",
    FontSlant->"Italic"],
  " is executed as first step to get new rays. The deflection initialization \
provides values for some local values, given in a ",
  StyleBox["HeldAxesCalculation",
    FontWeight->"Bold"],
  " rule.\n\[InvisibleSpace]For example, a reflection yields ",
  StyleBox["HeldGeometryCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[RayTilt = RayTilt - ",
    FontWeight->"Bold"],
  "2",
  StyleBox["*",
    FontWeight->"Bold"],
  StyleBox["ZAxis",
    FontSlant->"Italic"],
  StyleBox["*Dot[",
    FontWeight->"Bold"],
  StyleBox["ZAxis",
    FontSlant->"Italic"],
  StyleBox[",RayTilt]; {Ray}]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["HeldGeometryCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". Some building blocks combine the geometry and wave calculations to get \
faster ",
  StyleBox["code",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldGeometryList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldGeometryList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code calculating the geometry (and \
wave values",
  ")",
  " of a deflection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldGeometryList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldGraphicalOutput", "Subsection"],

Cell[TextData[{
  StyleBox["HeldGraphicalOutput[",
    FontWeight->"Bold"],
  "graphics",
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object containing ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  " information that has the ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  " attribute.\n\[InvisibleSpace]See also ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldHoleCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldHoleCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " checking intersections for being inside a surface hole.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldHoleCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldHoleList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldHoleList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code checking intersections for \
being inside a surface hole.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldHoleList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldInitialization", "Subsection"],

Cell[TextData[{
  StyleBox["HeldInitialization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " to be executed  before the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Usually, the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " initializes all symbols newly introduced. For example, a unidimensional \
real ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and an integer ",
  StyleBox["scalar",
    FontSlant->"Italic"],
  " can yield ",
  StyleBox["HeldInitialization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox[" = {",
    FontWeight->"Bold"],
  "1.",
  StyleBox["}; ",
    FontWeight->"Bold"],
  StyleBox["scalar",
    FontSlant->"Italic"],
  StyleBox[" = ",
    FontWeight->"Bold"],
  "1",
  StyleBox["]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["HeldInitialization",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldIntersectionCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldIntersectionCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " to find ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersections.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldIntersectionCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldIntersectionList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldIntersectionList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code to calculate a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldIntersectionList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldOpticalSystem", "Subsection"],

Cell[TextData[{
  StyleBox["HeldOpticalSystem[{",
    FontWeight->"Bold"],
  StyleBox["listofrays",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofsources",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox["}, GraphicalOutput[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], Options->",
    FontWeight->"Bold"],
  StyleBox["opts",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object containing an ordered listing of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects, ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, and ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  " that has the ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  " attribute.\n\[InvisibleSpace]See also ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldPolarizationCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldPolarizationCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " calculating the new polarization.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A new rotation matrix and polarization is calculated for all deflected \
rays. The option ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " may suppress this calculation. ",
  StyleBox["HeldPolarizationCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldPolarizationList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldPolarizationList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with code for a new rotation matrix and \
polarization.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldTransformationMatrixList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldRayEndCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldRayEndCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " to calculate a new ray end and optical length.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldRayEndCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldRayEndList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldRayEndList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code to get the ray to the new \
surface.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldBoundaryList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldRayInitialization", "Subsection"],

Cell[TextData[{
  StyleBox["HeldRayInitialization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " to be executed before the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "intersection calculation.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For example, the local ray tilt is calculated here. ",
  StyleBox["HeldRayInitialization",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldRayInitializationList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldRayInitializationList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with assignments of ray values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldRayInitializationList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldSurfaceInitialization", "Subsection"],

Cell[TextData[{
  StyleBox["HeldSurfaceInitialization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " to be executed after the ray initialization and before the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "intersection calculation.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It sets a few surface specific values and is normally not changed. ",
  StyleBox["HeldSurfaceInitialization",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldSurfaceInitializationList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldSurfaceInitializationList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with assignments of surface values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldSurfaceInitializationList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldSymbolTypes", "Subsection"],

Cell[TextData[{
  StyleBox["HeldSymbolTypes",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["listofsymbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a list of symbol declarations.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The format is the same as used in ",
  StyleBox["Compile",
    FontWeight->"Bold"],
  ". For example, a declaration of a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional real ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and a complex ",
  StyleBox["scalar",
    FontSlant->"Italic"],
  " is given as ",
  StyleBox["HeldSymbolTypes",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[{{",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox[",_Real,",
    FontWeight->"Bold"],
  "1",
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["scalar",
    FontSlant->"Italic"],
  StyleBox[",_Complex}}]",
    FontWeight->"Bold"],
  ". The declarations are used to generate a custom tracing engine of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["HeldSymbolTypes",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldTraceKernel", "Subsection"],

Cell[TextData[{
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["heldcode",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " denotes the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing behavior at component surfaces.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to help construct the compiled ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " information. The rule corresponds to a function ",
  StyleBox["HeldTraceKernel[",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["parameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ". As an example, a mirror with the ",
  StyleBox["reflectance",
    FontSlant->"Italic"],
  " ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  StyleBox["reflectance",
    FontSlant->"Italic"],
  StyleBox["*Temperature/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  ", is accessed with ",
  StyleBox["HeldTraceKernel[Reflection, Function[",
    FontWeight->"Bold"],
  StyleBox["reflectance",
    FontSlant->"Italic"],
  StyleBox["], {Temperature -> ",
    FontWeight->"Bold"],
  "20",
  StyleBox["}]",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["options",
    FontSlant->"Italic"],
  " are used to replace values that are not present in ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["heldcode",
    FontSlant->"Italic"],
  " contains the information of the evaluated ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " rule, but uses ray option names for ",
  StyleBox["parameters",
    FontSlant->"Italic"],
  ". For example, a transmission with 80% transmittance yields ",
  StyleBox["HeldWaveCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[AllCreatedRays = Map[",
    FontWeight->"Bold"],
  "(",
  StyleBox["Intensity = Intensity * ",
    FontWeight->"Bold"],
  "0.8",
  StyleBox["; Ray",
    FontWeight->"Bold"],
  ")",
  StyleBox["&, AllCreatedRays]]",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["heldcode",
    FontSlant->"Italic"],
  " may access all information being used in ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ". A ray is present as the symbol ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", being a placeholder like the ray option names. ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  " represents all rays being created by a deflection.\n\[InvisibleSpace]The \
symbols of built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in kernels are in the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " private context (",
  StyleBox["$",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["PrivateContext",
    FontWeight->"Bold"],
  "). If user code is not defined with the private context being accessible \
(",
  StyleBox["$Context",
    FontWeight->"Bold"],
  " or ",
  StyleBox["$ContextPath",
    FontWeight->"Bold"],
  " set accordingly), the symbols must be accessed with full qualified names, \
context included.\n\[InvisibleSpace]",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " are not taken into account. See also: ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceIntersections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NoSurfaceIntersection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldTransformationMatrixCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldTransformationMatrixCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " calculating a transformation matrix.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "With this matrix, vectors can be rotated to the coordinate system of the \
deflected rays. The ",
  StyleBox["PAxis",
    FontSlant->"Italic"],
  ", see help on ",
  StyleBox["HeldGeometryCalculation",
    FontWeight->"Bold"],
  ", can be transformed to the new system with ",
  StyleBox["Dot[",
    FontWeight->"Bold"],
  StyleBox["TransformationMatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["PAxis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " skips the calculation of the matrix.\n\[InvisibleSpace]",
  StyleBox["HeldTransformationMatrixCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldTransformationMatrixList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldTransformationMatrixList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with code to rotate vectors according to the \
new ray tilt.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldTransformationMatrixList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldWaveCalculation", "Subsection"],

Cell[TextData[{
  StyleBox["HeldWaveCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[",
    FontWeight->"Bold"],
  StyleBox["code",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that holds a ",
  StyleBox["CompoundExpression",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["code",
    FontSlant->"Italic"],
  " calculating the new wave parameters, like intensity.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For example, a transmission of 50% yields ",
  StyleBox["HeldWaveCalculation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Hold[AllCreatedRays = Map[",
    FontWeight->"Bold"],
  "(",
  StyleBox["Intensity = Intensity * ",
    FontWeight->"Bold"],
  "0.5",
  StyleBox["; Ray",
    FontWeight->"Bold"],
  ")",
  StyleBox["&, AllCreatedRays]]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["HeldWaveCalculation",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HeldWaveList", "Subsection"],

Cell[TextData[{
  StyleBox["HeldWaveList",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " is a rule that holds a list with the code calculating the wave values of \
a deflection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["HeldWaveList",
    FontWeight->"Bold"],
  " is used for the creation of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HerzbergerFunction", "Subsection"],

Cell[TextData[{
  StyleBox["HerzbergerFunction[",
    FontWeight->"Bold"],
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["e",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes five terms and creates the pure function ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["-",
    FontWeight->"Bold"],
  "0.028)",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["-",
    FontWeight->"Bold"],
  "0.028)",
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["e",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "4)",
  StyleBox["/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  " used to model the index of refraction versus wavelength for various \
materials.\n\[InvisibleSpace]",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  " is used together with ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to designate ",
  StyleBox["a",
    FontSlant->"Italic"],
  " new material model. ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  " is also used by ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "to model Germanium and other infrared crystalline materials. See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hole", "Subsection"],

Cell[TextData[{
  StyleBox["Hole[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block for creating a hole within a ",
  StyleBox["component",
    FontSlant->"Italic"],
  " surface.\n\[InvisibleSpace]The ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " parameter specifies the hole dimensions, which can be either circular, \
rectangular, or polygonal. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " also modifies the ",
  StyleBox["component",
    FontSlant->"Italic"],
  " rendering to show the hole. You can use the ",
  StyleBox["HoleOffset",
    FontWeight->"Bold"],
  " option to position the hole away from the affected surface center.\n\
\[InvisibleSpace]The ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " as well as ",
  StyleBox["Options[HoleBoundary]",
    FontWeight->"Bold"],
  " show ",
  "Optica",
  "`s internal behavior and are ignored by ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HoleBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the hole aperture dimensions for the last surface to intercept \
the ray.\n\[InvisibleSpace]",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  " is also a rule parameter of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and is nested within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule when a hole in the surface is present. Its value is always a list of \
boundaries.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["SymbolicHoleBoundary",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HoleOffset",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HoleBoundaryLabel", "Subsection"],

Cell[TextData[{
  StyleBox["HoleBoundaryLabel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["label",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that designates a boundary type of a hole",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HoleOffset", "Subsection"],

Cell[TextData[{
  StyleBox["HoleOffset",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the offset dimensions of a hole aperture for the last surface \
to intercept the ray.\n\[InvisibleSpace]",
  StyleBox["HoleOffset",
    FontWeight->"Bold"],
  " is also a rule parameter of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and is nested within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule when a hole in the surface is present. Its value is always a list of \
offsets. It is independent of the values given in the ",
  StyleBox["OffAxis",
    FontWeight->"Bold"],
  " option, it does not add to these values.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SymbolicHoleOffset",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HollowCornerCube", "Subsection"],

Cell[TextData[{
  StyleBox["HollowCornerCube[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided retro",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflective mirror arrangement having a single circular entrance",
  StyleBox["/",
    FontWeight->"Bold"],
  "exit face that is located in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and three reflecting surfaces that are arranged about the positive \
x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis.\n\[InvisibleSpace]",
  StyleBox["HollowCornerCube",
    FontWeight->"Bold"],
  " behaves like a corner cube. There can be two different forms of ",
  StyleBox["HollowCornerCube",
    FontWeight->"Bold"],
  ": with ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the reflective surfaces have square boundaries",
  StyleBox[";",
    FontWeight->"Bold"],
  " with ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the reflective surfaces have polygonal boundaries that shorten the \
overall thickness of the reflector. For ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HollowCornerCube",
    FontWeight->"Bold"],
  " is created with a circular",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped absorbing annulus placed at the entrance plane. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["SolidCornerCube",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hologram", "Subsection"],

Cell[TextData[{
  StyleBox["Hologram",
    FontWeight->"Bold"],
  " denotes an unimplemented component that behaves as a hologram, recording \
various rays positions and directions and reconstructing them for various \
WaveLengths and reference phase fronts",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HorizontalSymmetry", "Subsection"],

Cell[TextData[{
  StyleBox["HorizontalSymmetry",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  " that implies that the surface grooves are symmetric about the component",
  StyleBox["'",
    FontWeight->"Bold"],
  "s vertical axis.\n\[InvisibleSpace]See ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HousingBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["HousingBoundary",
    FontWeight->"Bold"],
  " is a database rule name that specifies the dimensions of an inert housing \
structure that surrounds an optical component.\n\[InvisibleSpace]",
  StyleBox["HousingBoundary",
    FontWeight->"Bold"],
  " may follow the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " convention for lens apertures, where a single number indicates the \
diameter of a circular shape and a list of two numbers indicate a rectangular \
shaped boundary. However, ",
  StyleBox["HousingBoundary",
    FontWeight->"Bold"],
  " can also be used to specify the shapes of other object forms. See also: \
",
  StyleBox["ComponentBoundary",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Identify", "Subsection"],

Cell[TextData[{
  StyleBox["Identify",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that returns internally information on a selected ",
  StyleBox["object",
    FontSlant->"Italic"],
  " in a list.\n\[InvisibleSpace]",
  StyleBox["Identify",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to select the objects getting displayed. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". If no ",
  StyleBox["object",
    FontSlant->"Italic"],
  " is found, ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  " returns information on all invisible ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects.\n\[InvisibleSpace]The list returned is: ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["objectnumber",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectoptions",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectdefaultoptions",
    FontSlant->"Italic"],
  StyleBox[", Move, ",
    FontWeight->"Bold"],
  StyleBox["moveparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["moveoptions",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["movedefaultoptions",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["object",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImageSampleSize", "Subsection"],

Cell[TextData[{
  StyleBox["ImageSampleSize",
    FontWeight->"Bold"],
  " is a rule that gives the smallest spatial sample size at the image \
(focal",
  ")",
  " plane."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IncrementComponentNumber", "Subsection"],

Cell[TextData[{
  StyleBox["IncrementComponentNumber[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentincrement",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that increments ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", relative to its present value.\n\[InvisibleSpace]",
  StyleBox["IncrementComponentNumber",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["IncrementComponentNumber",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndependentScattering", "Subsection"],

Cell[TextData[{
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " is an option of most generic building blocks that controls the generation \
of the ",
  StyleBox["WaveFrontID",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "True creates for every incoming ray a new identifier, ",
  StyleBox["False",
    FontWeight->"Bold"],
  " assigns an identifier corresponding to the slot position of a generated \
ray in the list of generated rays. For example, diffusers usually use ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", refraction with ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " reflection uses ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". For a component, ",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " can also specify a list that distributes over the generic building blocks \
being called.\n\[InvisibleSpace]As an option to ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " collects all wavefronts of the seed rays together that are deflected with \
the option ",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ". For example a diffuser then does not create one surface path for every \
incident seed ray, but only one. ",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " collects all wave fronts together. Both settings do not change the rule \
",
  StyleBox["WaveFrontID",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " is also an unauthorized ray parameter",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndependentSources", "Subsection"],

Cell[TextData[{
  StyleBox["IndependentSources",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " that controls what rays are taken to find the focus. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", each source has its own focus. Otherwise the focus built by all rays is \
calculated. ",
  StyleBox["IndependentSources",
    FontWeight->"Bold"],
  " is independent of the option ",
  StyleBox["IndependentWaveFronts",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndependentSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that indicates a different deflection function segment will be used at \
each surface.\n\[InvisibleSpace]",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  " can only be used when ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " receives a listing of new deflection function segments to match the total \
number of the surfaces present. In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndependentWaveFronts", "Subsection"],

Cell[TextData[{
  StyleBox["IndependentWaveFronts",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " that controls what rays are taken to find the focus. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", each wave front has its own focus. Otherwise the focus built by all wave \
fronts is calculated. ",
  StyleBox["IndependentWaveFronts",
    FontWeight->"Bold"],
  " is independent of the option ",
  StyleBox["IndependentSources",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndexCoefficients", "Subsection"],

Cell[TextData[{
  StyleBox["IndexCoefficients",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofcoefficients",
    FontSlant->"Italic"],
  " is a database rule name that specifies coefficients for the refractive \
index function specified by ",
  "Optica",
  StyleBox["Function",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also ",
  StyleBox["WaveLengthRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndexFunction", "Subsection"],

Cell[TextData[{
  StyleBox["IndexFunction[",
    FontWeight->"Bold"],
  StyleBox["a0",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a4",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a5",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes six terms and creates the pure function ",
  StyleBox["Function[Sqrt[",
    FontWeight->"Bold"],
  StyleBox["a0",
    FontSlant->"Italic"],
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a1",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a2",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^-",
    FontWeight->"Bold"],
  "2",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a3",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^-",
    FontWeight->"Bold"],
  "4",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a4",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^-",
    FontWeight->"Bold"],
  "6",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a5",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^-",
    FontWeight->"Bold"],
  "8",
  StyleBox["]/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  " used to model the index of refraction versus wavelength for various \
materials.\n\[InvisibleSpace]",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  " is used together with ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to designate a new material model. ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  " (also known as the Schott glass formula) is commonly generated by ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  " and used to model most of ",
  "Optica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in materials. See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndexInterpolationFunction", "Subsection"],

Cell[TextData[{
  StyleBox["IndexInterpolationFunction[{{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to create an interpolating function to represent the ",
  StyleBox["index",
    FontSlant->"Italic"],
  " of refraction versus ",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  " for various materials.\n\[InvisibleSpace]",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  " is used together with ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to designate a new material model. ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  " internally uses ",
  StyleBox["Interpolation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InterpolatingFunction",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Interpolation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InterpolatingFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InfinityFocusAngle", "Subsection"],

Cell[TextData[{
  StyleBox["InfinityFocusAngle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " that controls what maximum angle deviation from the mean ray directions \
is considered to represent a focus at infinity.\n\[InvisibleSpace]For a focus \
at infinity, ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FocalPoint",
    FontWeight->"Bold"],
  " gives the position, where the spot size was calculated",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InitializeSource", "Subsection"],

Cell[TextData[{
  StyleBox["InitializeSource[",
    FontWeight->"Bold"],
  StyleBox["inputrays",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["sourcename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["sourceparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a utility function that is used by ",
  "Optica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in light source definitions to create a new ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]",
  StyleBox["InitializeSource",
    FontWeight->"Bold"],
  " takes the given ",
  StyleBox["sourcename",
    FontSlant->"Italic"],
  ", ",
  StyleBox["sourceparameters",
    FontSlant->"Italic"],
  ", and any nested ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects specified by ",
  StyleBox["inputrays",
    FontSlant->"Italic"],
  ", and returns a new ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " object. During this initialization of the ",
  StyleBox["Source",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InitializeSource",
    FontWeight->"Bold"],
  " builds and installs the necessary rules and structures which make up a ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " object."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InputEdgeThickness", "Subsection"],

Cell[TextData[{
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " specifies whether the center thickness or the edge thickness is given by \
the thickness input argument of an optical component function.\n\
\[InvisibleSpace]",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " denotes that the thickness argument of component function gives the \
component edge dimension. ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " indicates that the thickness argument of component function specifies the \
center of the component. ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " is used primarily with curved mirrors and wedge",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped optics such as ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WedgeBeamSplitter",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InsertDeflection", "Subsection"],

Cell[TextData[{
  StyleBox["InsertDeflection[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used to connect surfaces to additional \
deflections.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["InsertDeflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["deflectionnumbers",
    FontSlant->"Italic"],
  " takes numbers for deflections and attaches them to all surfaces given in \
the option ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["RemoveDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RemoveSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InsideHoleBoundaryQ", "Subsection"],

Cell[TextData[{
  StyleBox["InsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " if the given parametric point is within the hole boundary.\n\
\[InvisibleSpace]The ",
  StyleBox["InsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " can simultaneously manage several holes within the same surface. The ",
  StyleBox["InsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " rule is located within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. See also",
  ":",
  " ",
  StyleBox["SymbolicInsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InsideMedium", "Subsection"],

Cell[TextData[{
  StyleBox["InsideMedium",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Box",
    FontWeight->"Bold"],
  " that sets the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " used within the middle of ",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Box",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InsideSurfaceBoundaryQ", "Subsection"],

Cell[TextData[{
  StyleBox["InsideSurfaceBoundaryQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " if the given parametric point is within the surface boundary.\n\
\[InvisibleSpace]",
  StyleBox["InsideSurfaceBoundaryQ",
    FontWeight->"Bold"],
  " is constructed inside ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " from the ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  " information and is automatically embedded within the ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " by ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["InsideSurfaceBoundaryQ",
    FontWeight->"Bold"],
  " rule is also located within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BoundaryChecked",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intensity", "Subsection"],

Cell[TextData[{
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the ray",
  StyleBox["'",
    FontWeight->"Bold"],
  "s intensity value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntensityFunction", "Subsection"],

Cell[TextData[{
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is an option of most sources that specifies a function to calculate \
intensities. The arguments to ",
  StyleBox["f",
    FontSlant->"Italic"],
  " are the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayEnd",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RaySourceNumber",
    FontWeight->"Bold"],
  ". The evaluation of ",
  StyleBox["f",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " must be a compilable expression, which returns an intensity value. E. g. \
a Gaussian beam can be modelled with ",
  StyleBox["GridOfRays[",
    FontWeight->"Bold"],
  "10",
  StyleBox[", IntensityFunction -> Function[#",
    FontWeight->"Bold"],
  "1",
  StyleBox["*Exp[-Dot[#",
    FontWeight->"Bold"],
  "3",
  StyleBox[",#",
    FontWeight->"Bold"],
  "3",
  StyleBox["]/",
    FontWeight->"Bold"],
  "25",
  StyleBox["]]]",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  " is also a returned rule of ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " that contains the calculated intensity function information. In addition, \
",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  " is also the head of a function that contains intensity information",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntensityScale", "Subsection"],

Cell[TextData[{
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and a passed parameter of ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " that specifies a fractional scaling value for the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter in order to correspond with the total integrated ",
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  " of the light source.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " is dynamically generated at the start of the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace and is used for making energy calculations by some built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in functions, such as ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ", and depends on the specified ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " as well as any specified ",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  ". Note that ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " does not directly alter the value of ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " but instead specifies a scaling for ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " is currently only implemented for ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntensitySetting", "Subsection"],

Cell[TextData[{
  StyleBox["IntensitySetting",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  StyleBox["/Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " that sets the central intensity value of the intensity function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["IntensitySetting",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " fixes the central point to the specified ",
  StyleBox["number",
    FontSlant->"Italic"],
  ". Otherwise, ",
  StyleBox["IntensitySetting",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " leaves the intensity function unchanged. ",
  StyleBox["IntensitySetting",
    FontWeight->"Bold"],
  " only works with the ",
  StyleBox["Energy",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " setting",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InterceptHole", "Subsection"],

Cell[TextData[{
  StyleBox["InterceptHole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that indicates whether the traced rays will pass through \
holes without interception or not",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InternalDirectionChange", "Subsection"],

Cell[TextData[{
  StyleBox["InternalDirectionChange",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is an internal flag variable. It is used by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " to indicate an internal reflection inside a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced component.\n\[InvisibleSpace]This causes ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " to increment backwards within the component",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["InternalTransmittance", "Subsection"],

Cell[TextData[{
  StyleBox["InternalTransmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  StyleBox["},",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that gives a list of bulk transmittance values \
(",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " in cm",
  StyleBox["^-",
    FontWeight->"Bold"],
  "1) for various wavelengths (given in nm",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntersectionNumber", "Subsection"],

Cell[TextData[{
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the total number of surface intersections encountered for the \
creation of the specified ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntrinsicCylindricalSurface", "Subsection"],

Cell[TextData[{
  StyleBox["IntrinsicCylindricalSurface[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a cylindrical component occupying half a complete cylinder that \
models the refractive index boundary between two different refractive \
mediums.\n\[InvisibleSpace]Refractive components encountered by rays that \
have previously encountered ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " are refracted using the new ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " value given by ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " uses parameters ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " to obtain intrinsic index functions on each side of the fluid boundary. \
If the ray is coming from an environment that has an intrinsic index given by \
",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ". Likewise, if the ray is coming from an environment that has an intrinsic \
index given by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ". ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. Please mote that all ",
  StyleBox["IntrinsicSurface-",
    FontWeight->"Bold"],
  "related functions are only intended for very specialized applications that \
involve changing the surrounding ambient environment of an optical system and \
are seldom ever used. For most applications involving refractive surfaces, a \
",
  StyleBox["LensSurface-",
    FontWeight->"Bold"],
  "type function should be used instead.\n\[InvisibleSpace]See also: ",
  StyleBox["SwitchIntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " are all related components."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntrinsicIndex", "Subsection"],

Cell[TextData[{
  StyleBox["IntrinsicIndex",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " giving a label that identifies the background refractive index value \
surrounding components.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " are other options involving the refractive index."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntrinsicMedium", "Subsection"],

Cell[TextData[{
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " giving a label that identifies the background optical medium surrounding \
components.\n\[InvisibleSpace]As examples: ",
  StyleBox["Air",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Water",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Vacuum",
    FontWeight->"Bold"],
  " are typical settings for ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " is also an option of ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ". Then, it can take a medium name or general material characteristics with \
the same values ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " can take. Any rule specified in ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " is applied before ray options, which then must contain the same intrinsic \
medium. This option narrows the possible ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " options of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", but can speed up calculations.\n\[InvisibleSpace]The ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " rule of ray always specifies a material that is isotropic and dielectric. \
The refractive index model is not checked for correct input.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " are other options involving the refractive index."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntrinsicSphericalSurface", "Subsection"],

Cell[TextData[{
  StyleBox["IntrinsicSphericalSurface[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a spherical component that has a given ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " of curvature that models the refractive index boundary between two \
different refractive mediums.\n\[InvisibleSpace]Refractive components \
encountered by rays that have previously encountered ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  " are refracted using the new ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " value given by ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  " uses parameters ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " to obtain intrinsic index functions on each side of the fluid boundary. \
If the ray is coming from an environment that has an intrinsic index given by \
",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ". Likewise, if the ray is coming from an environment that has an intrinsic \
index given by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ". ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. Please mote that all ",
  StyleBox["IntrinsicSurface-",
    FontWeight->"Bold"],
  "related functions are only intended for very specialized applications that \
involve changing the surrounding ambient environment of an optical system and \
are seldom ever used. For most applications involving refractive surfaces, a \
",
  StyleBox["LensSurface-",
    FontWeight->"Bold"],
  "type function should be used instead.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["SwitchIntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  " are all related components."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntrinsicSurface", "Subsection"],

Cell[TextData[{
  StyleBox["IntrinsicSurface[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a planar component that models the refractive index boundary \
between two different refractive mediums.\n\[InvisibleSpace]Refractive \
components encountered by rays that have previously encountered ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  " are refracted using the new ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " value given by ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  " uses parameters ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " to obtain intrinsic index functions on each side of the fluid boundary. \
If the ray is coming from an environment that has an intrinsic index given by \
",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ". Likewise, if the ray is coming from an environment that has an intrinsic \
index given by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is replaced by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ". ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. Please mote that ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  " is only intended for very specialized applications that involve changing \
the surrounding ambient environment of an optical system and are seldom ever \
used. For most applications involving refractive surfaces, the ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " function should be used instead.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["SwitchIntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicSphericalSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicCylindricalSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomIntrinsicSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Isotropic", "Subsection"],

Cell[TextData[{
  StyleBox["Isotropic",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " to characterize an isotropic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JacobianMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["JacobianMatrix",
    FontWeight->"Bold"],
  " is a rule sometimes embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives a matrix of symbolic functions to be used by the ",
  StyleBox["Jacobian",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " for finding the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersections at a particular surface. The functions take as \
arguments the ray length, the surface coordinates and the ray tilt as a \
sequence of six values",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JonesMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["JonesMatrix[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["jonesmatrix",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that linearly transforms the polarization \
state of rays.\n\[InvisibleSpace]The ",
  StyleBox["jonesmatrix",
    FontSlant->"Italic"],
  " parameter uses a 2x2 Jones transformation matrix. The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the Jones matrix \
coordinate axis along the optical surface with respect to the horizontal axis \
of the local surface coordinate system. The ",
  StyleBox["Transmission",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " option can be used to weight the outgoing intensity of each outgoing ray, \
where ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " can be either a number between 0 and 100, a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, or a ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expression that depends on ray ",
  StyleBox["options",
    FontSlant->"Italic"],
  " such as ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ". Otherwise, ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["componentmedium",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be defined to hold an absorption function or a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values. See also",
  ":",
  " ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PhaseRetardation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JonesMatrixOptic", "Subsection"],

Cell[TextData[{
  StyleBox["JonesMatrixOptic[",
    FontWeight->"Bold"],
  StyleBox["jonesmatrix",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a flat surface optic used to transform the ray polarization \
information according to the given ",
  StyleBox["jonesmatrix",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["jonesmatrix",
    FontSlant->"Italic"],
  " parameter uses a 2x2 Jones matrix. The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the Jones matrix \
coordinate axis along the optical surface with respect to the horizontal axis \
of the local surface coordinate system. If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " option can be used to weight the outgoing intensity of each outgoing ray, \
where ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " can be either a number between 0 and 100, a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, or a ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expression that depends on ray ",
  StyleBox["options",
    FontSlant->"Italic"],
  " such as ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ". Otherwise, ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["componentmedium",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be defined to hold an absorption function or a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["JonesMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JumpToOpticaSourceCode", "Subsection"],

Cell[TextData[{
  StyleBox["JumpTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["SourceCode[",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["filename",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tries to jump to the definition of ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " inside the given file. ",
  StyleBox["JumpTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox["SourceCode[",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["filename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["type",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " jumps to the specified kind of definition."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["KDPToData", "Subsection"],

Cell[TextData[{
  StyleBox["KDPToData[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import KDP lens data into Optica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s database format.\n\[InvisibleSpace]",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  " requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished by directly copying and pasting the KDP data from a text editor \
into a Mathematica notebook with double quotation marks placed manually on \
either side of the pasted data. ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  " then converts this string information into a rule",
  StyleBox["-",
    FontWeight->"Bold"],
  "based, list format that is recognized by Mathematica. The translation \
process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  ". Once converted, the new information can be edited further with ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  ", saved to disk with ",
  StyleBox["SaveData",
    FontWeight->"Bold"],
  ", and converted to optical component models with ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  " is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. KDP is a Trademark of Engineering Calculations, \
Glendale, CA. See also: ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "KDP",
  StyleBox["To",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["KDPToOptica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import and convert KDP refractive lens data into one or more \
optical lens models for ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished either by opening the KDP data file inside Mathematica or by \
manually copying and pasting the relevant data into an existing Mathematica \
notebook and, as a final last step, creating a string object by manually \
placing double",
  StyleBox["-",
    FontWeight->"Bold"],
  "quotation marks on either side of the data. ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "then converts this string information into one or more optical lens models \
that work with ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". The conversion process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "(that get passed internally to ",
  StyleBox["StringReplace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  "). ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "makes internal calls to ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. KDP is a Trademark of Engineering Calculations, \
Glendale, CA. See also: ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["KernelScale", "Subsection"],

Cell[TextData[{
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Relative",
    FontWeight->"Bold"],
  " ",
  StyleBox["/",
    FontWeight->"Bold"],
  " ",
  StyleBox["Absolute",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " to specify the form of the ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Relative",
    FontWeight->"Bold"],
  " indicates that the specified ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " dimensions is a relative multiplicative factor of the minimum estimated \
spatial sampling dimension, as determined from Nyquist sampling criteria. ",
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Absolute",
    FontWeight->"Bold"],
  " denotes that the specified ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " dimensions are given in absolute spatial dimensions. See also",
  ":",
  " ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["KnoopHardness", "Subsection"],

Cell[TextData[{
  StyleBox["KnoopHardness",
    FontWeight->"Bold"],
  " is a database rule name that specifies the Knoop hardness of a material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelOffset", "Subsection"],

Cell[TextData[{
  StyleBox["LabelOffset",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that scales the label offset",
  StyleBox["-",
    FontWeight->"Bold"],
  "positions according to the overall dimensions of the system rendering.\n\
\[InvisibleSpace]See also",
  ":",
  " ShiftLabels, ",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelPositions", "Subsection"],

Cell[TextData[{
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that indicates the rendering positions of one or more label names in the \
rendered ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Note that the specified values are automatically \
updated with subsequent ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " operations. See also",
  ":",
  " ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Offx",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Offy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Offz",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Labels", "Subsection"],

Cell[TextData[{
  StyleBox["Labels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["labelnames",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  " that supplies one or more label names for various parts of the rendered \
",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". Each ",
  StyleBox["labelname",
    FontSlant->"Italic"],
  " can be an expression, a string or ",
  StyleBox["StyleForm[",
    FontWeight->"Bold"],
  StyleBox["labelname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["format",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " is usually accompanied with a specification for ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["LabelSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/<",
    FontWeight->"Bold"],
  StyleBox["surface",
    FontSlant->"Italic"],
  " parameter",
  StyleBox[">",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that displays either ",
  StyleBox["{ComponentNumber, SurfaceNumber}",
    FontWeight->"Bold"],
  " information or one or more specified ",
  StyleBox["surface",
    FontSlant->"Italic"],
  " parameters at each component ",
  StyleBox["surface",
    FontSlant->"Italic"],
  " in an optical system.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For ",
  StyleBox["LabelSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and when a single component element is present, the corresponding ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  " for each ",
  StyleBox["surface",
    FontSlant->"Italic"],
  " is displayed. However, when several components are present and ",
  StyleBox["LabelSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is specified, a pair of numbers that correspond with ",
  StyleBox["{ComponentNumber, SurfaceNumber}",
    FontWeight->"Bold"],
  " is displayed by each ",
  StyleBox["surface",
    FontSlant->"Italic"],
  ". Examples of parameters for ",
  StyleBox["LabelSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["<",
    FontWeight->"Bold"],
  StyleBox["surface",
    FontSlant->"Italic"],
  " parameter",
  StyleBox[">",
    FontWeight->"Bold"],
  " include",
  ":",
  " ",
  StyleBox["ActiveRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceCenter",
    FontWeight->"Bold"],
  ". A list of ",
  StyleBox["surface",
    FontSlant->"Italic"],
  " parameters may also be specified."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lambertian", "Subsection"],

Cell[TextData[{
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " that indicates whether the diffused light is equally distributed about \
the surface normal or is distributed with the direction of the incoming ray.\n\
\[InvisibleSpace]For ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LaSF9", "Subsection"],

Cell[TextData[{
  StyleBox["LaSF9",
    FontWeight->"Bold"],
  " denotes the use of the ",
  StyleBox["LaSF9",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["LaSF9",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LastSegment", "Subsection"],

Cell[TextData[{
  StyleBox["LastSegment",
    FontWeight->"Bold"],
  " labels an unauthorized rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is an internal flag variable used by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". It indicates the last segment of each ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " pathway to be propagated through an optical system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LastSlot", "Subsection"],

Cell[TextData[{
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " and specifies that the last slot position within each confined path in ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " inherits the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LensDoublet", "Subsection"],

Cell[TextData[{
  StyleBox["LensDoublet[",
    FontWeight->"Bold"],
  StyleBox["r1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens having three spherical surfaces.\n\[InvisibleSpace]The \
radii of curvatures are specified by ",
  StyleBox["r1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["r3",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " is used to indicate planar surfaces. In addition, ",
  StyleBox["LensDoublet",
    FontWeight->"Bold"],
  " is specified by two thicknesses: ",
  StyleBox["t1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t2",
    FontSlant->"Italic"],
  ". The two refractive indexes must also be specified either as a function \
of wavelength or using one of the built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in optical material labels. ",
  StyleBox["LensDoublet",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and the \
remaining surfaces positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. See also: ",
  StyleBox["LensTriplet",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["LensSurface[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a planar component that models the refractive index boundary at a \
lens surface.\n\[InvisibleSpace]",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LensTriplet", "Subsection"],

Cell[TextData[{
  StyleBox["LensTriplet[",
    FontWeight->"Bold"],
  StyleBox["r1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r4",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index3",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a lens having four spherical surfaces.\n\[InvisibleSpace]The \
radii of curvatures are specified by ",
  StyleBox["r1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r3",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["r4",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " is used to indicate planar surfaces. In addition, ",
  StyleBox["LensTriplet",
    FontWeight->"Bold"],
  " is specified by three thicknesses: ",
  StyleBox["t1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["t3",
    FontSlant->"Italic"],
  ". The three refractive indexes must also be specified either as a function \
of wavelength or using one of the built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in index functions. ",
  StyleBox["LensTriplet",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and the \
remaining surfaces positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. See also: ",
  StyleBox["LensDoublet",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CompoundLens",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LimitByReflection", "Subsection"],

Cell[TextData[{
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " that indicates whether the ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  " feature operates by reflecting the over",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattered rays off the surface or by re",
  StyleBox["-",
    FontWeight->"Bold"],
  "assigning a new random factor to the over",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattered rays.\n\[InvisibleSpace]For ",
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the over",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattered rays are reflected off the surface. This gives an un",
  StyleBox["-",
    FontWeight->"Bold"],
  "even bias to the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "scatter distribution. For ",
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the over",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattered rays are re",
  StyleBox["-",
    FontWeight->"Bold"],
  "assigned new random values to evenly distribute the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "scatter angles. Note that the ",
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " behavior is always used in the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function and cannot be switched. See also ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LimitScatter", "Subsection"],

Cell[TextData[{
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " that indicates whether the diffused light is restricted to emission from \
a single side of an optical surface.\n\[InvisibleSpace]For ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the scattered rays are limited to emit from one optical surface side. \
For ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the scattered rays are permitted to emit through both surface sides. See \
also ",
  StyleBox["LimitByReflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearPolarization", "Subsection"],

Cell[TextData[{
  StyleBox["LinearPolarization[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that causes linearly polarized rays.\n\
\[InvisibleSpace]The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the first \
polarization state along the optical surface with respect to the ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " axis of the local surface coordinate system. The ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " option can be used to weight the outgoing two polarizations components of \
the transmitted ray, where ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  " can be either a number between 0 and 100, a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, or a ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expression that depends on ray ",
  StyleBox["options",
    FontSlant->"Italic"],
  " such as ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ". Here, the first value of the ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " option weights the ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " polarization state and the second value weights the ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  " polarization state. In addition, ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to weight the two polarizations of the outgoing reflected (or \
second split",
  ")",
  " ray when the ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " option is also invoked.\n\[InvisibleSpace]Instead of giving values for \
Tramsmittance and ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " explicitly, ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["componentmedium",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be defined to hold two absorption functions or two lists of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, where ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to define ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  " separately for two split polarized rays. The ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option can be used to create two orthogonally polarized rays that \
initially propagate in the same direction. ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  " produces a reflected ray whose polarization is determined by the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " setting and a transmitted ray whose polarization is determined by the ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " setting.\n\[InvisibleSpace]See also: ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PhaseRetardation",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearPolarizer", "Subsection"],

Cell[TextData[{
  StyleBox["LinearPolarizer[",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a flat surface optic used to create linearly polarized rays along an \
axis of alignment given by ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LinearPolarizer[",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " can also be used to specify a ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " to the polarizer and a nonplaner custom ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the ",
  StyleBox["first",
    FontSlant->"Italic"],
  " polarization state along the optical surface with respect to the \
horizontal axis of the local surface coordinate system. The ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["first",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["second",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " option can be also used to weight the outgoing intensity of each \
polarization direction, where ",
  StyleBox["first",
    FontSlant->"Italic"],
  " and ",
  StyleBox["second",
    FontSlant->"Italic"],
  " can be either a number between 0 and 100, a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, or a ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expression that depends on ray ",
  StyleBox["options",
    FontSlant->"Italic"],
  " such as ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ". Otherwise, ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["componentmedium",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["first",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["second",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be defined to hold two absorption functions or two lists of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values. ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["polarizationmaterial",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["refractivematerial",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can also be used to indicate that the polarization material is mounted on \
a refractive substrate. The ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option can be used to create two orthogonally polarized rays. ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  " produces a reflected vertically polarized ray and a transmitted \
horizontally polarized ray. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LineOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["LineOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["linewidth",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane that point down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis (for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting",
  ")",
  " and are distributed along the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "coordinate with the specified ",
  StyleBox["linewidth",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["CreateRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LineStyle", "Subsection"],

Cell[TextData[{
  StyleBox["LineStyle",
    FontWeight->"Bold"],
  " is an option of optical components that carries a list of ",
  "graphics",
  " styles for the rendering of edges and wire",
  StyleBox["-",
    FontWeight->"Bold"],
  "framed surfaces. See also: ",
  StyleBox["FillStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ListOptionGeneticQ", "Subsection"],

Cell[TextData[{
  StyleBox["ListOptionGeneticQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a list of options for a genetic building block (can be empty",
  ")",
  ". The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LoadOpticaFiles", "Subsection"],

Cell[TextData[{
  StyleBox["Load",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Files[",
    FontWeight->"Bold"],
  StyleBox["foldername",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["filename",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a utility to load ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " files after having saved them. Interface files are loaded in the public \
",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " context, the rest is loaded in the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " private context. Both parameters can be a list to load multiple files."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetic", "Subsection"],

Cell[TextData[{
  StyleBox["Magnetic",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a nonconductive, magnetic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MassDensity", "Subsection"],

Cell[TextData[{
  StyleBox["MassDensity",
    FontWeight->"Bold"],
  " is a database rule name that specifies the mass density of a material in \
gm",
  StyleBox["/",
    FontWeight->"Bold"],
  "cc",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaterialDirectory", "Subsection"],

Cell[TextData[{
  StyleBox["MaterialDirectory",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a directory.\n\[InvisibleSpace]This directory contains \
data on optical materials",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaterialFiles", "Subsection"],

Cell[TextData[{
  StyleBox["MaterialFiles",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a list of file names to be loaded.\n\[InvisibleSpace]These \
files contain information on optical materials",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaterialRotationMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the orientation of the material relative to the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the component. Examples are the gratingvector in ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " or indexellipsoid in ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ". Like the latter, the value of ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " is a list of three lists, representing the three base vectors of an \
orthonormal coordinate system. All material direction dependent values are \
given in the coordinate system defined by ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  ". ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  " may depend on surface coordinates. See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PhaseRetardation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeanDispersion", "Subsection"],

Cell[TextData[{
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  " is a rule name that specifies the refractive index difference of an \
optical material at chosen two wavelengths, mean dispersion ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (nf",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc",
  ")",
  ", and gives a measure of the chromatic aberration of an optical material.\n\
\[InvisibleSpace]Here, nf and nc are the refractive index values for two \
different wavelengths specified by the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option. See also: ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MediumNameQ", "Subsection"],

Cell[TextData[{
  StyleBox["MediumNameQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a name for a medium for which ",
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["][",
    FontWeight->"Bold"],
  StyleBox["ray",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " evaluates to a ",
  StyleBox["number",
    FontSlant->"Italic"],
  " or a list with a rule ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  ". The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeltingPoint", "Subsection"],

Cell[TextData[{
  StyleBox["MeltingPoint",
    FontWeight->"Bold"],
  " is a database rule name that indicates the melting temperature of a \
material (in degrees Celsius",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeritType", "Subsection"],

Cell[TextData[{
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " that indicates the performance criteria to be invoked by ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " presently has nine possible settings: ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{SurfaceCoordinates, Intensity}",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{OpticalLength, Intensity}",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{RayTilt, Intensity}",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{Centered, SurfaceCoordinates}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{Centered, SurfaceCoordinates, Intensity}",
    FontWeight->"Bold"],
  ". ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " calculates the beam spot size by using the sum of the squared ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intercept distances from the calculated spot center. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Centered, SurfaceCoordinates}",
    FontWeight->"Bold"],
  " assumes that the spot focus runs through the output surface center. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  " uses the sum of the squared optical path length differences. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " measures the collimation of rays by projecting the average ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " value with the individual ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " values. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  " measures the intensity",
  StyleBox["-",
    FontWeight->"Bold"],
  "weighted RMS beam spot size in the same manner as ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  ". When the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter is listed with parameters, the performance criteria gets \
weighted by the sum of the ray intensities present.\n\[InvisibleSpace]",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " is internally converted by ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " into particular settings for the ReportedParameter and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " options. As an alternative to using the ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " option, the user can instead work directly with the ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " options.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metallic", "Subsection"],

Cell[TextData[{
  StyleBox["Metallic",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize a conductive, magnetic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Methanol", "Subsection"],

Cell[TextData[{
  StyleBox["Methanol",
    FontWeight->"Bold"],
  " indicates the use of a methanol liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Methanol",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .43 microns to .66 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MinimizationType", "Subsection"],

Cell[TextData[{
  StyleBox["MinimizationType",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  " that indicates the minimization function to the invoked by ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The default setting is usually ",
  StyleBox["MinimizationType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MinimumArrowLength", "Subsection"],

Cell[TextData[{
  StyleBox["MinimumArrowLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["length",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that sets the minimum geometric ",
  StyleBox["length",
    FontSlant->"Italic"],
  " for each ray segment to be rendered as an arrow. Otherwise, ",
  StyleBox["MinimumArrowLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["scale",
    FontSlant->"Italic"],
  StyleBox["*Max",
    FontWeight->"Bold"],
  " scales the minimum ",
  StyleBox["length",
    FontSlant->"Italic"],
  " to the maximum dimension of the resulting graphic. See also",
  ":",
  " ",
  StyleBox["ShowArrows",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MinimumRayLength", "Subsection"],

Cell[TextData[{
  StyleBox["MinimumRayLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["length",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that controls the minimum allowed ray ",
  StyleBox["length",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The number defines, what is considered to be a zero \
ray ",
  StyleBox["length",
    FontSlant->"Italic"],
  ". Rays intersecting the same surface they come from, must have a ray ",
  StyleBox["length",
    FontSlant->"Italic"],
  " above this threshold to yield a valid intersection.\n\[InvisibleSpace]See \
also",
  ":",
  " ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mirror", "Subsection"],

Cell[TextData[{
  StyleBox["Mirror[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mirror[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a planar mirror.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["Mirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mirrored", "Subsection"],

Cell[TextData[{
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " is an option of some built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in component functions that specifies the reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surfaces present.\n\[InvisibleSpace]",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " is handled differently by different component functions, but ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " indicates that one or more surfaces within the component are to be \
reflective and ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " indicates that surfaces are not reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated, but may still internally reflect. ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used to specify each reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surface by the surface number. Finally, ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Base",
    FontWeight->"Bold"],
  " is sometimes also used to indicate that the base of the component is \
reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated. See also",
  ":",
  " ",
  StyleBox["Base",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MirrorSpan", "Subsection"],

Cell[TextData[{
  StyleBox["MirrorSpan[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["MirrorSpan[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " are similar to ",
  StyleBox["Mirror",
    FontWeight->"Bold"],
  " except that its size and placement are specified by the two two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinates ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["MirrorSpan",
    FontWeight->"Bold"],
  " spans the specified coordinates and has the specified ",
  StyleBox["height",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MismatchCutOff", "Subsection"],

Cell[TextData[{
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  " is an option that denotes a real number that designates the maximum \
mismatch cutoff value of a diffracting ray.\n\[InvisibleSpace]If a \
diffraction order has a ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  " value greater than specified by ",
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  ", the ray is terminated by setting its ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter to zero. ",
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  " is an option of all grating components, as well as the ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " genetic building block. However, ",
  StyleBox["MismatchCutOff",
    FontWeight->"Bold"],
  " is largely not used anymore since it is only active with ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CoupledWaveTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffractionMismatch",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EfficiencyFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelCoating", "Subsection"],

Cell[TextData[{
  StyleBox["ModelCoating[",
    FontWeight->"Bold"],
  StyleBox["coatingname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelCoating[",
    FontWeight->"Bold"],
  StyleBox["coatingname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["substratename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "parameter",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent function that models the filter properties of a surface coating \
on respective reflective and refractive components.\n\[InvisibleSpace]For \
reflective component coatings, ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " should return a single ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " that contains the reflective properties of the coating. For refractive \
components, ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " should return a list of two functions, the first for transmission and the \
second for reflection, each returning a new intensity and optional \
polarization value.\n\[InvisibleSpace]The defaults for ",
  StyleBox["substratename",
    FontSlant->"Italic"],
  " and ",
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  " are ",
  StyleBox["BK7",
    FontWeight->"Bold"],
  " and 0.532, respectively. If the properties depend only on: ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ", the function can be automatically optimized for speed. The ",
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  " can be for example a center wavelength in microns, the ",
  StyleBox["coatingname",
    FontSlant->"Italic"],
  " can also be a ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " in percent. Calculated values for ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " replace the ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " refraction calculation, ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", if not calculated, is reset to its original value.\n\
\[InvisibleSpace]With equal length lists for ",
  StyleBox["coatingname",
    FontSlant->"Italic"],
  " and ",
  StyleBox["coatingspecification",
    FontSlant->"Italic"],
  ", layered media are modeled. A list of two names for ",
  StyleBox["substratename",
    FontSlant->"Italic"],
  " specifies besides the substrate the optical material before the coating, \
e. g. for special intrinsic media. Such models are not yet built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]In addition to the existing coating models, user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified model libraries of coating materials can be created by listing \
and evaluating ",
  StyleBox["ModelCoating[",
    FontWeight->"Bold"],
  StyleBox["coatingname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["reflectancefunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  "...",
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelCoating[",
    FontWeight->"Bold"],
  StyleBox["coatingname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["substratename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["transmittancefunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["reflectancefunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  "...",
  StyleBox["]}",
    FontWeight->"Bold"],
  " for different coating types. Before the user can define new ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " functions, ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  " must first be unprotected or included within the \"Models\" directory of \
the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package, behind the file \"Models.nb\". Ranges for the model can be \
specified in the same fashion as ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a function evaluated by the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing engine at every ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface interface and is used for modeling the bulk absorptive properties \
of materials identified by ",
  StyleBox["materialname",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  " may depend on various parameters including ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", and returns a single intensity value that is stored in the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter of the ray. User",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified intensity model libraries of refractive materials can be created \
by listing and evaluating ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " intensityfunction for different specified materialnames. \
Intensityfunction is called with a ray and has the structure: ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "(",
  StyleBox["rulenames",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["inside",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["formula",
    FontSlant->"Italic"],
  ")",
  StyleBox["/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  ". The default intensityfunction for unspecified materialnames does not \
change the intensity of the ray. ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  " may be based on spectroscopic data, and can be used to model gain (in \
lasers) as well as absorption. Before the user can define new ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  " functions, they must first be unprotected or included in the \"Models\" \
directory of the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package, behind the file \"Models.nb\". See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelJacobianMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["ModelJacobianMatrix[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a global function that is used by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " to create the ",
  StyleBox["Jacobian",
    FontWeight->"Bold"],
  " matrix for component surfaces. ",
  StyleBox["ModelJacobianMatrix",
    FontWeight->"Bold"],
  " gives a ",
  StyleBox["Jacobian",
    FontWeight->"Bold"],
  " matrix function expression to ",
  StyleBox["JacobianMatrix",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". The function must have the matrix explicitly as last element of the \
expression. If no pattern is defined for ",
  StyleBox["ModelJacobianMatrix",
    FontWeight->"Bold"],
  ", the matrix is given as the last two rows of the matrix given by ",
  StyleBox["ModelSurfaceNormal",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelPolarization", "Subsection"],

Cell[TextData[{
  StyleBox["ModelPolarization[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a function evaluated by the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing engine at every ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface interface and is used for modeling the bulk polarizing properties \
of materials identified by ",
  StyleBox["materialname",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  " may depend on various parameters including ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", and returns a single polarization value that is stored in the ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " parameter of the ray. User",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified polarization model libraries of materials can be created by \
listing and evaluating ",
  StyleBox["ModelPolarization[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " polarizationfunction for different specified materialnames. \
Polarizationfunction is called with a ray and has the structure: ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "(",
  StyleBox["rulenames",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["inside",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["formula",
    FontSlant->"Italic"],
  ")",
  StyleBox["/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  ". The default polarizationfunction for unspecified materialnames leaves ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " unchanged. ",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  " could be used to implement an optically active material. Before the user \
can define new ",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  " functions, they must first be unprotected or included in the \"Models\" \
directory of the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package, behind the file \"Models.nb\". See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRayColor", "Subsection"],

Cell[TextData[{
  StyleBox["ModelRayColor[",
    FontWeight->"Bold"],
  StyleBox["rayparameterlabels",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["minvalue",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["maxvalue",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  StyleBox["parametervalue",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " attempts to convert the ray parameters indicated by ",
  StyleBox["rayparameterlabels",
    FontSlant->"Italic"],
  " into rendered color values.\n\[InvisibleSpace]Custom ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "rendering schemes can be defined for various ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "parameter labels by using ",
  StyleBox["ModelRayColor[",
    FontWeight->"Bold"],
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["min",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["max",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["parametervalue",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["function",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["parametervalue",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["function",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["parametervalue",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns graphics styles such as ",
  StyleBox["Hue",
    FontWeight->"Bold"],
  ", GreyLevel, and ",
  StyleBox["RGBColor",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["rayparameterlabel",
    FontSlant->"Italic"],
  " from the ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " option of ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ". Arguments ",
  StyleBox["minvalue",
    FontSlant->"Italic"],
  " and ",
  StyleBox["maxvalue",
    FontSlant->"Italic"],
  " are calculated based on the minimum and maximum parameter values from the \
currently displayed rays, selected by the ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " option. As a default for undefined ray parameter labels given by the ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  " assigns a color ",
  StyleBox["Hue",
    FontWeight->"Bold"],
  " to each ray according to the segment parameter",
  StyleBox["'",
    FontWeight->"Bold"],
  "s numerical position between ",
  StyleBox["minvalue",
    FontSlant->"Italic"],
  " and ",
  StyleBox["maxvalue",
    FontSlant->"Italic"],
  ", with red assigned to the maximum encountered parameter value. Parameters \
made up of three elements are evaluated by representing each element \
independently with a red, green, or blue value. Two",
  StyleBox["-",
    FontWeight->"Bold"],
  "element parameters are assigned a red and a green value, each representing \
an element. ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " attempts to match the wavelength of the ray to the perceived visual color \
of that wavelength. The option ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Black",
    FontWeight->"Bold"],
  " may be used to produce black",
  StyleBox["-",
    FontWeight->"Bold"],
  "rendered ray lines. Before the user can define new ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  " functions, ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  " must be unprotected or included within the \"Models\" directory of the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package, behind the file \"Models.nb\". See also: ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractionTheory", "Subsection"],

Cell[TextData[{
  StyleBox["ModelRefractionTheory[{",
    FontWeight->"Bold"],
  StyleBox["refractiveindex",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["attenuationindex",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["polarizationcalculations",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["directioncalculations",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " returns the theory to be used in calculation. The theory is a list with \
two labels: the first is the general theory, the second designates the \
material character. For possible values see ",
  StyleBox["$Theory",
    FontWeight->"Bold"],
  ". The second list of ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  " is optional. See also",
  ":",
  " ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FresnelReflections",
    FontWeight->"Bold"],
  ", and DirectionCalculations."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex", "Subsection"],

Cell[TextData[{
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "parameter",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent function or list of rules that models the refractive properties \
of materials identified by ",
  StyleBox["materialname",
    FontSlant->"Italic"],
  ". If the properties depend only on the parameters ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  ", MaterialSpecification, ",
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  ", the model can be optimized in speed automatically.\n\[InvisibleSpace]In \
addition to the existing material models, user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified model libraries of refractive materials can be created by \
listing and evaluating ",
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " indexfunction",
  StyleBox["[",
    FontWeight->"Bold"],
  "...",
  StyleBox["]",
    FontWeight->"Bold"],
  " for different material names. Note that the indexfunction can either be a \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified function or the built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  " resource. The ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  " can be used in facilitating this process. Before the user can define new \
",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " functions, the ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " must first be unprotected or included within the \"Models\" directory of \
the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package, behind the file \"Models.nb \".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " may return a single function or a list of rules, designating the index \
functions for ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermittivity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Conductivity",
    FontWeight->"Bold"],
  ": ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["name1",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["indexfunction1",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  ". All, but ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Allowed ranges for index functions can be given for ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ". For Wavelength, they are specified as ",
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox[", WaveLength]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["minimumwavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["maximumwavelength",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". If ranges are specified, the whole number of ranges must be given: 18 \
for ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", 2 for the rest. A medium specified by the ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " rule of a ray is not checked.\n\[InvisibleSpace]",
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["listofindexnames",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns a list of functions describing the material behavior, ",
  StyleBox["ModelRefractiveIndex[",
    FontWeight->"Bold"],
  StyleBox["materialname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["indexname",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns a function. An optional third parameter ",
  StyleBox["False",
    FontWeight->"Bold"],
  " uses default values for undefined indices.\n\[InvisibleSpace]See also: ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateRefractiveIndexModel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelCoating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelSurfaceNormal", "Subsection"],

Cell[TextData[{
  StyleBox["ModelSurfaceNormal[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a global function that is used by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " to create the normal functions for component surfaces. ",
  StyleBox["ModelSurfaceNormal",
    FontWeight->"Bold"],
  " gives a normal surface function expression to ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ". The function must have the matrix explicitly as last element of the \
expression.\n\[InvisibleSpace]For surfaces to be treated fully numerically, \
",
  StyleBox["ModelSurfaceNormal[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used. In order to be usable in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", the function should return an explicit three by three surface normal \
matrix. See also",
  ":",
  " ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelSurfaceRayIntersections", "Subsection"],

Cell[TextData[{
  StyleBox["ModelSurfaceRayIntersections[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["calculationmethod",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to model the intersection of a ray with a component surface.\n\
\[InvisibleSpace]",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  " returns either a single ",
  StyleBox["function",
    FontSlant->"Italic"],
  " or list of rules. ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " designates a ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " object that takes the ray start and tilt in local surface coordinates as \
a sequence of six values and returns a list of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional intersection points. In order to be compilable in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", every symbol local to the ",
  StyleBox["function",
    FontSlant->"Italic"],
  " must be initialized and the intersection list can not be empty. Invalid \
intersections are returned as the symbol ",
  StyleBox["NoSurfaceIntersection",
    FontWeight->"Bold"],
  " that is transformed internally.\n\[InvisibleSpace]New intersections can \
be modelled by solving the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional equations line",
  StyleBox["==",
    FontWeight->"Bold"],
  "surface for the x, y, and z components of the line. ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " automatically rejects invalid intersections. For ",
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  " being ",
  StyleBox["OtherShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["surfacevalue",
    FontSlant->"Italic"],
  " is the surfacefunction. ",
  StyleBox["ModelRaySurfaceIntersections",
    FontWeight->"Bold"],
  " is called internally with an option ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The parameter ",
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  " is a label for the surface type and is identical to that of ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["calculationmethod",
    FontSlant->"Italic"],
  " is the label used as value of ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If possible, SymbolicSurfaceRayIntersections uses \
definitions of ",
  StyleBox["ModelSurfaceRayIntersections[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", Symbol]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelSurfaceShape", "Subsection"],

Cell[TextData[{
  StyleBox["ModelSurfaceShape[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " surfacefunction is a global function that defines a surfacefunction with \
the ",
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  " as a reference tag.\n\[InvisibleSpace]Users can add new surface \
definitions by assigning new surfacefunctions to ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " with ",
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  " that names the surface type. The ",
  StyleBox["value",
    FontSlant->"Italic"],
  " parameter can be a single number or list of numbers, and it specifies \
surface curvature characteristics. ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " can either define a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface using a function of two parameters or a list of three \
parametric functions. New definitions may be assigned to ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " by evaluating either ",
  StyleBox["ModelSurfaceShape[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  " for explicitly parametric surface functions or ",
  StyleBox["ModelSurfaceShape[",
    FontWeight->"Bold"],
  StyleBox["surfacelabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontWeight->"Bold"],
  " for simple surface functions. Before the user can define new ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " functions, the ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  " must first be unprotected or included within the \"Model Functions\" \
section of the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package. Internally, formal surface function parameters are renamed to \
corresponding ",
  StyleBox["Slot",
    FontWeight->"Bold"],
  " (",
  StyleBox["#",
    FontWeight->"Bold"],
  ") expressions. See also: ",
  StyleBox["ModelSurfaceNormal",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModifyElementsOptions", "Subsection"],

Cell[TextData[{
  StyleBox["ModifyElementsOptions[",
    FontWeight->"Bold"],
  StyleBox["functionname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["functionparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a utility function that creates a new optical component description.\n\
\[InvisibleSpace]",
  StyleBox["ModifyElementsOptions",
    FontWeight->"Bold"],
  " is used within each new optical component definition and modifies the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " of a component function to include a new ",
  StyleBox["ComponentDescription",
    FontWeight->"Bold"],
  ". This identifies the specified optical component with a special ",
  StyleBox["functionname",
    FontSlant->"Italic"],
  " (such as ",
  StyleBox["PlanoConvexLens",
    FontWeight->"Bold"],
  ") and ",
  StyleBox["functionparameters",
    FontSlant->"Italic"],
  " (such as ",
  StyleBox["{",
    FontWeight->"Bold"],
  "100",
  StyleBox[",",
    FontWeight->"Bold"],
  "50",
  StyleBox[",",
    FontWeight->"Bold"],
  "10",
  StyleBox["}",
    FontWeight->"Bold"],
  ")",
  ". This description is ultimately produced in the printed output cell for \
the component."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModularSystem", "Subsection"],

Cell[TextData[{
  StyleBox["ModularSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that creates an optical system that can be used as a module together with \
other optics.\n\[InvisibleSpace]With the default, ",
  StyleBox["ModularSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the last reported rays are not deflected at the last surface. To connect \
optical systems, the rays must be propagated behind the last surface. The \
last ray segments then get the rule ",
  StyleBox["LastSegment",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["ModularSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModulationTransferFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ModulationTransferFunction[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " calculates the modulation and phase transfer functions of the optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " for a given object source input.\n\[InvisibleSpace]",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  " works together with ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ". As input, ",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  " takes the returned output from ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ". The optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " must contain a light source followed by the imaging optics with the focal \
surface as its last element.\n\[InvisibleSpace]Note: ",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  " works equally well for both point sources and planar sources, as long as \
the described imaging ",
  StyleBox["system",
    FontSlant->"Italic"],
  " contains a focus. If a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional light source is used (ie. ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  " or ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  "), then a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional modulation transfer function is calculated. If a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional light source is used (ie. ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " or ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ")",
  ", then the optical transfer function calculations are carried out in two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions. Warning: in general, most one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional and two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional results are not fully equivalent to each other.\n\
\[InvisibleSpace]",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  " is also a label used with the ",
  StyleBox["RenderedParameters",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  " is a rule returned by gives the modulation transfer function of an \
imaging ",
  StyleBox["system",
    FontSlant->"Italic"],
  " for a specific image point. See also: ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PhaseTransferFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MTF",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move", "Subsection"],

Cell[TextData[{
  StyleBox["Move[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["movement",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays.\n\[InvisibleSpace]",
  StyleBox["Move",
    FontWeight->"Bold"],
  " accepts a number of patterns to specify a ",
  StyleBox["movement",
    FontSlant->"Italic"],
  " in one, two, or three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space. In particular, the ",
  StyleBox["movement",
    FontSlant->"Italic"],
  " can be specified as six different sequences of parameters: ",
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["};",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["};",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", rotate",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", rotate, twist",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", rotationmatrix",
  StyleBox[";",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", tilt",
  StyleBox[";",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", tilt, twist. Here, the rotation angle determines the angular orientation \
of ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " within the horizontal plane. To get a three dimensional ",
  StyleBox["movement",
    FontSlant->"Italic"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional tilt vector or rotation matrix is specified in addition to the \
three components of displacement, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". The optional twist angle, which may be given as an option ",
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  ", can be used to specify a rotation around the axis of orientation \
(typically the optical axis).",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A component or source may be moved additionally symbolically by specifying \
a list of a nonnumerical quantity and a number for each coordinate. Missing \
symbols are filled with the corresponding numerical specification, for \
example ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "10",
  StyleBox["}, ",
    FontWeight->"Bold"],
  "5",
  StyleBox["}",
    FontWeight->"Bold"],
  " to move symbolically ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox["}",
    FontWeight->"Bold"],
  " and numerically ",
  StyleBox["{",
    FontWeight->"Bold"],
  "10",
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Other related commands used for positioning components \
and rays include: ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["Move",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that moves components and rays in the optical system.\n\
\[InvisibleSpace]",
  StyleBox["Move",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to specify a ",
  StyleBox["movement",
    FontSlant->"Italic"],
  " for the selected objects. The first coordinate point non pointing on an \
object indicates the point where to move objects. The next two points can \
specify an additional rotation. For one more point the objects are oriented \
parallel to the line defined by these two points. Two more points define a \
relative rotation, given by the lines from the first to the second and from \
the first to the third point. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move3D", "Subsection"],

Cell[TextData[{
  StyleBox["Move3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["tiltvector",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space.\n\[InvisibleSpace]The functioning of ",
  StyleBox["Move3D",
    FontWeight->"Bold"],
  " has been fully taken over by ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " in the current version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " and, as such, ",
  StyleBox["Move3D",
    FontWeight->"Bold"],
  " is now obsolete. The ",
  StyleBox["tiltvector",
    FontSlant->"Italic"],
  " is a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional unit vector that points the direction of the axis of \
orientation. The ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " specifies a rotation around the axis of orientation.\n\[InvisibleSpace]A \
component or source may be moved additionally symbolically by specifying a \
list of a nonnumerical quantity and a number for each coordinate. Missing \
symbols are filled with the corresponding numerical specification, for \
example ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "10",
  StyleBox["}, ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "7",
  StyleBox["}",
    FontWeight->"Bold"],
  " to move symbolically ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "7",
  StyleBox["}",
    FontWeight->"Bold"],
  " and numerically ",
  StyleBox["{",
    FontWeight->"Bold"],
  "10",
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "7",
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Other related commands used for positioning components \
and rays include: ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveAligned", "Subsection"],

Cell[TextData[{
  StyleBox["MoveAligned[",
    FontWeight->"Bold"],
  StyleBox["chiefray",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["elementswithdistances",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to specify the position and orientation of a list of component \
elements by tracing a chief ray through the system of elements.\n\
\[InvisibleSpace]",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  " is a function that generalizes ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ". Instead of following a linear rail, ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  " follows an arbitrary light path through three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space, where the components and their spacings are alternately \
specified in ",
  StyleBox["elementswithdistances",
    FontSlant->"Italic"],
  ". ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  " places each component at a given spacing along the light path determined \
by the preceding component. ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  " invokes ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " internally to find the light path.\n\[InvisibleSpace]Other related \
commands used for positioning components and rays include",
  ":",
  " ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveDirected", "Subsection"],

Cell[TextData[{
  StyleBox["MoveDirected[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xpoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypoint",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays within a horizontal plane whose axis of orientation is \
defined by a line intersecting the object",
  StyleBox["'",
    FontWeight->"Bold"],
  "s position and a second defined point in the plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional placement, ",
  StyleBox["MoveDirected[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xpoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpoint",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used instead. The option ",
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " can be used to specify a rotation around the axis of orientation. The \
option ",
  StyleBox["SideOfObject",
    FontWeight->"Bold"],
  " is used to specify on which side of the object the second defined point \
is located. ",
  StyleBox["SideOfObject",
    FontWeight->"Bold"],
  " takes the values ",
  StyleBox["Before",
    FontWeight->"Bold"],
  " and ",
  StyleBox["After",
    FontWeight->"Bold"],
  ". Other related commands used for positioning components and rays \
include",
  ":",
  " ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveDirected3D", "Subsection"],

Cell[TextData[{
  StyleBox["MoveDirected3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xpoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypoint",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpoint",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space, whose axis of orientation is defined by a line \
intersecting the object set",
  StyleBox["'",
    FontWeight->"Bold"],
  "s position and a second defined point in space.\n\[InvisibleSpace]The \
functioning of ",
  StyleBox["MoveDirected3D",
    FontWeight->"Bold"],
  " has been fully taken over by ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  "  in the current version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " and, as such, ",
  StyleBox["MoveDirected3D",
    FontWeight->"Bold"],
  " is now obsolete. The ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " specifies a rotation around the axis of orientation. The option ",
  StyleBox["SideOfObject",
    FontWeight->"Bold"],
  " is used to specify on which side of the object the second defined point \
is located. ",
  StyleBox["SideOfObject",
    FontWeight->"Bold"],
  " takes the values ",
  StyleBox["Before",
    FontWeight->"Bold"],
  " and ",
  StyleBox["After",
    FontWeight->"Bold"],
  ". Other related commands used for positioning components and rays include: \
",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveFunctions", "Subsection"],

Cell[TextData[{
  StyleBox["MoveFunctions",
    FontWeight->"Bold"],
  " generates a hyperlinked listing of the common positioning functions \
available in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveGraphicalOutput", "Subsection"],

Cell[TextData[{
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  " is an option of all moving functions that controls the movement of \
graphics for components inside an ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  ". It can be used with any move function. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the graphics is not moved with the system (the rendering is deleted), \
all other values move the ",
  "graphics",
  ". The rendering for components of optical systems is also deleted for \
moving commands, which would result in wrong display of optical systems. Then \
a new propagation through the optical system is needed. See also: ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveLabels", "Subsection"],

Cell[TextData[{
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["oldposition1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newposition1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["oldposition2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newposition2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that shifts the previously rendered positions of one or more of the \
labels.\n\[InvisibleSpace]",
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  " uses a sequence of two or more screen coordinates where oldposition \
selects the relevent label and newposition indicates the new label position. \
See also",
  ":",
  " ",
  StyleBox["MoveRayLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveLinear", "Subsection"],

Cell[TextData[{
  StyleBox["MoveLinear[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xstart",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ystart",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["lineposition",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays along a line specified by a starting point and ending \
point within the horizontal plane.\n\[InvisibleSpace]For three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional placement, ",
  StyleBox["MoveLinear3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xstart",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ystart",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zstart",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["lineposition",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used instead, where ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " is an optional parameter. The returned set of objects is placed on the \
line at a distance of ",
  StyleBox["lineposition",
    FontSlant->"Italic"],
  " from the specified starting point. The option ",
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " can be used to specify a rotation around the axis of orientation. Other \
related commands used for positioning components and rays include",
  ":",
  " ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveLinear3D", "Subsection"],

Cell[TextData[{
  StyleBox["MoveLinear3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xstart",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ystart",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zstart",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["lineposition",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays along a line specified by a starting point and ending \
point in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space.\n\[InvisibleSpace]The functioning of ",
  StyleBox["MoveLinear3D",
    FontWeight->"Bold"],
  " has been fully taken over by ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  " in the current version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " and, as such, ",
  StyleBox["MoveLinear3D",
    FontWeight->"Bold"],
  " is now obsolete. The returned set of objects is placed on the line at a \
distance of ",
  StyleBox["lineposition",
    FontSlant->"Italic"],
  " from the specified starting point. The ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " specifies a rotation around the axis of orientation. Other related \
commands used for positioning components and rays include: ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveRayLabels", "Subsection"],

Cell[TextData[{
  StyleBox["MoveRayLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["oldposition1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newposition1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["oldposition2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newposition2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that shifts the previously rendered positions of one or more of the ray \
labels.\n\[InvisibleSpace]",
  StyleBox["MoveRayLabels",
    FontWeight->"Bold"],
  " uses a sequence of two or more screen coordinates where oldposition \
selects the relevent label and newposition indicates the new label position. \
See also",
  ":",
  " ",
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveReflected", "Subsection"],

Cell[TextData[{
  StyleBox["MoveReflected[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xbegin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ybegin",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays within a horizontal plane whose axis of orientation is \
defined by a line intersecting the object set",
  StyleBox["'",
    FontWeight->"Bold"],
  "s position and bisecting a starting point and ending point in the plane.\n\
\[InvisibleSpace]For three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional placement, ",
  StyleBox["MoveReflected3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xbegin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ybegin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zbegin",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used instead, where ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " is an optional parameter. The option ",
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " can be used to specify a rotation around the axis of orientation. Other \
related commands used for positioning components and rays include: ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that moves components and rays in the optical system.\n\
\[InvisibleSpace]",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to specify a movement for the selected objects. The first coordinate \
point non pointing on an object indicates the point where to move objects. \
The next two points are used for defining two optical axes originating at the \
moved object. Any missing point is filled with the position of the object \
after and before the moved object in the object sequence. The moved object is \
oriented to the bisecting of the two optical axes. This is the orientation a \
mirror must have to reflect a ray along the first optical axis along the \
second one. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveReflected3D", "Subsection"],

Cell[TextData[{
  StyleBox["MoveReflected3D[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["xbegin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ybegin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zbegin",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["xpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ypos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zpos",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["xend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yend",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zend",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["twistangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the relative position and orientation of a set of \
components and rays in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space, whose axis of orientation is defined by a line \
intersecting the object set",
  StyleBox["'",
    FontWeight->"Bold"],
  "s position and bisecting a starting point and ending point in space.\n\
\[InvisibleSpace]The functioning of ",
  StyleBox["MoveReflected3D",
    FontWeight->"Bold"],
  " has been fully taken over by ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  " in the current version of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " and, as such, ",
  StyleBox["MoveReflected3D",
    FontWeight->"Bold"],
  " is now obsolete. The ",
  StyleBox["twistangle",
    FontSlant->"Italic"],
  " specifies a rotation around the axis of orientation. Other related \
commands used for positioning components and rays include: ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveRelative", "Subsection"],

Cell[TextData[{
  StyleBox["MoveRelative",
    FontWeight->"Bold"],
  " is an option of all ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " functions that controls the movements of objects. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the objects are moved independent of their orientations. This is the \
default for all move commands. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the object is moved in a coordinate system, defined by its own location \
and orientation, i. e. its ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  ". For ray sources this information is taken from ",
  StyleBox["SourceTransformation",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["RayStart",
    FontWeight->"Bold"],
  " instead of ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The first movement is not affected by this option, \
because the object is at the origin of the global coordinate system. See \
also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MoveSurface", "Subsection"],

Cell[TextData[{
  StyleBox["MoveSurface[",
    FontWeight->"Bold"],
  StyleBox["components",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["moveparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to move the local position and orientation of one or more of \
surfaces, specified by ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  ", within one or more optical ",
  StyleBox["components",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]Here, ",
  StyleBox["moveparameters",
    FontSlant->"Italic"],
  " accepts a sequence of movement parameters used by either ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  " according to the ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " option. For example, if ",
  StyleBox["Head->Move",
    FontWeight->"Bold"],
  " is specified, then, as one possible pattern, ",
  StyleBox["moveparameters",
    FontSlant->"Italic"],
  " would accept: ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", angle. ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  " operates in the local coordinate system of each surface. If more than one \
surface is indicated by ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  ", then each surface shall be treated in an identical fashion according to \
its local coordinate system. If more than one component is present, then the \
surfaces indicated by ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  " within each component shall be affected. If a particular component does \
not have a sufficient number of surfaces, it is left unaffected by ",
  StyleBox["MoveSurface",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Other related commands used for positioning ",
  StyleBox["components",
    FontSlant->"Italic"],
  " and rays include",
  ":",
  " ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveAligned",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MTF", "Subsection"],

Cell[TextData[{
  StyleBox["MTF[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an alias to ",
  StyleBox["ModulationTransferFunction[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MultipleCreatedRays", "Subsection"],

Cell[TextData[{
  StyleBox["MultipleCreatedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/",
    FontWeight->"Bold"],
  StyleBox["numberofrays",
    FontSlant->"Italic"],
  " specifies how many rays are generated at an optical surface by a \
deflection function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["MultipleCreatedRays",
    FontWeight->"Bold"],
  " is only used in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, but is not used by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". In this instance, ",
  StyleBox["True",
    FontWeight->"Bold"],
  " would indicate that more than one ray is created at the surface by the \
deflection function, while ",
  StyleBox["False",
    FontWeight->"Bold"],
  " would indicate that a single ray is generated.  Otherwise, a numeric ",
  StyleBox["numberofrays",
    FontSlant->"Italic"],
  " value can be specified if the precise number of generated rays is known",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NA", "Subsection"],

Cell[TextData[{
  StyleBox["NA",
    FontWeight->"Bold"],
  " is a database rule name that indicates the numerical aperture of a lens \
system.\n\[InvisibleSpace]The numerical aperture is defined as the index of \
refraction (of the image medium",
  ")",
  " times the sine of the half angle of the cone of illumination. The ",
  StyleBox["NA",
    FontWeight->"Bold"],
  " by also be approximated by 0.5",
  StyleBox["/",
    FontWeight->"Bold"],
  "f",
  StyleBox["-",
    FontWeight->"Bold"],
  "number of the system. See also: ",
  StyleBox["FNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NewAuthorizedOptions", "Subsection"],

Cell[TextData[{
  StyleBox["NewAuthorizedOptions",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives a list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " option names authorized in addition to the names listed in ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " for propagating several generations.\n\[InvisibleSpace]",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " parameter names may be added or removed from ",
  StyleBox["NewAuthorizedOptions",
    FontWeight->"Bold"],
  " by a surface ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function. Unauthorized ray parameters (labels not listed in ",
  StyleBox["NewAuthorizedOptions",
    FontWeight->"Bold"],
  " or in ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  ")",
  " are allowed to propagate to the next ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface interaction before removal. Note that every ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object may have its own unique list of new authorized parameters. In \
general, these lists will not be the same."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NewRay", "Subsection"],

Cell[TextData[{
  StyleBox["NewRay",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " and designates that newly created ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects are returned from ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If specified in ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  " creates a new set of one or more ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  " can only be given as an output object. Inputs from previous ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  " objects are given by ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NewSCx", "Subsection"],

Cell[TextData[{
  StyleBox["NewSCx",
    FontWeight->"Bold"],
  " is a symbol that denotes the first of the parametric surface \
coordinates",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NewSCy", "Subsection"],

Cell[TextData[{
  StyleBox["NewSCy",
    FontWeight->"Bold"],
  " is a symbol that specifies the second of the parametric surface \
coordinates",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NewSources", "Subsection"],

Cell[TextData[{
  StyleBox["NewSources",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["newsources",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that lists new sources for a ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object.\n\[InvisibleSpace]",
  StyleBox["NewSources",
    FontWeight->"Bold"],
  " replaces all the sources in the object. This option may reduce \
calculation time considerably, because ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " can recycle most of the optical system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NextValue", "Subsection"],

Cell[TextData[{
  StyleBox["NextValue",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " that gives a follow",
  StyleBox["-",
    FontWeight->"Bold"],
  "up number to help ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " begin its search",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NoCoating", "Subsection"],

Cell[TextData[{
  StyleBox["NoCoating",
    FontWeight->"Bold"],
  " designates that no coating is present",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormalizePlot", "Subsection"],

Cell[TextData[{
  StyleBox["NormalizePlot",
    FontWeight->"Bold"],
  " is an option that indicates whether the plotted information should be \
normalized.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "When used with ",
  StyleBox["ModulationTransferFunction",
    FontWeight->"Bold"],
  ", both the plotted and the returned modulation transfer function \
information are normalized for ",
  StyleBox["NormalizePlot",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ". However, with other functions, the plotted information is normalized \
without altering the returned function information",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NoSurfaceIntersection", "Subsection"],

Cell[TextData[{
  StyleBox["NoSurfaceIntersection",
    FontWeight->"Bold"],
  " is a placeholder that designates an invalid intersection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It is used in ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " to avoid empty tensors",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NotFirstSlot", "Subsection"],

Cell[TextData[{
  StyleBox["NotFirstSlot",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " and designates that all but the first slot position within each confined \
path in ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " inherits the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NotLastSlot", "Subsection"],

Cell[TextData[{
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  " and denotes that all but the last slot position within each confined path \
in ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  " inherits the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function trait.\n\[InvisibleSpace]In general, ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function traits are added to a surface by appending the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function position (within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ")",
  " to the affected ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " value within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FirstSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NotLastSlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["IndependentSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberElements", "Subsection"],

Cell[TextData[{
  StyleBox["NumberElements",
    FontWeight->"Bold"],
  " is a database rule name that indicates the number of lens elements \
present in the compound lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberLength", "Subsection"],

Cell[TextData[{
  StyleBox["NumberLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  " that controls the string length of numbers produced by ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfCycles", "Subsection"],

Cell[TextData[{
  StyleBox["NumberOfCycles",
    FontWeight->"Bold"],
  " returns the total number of ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace function calls made by ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  " to obtain the minimized result.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfElementGroups", "Subsection"],

Cell[TextData[{
  StyleBox["NumberOfElementGroups",
    FontWeight->"Bold"],
  " is a database rule name that indicates the number of lens element groups \
present in the compound lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfPoints", "Subsection"],

Cell[TextData[{
  StyleBox["NumberOfPoints",
    FontWeight->"Bold"],
  " is an option that gives the number of discrete sampling points to be \
used",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " is an option of ray sources that designates the number of rays to be \
initially created by a ray source function. See also",
  ":",
  " ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumberOfSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["NumberOfSurfaces",
    FontWeight->"Bold"],
  " is a database rule name that specifies the total number of surfaces \
present in a lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numeric", "Subsection"],

Cell[TextData[{
  StyleBox["Numeric",
    FontWeight->"Bold"],
  " is a value of the ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceNormalCalculations",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  ", that designates that a direct numerical calculation is used for \
determining surface normals and ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "intersection coordinates",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumericJacobianFunction", "Subsection"],

Cell[TextData[{
  StyleBox["NumericJacobianFunction[",
    FontWeight->"Bold"],
  StyleBox["function",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to designate a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " that calculates ",
  StyleBox["Jacobian",
    FontWeight->"Bold"],
  " of a surface.\n\[InvisibleSpace]",
  StyleBox["NumericJacobianFunction",
    FontWeight->"Bold"],
  " replaces the ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " head and is always used in connection with the ",
  StyleBox["JacobianMatrix",
    FontWeight->"Bold"],
  " rule embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. The principle advantage of ",
  StyleBox["NumericJacobianFunction",
    FontWeight->"Bold"],
  " is that it hides the contents of the ",
  StyleBox["function",
    FontSlant->"Italic"],
  " from normal view. See also",
  ":",
  " ",
  StyleBox["NumericSurfaceNormalFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumericSurfaceNormalFunction", "Subsection"],

Cell[TextData[{
  StyleBox["NumericSurfaceNormalFunction[",
    FontWeight->"Bold"],
  StyleBox["compiledfunction",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to designate a compiled function that calculates surface normal.\n\
\[InvisibleSpace]",
  StyleBox["NumericSurfaceNormalFunction",
    FontWeight->"Bold"],
  " replaces the ",
  StyleBox["CompiledFunction",
    FontWeight->"Bold"],
  " head and is always used in connection with the ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " rule embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. The principle advantage of ",
  StyleBox["NumericSurfaceNormalFunction",
    FontWeight->"Bold"],
  " is that it hides the contents of the function from normal view. ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " is used as a wrapper instead of ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " when numeric surface normal function is not compiled. See also",
  ":",
  " ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NumericJacobianFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OffAxis", "Subsection"],

Cell[TextData[{
  StyleBox["OffAxis",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xoffset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yoffset",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option that specifies an offset of the axis of symmetry for curved \
surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Offx", "Subsection"],

Cell[TextData[{
  StyleBox["Offx",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " to indicate an offset value",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Offy", "Subsection"],

Cell[TextData[{
  StyleBox["Offy",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " to indicate an offset value",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Offz", "Subsection"],

Cell[TextData[{
  StyleBox["Offz",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " to indicate an offset value",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpenSide", "Subsection"],

Cell[TextData[{
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["CylinderGraphic",
    FontWeight->"Bold"],
  " that allows for an opening to be formed in the Cylinder shell.\n\
\[InvisibleSpace]",
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " takes a list of two numbers, ",
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["anglestart",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["anglestop",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", given in radians. ",
  StyleBox["OpenSide",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " indicates a closed cylinder",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticalLength", "Subsection"],

Cell[TextData[{
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the total optical path length of the ray from the beginning of \
its creation up to a particular surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticalMedium", "Subsection"],

Cell[TextData[{
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that identifies the optical material medium traversed by each ray \
segment.\n\[InvisibleSpace]The value of ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  " is typically used by ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " for selecting a refractive index model. See also",
  ":",
  " ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticalSystem", "Subsection"],

Cell[TextData[{
  StyleBox["OpticalSystem[{",
    FontWeight->"Bold"],
  StyleBox["listofrays",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofsources",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox["}, GraphicalOutput[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], Options->",
    FontWeight->"Bold"],
  StyleBox["opts",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object containing an ordered listing of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects, ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, and ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " doubles as a value of ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticalSystemQ", "Subsection"],

Cell[TextData[{
  StyleBox["OpticalSystemQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is an ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " object. The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OptimizeSystem", "Subsection"],

Cell[TextData[{
  StyleBox["OptimizeSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " optimizes the performance of an optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " for a specified set of input parameters.\n\[InvisibleSpace]",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  " first calls ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " to create a ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " according to the ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " option setting and then calls a minimization algorithm according to the \
",
  StyleBox["MinimizationType",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " is internally converted into particular settings for the \
ReportedParameter and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". As an alternative to using the ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  " option, the user can instead work directly with the ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". In addition to accepting an optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and components, one or more previously calculated \
results from ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " may be directly passed to ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  ". If more than one ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  " result is passed, ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  " uses the combined merit results to perform the minimization.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["ConstructMeritFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeritType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MinimizationType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OriginalRay", "Subsection"],

Cell[TextData[{
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " and denotes that the original incoming ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object is passed to ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " can also be used with ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ", but only in rare instances. Normally ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " instead. ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " contains the original ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object parameters of the ray incident on the surface from the previous \
generation. See also",
  ":",
  " ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OriginalSurfaceNormalFunction", "Subsection"],

Cell[TextData[{
  StyleBox["OriginalSurfaceNormalFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the normals of the surface functions.\n\[InvisibleSpace]",
  StyleBox["OriginalSurfaceNormalFunction",
    FontWeight->"Bold"],
  " is present when the ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " has been modified by the ",
  StyleBox["AddSurfaceRoughness",
    FontWeight->"Bold"],
  " function and holds the surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "normal information originally given for the surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OriginalSurfaceNormalMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["OriginalSurfaceNormalMatrix",
    FontWeight->"Bold"],
  " is a rule that gives a direction matrix for the point at the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It contains a unit normal vector of the surface as its first element, as \
well as the two unit",
  StyleBox["-",
    FontWeight->"Bold"],
  "tangent vectors. ",
  StyleBox["OriginalSurfaceNormalMatrix",
    FontWeight->"Bold"],
  " works with ",
  StyleBox["OriginalSurfaceNormalFunction",
    FontWeight->"Bold"],
  " within ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OtherDeflections", "Subsection"],

Cell[TextData[{
  StyleBox["OtherDeflections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["data",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that specifies the ",
  StyleBox["data",
    FontSlant->"Italic"],
  " used in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to execute an external call to calculate ray deflections",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OtherShape", "Subsection"],

Cell[TextData[{
  StyleBox["OtherShape",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates that the ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " is something other than planar, spherical, parabolic, or cylindrical",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OtherSymmetry", "Subsection"],

Cell[TextData[{
  StyleBox["OtherSymmetry",
    FontWeight->"Bold"],
  " implies that the symmetry of the object cannot be specified in advance.\n\
\[InvisibleSpace]",
  StyleBox["FresnelSymmetry->OtherSymmetry",
    FontWeight->"Bold"],
  " also makes ",
  StyleBox["SagFit->True",
    FontWeight->"Bold"],
  ". See ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Output", "Subsection"],

Cell[TextData[{
  StyleBox["Output",
    FontWeight->"Bold"],
  " is a value of the ",
  StyleBox["Print",
    FontWeight->"Bold"],
  " option in ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OutputGraphics", "Subsection"],

Cell[TextData[{
  StyleBox["OutputGraphics",
    FontWeight->"Bold"],
  " is a rule returned by a function that holds the plot information in the \
function output.\n\[InvisibleSpace]",
  StyleBox["OutputGraphics",
    FontWeight->"Bold"],
  " is used by several built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in functions of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OutputType", "Subsection"],

Cell[TextData[{
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " is an option of many ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions that is used to indicate the final output format of the \
function evaluation.\n\[InvisibleSpace] However, the allowed settings of ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " can change for different parent functions. With the ",
  StyleBox["AnalyzeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " functions, there are two common ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " modes: ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  ". If the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  " mode is indicated, then a graphics object in the standard ",
  StyleBox["Graphics",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Graphics3D",
    FontWeight->"Bold"],
  " format of Mathematica is returned. The default ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " mode returns the optical component and ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace information, as an ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " object, that can be analyzed and manipulated by the functions of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " is also an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  " to denote the format of the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing output. With ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " or ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " and both a light source and one or more optical elements being present, \
",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  " both constructs and executes a compiled ray trace that is encapsulated in \
the ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", the result is compiled and returned without execution as a ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " object. With ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  ", all symbolic parameters are ignored and a numeric trace of the system is \
executed. In addition, ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  " also uses the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  " as previously described. Finally, a few advanced built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in functions call ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " setting. In this case, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " object (without compiling a ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ").\n\[InvisibleSpace]See also: ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OutsideMedium", "Subsection"],

Cell[TextData[{
  StyleBox["OutsideMedium",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Box",
    FontWeight->"Bold"],
  " that sets the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " used outside ",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Box",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PaddingFactor", "Subsection"],

Cell[TextData[{
  StyleBox["PaddingFactor",
    FontWeight->"Bold"],
  " is an option that gives the number zero data points to be used for \
padding around the nonzero data points.\n\[InvisibleSpace]The number of zero \
data points is expressed by a factor of the non",
  StyleBox["-",
    FontWeight->"Bold"],
  "zero data points (given by ",
  StyleBox["NumberOfPoints",
    FontWeight->"Bold"],
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PAN", "Subsection"],

Cell[TextData[{
  StyleBox["PAN",
    FontWeight->"Bold"],
  " specifies the use of the polyacrylonitrile polymer medium.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["PAN",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicDiffuser", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicDiffuser[",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ParabolicDiffuser[",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a parabolic, diffusing, component that splits incoming rays into \
diffused rays rays after an optical surface using the ray scattering \
distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["ParabolicDiffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction.  The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicDiffuserMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ParabolicDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a parabolic, diffusing, reflective, component that splits incoming \
rays into diffused rays reflected rays after an optical surface using the ray \
scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser.\n\[InvisibleSpace]",
  StyleBox["ParabolicDiffuserMirror",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicLensSurface[",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a parabolic component that models the refractive index \
boundary at a lens surface.\n\[InvisibleSpace]The ",
  StyleBox["focus",
    FontSlant->"Italic"],
  " specifies a curvature that a reflective parabolic surface must have to \
get this focal length. ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicMirror[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ParabolicMirror[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a mirror that has a parabolic reflective side.\n\
\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates the mirror on a flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "backed substrate. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness->True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the maximum edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " option can be used to change substrate rear surface position in off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis parabolic mirrors. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " indicates that the substrate rear surface is located directly behind and \
parallel with the local off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis mirror surface. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " only ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is recognized. For ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the substrate orientation remains fixed with the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and parallel with the parabolic vertex. In addition, ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " changes the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken for the projected boundary shape onto the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane (as seen from projection down the primary optical (x) axis). For \
",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the specified ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is taken as the actual boundary shape of the off",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis surface (as seen by projection down the local surface normal). The ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " option automatically changes its value to fit best with other ",
  StyleBox["options",
    FontSlant->"Italic"],
  " settings of ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicMirrorWithHole", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicMirrorWithHole",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " option instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParabolicShape", "Subsection"],

Cell[TextData[{
  StyleBox["ParabolicShape",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that indicates the parabolic ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PartialDispersionRatio", "Subsection"],

Cell[TextData[{
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  " is a rule name that specifies the partial dispersion ratio, Pdc ",
  StyleBox["=",
    FontWeight->"Bold"],
  " (nd",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc) ",
  StyleBox["/",
    FontWeight->"Bold"],
  " (nf",
  StyleBox["-",
    FontWeight->"Bold"],
  "nc",
  ")",
  ", and represents the second order chromatic aberration contribution of an \
optical material.\n\[InvisibleSpace]Here, nf, nd, and nc are the refractive \
index values for three different wavelengths specified by the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option. See also: ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PavilionAngle", "Subsection"],

Cell[TextData[{
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that indicates the angle (in degrees) that the Pavilion facet makes \
with respect to the girdle waist. Note that ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  " are all complementary ways of defining the facet dimensions on the \
pavilion (below the girdle",
  ")",
  ".\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PavilionDepth", "Subsection"],

Cell[TextData[{
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that specifies the vertical distance from the girdle waist to the \
bottom vertex of the culet as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter. Note that ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  " are all complementary ways of defining the facet dimensions on the \
pavilion (below the girdle",
  ")",
  ".\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PechanPrism", "Subsection"],

Cell[TextData[{
  StyleBox["PechanPrism[",
    FontWeight->"Bold"],
  StyleBox["smallentranceside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to an image erecting prism that does not deviate or displace an \
image but can be used to invert or revert an image.\n\[InvisibleSpace]",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  " performs the same function as the ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", but it also works with converging and diverging beams. ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  " is located with its small entrance face centered in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and its rotation axis aligned with the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. Two surfaces of ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  " are reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated. ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["SurfaceSeparation",
    FontWeight->"Bold"],
  " to denote the airspace between the two prism halves. ",
  StyleBox["SurfaceSeparation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["relativevector",
    FontSlant->"Italic"],
  " gives a relative vector factor that gets multiplied by ",
  StyleBox["smallentranceside",
    FontSlant->"Italic"],
  " to determine the airspaced offset for the prism interface. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PellinBrocaPrism", "Subsection"],

Cell[TextData[{
  StyleBox["PellinBrocaPrism[",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Bside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Aside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a six",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided prism having polygon dimensions on two sides and rectangular \
dimensions on the remaining sides.\n\[InvisibleSpace]",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  " is initially generated with the ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " corner vertex placed at the origin of the global coordinate system and \
with the large polygon prism faces lieing in the horizontal x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane direction. The ",
  StyleBox["Bside",
    FontSlant->"Italic"],
  " is initially generated to touch the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  " is primarily used in wavelength dispersion and beam separation \
applications. For normal operation, the ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " angle is set at 60 degrees and the ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " angle is roughly between 75 and 80 degrees. Typical values for the \
remaining parameters are: ",
  StyleBox["Aside",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 24 mm, ",
  StyleBox["Bside",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 40 mm, and ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 10 mm. The beam entrance can be on either the ",
  StyleBox["Aside",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Bside",
    FontSlant->"Italic"],
  " at roughly the Brewster angle of incidence and depending on which side is \
chosen, the result will have either positive or negative dispersion. The \
resulting output beams leave the prism at roughly the Brewster angle and \
approximately 90 degrees to the input beam. One can orient ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  " such that the degree of deflection is exactly 90 for one desired \
wavelength. (Notes by Alex Angerhofer, Dept of Chemistry, University of \
Florida) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PentaPrism", "Subsection"],

Cell[TextData[{
  StyleBox["PentaPrism[",
    FontWeight->"Bold"],
  StyleBox["entranceheight",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a prism having and five rectangular faces and two pentagon \
faces.\n\[InvisibleSpace]",
  StyleBox["PentaPrism[",
    FontWeight->"Bold"],
  StyleBox["entranceheight",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prismthickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is another pattern for ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ". ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  " is located with its entrance face centered in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and its polygon faces laying in the horizontal x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane direction. ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  " is commonly used to deviate a beam by exactly 90 degrees. Two surfaces of \
",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  " are always reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated. A third, middle surface is also reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated with the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " makes the two pentagon surfaces absorptive. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseAngle", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseAngle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  " that specifies a phase angle or a range of phase angles. See also",
  ":",
  " ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseMismatch", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseMismatch",
    FontWeight->"Bold"],
  " is an unauthorized rule of ray that denotes the phase mismatch in radians \
of a diffracted wave. It is not normalized.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseRetardation", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseRetardation[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["wavedifference",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that uses retards the phase of polarized rays \
in order to rotate their polarization state.\n\[InvisibleSpace]The ",
  StyleBox["wavedifference",
    FontSlant->"Italic"],
  " parameter, given in wavelength fractions, determines the amount of phase \
delay between two polarization states. The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the first \
polarization state along the optical surface with respect to the horizontal \
axis of the local surface coordinate system. See also",
  ":",
  " ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DielectricTensor",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseShift", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseShift",
    FontWeight->"Bold"],
  " is a parameter of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " that specifies the accumulated phase shift of a ray from optical",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface interactions.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["PhaseShift",
    FontWeight->"Bold"],
  " is specified in wavelength units. ",
  StyleBox["PhaseShift",
    FontWeight->"Bold"],
  " is used by optical elements such as beam splitters and mirrors. Note that \
",
  StyleBox["PhaseShift",
    FontWeight->"Bold"],
  " does not include the optical path length information, which is instead \
stored in the ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  " parameter",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseTilt", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseTilt",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate that designates the direction in which the real \
phase of the ray segment is pointing in space. For dielectrics it is the same \
as ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ". The option is unauthorized and not part of ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhaseTransferFunction", "Subsection"],

Cell[TextData[{
  StyleBox["PhaseTransferFunction",
    FontWeight->"Bold"],
  " is a rule returned gives the phase transfer function of an imaging system \
for a specific image point",
  ".",
  "\n\[InvisibleSpace]",
  StyleBox["PhaseTransferFunction",
    FontWeight->"Bold"],
  " is also a label used with the ",
  StyleBox["RenderedParameters",
    FontWeight->"Bold"],
  " option"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhosphateResistance", "Subsection"],

Cell[TextData[{
  StyleBox["PhosphateResistance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the phosphate resistance of a \
material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PinHole", "Subsection"],

Cell[TextData[{
  StyleBox["PinHole[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PinHole[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a planar component with a hole created in its middle.\n\
\[InvisibleSpace]",
  StyleBox["PinHole",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " and ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " arguments may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pipe", "Subsection"],

Cell[TextData[{
  StyleBox["Pipe[",
    FontWeight->"Bold"],
  StyleBox["outerdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["wallthickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a cylindrical pipe that has a given diameter and wall \
thickness that models the optical properties of a transparent, thick",
  StyleBox["-",
    FontWeight->"Bold"],
  "walled cylinder.\n\[InvisibleSpace]",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " may be filled with an index medium other than ",
  StyleBox["Air",
    FontWeight->"Bold"],
  " by having the interior intrinsic index of refraction given by the option \
",
  StyleBox["InsideMedium",
    FontWeight->"Bold"],
  ". The refractive index of the pipe walls is given by the ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["Pipe",
    FontWeight->"Bold"],
  " is created with its center located at the origin and its length (",
  StyleBox["height",
    FontSlant->"Italic"],
  ") oriented vertically.  The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. See also ",
  StyleBox["Box",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlanarShape", "Subsection"],

Cell[TextData[{
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates a planar ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlanoConcaveCylindricalLens", "Subsection"],

Cell[TextData[{
  StyleBox["PlanoConcaveCylindricalLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a lens with a planar surface on one side and a concave \
cylindrical surface on the other side.\n\[InvisibleSpace]",
  StyleBox["PlanoConcaveCylindricalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlanoConcaveLens", "Subsection"],

Cell[TextData[{
  StyleBox["PlanoConcaveLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a lens with a planar surface on one side and a concave spherical \
surface on the other side.\n\[InvisibleSpace]",
  StyleBox["PlanoConcaveLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlanoConvexCylindricalLens", "Subsection"],

Cell[TextData[{
  StyleBox["PlanoConvexCylindricalLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a lens with a planar surface on one side and a convex cylindrical \
surface on the other side.\n\[InvisibleSpace]",
  StyleBox["PlanoConvexCylindricalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlanoConvexLens", "Subsection"],

Cell[TextData[{
  StyleBox["PlanoConvexLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a lens with a planar surface on one side and a convex spherical \
surface on the other side.\n\[InvisibleSpace]",
  StyleBox["PlanoConvexLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]Note that the \
specified ",
  StyleBox["focallength",
    FontSlant->"Italic"],
  " is always determined for a particular setting of the ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". By default, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["DesignWaveLength->",
    FontWeight->"Bold"],
  "0.5461 microns and ",
  StyleBox["ComponentMedium->BK7",
    FontWeight->"Bold"],
  ". Care should be taken to insure that these default settings are \
compatible with the intended experimental design or unintended results can \
occur."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot2D", "Subsection"],

Cell[TextData[{
  StyleBox["Plot2D",
    FontWeight->"Bold"],
  " is an option that indicates whether the plotted information is given in \
two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions or three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions for three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace data sets.\n\[InvisibleSpace]",
  StyleBox["Plot2D->True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Plot2D->SideView",
    FontWeight->"Bold"],
  " specifies a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional plot taken along the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis of the data. ",
  StyleBox["Plot2D->FrontView",
    FontWeight->"Bold"],
  " specifies a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional plot taken along the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis of the data. ",
  StyleBox["Plot2D->False",
    FontWeight->"Bold"],
  " is used to specify a full three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional plot of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional data and in some functions and a ",
  StyleBox["DensityPlot",
    FontWeight->"Bold"],
  " in other functions. Finally, ",
  StyleBox["Plot2D->ContourPlot",
    FontWeight->"Bold"],
  " is used to specify a contour plot of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional data in some functions. Note that if three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional data is not available for the chosen ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace data then only a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional plot will be given",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotDomain", "Subsection"],

Cell[TextData[{
  StyleBox["PlotDomain->{{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is an option that gives the surface plot boundary dimensions at a \
designated surface.\n\[InvisibleSpace]",
  StyleBox["PlotDomain->{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used for one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional traces. (Technical note: ",
  StyleBox["PlotDomain",
    FontWeight->"Bold"],
  " is essentially a design fix to the flawed, built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in ",
  StyleBox["PlotRegion",
    FontWeight->"Bold"],
  " option of Mathematica, since ",
  StyleBox["PlotRegion",
    FontWeight->"Bold"],
  " does not accept a simple plot",
  StyleBox["-",
    FontWeight->"Bold"],
  "domain specification.",
  ")"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotFactor", "Subsection"],

Cell[TextData[{
  StyleBox["PlotFactor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["widthscale",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["heightscale",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " and a rule embedded within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that independently scales the plot resolution of the ",
  "graphics",
  " rendering for the width and height of surfaces."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotType", "Subsection"],

Cell[TextData[{
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that designates the display form of the graphics rendering.\n\
\[InvisibleSpace]",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " takes ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  " as values.\n\[InvisibleSpace]A list of one or two points specify a \
direction and center to project the ",
  "graphics",
  ". The points can be specified as rules ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["sel",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["sel",
    FontSlant->"Italic"],
  " and ",
  StyleBox["SurfaceSelect",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["sel",
    FontSlant->"Italic"],
  ", with ",
  StyleBox["sel",
    FontSlant->"Italic"],
  " being a list of selection properties passed to the designated functions. \
See also: ",
  StyleBox["CreateStereoView",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ProjectGraphics3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PMMA", "Subsection"],

Cell[TextData[{
  StyleBox["PMMA",
    FontWeight->"Bold"],
  " designates the use of the poly(methyl methacrylate",
  ")",
  " polymer medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["PMMA",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PointOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["PointOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["spread",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays distributed within a funnel",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped volume that is oriented down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter is taken as the full cone angle, in degrees units, for the \
default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting of ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ". However, for other ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " settings, the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter specifies the intercept spatial dimensions, at the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane, of the ray set. If ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a list of two positive numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " forms a rectangular grid of dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ". If the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a single number, then ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " forms a circular grid of rays that has a diameter dictated by the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  ". If the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " is a list of two negative numbers ",
  StyleBox["{-",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", -",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " forms an elliptical grid of elliptical dimensions ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The number of rays in each of the grid dimensions is given in the option \
",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ". ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " may also point to a list of two numbers ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rays1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rays2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " for each direction of the grid of starting points. For circular and \
elliptical shapes the total number of rays is (",
  StyleBox["rays1",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "1",
  ")",
  StyleBox["*",
    FontWeight->"Bold"],
  StyleBox["rays2",
    FontSlant->"Italic"],
  StyleBox["+",
    FontWeight->"Bold"],
  "1 to get a single ray at the center.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PoissonRatio", "Subsection"],

Cell[TextData[{
  StyleBox["PoissonRatio",
    FontWeight->"Bold"],
  " is a database rule name that specifies the Poisson",
  StyleBox["'",
    FontWeight->"Bold"],
  "s Ratio of a material, a dimensionless number",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolarCoordinates", "Subsection"],

Cell[TextData[{
  StyleBox["PolarCoordinates",
    FontWeight->"Bold"],
  " is a value of the option ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The three coordinates are radius, angle in x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane, angle in x",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. The radius may also take the value ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " for ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polarization", "Subsection"],

Cell[TextData[{
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["phaseangle",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that specifies the direction of polarization of the ray segment. It is \
measured in the plane transverse to the axis of propagation.\n\
\[InvisibleSpace]In general, ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["phaseangle",
    FontSlant->"Italic"],
  " are real numbers, with ",
  StyleBox["phaseangle",
    FontSlant->"Italic"],
  " indicating a phase difference between the two transverse directions of \
polarization. The absolute directions of polarization are given by the second \
and third vector elements listed in the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " ray parameter. ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " are all related parameters. Note that ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " is a field quantity, while ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " is an energy quantity",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolarizationFunction", "Subsection"],

Cell[TextData[{
  StyleBox["PolarizationFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is an option of most sources that specifies a function to calculate \
polarizations. The arguments to ",
  StyleBox["f",
    FontSlant->"Italic"],
  " are the ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayEnd",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RaySourceNumber",
    FontWeight->"Bold"],
  ". The evaluation of ",
  StyleBox["f",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " must be a compilable expression, which returns an intensity value. E. g. \
a constant projection of the horizontal polarization 0.8 can be modelled with \
",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "10",
  StyleBox[", Polarization -> {",
    FontWeight->"Bold"],
  "0.8",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0.6",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, PolarizationFunction -> Function[{ #",
    FontWeight->"Bold"],
  "1",
  StyleBox["[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]/Dot[#",
    FontWeight->"Bold"],
  "2",
  StyleBox[",{",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}], Sqrt[",
    FontWeight->"Bold"],
  "1",
  StyleBox["-",
    FontWeight->"Bold"],
  "(",
  StyleBox["#",
    FontWeight->"Bold"],
  "1",
  StyleBox["[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]/Dot[#",
    FontWeight->"Bold"],
  "2",
  StyleBox[",{",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}]",
    FontWeight->"Bold"],
  ")",
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["], #",
    FontWeight->"Bold"],
  "1",
  StyleBox["[[",
    FontWeight->"Bold"],
  "3",
  StyleBox["]] }] ]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolarizingBeamSplitterCube", "Subsection"],

Cell[TextData[{
  StyleBox["PolarizingBeamSplitterCube[",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a solid cube beam splitter that has a polarization reflective \
surface across its diagonal.\n\[InvisibleSpace]",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " is created with one face centered about the origin and the opposite face \
positioned down the positive x axis. The ",
  StyleBox["side",
    FontSlant->"Italic"],
  " parameter specifies the edge dimension of a cube. ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is used to create absorbing surfaces at the top of the bottom of the \
cube. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeBeamSplitter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConjugateBeamSplitter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolarizingPrism", "Subsection"],

Cell[TextData[{
  StyleBox["PolarizingPrism[",
    FontWeight->"Bold"],
  StyleBox["interfaceangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperturethickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prismlength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a cubical",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped birefringent prism that has two or three internal interfaces and \
rectangular dimensions on the outside.\n\[InvisibleSpace]",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " is located with its first entrance face centered in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. ",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["SurfaceSeparation",
    FontWeight->"Bold"],
  " to denote an additional space between the joining prism elements. ",
  StyleBox["SurfaceSeparation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["horizontalgap",
    FontSlant->"Italic"],
  " gives the absolute horizontal spacing of the prism interface. The angle \
of the interface, given by ",
  StyleBox["interfaceangle",
    FontSlant->"Italic"],
  ", is measured from the first entrance surface of the prism.\n\
\[InvisibleSpace]",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " assumes that a single type of birefringent and isotropic material is used \
throughout the prism construction. ",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["isotropicmedium",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " to designate the ordinary and extraordinary refractive index of the \
birefringent material of the prism elements that has an isotropic refractive \
index in the interface between the different prism elements. Otherwise, the \
option ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["isotropicmedium",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is used to denote an isotropic index material for the prism elements with \
a birefringent interface between the prism elements. Finally, ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["mediumO",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["mediumE",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to indicate air",
  StyleBox["-",
    FontWeight->"Bold"],
  "spaced birefringent prism elements (the air",
  StyleBox["-",
    FontWeight->"Bold"],
  "space is automatically given by ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ").\n\[InvisibleSpace]",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " uses the option ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " to indicate whether there exists one or two distinct internal interfaces \
that connect either two or three corresponding prism elements. The default ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " creates a single interface with two connecting pieces. With ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", three prism elements are created, and the third element always takes the \
mirror",
  StyleBox["-",
    FontWeight->"Bold"],
  "image shape of the first crystal in the prism",
  StyleBox["-",
    FontWeight->"Bold"],
  "element sequence.\n\[InvisibleSpace]The birefringent axis alignment is \
given by ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter indicates the birefringent alignment relative to the horizontal \
(y",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis) of the first prism surface (along the optical axis). If a single \
value is given for ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  ", the following crystal pieces are assumed to have their birefringent axes \
rotated by 90 degrees, consecutively. Otherwise, two values for ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " may be given, and in this way, the birefringent axis may be directly \
specified for the first and second prism elements. If three pieces of \
crystals are used (i.e. ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  "), the third prism element retains the same ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " as the first prism element.\n\[InvisibleSpace]Lastly, the ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is used to specify a second exit face to the prism assembly. This \
additional face is used to guide the critically reflected beam out of the \
prism. ",
  StyleBox["PolarizingPrism",
    FontWeight->"Bold"],
  " can be used to define many types of polarizing prisms such as Wollaston, \
Glan",
  StyleBox["-",
    FontWeight->"Bold"],
  "TaylorPrism, and Glan",
  StyleBox["-",
    FontWeight->"Bold"],
  "Thompson. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["BirefringentLensSurface",
    FontWeight->"Bold"],
  ", FresnelRhom, ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RetardationPlate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomBirefringentLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolygonalMirror", "Subsection"],

Cell[TextData[{
  StyleBox["PolygonalMirror[",
    FontWeight->"Bold"],
  StyleBox["numberofsides",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a polygonal mirror having radial symmetry and vertical \
surfaces.\n\[InvisibleSpace]",
  StyleBox["PolygonalMirror",
    FontWeight->"Bold"],
  " is initially placed with its axis of symmetry located vertically at the \
origin. The ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  " parameter specifies the ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  " of a circle circumscribing the polygon. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolygonGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["PolygonGraphic[",
    FontWeight->"Bold"],
  StyleBox["numberofsides",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional equilateral polygon lying in the horizontal x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane with its center placed at the origin of the coordinate system.\n\
\[InvisibleSpace]",
  StyleBox["PolygonGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but can be listed with active \
components or with other graphics components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  " parameter specifies the ",
  StyleBox["diameter",
    FontSlant->"Italic"],
  " of a circle circumscribing the polygon. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PorroPrism", "Subsection"],

Cell[TextData[{
  StyleBox["PorroPrism[",
    FontWeight->"Bold"],
  StyleBox["entrancelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a triangular corner prism that has rounded edges.\n\
\[InvisibleSpace]",
  StyleBox["PorroPrism",
    FontWeight->"Bold"],
  " is created with entrance face lying in the vertical y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. If the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, a reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surface is placed on the two reflective faces of the prism. For ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the side surface panels are refractive surfaces. If the ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, the side panels absorb any rays hitting them. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PosH", "Subsection"],

Cell[TextData[{
  StyleBox["PosH",
    FontWeight->"Bold"],
  " is a symbol that indicates the horizontal, y",
  StyleBox["-",
    FontWeight->"Bold"],
  "displacement position of a paraxial ray in a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system.\n\[InvisibleSpace]",
  StyleBox["PosH",
    FontWeight->"Bold"],
  " is designed to be used exclusively by light sources in paraxial ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations. See also",
  ":",
  " ",
  StyleBox["PosV",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SlopeH",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SlopeV",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PositionGroup", "Subsection"],

Cell[TextData[{
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the translation of objects. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", all objects passed to ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " are considered to be separate objects. All other values result in moving \
the whole group. In combination with ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objectnumber",
    FontSlant->"Italic"],
  " or ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["groupposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["grouprotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can identify the group, otherwise the orientation and position of a group \
is given by its first object. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PositionRelative", "Subsection"],

Cell[TextData[{
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the translation of objects. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the objects are translated to the given coordinates, independent of \
their actual positions. All other values result in a relative translation. In \
combination with ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PosV", "Subsection"],

Cell[TextData[{
  StyleBox["PosV",
    FontWeight->"Bold"],
  " is a symbol that specifies the vertical, z",
  StyleBox["-",
    FontWeight->"Bold"],
  "displacement position of a paraxial ray in a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional paraxial coordinate system.\n\[InvisibleSpace]",
  StyleBox["PosV",
    FontWeight->"Bold"],
  " is designed to be used exclusively by light sources in paraxial ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations. See also",
  ":",
  " ",
  StyleBox["PosH",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SlopeH",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SlopeV",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PowerOutput", "Subsection"],

Cell[TextData[{
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  " is an option of light source functions that specifies the total \
integrated output power or energy to be expressed by a particular light \
source.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  " is used for making energy calculations by some built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in functions such as ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ". ",
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  " can take either power or energy units such as Watts or Joules. While the \
scale for these units can be arbitrary, for meanful results, it is important \
that all light sources in a particular ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace are specified in a consistent fashion. ",
  StyleBox["PowerOutput",
    FontWeight->"Bold"],
  " does not directly change the value of the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " parameter, but is instead used to create an ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  ". Note that ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  " is currently only implemented for ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["IntensityScale",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntensityFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrependGraphics", "Subsection"],

Cell[TextData[{
  StyleBox["PrependGraphics",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["primitiveslist",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that gives a list of ",
  "graphics",
  " to be rendered before those of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["AppendGraphics",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrinciplePointSeparation", "Subsection"],

Cell[TextData[{
  StyleBox["PrinciplePointSeparation",
    FontWeight->"Bold"],
  " is a database rule name that specifies the distance between the two \
principle planes in a lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prism", "Subsection"],

Cell[TextData[{
  StyleBox["Prism[{",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a triangular refractive prism specified by two angles, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ", a ",
  StyleBox["side",
    FontSlant->"Italic"],
  " between the two angles, and a ",
  StyleBox["height",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["Prism",
    FontWeight->"Bold"],
  " is created with its triangle lying in the horizontal x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane and its ",
  StyleBox["height",
    FontSlant->"Italic"],
  " pointing vertically. The specified ",
  StyleBox["side",
    FontSlant->"Italic"],
  " is bisected by the origin, pointing in line with the x axis. If the ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  " is created instead with its left apex surface centered on the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " option is used to specify reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surfaces in the prism. ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be used to indicate one or more reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surfaces. Otherwise, ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " can hold the values: ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Base",
    FontWeight->"Bold"],
  ". For ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the triangular surface panels are refractive surfaces. If the ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, the triangular surface panels absorb any rays hitting \
them. ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can also be used. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ProgressReport", "Subsection"],

Cell[TextData[{
  StyleBox["ProgressReport",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " that controls printing of progress. ",
  StyleBox["ProgressReport",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " results in a printed out display of distance values determined by ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PropagateSystem", "Subsection"],

Cell[TextData[{
  StyleBox["PropagateSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements defined by a mixed list of ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, traces the rays through the components, and returns the results \
as an ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " object carrying a divided listing of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Source",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects.\n\[InvisibleSpace]",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is called internally by ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " as well as by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " (with ",
  StyleBox["ScoutTrace->True",
    FontWeight->"Bold"],
  ")",
  ". See also ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AnalyzeSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PropagateSystemDeflection", "Subsection"],

Cell[TextData[{
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["CustomDeflections",
    FontWeight->"Bold"],
  " that specifies the ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " to be used in ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations.\n\[InvisibleSpace]When ",
  StyleBox["CustomDeflections",
    FontWeight->"Bold"],
  " uses an input deflection function parameter that is compatible with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations, then ",
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " is not utilized. Otherwise, the input deflection function parameter is \
only used for ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations and ",
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " is used with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". ",
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic/Transmission",
    FontWeight->"Bold"],
  " uses a ",
  StyleBox["Transmission-",
    FontWeight->"Bold"],
  "type ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  " uses a ",
  StyleBox["Reflection-",
    FontWeight->"Bold"],
  "type ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ". In all other cases, the value of ",
  StyleBox["PropagateSystemDeflection",
    FontWeight->"Bold"],
  " is directly passed as the ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " setting in ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PS", "Subsection"],

Cell[TextData[{
  StyleBox["PS",
    FontWeight->"Bold"],
  " specifies the use of the polystyrene polymer medium.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["PS",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilLimited", "Subsection"],

Cell[TextData[{
  StyleBox["PupilLimited",
    FontWeight->"Bold"],
  " is an option that denotes whether the object",
  StyleBox["-",
    FontWeight->"Bold"],
  "scattered light is directed through a centered pupil in the optical \
system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PVA", "Subsection"],

Cell[TextData[{
  StyleBox["PVA",
    FontWeight->"Bold"],
  " denotes the use of the poly(vinyl alcohol",
  ")",
  " polymer medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["PVA",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PVB", "Subsection"],

Cell[TextData[{
  StyleBox["PVB",
    FontWeight->"Bold"],
  " indicates the use of the poly(vinyl benzoate",
  ")",
  " polymer medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["PVB",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PVF", "Subsection"],

Cell[TextData[{
  StyleBox["PVF",
    FontWeight->"Bold"],
  " indicates the use of the poly(vinylformal",
  ")",
  " polymer medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["PVF",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PVP", "Subsection"],

Cell[TextData[{
  StyleBox["PVP",
    FontWeight->"Bold"],
  " designates the use of the poly(vinyl pyrolidone",
  ")",
  " polymer medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["PVP",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pyrex", "Subsection"],

Cell[TextData[{
  StyleBox["Pyrex",
    FontWeight->"Bold"],
  " denotes the use of low",
  StyleBox["-",
    FontWeight->"Bold"],
  "expansion borosilicate glass medium.\n\[InvisibleSpace]The refractive \
index model for ",
  StyleBox["Pyrex",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .49 microns to .64 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quartz", "Subsection"],

Cell[TextData[{
  StyleBox["Quartz",
    FontWeight->"Bold"],
  " specifies the use of a quartz medium.\n\[InvisibleSpace]The refractive \
index model for ",
  StyleBox["Quartz",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .46 microns to 1.06 \
microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QuickSurfaceSort", "Subsection"],

Cell[TextData[{
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that selects between two competing methods for determining ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequencing trajectories.\n\[InvisibleSpace]",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " determines the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequencing order through each of the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object",
  StyleBox["'",
    FontWeight->"Bold"],
  "s surfaces by using an efficient, but occasionally fallible, method. The \
method uses surface center distances to get the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequencing order.\n\[InvisibleSpace]",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " uses a slower, but more exacting approach.\n\[InvisibleSpace]",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " only affects the selection of a path through the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " collection of surfaces. Once a path has been chosen within a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " has no further effect within the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " pathway. ",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " now replaces the previous ",
  StyleBox["QuickTrace",
    FontWeight->"Bold"],
  " option name. ",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " is not directly used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". Instead, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " always assumes a ",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " behavior",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QuickTrace", "Subsection"],

Cell[TextData[{
  StyleBox["QuickTrace",
    FontWeight->"Bold"],
  " has been renamed to ",
  StyleBox["QuickSurfaceSort",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RadialSymmetry", "Subsection"],

Cell[TextData[{
  StyleBox["RadialSymmetry",
    FontWeight->"Bold"],
  " implies that the object is radially symmetric.\n\[InvisibleSpace]In a ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " surface, ",
  StyleBox["RadialSymmetry",
    FontWeight->"Bold"],
  " implies that the surface grooves are circular. See ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RadiusOfCurvature", "Subsection"],

Cell[TextData[{
  StyleBox["RadiusOfCurvature",
    FontWeight->"Bold"],
  " is a database rule name that specifies a list of radius",
  StyleBox["-",
    FontWeight->"Bold"],
  "of",
  StyleBox["-",
    FontWeight->"Bold"],
  "curvatures for a component made up of spherical or cylindrical surfaces. \
See also ",
  StyleBox["SurfaceCurvature",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RainbowOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["RainbowOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["minwavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["maxwavelength",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of overlapping rays that point down the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis (for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting",
  ")",
  " and are distributed over the specified range of wavelengths, given in \
microns.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option. If it is a list of two values, the second is used to calculate \
the ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ". The starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option. The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  " instead.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ray", "Subsection"],

Cell[TextData[{
  StyleBox["Ray[",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " contains rules that is used to characterize a single ray segment of light \
between two optical surfaces.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A sequence of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects is generated by ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " to characterize a single ray of light as it propagates through a branch \
of component surfaces. During a ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculation, each time a ray intersects a new component surface, a new ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " is created made up of new ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " rule values that are either updated from old parameters or introduced as \
new parameters according to the new surface",
  StyleBox["'",
    FontWeight->"Bold"],
  "s ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions. In previous versions of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object could be directly assigned by the user to define new types of \
light source distributions. Presently, however, ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects are only used with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " instead uses the ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object, which can hold the ray information much more efficiently. As \
such, it is no longer recommended to directly specify ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. Instead, one should utilize ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " when a single ray is to be traced and ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " when a greater quantity of user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified rays are required. See ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " for a partial listing of the parameters embedded within ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". Please change ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " only with ",
  StyleBox["SetOptions",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["RayParameters",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayAmplitude", "Subsection"],

Cell[TextData[{
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["ax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ay",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["az",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used within ",
  StyleBox["HeldDeflectionKernel",
    FontWeight->"Bold"],
  " functions to input the electric",
  StyleBox["-",
    FontWeight->"Bold"],
  "field vector of a ray intersection point.\n\[InvisibleSpace]In general, ",
  StyleBox["ax",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ay",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["az",
    FontSlant->"Italic"],
  " are complex numbers that indicate absolute field directions. ",
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  " is automatically generated by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and used internally by some ",
  StyleBox["HeldDeflectionKernel",
    FontWeight->"Bold"],
  " functions. Note that ",
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  " cannot be modified by ",
  StyleBox["HeldDeflectionKernel",
    FontWeight->"Bold"],
  " functions. In order to specify new field information, ",
  StyleBox["AllCreatedAmplitudes",
    FontWeight->"Bold"],
  " must be used instead. In addition, ",
  StyleBox["RayAmplitude",
    FontWeight->"Bold"],
  " is not a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " quantity. Instead, ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " is used to hold the electric",
  StyleBox["-",
    FontWeight->"Bold"],
  "field information.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["AllCreatedAmplitudes",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["RayBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["leftedge",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rightedge",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["topedge",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bottomedge",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is a returned rule that gives the minimum rectangular dimensions that \
encloses the locus of rays at a designated surface.\n\[InvisibleSpace]For the \
one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional case, ",
  StyleBox["RayBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["leftedge",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["rightedge",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayChoice", "Subsection"],

Cell[TextData[{
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " that is used to selectively display ray segments in ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]A typical option value of ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " would be ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{ComponentNumber -> ",
    FontWeight->"Bold"],
  "1",
  StyleBox[", ConfinedPosition -> ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}",
    FontWeight->"Bold"],
  ". See ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  " about how ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " can be structured",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayCurve", "Subsection"],

Cell[TextData[{
  StyleBox["RayCurve",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is composed of a list of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional points composing a curved ray trajectory in space",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayEnd", "Subsection"],

Cell[TextData[{
  StyleBox["RayEnd",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the spatial ending coordinate of a ray segment. It shows the \
three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate point where the ray intersects with the next \
component surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayHistory", "Subsection"],

Cell[TextData[{
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofnames",
    FontSlant->"Italic"],
  " is a specialized, advanced option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that specifies a named list of ray and component parameters to be \
reported at the end of the ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " ray ",
  StyleBox["trace",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Normally, the list of named parameter values, given as ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["name1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["name2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  ", gets recorded after each ray surface interaction. However, with name ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["First",
    FontWeight->"Bold"],
  ", the value before the surface deflection is returned. To get the values \
on both sides of the deflection, name ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{First, Last}",
    FontWeight->"Bold"],
  " is used. The ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  " rule is always reported for both sides of a deflection. The resulting ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " information is passed within the returned ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects of the ",
  StyleBox["trace",
    FontSlant->"Italic"],
  " and is recovered with ",
  StyleBox["ReadRays[",
    FontWeight->"Bold"],
  StyleBox["trace",
    FontSlant->"Italic"],
  StyleBox[", RayHistory]",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " is primarily used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " (with ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ")",
  " in order to obtain surface sequence information from ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " and is seldom used directly. However, such ",
  StyleBox["RayHistory",
    FontWeight->"Bold"],
  " information may be recovered from ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " option setting followed by the ",
  StyleBox["ReadSurfaces",
    FontWeight->"Bold"],
  " function.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReadSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Optica", "Subsection"],

Cell[TextData[{
  StyleBox["Optica",
    FontSlant->"Italic"],
  " is a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing program. This is version 2.0 with the build",
  StyleBox["-",
    FontWeight->"Bold"],
  "date Dec 13, 2004. Some new options may be set in the file \"Options.nb\". \
",
  StyleBox["Options[",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["]",
    FontWeight->"Bold"],
  " contains ",
  StyleBox["Options",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["name",
    FontSlant->"Italic"],
  " to specify the default settings and rules ",
  StyleBox["name",
    FontSlant->"Italic"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  ". Each rule in ",
  StyleBox["listofrules",
    FontSlant->"Italic"],
  " has the form ",
  StyleBox["functioname",
    FontSlant->"Italic"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["listofoptions",
    FontSlant->"Italic"],
  " and is used internally as ",
  StyleBox["SetOptions[",
    FontWeight->"Bold"],
  StyleBox["functioname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["listofoptions",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SetOptions[",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["]",
    FontWeight->"Bold"],
  " sets some default settings, ",
  StyleBox["SetOptions[",
    FontWeight->"Bold"],
  "Optica",
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " selects a named list of settings inside ",
  StyleBox["Options[",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["]",
    FontWeight->"Bold"],
  ". At the end of loading ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", ",
  StyleBox["SetOptions[",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["]",
    FontWeight->"Bold"],
  " is called, but \".mx\" files are used.\n\[InvisibleSpace]If no \".mx\" \
files are used, ",
  StyleBox["Needs[",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  " ",
  StyleBox["context",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["Print",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["All",
    FontWeight->"Bold"],
  " generates a detailed loading progress report, ",
  StyleBox["Print",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " a short one.\n\[InvisibleSpace]See also: ",
  StyleBox["Needs",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$SystemSymbolsIn",
    FontWeight->"Bold"],
  "Optica."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaDeveloper", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Developer[",
    FontWeight->"Bold"],
  StyleBox["switch",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " put the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " developer contexts on the ",
  StyleBox["$ContextPath",
    FontWeight->"Bold"],
  " (",
  StyleBox["switch",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["True",
    FontWeight->"Bold"],
  ") or remove it (",
  StyleBox["switch",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["False",
    FontWeight->"Bold"],
  "). See also: ",
  StyleBox["SwitchContextPath",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaFunction", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Function",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["functionhead",
    FontSlant->"Italic"],
  " is a database rule name that specifies the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " function used to create a model representation of the database item in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaFunctions", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Functions",
    FontWeight->"Bold"],
  " generates a hyperlinked listing of the common high",
  StyleBox["-",
    FontWeight->"Bold"],
  "level functions available in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaPrivate", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Private[",
    FontWeight->"Bold"],
  StyleBox["switch",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " put the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " private context on the ",
  StyleBox["$ContextPath",
    FontWeight->"Bold"],
  " (",
  StyleBox["switch",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["True",
    FontWeight->"Bold"],
  ") or remove it (",
  StyleBox["switch",
    FontSlant->"Italic"],
  " equals ",
  StyleBox["False",
    FontWeight->"Bold"],
  "). See also: ",
  StyleBox["SwitchContextPath",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaSymbols", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Symbols[",
    FontWeight->"Bold"],
  StyleBox["string",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns a list of names defined in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " that are related to the given parameter ",
  StyleBox["string",
    FontSlant->"Italic"],
  ". It is fixed at the ending of the loading process and derived from ",
  StyleBox["ListedSymbolNames",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpticaVersion", "Subsection"],

Cell[TextData[{
  "Optica",
  StyleBox["Version",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that indicates the default mode of behavior where Optica",
  StyleBox["Version->",
    FontWeight->"Bold"],
  "1 indicates the original behavior of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " version 1."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayL", "Subsection"],

Cell[TextData[{
  StyleBox["RayL",
    FontWeight->"Bold"],
  " is a symbol that indicates the length of the ray segment to a particular \
surface intersection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLabel", "Subsection"],

Cell[TextData[{
  StyleBox["RayLabel",
    FontWeight->"Bold"],
  " is now replaced by ",
  StyleBox["RayLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLabelPositions", "Subsection"],

Cell[TextData[{
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["xrelpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yrelpos",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zrelpos",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that indicates the rendering positions of one or more label names in the \
rendered ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". The given coordinates are scaled coordinates. The first coordinate is \
along the ray and runs along the ray from ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1 to 1. The second and third are in the direction of the equivalent parts \
of the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the ray. The scaling is the same as for the labelling offsets for \
components. ",
  StyleBox["{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " is at the center of the ray segment. For display of information at the \
end of a ray, use ",
  StyleBox["{",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  ", to show the label a bit apart from the ray use for example ",
  StyleBox["{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "1",
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace] See also",
  ":",
  " ",
  StyleBox["RayLabels",
    FontWeight->"Bold"],
  ", DisplayInformation, ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GroupLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLabels", "Subsection"],

Cell[TextData[{
  StyleBox["RayLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["raylabel",
    FontSlant->"Italic"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that assigns a descriptive label to the ray. Raylabel can be an \
expression, a string or ",
  StyleBox["StyleForm[",
    FontWeight->"Bold"],
  StyleBox["raylabel",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["format",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["RayLabels",
    FontWeight->"Bold"],
  " is usually accompanied with a specification for ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLength", "Subsection"],

Cell[TextData[{
  StyleBox["RayLength",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the geometric length of the ray segment running between two \
optical surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLimit", "Subsection"],

Cell[TextData[{
  StyleBox["RayLimit",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that sets the maximum number of rays permitted before the ray propagation \
is exited. It exits after the actual calculation step. It can be used to stop \
",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  " ray tracing automatically, or to restrict automatically the memory usage.\
\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLineRGB", "Subsection"],

Cell[TextData[{
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that denotes the color used in rendering the rays.\n\[InvisibleSpace]If \
",
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is used, then the RGB value is determined using the value of ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " with ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  ". ",
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the rendering. Note that ",
  StyleBox["RayLineRGB",
    FontWeight->"Bold"],
  " will not affect the graphical rendering of rays unless the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is used. See also",
  ":",
  " ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ModelRayColor",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLineStyle", "Subsection"],

Cell[TextData[{
  StyleBox["RayLineStyle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that carries a list of user",
  StyleBox["-",
    FontWeight->"Bold"],
  "expressed ",
  "graphics",
  " styles for the rendering of ray lines."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayLineThickness", "Subsection"],

Cell[TextData[{
  StyleBox["RayLineThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that supplies ",
  StyleBox["AbsoluteThickness[#]",
    FontWeight->"Bold"],
  " thickness values for rendering the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayNumber", "Subsection"],

Cell[TextData[{
  StyleBox["RayNumber->",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  " is an option inside a ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipseSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipseSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlotSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValueSelection",
    FontWeight->"Bold"],
  " rule that designates rays to be shown.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  " it is used to show numbers of rays.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In the selection rules it is used to reference specified rays.\n\
\[InvisibleSpace]Possible values are the same as for every rule inside a \
selection rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayParameters", "Subsection"],

Cell[TextData[{
  StyleBox["RayParameters",
    FontWeight->"Bold"],
  " is an array of ray option name lists. Each list collects the option \
names, necessary to describe the information, for example ",
  StyleBox["RayParameters[Field]",
    FontWeight->"Bold"],
  " ",
  StyleBox["==",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization, Intensity, WaveLength}",
    FontWeight->"Bold"],
  ". Defined patterns are: ",
  StyleBox["Source",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Geometry",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Field",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Environment",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Position",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Increment",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RenderSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rest",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayPointRGB", "Subsection"],

Cell[TextData[{
  StyleBox["RayPointRGB",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that designates the color used in rendering the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection points. ",
  StyleBox["RayPointRGB",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the rendering",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayPointSize", "Subsection"],

Cell[TextData[{
  StyleBox["RayPointSize",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that passes information to ",
  StyleBox["AbsolutePointSize",
    FontWeight->"Bold"],
  " for the rendering of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection points",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayPointStyle", "Subsection"],

Cell[TextData[{
  StyleBox["RayPointStyle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that carries a list of user",
  StyleBox["-",
    FontWeight->"Bold"],
  "expressed ",
  "graphics",
  " styles for the rendering of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection points."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayQ", "Subsection"],

Cell[TextData[{
  StyleBox["RayQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object. The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayScatterFunction", "Subsection"],

Cell[TextData[{
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["scatteringfunction",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " that indicates an angular dependent scattering function for diffuse \
optical surfaces.\n\[InvisibleSpace]Typical ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " settings include: ",
  StyleBox["Function[Cos[#]]",
    FontWeight->"Bold"],
  " for cosine",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependant (lambertian",
  ")",
  " scattering, ",
  StyleBox["Function[Cos[#]^",
    FontWeight->"Bold"],
  "2",
  StyleBox["]",
    FontWeight->"Bold"],
  " for non",
  StyleBox["-",
    FontWeight->"Bold"],
  "lambertian scattering, and ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]",
    FontWeight->"Bold"],
  " for uniform scattering. ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["scatteringfunction1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["scatteringfunction2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can also be used to specify a different scattering function in the \
horizontal and vertical angular directions. Finally, ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " works together with the ",
  StyleBox["CosineCompensation",
    FontWeight->"Bold"],
  " option. In particular, with ",
  StyleBox["CosineCompensation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " is internally set to ",
  StyleBox["Function[Cos[#]]",
    FontWeight->"Bold"],
  ". Similarly, with ",
  StyleBox["CosineCompensation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RayScatterFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]",
    FontWeight->"Bold"],
  " is used internally instead."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RaySelect", "Subsection"],

Cell[TextData[{
  StyleBox["RaySelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes an object set composed of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects, and returns a filtered list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects that shares the common set of traits specified in ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]There are two ways of specifying ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ":",
  " the first way is to give a list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " options selected. The second way is to give a function that takes ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " options as inputs and returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". An example of the first method is ",
  StyleBox["{IntersectionNumber -> ",
    FontWeight->"Bold"],
  "3",
  StyleBox[", ComponentNumber -> ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}",
    FontWeight->"Bold"],
  ". An example of the second method is ",
  StyleBox["Function[{ComponentNumber, IntersectionNumber}, ComponentNumber \
== ",
    FontWeight->"Bold"],
  "2",
  StyleBox[" && IntersectionNumber > ",
    FontWeight->"Bold"],
  "10",
  StyleBox["]",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " ",
  StyleBox["===",
    FontWeight->"Bold"],
  " ",
  StyleBox["All",
    FontWeight->"Bold"],
  " or ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is left out, then all ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects are passed back. ",
  StyleBox["RaySelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns an unfiltered list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects.\n\[InvisibleSpace]",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  " can also be used to translate ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " data into ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object format. As an option to ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", it affects how an optical system is converted to a ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RaySelectRayOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["RaySelectRayOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  " that determines the rays, for which an orientation should be drawn. The \
value of the option is directly passed to ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayShowLabels", "Subsection"],

Cell[TextData[{
  StyleBox["RayShowLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that automatically generates label captions for each rendered ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["RayShowLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " switches off for three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional presentations. ",
  StyleBox["RayShowLabels->True",
    FontWeight->"Bold"],
  " also includes labels for three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions. See also",
  ":",
  " ",
  StyleBox["MoveRayLabels",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RaySlot", "Subsection"],

Cell[TextData[{
  StyleBox["RaySlot",
    FontWeight->"Bold"],
  " is an unauthorized rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that designates the position of a ray in a list of rays.\n\
\[InvisibleSpace]The ",
  StyleBox["RaySlot",
    FontWeight->"Bold"],
  " rules are renumbered after every deflection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RaySourceNumber", "Subsection"],

Cell[TextData[{
  StyleBox["RaySourceNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["raycounter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["totalnumber",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["numberlist",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that uniquely identifies a ray inside a source. The ",
  StyleBox["raycounter",
    FontSlant->"Italic"],
  " runs from 1 to ",
  StyleBox["totalnumber",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The list ",
  StyleBox["numberlist",
    FontSlant->"Italic"],
  " holds the numbering of rays for each basic source included in the source. \
Each entry in the list is a list of two integers, numbering the first and \
second dimension of a source. Rows and radial position are first dimensions, \
columns and circumferences are second ones. If a dimension is not present or \
a numbering could not be calculated, the corresponding figure is set to zero. \
Inner sources appear right in ",
  StyleBox["numberlist",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]For example, ",
  StyleBox["LineOfRays[ConeOfRays[",
    FontWeight->"Bold"],
  "10",
  StyleBox[", NumberOfRays -> ",
    FontWeight->"Bold"],
  "2",
  StyleBox["], ",
    FontWeight->"Bold"],
  "10",
  StyleBox[", NumberOfRays -> ",
    FontWeight->"Bold"],
  "3",
  StyleBox["]",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["numberlist",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["{{{",
    FontWeight->"Bold"],
  "1",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "1",
  StyleBox["}}, {{",
    FontWeight->"Bold"],
  "1",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}}, {{",
    FontWeight->"Bold"],
  "2",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "1",
  StyleBox["}}, {{",
    FontWeight->"Bold"],
  "2",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}}, {{",
    FontWeight->"Bold"],
  "3",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "1",
  StyleBox["}}, {{",
    FontWeight->"Bold"],
  "3",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}}}",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Source",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayStart", "Subsection"],

Cell[TextData[{
  StyleBox["RayStart",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the spatial starting coordinate of a ray segment. It shows the \
three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate point where the ray intersected with a component \
surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayTilt", "Subsection"],

Cell[TextData[{
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector that designates the direction in which a ray segment is \
pointing in space. It is the direction of propagation of energy. ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " is normalized internally by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RayTraceFunction", "Subsection"],

Cell[TextData[{
  StyleBox["RayTraceFunction[",
    FontWeight->"Bold"],
  StyleBox["inputparameters",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an encapsulated function, created by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", that contains compiled source code for a specific optical system and \
performs high",
  StyleBox["-",
    FontWeight->"Bold"],
  "speed, geometric ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations.\n\[InvisibleSpace]The ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " object is returned by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " when the option ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " is given. Otherwise, for ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " is left embedded within the ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object and used internally by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  ". In general, user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified symbolic parameters defined for the optical system are \
automatically included in the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["inputparameters",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadComponent", "Subsection"],

Cell[TextData[{
  StyleBox["ReadComponent[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an advanced function that takes an object set composed of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects and returns a list of values for ",
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  " given.\n\[InvisibleSpace]",
  StyleBox["ReadComponent",
    FontWeight->"Bold"],
  " first obtains a filtered set of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects by calling ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  " and using the given ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  " may contain formulas, e. g. ",
  StyleBox["ReadComponent[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", TranslationVector[[",
    FontWeight->"Bold"],
  "3",
  StyleBox["]]]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ReadComponent",
    FontWeight->"Bold"],
  " is an alias of ",
  StyleBox["ReadComponents",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  " for more about ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadComponents", "Subsection"],

Cell[TextData[{
  StyleBox["ReadComponents[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an advanced function that takes an object set composed of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects and returns a list of values for  ",
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  " given.\n\[InvisibleSpace]",
  StyleBox["ReadComponents",
    FontWeight->"Bold"],
  " first obtains a filtered set of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects by calling ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  " and using the given ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["componentparameters",
    FontSlant->"Italic"],
  " may contain formulas, (",
  StyleBox["ReadComponents[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", TranslationVector[[",
    FontWeight->"Bold"],
  "3",
  StyleBox["]]]",
    FontWeight->"Bold"],
  ")",
  ". See also: ",
  StyleBox["ComponentSelect",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadRays", "Subsection"],

Cell[TextData[{
  StyleBox["ReadRays[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an advanced function that takes a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced result and returns a list of values for the ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " given.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  " first obtains a filtered set of rays using the given ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". However, the ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted, in which case, the relevant ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " information from all rays present in the system will be reported. In \
addition, the ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " may contain formulas, such as ",
  StyleBox["ReadRays[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", Polarization[[",
    FontWeight->"Bold"],
  "3",
  StyleBox["]]]",
    FontWeight->"Bold"],
  " to get the polarization phase shift.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  " works with ",
  StyleBox["AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " results. In the case of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["ReadTurboRays",
    FontWeight->"Bold"],
  " internally and operates much more efficiently when ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is omitted. See also",
  ":",
  " ",
  StyleBox["ReadTurboRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TurboRaySelect",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["ReadSurfaces[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfaceparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an advanced function that takes an object set composed of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and",
  StyleBox["/",
    FontWeight->"Bold"],
  "or ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " objects and returns a list of values for ",
  StyleBox["surfaceparameters",
    FontSlant->"Italic"],
  " given. The objects may be inside an ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " or ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ReadSurfaces",
    FontWeight->"Bold"],
  " first obtains a filtered set of ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " objects by calling ",
  StyleBox["SurfaceSelect",
    FontWeight->"Bold"],
  " and using the given ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["surfaceparameters",
    FontSlant->"Italic"],
  " may contain formulas, e. g. ",
  StyleBox["ReadSurfaces[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", TranslationVector[[",
    FontWeight->"Bold"],
  "3",
  StyleBox["]]]",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["SurfaceSelect",
    FontWeight->"Bold"],
  " for more about ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadTurboRays", "Subsection"],

Cell[TextData[{
  StyleBox["ReadTurboRays[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ", or a list with ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " and returns a list of values for ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " given.\n\[InvisibleSpace]The ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " parameter is used to select the rays in the same fashion as for ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ", and  ",
  StyleBox["TurboRaySelect",
    FontWeight->"Bold"],
  ". However, the ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " parameter in ",
  StyleBox["ReadTurboRays",
    FontWeight->"Bold"],
  " is optional and can be omitted, in which case, the relevant ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " information from all rays present in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " will be reported. In general, ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  " operates much more efficiently when ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is omitted. When ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is included, ",
  StyleBox["ReadTurboRays",
    FontWeight->"Bold"],
  " first calls ",
  StyleBox["TurboRaySelect",
    FontWeight->"Bold"],
  " with ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " to select rays. An example of ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is: ",
  StyleBox["ComponentNumber->",
    FontWeight->"Bold"],
  "1 (see ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  " for further examples.",
  ")",
  " The ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " generally contains a list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " parameter labels that designate a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced value stored in ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ". Some examples of ",
  StyleBox["rayparameters",
    FontSlant->"Italic"],
  " are: ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayEnd",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["TurboRaySelect",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RealTime3D", "Subsection"],

Cell[TextData[{
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " that which allows the rendered three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional graphics to be rotated interactively in the front end.\n\
\[InvisibleSpace]See also: ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateStereoView",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RealTimeGraphicsDisplayFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RecenterData", "Subsection"],

Cell[TextData[{
  StyleBox["RecenterData",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of that specifies the local coordinate origin of sampled \
data from an optical surface.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RecenterData",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " shifts the coordinate origin of sampled data to the center of the data \
sampling aperture. ",
  StyleBox["RecenterData",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " leaves the original data coordinates undisturbed",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RecoverInput", "Subsection"],

Cell[TextData[{
  StyleBox["RecoverInput[",
    FontWeight->"Bold"],
  StyleBox["opticalsystem",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " reconstructs new input expressions for the specified ",
  StyleBox["opticalsystem",
    FontSlant->"Italic"],
  " and is used internally by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " to determine the ",
  StyleBox["Out",
    FontWeight->"Bold"],
  " cell format.\n\[InvisibleSpace] The output format of ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  " is controlled by the ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ". The option ",
  StyleBox["Drop",
    FontWeight->"Bold"],
  " specifies a list of names of rules not to be returned by ",
  StyleBox["RecoverInput",
    FontWeight->"Bold"],
  ". A value of ",
  StyleBox["Default",
    FontWeight->"Bold"],
  " is used to pad incomplete components. Numbers are reconstructed with the \
length given by ",
  StyleBox["NumberLength",
    FontWeight->"Bold"],
  ". The whole reconstruction can be forced to return a string representing \
",
  StyleBox["InputForm[",
    FontWeight->"Bold"],
  StyleBox["opticalsystem",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " with ",
  StyleBox["SetOptions[RecoverInput, Active -> False]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RectangleGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["RectangleGraphic[{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional rectangle lying in the horizontal x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane with its diagonal corners placed at ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xmin",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymin",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xmax",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["ymax",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["RectangleGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but it can be listed with active \
components or with other graphics components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReferenceOrder", "Subsection"],

Cell[TextData[{
  StyleBox["ReferenceOrder",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", used in ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " that sets the reference order for diffraction calculations. It denotes \
the order of diffracted light to which formulas for calculating the \
diffraction efficiencies are referenced. The rule is used only inside \
functions which calculate diffraction efficiencies. See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReferenceSystem", "Subsection"],

Cell[TextData[{
  StyleBox["ReferenceSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["reference",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that specifies a ",
  StyleBox["reference",
    FontSlant->"Italic"],
  " passed to PlugIns of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". This ",
  StyleBox["reference",
    FontSlant->"Italic"],
  " may have the same structure as the objects passed to ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ": ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " or a list of these elements. If ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " fails to find matches between the system passed to ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and the ",
  StyleBox["reference",
    FontSlant->"Italic"],
  ", it sets this element of the ",
  StyleBox["reference",
    FontSlant->"Italic"],
  " to an empty element with the proper head. The ray and component \
information of the ",
  StyleBox["reference",
    FontSlant->"Italic"],
  " is passed to all PlugIns of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", inside ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " no calculations are done with the ",
  StyleBox["reference",
    FontSlant->"Italic"],
  ". See also: ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReferenceWaveLengthNumber", "Subsection"],

Cell[TextData[{
  StyleBox["ReferenceWaveLengthNumber",
    FontWeight->"Bold"],
  " is a database rule name used with multiple",
  StyleBox["-",
    FontWeight->"Bold"],
  "valued ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " entries that specifies which ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " slot gets used for paraxial calculations. See also",
  ":",
  " ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflectance", "Subsection"],

Cell[TextData[{
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  " that specifies the percentage of the incident ray segment intensity that \
is present in a reflected outgoing ray segment.\n\[InvisibleSpace]",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " usually takes values running between 0 and 100. ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " is an option used by mirrors, lenses, and beam splitters. In some cases, \
",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " can be a function. In the case of ordinary refractive surfaces, the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " works in tandom with the ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " option. In this case, for ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["r",
    FontSlant->"Italic"],
  " value (",
  StyleBox["r",
    FontSlant->"Italic"],
  " between 0 ",
  StyleBox["-",
    FontWeight->"Bold"],
  " 100) will automatically generate a reflected ray that is intensity",
  StyleBox["-",
    FontWeight->"Bold"],
  "scaled by ",
  StyleBox["r",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "100 and a transmitted ray that is scaled by (100",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["r",
    FontSlant->"Italic"],
  ")",
  StyleBox["/",
    FontWeight->"Bold"],
  "100 in intensity. By this method, any refractive surface can be made to \
behave as a beamsplitter. However, if a numeric ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " value is specified in addition to the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value, then each option will determine the intensity of a corresponding \
transmitted and reflected ray.\n\[InvisibleSpace]With components that are \
based on ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", however, the form ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used to modify the ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  " components of polarization in a reflected ray. In this case, however, ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " is only used in conjunction with ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/Reflection",
    FontWeight->"Bold"],
  ". In addition to the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value, a value for ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " must always be separately specified for the ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  " function. ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  " permits both ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " to carry either two ",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent functions or two lists of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmittance",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " interpolation points."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection", "Subsection"],

Cell[TextData[{
  StyleBox["Reflection[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that produces reflected rays from optical \
surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Refraction", "Subsection"],

Cell[TextData[{
  StyleBox["Refraction[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block that produces refracted rays through optical \
surfaces.\n\[InvisibleSpace]",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  " and ray ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  " as ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " parameters",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RefractiveIndex", "Subsection"],

Cell[TextData[{
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the refractive index value for the ray segment in the local \
environment. It uses ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to calculate its value.\n\[InvisibleSpace]",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " uses the model",
  StyleBox["'",
    FontWeight->"Bold"],
  "s associated labels supplied by ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ". ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " are other options involving the refractive index. See also",
  ":",
  " ",
  StyleBox["AttenuationIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RefractiveIndexAfter", "Subsection"],

Cell[TextData[{
  StyleBox["RefractiveIndexAfter",
    FontWeight->"Bold"],
  " is a placeholder inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that designates the refractive index of the transmitted ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RefractiveIndexBefore", "Subsection"],

Cell[TextData[{
  StyleBox["RefractiveIndexBefore",
    FontWeight->"Bold"],
  " is a placeholder inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that designates the refractive index of the incident ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RefractiveIndexFunction", "Subsection"],

Cell[TextData[{
  StyleBox["RefractiveIndexFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that designates the functions for the refractive indices on both sides of \
a surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Regular", "Subsection"],

Cell[TextData[{
  StyleBox["Regular",
    FontWeight->"Bold"],
  " is a name inside a ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " rule to describe a general theory in contrast to exceptions defined by \
special names in a theory rule. See also",
  ":",
  " ",
  StyleBox["Theory",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RelativePermeability", "Subsection"],

Cell[TextData[{
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the relative permeability value for the ray segment in the \
local environment. Usually, the relative permeability is unity at optical \
frequencies. The refractive index already includes ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  ", amplitude calculations may involve an additional explicit ",
  StyleBox["RelativePermeability",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RelativePermittivity", "Subsection"],

Cell[TextData[{
  StyleBox["RelativePermittivity",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " ",
  StyleBox["permittivity",
    FontSlant->"Italic"],
  " value for the ray segment in the local environment. The refractive index \
already includes the ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " ",
  StyleBox["permittivity",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " includes the ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " ",
  StyleBox["permittivity",
    FontSlant->"Italic"],
  ", it overwrites the refractive and attenuation index. The effective \
refractive index is then calculated as ",
  StyleBox["Sqrt[",
    FontWeight->"Bold"],
  StyleBox["relative",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["permeability",
    FontSlant->"Italic"],
  StyleBox[" * ",
    FontWeight->"Bold"],
  StyleBox["relative",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["permittivity",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveDeflection", "Subsection"],

Cell[TextData[{
  StyleBox["RemoveDeflection[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block used to remove deflections from surfaces.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RemoveDeflection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["deflectionnumbers",
    FontSlant->"Italic"],
  " takes numbers for deflections and removes them from all surfaces given in \
the option ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["InsertDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RemoveSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveFunctionHead", "Subsection"],

Cell[TextData[{
  StyleBox["RemoveFunctionHead[Function[",
    FontWeight->"Bold"],
  StyleBox["expression",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["localvariables",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " converts the ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " head to a ",
  StyleBox["Hold-",
    FontWeight->"Bold"],
  "headed object and replaces the ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "variable names with the names listed in ",
  StyleBox["localvariables",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RemoveFunctionHead",
    FontWeight->"Bold"],
  " can be used to build a larger held ",
  StyleBox["expression",
    FontSlant->"Italic"],
  " out of several smaller ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expressions without evaluating the subexpressions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveSurface", "Subsection"],

Cell[TextData[{
  StyleBox["RemoveSurface[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RemoveSurface[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a genetic building block used to remove the effects of specified \
surfaces from the ",
  StyleBox["component",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  " is not given, then the ",
  StyleBox["RemoveSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  " option is used instead. See also",
  ":",
  " ",
  StyleBox["InsertDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AffectedSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddDeflection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RemoveDeflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveSurfaceBreaks", "Subsection"],

Cell[TextData[{
  StyleBox["RemoveSurfaceBreaks",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that indicates whether the compiled ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " information should contain special ",
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  " markers that delineate ray information from different surfaces.\n\
\[InvisibleSpace]Normally the ",
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  " information is needed to nest the ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " information into the different surface sites (specified by ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  ")",
  ". However, this ",
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  " information can corrupt the results of ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " when ray information from more than one surface is reported. The default \
setting of ",
  StyleBox["RemoveSurfaceBreaks",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " becomes ",
  StyleBox["False",
    FontWeight->"Bold"],
  " with the default ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Identity",
    FontWeight->"Bold"],
  " setting and ",
  StyleBox["True",
    FontWeight->"Bold"],
  " when ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " is set a user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified function. Consequently, the setting of ",
  StyleBox["RemoveSurfaceBreaks",
    FontWeight->"Bold"],
  " seldom requires the attention of the user.\n\[InvisibleSpace]See also: ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenameLabels", "Subsection"],

Cell[TextData[{
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["oldname1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newname1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["oldname2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["newname2",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that renames one or more of the previously rendered labels.\n\
\[InvisibleSpace]",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  " uses a sequence of two or more words that selects the relevant labels and \
indicates the new label names. See also",
  ":",
  " ",
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenderedParameters", "Subsection"],

Cell[TextData[{
  StyleBox["RenderedParameters",
    FontWeight->"Bold"],
  " is a option that gives the function parameters to be plotted.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["RenderedParameters",
    FontWeight->"Bold"],
  " is passed as an option to a function to select the plotted parameters. ",
  StyleBox["RenderedParameters",
    FontWeight->"Bold"],
  " takes either the ",
  StyleBox["All",
    FontWeight->"Bold"],
  " label, or a list of parameter",
  StyleBox["-",
    FontWeight->"Bold"],
  "types",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenderedPolygons", "Subsection"],

Cell[TextData[{
  StyleBox["RenderedPolygons",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that directs the rendering of one or more planes whose polygonal shapes \
are defined by connecting surfaces given by ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["RenderedPolygons",
    FontWeight->"Bold"],
  " contains nested lists carrying ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StartPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FinishPoint",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  " rules. It is used to define the bounds and render type of the cross \
bridging a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided component",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenderedSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["RenderedSurfaces",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that denotes a nested list of rules that defines the graphical rendering \
of simple surfaces.\n\[InvisibleSpace]",
  StyleBox["RenderedSurfaces",
    FontWeight->"Bold"],
  " contains lists containing ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  " rules",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenderSystem", "Subsection"],

Cell[TextData[{
  StyleBox["RenderSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " renders any ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. These ",
  "graphics",
  " primitives have the head ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenderType", "Subsection"],

Cell[TextData[{
  StyleBox["RenderType",
    FontWeight->"Bold"],
  " is a rule nested within the ",
  StyleBox["RenderedSurfaces",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RenderedPolygons",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies the type of rendering to be performed.\n\
\[InvisibleSpace]",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  " uses one or more of the following command words",
  ":",
  " ",
  StyleBox["Empty",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Fill",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Trace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Mesh",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReplaceFor", "Subsection"],

Cell[TextData[{
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objecttypes",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that indicates which types of objects are replaced by the new parameter \
results of the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function calculation.\n\[InvisibleSpace]",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " supplants the entire contents of an object type regardless of its prior \
contents. For this reason, the command option ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  " is usually preferred over ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  ". Possible object types of ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " include ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  ". Note that the ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  " object type is rarely changed. Modifications to the past ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object type are generally made using ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " instead. ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  " can point to a list of object types, but is often a single value. See \
also",
  ":",
  " ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionLabel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReplaceGraphics", "Subsection"],

Cell[TextData[{
  StyleBox["ReplaceGraphics",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that specifies a list of replacement rules, applied to graphics before \
rendering. Internally, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["ReplaceGraphics",
    FontWeight->"Bold"],
  " to drop some ",
  StyleBox["Text",
    FontWeight->"Bold"],
  " primitives during incremental rendering. See also: ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReportedFunction", "Subsection"],

Cell[TextData[{
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[",
    FontWeight->"Bold"],
  StyleBox["list",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["of",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["reported",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["parameters",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an option ",
  StyleBox["of",
    FontSlant->"Italic"],
  " ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " for ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " that determines the final format ",
  StyleBox["of",
    FontSlant->"Italic"],
  " the raytrace output.\n\[InvisibleSpace]",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " uses the ray information specified by ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " for its calculations. As such, ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " relies on the joint specification ",
  StyleBox["of",
    FontSlant->"Italic"],
  " ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " to provide the ",
  StyleBox["list",
    FontSlant->"Italic"],
  " ",
  StyleBox["of",
    FontSlant->"Italic"],
  " ",
  StyleBox["reported",
    FontSlant->"Italic"],
  " ",
  StyleBox["parameters",
    FontSlant->"Italic"],
  " for its calculation. An example ",
  StyleBox["of",
    FontSlant->"Italic"],
  " this joint specification is ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[Apply[Plus,#]]",
    FontWeight->"Bold"],
  ". A more complex example is ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Function[Sqrt[Apply[Plus,Map[Dot[#,#]&,#]]]/Length[#]]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The default setting ",
  StyleBox["of",
    FontSlant->"Italic"],
  " ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Identity",
    FontWeight->"Bold"],
  " returns the results ",
  StyleBox["of",
    FontSlant->"Italic"],
  " ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " without change. Note that ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " is only used with the ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " option setting ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RemoveSurfaceBreaks",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReportedParameters", "Subsection"],

Cell[TextData[{
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["rayoptionnames",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " for ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " that indicates the ray parameters to be incorporated into the output of \
the ray trace.\n\[InvisibleSpace]Two examples of this are ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Intensity, SurfaceCoordinates}",
    FontWeight->"Bold"],
  ". Instead of ",
  StyleBox["rayoptionnames",
    FontSlant->"Italic"],
  ", the word values ",
  StyleBox["All",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " may be used.\n\[InvisibleSpace]Note that although ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " also exists for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", it cannot be used in combination with ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " ",
  "graphics",
  ". See also: ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReportedRays", "Subsection"],

Cell[TextData[{
  StyleBox["ReportedRays",
    FontWeight->"Bold"],
  " is used as a dummy variable within ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  " to refer to the rays that are reported at the end of a trace",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReportedSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["ReportedSurfaces->",
    FontWeight->"Bold"],
  StyleBox["numbers",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " that indicates which surface results get included in the final ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing report.\n\[InvisibleSpace]Special values are ",
  StyleBox["All",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Last",
    FontWeight->"Bold"],
  " (or ",
  StyleBox["{-",
    FontWeight->"Bold"],
  "1",
  StyleBox["}",
    FontWeight->"Bold"],
  ")",
  ", which specify all surfaces and the last respectively. Both ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " accept a component number or a list of component ",
  StyleBox["numbers",
    FontSlant->"Italic"],
  " to be reported. A sublist of componentnumber and surfacenumbers inside \
the component may also be used. These ",
  StyleBox["numbers",
    FontSlant->"Italic"],
  " relate to the sequence of the system definition.\n\[InvisibleSpace]In ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", the behavior of the ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Last",
    FontWeight->"Bold"],
  " setting is dependent on the ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " option. For ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", only rays striking the last surface present in the trace sequence gets \
reported. However, for ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", all ray intercepts from the last ",
  StyleBox["Component'",
    FontWeight->"Bold"],
  "s surfaces are reported. See also: ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ResolvePoints", "Subsection"],

Cell[TextData[{
  StyleBox["ResolvePoints",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["BundleOfRays",
    FontWeight->"Bold"],
  " that controls whether every point of the created ray list is an \
independent source.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", independent sources are created, if more than one ray is used as seed to \
",
  StyleBox["BundleOfRays",
    FontWeight->"Bold"],
  ". The default is a single ray, ",
  StyleBox["ResolvePoints",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". The id numbers for resolved ray sets start at the number given in the ",
  StyleBox["SourceID",
    FontWeight->"Bold"],
  " option, or are created automatically",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resonate", "Subsection"],

Cell[TextData[{
  StyleBox["Resonate[",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectname",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block, labeled by an optional ",
  StyleBox["objectname",
    FontSlant->"Italic"],
  ", that causes a ray to be nonsequentially traced within all of the \
surfaces defined by ",
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " takes a list of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects and creates a single ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object from the list. Once the all of the surfaces are no longer in its \
trajectory, the ray is allowed to continue propagating to other components. \
This effect enables repeated nonsequential ray interactions with a number of \
surfaces to occur.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " is also used as an unauthorized option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". A ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object carrying ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " will loop through surface targets within the resonant component until no \
surface intersection can be found within the component. See also",
  ":",
  " ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Unconfine",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RestoreOpticaCache", "Subsection"],

Cell[TextData[{
  StyleBox["Restore",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Cache[]",
    FontWeight->"Bold"],
  " restores special ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " caches. All other deleted caches are restored automatically by using ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". Any missing cache only affects the calculation time, not the results.\n\
\[InvisibleSpace]See also: ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Clear",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Cache",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RetardationPlate", "Subsection"],

Cell[TextData[{
  StyleBox["RetardationPlate[",
    FontWeight->"Bold"],
  StyleBox["wavedifference",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a flat surface optic used to introduce anisotropic phase",
  StyleBox["-",
    FontWeight->"Bold"],
  "changes to polarized rays.\n\[InvisibleSpace]The ",
  StyleBox["wavedifference",
    FontSlant->"Italic"],
  " parameter, given in ",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  " fractions, determines the amount of phase delay between two polarization \
states. The ",
  StyleBox["axisangle",
    FontSlant->"Italic"],
  " parameter, given in Degrees, determines the direction of the first \
polarization state along the optical surface with respect to the horizontal \
axis of the local surface coordinate system. If the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is zero or is omitted, then the optic will be created without \
any ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " option can be used to weight the outgoing intensity of each outgoing ray, \
where ",
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  " can be either a number between 0 and 100, a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values, or a ",
  StyleBox["Function-",
    FontWeight->"Bold"],
  "headed expression that depends on ray ",
  StyleBox["options",
    FontSlant->"Italic"],
  " such as ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ". Otherwise, ",
  StyleBox["ModelIntensity[",
    FontWeight->"Bold"],
  StyleBox["componentmedium",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["transmissionvalue",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can be defined to hold an absorption function or a list of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmission",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " values. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PhaseRetardation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarizer",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["JonesMatrixOptic",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReverseMigration", "Subsection"],

Cell[TextData[{
  StyleBox["ReverseMigration[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that switches the sign of ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ReverseMigration",
    FontWeight->"Bold"],
  " is only valid for ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and is not recognized by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ". In this regard, ",
  StyleBox["ReverseMigration",
    FontWeight->"Bold"],
  " is now obsolete and ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " should be used instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReversionPrism", "Subsection"],

Cell[TextData[{
  StyleBox["ReversionPrism[",
    FontWeight->"Bold"],
  StyleBox["entranceheight",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a combination of two prism elements cemented together that \
reverses the image orientation without deviating the beam position.\n\
\[InvisibleSpace]",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  " is created with its entrance surface centered in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane at the global origin, its trapizoidal dimensions parallel to the \
x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane, and the exit surface centered further down about the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The middle prism surface is reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated. Similar in function to a ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  " is commonly used as an image rotator. Unlike ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  " works equally well for converging and diverging beams as well as \
collimated beams. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RhomboidPrism", "Subsection"],

Cell[TextData[{
  StyleBox["RhomboidPrism[",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RhomboidPrism[",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a six",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided prism having asymmetric trapezoidal dimensions on two sides and \
rectangular dimensions on the remaining sides.\n\[InvisibleSpace]",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  " is commonly used in laser resonators and for beam displacement \
applications. The ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " parameter gives the ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " of the two inclined entrance and exist faces. ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  " is normally aligned with its entrance face at x ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 0 and the exit face positioned along the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. However, if ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is given for the ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " parameter then the Brewster",
  StyleBox["'",
    FontWeight->"Bold"],
  "s ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " is used according to the ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DesignWaveLength",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ", and the prism is automatically tilted in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane to maintain a parallel exit beam with the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["SlabPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FresnelRhomb",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PellinBrocaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RMSFocus", "Subsection"],

Cell[TextData[{
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " that specifies that the second momentum is to be minimized",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RodBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["RodBaffle[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an entire cylindrical absorbing surface.\n\[InvisibleSpace]",
  StyleBox["RodBaffle",
    FontWeight->"Bold"],
  " is created with its center at the origin of the coordinate system. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RodLens", "Subsection"],

Cell[TextData[{
  StyleBox["RodLens[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates an entire cylindrical refractive surface.\n\
\[InvisibleSpace]With the option setting ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RodLens",
    FontWeight->"Bold"],
  " is created with its center of mass at the coordinate origin. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RodLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RodMirror", "Subsection"],

Cell[TextData[{
  StyleBox["RodMirror[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes an entire cylindrical mirror.\n\[InvisibleSpace]With the option \
setting ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RodMirror",
    FontWeight->"Bold"],
  " is created with its center of mass at the coordinate origin. With ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RodMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RoofPrism", "Subsection"],

Cell[TextData[{
  StyleBox["RoofPrism[",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " creates either a six",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided or a nine",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided roof prism that can be used to invert, revert, and deviate an image \
by 90 degrees.\n\[InvisibleSpace]With the default ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  " creates a nine",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided, Amici",
  StyleBox["-",
    FontWeight->"Bold"],
  "type, roof prism that has the excess corner material trimmed away. With ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  " creates the full",
  StyleBox["-",
    FontWeight->"Bold"],
  "sized, six",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided, roof prism. ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  " is generated with its entranceface located in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and its exit face parallel to the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane. If the ",
  StyleBox["Centered",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is specified, ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  " is centered about the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis. If the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, two reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated surfaces are placed on the roof of the prism. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReversionPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PechanPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rotate", "Subsection"],

Cell[TextData[{
  " ",
  StyleBox["Rotate[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rotationangle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axisdirection",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["axiscenter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " are used to rotate objects by a ",
  StyleBox["rotationangle",
    FontSlant->"Italic"],
  " about an axis defined by the optional quantities: ",
  StyleBox["axisdirection",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axiscenter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The primary calling pattern accepts three parameters: \
angle of rotation, axis direction vector, and axis center position. The angle \
specifies the amount of rotation. The direction and center define a line in \
space that is the axis of rotation. The center is a point on the line, while \
the direction fixes its attitude. When omitted, these parameters adopt \
default values of  ",
  StyleBox["{",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " for the direction vector and ",
  StyleBox["{",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " for the center.  This default is a vertical line through the origin.\n\
\[InvisibleSpace]In addition, ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  " has two axillary calling patterns given by ",
  StyleBox["Rotate[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Rotate[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["tiltvector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ". Here, the ",
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  " is a 3 ",
  StyleBox["x",
    FontSlant->"Italic"],
  " 3 matrix that defines a rotational transformation for the object. On the \
other hand, ",
  StyleBox["tiltvector",
    FontSlant->"Italic"],
  " is used to realign the previous optical axis of the ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " with the new direction of the ",
  StyleBox["tiltvector",
    FontSlant->"Italic"],
  " in the same fashion as the ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " function.\n\[InvisibleSpace]Tiltvector and twistangle relate to every \
object separately for ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " respectively. Otherwise all objects are rotated together. Similarly they \
are with respect to the actual position for ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", and otherwise they specify an absolute tilt and twist. The actual \
orientation is defined by the option ",
  StyleBox["Group",
    FontWeight->"Bold"],
  ". An absolute twist is measured as the projection of the first surface \
coordinate against the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis. For ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " the graphical output is not moved.\n\[InvisibleSpace]A component or \
source may be rotated additionally symbolically by specifying a list of a \
nonnumerical quantity and a number for each coordinate. Missing symbols are \
filled with the corresponding numerical specification, for example ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "0.6",
  StyleBox["}, ",
    FontWeight->"Bold"],
  "0.8",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " to rotate symbolically ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "0.6",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " and numerically ",
  StyleBox["{",
    FontWeight->"Bold"],
  "0.6",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0.8",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is also an option of ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that rotates components and rays in two dimensions about the selected \
object point.\n\[InvisibleSpace]",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the objects being rotated and the rotation value. In a \
sequence of three points, the first point selects the object getting rotated \
and also indicates the pivot. The second and third points of the sequence \
give the starting and ending moment arms of rotation. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace] Other related commands used for positioning \
components and rays include: ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RotationMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " is a rule that gives a 3 x 3 matrix of spatial rotations invoked on the \
original object coordinate system by ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " functions.\n\[InvisibleSpace]Both ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " use ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RSx", "Subsection"],

Cell[TextData[{
  StyleBox["RSx",
    FontWeight->"Bold"],
  " is a symbol that indicates the x component in local surface coordinates \
of the starting point of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RSy", "Subsection"],

Cell[TextData[{
  StyleBox["RSy",
    FontWeight->"Bold"],
  " is a symbol that specifies the y component in local surface coordinates \
of the starting point of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RSz", "Subsection"],

Cell[TextData[{
  StyleBox["RSz",
    FontWeight->"Bold"],
  " is a symbol that denotes the z component in local surface coordinates of \
the starting point of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RTx", "Subsection"],

Cell[TextData[{
  StyleBox["RTx",
    FontWeight->"Bold"],
  " is a symbol that designates the x component in local surface coordinates \
of the tilt of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RTy", "Subsection"],

Cell[TextData[{
  StyleBox["RTy",
    FontWeight->"Bold"],
  " is a symbol that indicates the y component in local surface coordinates \
of the tilt of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RTz", "Subsection"],

Cell[TextData[{
  StyleBox["RTz",
    FontWeight->"Bold"],
  " is a symbol that specifies the z component in local surface coordinates \
of the tilt of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RunningCommentary", "Subsection"],

Cell[TextData[{
  StyleBox["RunningCommentary",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", and other ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions that controls reporting of the calculation process. ",
  StyleBox["RunningCommentary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " results in a printed report of the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculation process.\n\[InvisibleSpace]Depending on the invoked \
function, other settings for ",
  StyleBox["RunningCommentary",
    FontWeight->"Bold"],
  " can be: ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllDeflections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["All",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Simplify",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Expand",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SagFit", "Subsection"],

Cell[TextData[{
  StyleBox["SagFit->True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " that varies the groove spacing along the ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " surface to maintain a constant groove depth.\n\[InvisibleSpace]In this \
case, the groove spacing is dependent on the surface curvature and the groove \
depth is specified by the user. ",
  StyleBox["SagFit->False",
    FontWeight->"Bold"],
  " employs a constant",
  StyleBox["-",
    FontWeight->"Bold"],
  "spaced groove pattern and the groove spacing is specified instead. See \
also",
  ":",
  " ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SampleFactor", "Subsection"],

Cell[TextData[{
  StyleBox["SampleFactor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " specifies the ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of sample points to be used relative to the original ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of data points",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sapphire", "Subsection"],

Cell[TextData[{
  StyleBox["Sapphire",
    FontWeight->"Bold"],
  " indicates the use of a sapphire crystal medium.\n\[InvisibleSpace]The \
refractive index model for ",
  StyleBox["Sapphire",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .27 microns to .82 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scale", "Subsection"],

Cell[TextData[{
  StyleBox["Scale",
    FontWeight->"Bold"],
  " is a label inside ",
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScatterProperties", "Subsection"],

Cell[TextData[{
  StyleBox["ScatterProperties",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " that indicates a list of ray properties that are to be affected by the \
seed rays of ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Allowed entries are ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayStart",
    FontWeight->"Bold"],
  ". The new rays inherit the intensity and tilt distribution of the seed \
rays. The wavelength and the polarization are set to the value of the seed \
ray. The ray seed`s y and z starting positions define the surface coordinates \
of newly created rays",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScatterRays", "Subsection"],

Cell[TextData[{
  StyleBox["ScatterRays[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["seedrays",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that creates a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function to generate diffused rays at an optical surface by using \
the seed ray distribution pattern given in ",
  StyleBox["seedrays",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["seedrays",
    FontSlant->"Italic"],
  " parameter takes a light source function. An example of such a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source function is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " weights the scattered ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values.\n\[InvisibleSpace]The ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " option is also used by ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ". For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. See \
also",
  ":",
  " ",
  StyleBox["Lambertian",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LimitScatter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SchmidtLens", "Subsection"],

Cell[TextData[{
  StyleBox["SchmidtLens[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fnumber",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced lens that has a shaped reflective side and a planar refractive \
side.\n\[InvisibleSpace]",
  StyleBox["SchmidtLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. (Contributed by William Cottingame, \
UCLA.) See also: ",
  StyleBox["SchmidtLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SchmidtLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["SchmidtLensSurface[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fnumber",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens component that has a given shape that models the \
refractive index boundary at a Schmidt surface.\n\[InvisibleSpace]",
  StyleBox["SchmidtLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["SchmidtLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. (Contributed by William Cottingame, \
UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics. See also: ",
  StyleBox["SchmidtLens",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScoutRays", "Subsection"],

Cell[TextData[{
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that specifies the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects to get used for seeding the scout ray trace.\n\[InvisibleSpace]",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses single",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray versions of the input light sources to conduct the scout trace such \
that, in general, ",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " generates as many scout rays as there are independent light sources \
present.  See also ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScoutTrace", "Subsection"],

Cell[TextData[{
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that specifies whether a preliminary \"scout\" ray trace with a small \
number of rays is used to determine the optical surfaces in the high",
  StyleBox["-",
    FontWeight->"Bold"],
  "speed ray trace.\n\[InvisibleSpace]",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " is closely linked with the ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " option as well as the ",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " option. In general, ",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " also forces the ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " setting. In its default setting, ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " is internally set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  " when ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is present and set to ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " setting. ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " prevents a scout trace from occurring. However, the manual setting of ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " can produce either a sequential trace (when accompanied by ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ") or a non",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequential trace (when ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is present",
  ")",
  ". Note that the manual setting of ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " together with ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is disallowed. See also: ",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScratchDig", "Subsection"],

Cell[TextData[{
  StyleBox["ScratchDig",
    FontWeight->"Bold"],
  " is a database rule name that specifies the scratch",
  StyleBox["/",
    FontWeight->"Bold"],
  "dig value for a lens",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Screen", "Subsection"],

Cell[TextData[{
  StyleBox["Screen[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a planar component that intersects rays without disturbing \
them.\n\[InvisibleSpace]Although ",
  StyleBox["Screen",
    FontWeight->"Bold"],
  " is usually not rendered, the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "screen intersections can be rendered by using the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["PlotType->Surface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Screen",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScreenPosition", "Subsection"],

Cell[TextData[{
  StyleBox["ScreenPosition",
    FontWeight->"Bold"],
  " labels the parametric surface coordinates for the center of the locus of \
ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersections.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScreenSizeFactor", "Subsection"],

Cell[TextData[{
  StyleBox["ScreenSizeFactor",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " that specifies the magnification factor of the spot to yield the ",
  StyleBox["screen",
    FontSlant->"Italic"],
  " dimension. For a value being nonzero, a rule ",
  StyleBox["Screen",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["screen",
    FontSlant->"Italic"],
  " is returned in the result of the functions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SCx", "Subsection"],

Cell[TextData[{
  StyleBox["SCx",
    FontWeight->"Bold"],
  " is a symbol that denotes the first of the parametric surface coordinates \
of the ray starting point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SCy", "Subsection"],

Cell[TextData[{
  StyleBox["SCy",
    FontWeight->"Bold"],
  " is a symbol that designates the second of the parametric surface \
coordinates of the ray starting point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SCz", "Subsection"],

Cell[TextData[{
  StyleBox["SCz",
    FontWeight->"Bold"],
  " is a symbol that indicates the distance to the surface of the ray \
starting point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SellmeierFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SellmeierFunction[",
    FontWeight->"Bold"],
  StyleBox["a0",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["a2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["b0",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["b1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["b2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes six terms and creates the pure function ",
  StyleBox["Function[Sqrt[",
    FontWeight->"Bold"],
  "1",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a0",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["b0",
    FontSlant->"Italic"],
  ")",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a1",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["b1",
    FontSlant->"Italic"],
  ")",
  StyleBox[" + ",
    FontWeight->"Bold"],
  StyleBox["a2",
    FontSlant->"Italic"],
  StyleBox["*WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["WaveLength^",
    FontWeight->"Bold"],
  "2",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["b2",
    FontSlant->"Italic"],
  ")",
  StyleBox["]/",
    FontWeight->"Bold"],
  ".",
  StyleBox["#]",
    FontWeight->"Bold"],
  " used to model the index of refraction versus wavelength for various \
materials.\n\[InvisibleSpace]",
  StyleBox["SellmeierFunction[{",
    FontWeight->"Bold"],
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "..",
  StyleBox["}]",
    FontWeight->"Bold"],
  " allows for an arbitrary number of ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " terms. ",
  StyleBox["SellmeierFunction[",
    FontWeight->"Bold"],
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "..",
  StyleBox["}]",
    FontWeight->"Bold"],
  " allows the constant term, ",
  StyleBox["c",
    FontSlant->"Italic"],
  ", to be something other than 1. ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  " is used together with ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  " to designate ",
  StyleBox["a",
    FontSlant->"Italic"],
  " new material model. ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  " is also used by ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "to model Optica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s external database of glasses and optical materials. See also: ",
  StyleBox["ModelRefractiveIndex",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexInterpolationFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DataToOptica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SequentialRead", "Subsection"],

Cell[TextData[{
  StyleBox["SequentialRead",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False/Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " that specifies whether the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced information for each optical surface should be read out in \
sequential fashion according to the ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  " or should be grouped according to ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SequentialRead",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " groups the information according to both ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SequentialRead",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " ranks the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced information for each optical surface into a single result by ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SequentialRead",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " and ",
  StyleBox["False",
    FontWeight->"Bold"],
  " with ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["CosineCompensation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SequentialTrace", "Subsection"],

Cell[TextData[{
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that selects between sequential and non",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequential ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace methods.\n\[InvisibleSpace]",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " is closely linked with the ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to perform a sequential ray trace (except with ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ".",
  ")",
  " ",
  StyleBox["In",
    FontWeight->"Bold"],
  " this setting, a small number of scout rays are first internally traced \
with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " to provide the order and type of optical surfaces. Then, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " uses a high",
  StyleBox["-",
    FontWeight->"Bold"],
  "speed, compiled ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace function, given by ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", to sequentially trace the complete group of input rays.\n\
\[InvisibleSpace]",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " still traces sequentially between distinct component",
  StyleBox["-",
    FontWeight->"Bold"],
  "groupings of surfaces but traces non",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequentially within those components that have the ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " attribute. In this case, however, two different methods may be used by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to acquire the optical surface information. For ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False/Automatic",
    FontWeight->"Bold"],
  ", all optical surfaces of the input optical system are included in the \
trace and no scout trace is performed. Otherwise, ",
  StyleBox["ScoutTrace->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", causes a scout trace is first used to obtain the optical surface \
information and any occurring duplicate surfaces are consolidated before the \
compiled, nonsequential trace takes place. Note that the combining ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " with ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is not permitted. In addition, ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is not permitted during the use of ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SetOpticaPrecision", "Subsection"],

Cell[TextData[{
  StyleBox["Set",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Precision[",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " sets ",
  StyleBox["number",
    FontSlant->"Italic"],
  " digits of precision for calculations of some functions.\n\
\[InvisibleSpace]It also reevaluates some internal symbols. See also: ",
  StyleBox["SetPackagePrecision",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SF11", "Subsection"],

Cell[TextData[{
  StyleBox["SF11",
    FontWeight->"Bold"],
  " designates the use of the ",
  StyleBox["SF11",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["SF11",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SF5", "Subsection"],

Cell[TextData[{
  StyleBox["SF5",
    FontWeight->"Bold"],
  " designates the use of the ",
  StyleBox["SF5",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["SF5",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShadowProject", "Subsection"],

Cell[TextData[{
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " that gives a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional rendering of the optical system along with two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional projections of the system onto the sides of a box.\n\
\[InvisibleSpace]See ",
  StyleBox["Shadow",
    FontWeight->"Bold"],
  " in the standard Mathematica packages. See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowArrows", "Subsection"],

Cell[TextData[{
  StyleBox["ShowArrows",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that sets the maximum ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of ray segments to be rendered as an arrow. ",
  StyleBox["ShowArrows",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " switches between arrow and simple line rendering of rays.  See also",
  ":",
  " ",
  StyleBox["Arrow",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Options[Arrow]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowClones", "Subsection"],

Cell[TextData[{
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that denotes whether the phantom clones of optical \
components are rendered. See also",
  ":",
  " ",
  StyleBox["CreateClones",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CloneSortLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowComponentOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that generates lines to show the orientation of all displayed components. \
The orientation is given by the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the component. ",
  StyleBox["Components",
    FontWeight->"Bold"],
  " orientations to be shown can be specified with the option ",
  StyleBox["ComponentSelectComponentOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SizeComponentOrientation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbsoluteSizeComponentOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowComponents", "Subsection"],

Cell[TextData[{
  StyleBox["ShowComponents",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that indicates whether optical components are rendered. See \
also",
  ":",
  " ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowArrows",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowEllipse", "Subsection"],

Cell[TextData[{
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  " is a PlugIn of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  " that describes the information to be added to the plot. Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The value is a list structure, where each sublist, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", gives a separate information to be shown. All elements of the sublists, \
but the first, are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The 1st element is a formula with names of rules of the values to be \
shown, for example ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ". If a part is to be accessed, it must be wrapped with ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Hold[Polarization[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]]*Intensity",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". If all optional arguments are omitted, the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " needs not to be wrapped with a list.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The value of the desired rule is multiplied by the ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " and converted to an object of ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". Scalingfactor and ",
  StyleBox["size",
    FontSlant->"Italic"],
  " can have the same number of dimensions as value, a ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " suppresses this dimension of value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If a threefold list is given, each list belongs to the corresponding \
element in the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " list. In the case of a twofold or a simple list or a simple formula, all \
information is shown at the first labelposition. If two",
  StyleBox["-",
    FontWeight->"Bold"],
  " and threefold lists are mixed, each second level element appears in its \
own labelposition.\n\[InvisibleSpace]One ellipse for each innermost list is \
added to the plot at the position chosen by the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " rule. The ellipse is constructed from a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector. The first two dimensions yield the major and minor \
axis, the third one is a measure for the ellipticity. The orientation of the \
matrix is given by the last two elements of the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the object. The plane of the ellipse is perpendicular to the first \
element of the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the object. For example ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " shows the polarization state of the rays. The amount of information to be \
shown can be diminished by giving a ",
  StyleBox["ShowEllipseSelection",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ShowEllipseSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowEllipseSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ShowEllipseSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["bounds",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule that selects information to be shown. The value is a list of \
rules. Each rule gives the ",
  StyleBox["bounds",
    FontSlant->"Italic"],
  " in which the value to be shown must be. If the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " does not match any ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " of the object, no restrictions on the information to be shown take \
place.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A single value specifies a fixed value, a list with one element a minimum, \
and a list with two value gives a range of allowed values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Each value can be a single value or a sequence of values with ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Selection[",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "6",
  StyleBox["]",
    FontWeight->"Bold"],
  ". In the latter case, a value is only shown, if it matches one of the \
given values in ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The restrictions apply only up to the length of min and max given. For \
example ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization -> {{",
    FontWeight->"Bold"],
  "0.1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.2",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[",",
    FontWeight->"Bold"],
  "1.",
  StyleBox[",",
    FontWeight->"Bold"],
  "25.",
  StyleBox["}}}",
    FontWeight->"Bold"],
  " leads to a selection of rays with a horizontal polarization between 0.1 \
and 0.2, a vertical between 0.2 and 1., and a phaseangle of less than 25. \
degrees.\n\[InvisibleSpace]The rule can be given as option for ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  ". Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".See also: ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowEngine", "Subsection"],

Cell[TextData[{
  StyleBox["ShowEngine",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["PlugIns",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that specifies plugins of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". For each list element there must be a function definition, which takes \
as parameters the optical system ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rays",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["components",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["showrange",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", the plot type, the graphical output produced by and the options passed \
to ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". The function itself returns a list with the new graphical output and the \
new plot type. To inform ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " about this file, the ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " ",
  StyleBox["ShowEngine",
    FontWeight->"Bold"],
  " of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " has to be modified. After reloading ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " with ",
  StyleBox["Needs",
    FontWeight->"Bold"],
  ", the new behavior of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " is implemented. Normally a PlugIn adds new graphical information to the \
existing output and it does not change the plot type. See also: ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowLabels", "Subsection"],

Cell[TextData[{
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that automatically generates label captions for each rendered ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " switches off for three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional presentations. ",
  StyleBox["ShowLabels->True",
    FontWeight->"Bold"],
  " also includes labels for three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensions. See also",
  ":",
  " ",
  StyleBox["MoveLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddLabels",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenameLabels",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowRange", "Subsection"],

Cell[TextData[{
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["values",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["DrawSystem/AnalyzeSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that uses ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["values",
    FontSlant->"Italic"],
  " to select the components and ray segments displayed by ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  " can take either the value ",
  StyleBox["All",
    FontWeight->"Bold"],
  " or a list of the ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["values",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowRayOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that generates lines to show the orientation of all rays selected by the \
option ",
  StyleBox["RaySelectRayOrientation",
    FontWeight->"Bold"],
  ". The value of this option is directly passed to ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ". The orientation is given by the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the ray and represented by red, green, and blue. Line lengths are \
controlled by ",
  StyleBox["SizeRayOrientation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AbsoluteSizeRayOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowRays", "Subsection"],

Cell[TextData[{
  StyleBox["ShowRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option that determines whether rays are rendered. See also",
  ":",
  " ",
  StyleBox["ShowLabels",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowComponents",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowArrows",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ShowClones",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSelectedPoints", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSelectedPoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that generates lines and points to show the selected movements inside the \
scripted moves.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Black",
    FontWeight->"Bold"],
  " points show the coordinates passed with the scripted moves function. ",
  StyleBox["Red",
    FontWeight->"Bold"],
  " points demonstrate the points actually used for the movement and are \
connected with a thin gray line, if an object is translated. ",
  StyleBox["Black",
    FontWeight->"Bold"],
  " and red points may differ, if a point signifies an object or a point is \
snapped to a grid.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A green line shows, where an object is rotated to, a blue line gives the \
initial orientation for the rotation. If both lines are present, they do not \
coincide with the object orientation. The direction of the rotation \
demonstrates a thin arrow. Movements of objects from the second on are shown \
with thin black lines.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Optical axes, used for example by ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", are drawn as black lines.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["ConnectSelectedPoints",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSnapGrid", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that generates lines to show the grid used by move commands based on \
mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated coordinate points. The star displays the angle grid, the big dot \
marks the x, the small one the y grid direction. If it is not on a line, the \
origin of this grid direction is outside the plot range.\n\[InvisibleSpace]",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  " reduces the number of shown lines in each coordinate direction the number \
of lines specified in ",
  StyleBox["ShowSnapGridLines",
    FontWeight->"Bold"],
  ". Therefore, not all lines might be shown for dense grids. Try to modify \
",
  StyleBox["ShowSnapGridStyle",
    FontWeight->"Bold"],
  ", if the grid lines are not rendered correctly. See also",
  ":",
  " ",
  StyleBox["ShowSnapGridLines",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSnapGridStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSnapGridPrepend",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSnapGridLines", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSnapGridLines",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  " that specifies the ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of grid lines to be shown. Number can be a single integer or a list of up \
to four integers in the range 0 to 100. For rotated grids, the ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of actually shown lines might differ slightly from the ",
  StyleBox["number",
    FontSlant->"Italic"],
  " specified. See also",
  ":",
  " ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSnapGridPrepend", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSnapGridPrepend",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["prepend",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  " that specifies the rendering order of grid lines to be shown. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the grid is rendered before components and rays. The effect is that the \
snap grid is behind them. False causes the lines to be above components and \
rays. Rays that are at the same position as a grid line, cannot be seen. See \
also",
  ":",
  " ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSnapGridStyle", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSnapGridStyle",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{AbsoluteThickness -> ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", RGBColor -> ",
    FontWeight->"Bold"],
  StyleBox["color",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  " that specifies the style of the grid lines to be shown. Thickness can be \
a single number or a list of up to three numbers, ",
  StyleBox["color",
    FontSlant->"Italic"],
  " can be a a list of three numbers or a list of up to three number lists. \
The values are passed to ",
  StyleBox["AbsoluteThickness",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RGBColor",
    FontWeight->"Bold"],
  " to render the x, y, and angle grid. The symbol ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " and ",
  StyleBox["color",
    FontSlant->"Italic"],
  " suppresses the corresponding ",
  "graphics",
  " primitives. See also: ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSnapGrid",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfaceEllipse", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  " is a PlugIn of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  " that describes the information to be added to the plot. Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The value is a list structure, where each sublist, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", gives a separate information to be shown. All elements of the sublists, \
but the first, are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The 1st element is a formula with names of rules of the values to be \
shown, for example ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ". If a part is to be accessed, it must be wrapped with ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Hold[Polarization[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]]*Intensity",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". If all optional arguments are omitted, the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " needs not to be wrapped with a list.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The value of the desired rule is multiplied by the ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " and converted to an object of ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". Scalingfactor and ",
  StyleBox["size",
    FontSlant->"Italic"],
  " can have the same number of dimensions as value, a ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " suppresses this dimension of value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If a threefold list is given, each list belongs to the corresponding \
element in the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " list. In the case of a twofold or a simple list or a simple formula, all \
information is shown at the first labelposition. If two",
  StyleBox["-",
    FontWeight->"Bold"],
  " and threefold lists are mixed, each second level element appears in its \
own labelposition.\n\[InvisibleSpace]One ellipse for each innermost list is \
added to the plot at the position chosen by the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " rule. The ellipse is constructed from a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector. The first two dimensions yield the major and minor \
axis, the third one is a measure for the ellipticity. The orientation of the \
matrix is given by the last two elements of the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the object. The plane of the ellipse is tilted, so that it is normal \
to the SurfaceNormal of the surface related to the object, rotated in its \
proper direction with the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the surface. For example ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " shows the polarization state of the rays. The amount of information to be \
shown can be diminished by giving a ",
  StyleBox["ShowSurfaceEllipseSelection",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ShowSurfaceEllipseSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfaceEllipseSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfaceEllipseSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["bounds",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule that selects information to be shown. The value is a list of \
rules. Each rule gives the ",
  StyleBox["bounds",
    FontSlant->"Italic"],
  " in which the value to be shown must be. If the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " does not match any ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " of the object, no restrictions on the information to be shown take \
place.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A single value specifies a fixed value, a list with one element a minimum, \
and a list with two value gives a range of allowed values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Each value can be a single value or a sequence of values with ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Selection[",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "6",
  StyleBox["]",
    FontWeight->"Bold"],
  ". In the latter case, a value is only shown, if it matches one of the \
given values in ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The restrictions apply only up to the length of min and max given. For \
example ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization -> {{",
    FontWeight->"Bold"],
  "0.1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.2",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[",",
    FontWeight->"Bold"],
  "1.",
  StyleBox[",",
    FontWeight->"Bold"],
  "25.",
  StyleBox["}}}",
    FontWeight->"Bold"],
  " leads to a selection of rays with a horizontal polarization between 0.1 \
and 0.2, a vertical between 0.2 and 1., and a phaseangle of less than 25. \
degrees.\n\[InvisibleSpace]The rule can be given as option for ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  ". Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".See also: ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfaceOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is a PlugIn for ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " that generates lines to show the orientation of all displayed surfaces. \
The orientation is given by the ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " of the ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  " orientations to be shown can be specified with the options ",
  StyleBox["SurfaceSelectSurfaceOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SizeSurfaceOrientation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbsoluteSizeSurfaceOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfacePlot", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  " is a PlugIn of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order) that describes the information to be \
added to the plot. Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The value is a list structure, where each sublist, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", gives a separate information to be shown. All elements of the sublists, \
but the first, are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The 1st element is a formula with names of rules of the values to be \
shown, for example ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ". If a part is to be accessed, it must be wrapped with ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Hold[Polarization[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]]*Intensity",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". If all optional arguments are omitted, the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " needs not to be wrapped with a list.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The value of the desired rule is multiplied by the ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " and converted to an object of ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". Scalingfactor and ",
  StyleBox["size",
    FontSlant->"Italic"],
  " can have the same number of dimensions as value, a ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " suppresses this dimension of value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If a threefold list is given, each list belongs to the corresponding \
element in the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " list. In the case of a twofold or a simple list or a simple formula, all \
information is shown at the first labelposition. If two",
  StyleBox["-",
    FontWeight->"Bold"],
  " and threefold lists are mixed, each second level element appears in its \
own labelposition.\n\[InvisibleSpace]One surface plot for each innermost list \
is plotted. These ",
  "graphics",
  " replace the rendered optical system. The x and y coordinates are that of \
the surface related to the object, the third coordinate is the value \
retrieved from ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  ". The amount of information to be shown can be diminished by giving a ",
  StyleBox["ShowSurfacePlotSelection",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ShowSurfacePlotSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlotSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DensityValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DistributeValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Coherent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfacePlotSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfacePlotSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["bounds",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule that selects information to be shown. The value is a list of \
rules. Each rule gives the ",
  StyleBox["bounds",
    FontSlant->"Italic"],
  " in which the value to be shown must be. If the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " does not match any ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " of the object, no restrictions on the information to be shown take \
place.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A single value specifies a fixed value, a list with one element a minimum, \
and a list with two value gives a range of allowed values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Each value can be a single value or a sequence of values with ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Selection[",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "6",
  StyleBox["]",
    FontWeight->"Bold"],
  ". In the latter case, a value is only shown, if it matches one of the \
given values in ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The restrictions apply only up to the length of min and max given. For \
example ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization -> {{",
    FontWeight->"Bold"],
  "0.1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.2",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[",",
    FontWeight->"Bold"],
  "1.",
  StyleBox[",",
    FontWeight->"Bold"],
  "25.",
  StyleBox["}}}",
    FontWeight->"Bold"],
  " leads to a selection of rays with a horizontal polarization between 0.1 \
and 0.2, a vertical between 0.2 and 1., and a phaseangle of less than 25. \
degrees.\n\[InvisibleSpace]The rule can be given as option for ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  ". Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".See also: ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSurfacePlotSurface", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSurfacePlotSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  " that specifies a coloring scheme for the surface generated by ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["value",
    FontSlant->"Italic"],
  " has the same specification as in ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ".See also",
  ":",
  " ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem", "Subsection"],

Cell[TextData[{
  StyleBox["ShowSystem[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements defined by a mixed list of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["OpticalSystem",
    FontWeight->"Bold"],
  " objects and renders them according to ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]If a ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  " head is present, then ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " presents the graphics according to the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". If a ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  " head is not present in the input, then ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["RenderSystem",
    FontWeight->"Bold"],
  " first. ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " renders the rays selected from the ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " option determines whether ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " displays the rendered ",
  "graphics",
  " three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensionally, with two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional projections, or as surface projections with points that \
specify where selected rays intersect with the surface.\n\[InvisibleSpace]See \
also: ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRange",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ColorView",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowText", "Subsection"],

Cell[TextData[{
  StyleBox["ShowText",
    FontWeight->"Bold"],
  " is a PlugIn of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  " that describes the information to be added to the plot. Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The value is a list structure, where each sublist, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", gives a separate information to be shown. All elements of the sublists, \
but the first, are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The 1st element is a formula with names of rules of the values to be \
shown, for example ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ". If a part is to be accessed, it must be wrapped with ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Hold[Polarization[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]]*Intensity",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". If all optional arguments are omitted, the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " needs not to be wrapped with a list.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The value of the desired rule is multiplied by the ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " and converted to an object of ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". Scalingfactor and ",
  StyleBox["size",
    FontSlant->"Italic"],
  " can have the same number of dimensions as value, a ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " suppresses this dimension of value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If a threefold list is given, each list belongs to the corresponding \
element in the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " list. In the case of a twofold or a simple list or a simple formula, all \
information is shown at the first labelposition. If two",
  StyleBox["-",
    FontWeight->"Bold"],
  " and threefold lists are mixed, each second level element appears in its \
own labelposition.\n\[InvisibleSpace]One line of text for each innermost list \
is added to the label, with the same font as the label. The text may be \
formatted with a ",
  StyleBox["StyleForm",
    FontWeight->"Bold"],
  " wrapper. The ",
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  " and the ",
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  " are put in front of and behind the value to be shown. The text is shown \
at the position chosen by the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " rule. The amount of information to be shown can be diminished by giving a \
",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowTextSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["bounds",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule that selects information to be shown. The value is a list of \
rules. Each rule gives the ",
  StyleBox["bounds",
    FontSlant->"Italic"],
  " in which the value to be shown must be. If the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " does not match any ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " of the object, no restrictions on the information to be shown take \
place.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A single value specifies a fixed value, a list with one element a minimum, \
and a list with two value gives a range of allowed values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Each value can be a single value or a sequence of values with ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Selection[",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "6",
  StyleBox["]",
    FontWeight->"Bold"],
  ". In the latter case, a value is only shown, if it matches one of the \
given values in ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The restrictions apply only up to the length of min and max given. For \
example ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization -> {{",
    FontWeight->"Bold"],
  "0.1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.2",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[",",
    FontWeight->"Bold"],
  "1.",
  StyleBox[",",
    FontWeight->"Bold"],
  "25.",
  StyleBox["}}}",
    FontWeight->"Bold"],
  " leads to a selection of rays with a horizontal polarization between 0.1 \
and 0.2, a vertical between 0.2 and 1., and a phaseangle of less than 25. \
degrees.\n\[InvisibleSpace]The rule can be given as option for ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  ". Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".See also: ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowValue", "Subsection"],

Cell[TextData[{
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " is a PlugIn of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " and an ",
  StyleBox["Option",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order) that describes the information to be \
added to the plot. Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The value is a list structure, where each sublist, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["prefixstring",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["postfixstring",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", gives a separate information to be shown. All elements of the sublists, \
but the first, are optional.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The 1st element is a formula with names of rules of the values to be \
shown, for example ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  ". If a part is to be accessed, it must be wrapped with ",
  StyleBox["Hold",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Hold[Polarization[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]]*Intensity",
    FontWeight->"Bold"],
  " for a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ". If all optional arguments are omitted, the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " needs not to be wrapped with a list.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The value of the desired rule is multiplied by the ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " and converted to an object of ",
  StyleBox["size",
    FontSlant->"Italic"],
  ". Scalingfactor and ",
  StyleBox["size",
    FontSlant->"Italic"],
  " can have the same number of dimensions as value, a ",
  StyleBox["False",
    FontWeight->"Bold"],
  " inside ",
  StyleBox["scalingfactor",
    FontSlant->"Italic"],
  " suppresses this dimension of value.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If a threefold list is given, each list belongs to the corresponding \
element in the ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  " list. In the case of a twofold or a simple list or a simple formula, all \
information is shown at the first labelposition. If two",
  StyleBox["-",
    FontWeight->"Bold"],
  " and threefold lists are mixed, each second level element appears in its \
own labelposition.\n\[InvisibleSpace]One surface plot for each innermost list \
is plotted. The x and y coordinates are that of the surface related to the \
object, the third coordinate is the value retrieved from ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  ". The ",
  "graphics",
  " are drawn on the surface. The amount of information to be shown can be \
diminished by giving a ",
  StyleBox["ShowValueSelection",
    FontWeight->"Bold"],
  " rule.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ShowValueSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValueSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DensityValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DistributeValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Coherent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayLabelPositions",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowText",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowEllipse",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowValueSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ShowValueSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["rulename",
    FontSlant->"Italic"],
  StyleBox[" -> ",
    FontWeight->"Bold"],
  StyleBox["bounds",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule that selects information to be shown. The value is a list of \
rules. Each rule gives the ",
  StyleBox["bounds",
    FontSlant->"Italic"],
  " in which the value to be shown must be. If the ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " does not match any ",
  StyleBox["rulename",
    FontSlant->"Italic"],
  " of the object, no restrictions on the information to be shown take \
place.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "A single value specifies a fixed value, a list with one element a minimum, \
and a list with two value gives a range of allowed values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Each value can be a single value or a sequence of values with ",
  StyleBox["Head",
    FontWeight->"Bold"],
  " ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", for example ",
  StyleBox["Selection[",
    FontWeight->"Bold"],
  "2",
  StyleBox[",",
    FontWeight->"Bold"],
  "6",
  StyleBox["]",
    FontWeight->"Bold"],
  ". In the latter case, a value is only shown, if it matches one of the \
given values in ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The restrictions apply only up to the length of min and max given. For \
example ",
  StyleBox["ShowTextSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Polarization -> {{",
    FontWeight->"Bold"],
  "0.1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0.2",
  StyleBox["},{",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[",",
    FontWeight->"Bold"],
  "1.",
  StyleBox[",",
    FontWeight->"Bold"],
  "25.",
  StyleBox["}}}",
    FontWeight->"Bold"],
  " leads to a selection of rays with a horizontal polarization between 0.1 \
and 0.2, a vertical between 0.2 and 1., and a phaseangle of less than 25. \
degrees.\n\[InvisibleSpace]The rule can be given as option for ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " (the rule is applied in this order",
  ")",
  ". Options of ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  " are additional to options directly given in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".See also: ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowValueSurface", "Subsection"],

Cell[TextData[{
  StyleBox["ShowValueSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["value",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " that specifies a coloring scheme for the surface generated by ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["value",
    FontSlant->"Italic"],
  " has the same specification as in ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ".See also",
  ":",
  " ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SideOfObject", "Subsection"],

Cell[TextData[{
  StyleBox["SideOfObject",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  " that denotes the direction of the axis point from the object.\n\
\[InvisibleSpace]If ",
  StyleBox["Before",
    FontWeight->"Bold"],
  " is used, then the object is oriented such that the point position is up \
stream from the object. If ",
  StyleBox["After",
    FontWeight->"Bold"],
  " is used, then the object is oriented such that the point position is down \
stream from the object",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SideView", "Subsection"],

Cell[TextData[{
  StyleBox["SideView",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " that gives a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional orthoscopic rendering showing a projection onto the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane of the optical system.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Silicon", "Subsection"],

Cell[TextData[{
  StyleBox["Silicon",
    FontWeight->"Bold"],
  " designates the use of a silicon crystal medium.\n\[InvisibleSpace]The \
refractive index model for ",
  StyleBox["Silicon",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of 1.25 microns to 2.0 \
microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimpleSurface", "Subsection"],

Cell[TextData[{
  StyleBox["SimpleSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " that forces a surface of the same shape as the surrounding surfaces.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If these are not of the same type or the values of ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " are 0 or 1, ",
  StyleBox["SimpleSurface",
    FontWeight->"Bold"],
  " has no effect. The surface is matched to the numbers given in the ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  " option only at a few points. This allows a simpler description of the \
surface. If the surface must be placed for every point exactly at the \
fraction given in ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SimpleSurface",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " must be used. See also",
  ":",
  " ",
  StyleBox["AddSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SingleRay", "Subsection"],

Cell[TextData[{
  StyleBox["SingleRay[",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a light source that creates a single ray directed down the positive x \
axis.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " is really designed for applications that require a single ray to be \
traced. In previous versions of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", the ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " function did not exist and the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object was directly assigned by the user to define new types of light \
source distributions. Presently, however, ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects are only used with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " calculations and ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " instead uses the ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object, which can hold the ray information much more efficiently. As \
such, it is no longer recommended to directly specify ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. Instead, one should utilize ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  " when a single ray is to be traced and ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  " when a greater quantity of user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified rays are required.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SizeComponentOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["SizeComponentOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  ", that determines the length of lines with respect to size of the \
component. ",
  StyleBox["SizeComponentOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeComponentOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowComponentOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SizeRayOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["SizeRayOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  " that determines the length of lines with respect to ray length. ",
  StyleBox["SizeRayOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeRayOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowRayOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SizeSurfaceOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["SizeSurfaceOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  " that determines the length of lines with respect to size of the \
component. ",
  StyleBox["SizeSurfaceOrientation",
    FontWeight->"Bold"],
  " is suppressed by ",
  StyleBox["AbsoluteSizeSurfaceOrientation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SK11", "Subsection"],

Cell[TextData[{
  StyleBox["SK11",
    FontWeight->"Bold"],
  " indicates the use of the ",
  StyleBox["SK11",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]The refractive index model for ",
  StyleBox["SK11",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .35 microns to 2.3 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sketch", "Subsection"],

Cell[TextData[{
  StyleBox["Sketch",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SlabPrism", "Subsection"],

Cell[TextData[{
  StyleBox["SlabPrism[",
    FontWeight->"Bold"],
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a rectangular refractive box.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Here, the user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression. There are four methods for specifying ",
  StyleBox["boundaryparameters",
    FontSlant->"Italic"],
  ": ",
  StyleBox["SlabPrism[{",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["x2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["z2",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " uses the coordinates of top and bottom opposite corners of a rectangular \
box, ",
  StyleBox["SlabPrism[",
    FontWeight->"Bold"],
  StyleBox["side",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a cube boundary, ",
  StyleBox["SlabPrism[",
    FontWeight->"Bold"],
  StyleBox["xside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["zside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a ",
  StyleBox["length",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["xside",
    FontSlant->"Italic"],
  ", a ",
  StyleBox["width",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["yside",
    FontSlant->"Italic"],
  ", and a ",
  StyleBox["height",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["zside",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["SlabPrism[",
    FontWeight->"Bold"],
  StyleBox["aside",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["bside",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " assumes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional box that has a ",
  StyleBox["length",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["aside",
    FontSlant->"Italic"],
  ", a ",
  StyleBox["width",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ", and a ",
  StyleBox["height",
    FontSlant->"Italic"],
  " specified by ",
  StyleBox["bside",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SlabPrism[",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["width",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["height",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " specifies angular tilts for the two facets that cross the optical (x) \
axis."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SlopeH", "Subsection"],

Cell[TextData[{
  StyleBox["SlopeH",
    FontWeight->"Bold"],
  " is a symbol that denotes the slope of a paraxial ray projected onto the \
horizontal (x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y",
  ")",
  " plane of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional paraxial coordinate system.\n\[InvisibleSpace]",
  StyleBox["SlopeH",
    FontWeight->"Bold"],
  " is designed to be used exclusively by light sources in paraxial ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations. See also: ",
  StyleBox["PosH",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PosV",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SlopeV",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SlopeV", "Subsection"],

Cell[TextData[{
  StyleBox["SlopeV",
    FontWeight->"Bold"],
  " is a symbol that designates the slope of a paraxial ray projected onto \
the vertical (x",
  StyleBox["-",
    FontWeight->"Bold"],
  "z",
  ")",
  " plane of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional paraxial coordinate system.\n\[InvisibleSpace]",
  StyleBox["SlopeV",
    FontWeight->"Bold"],
  " is designed to be used exclusively by light sources in paraxial ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace calculations. See also: ",
  StyleBox["PosH",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PosV",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SlopeH",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmoothFresnel", "Subsection"],

Cell[TextData[{
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " that specifies that the \"rounding\" of sharp groove edges due to the \
manufacturing process is modelled.\n\[InvisibleSpace]This setting also \
enables the vertical facets to be modeled. For ",
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the grooves have perfect sharpness but the straight vertical facets are \
not modeled. This setting enables the fastest ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace speeds. See also",
  ":",
  " ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SmoothKernelRange",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmoothKernelRange", "Subsection"],

Cell[TextData[{
  StyleBox["SmoothKernelRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["factor",
    FontSlant->"Italic"],
  " is an option of some functions that specifies a multiplicative ",
  StyleBox["factor",
    FontSlant->"Italic"],
  " of the ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " over which the Gaussian smoothing convolution takes place.\n\
\[InvisibleSpace]In particular, the range of integration is given by ",
  StyleBox["{-SmoothKernelRange*SmoothKernelSize,+SmoothKernelRange*\
SmoothKernelSize}",
    FontWeight->"Bold"],
  ". With ",
  StyleBox["Fresnel-",
    FontWeight->"Bold"],
  "related functions, the total number of convolution sample points is given \
by the ",
  StyleBox["GaussPoints",
    FontWeight->"Bold"],
  " option. See also",
  ":",
  " ",
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SmoothKernelSize", "Subsection"],

Cell[TextData[{
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " is an option that specifies the ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " of a Gaussian smoothing kernel: ",
  StyleBox["Exp[-",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["/",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox["^",
    FontWeight->"Bold"],
  "2",
  StyleBox["]",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is distance along the surface.\n\[InvisibleSpace]In particular, this \
smoothing kernel is convolved with another function in order to low",
  StyleBox["-",
    FontWeight->"Bold"],
  "pass filter its shape along a spatial surface. In its use with ",
  StyleBox["Fresnel-",
    FontWeight->"Bold"],
  "related functions, this models the \"rounding\" of sharp groove edges due \
to the manufacturing process and enables the vertical facets to be modeled. \
With ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  ", when ",
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 0 is specified, the grooves have perfect sharpness but the straight \
vertical facets are not modeled. In its use with the ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  " function, ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " works together with the ",
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  " option to smooth the calculated intensity function. ",
  StyleBox["SmoothKernelSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 0 is not permitted with its use in ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ", however.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also",
  ":",
  " ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KernelScale",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SmoothFresnel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SmoothKernelRange",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Snap", "Subsection"],

Cell[TextData[{
  StyleBox["Snap",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that automatically repositions and aligns components and rays along an \
optical axis. The axis is three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional and defined by the closest neighboring objects, or two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional and defined as points.\n\[InvisibleSpace]",
  StyleBox["Snap",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the objects getting translated and the new translation \
coordinates. Up to two additional coordinates specify an axis to snap on. \
Missing axis points are taken from neighbors in the object sequence. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["Snap",
    FontWeight->"Bold"],
  " does essentially the same as ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", but it uses another order of coordinate points.\n\[InvisibleSpace]See \
also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SnapGrid", "Subsection"],

Cell[TextData[{
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["grid",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " that specifies a ",
  StyleBox["grid",
    FontSlant->"Italic"],
  " for moving operations. The ",
  StyleBox["grid",
    FontSlant->"Italic"],
  " is a number or a list of numbers and specifies a ",
  StyleBox["grid",
    FontSlant->"Italic"],
  " to snap on. The list elements represent the horizontal and vertical \
direction to an axis and the angle in the drawing plane. A value of zero \
suppresses snapping in that direction. Missing values are filled with a zero.\
\n\[InvisibleSpace]",
  StyleBox["Move",
    FontWeight->"Bold"],
  " uses all three grids to snap on, ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  " snaps all points to the translation ",
  StyleBox["grid",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  " only uses the angle ",
  StyleBox["grid",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  " and commands using object positions are not affected by ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SnapGridOffset", "Subsection"],

Cell[TextData[{
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["offset",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " that specifies an ",
  StyleBox["offset",
    FontSlant->"Italic"],
  " for a grid for moving operations by options like ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["offset",
    FontSlant->"Italic"],
  " is a number or a list of numbers and specifies the ",
  StyleBox["offset",
    FontSlant->"Italic"],
  " of the grid to snap on. The list elements represent the horizontal and \
vertical direction to an axis and one angle. Missing values are filled with a \
zero. The angle represents the angle of the Cartesian grid against the \
horizontal axis and must be greater than 0 and less than 90.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Snell", "Subsection"],

Cell[TextData[{
  StyleBox["Snell",
    FontWeight->"Bold"],
  " is a symbolic value that indicates refraction without ",
  StyleBox["Fresnel",
    FontWeight->"Bold"],
  " reflections and losses",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SnellRefraction", "Subsection"],

Cell[TextData[{
  StyleBox["SnellRefraction",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  ", for example returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ", to characterize an isotropic",
  StyleBox["-",
    FontWeight->"Bold"],
  "medium obeying Snells law. No intensity changes occur",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SnowConeLens", "Subsection"],

Cell[TextData[{
  StyleBox["SnowConeLens[",
    FontWeight->"Bold"],
  StyleBox["domeradius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["entrancediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " defines a lens having a spherical entrance surface with the specified ",
  StyleBox["domeradius",
    FontSlant->"Italic"],
  ", linear tapered side walls defined by the entrance and exit aperture \
along with the ",
  StyleBox["length",
    FontSlant->"Italic"],
  ", and a planar exit surface.\n\[InvisibleSpace]",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  " is created with the center of the spherical lens centered at the origin \
and the center of the planar exit surface positioned down the positive x \
axis. ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by Robert Rieben, UCR.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SNx", "Subsection"],

Cell[TextData[{
  StyleBox["SNx",
    FontWeight->"Bold"],
  " is a symbol that indicates the first component of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface normal vector",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SNy", "Subsection"],

Cell[TextData[{
  StyleBox["SNy",
    FontWeight->"Bold"],
  " is a symbol that indicates the second component of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface normal vector",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SNz", "Subsection"],

Cell[TextData[{
  StyleBox["SNz",
    FontWeight->"Bold"],
  " is a symbol that indicates the third component of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface normal vector",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solid", "Subsection"],

Cell[TextData[{
  StyleBox["Solid",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SolidAngle", "Subsection"],

Cell[TextData[{
  StyleBox["SolidAngle",
    FontWeight->"Bold"],
  " is a special value of the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option that creates a uniform distribution of rays in solid angle.\n\
\[InvisibleSpace]It is only used by ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ". The ray tilts are aligned with the corners of a polyhedron inscribed in \
a unit sphere. This polyhedron is generated from an icosahedron that is \
subdivided by factors of two. The ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " option specifies the number of subdivisions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SolidCornerCube", "Subsection"],

Cell[TextData[{
  StyleBox["SolidCornerCube[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a four",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided retro",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflective prism arrangement having a single circular or hexagonal \
entrance",
  StyleBox["/",
    FontWeight->"Bold"],
  "exit face located in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane and its ",
  StyleBox["length",
    FontSlant->"Italic"],
  " located along the positive x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis, with three internally reflecting surfaces.\n\[InvisibleSpace]",
  StyleBox["SolidCornerCube",
    FontWeight->"Bold"],
  " behaves like a corner cube. Normally, the ",
  StyleBox["length",
    FontSlant->"Italic"],
  " parameter specifies the overall distance from the entrance face to the \
corner vertex, however, if either zero or a tiny value is given for ",
  StyleBox["length",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["SolidCornerCube",
    FontWeight->"Bold"],
  " is created with the minimum ",
  StyleBox["length",
    FontSlant->"Italic"],
  " configuration. If the ",
  StyleBox["Mirrored",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, the three corner surfaces are reflective",
  StyleBox["-",
    FontWeight->"Bold"],
  "coated. Otherwise, they are refractive surfaces that can also internally \
reflect. For ",
  StyleBox["Baffled->False",
    FontWeight->"Bold"],
  ", the side surface panels are refractive surfaces. If the ",
  StyleBox["Baffled",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " option is given, the side surface panels absorb any rays hitting them. \
There can be two different forms of ",
  StyleBox["SolidCornerCube",
    FontWeight->"Bold"],
  ": with ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the internal reflective surfaces have square boundaries and the entrance \
face is hexagonal",
  StyleBox[";",
    FontWeight->"Bold"],
  " with ",
  StyleBox["FullForm",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the internal reflective surfaces have partially rounded boundaries and \
the entrance face is circular. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["HollowCornerCube",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RoofPrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solitaire", "Subsection"],

Cell[TextData[{
  StyleBox["Solitaire[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " creates the 58",
  StyleBox["-",
    FontWeight->"Bold"],
  "faceted round prism commonly found in solitaire diamond engagement \
rings.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "You can use the option: ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " to specify a diamond refractive index function. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " uses special ",
  StyleBox["options",
    FontSlant->"Italic"],
  " for controlling its overall geometric shape that include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solubility", "Subsection"],

Cell[TextData[{
  StyleBox["Solubility",
    FontWeight->"Bold"],
  " is a database rule name that indicates the solubility of a material in \
water.\n\[InvisibleSpace]",
  StyleBox["Solubility",
    FontWeight->"Bold"],
  " is usually expressed in g",
  StyleBox["/",
    FontWeight->"Bold"],
  "(100 g water",
  ")",
  " at 26 degrees Celsius."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SortSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["SortSurfaces",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  " that indicates the surface ordering within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SortSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " lists the surfaces according to their relative placements, while ",
  StyleBox["SortSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " preserves the original ordering of surfaces given to ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Source", "Subsection"],

Cell[TextData[{
  StyleBox["Source[",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Source[",
    FontWeight->"Bold"],
  StyleBox["input",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " are objects created by the built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in ray source functions. The ",
  StyleBox["options",
    FontSlant->"Italic"],
  " contain rules that characterize the position and direction of the chief \
ray from the represented light source.\n\[InvisibleSpace] Both elements of ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " have the same format as the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object, and uses the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["input",
    FontSlant->"Italic"],
  " may also be a list of such objects. During the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace operation, ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " generates, for every ",
  StyleBox["input",
    FontSlant->"Italic"],
  " object independently, ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects for ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing. Any of the ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " functions may be nested around ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " to change its starting position and direction of propagation. There are \
six built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in ray source functions",
  ":",
  " ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  ". See ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  " for a partial listing of the parameters embedded within ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceDescription", "Subsection"],

Cell[TextData[{
  StyleBox["SourceDescription",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["sourcefunction",
    FontSlant->"Italic"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that describes the parent source function of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceDirectory", "Subsection"],

Cell[TextData[{
  StyleBox["SourceDirectory",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a directory.\n\[InvisibleSpace]This directory contains \
data on light sources",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceFiles", "Subsection"],

Cell[TextData[{
  StyleBox["SourceFiles",
    FontWeight->"Bold"],
  " is an option to ",
  StyleBox["LoadData",
    FontWeight->"Bold"],
  " that specifies a list of file names to be loaded.\n\[InvisibleSpace]These \
files contain information on light sources",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceFraction", "Subsection"],

Cell[TextData[{
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is option of ray source functions that indicates the part of the full \
source to be filled. Number must be between 0 and 1. To create an arc of \
rays, use e. g. ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 0.2 in ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", The ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  " uses the same coordinates as ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ". Two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional sources accept a list of two values",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceFunctions", "Subsection"],

Cell[TextData[{
  StyleBox["SourceFunctions",
    FontWeight->"Bold"],
  " generates a hyperlinked listing of the common light source models \
available in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceID", "Subsection"],

Cell[TextData[{
  StyleBox["SourceID",
    FontWeight->"Bold"],
  " is internal option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ray source functions that specifies a unique identification number.\n\
\[InvisibleSpace]",
  StyleBox["SourceID",
    FontWeight->"Bold"],
  " is usually determined by the function ",
  StyleBox["Unique",
    FontWeight->"Bold"],
  " during the creation of each ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " object. ",
  StyleBox["SourceID",
    FontWeight->"Bold"],
  " is used to identify the off",
  StyleBox["-",
    FontWeight->"Bold"],
  "spring ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects from the particular source function. See also",
  ":",
  " ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " and ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceLevel", "Subsection"],

Cell[TextData[{
  StyleBox["SourceLevel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["list",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " that designates the position of embedded sources.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["list",
    FontSlant->"Italic"],
  " is constructed automatically and contains the level of the source as well \
as the total number of levels. The innermost source has the level one",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceOffset", "Subsection"],

Cell[TextData[{
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is option of ray source functions that indicates the part of the full \
source to be filled has an offset. Number in combination with ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  " must be between 0 and 1. To create an arc of rays, use e. g. ",
  StyleBox["{SourceFraction -> ",
    FontWeight->"Bold"],
  "0.2",
  StyleBox[", SourceOffset -> ",
    FontWeight->"Bold"],
  "0.3",
  StyleBox["}",
    FontWeight->"Bold"],
  " in ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", The ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  " uses the same coordinates as ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ". Two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional sources accept a list of two values",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceQ", "Subsection"],

Cell[TextData[{
  StyleBox["SourceQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " tests whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Source",
    FontWeight->"Bold"],
  " object. The result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SourceTransformation", "Subsection"],

Cell[TextData[{
  StyleBox["SourceTransformation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["translationvector",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that describes the original position and orientation of the parent source \
of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpatialScale", "Subsection"],

Cell[TextData[{
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  " is a option that designates the spatial scale factor that gives \
millimeter units in the chosen optical coordinate system.\n\
\[InvisibleSpace]Note that ",
  StyleBox["SpatialScale",
    FontWeight->"Bold"],
  " presently does not affect the units of the ",
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " option, which is always specified in microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpecificHeat", "Subsection"],

Cell[TextData[{
  StyleBox["SpecificHeat",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["erg",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["g",
    FontSlant->"Italic"],
  " ",
  StyleBox["K",
    FontWeight->"Bold"],
  ")",
  " is a database rule name that specifies the specific heat of a material."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpectralIndex", "Subsection"],

Cell[TextData[{
  StyleBox["SpectralIndex",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["line",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["name",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["index",
    FontSlant->"Italic"],
  StyleBox["},",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule ",
  StyleBox["name",
    FontSlant->"Italic"],
  " that gives a list of refractive values for various wavelengths (given in \
nm",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpectralRegion", "Subsection"],

Cell[TextData[{
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " is the name of an option that specifies either two or three wavelength \
values, and is used in calculations of the Abbe V",
  StyleBox["-",
    FontWeight->"Bold"],
  "number (",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ") and the relative partial dispersion (",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  ")",
  " of an optical material.\n\[InvisibleSpace]The ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " wavelength values are conventionally chosen for the nominal visible range \
by the F",
  StyleBox["-",
    FontWeight->"Bold"],
  "d",
  StyleBox["-",
    FontWeight->"Bold"],
  "C spectral lines of hydrogen, helium, and hydrogen: 0.4861, 0.5876, and \
0.6563 microns. However, ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " can also specify other parts of the spectrum as well. Usually the ",
  StyleBox["SpectralRegion",
    FontWeight->"Bold"],
  " option need only specify the lower and upper wavelength bounds and the \
middle wavelength is automatically determined later to keep the same relative \
fraction with the traditional values. Otherwise, all three wavelength values \
can be specified. See also: ",
  StyleBox["GlassMap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindGlassNumbers",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GlassCodeFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AbbeVNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MeanDispersion",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PartialDispersionRatio",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphereGraphic", "Subsection"],

Cell[TextData[{
  StyleBox["SphereGraphic[",
    FontWeight->"Bold"],
  StyleBox["diameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional sphere with its center placed at the origin of the coordinate \
system.\n\[InvisibleSpace]",
  StyleBox["SphereGraphic",
    FontWeight->"Bold"],
  " can be rendered with opened quadrant sides by changing the ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["SphereGraphic",
    FontWeight->"Bold"],
  " does not interact with rays in any way, but can be listed with active \
components or with other graphics components for creating passive three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional shapes. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered ",
  "graphics",
  " and the output cell expression."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalBaffle[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalBaffle[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refer to a spherical component that absorbs light.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SphericalBaffle",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may indicate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalBeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalBeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designate a spherical component that has a partially reflective",
  StyleBox["/",
    FontWeight->"Bold"],
  "transmissive side with a ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " of curvature and ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " specified and a refractive side.\n\[InvisibleSpace]",
  StyleBox["SphericalBeamSplitter",
    FontWeight->"Bold"],
  " is created with its splitting surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalDiffuser", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalDiffuser[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalDiffuser[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffusing, component that splits incoming rays into \
diffused rays rays after an optical surface using the ray scattering \
distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser. ",
  StyleBox["SphericalDiffuser",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalDiffuserMirror", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalDiffuserMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffusing, reflective, component that splits incoming \
rays into diffused rays reflected rays after an optical surface using the ray \
scattering distribution pattern given in ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " can either be light source function or a listing of one or more angles \
that describe the scattering behavior. If a light source function is \
specified, then the ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  " function is called internally. An example of a light",
  StyleBox["-",
    FontWeight->"Bold"],
  "source ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  " is ",
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  "90",
  StyleBox[", NumberOfRays->",
    FontWeight->"Bold"],
  "1",
  StyleBox[", MonteCarlo -> True]",
    FontWeight->"Bold"],
  ". Otherwise, if a single number or a list of numeric scatter angles are \
passed in the ",
  StyleBox["scatteringparameter",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  " is called instead. Three examples of this are: 90, ",
  StyleBox["{",
    FontWeight->"Bold"],
  "90",
  StyleBox[",",
    FontWeight->"Bold"],
  "90",
  StyleBox["}",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["},{-",
    FontWeight->"Bold"],
  "45",
  StyleBox[",",
    FontWeight->"Bold"],
  "45",
  StyleBox["}}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the diffuser. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided diffuser.\n\[InvisibleSpace]",
  StyleBox["SphericalDiffuserMirror",
    FontWeight->"Bold"],
  " weights the scattered ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values according to seed ray ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " values. For ",
  StyleBox["Lambertian->True",
    FontWeight->"Bold"],
  ", the scattered rays are oriented about the surface normal. For ",
  StyleBox["Lambertian->False",
    FontWeight->"Bold"],
  ", the scattered rays are oriented with the incoming ray direction. The \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ScatterRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddRandomRayTilt",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffuser",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DiffuserMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomDiffuser",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomDiffuserMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalGratingMirror", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalGratingMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denote a spherical, diffractive, reflective, component that splits \
incoming rays into multiple diffracted, reflected orders according to the ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter and the ",
  StyleBox["DiffractedOrders",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the grating. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided grating. According to the ",
  StyleBox["GratingThickness",
    FontWeight->"Bold"],
  " option, a refractive part may be present in the grating. The ",
  StyleBox["gratingfunction",
    FontSlant->"Italic"],
  " parameter specifies a grating vector either as a one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional value, ",
  StyleBox["Gy",
    FontSlant->"Italic"],
  ", a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of values, ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  ", or a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional function, ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["], ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  ", in which ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["Gx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["Gz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. These vector quantities have units of spatial frequency and are \
given in line pairs per millimeter. A single number used in the grating \
parameter denotes a uniformly distributed grating vector pointing in the \
direction of the y axis. A list of two numbers indicates a uniformly \
distributed grating vector whose direction lies within the surface plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If you compare results with calculations by hand, please keep track of the \
correspondence of the ",
  StyleBox["options",
    FontSlant->"Italic"],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GratingMedium",
    FontWeight->"Bold"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["GratingTheory",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalLens", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalLens[",
    FontWeight->"Bold"],
  StyleBox["r1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["r2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a lens having spherical surfaces.\n\[InvisibleSpace]The radii of \
curvatures are specified by ",
  StyleBox["r1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["r2",
    FontSlant->"Italic"],
  " where ",
  StyleBox["Infinity",
    FontWeight->"Bold"],
  " is used to specify planar surfaces. ",
  StyleBox["SphericalLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalLensSurface[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a spherical component that has a given ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " of curvature that models the refractive index boundary at a lens surface.\
\n\[InvisibleSpace]",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicLensSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CustomLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalMirror", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SphericalMirror[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " specify a mirror that has a spherical reflective side.\n\
\[InvisibleSpace]The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["SphericalMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates the mirror on a flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "backed substrate. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalScreen", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalScreen[",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a spherical component that intersects rays without disturbing \
them.\n\[InvisibleSpace]Although ",
  StyleBox["SphericalScreen",
    FontWeight->"Bold"],
  " is usually not rendered, the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "screen intersections can be rendered by using the ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["PlotType->Surface",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SphericalScreen",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SphericalShape", "Subsection"],

Cell[TextData[{
  StyleBox["SphericalShape",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies the spherical ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SplitRays", "Subsection"],

Cell[TextData[{
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Polarization",
    FontWeight->"Bold"],
  " that indicates whether each incoming ray is to be split into two outgoing \
rays that contain two different polarization states denoted by the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " options.\n\[InvisibleSpace]The ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates two polarized rays that propagate in the same direction. ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  " produces a reflected polarized ray and a transmitted polarized ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpotPosition", "Subsection"],

Cell[TextData[{
  StyleBox["SpotPosition",
    FontWeight->"Bold"],
  " labels the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional point in space lying at the center of the locus of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersections.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpotSize", "Subsection"],

Cell[TextData[{
  StyleBox["SpotSize",
    FontWeight->"Bold"],
  " is a returned rule that indicates the \"diameter\" of a circle which \
encloses the locus of ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersections on a given optical surface.\n\[InvisibleSpace]For ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  ", the circle is determined by the two most distant rays, for ",
  StyleBox["FocusRadius",
    FontWeight->"Bold"],
  " the circle center is the mean of the rays and its radius is given by the \
ray most distant from the circle center. An ",
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  " defines the circle diameter as the second momentum of the rays. In all \
cases, the ",
  StyleBox["WeightingFunction",
    FontWeight->"Bold"],
  " is set to 1.\n\[InvisibleSpace]See also",
  ":",
  " MeritFunction, ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpotSizeFactor", "Subsection"],

Cell[TextData[{
  StyleBox["SpotSizeFactor",
    FontWeight->"Bold"],
  " is a option of ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that determines the outer beam radius used for raytracing as a \
multiplicative factor of ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  " dimensions.\n\[InvisibleSpace]",
  StyleBox["SpotSizeFactor",
    FontWeight->"Bold"],
  " does not alter the physical spot size of the Gaussian beam model but \
rather changes the outer cutoff radius of the generated rays. As a \
consequence, the Gaussian beam ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace radius is taken from the ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  " (at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of its amplitude peak",
  ")",
  " multiplied by the ",
  StyleBox["SpotSizeFactor",
    FontWeight->"Bold"],
  " in the starting transverse plane. See also: ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SPx", "Subsection"],

Cell[TextData[{
  StyleBox["SPx",
    FontWeight->"Bold"],
  " is a symbol that indicates the first element of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface intersection point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SPy", "Subsection"],

Cell[TextData[{
  StyleBox["SPy",
    FontWeight->"Bold"],
  " is a symbol that indicates the second element of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface intersection point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SPz", "Subsection"],

Cell[TextData[{
  StyleBox["SPz",
    FontWeight->"Bold"],
  " is a symbol that indicates the second element of a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface intersection point",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SquareConeMirror", "Subsection"],

Cell[TextData[{
  StyleBox["SquareConeMirror[",
    FontWeight->"Bold"],
  StyleBox["entrancedimension",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitdimension",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a component function which models a reflective light collector \
composed of four tapered mirror panels arranged around the shape of a cone.\n\
\[InvisibleSpace]",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by Robert Rieben, UCR.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StainResistance", "Subsection"],

Cell[TextData[{
  StyleBox["StainResistance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the stain resistance of a \
material",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StandardGraphics", "Subsection"],

Cell[TextData[{
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]If ",
  StyleBox["StandardGraphics",
    FontWeight->"Bold"],
  " mode is indicated, then a standard ",
  StyleBox["Graphics",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Graphics3D",
    FontWeight->"Bold"],
  " object is returned that is recognized by Mathematica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in graphical functions such as ",
  StyleBox["Show",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StarDiameter", "Subsection"],

Cell[TextData[{
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that specifies the outer diameter of the star",
  StyleBox["-",
    FontWeight->"Bold"],
  "patterned facets (above the girdle",
  ")",
  " as a percentage of the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter.\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include: ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StartAtBirthPoint", "Subsection"],

Cell[TextData[{
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["start",
    FontSlant->"Italic"],
  " is an option of most ray sources that controls the starting plane of the \
rays. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the rays are starting in the plane of the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ". Otherwise, they ",
  StyleBox["start",
    FontSlant->"Italic"],
  " in the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane. If ",
  StyleBox["start",
    FontSlant->"Italic"],
  " is a list, then the second element controls the starting point of ",
  StyleBox["OpticalLength",
    FontWeight->"Bold"],
  ". Recycling of optical systems causes both lengths to be reset to 0.\n\
\[InvisibleSpace]A low divergence sources can be modelled by a point source \
with a ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " far away and ",
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  " set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StartPoint", "Subsection"],

Cell[TextData[{
  StyleBox["StartPoint",
    FontWeight->"Bold"],
  " is a rule nested within ",
  StyleBox["RenderedPolygons",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional starting coordinate on a surface indicated by ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["StartPoint",
    FontWeight->"Bold"],
  " is used for creating the sides of a polygon that span several surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StartValue", "Subsection"],

Cell[TextData[{
  StyleBox["StartValue",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " that gives a starting number to help ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " begin its search",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StepFraction", "Subsection"],

Cell[TextData[{
  StyleBox["StepFraction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["stepfraction",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  " that determines the second starting value of a minimization as a \
fractional addition of the initial starting value. See also",
  ":",
  " ",
  StyleBox["OptimizeSystem",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StepSize", "Subsection"],

Cell[TextData[{
  StyleBox["StepSize",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " gives the rate of ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " used to step through numeric solutions.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["StepSize",
    FontWeight->"Bold"],
  " is typically employed as a relative setting that is scaled by a physical \
parameter in the model, such as length. See also",
  ":",
  " ",
  StyleBox["AbsoluteStepSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["StopPosition", "Subsection"],

Cell[TextData[{
  StyleBox["StopPosition",
    FontWeight->"Bold"],
  " is a database rule name that indicates the corresponding surface number \
for the field stop in a lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stratified", "Subsection"],

Cell[TextData[{
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Stratified, ",
    FontWeight->"Bold"],
  StyleBox["xvariance",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yvariance",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "  generates rays that randomly fluctuate about uniformly spaced intervals \
independently specified by the ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  " option.\n\[InvisibleSpace]",
  StyleBox["Stratified",
    FontWeight->"Bold"],
  " may be passed either on its own or with optional ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xvariance",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yvariance",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " factors that attenuate (or amplify",
  ")",
  " the fluctuation amplitude. If no explicate values are given for ",
  StyleBox["xvariance",
    FontSlant->"Italic"],
  " and ",
  StyleBox["yvariance",
    FontSlant->"Italic"],
  ", then values of 1 are assumed and the fluctuation amplitude matches the \
uniform grid spacing for the light source. For values less than 1, the \
fluctuation amplitude is diminished. For one",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional light sources, only a single variance parameter is employed."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SuppressReflectance", "Subsection"],

Cell[TextData[{
  StyleBox["SuppressReflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " and some refractive component functions that suppresses the given value \
of the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " option such that ",
  StyleBox["Reflectance->Automatic",
    FontWeight->"Bold"],
  " is always used by the refractive surface.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "Otherwise, ",
  StyleBox["SuppressReflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " allows the specified ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value to be incorporated into the refractive surface behavior. ",
  StyleBox["SuppressReflectance",
    FontWeight->"Bold"],
  " is used with components that contain both reflective and refractive \
surfaces in order to pass ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " information to the reflective surfaces without affecting the refractive \
surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suprasil", "Subsection"],

Cell[TextData[{
  StyleBox["Suprasil",
    FontWeight->"Bold"],
  " denotes the use of the ",
  StyleBox["Suprasil",
    FontWeight->"Bold"],
  " glass medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Surface", "Subsection"],

Cell[TextData[{
  StyleBox["Surface",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " giving a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional plot that shows selected intersection points between rays and \
one or more optical surfaces.\n\[InvisibleSpace]The ",
  StyleBox["RayChoice",
    FontWeight->"Bold"],
  " option is used in selecting rays to be displayed. See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TopView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceAccuracy", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  " is a database rule name that specifies the accuracy, in wavelengths, of \
an optical surface. Unless denoted otherwise, ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  " is normally based on 0.633 microns wavelength. In addition to ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WaveFrontFlatness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  " is particularly important as a selection criteria for mirrors. See also",
  ":",
  " ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WaveFrontFlatness",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceApproximation", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["method",
    FontSlant->"Italic"],
  " specifies the ",
  StyleBox["method",
    FontSlant->"Italic"],
  " used to determine an approximate starting point for numerical ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection calculations.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " becomes active for numerical settings of SurfaceRayIntersection. These \
include: SurfaceRayIntersection ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " settings include:",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(1) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  " (or ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ") constructs a triangular fishnet of starting points based on the original \
optical ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ". For this, the ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " option specifies the number of fishnet elements.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(2) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{TriangleNet -> ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " denotes an alternative surface function to generate the fish",
  StyleBox["-",
    FontWeight->"Bold"],
  "net of numerical starting points.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(3) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Symbol -> ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " indicates an alternative surface function which has an analytic ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection solution (determined by ",
  "Optica",
  ").",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(4) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  " uses the intersection point with a plane for a starting condition.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(5) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{SphericalShape -> ",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses the intersection point with a hemi",
  StyleBox["-",
    FontWeight->"Bold"],
  "spherical surface that has a given ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(6) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{CylindricalShape -> ",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses the intersection point with a half",
  StyleBox["-",
    FontWeight->"Bold"],
  "cylinder that has a given ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(7) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{ParabolicShape -> ",
    FontWeight->"Bold"],
  StyleBox["focus",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses the intersection point with a paraboloid that has a given ",
  StyleBox["focus",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(8) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{SurfaceIntersectionFunction-> ",
    FontWeight->"Bold"],
  StyleBox["intersectionfunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " directly specifies an alternative ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection solution. In this case, the ",
  StyleBox["intersectionfunction",
    FontSlant->"Italic"],
  " need not be analytic.\n\[InvisibleSpace]For SurfaceRayIntersection ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FindRoot/FindMinimum",
    FontWeight->"Bold"],
  ", there are two additional settings available:",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(9) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Solve -> ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " dynamically uses the ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " function to determine an initial condition.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "(10) ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{NSolve -> ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  " function to dynamically determine an approximate intersection point for \
",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]In general, ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " describes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional parametric surface in form of ",
  StyleBox["Function[{",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["],",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["],",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]}]",
    FontWeight->"Bold"],
  " although many format variations are also permitted. See also: ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  ", and SurfaceRayIntersection."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " parameter that gives a list of numbers describing the surface boundary.\n\
\[InvisibleSpace]Depending on the form of ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  ", either a circular, elliptical, rectangular or polygonal boundary is \
defined",
  ":",
  " a single number indicates a circular boundary having the indicated \
diameter",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of two positive numbers indicates a rectangular boundary that has \
a length and a width",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of two negative numbers indicates an elliptical boundary having \
the indicated major and minor axis",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of paired numbers designates a polygonal boundary having the \
indicated vertex points. ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  " is also a ray parameter rule that gives the ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " dimensions of the last surface to intercept the ray."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceBoundaryFactor", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceBoundaryFactor",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["number",
    FontSlant->"Italic"],
  " is option that is used to increase the ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  " dimensions by a tiny margin.\n\[InvisibleSpace]",
  StyleBox["SurfaceBoundaryFactor",
    FontWeight->"Bold"],
  " is always a ",
  StyleBox["number",
    FontSlant->"Italic"],
  " that is equal or slightly larger than 1. This is useful to insure \
overlapping aperture coverage in multi",
  StyleBox["-",
    FontWeight->"Bold"],
  "faceted optics. ",
  StyleBox["SurfaceBoundaryFactor",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceBreak", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  " forms a list of constant real numbers inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " that marks an information break between reported rays from different \
surfaces.\n\[InvisibleSpace]",
  StyleBox["SurfaceBreak",
    FontWeight->"Bold"],
  " has a length that is equal to a single ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " element and whose number values are all equal to ",
  StyleBox["-",
    FontWeight->"Bold"],
  "$MaxMachineNumber. See also",
  ":",
  " ",
  StyleBox["RemoveSurfaceBreaks",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceCenter", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceCenter",
    FontWeight->"Bold"],
  " is a rule embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface center coordinates.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["EntranceCoordinates",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FunctionCenter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceCoating", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " is a database rule name that specifies the type of coating placed on an \
optical component.\n\[InvisibleSpace]",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " is used with mirrors to indicate a reflective coating. ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " may also be used with lenses to indicate an anti",
  StyleBox["-",
    FontWeight->"Bold"],
  "reflective coating. ",
  StyleBox["ReadData[SurfaceCoating, SurfaceCoating, Union->True]",
    FontWeight->"Bold"],
  " is used to get a listing of current coatings. In addition to ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " is particularly important as a selection criteria for mirrors. Note that \
although ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " is useful for selecting a particular catalog item, ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " is presently not used by ",
  StyleBox["DataToOptica",
    FontWeight->"Bold"],
  " for actual optical component models. See also: ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceContinuation", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceContinuation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that indicates whether a particular surface is part of a connected set of \
surfaces that follows a continuous shape.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In such instances, the ",
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  " remains the same for each of the continued surface elements. See also",
  ":",
  " ",
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceCoordinates", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the parametric coordinate of the last surface function to \
intersect with the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceCurvature", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceCurvature",
    FontWeight->"Bold"],
  " is a database rule name that specifies a list of inverse radius",
  StyleBox["-",
    FontWeight->"Bold"],
  "of",
  StyleBox["-",
    FontWeight->"Bold"],
  "curvatures for a component made up of spherical or cylindrical surfaces.\n\
\[InvisibleSpace]Note that ",
  StyleBox["SurfaceCurvature",
    FontWeight->"Bold"],
  " is not recognized by ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "requires the use of ",
  StyleBox["RadiusOfCurvature",
    FontWeight->"Bold"],
  " instead. ",
  StyleBox["SurfaceCurvature",
    FontWeight->"Bold"],
  " can easily be converted into ",
  StyleBox["RadiusOfCurvature",
    FontWeight->"Bold"],
  " with the command, ",
  StyleBox["EditData[",
    FontWeight->"Bold"],
  StyleBox["data",
    FontSlant->"Italic"],
  StyleBox[", {RadiusOfCurvature ",
    FontWeight->"Bold"],
  ":",
  StyleBox["> Map[",
    FontWeight->"Bold"],
  "(1",
  StyleBox["/#",
    FontWeight->"Bold"],
  ")",
  StyleBox["&, Flatten[{SurfaceCurvature}]]}]",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["RadiusOfCurvature",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceFacet", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceFacet[",
    FontWeight->"Bold"],
  StyleBox["points",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " denotes a polygon",
  StyleBox["-",
    FontWeight->"Bold"],
  "edged planar surface with user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified optical properties.\n\[InvisibleSpace]",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  " is created with its surface edges oriented according to the specified \
list of three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional surface ",
  StyleBox["points",
    FontSlant->"Italic"],
  ". These surface ",
  StyleBox["points",
    FontSlant->"Italic"],
  " describe the aperture boundary of the surface facet. In general, the \
surface ",
  StyleBox["points",
    FontSlant->"Italic"],
  " should all lie within the single plane in space. When several ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  " components are required, it is often more efficient to use the ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  " object instead. The optical properties of ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  " are specified by the ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " option. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " giving a list of three parametric pure function equations ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " that describe a particular optical surface in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceFunctionQ", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceFunctionQ[",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceFunctionQ[{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontWeight->"Bold"],
  " test whether ",
  StyleBox["x",
    FontSlant->"Italic"],
  " indicates one or more ",
  StyleBox["Function",
    FontWeight->"Bold"],
  " objects that evalue to a numerical result or a numerical value. The \
result is ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceGrating", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceGrating",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  " family of components that indicate the diffraction grating is located on \
the surface of the element and has no intrinsic thickness.\n\
\[InvisibleSpace]",
  StyleBox["SurfaceGrating",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " denotes that the diffraction grating is located within an emulsion that \
is normally coated onto a substrate material. ",
  StyleBox["SurfaceGrating",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["True",
    FontWeight->"Bold"],
  " when no substrate thickness parameter has been specified for the \
component. See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceID", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies a unique identification number.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  " is usually determined by the function ",
  StyleBox["Unique",
    FontWeight->"Bold"],
  " during the creation of a surface. As a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceID",
    FontWeight->"Bold"],
  " indicates the surface encountered by the ray segment. See also",
  ":",
  " ",
  StyleBox["SurfaceContinuation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Component",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceIncrement", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the rate of ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " used to step through component surfaces.\n\[InvisibleSpace]",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["+",
    FontWeight->"Bold"],
  "1 increments ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " by 1, while ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1 increments ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " by ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1. ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " locations can be skipped by forcing ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " to be some integer ",
  StyleBox[">",
    FontWeight->"Bold"],
  "1 or ",
  StyleBox["<",
    FontWeight->"Bold"],
  "1. By setting ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 0, ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " remains at the same ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  " location for an iteration. ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  " will always revert to ",
  StyleBox["Sign[",
    FontWeight->"Bold"],
  StyleBox["increment",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " after one propagation iteration. A related parameter is ",
  StyleBox["ComponentIncrement",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceIntersectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a rule embedded within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component designating a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " that calculates surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersections.\n\[InvisibleSpace]The ",
  StyleBox["function",
    FontSlant->"Italic"],
  " takes the ray start and tilt in local surface coordinates as a sequence \
of six real values and returns a list of all the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional parametric intersection coordinates, ray length and two \
surface coordinates. If no intersection is found, the ",
  StyleBox["function",
    FontSlant->"Italic"],
  " either returns ",
  StyleBox["{{-",
    FontWeight->"Bold"],
  "1",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox[",",
    FontWeight->"Bold"],
  "0",
  StyleBox["}}",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{NoSurfaceIntersection}",
    FontWeight->"Bold"],
  " (which is expanded internally with a proper value.",
  ")",
  " ",
  StyleBox["SurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " may also used as the head for the surface intersection ",
  StyleBox["function",
    FontSlant->"Italic"],
  ". See also: ",
  StyleBox["CompiledSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceIntersections", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceIntersections",
    FontWeight->"Bold"],
  " is a placeholder that designates the surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersections.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "It is used in ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " as a placeholder to access the already calculated intersections",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceLabel", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates the shapes of surfaces created by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " contains one or more elements of ",
  StyleBox["SphericalShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParabolicShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlanarShape",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CylindricalShape",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["OtherShape",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " usually has as many elements as there are related surfaces. If only shape \
element is indicated, all surfaces are assigned the same type of shape. A \
user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined value for ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " may also be used. ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " is also a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "word description of a particular optical surface. See also",
  ":",
  " ",
  StyleBox["ModelSurfaceShape",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceLabelNumber", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceLabelNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns an identifying number to a surface type",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceNormalCalculations", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceNormalCalculations",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that specifies whether calculations are based on symbolic or direct \
numerical solutions for the ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " parameter.\n\[InvisibleSpace]For some discontinuous and ill",
  StyleBox["-",
    FontWeight->"Bold"],
  "behaved surface functions, ",
  StyleBox["SurfaceNormalCalculations",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  " may be necessary. Then, a Romberg algorithm is used to calculate \
derivatives from the surface function. Generally, ",
  StyleBox["SurfaceNormalCalculations",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is used for well",
  StyleBox["-",
    FontWeight->"Bold"],
  "behaved functions",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceNormalFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the normals of the surface functions.\n\[InvisibleSpace]",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " is calculated without normalization and added by ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  " is used by ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing functions such as ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Reflection",
    FontWeight->"Bold"],
  ", or where ",
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  " is included in the TakeForm rule within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceNormalMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceNormalMatrix",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives a direction matrix for the point at the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection. It contains a unit normal vector of the surface as \
its first element, as well as the two unit",
  StyleBox["-",
    FontWeight->"Bold"],
  "tangent vectors",
  ".",
  " "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceNumber", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  " is a rule of both ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that denotes the slot positions used within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfacePlot", "Subsection"],

Cell[TextData[{
  StyleBox["SurfacePlot",
    FontWeight->"Bold"],
  " is a pattern of ",
  StyleBox["RayParameters",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfacePoints", "Subsection"],

Cell[TextData[{
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that specifies the number of points of a surface net.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["m",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  "  is used to separately specify a different number of points along each \
parametric coordinate direction. This net is used with custom surface \
functions and certain settings of SurfaceRayIntersection in order to \
determine an initial condition for the numeric ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection solving procedure. Increasing the number helps to \
deal with steeply curved custom surfaces.\n\[InvisibleSpace]Inside the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component, ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["pointlist",
    FontSlant->"Italic"],
  " gives the coordinates of the net. As an option to ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True|Fill|Mesh",
    FontWeight->"Bold"],
  " draw the net on top of the surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceRayIntersections", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["method",
    FontSlant->"Italic"],
  " is an option of all component functions and ",
  StyleBox["ComponentFoundation",
    FontWeight->"Bold"],
  " that specifies the ",
  StyleBox["method",
    FontSlant->"Italic"],
  " for finding the surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "ray intersection point.\n\[InvisibleSpace]Currently, there are seven \
different settings available for ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  ": ",
  StyleBox["Symbol",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ". In general, the optimal choice of ",
  StyleBox["method",
    FontSlant->"Italic"],
  " depends on the particular ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace circumstances. While all of these settings work transparently within \
",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", only ",
  StyleBox["Symbol",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  " can be directly integrated into compiled ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace code. Symbol constructs an analytic, closed",
  StyleBox["-",
    FontWeight->"Bold"],
  "form solution for the intersection point and exhibits the fastest ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace response. Unfortunately, ",
  StyleBox["Symbol",
    FontWeight->"Bold"],
  " does not work with surface functions that lack a closed",
  StyleBox["-",
    FontWeight->"Bold"],
  "form inverse solution and the build",
  StyleBox["-",
    FontWeight->"Bold"],
  "time of ",
  StyleBox["Symbol",
    FontWeight->"Bold"],
  " is much longer than the other methods. ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  " constructs a numerical solution that can be directly compiled by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]In cases involving interpolated surfacefunctions or \
when the previous two methods fail to perform, one of the remaining methods \
can work more effectively. ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " internally and is the fastest and most robust numerical ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace ",
  StyleBox["method",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  " internally and, in special cases, can work better than the ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  " (although not in most cases.) ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " internally to dynamically find the analytic ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface solution. ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  " internally and works exclusively with polynomial surface equations. For \
qualified surface functions, ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  " will always find the globally correct intersection point.\n\
\[InvisibleSpace]Finally, ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " automatically to chooses an appropriate ",
  StyleBox["method",
    FontSlant->"Italic"],
  ". Note that ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " works in conjunction with ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["FindRoot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ", ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ModelSurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceRendering", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that denotes the surface graphical rendering of single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced and multisurfaced components.\n\[InvisibleSpace]",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  " uses a list composed of: ",
  StyleBox["Fill",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Trace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mesh",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Empty",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["{Fill, Mesh}",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RenderType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceRotationMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceRotationMatrix",
    FontWeight->"Bold"],
  " is a rule that gives a 3 x 3 matrix spatial rotations invoked on the \
original object coordinate system. See also",
  ":",
  " ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Surfaces", "Subsection"],

Cell[TextData[{
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " giving a list of elements that defines component surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceSelect", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceSelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes an ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " and returns a filtered list of ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " objects that shares the common set of traits specified in ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ". The allowed types of ",
  StyleBox["objectset",
    FontSlant->"Italic"],
  " are the same as for ",
  StyleBox["ConvertOptics[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox[", Surfaces]",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]There are two ways of specifying ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  ":",
  " the first way is to give a list of ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rules selected. The second way is to give a function that takes ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rules as inputs and returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  ". An example of the first method is ",
  StyleBox["{TranslationVector -> {",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}, ComponentNumber -> ",
    FontWeight->"Bold"],
  "2",
  StyleBox["}",
    FontWeight->"Bold"],
  ". An example of the second method is ",
  StyleBox["Function[{ComponentNumber, TranslationVector}, ComponentNumber == \
",
    FontWeight->"Bold"],
  "2",
  StyleBox[" && TranslationVector[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]] > ",
    FontWeight->"Bold"],
  "0",
  StyleBox["]",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " ",
  StyleBox["===",
    FontWeight->"Bold"],
  " ",
  StyleBox["All",
    FontWeight->"Bold"],
  " or ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " is left out, then all ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " objects are passed back. ",
  StyleBox["SurfaceSelect[",
    FontWeight->"Bold"],
  StyleBox["objectset",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns an unfiltered list of ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " objects."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceSelectSurfaceOrientation", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceSelectSurfaceOrientation",
    FontWeight->"Bold"],
  " is a an option of ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  " that determines a list of numbers of components and surfaces, for which \
an orientation should be drawn. A single number in the list specifies a whole \
component, a list of numbers specifies a component number and surface numbers \
of this component. See also",
  ":",
  " ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfaceOrientation",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceSeparation", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceSeparation",
    FontWeight->"Bold"],
  " is a database rule name that provides the geometric distance of \
separation between different lens surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceStyle", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceStyle",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["ComponentRendering",
    FontWeight->"Bold"],
  " that denotes the graphical primitives to be inserted before the surface \
graphical rendering of single",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced and multisurfaced components.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "For each surface, one list may be specified. It is a list of two rules: ",
  StyleBox["LineStyle",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FillStyle",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["DefaultStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrossStyle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeStyle",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceTranslationVector", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceTranslationVector",
    FontWeight->"Bold"],
  " is a rule that denotes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector for spatial translations invoked on the original \
surface coordinate system. See also",
  ":",
  " ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceType", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["functionhead",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["CustomPrism",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceFacet",
    FontWeight->"Bold"],
  " that specifies the type of optical surface used in the prism \
construction.\n\[InvisibleSpace]Examples are",
  ":",
  " ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Mirror",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Baffle",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SurfaceType->{",
    FontWeight->"Bold"],
  StyleBox["functionhead",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["parameters",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used for component functions that require additional ",
  StyleBox["parameters",
    FontSlant->"Italic"],
  ". Example of this is ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Grating, ",
    FontWeight->"Bold"],
  "1000",
  StyleBox["}",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{BeamSplitter, {",
    FontWeight->"Bold"],
  "50",
  StyleBox[",",
    FontWeight->"Bold"],
  "50",
  StyleBox["}}",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SurfaceValue", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceValue",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies the curvature characteristics of the function given in ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceValue",
    FontWeight->"Bold"],
  " is interpreted differently by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " according to the accompanying ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " option."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Swap", "Subsection"],

Cell[TextData[{
  StyleBox["Swap",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["newobjects",
    FontSlant->"Italic"],
  StyleBox[", {",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that exchanges new components and rays with designated old components and \
rays of an existing system.\n\[InvisibleSpace]",
  StyleBox["Swap",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the existing objects getting replaced. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwitchDirectionOnReflection", "Subsection"],

Cell[TextData[{
  StyleBox["SwitchDirectionOnReflection",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " and refractive components that determines whether the direction of \
propagation is reversed by an internal reflection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SwitchIntrinsicMedium", "Subsection"],

Cell[TextData[{
  StyleBox["SwitchIntrinsicMedium[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["medium2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block used for changing the values of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " between ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["SwitchIntrinsicMedium",
    FontWeight->"Bold"],
  " uses parameters ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " to obtain intrinsic index functions. If the ray is coming from an \
environment that has an intrinsic index given by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " is replaced by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ". Likewise, if the ray is coming from an environment that has an intrinsic \
index given by ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  ", then the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " is replaced by ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  ". Note that either ",
  StyleBox["medium1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["medium2",
    FontSlant->"Italic"],
  " must correspond with the value of ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  " of the incident ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object. If the ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " object of the incident ray does not already contain one of the two \
intrinsic index values, then the ray",
  StyleBox["'",
    FontWeight->"Bold"],
  "s propagation is terminated by setting its ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " to zero, which specifies a design entry error. See also",
  ":",
  " ",
  StyleBox["IntrinsicMedium",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RefractiveIndex",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBeamCurvature", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the symbolic phase radius of curvature in a particular \
transverse plane for a Gaussian beam.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBeamDivergence", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  " is an rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that indicates the symbolic far",
  StyleBox["-",
    FontWeight->"Bold"],
  "field full angle of divergence (in radians",
  ")",
  " of a Gaussian beam.\n\[InvisibleSpace]See also: ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBeamScaleLength", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that is directly related to the beam waist spot size and is the symbolic \
axial scale length given for the particular Gaussian beam waist.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBeamSpotSize", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that denotes the Gaussian beam radius (at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of its amplitude peak",
  ")",
  " in a particular transverse plane.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBeamWaist", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the symbolic minimum radius size (at 1",
  StyleBox["/",
    FontWeight->"Bold"],
  "e of its amplitude peak",
  ")",
  " at the waist position of a particular Gaussian beam.\n\
\[InvisibleSpace]See also: ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicBirthPoint", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicBirthPoint->",
    FontWeight->"Bold"],
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " is an option of ray sources that gives the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional spatial ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " of the light source. ",
  StyleBox["SymbolicBirthPoint",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " automatically sets its value to match the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["SymbolicBirthPoint",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " option to specify whether its arguments shall be given in rectangular ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " (",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["CartesianCoordinates",
    FontWeight->"Bold"],
  ") or spherical ",
  StyleBox["coordinates",
    FontSlant->"Italic"],
  " (",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["PolarCoordinates",
    FontWeight->"Bold"],
  ")",
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CoordinateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StartAtBirthPoint",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["BalancePhaseFront",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicComplexBeamParameter", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  " is an rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that indicates the symbolic complex beam parameter q of a Gaussian beam \
at a particular transverse plane.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicComponentTransformation", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicComponentTransformation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["symbolictranslationvector",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["symbolicrotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the symbolic original position and orientation of the \
parent component of the surface. Functions grouping components together, like \
",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  ", do not change ",
  StyleBox["SymbolicComponentTransformation",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["SymbolicTranslationVector",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicRotationMatrix",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicDeflectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicDeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["list",
    FontSlant->"Italic"],
  " denotes briefly the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing behavior at component surfaces. See also",
  ":",
  " ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicHoleBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicHoleBoundary",
    FontWeight->"Bold"],
  " is a rule parameter that gives the hole aperture dimensions for a \
particular ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " surface.\n\[InvisibleSpace]",
  StyleBox["SymbolicHoleBoundary",
    FontWeight->"Bold"],
  " may hold user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined, symbolic parameters. See also",
  ":",
  " ",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SymbolicHoleOffset",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicHoleOffset", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicHoleOffset",
    FontWeight->"Bold"],
  " is a rule parameter that gives the offset dimensions of a hole aperture \
for a particular ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " surface.\n\[InvisibleSpace]",
  StyleBox["SymbolicHoleOffset",
    FontWeight->"Bold"],
  " may hold user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined, symbolic parameters. See also",
  ":",
  " ",
  StyleBox["SymbolicHoleBoundary",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HoleOffset",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicInsideHoleBoundaryQ", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicInsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " designates a ",
  StyleBox["function",
    FontSlant->"Italic"],
  ", with user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined symbolic parameters included, that returns ",
  StyleBox["True",
    FontWeight->"Bold"],
  " if the given parametric point is within the hole boundary.\n\
\[InvisibleSpace]The ",
  StyleBox["SymbolicInsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " can simultaneously manage several holes within the same surface. The ",
  StyleBox["SymbolicInsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " rule is located within the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of a component. See also",
  ":",
  " ",
  StyleBox["InsideHoleBoundaryQ",
    FontWeight->"Bold"],
  " and ",
  StyleBox["HoleBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicIntensity",
    FontWeight->"Bold"],
  " is a rule that gives a symbolic ray intensity value",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicJacobianMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicJacobianMatrix",
    FontWeight->"Bold"],
  " is a rule sometimes embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that gives the ",
  StyleBox["Jacobian",
    FontWeight->"Bold"],
  " of the symbolic description of the surface. The functions take as \
arguments the ray length, the surface coordinates and the ray tilt as a \
sequence of six values",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicOffAxis", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicOffAxis",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["xoffset",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["yoffset",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option that specifies an offset of the axis of symmetry for curved \
surfaces. It is created, if symbols are given in the option ",
  StyleBox["OffAxis",
    FontWeight->"Bold"],
  " of the component. See also",
  ":",
  " ",
  StyleBox["OffAxis",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicOpticalLength", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicOpticalLength",
    FontWeight->"Bold"],
  " is a rule that gives the total symbolic optical path length of a ray from \
the beginning of its creation",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicPolarization", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicPolarization",
    FontWeight->"Bold"],
  " is a rule that denotes a symbolic ray polarization vector",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRayEnd", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRayEnd",
    FontWeight->"Bold"],
  " is a rule that gives the symbolic spatial ending coordinate of a ray \
segment. It shows the three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate point where the ray intersects with the next \
symbolic component surface",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRayLength", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRayLength",
    FontWeight->"Bold"],
  " is a rule that gives the symbolic geometric length of a ray segment \
running between two symbolic optical surfaces",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRayStart", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRayStart",
    FontWeight->"Bold"],
  " is a rule that gives the symbolic spatial starting coordinate of a ray \
segment",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRayTilt", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRayTilt",
    FontWeight->"Bold"],
  " is a rule that gives the symbolic three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector that designates the direction in which a ray segment is \
pointing in space. It is the direction of propagation of energy",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRefractiveModels", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRefractiveModels",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["opticalmedium",
    FontSlant->"Italic"],
  StyleBox["->",
    FontWeight->"Bold"],
  StyleBox["symbolicexpression",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and SymbolicTrace that provides a mechanism to replace pre",
  StyleBox["-",
    FontWeight->"Bold"],
  "existing refractive index models with new models that contain user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined symbolic parameters.\n\[InvisibleSpace]In this, each specified ",
  StyleBox["symbolicexpression",
    FontSlant->"Italic"],
  " holds the symbolic refractive index model to be exchanged with the pre",
  StyleBox["-",
    FontWeight->"Bold"],
  "existing model identified by ",
  StyleBox["opticalmedium",
    FontSlant->"Italic"],
  ". See also",
  ":",
  " ",
  StyleBox["OpticalMedium",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicRotationMatrix", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicRotationMatrix",
    FontWeight->"Bold"],
  " is a rule that gives a 3 x 3 matrix of symbolic spatial rotations invoked \
on the original object coordinate system. It is created, if symbols are given \
in the parameters of the component. See also",
  ":",
  " ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSourceTransformation", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSourceTransformation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["translationvector",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["rotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that describes symbolically the original position and orientation of the \
parent source of the ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " parameter that gives a list describing the surface boundary.\n\
\[InvisibleSpace]Depending on the form of ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  ", either a circular, elliptical, rectangular or polygonal boundary is \
defined: a single symbol indicates a circular boundary having the indicated \
diameter",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of two symbols indicates a rectangular boundary that has a length \
and a width",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of two symbols with a minus, \"-\", indicates an elliptical \
boundary having the indicated major and minor axis",
  StyleBox[";",
    FontWeight->"Bold"],
  " a list of paired symbols designates a polygonal boundary having the \
indicated vertex points. It is created, if symbols are given in the \
parameters of the component. See also",
  ":",
  " ",
  StyleBox["SurfaceBoundary",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceCoordinates", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceCoordinates",
    FontWeight->"Bold"],
  " is a rule that gives the symbolic parametric coordinate function of a \
surface intersecting with a ray",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " giving a list of three parametric symbolic pure function equations ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["fx",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fy",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["fz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " that describe a particular optical surface in three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional space. It is created, if symbols are given in the parameters \
of the component. See also",
  ":",
  " ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceIntersectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that denotes the symbolic solutions for the ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersection points.\n\[InvisibleSpace]",
  StyleBox["SymbolicSurfaceIntersectionFunction",
    FontWeight->"Bold"],
  " is calculated with the values in the ",
  StyleBox["SymbolicSurfaceFunction",
    FontWeight->"Bold"],
  " rule",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceNormalFunction", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceNormalFunction",
    FontWeight->"Bold"],
  " is a rule embedded within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the symbolic normals of the surface functions. It is \
created, if symbols are given in the parameters of the component. See also",
  ":",
  " ",
  StyleBox["SurfaceNormalFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicSurfaceValue", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicSurfaceValue",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " is a rule within ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " of ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that specifies the curvature characteristics of the function given in ",
  StyleBox["SymbolicSurfaceFunction",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SymbolicSurfaceValue",
    FontWeight->"Bold"],
  " is interpreted differently by ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " according to the accompanying ",
  StyleBox["SurfaceLabel",
    FontWeight->"Bold"],
  " option."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicTranslationVector", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicTranslationVector",
    FontWeight->"Bold"],
  " is a rule that denotes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional symbolic vector for spatial translations invoked on the \
original surface coordinate system. It is created, if symbols are given in \
the parameters of the component. See also",
  ":",
  " ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicValues", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox["->",
    FontWeight->"Bold"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option that attaches numerical values to the specified symbolic \
variable names.\n\[InvisibleSpace]",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  " is required in custom component functions, such as ",
  StyleBox["CustomMirror",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomLens",
    FontWeight->"Bold"],
  ", to assign numerical values to any user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined symbolic variables present in the custom surface function. ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  " is stored in the ",
  StyleBox["Surfaces",
    FontWeight->"Bold"],
  " rule of the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object. ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  " can be user",
  StyleBox["-",
    FontWeight->"Bold"],
  "specified or, in some cases, is automatically generated during the ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " creation",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicWaistDistance", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the symbolic axial distance of the particular measurement \
position to the minimum Gaussian beam waist position.\n\[InvisibleSpace]See \
also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolicWaveLength", "Subsection"],

Cell[TextData[{
  StyleBox["SymbolicWaveLength",
    FontWeight->"Bold"],
  " is a rule that denotes a symbolic value for the optical wavelength (in \
microns",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TableDiameter", "Subsection"],

Cell[TextData[{
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  " is an option of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism that indicates the diameter of the table facet as a percentage of \
the overall ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " diameter.\n\[InvisibleSpace]Specialized options of the ",
  StyleBox["Solitaire",
    FontWeight->"Bold"],
  " prism include",
  ":",
  " ",
  StyleBox["TableDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GirdleThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionAngle",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StarDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFacetDiameter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CrownHeight",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PavilionDepth",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CuletAngle",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CuletDiameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TakeFrom", "Subsection"],

Cell[TextData[{
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objecttypes",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that designates which types of objects are used as inputs to the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing ",
  StyleBox["function",
    FontSlant->"Italic"],
  " calculation.\n\[InvisibleSpace]Possible object types of ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " include ",
  StyleBox["OriginalRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CreatedRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AllCreatedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ChangedSurface",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ChangedComponent",
    FontWeight->"Bold"],
  ". ",
  StyleBox["TakeFrom",
    FontWeight->"Bold"],
  " often uses a list of object types. If one of the ",
  StyleBox["objecttypes",
    FontSlant->"Italic"],
  " is a pure ",
  StyleBox["function",
    FontSlant->"Italic"],
  ", it is replaced by ",
  StyleBox["FilterAllCreatedRays",
    FontWeight->"Bold"],
  " and a rule ",
  StyleBox["FilterAllCreatedRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is added inside the ",
  StyleBox["Deflections",
    FontWeight->"Bold"],
  " rule. See also",
  ":",
  " ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionLabel",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AddTo",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ReplaceFor",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Temperature", "Subsection"],

Cell[TextData[{
  StyleBox["Temperature",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that denotes the temperature of a component surface given in degrees \
Celsius.\n\[InvisibleSpace]",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  " is also an option of refractive components and the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " genetic building block. Then, it may depend on surface coordinates and \
overwrites ray options. Note that although ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  " is an option of all refractive components, not all refractive materials \
have temperature",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent properties incorporated into their working model",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TemperatureCoefficientIndex", "Subsection"],

Cell[TextData[{
  StyleBox["TemperatureCoefficientIndex",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["D0",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["D1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["D2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["E0",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["E1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["lTK",
    FontSlant->"Italic"],
  "(",
  StyleBox["nm",
    FontSlant->"Italic"],
  ")",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that gives the list of temperature coefficients \
for a temperature",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent refractive index function of a material."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar1", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar1",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar10", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar10",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar2", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar2",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar3", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar3",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar4", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar4",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar5", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar5",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar6", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar6",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar7", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar7",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar8", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar8",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TempVar9", "Subsection"],

Cell[TextData[{
  StyleBox["TempVar9",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tension", "Subsection"],

Cell[TextData[{
  StyleBox["Tension",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that denotes the tensor of tension at a component surface given in \
Pascal.\n\[InvisibleSpace]",
  StyleBox["Tension",
    FontWeight->"Bold"],
  " is also an option of refractive components and the ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " genetic building block. Then, it may depend on surface coordinates and \
overwrites ray options. Note that although ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  " is an option of all refractive components, not all refractive materials \
have tension",
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent properties incorporated into their working model",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TerminateDeflection", "Subsection"],

Cell[TextData[{
  StyleBox["TerminateDeflection",
    FontWeight->"Bold"],
  " is a placeholder for a boolean variable inside ",
  StyleBox["HeldTraceKernel",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CustomDeflections",
    FontWeight->"Bold"],
  " that indicates whether a cascaded series of ray deflection calculations \
should be prematurely terminated and the remainder of the deflections \
skipped.\n\[InvisibleSpace]",
  StyleBox["TerminateDeflection",
    FontWeight->"Bold"],
  " is automatically set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  " at the start of every new ray deflection calculation. ",
  StyleBox["TerminateDeflection",
    FontWeight->"Bold"],
  " only applies to cascaded deflection operations at a surface and has no \
effect on single surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "deflection calculations",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Subsection"],

Cell[TextData[{
  StyleBox["Theory",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " that describes the theory to be applied during calculations of \
deflections. The value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " is a list of names. The value of the rule is passed to all functions, \
which determine polarization, ray direction and intensity and which are \
called within a ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " names serve as a pattern for calling the appropriate functions during \
calculations. If different theories on both sides of a surface are given, the \
more general is applied (see ",
  StyleBox["$Theory",
    FontWeight->"Bold"],
  ")",
  ". Normally the value of ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " is determined automatically inside the genetic building blocks, but the \
user can force a special theory by passing a ",
  StyleBox["Theory",
    FontWeight->"Bold"],
  " rule as option to a function which generates a component. These functions \
are now used as follows:",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  StyleBox["Refraction",
    FontWeight->"Bold"],
  " with values returned by ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Experienced users can implement a totally new behavior \
for a deflection by giving new theorynames as well as the appropriate \
functions with the new theorynames as part of their signature. The rest of \
the signature must be the same as for the functions already defined. See \
also: ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThermalConductivity", "Subsection"],

Cell[TextData[{
  StyleBox["ThermalConductivity",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["erg",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "(",
  StyleBox["s",
    FontSlant->"Italic"],
  " cm ",
  StyleBox["K",
    FontWeight->"Bold"],
  ")",
  " is a database rule name that specifies the thermal conductivity of a \
material."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThermalExpansion", "Subsection"],

Cell[TextData[{
  StyleBox["ThermalExpansion",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["minimumtemperature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["maximumtemperature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["expansioncoefficient",
    FontSlant->"Italic"],
  StyleBox["},",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that indicates the thermal expansion of a \
material over various temperature ranges in Celsius",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThickLens", "Subsection"],

Cell[TextData[{
  StyleBox["ThickLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["principleplanespacing",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " behaves as an ideal thick lens for two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional, paraxial ray traces by using the ABCD matrix representations \
for a thick lens.\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ThinLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ABCDOptic",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ABCDMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThicknessTolerance", "Subsection"],

Cell[TextData[{
  StyleBox["ThicknessTolerance",
    FontWeight->"Bold"],
  " is a database rule name that specifies the manufacturing center thickness \
tolerances of an optical component expressed in units of either ",
  StyleBox["+-",
    FontWeight->"Bold"],
  " mm or as a percentage of the overall thickness (indicated by a % sign",
  ")",
  ". See also: ",
  StyleBox["DimensionalTolerance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["AngleTolerance",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinBaffle", "Subsection"],

Cell[TextData[{
  StyleBox["ThinBaffle",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["Baffle",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["ThinBeamSplitter",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinLens", "Subsection"],

Cell[TextData[{
  StyleBox["ThinLens[",
    FontWeight->"Bold"],
  StyleBox["focallength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " behaves as an ideal thin lens for two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional, paraxial ray traces by using the ABCD matrix representation \
for a thin lens.\n\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["ThickLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ABCDOptic",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ABCDMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ThinMirror",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["Mirror",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinParabolicMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ThinParabolicMirror",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["ParabolicMirror",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThinSphericalMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ThinSphericalMirror",
    FontWeight->"Bold"],
  " is obsolete. Use ",
  StyleBox["SphericalMirror",
    FontWeight->"Bold"],
  " with no thickness instead",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThresholdIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " that suppresses rays with low intensities. It dictates the value of the \
ray intensity, above which the ray will continue to be propagated and below \
which the ray",
  StyleBox["'",
    FontWeight->"Bold"],
  "s propagation through optical surfaces is terminated.\n\[InvisibleSpace]A \
negative value terminates rays which are below the absolute of the value and \
not zero. Rays behind an absorber are therefore propagated. For selection of \
scout rays, use ",
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TiltGroup", "Subsection"],

Cell[TextData[{
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the rotation of objects. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", all objects passed to ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " are considered to be separate objects. All other values result in moving \
the whole group. ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objectnumber",
    FontSlant->"Italic"],
  " or ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["groupposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["grouprotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can identify the group, otherwise the orientation and position of a group \
is given by its first object. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TiltRelative", "Subsection"],

Cell[TextData[{
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the rotation of objects. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the tilt vector given is relative to the actual object orientation, all \
other values result in a tilt in global coordinates. Independent of ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TiltVector", "Subsection"],

Cell[TextData[{
  StyleBox["TiltVector",
    FontWeight->"Bold"],
  " labels the unit vector that denotes the direction of the ray bundle \
optical axis.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToleranceDoubleClick", "Subsection"],

Cell[TextData[{
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["tol",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " that specifies a tolerance for selecting points with the mouse. \
Neighboring points closer than ",
  StyleBox["tol",
    FontSlant->"Italic"],
  " are shrinked to a single point, mouse double",
  StyleBox["-",
    FontWeight->"Bold"],
  "clicks are suppressed. The ",
  StyleBox["tol",
    FontSlant->"Italic"],
  " is a number or a list of numbers and specifies the tolerance in the \
horizontal and vertical direction of the plot. Positive values are absolute, \
negative are percentages of the overall dimension. Missing values are filled \
with 1 % of the overall dimension.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToleranceSelection", "Subsection"],

Cell[TextData[{
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["tol",
    FontSlant->"Italic"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " that specifies a tolerance for selecting objects with the mouse. The ",
  StyleBox["tol",
    FontSlant->"Italic"],
  " is a number or a list of numbers and specifies the tolerance in the \
horizontal and vertical direction of the plot. Positive values are absolute, \
negative are percentages of the objectdimension. Missing values are filled \
with 2.5 % of the object dimension.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Toluene", "Subsection"],

Cell[TextData[{
  StyleBox["Toluene",
    FontWeight->"Bold"],
  " denotes the use of a toluene liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Toluene",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .43 microns to .66 microns. \
",
  StyleBox["Toluene",
    FontWeight->"Bold"],
  " has a density of 0.86, relative to the density of water",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TopView", "Subsection"],

Cell[TextData[{
  StyleBox["TopView",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " that gives a two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional orthoscopic rendering showing a projection onto the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane of the optical system.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["RealTime3D",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SideView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FrontView",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShadowProject",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Full3D",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToroidalLens", "Subsection"],

Cell[TextData[{
  StyleBox["ToroidalLens[{",
    FontWeight->"Bold"],
  StyleBox["curvature1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conic1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["toroidradius1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture1",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["curvature2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conic2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["toroidradius2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture2",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a double",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaced lens both having aspherical toroidal surfaces.\n\
\[InvisibleSpace]The centerline curvature, conicconstant, and toroidradius \
for a toroidal lens prescription are all required. Optional specifications \
for the aspheric toroidal polynomialcoefficients and an insideaperture to \
each surface may also be given. ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order term. Otherwise, both even and \
odd power terms will be used. ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. (Inspired by William Cottingame, \
UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToroidalLensSurface", "Subsection"],

Cell[TextData[{
  StyleBox["ToroidalLensSurface[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["toroidradius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a lens component that has a toroidal aspheric shape.\n\
\[InvisibleSpace]The centerline ",
  StyleBox["curvature",
    FontSlant->"Italic"],
  ", ",
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["toroidradius",
    FontSlant->"Italic"],
  " for an toroidal lens prescription are all required. Optional \
specifications for the aspheric ",
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  " and ",
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  " to the surface may also be given. ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  " is always used in combination with one or more additional ",
  StyleBox["LensSurface",
    FontWeight->"Bold"],
  " component types to create a complete lens object. ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order. Otherwise, both even and odd \
power terms will be used. ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  " is created with its surface centered about the origin. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. (Inspired by William Cottingame, \
UCLA.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToroidalMirror", "Subsection"],

Cell[TextData[{
  StyleBox["ToroidalMirror[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["toroidradius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ToroidalMirror[{",
    FontWeight->"Bold"],
  StyleBox["curvature",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["toroidradius",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " designates a mirror component that has a toroidal aspheric reflective \
shape.\n\[InvisibleSpace]The centerline ",
  StyleBox["curvature",
    FontSlant->"Italic"],
  ", ",
  StyleBox["conicconstant",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["toroidradius",
    FontSlant->"Italic"],
  " for an toroidal mirror prescription are all required. Optional \
specifications for the aspheric ",
  StyleBox["polynomialcoefficients",
    FontSlant->"Italic"],
  " and ",
  StyleBox["insideaperture",
    FontSlant->"Italic"],
  " to the surface may also be given. The ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " refers to the refractive substrate of the mirror. If no ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " value is given, the component is a single",
  StyleBox["-",
    FontWeight->"Bold"],
  "sided mirror. ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the positive x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may designate a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. ",
  StyleBox["FlatSubstrate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " creates the mirror on a flat",
  StyleBox["-",
    FontWeight->"Bold"],
  "backed substrate. ",
  StyleBox["Hole",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["holeaperture",
    FontSlant->"Italic"],
  " creates hole in the mirror. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ToroidalMirror",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["EvenFunction->True",
    FontWeight->"Bold"],
  " option to indicate the use of even power polynomial terms as \
coefficients, starting with the second order. Otherwise, both even and odd \
power terms will be used. (Inspired by Dave Whiteman, NASA.)\n\
\[InvisibleSpace]The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.\n\[InvisibleSpace]See also: ",
  StyleBox["AsphericLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AsphericMirror",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToroidalLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["AsphericLensSurface",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TracingEngine", "Subsection"],

Cell[TextData[{
  StyleBox["TracingEngine",
    FontWeight->"Bold"],
  " is an option that indicates whether ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " or ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " is used for ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferDeflectionFunction", "Subsection"],

Cell[TextData[{
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " that specifies whether the ",
  StyleBox["DeflectionFunction",
    FontWeight->"Bold"],
  " properties of the donor component are transferred to the recipient \
component. See also",
  ":",
  " ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceBoundary",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferRendering", "Subsection"],

Cell[TextData[{
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " that specifies whether the surface rendering properties of the donor \
component are transferred to the recipient component. See also",
  ":",
  " ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceBoundary",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferSurfaceBoundary", "Subsection"],

Cell[TextData[{
  StyleBox["TransferSurfaceBoundary",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " that specifies whether the surface boundary aperture properties of the \
donor component are transferred to the recipient component. See also",
  ":",
  " ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferSurfaceFunction", "Subsection"],

Cell[TextData[{
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/False",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " that specifies whether the ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " properties of the donor component are transferred to the recipient \
component. See also",
  ":",
  " ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferSurfaceBoundary",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferTraits", "Subsection"],

Cell[TextData[{
  StyleBox["TransferTraits[",
    FontWeight->"Bold"],
  StyleBox["donor",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["recipient",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["opts",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a function that transfers the surface traits of a ",
  StyleBox["donor",
    FontSlant->"Italic"],
  " ",
  StyleBox["component",
    FontSlant->"Italic"],
  " surface into the surfaces (specified by ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  ") of a ",
  StyleBox["recipient",
    FontSlant->"Italic"],
  " ",
  StyleBox["component",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "If the ",
  StyleBox["donor",
    FontSlant->"Italic"],
  " ",
  StyleBox["component",
    FontSlant->"Italic"],
  " contains more than one surface, then only the traits from a single \
surface (specified by ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  ")",
  " will be used. In general, the ",
  StyleBox["surfacenumbers",
    FontSlant->"Italic"],
  " parameter can pass either: a list of integers, ",
  StyleBox["First",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Last",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["All",
    FontWeight->"Bold"],
  " as a setting. ",
  StyleBox["TransferTraits",
    FontWeight->"Bold"],
  " uses the options: ",
  StyleBox["TransferSurfaceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferDeflectionFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransferRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["DonorSurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transform", "Subsection"],

Cell[TextData[{
  StyleBox["Transform",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{Function[",
    FontWeight->"Bold"],
  StyleBox["function",
    FontSlant->"Italic"],
  StyleBox["[#]], ",
    FontWeight->"Bold"],
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["AnalyzeSystem/ShowSystem",
    FontWeight->"Bold"],
  " based on mouse",
  StyleBox["-",
    FontWeight->"Bold"],
  "generated ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " that applies the specified ",
  StyleBox["function",
    FontSlant->"Italic"],
  " to the indicated components and rays.\n\[InvisibleSpace]",
  StyleBox["Transform",
    FontWeight->"Bold"],
  " can work with any genetic",
  StyleBox["-",
    FontWeight->"Bold"],
  "building",
  StyleBox["-",
    FontWeight->"Bold"],
  "block ",
  StyleBox["function",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Move-",
    FontWeight->"Bold"],
  "related ",
  StyleBox["function",
    FontSlant->"Italic"],
  ", or custom",
  StyleBox["-",
    FontWeight->"Bold"],
  "designed ",
  StyleBox["function",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  " uses a list of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  " taken with the mouse from the rendered ",
  "graphics",
  " to indicate the effected objects. Object",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequence positions may also be used to specify objects instead of ",
  StyleBox["coordinatepoints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Transform",
    FontWeight->"Bold"],
  " uses the two",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate system given in ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also: ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceSelection",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ToleranceDoubleClick",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGrid",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnapGridOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Arrange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Copy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constrain",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Snap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Align",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Add",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Swap",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Remove",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Identify",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransformationTemperature", "Subsection"],

Cell[TextData[{
  StyleBox["TransformationTemperature",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["temperature",
    FontSlant->"Italic"],
  " (Celsius",
  ")",
  " is a database rule name for a material that determines the practical \
upper ",
  StyleBox["temperature",
    FontSlant->"Italic"],
  " limit for optics use.\n\[InvisibleSpace]See also: ",
  StyleBox["ViscousTemperature1",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ViscousTemperature1",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Translate", "Subsection"],

Cell[TextData[{
  StyleBox["Translate[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["vectorposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to translate objects.\n\[InvisibleSpace]Here, ",
  StyleBox["vectorposition",
    FontSlant->"Italic"],
  " can be a one, two, or three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional list of numbers. With ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", rendered ",
  "graphics",
  " are also translated. ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " allow positioning relative to the actual object position, ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " affects the whole groups passed to ",
  StyleBox["Translate",
    FontWeight->"Bold"],
  ". Groups are automatically created or can be forced by wrapping a list of \
objects with ",
  StyleBox["Group",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]A component or source may be moved additionally \
symbolically by specifying a list of a nonnumerical quantity and a number for \
each coordinate. Missing symbols are filled with the corresponding numerical \
specification, for example ",
  StyleBox["{{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "10",
  StyleBox["}, ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " to move symbolically ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  " and numerically ",
  StyleBox["{",
    FontWeight->"Bold"],
  "10",
  StyleBox[", ",
    FontWeight->"Bold"],
  "5",
  StyleBox[", ",
    FontWeight->"Bold"],
  "0",
  StyleBox["}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Other related commands used for positioning components \
and rays include: ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  ". See also: ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Translation", "Subsection"],

Cell[TextData[{
  StyleBox["Translation",
    FontWeight->"Bold"],
  " is a label inside ",
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TranslationVector", "Subsection"],

Cell[TextData[{
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  " is a rule that denotes a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional vector for spatial translations invoked on the original \
surface coordinate system by the ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " functions.\n\[InvisibleSpace]Each ",
  StyleBox["SurfaceFunction",
    FontWeight->"Bold"],
  " has a corresponding ",
  StyleBox["TranslationVector",
    FontWeight->"Bold"],
  " listed with it. See also",
  ":",
  " ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission", "Subsection"],

Cell[TextData[{
  StyleBox["Transmission[",
    FontWeight->"Bold"],
  StyleBox["component",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that creates a ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing function to pass rays through optical surfaces while preserving \
ray tilts.\n\[InvisibleSpace]",
  StyleBox["Transmission",
    FontWeight->"Bold"],
  " modifies ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " according to the option ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["#",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Options[Transmission]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransmissionRange", "Subsection"],

Cell[TextData[{
  StyleBox["TransmissionRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["min",
    FontSlant->"Italic"],
  "(",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  ")",
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["max",
    FontSlant->"Italic"],
  "(",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  ")",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that indicates the range of wavelengths for which \
the optical component or material transmits light efficiently.\n\
\[InvisibleSpace]See also: ",
  StyleBox["DiffractionLimitedRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveLengthRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexCoefficients",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmittance", "Subsection"],

Cell[TextData[{
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Transmission",
    FontWeight->"Bold"],
  " that denotes the percent of the incident ray segment intensity that is \
present in a transmitted outgoing ray segment.\n\[InvisibleSpace]",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " usually takes values running between 0 and 100. ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " is also an option used by mirrors, lenses, and beam splitters. In some \
cases, ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " can be a function. In the case of ordinary refractive surfaces, the ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " works in tandom with the ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " option. In this case, for ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["t",
    FontSlant->"Italic"],
  " value (",
  StyleBox["t",
    FontSlant->"Italic"],
  " between 0 ",
  StyleBox["-",
    FontWeight->"Bold"],
  " 100) will automatically generate a transmitted ray that is intensity",
  StyleBox["-",
    FontWeight->"Bold"],
  "scaled by ",
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Bold"],
  "100 and a reflected ray that is scaled by (100",
  StyleBox["-",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  StyleBox["/",
    FontWeight->"Bold"],
  "100 in intensity. By this method, any refractive surface can be made to \
behave as a beamsplitter. However, if a numeric ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value is specified in addition to the ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " value, then each option will determine the intensity of a corresponding \
reflected and transmitted ray.\n\[InvisibleSpace]With components that are \
based on ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  ", however, the form ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["horizontal",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold"],
  StyleBox["vertical",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used to modify the ",
  StyleBox["horizontal",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  " components of polarization in the transmitted ray. ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  " also permits the specification of a ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value (with ",
  StyleBox["SplitRays",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True/Reflection",
    FontWeight->"Bold"],
  ")",
  " but, unlike ",
  StyleBox["Refraction",
    FontWeight->"Bold"],
  ", a value for ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " must always be indicated in addition to any ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " value given. ",
  StyleBox["LinearPolarization",
    FontWeight->"Bold"],
  " permits both ",
  StyleBox["Transmittance",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Reflectance",
    FontWeight->"Bold"],
  " to carry either two ",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "dependent functions or two lists of ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["wavelength",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["transmittance",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " interpolation points."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TriangleNet", "Subsection"],

Cell[TextData[{
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  " uses a triangle",
  StyleBox["-",
    FontWeight->"Bold"],
  "faceted fish",
  StyleBox["-",
    FontWeight->"Bold"],
  "net to approximate an optical surface. This approximation then provides an \
initial ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection point for further numerical minimization according to \
the ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  " setting.\n\[InvisibleSpace]The ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  " setting works in conjunction with the ",
  StyleBox["Interpolation",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["Interpolation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " uses the facet intersection point to approximate the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intersection parameters. ",
  StyleBox["Interpolation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " instead uses the closest triangle vertex in the fish",
  StyleBox["-",
    FontWeight->"Bold"],
  "net. ",
  StyleBox["TriangleNet",
    FontWeight->"Bold"],
  " also works in conjunction with the ",
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  " option (described elsewhere.",
  ")",
  " ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{TriangleNet -> ",
    FontWeight->"Bold"],
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " uses a ",
  StyleBox["surfacefunction",
    FontSlant->"Italic"],
  " that is different from the actual optical surface.\n\[InvisibleSpace]See \
also: ",
  StyleBox["SurfaceApproximation",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfacePoints",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircumscribeBoundary",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceRayIntersections",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboDeflectionID", "Subsection"],

Cell[TextData[{
  StyleBox["TurboDeflectionID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns a unique deflection number within the optical system.\n\
\[InvisibleSpace]The same surface may appear in different positions within \
the list of ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " with different ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " values. All such surfaces share the same deflection",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboDeflectionNumber", "Subsection"],

Cell[TextData[{
  StyleBox["TurboDeflectionNumber",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that designates the slot position of a deflection at a surface.\n\
\[InvisibleSpace]Because each wave front is traced separately in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DeflectionNumber",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboDeflectionNumber",
    FontWeight->"Bold"],
  " can be different. For an ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " bigger than one, an already calculated intersection is reused during the \
calculation",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboModelIntensityID", "Subsection"],

Cell[TextData[{
  StyleBox["TurboModelIntensityID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns a unique intensity model number within the optical system.\n\
\[InvisibleSpace]The same surface may appear in different positions within \
the list of ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " with different ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " values. All such surfaces share the same value for ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboModelPolarizationID", "Subsection"],

Cell[TextData[{
  StyleBox["TurboModelPolarizationID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns a unique polarization model number within the optical \
system.\n\[InvisibleSpace]The same surface may appear in different positions \
within the list of ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " with different ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " values. All such surfaces share the same value for ",
  StyleBox["ModelPolarization",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot", "Subsection"],

Cell[TextData[{
  StyleBox["TurboPlot[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " works with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " to perform accelerated ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing and rendering of a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements.\n\[InvisibleSpace]",
  StyleBox["TurboPlot[",
    FontWeight->"Bold"],
  StyleBox["source",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["tracedsystem",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " can be used to more quickly trace a new light ",
  StyleBox["source",
    FontSlant->"Italic"],
  " through a previously traced optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  " (by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " or ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  ")",
  ". When the default setting of ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Surface",
    FontWeight->"Bold"],
  " with ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  " is used, ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  " displays a spot diagram of the locus of ray intersections on the last \
optical surface in the traced results. However, when other ",
  StyleBox["PlotType",
    FontWeight->"Bold"],
  " settings are specified, all of the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces are displayed in the same fashion as ",
  StyleBox["ShowSystem",
    FontWeight->"Bold"],
  ". ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  " has the same relationship with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " that ",
  StyleBox["DrawSystem",
    FontWeight->"Bold"],
  " does with ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". See also ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboRays", "Subsection"],

Cell[TextData[{
  StyleBox["TurboRays[{",
    FontWeight->"Bold"],
  StyleBox["raysegment1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["raysegment2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["}]",
    FontWeight->"Bold"],
  " gives a collection of ray segment parameters for use with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Within ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ", each raysegment carries parameters that are associated with the \
following ray options: ",
  StyleBox["{RayStart, RayEnd, RotationMatrix, WaveLength, Intensity, \
RayLength, RefractiveIndex, OpticalLength, ComponentNumber, SurfaceNumber, \
SurfaceCoordinates, SourceID, WaveFrontID, RaySourceNumber, RaySlot, \
GenerationNumber, IntersectionNumber, Polarization}",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboRaySelect", "Subsection"],

Cell[TextData[{
  StyleBox["TurboRaySelect[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " takes ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ", or a list with ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " and selects rays similar to ",
  StyleBox["RaySelect",
    FontWeight->"Bold"],
  ". ",
  StyleBox["TurboRaySelect",
    FontWeight->"Bold"],
  " always returns a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object with a single list of rays. Only rules without formulas as ",
  StyleBox["selectionproperties",
    FontSlant->"Italic"],
  " are selected fast. Parts are accessed, for example ",
  StyleBox["RaySourceNumber[[",
    FontWeight->"Bold"],
  "1",
  StyleBox["]]",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  "2",
  StyleBox[", ",
    FontWeight->"Bold"],
  "33",
  StyleBox["}",
    FontWeight->"Bold"],
  ". An ",
  StyleBox["Interval",
    FontWeight->"Bold"],
  " as value is allowed. The whole ",
  StyleBox["RotationMatrix",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RaySourceNumber",
    FontWeight->"Bold"],
  " may not be used for selection.\n\[InvisibleSpace]The rulename WaveFrontId \
and ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  " are treated specially. See also",
  ":",
  " ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ReadTurboRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboRaysFullPartitionedPosition", "Subsection"],

Cell[TextData[{
  StyleBox["TurboRaysFullPartitionedPosition[",
    FontWeight->"Bold"],
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " provides the partitioning of positions for the given ",
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  " within an element of ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TurboRaysPosition",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboRaysFullPosition",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboRaysFullPosition", "Subsection"],

Cell[TextData[{
  StyleBox["TurboRaysFullPosition[",
    FontWeight->"Bold"],
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " provides the sequence of positions for the given ",
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  " within an element of ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TurboRaysPosition",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboRaysFullPartitionedPosition",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboRaysPosition", "Subsection"],

Cell[TextData[{
  StyleBox["TurboRaysPosition[",
    FontWeight->"Bold"],
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " provides the starting and ending positions for a given ",
  StyleBox["rayparameter",
    FontSlant->"Italic"],
  " within an element of ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TurboRaysFullPosition",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboRaysFullPartitionedPosition",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboResonateID", "Subsection"],

Cell[TextData[{
  StyleBox["TurboResonateID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns a unique resonate number within this wave front.\n\
\[InvisibleSpace]It is used to group surfaces to build up resonators",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboSurfaceID", "Subsection"],

Cell[TextData[{
  StyleBox["TurboSurfaceID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " is a rule within ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " that assigns a unique surface number within the optical system.\n\
\[InvisibleSpace]The same surface may appear in different positions within \
the list of ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " with different ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " values. All such surfaces share the same geometry",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboSurfaces", "Subsection"],

Cell[TextData[{
  StyleBox["TurboSurfaces[",
    FontWeight->"Bold"],
  StyleBox["surfacesegment1",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["surfacesegment2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  "...",
  StyleBox["]",
    FontWeight->"Bold"],
  " gives a sequence of collections of surface parameters generated by a ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " is returned by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " when ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " is specified.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboSystem", "Subsection"],

Cell[TextData[{
  StyleBox["TurboSystem[{Source[",
    FontWeight->"Bold"],
  "...",
  StyleBox["]",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["raytracefunction",
    FontSlant->"Italic"],
  StyleBox[", {TurboRays[",
    FontWeight->"Bold"],
  "...",
  StyleBox["]",
    FontWeight->"Bold"],
  "..",
  StyleBox["}, OpticalSystem[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], Options -> ",
    FontWeight->"Bold"],
  StyleBox["sysopts",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is the object given in the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing output from ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]Within ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  ", the first element is given by the original input light sources, the ",
  StyleBox["raytracefunction",
    FontSlant->"Italic"],
  " contains the compiled ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code, the third element contains the final ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace results, and the fourth element contains the reported ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " information from ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboTrace", "Subsection"],

Cell[TextData[{
  StyleBox["TurboTrace[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " produces an accelerated ray trace of a ",
  StyleBox["system",
    FontSlant->"Italic"],
  " of light sources and optical elements.\n\[InvisibleSpace]Whereas ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " executes an interpreted ray trace, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " both compiles and executes purpose",
  StyleBox["-",
    FontWeight->"Bold"],
  "built ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace code that characterizes a particular ",
  StyleBox["system",
    FontSlant->"Italic"],
  ". When ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " is called for the first time with an untraced optical ",
  StyleBox["system",
    FontSlant->"Italic"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " first constructs a ",
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox["-",
    FontWeight->"Bold"],
  "specific, compiled function (",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ") that can be returned either directly without execution or embedded \
within a traced, ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object. Any subsequent call made to ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " with a previously",
  StyleBox["-",
    FontWeight->"Bold"],
  "created, ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object is then executed at a greatly accelerated speed. This is \
particularly useful when iterative traces are invoked with changed parameter \
values (see ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  "). When called for the first time, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to determine both the construction and format of the new ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace code. With either ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " or ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " constructs the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace code from scout",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced information (via ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ") of the chief rays (constructed according to the ",
  StyleBox["ScoutRays",
    FontWeight->"Bold"],
  " option) passing through the optical surfaces in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  ". In this case, optical surfaces that do not intercept the scout trace are \
not included in final ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code. With ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the compiled ray trace sequentially follows the surfaces in the same \
order as the scout trace. However, with ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", the surfaces are still traced sequentially between distinct ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects but are non",
  StyleBox["-",
    FontWeight->"Bold"],
  "sequentially traced within those ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " surface",
  StyleBox["-",
    FontWeight->"Bold"],
  "groupings that have the ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " attribute (",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  "). When ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is used or ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is used without a ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " specification (",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  "), no scout trace is performed and all optical surfaces are included in \
the compiled ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " source code. In this case, the trace follows the component order \
specified in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " input parameter.\n\[InvisibleSpace]Unlike ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " can utilize one or more user",
  StyleBox["-",
    FontWeight->"Bold"],
  "defined symbolic parameters in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " input. When one or more symbolic parameters are present, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " uses these as input parameters for the compiled ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "trace code (",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  "). Then, subsequent calls to ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " with newly",
  StyleBox["-",
    FontWeight->"Bold"],
  "assigned numeric values to such parameters (via ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  ") enables high",
  StyleBox["-",
    FontWeight->"Bold"],
  "speed, iterative ray traces.\n\[InvisibleSpace]The final output of ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " depends on the value of the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " option as well as the contents of the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " input parameter. With ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Automatic/TurboSystem/Numeric",
    FontWeight->"Bold"],
  " and both a light source and one or more optical elements being present, \
",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " both constructs and executes a compiled ray trace of the ",
  StyleBox["system",
    FontSlant->"Italic"],
  ". In this case, the ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " is returned embedded within a ",
  StyleBox["TurboSystem",
    FontWeight->"Bold"],
  " object that also contains the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "traced results. However, with ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " or if a light source is not present in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " specification, the result is compiled and returned without execution. \
With ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Numeric",
    FontWeight->"Bold"],
  ", all symbolic parameters are ignored and a numeric trace of the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " is executed. Finally, a few advanced built",
  StyleBox["-",
    FontWeight->"Bold"],
  "in functions call ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["OutputType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " setting. In this case, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["TurboSurfaces",
    FontWeight->"Bold"],
  " object (without compiling a ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ").\n\[InvisibleSpace]",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  " parameter to determine which ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "surface intercepts will be returned in the traced results. In its default \
(",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Last",
    FontWeight->"Bold"],
  ") setting, only the intercept information on last surface in the ",
  StyleBox["system",
    FontSlant->"Italic"],
  " is returned by ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace] ",
  StyleBox["In",
    FontWeight->"Bold"],
  " addition to the standard input format, ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " accepts two additional input formats: ",
  StyleBox["TurboTrace[",
    FontWeight->"Bold"],
  StyleBox["system",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["reportedparameters",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TurboTrace[",
    FontWeight->"Bold"],
  StyleBox["newsources",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["tracedsystem",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  ". Here, ",
  StyleBox["reportedparameters",
    FontSlant->"Italic"],
  " is internally passed to the ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " option and ",
  StyleBox["newsources",
    FontSlant->"Italic"],
  " is internally passed to the ",
  StyleBox["NewSources",
    FontWeight->"Bold"],
  " option. (See ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NewSources",
    FontWeight->"Bold"],
  " for further information.",
  ")",
  "\n\[InvisibleSpace]See also: ",
  StyleBox["TurboPlot",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SequentialTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ScoutTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicValues",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FilterTrace",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedParameters",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ReportedSurfaces",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["NewSources",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Turpentine", "Subsection"],

Cell[TextData[{
  StyleBox["Turpentine",
    FontWeight->"Bold"],
  " designates the use of a turpentine liquid medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Turpentine",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .4 microns to .66 microns. \
",
  StyleBox["Turpentine",
    FontWeight->"Bold"],
  " has a density of 0.87, relative to the density of water",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV1", "Subsection"],

Cell[TextData[{
  StyleBox["TV1",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV10", "Subsection"],

Cell[TextData[{
  StyleBox["TV10",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV2", "Subsection"],

Cell[TextData[{
  StyleBox["TV2",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV3", "Subsection"],

Cell[TextData[{
  StyleBox["TV3",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV4", "Subsection"],

Cell[TextData[{
  StyleBox["TV4",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV5", "Subsection"],

Cell[TextData[{
  StyleBox["TV5",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV6", "Subsection"],

Cell[TextData[{
  StyleBox["TV6",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV7", "Subsection"],

Cell[TextData[{
  StyleBox["TV7",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV8", "Subsection"],

Cell[TextData[{
  StyleBox["TV8",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TV9", "Subsection"],

Cell[TextData[{
  StyleBox["TV9",
    FontWeight->"Bold"],
  " is a publicly",
  StyleBox["-",
    FontWeight->"Bold"],
  "visible, temporary variable used in some ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TwistAngle", "Subsection"],

Cell[TextData[{
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " is an option that relates to an amount of rotation around an axis, given \
in degrees.\n\[InvisibleSpace]",
  StyleBox["TwistAngle",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["Rotate",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveLinear",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveDirected",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["MoveReflected",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TwistGroup", "Subsection"],

Cell[TextData[{
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the twisting of objects. For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", all objects passed to ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " are considered to be separate objects. All other values result in moving \
the whole group. ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. ",
  StyleBox["Group",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["objectnumber",
    FontSlant->"Italic"],
  " or ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["groupposition",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["grouprotationmatrix",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " can identify the group, otherwise the orientation and position of a group \
is given by its first object. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TwistRelative", "Subsection"],

Cell[TextData[{
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Move",
    FontWeight->"Bold"],
  " that controls the twisting of objects. For ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the twist is relative to the actual object orientation, all other values \
result in an absolute twist. Independent of ",
  StyleBox["TwistRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " in an optical system resets all rays to their sources and the rendering \
of components is deleted. See also",
  ":",
  " ",
  StyleBox["Move",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MoveGraphicalOutput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltRelative",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PositionGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TiltGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwistGroup",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ultran30", "Subsection"],

Cell[TextData[{
  StyleBox["Ultran30",
    FontWeight->"Bold"],
  " specifies the use of the ",
  StyleBox["Ultran30",
    FontWeight->"Bold"],
  " glass medium.\n\[InvisibleSpace]",
  StyleBox["Ultran30",
    FontWeight->"Bold"],
  " is a UV",
  StyleBox["-",
    FontWeight->"Bold"],
  "transparent glass produced by Schott",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UncompiledMaterialSpecification", "Subsection"],

Cell[TextData[{
  StyleBox["UncompiledMaterialSpecification",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GetMaterialRules",
    FontWeight->"Bold"],
  ", which describes the material, which may depend on ",
  StyleBox["SurfaceCoordinates",
    FontWeight->"Bold"],
  ". The result is a list with ",
  StyleBox["Temperature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Tension",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MaterialRotationMatrix",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unconfine", "Subsection"],

Cell[TextData[{
  StyleBox["Unconfine[",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a generic building block that takes one or more ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects and creates a single ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " object that allows rays to enter the component through any surface.\n\
\[InvisibleSpace]",
  StyleBox["Unconfine",
    FontWeight->"Bold"],
  " passes ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["BuildComponent",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["Resonate",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Confine",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnconfinedIncrement", "Subsection"],

Cell[TextData[{
  StyleBox["UnconfinedIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that gives the rate of ",
  StyleBox["increment",
    FontSlant->"Italic"],
  " used to step through the unconfined migration path.\n\[InvisibleSpace]",
  StyleBox["UnconfinedIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["+",
    FontWeight->"Bold"],
  "1 increments ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  " by 1, while ",
  StyleBox["UnconfinedIncrement",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1 increments ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  " by ",
  StyleBox["-",
    FontWeight->"Bold"],
  "1. See also",
  ":",
  " ",
  StyleBox["SurfaceIncrement",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnconfinedPath", "Subsection"],

Cell[TextData[{
  StyleBox["UnconfinedPath",
    FontWeight->"Bold"],
  " is a ray parameter that gives the slot positions for entrance surfaces \
within ",
  StyleBox["ConfinedPaths",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["UnconfinedPath",
    FontWeight->"Bold"],
  " is determined dynamically during the ray",
  StyleBox["-",
    FontWeight->"Bold"],
  "tracing operation and is updated each time ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " is incremented to a new component. See also",
  ":",
  " ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnconfinedPosition", "Subsection"],

Cell[TextData[{
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that specifies the present slot position used within the ",
  StyleBox["UnconfinedPath",
    FontWeight->"Bold"],
  " parameter stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]",
  StyleBox["SurfaceNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComponentNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["UnconfinedPosition",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionNumber",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GenerationNumber",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ConfinedNumber",
    FontWeight->"Bold"],
  " are all pointer parameters stored in ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnpropagatedOpticalSystem", "Subsection"],

Cell[TextData[{
  StyleBox["UnpropagatedOpticalSystem[{",
    FontWeight->"Bold"],
  StyleBox["listofrays",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofsources",
    FontSlant->"Italic"],
  StyleBox["}, {",
    FontWeight->"Bold"],
  StyleBox["listofcomponents",
    FontSlant->"Italic"],
  StyleBox["}, GraphicalOutput[",
    FontWeight->"Bold"],
  "...",
  StyleBox["], Options->",
    FontWeight->"Bold"],
  StyleBox["opts",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is an object containing an ordered listing of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects, ",
  StyleBox["Component",
    FontWeight->"Bold"],
  " objects, and ",
  StyleBox["GraphicalOutput",
    FontWeight->"Bold"],
  ". The tracing information is NOT valid",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["V1H1", "Subsection"],

Cell[TextData[{
  StyleBox["V1H1",
    FontWeight->"Bold"],
  " is a database rule name that specifies the distance between the front \
surface vertex and the front principle plane of a lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["V2H2", "Subsection"],

Cell[TextData[{
  StyleBox["V2H2",
    FontWeight->"Bold"],
  " is a database rule name that specifies the distance between the back \
surface vertex and the back principle plane of a lens system",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vacuum", "Subsection"],

Cell[TextData[{
  StyleBox["Vacuum",
    FontWeight->"Bold"],
  " specifies the use of a vacuum medium (i.e., refractive index ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 1.0",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VacuumFrequency", "Subsection"],

Cell[TextData[{
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " that indicates that the grating frequency parameters are listed with \
their free space values.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["VacuumFrequency",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " denotes that the grating values are for the residing optical material. \
See also",
  ":",
  " ",
  StyleBox["Diffraction",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Grating",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Values", "Subsection"],

Cell[TextData[{
  StyleBox["Values",
    FontWeight->"Bold"],
  " is a label inside ",
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VerticalSymmetry", "Subsection"],

Cell[TextData[{
  StyleBox["VerticalSymmetry",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  " that implies that the surface grooves are symmetric about the component",
  StyleBox["'",
    FontWeight->"Bold"],
  "s horizontal axis.\n\[InvisibleSpace]See ",
  StyleBox["FresnelSymmetry",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ViscousTemperature1", "Subsection"],

Cell[TextData[{
  StyleBox["ViscousTemperature1",
    FontWeight->"Bold"],
  " is a database rule name for a material that indicates the temperature \
(Celsius",
  ")",
  " at which viscosity ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 10",
  StyleBox["^",
    FontWeight->"Bold"],
  "13 dPa",
  StyleBox["*",
    FontWeight->"Bold"],
  "s.\n\[InvisibleSpace]This value appears important for annealing",
  StyleBox["-",
    FontWeight->"Bold"],
  "like manufacturing processes. See also: ",
  StyleBox["TransformationTemperature",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ViscousTemperature2",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ViscousTemperature2", "Subsection"],

Cell[TextData[{
  StyleBox["ViscousTemperature2",
    FontWeight->"Bold"],
  " is a database rule name for a material that indicates the temperature \
(Celsius) at which viscosity ",
  StyleBox["=",
    FontWeight->"Bold"],
  " 10",
  StyleBox["^",
    FontWeight->"Bold"],
  "(7.6",
  ")",
  " dPa",
  StyleBox["*",
    FontWeight->"Bold"],
  "s.\n\[InvisibleSpace]Glass is soft here",
  StyleBox["!",
    FontWeight->"Bold"],
  " See also: ",
  StyleBox["TransformationTemperature",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ViscousTemperature1",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaistDistance", "Subsection"],

Cell[TextData[{
  StyleBox["WaistDistance",
    FontWeight->"Bold"],
  " is a rule returned by ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  " that designates the axial distance of the particular measurement position \
to the minimum Gaussian beam waist position.\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["BeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamWaist",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicWaistDistance",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamSpotSize",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamCurvature",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamDivergence",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SymbolicBeamScaleLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ComplexBeamParameter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SymbolicComplexBeamParameter",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Water", "Subsection"],

Cell[TextData[{
  StyleBox["Water",
    FontWeight->"Bold"],
  " denotes the use of a water medium at 20 degrees Celsius.\n\
\[InvisibleSpace]The refractive index model for ",
  StyleBox["Water",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .4 microns to .66 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveFrontFlatness", "Subsection"],

Cell[TextData[{
  StyleBox["WaveFrontFlatness",
    FontWeight->"Bold"],
  " is a database rule name that specifies the accuracy, in wavelengths, of \
an optical surface. Unless denoted otherwise, ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  " is normally based on 0.633 microns wavelength. In addition to ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveFrontFlatness",
    FontWeight->"Bold"],
  " is particularly important as a selection criteria for mirrors. See also",
  ":",
  " ",
  StyleBox["SurfaceCoating",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SurfaceAccuracy",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveFrontFlatness",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveFrontID", "Subsection"],

Cell[TextData[{
  StyleBox["WaveFrontID",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that labels rays uniquely that belong to the same wave front.\n\
\[InvisibleSpace]As an option to ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveFrontID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["False",
    FontWeight->"Bold"],
  " suppresses the labelling. Internally, ",
  StyleBox["SourceID",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$ModuleNumber",
    FontWeight->"Bold"],
  " and the slot position of a ray in the list returned by a deflection are \
used to create a unique identification. The genetics option ",
  StyleBox["IndependentScattering",
    FontWeight->"Bold"],
  " controls what is to be considered a wave front. Some genetics may take \
the option ",
  StyleBox["WaveFrontID",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["NewRay",
    FontWeight->"Bold"],
  " to force the generation of a new wave front, for example in beam \
splitters",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveLength", "Subsection"],

Cell[TextData[{
  StyleBox["WaveLength",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that describes the ray",
  StyleBox["'",
    FontWeight->"Bold"],
  "s optical wavelength (in microns",
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveLengthRange", "Subsection"],

Cell[TextData[{
  StyleBox["WaveLengthRange",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["min",
    FontSlant->"Italic"],
  "(",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  ")",
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["max",
    FontSlant->"Italic"],
  "(",
  StyleBox["wavelength",
    FontSlant->"Italic"],
  ")",
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that indicates the valid range of wavelengths for \
optimal performance.\n\[InvisibleSpace]",
  StyleBox["WaveLengthRange",
    FontWeight->"Bold"],
  " may imply a naturally occurring performance range for an optical \
component or it can imply an artificially occurring performance range for an \
optical model. See also: ",
  StyleBox["DiffractionLimitedRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TransmissionRange",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IndexCoefficients",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SellmeierFunction",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["HerzbergerFunction",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveTilt", "Subsection"],

Cell[TextData[{
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  " is a rule of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that is a three",
  StyleBox["-",
    FontWeight->"Bold"],
  "dimensional coordinate that designates the direction in which the complex \
phase of the ray segment is pointing in space. For dielectrics it is the same \
as ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ". The option is unauthorized and not part of ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WaveTiltUpdate", "Subsection"],

Cell[TextData[{
  StyleBox["WaveTiltUpdate",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["oldindex",
    FontSlant->"Italic"],
  " or ",
  StyleBox["False",
    FontWeight->"Bold"],
  " is an internally used flag of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " that designates a valid ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  ". For ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WaveTilt",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PhaseTilt",
    FontWeight->"Bold"],
  " are assumed to be identical to ",
  StyleBox["RayTilt",
    FontWeight->"Bold"],
  ". The option is unauthorized and not part of ",
  StyleBox["Options[Ray]",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WedgeBeamSplitter", "Subsection"],

Cell[TextData[{
  StyleBox["WedgeBeamSplitter[{",
    FontWeight->"Bold"],
  StyleBox["percentreflected",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["percenttransmitted",
    FontSlant->"Italic"],
  StyleBox["}, ",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a wedge",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped beam",
  StyleBox["-",
    FontWeight->"Bold"],
  "splitter element.\n\[InvisibleSpace]",
  StyleBox["WedgeBeamSplitter",
    FontWeight->"Bold"],
  " is created with the first reflective surface centered vertically about \
the origin and its second surface positioned down the positive x axis with a \
tilt in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y direction. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness->True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSplitterCube",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BeamSplitter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConjugateBeamSplitter",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WedgeOfRays", "Subsection"],

Cell[TextData[{
  StyleBox["WedgeOfRays[",
    FontWeight->"Bold"],
  StyleBox["seed",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["spread",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " initializes a set of rays in the x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y plane that fan out with their chief direction oriented down the positive \
x",
  StyleBox["-",
    FontWeight->"Bold"],
  "axis (for the default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting",
  ")",
  " and are distributed across the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "coordinate with the specified fan ",
  StyleBox["spread",
    FontSlant->"Italic"],
  ".",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter is taken as the full fan angle, in degrees units, for the \
default ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " setting of ",
  StyleBox["Automatic",
    FontWeight->"Bold"],
  ". However, for other ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " settings, the ",
  StyleBox["spread",
    FontSlant->"Italic"],
  " parameter specifies the intercept spatial dimensions, at the y",
  StyleBox["-",
    FontWeight->"Bold"],
  "z plane, of the ray set.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "The ",
  StyleBox["seed",
    FontSlant->"Italic"],
  " parameter is optional and is used to generate more elaborate ray \
patterns. When it is present, it specifies additional light sources to be \
nested with the basic ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  " result. When ",
  StyleBox["PropagateSystem",
    FontWeight->"Bold"],
  " is used for the ray trace, ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  " produces a set of ",
  StyleBox["Ray",
    FontWeight->"Bold"],
  " objects. However, with ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " calculations, a ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object is generated from ",
  StyleBox["WedgeOfRays",
    FontWeight->"Bold"],
  " instead. The distribution of rays is controlled by the ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  " option and the starting origin is defined by the ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  " option.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["NumberOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MonteCarlo",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridSpacing",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceFraction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SourceOffset",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BirthPoint",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SingleRay",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CircleOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ConeOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LineOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GridOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CustomRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FieldOfRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussianBeam",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RainbowOfRays",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WedgePrism", "Subsection"],

Cell[TextData[{
  StyleBox["WedgePrism[",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " indicates a wedge",
  StyleBox["-",
    FontWeight->"Bold"],
  "shaped beamsteering prism element.\n\[InvisibleSpace]",
  StyleBox["WedgePrism",
    FontWeight->"Bold"],
  " is created with the first surface centered vertically about the origin \
and its second surface positioned down the positive x axis with a tilt in the \
x",
  StyleBox["-",
    FontWeight->"Bold"],
  "y direction. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " argument may denote a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. Depending on the ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " option setting, the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter may denote either the small edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " or the center ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " of the component. With ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " parameter is taken for the edge ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ". The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also: ",
  StyleBox["InputEdgeThickness",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WedgeBeamSplitter",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Prism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DovePrism",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PentaPrism",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["RhomboidPrism",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WeightedSpotSize", "Subsection"],

Cell[TextData[{
  StyleBox["WeightedSpotSize",
    FontWeight->"Bold"],
  " labels the weighted \"diameter\" of a circle that encloses the locus of \
ray",
  StyleBox["/",
    FontWeight->"Bold"],
  "surface intersections on a given planar surface. This diameter is the \
figure to be minimized to find the focus.\n\[InvisibleSpace]For ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["FocusDiameter",
    FontWeight->"Bold"],
  ", the only choice of ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  ", the circle is determined by the two most distant weighted rays, for ",
  StyleBox["FocusRadius",
    FontWeight->"Bold"],
  " the circle center is the mean of the weighted rays and its radius is \
given by the weighted ray most distant from the circle center. An ",
  StyleBox["RMSFocus",
    FontWeight->"Bold"],
  " defines the circle diameter as the second momentum of the weighted rays.\n\
\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["WeightingFunction",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindSpotSize",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WeightingFunction", "Subsection"],

Cell[TextData[{
  StyleBox["WeightingFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["Intensity",
    FontWeight->"Bold"],
  " is an option of ",
  StyleBox["FindFocus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindFocusFast",
    FontWeight->"Bold"],
  " that specifies that each ray is weighted with the given property before \
calculating the focus. To obtain a geometrical focus, set ",
  StyleBox["WeightingFunction",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " 1. The value may also be a formula as in ",
  StyleBox["ReadRays",
    FontWeight->"Bold"],
  ". This option is independent of ",
  StyleBox["FocusType",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Window", "Subsection"],

Cell[TextData[{
  StyleBox["Window[",
    FontWeight->"Bold"],
  StyleBox["aperture",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " refers to a planar, refractive component that has a specified ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["Window",
    FontWeight->"Bold"],
  " is created with its first surface centered about the origin and its \
second surface positioned down the x axis. The ",
  StyleBox["aperture",
    FontSlant->"Italic"],
  " parameter may specify a circle, rectangle, or polygon depending on the \
number and type of elements listed by it. The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WindowParameters", "Subsection"],

Cell[TextData[{
  StyleBox["WindowParameters",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["thickness",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["opticalmaterial",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is a database rule name that specifies the ",
  StyleBox["thickness",
    FontSlant->"Italic"],
  " and ",
  StyleBox["opticalmaterial",
    FontSlant->"Italic"],
  " of a optical window.\n\[InvisibleSpace]",
  StyleBox["WindowParameters",
    FontWeight->"Bold"],
  " is usually included in a lens data to describe a specific window to \
accompany the lens. ",
  StyleBox["WindowParameters",
    FontWeight->"Bold"],
  " can be used together with the ",
  StyleBox["Window",
    FontWeight->"Bold"],
  " function to model an optical window in front of the lens. In such cases, \
the ",
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  " rule of the lens data is used to get the aperture dimensions for the \
window. See also",
  ":",
  " ",
  StyleBox["ClearAperture",
    FontWeight->"Bold"],
  " and ",
  StyleBox["WorkingDistance",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WinstonConeMirror", "Subsection"],

Cell[TextData[{
  StyleBox["WinstonConeMirror[",
    FontWeight->"Bold"],
  StyleBox["entrancediameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["exitdiameter",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["length",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["label",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is a function which models a Winston cone light collector.\n\
\[InvisibleSpace]",
  StyleBox["WinstonConeMirror",
    FontWeight->"Bold"],
  " is used in light gathering applications. (This is an experimental \
component contributed by Robert Rieben, UCR.) The user",
  StyleBox["-",
    FontWeight->"Bold"],
  "named ",
  StyleBox["label",
    FontSlant->"Italic"],
  " parameter is optional and can be omitted. When it is present, its text \
content is used to identify the object in both the rendered graphics and the \
output cell expression. When it is omitted, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses the default setting of the ",
  StyleBox["Labels",
    FontWeight->"Bold"],
  " option with the rendered graphics.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "See also ",
  StyleBox["DTIRCLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DTIRCLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLens",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FunnelLensSurface",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SnowConeLens",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["SquareConeMirror",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wire", "Subsection"],

Cell[TextData[{
  StyleBox["Wire",
    FontWeight->"Bold"],
  " is a value of ",
  StyleBox["GraphicDesign",
    FontWeight->"Bold"],
  ".\n\[InvisibleSpace]See also",
  ":",
  " ",
  StyleBox["SurfaceRendering",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EdgeRendering",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CrossRendering",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WorkingDistance", "Subsection"],

Cell[TextData[{
  StyleBox["WorkingDistance",
    FontWeight->"Bold"],
  " is a database rule name for a lens that specifies the distance between \
the front focal point and the front lens surface.\n\[InvisibleSpace]",
  StyleBox["WorkingDistance",
    FontWeight->"Bold"],
  " is nearly equivalent to ",
  StyleBox["FrontFocalLength",
    FontWeight->"Bold"],
  " except that ",
  StyleBox["WorkingDistance",
    FontWeight->"Bold"],
  " may also include the effects of an optical window in some cases. ",
  StyleBox["WorkingDistance",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontWeight->"Bold"],
  StyleBox["imagedistance",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["objectdistance",
    FontSlant->"Italic"],
  StyleBox["}",
    FontWeight->"Bold"],
  " is used with finite",
  StyleBox["-",
    FontWeight->"Bold"],
  "conjugate lens systems. See also",
  ":",
  " ",
  StyleBox["FrontFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["BackFocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["FocalLength",
    FontWeight->"Bold"],
  ", ",
  StyleBox["WindowParameters",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CatalogFocalLength",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZemaxToData", "Subsection"],

Cell[TextData[{
  StyleBox["ZemaxToData[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import Zemax lens data into Optica",
  StyleBox["'",
    FontWeight->"Bold"],
  "s database format.\n\[InvisibleSpace]",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  " requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished either by opening the Zemax data file inside Mathematica or by \
manually copying and pasting the relevant data into an existing Mathematica \
notebook and, as a final last step, creating a string object by manually \
placing double",
  StyleBox["-",
    FontWeight->"Bold"],
  "quotation marks on either side of the data. ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  " then converts this string information into a rule",
  StyleBox["-",
    FontWeight->"Bold"],
  "based, list format that is recognized by Mathematica. The translation \
process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  " (that get passed internally to ",
  StyleBox["StringReplace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  "). Once converted, the new information can be edited further with ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  ", saved to disk with ",
  StyleBox["SaveData",
    FontWeight->"Bold"],
  ", and converted to optical component models with ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  " is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. Zemax is a Trademark of Focus Software, Inc., \
Tucson, AZ. See also: ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KDPTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVToData",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["CodeVTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZemaxToOptica", "Subsection"],

Cell[TextData[{
  StyleBox["ZemaxToOptica",
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["stringdata",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " is used to import and convert Zemax refractive lens data into one or more \
optical lens models for ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".\n\[InvisibleSpace]",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "requires that the ",
  StyleBox["stringdata",
    FontSlant->"Italic"],
  " for import be given in a single ascii string. Usually, this operation is \
accomplished either by opening the Zemax data file inside Mathematica or by \
manually copying and pasting the relevant data into an existing Mathematica \
notebook and, as a final last step, creating a string object by manually \
placing double",
  StyleBox["-",
    FontWeight->"Bold"],
  "quotation marks on either side of the data. ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "then converts this string information into one or more optical lens models \
that work with ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". The conversion process can be further modified by giving additional ",
  StyleBox["options",
    FontSlant->"Italic"],
  " to ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "(that get passed internally to ",
  StyleBox["StringReplace",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EditData",
    FontWeight->"Bold"],
  "). ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "makes internal calls to ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DataTo",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  ". ",
  StyleBox["ZemaxTo",
    FontWeight->"Bold"],
  StyleBox["Optica ",
    FontWeight->"Bold"],
  "is presently restricted to lens data that describe centered, refractive, \
spherical, multiple lens",
  StyleBox["-",
    FontWeight->"Bold"],
  "surfaces with field stops. Zemax is a Trademark of Focus Software, Inc., \
Tucson, AZ. See also: ",
  StyleBox["ZemaxToData",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DataToOptica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ExcelToOptica",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CodeVToOptica",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["KDPToOptica",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZincSelenide", "Subsection"],

Cell[TextData[{
  StyleBox["ZincSelenide",
    FontWeight->"Bold"],
  " denotes the use of a zinc selenide medium.\n\[InvisibleSpace]The \
refractive index model for ",
  StyleBox["ZincSelenide",
    FontWeight->"Bold"],
  " is most suitable for the wavelength range of .5 microns to 10.6 microns",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$CompiledDiffractionList", "Subsection"],

Cell[TextData[{
  StyleBox["$CompiledDiffractionList",
    FontWeight->"Bold"],
  " is a list of functionnames used for labelling compiled grating modulation \
models. To reduce memory needs of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " you can apply ",
  StyleBox["Clear",
    FontWeight->"Bold"],
  " to symbols inside the list no longer used, do not remove the entries \
themselves. During creation of components some models are compiled to \
increase speed. ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " reuses precompiled symbols, if possible."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$CompiledModelsList", "Subsection"],

Cell[TextData[{
  StyleBox["$CompiledModelsList",
    FontWeight->"Bold"],
  " is a list of functionnames used for labelling compiled material models. \
To reduce memory needs of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " you can apply ",
  StyleBox["Clear",
    FontWeight->"Bold"],
  " to symbols inside the list no longer used, do not remove the entries \
themselves. During creation of components some material models are compiled \
to increase speed. ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " reuses precompiled symbols, if possible."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$generationlimit", "Subsection"],

Cell[TextData[{
  StyleBox["$generationlimit",
    FontWeight->"Bold"],
  " is an input parameter of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " for ",
  StyleBox["GenerationLimit",
    FontWeight->"Bold"],
  " information. See also",
  ":",
  " ",
  StyleBox["EmbedGenerationLimit",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$inputrays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["$thresholdintensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$IndicesIntrinsicName", "Subsection"],

Cell[TextData[{
  StyleBox["$IndicesIntrinsicName",
    FontWeight->"Bold"],
  " is a string that is prepended to the functionname of refractive indices \
of the intrinsic medium",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$inputrays", "Subsection"],

Cell[TextData[{
  StyleBox["$inputrays",
    FontWeight->"Bold"],
  " is an input parameter of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " for geometric ray information. See also",
  ":",
  " ",
  StyleBox["EmbedRays",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$thresholdintensity",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["$generationlimit",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$MaterialList", "Subsection"],

Cell[TextData[{
  StyleBox["$MaterialList",
    FontWeight->"Bold"],
  " is a list of material names that was generated by a call to ",
  StyleBox["SymbolHandling",
    FontWeight->"Bold"],
  " with ",
  StyleBox["ComponentMedium",
    FontWeight->"Bold"],
  " as first parameter",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$ModelIntensity", "Subsection"],

Cell[TextData[{
  StyleBox["$ModelIntensity",
    FontWeight->"Bold"],
  " is the general function to model an intensity. It takes the imaginary \
part of the projection of the phase propagation onto the ray to calculate the \
loss in the material. See also",
  ":",
  " ",
  StyleBox["ModelIntensity",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaCoatings", "Subsection"],

Cell[TextData[{
  StyleBox["$",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Coatings",
    FontWeight->"Bold"],
  " is the coatings catalog directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaContext", "Subsection"],

Cell[TextData[{
  StyleBox["$",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Context",
    FontWeight->"Bold"],
  " is the public context of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaData", "Subsection"],

Cell[TextData[{
  StyleBox["$",
    FontWeight->"Bold"],
  "Optica",
  StyleBox["Data",
    FontWeight->"Bold"],
  " is the catalogs directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". It contains subdirectories with catalog files."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaDeveloperContexts", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["DeveloperContexts",
    FontWeight->"Bold"],
  " is a list of contexts with Optica tools. The tools do not depend on ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", but ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " depends on them. See also: Optica",
  StyleBox["Developer",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaElements", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Elements",
    FontWeight->"Bold"],
  " is the elements catalog directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaHome", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Home",
    FontWeight->"Bold"],
  " is the home directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaMainFile", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["MainFile",
    FontWeight->"Bold"],
  " is the filename of the central file of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaMaterials", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Materials",
    FontWeight->"Bold"],
  " is the materials catalog directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaMessageFile", "Subsection"],

Cell[TextData[{
  "If ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " uses a message file, the location stored in ",
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["MessageFile",
    FontWeight->"Bold"],
  " is taken."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaPalette", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Palette",
    FontWeight->"Bold"],
  " is the filename of the loading palette of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaPaletteName", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["PaletteName",
    FontWeight->"Bold"],
  " is the filename with path of the loading palette of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaPalettes", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Palettes",
    FontWeight->"Bold"],
  " is the palettes directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaPrivateContext", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["PrivateContext",
    FontWeight->"Bold"],
  " is the private context of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaSources", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Sources",
    FontWeight->"Bold"],
  " is the sources catalog directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaTemplates", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["Templates",
    FontWeight->"Bold"],
  " is the template directory of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaUserContext", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["UserContext",
    FontWeight->"Bold"],
  " is the public context of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " for files provided by a user."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$OpticaUserPrivateContext", "Subsection"],

Cell[TextData[{
  StyleBox["$Optica",
    FontWeight->"Bold"],
  StyleBox["UserPrivateContext",
    FontWeight->"Bold"],
  " is the private context of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " for files provided by a user."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$SurfacePlotValues", "Subsection"],

Cell[TextData[{
  StyleBox["$SurfacePlotValues",
    FontWeight->"Bold"],
  " stores the last array of numbers generated to produce a surface plot by \
",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  ". See also",
  ":",
  " ",
  StyleBox["ShowValue",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ShowSurfacePlot",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$SystemSymbolsInOptica", "Subsection"],

Cell[TextData[{
  StyleBox["$SystemSymbolsIn",
    FontWeight->"Bold"],
  StyleBox["Optica",
    FontWeight->"Bold"],
  " is a list of symbols in the System context, used specially or modified in \
",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$Theory", "Subsection"],

Cell[TextData[{
  StyleBox["$Theory",
    FontWeight->"Bold"],
  " is a list of 2 lists of values ",
  StyleBox["ModelRefractionTheory",
    FontWeight->"Bold"],
  " returns. The first list is the general theory, the second designate the \
material character. The elements in the list are ordered from the most \
special to the most general case",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$thresholdintensity", "Subsection"],

Cell[TextData[{
  StyleBox["$thresholdintensity",
    FontWeight->"Bold"],
  " is an input parameter of ",
  StyleBox["RayTraceFunction",
    FontWeight->"Bold"],
  " for ",
  StyleBox["ThresholdIntensity",
    FontWeight->"Bold"],
  " information. See also",
  ":",
  " ",
  StyleBox["EmbedThresholdIntensity",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$inputrays",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["$generationlimit",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$TurboRaysRuleNames", "Subsection"],

Cell[TextData[{
  StyleBox["$TurboRaysRuleNames",
    FontWeight->"Bold"],
  " lists all of the ray parameters that are present in ",
  StyleBox["TurboTrace",
    FontWeight->"Bold"],
  " and the ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " object.",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  " ",
  StyleBox["\n\[InvisibleSpace]",
    FontSize->10],
  "In particular, the ",
  StyleBox["$TurboRaysRuleNames",
    FontWeight->"Bold"],
  " list order follows the ",
  StyleBox["TurboRays",
    FontWeight->"Bold"],
  " parameter order",
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{1155, 1067},
WindowMargins->{{133, Automatic}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 33, 0, 36, "Subsection"],
Cell[1812, 55, 1115, 47, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2964, 107, 32, 0, 36, "Subsection"],
Cell[2999, 109, 1146, 49, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4182, 163, 31, 0, 36, "Subsection"],
Cell[4216, 165, 2001, 76, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6254, 246, 54, 0, 36, "Subsection"],
Cell[6311, 248, 560, 21, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6908, 274, 48, 0, 36, "Subsection"],
Cell[6959, 276, 529, 21, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7525, 302, 52, 0, 36, "Subsection"],
Cell[7580, 304, 549, 21, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8166, 330, 38, 0, 36, "Subsection"],
Cell[8207, 332, 990, 43, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9234, 380, 32, 0, 36, "Subsection"],
Cell[9269, 382, 443, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9749, 404, 29, 0, 36, "Subsection"],
Cell[9781, 406, 446, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10264, 424, 36, 0, 36, "Subsection"],
Cell[10303, 426, 168, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10508, 437, 37, 0, 36, "Subsection"],
Cell[10548, 439, 703, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11288, 471, 34, 0, 36, "Subsection"],
Cell[11325, 473, 1305, 50, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12667, 528, 38, 0, 36, "Subsection"],
Cell[12708, 530, 2141, 95, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14886, 630, 25, 0, 36, "Subsection"],
Cell[14914, 632, 2447, 107, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17398, 744, 35, 0, 36, "Subsection"],
Cell[17436, 746, 1969, 85, 149, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19442, 836, 31, 0, 46, "Subsection"],
Cell[19476, 838, 902, 40, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20415, 883, 38, 0, 46, "Subsection"],
Cell[20456, 885, 3151, 130, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23644, 1020, 32, 0, 46, "Subsection"],
Cell[23679, 1022, 2536, 104, 176, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26252, 1131, 41, 0, 46, "Subsection"],
Cell[26296, 1133, 2828, 120, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29161, 1258, 38, 0, 46, "Subsection"],
Cell[29202, 1260, 2122, 79, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31361, 1344, 25, 0, 36, "Subsection"],
Cell[31389, 1346, 614, 15, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32040, 1366, 27, 0, 36, "Subsection"],
Cell[32070, 1368, 2604, 107, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34711, 1480, 38, 0, 36, "Subsection"],
Cell[34752, 1482, 172, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34961, 1493, 42, 0, 36, "Subsection"],
Cell[35006, 1495, 1650, 70, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36693, 1570, 36, 0, 36, "Subsection"],
Cell[36732, 1572, 1877, 81, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38646, 1658, 36, 0, 36, "Subsection"],
Cell[38685, 1660, 1289, 50, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40011, 1715, 40, 0, 36, "Subsection"],
Cell[40054, 1717, 938, 33, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41029, 1755, 33, 0, 36, "Subsection"],
Cell[41065, 1757, 1326, 53, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42428, 1815, 35, 0, 36, "Subsection"],
Cell[42466, 1817, 1288, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43791, 1877, 38, 0, 36, "Subsection"],
Cell[43832, 1879, 3459, 122, 170, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47328, 2006, 36, 0, 36, "Subsection"],
Cell[47367, 2008, 434, 16, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47838, 2029, 33, 0, 36, "Subsection"],
Cell[47874, 2031, 195, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48106, 2044, 43, 0, 36, "Subsection"],
Cell[48152, 2046, 574, 22, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48763, 2073, 31, 0, 36, "Subsection"],
Cell[48797, 2075, 409, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49243, 2098, 34, 0, 36, "Subsection"],
Cell[49280, 2100, 1891, 68, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51208, 2173, 36, 0, 36, "Subsection"],
Cell[51247, 2175, 473, 21, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51757, 2201, 29, 0, 36, "Subsection"],
Cell[51789, 2203, 2534, 105, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54360, 2313, 34, 0, 36, "Subsection"],
Cell[54397, 2315, 3103, 104, 146, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57537, 2424, 41, 0, 36, "Subsection"],
Cell[57581, 2426, 2936, 97, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60554, 2528, 36, 0, 36, "Subsection"],
Cell[60593, 2530, 4994, 184, 200, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65624, 2719, 31, 0, 36, "Subsection"],
Cell[65658, 2721, 266, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65961, 2736, 38, 0, 36, "Subsection"],
Cell[66002, 2738, 1119, 40, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67158, 2783, 46, 0, 36, "Subsection"],
Cell[67207, 2785, 372, 15, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67616, 2805, 41, 0, 36, "Subsection"],
Cell[67660, 2807, 1626, 59, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69323, 2871, 26, 0, 36, "Subsection"],
Cell[69352, 2873, 156, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69545, 2885, 39, 0, 36, "Subsection"],
Cell[69587, 2887, 1122, 48, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70746, 2940, 37, 0, 36, "Subsection"],
Cell[70786, 2942, 401, 16, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71224, 2963, 28, 0, 36, "Subsection"],
Cell[71255, 2965, 1702, 61, 119, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72994, 3031, 29, 0, 36, "Subsection"],
Cell[73026, 3033, 1023, 40, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74086, 3078, 32, 0, 36, "Subsection"],
Cell[74121, 3080, 2936, 124, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77094, 3209, 36, 0, 36, "Subsection"],
Cell[77133, 3211, 1899, 68, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79069, 3284, 26, 0, 36, "Subsection"],
Cell[79098, 3286, 345, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79480, 3302, 38, 0, 36, "Subsection"],
Cell[79521, 3304, 1690, 70, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81248, 3379, 39, 0, 36, "Subsection"],
Cell[81290, 3381, 897, 30, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82224, 3416, 32, 0, 36, "Subsection"],
Cell[82259, 3418, 1024, 34, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83320, 3457, 30, 0, 36, "Subsection"],
Cell[83353, 3459, 1538, 56, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84928, 3520, 32, 0, 36, "Subsection"],
Cell[84963, 3522, 1530, 56, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86530, 3583, 26, 0, 36, "Subsection"],
Cell[86559, 3585, 150, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86746, 3595, 35, 0, 36, "Subsection"],
Cell[86784, 3597, 1111, 46, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87932, 3648, 36, 0, 36, "Subsection"],
Cell[87971, 3650, 1203, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89211, 3706, 37, 0, 36, "Subsection"],
Cell[89251, 3708, 1077, 44, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90365, 3757, 34, 0, 36, "Subsection"],
Cell[90402, 3759, 2206, 78, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92645, 3842, 38, 0, 36, "Subsection"],
Cell[92686, 3844, 1952, 67, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94675, 3916, 34, 0, 36, "Subsection"],
Cell[94712, 3918, 1221, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95970, 3974, 31, 0, 36, "Subsection"],
Cell[96004, 3976, 1181, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97222, 4030, 46, 0, 36, "Subsection"],
Cell[97271, 4032, 2199, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99507, 4108, 35, 0, 36, "Subsection"],
Cell[99545, 4110, 2175, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101757, 4186, 45, 0, 36, "Subsection"],
Cell[101805, 4188, 2196, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104038, 4264, 34, 0, 36, "Subsection"],
Cell[104075, 4266, 2172, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106284, 4342, 45, 0, 36, "Subsection"],
Cell[106332, 4344, 3239, 115, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109608, 4464, 32, 0, 36, "Subsection"],
Cell[109643, 4466, 1630, 70, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111310, 4541, 25, 0, 36, "Subsection"],
Cell[111338, 4543, 342, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111717, 4559, 30, 0, 36, "Subsection"],
Cell[111750, 4561, 3144, 123, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114931, 4689, 37, 0, 36, "Subsection"],
Cell[114971, 4691, 1156, 45, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116164, 4741, 36, 0, 36, "Subsection"],
Cell[116203, 4743, 1150, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117390, 4799, 35, 0, 36, "Subsection"],
Cell[117428, 4801, 303, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117768, 4820, 33, 0, 36, "Subsection"],
Cell[117804, 4822, 4232, 170, 168, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122073, 4997, 34, 0, 36, "Subsection"],
Cell[122110, 4999, 2845, 118, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124992, 5122, 32, 0, 36, "Subsection"],
Cell[125027, 5124, 2132, 86, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127196, 5215, 38, 0, 36, "Subsection"],
Cell[127237, 5217, 2468, 79, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129742, 5301, 33, 0, 36, "Subsection"],
Cell[129778, 5303, 160, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129975, 5313, 36, 0, 36, "Subsection"],
Cell[130014, 5315, 1002, 38, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131053, 5358, 44, 0, 36, "Subsection"],
Cell[131100, 5360, 307, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131444, 5375, 34, 0, 36, "Subsection"],
Cell[131481, 5377, 680, 30, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132198, 5412, 30, 0, 36, "Subsection"],
Cell[132231, 5414, 298, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132566, 5431, 30, 0, 36, "Subsection"],
Cell[132599, 5433, 298, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132934, 5450, 42, 0, 36, "Subsection"],
Cell[132979, 5452, 181, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133197, 5464, 40, 0, 36, "Subsection"],
Cell[133240, 5466, 554, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133831, 5491, 40, 0, 36, "Subsection"],
Cell[133874, 5493, 1453, 57, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135364, 5555, 30, 0, 36, "Subsection"],
Cell[135397, 5557, 1357, 55, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136791, 5617, 40, 0, 36, "Subsection"],
Cell[136834, 5619, 275, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137146, 5633, 37, 0, 36, "Subsection"],
Cell[137186, 5635, 164, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137387, 5645, 38, 0, 36, "Subsection"],
Cell[137428, 5647, 1083, 45, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138548, 5697, 32, 0, 36, "Subsection"],
Cell[138583, 5699, 1162, 47, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139782, 5751, 36, 0, 36, "Subsection"],
Cell[139821, 5753, 1008, 42, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140866, 5800, 31, 0, 36, "Subsection"],
Cell[140900, 5802, 796, 30, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141733, 5837, 44, 0, 36, "Subsection"],
Cell[141780, 5839, 942, 35, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142759, 5879, 43, 0, 36, "Subsection"],
Cell[142805, 5881, 1026, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143868, 5924, 33, 0, 36, "Subsection"],
Cell[143904, 5926, 1280, 47, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145221, 5978, 35, 0, 36, "Subsection"],
Cell[145259, 5980, 1405, 46, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146701, 6031, 34, 0, 36, "Subsection"],
Cell[146738, 6033, 4293, 183, 220, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151068, 6221, 42, 0, 36, "Subsection"],
Cell[151113, 6223, 1146, 48, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152296, 6276, 35, 0, 36, "Subsection"],
Cell[152334, 6278, 463, 16, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152834, 6299, 35, 0, 36, "Subsection"],
Cell[152872, 6301, 3421, 130, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156330, 6436, 38, 0, 36, "Subsection"],
Cell[156371, 6438, 734, 29, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157142, 6472, 40, 0, 36, "Subsection"],
Cell[157185, 6474, 189, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157411, 6485, 35, 0, 36, "Subsection"],
Cell[157449, 6487, 713, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158199, 6520, 35, 0, 36, "Subsection"],
Cell[158237, 6522, 736, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159010, 6555, 32, 0, 36, "Subsection"],
Cell[159045, 6557, 725, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159807, 6590, 37, 0, 36, "Subsection"],
Cell[159847, 6592, 744, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160628, 6624, 37, 0, 36, "Subsection"],
Cell[160668, 6626, 1291, 41, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161996, 6672, 27, 0, 36, "Subsection"],
Cell[162026, 6674, 472, 18, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162535, 6697, 38, 0, 36, "Subsection"],
Cell[162576, 6699, 312, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162925, 6715, 38, 0, 36, "Subsection"],
Cell[162966, 6717, 361, 14, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163364, 6736, 34, 0, 36, "Subsection"],
Cell[163401, 6738, 284, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163722, 6752, 35, 0, 36, "Subsection"],
Cell[163760, 6754, 916, 32, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164713, 6791, 42, 0, 36, "Subsection"],
Cell[164758, 6793, 853, 28, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165648, 6826, 33, 0, 36, "Subsection"],
Cell[165684, 6828, 2574, 93, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168295, 6926, 131, 6, 36, "Subsection"],
Cell[168429, 6934, 2846, 105, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171312, 7044, 30, 0, 36, "Subsection"],
Cell[171345, 7046, 570, 25, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171952, 7076, 31, 0, 36, "Subsection"],
Cell[171986, 7078, 832, 29, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172855, 7112, 31, 0, 36, "Subsection"],
Cell[172889, 7114, 2805, 113, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175731, 7232, 37, 0, 36, "Subsection"],
Cell[175771, 7234, 1440, 64, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177248, 7303, 37, 0, 36, "Subsection"],
Cell[177288, 7305, 1596, 64, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178921, 7374, 50, 0, 36, "Subsection"],
Cell[178974, 7376, 728, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179739, 7408, 57, 0, 36, "Subsection"],
Cell[179799, 7410, 1432, 49, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181268, 7464, 34, 0, 36, "Subsection"],
Cell[181305, 7466, 253, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181595, 7480, 42, 0, 36, "Subsection"],
Cell[181640, 7482, 1310, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182987, 7542, 31, 0, 36, "Subsection"],
Cell[183021, 7544, 1069, 42, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184127, 7591, 39, 0, 36, "Subsection"],
Cell[184169, 7593, 871, 26, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185077, 7624, 42, 0, 36, "Subsection"],
Cell[185122, 7626, 794, 31, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185953, 7662, 41, 0, 36, "Subsection"],
Cell[185997, 7664, 5361, 207, 196, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191395, 7876, 40, 0, 36, "Subsection"],
Cell[191438, 7878, 231, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191706, 7891, 33, 0, 36, "Subsection"],
Cell[191742, 7893, 986, 39, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192765, 7937, 40, 0, 36, "Subsection"],
Cell[192808, 7939, 2178, 94, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195023, 8038, 37, 0, 36, "Subsection"],
Cell[195063, 8040, 1078, 38, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196178, 8083, 37, 0, 36, "Subsection"],
Cell[196218, 8085, 798, 32, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[197053, 8122, 32, 0, 36, "Subsection"],
Cell[197088, 8124, 419, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[197544, 8149, 40, 0, 36, "Subsection"],
Cell[197587, 8151, 2548, 99, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200172, 8255, 37, 0, 36, "Subsection"],
Cell[200212, 8257, 2525, 99, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202774, 8361, 57, 0, 36, "Subsection"],
Cell[202834, 8363, 435, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203306, 8384, 45, 0, 36, "Subsection"],
Cell[203354, 8386, 942, 38, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204333, 8429, 34, 0, 36, "Subsection"],
Cell[204370, 8431, 3295, 96, 162, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207702, 8532, 32, 0, 36, "Subsection"],
Cell[207737, 8534, 299, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208073, 8550, 34, 0, 36, "Subsection"],
Cell[208110, 8552, 852, 38, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208999, 8595, 32, 0, 36, "Subsection"],
Cell[209034, 8597, 4639, 192, 236, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[213710, 8794, 29, 0, 36, "Subsection"],
Cell[213742, 8796, 1346, 52, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215125, 8853, 36, 0, 36, "Subsection"],
Cell[215164, 8855, 902, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216103, 8898, 35, 0, 36, "Subsection"],
Cell[216141, 8900, 745, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216923, 8932, 38, 0, 36, "Subsection"],
Cell[216964, 8934, 904, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217905, 8977, 43, 0, 36, "Subsection"],
Cell[217951, 8979, 2291, 81, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220279, 9065, 37, 0, 36, "Subsection"],
Cell[220319, 9067, 1953, 68, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222309, 9140, 41, 0, 36, "Subsection"],
Cell[222353, 9142, 410, 16, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222800, 9163, 43, 0, 36, "Subsection"],
Cell[222846, 9165, 287, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223170, 9182, 36, 0, 36, "Subsection"],
Cell[223209, 9184, 432, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223678, 9207, 31, 0, 36, "Subsection"],
Cell[223712, 9209, 2330, 102, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226079, 9316, 44, 0, 36, "Subsection"],
Cell[226126, 9318, 1877, 75, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228040, 9398, 35, 0, 36, "Subsection"],
Cell[228078, 9400, 1649, 70, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229764, 9475, 38, 0, 36, "Subsection"],
Cell[229805, 9477, 777, 29, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230619, 9511, 26, 0, 36, "Subsection"],
Cell[230648, 9513, 2341, 105, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233026, 9623, 40, 0, 36, "Subsection"],
Cell[233069, 9625, 481, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233587, 9649, 39, 0, 36, "Subsection"],
Cell[233629, 9651, 1856, 55, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235522, 9711, 34, 0, 36, "Subsection"],
Cell[235559, 9713, 5562, 205, 216, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241158, 9923, 32, 0, 36, "Subsection"],
Cell[241193, 9925, 1436, 58, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242666, 9988, 38, 0, 36, "Subsection"],
Cell[242707, 9990, 866, 37, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[243610, 10032, 31, 0, 36, "Subsection"],
Cell[243644, 10034, 1836, 75, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245517, 10114, 32, 0, 36, "Subsection"],
Cell[245552, 10116, 1886, 76, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247475, 10197, 48, 0, 36, "Subsection"],
Cell[247526, 10199, 2752, 103, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250315, 10307, 36, 0, 36, "Subsection"],
Cell[250354, 10309, 1068, 46, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251459, 10360, 32, 0, 36, "Subsection"],
Cell[251494, 10362, 913, 37, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252444, 10404, 32, 0, 36, "Subsection"],
Cell[252479, 10406, 1224, 50, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253740, 10461, 32, 0, 36, "Subsection"],
Cell[253775, 10463, 313, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254125, 10477, 33, 0, 36, "Subsection"],
Cell[254161, 10479, 1307, 53, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255505, 10537, 32, 0, 36, "Subsection"],
Cell[255540, 10539, 1278, 53, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256855, 10597, 35, 0, 36, "Subsection"],
Cell[256893, 10599, 1069, 45, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257999, 10649, 40, 0, 36, "Subsection"],
Cell[258042, 10651, 531, 16, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[258610, 10672, 40, 0, 36, "Subsection"],
Cell[258653, 10674, 536, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259226, 10697, 34, 0, 36, "Subsection"],
Cell[259263, 10699, 2183, 83, 98, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261483, 10787, 40, 0, 36, "Subsection"],
Cell[261526, 10789, 2777, 100, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264340, 10894, 51, 0, 36, "Subsection"],
Cell[264394, 10896, 3585, 128, 148, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268016, 11029, 44, 0, 36, "Subsection"],
Cell[268063, 11031, 2965, 96, 148, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271065, 11132, 49, 0, 36, "Subsection"],
Cell[271117, 11134, 2755, 98, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273909, 11237, 43, 0, 36, "Subsection"],
Cell[273955, 11239, 5794, 222, 212, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[279786, 11466, 46, 0, 36, "Subsection"],
Cell[279835, 11468, 270, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280142, 11484, 39, 0, 36, "Subsection"],
Cell[280184, 11486, 609, 24, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280830, 11515, 36, 0, 36, "Subsection"],
Cell[280869, 11517, 5819, 224, 246, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286725, 11746, 42, 0, 36, "Subsection"],
Cell[286770, 11748, 5829, 224, 238, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[292636, 11977, 33, 0, 36, "Subsection"],
Cell[292672, 11979, 3299, 135, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296008, 12119, 39, 0, 36, "Subsection"],
Cell[296050, 12121, 2154, 85, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298241, 12211, 43, 0, 36, "Subsection"],
Cell[298287, 12213, 177, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298501, 12225, 35, 0, 36, "Subsection"],
Cell[298539, 12227, 6638, 257, 248, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[305214, 12489, 41, 0, 36, "Subsection"],
Cell[305258, 12491, 6534, 253, 242, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[311829, 12749, 42, 0, 36, "Subsection"],
Cell[311874, 12751, 209, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[312120, 12764, 44, 0, 36, "Subsection"],
Cell[312167, 12766, 4262, 144, 244, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[316466, 12915, 44, 0, 36, "Subsection"],
Cell[316513, 12917, 1659, 62, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[318209, 12984, 32, 0, 36, "Subsection"],
Cell[318244, 12986, 2113, 77, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[320394, 13068, 39, 0, 36, "Subsection"],
Cell[320436, 13070, 2402, 82, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322875, 13157, 43, 0, 36, "Subsection"],
Cell[322921, 13159, 1563, 58, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[324521, 13222, 34, 0, 36, "Subsection"],
Cell[324558, 13224, 5784, 222, 212, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[330379, 13451, 33, 0, 36, "Subsection"],
Cell[330415, 13453, 1550, 59, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332002, 13517, 32, 0, 36, "Subsection"],
Cell[332037, 13519, 3808, 168, 188, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335882, 13692, 44, 0, 36, "Subsection"],
Cell[335929, 13694, 1662, 62, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337628, 13761, 34, 0, 36, "Subsection"],
Cell[337665, 13763, 2191, 75, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339893, 13843, 37, 0, 36, "Subsection"],
Cell[339933, 13845, 1884, 69, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[341854, 13919, 39, 0, 36, "Subsection"],
Cell[341896, 13921, 1927, 69, 119, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[343860, 13995, 41, 0, 36, "Subsection"],
Cell[343904, 13997, 4558, 173, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348499, 14175, 47, 0, 36, "Subsection"],
Cell[348549, 14177, 4616, 173, 214, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353202, 14355, 46, 0, 36, "Subsection"],
Cell[353251, 14357, 5963, 232, 226, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[359251, 14594, 37, 0, 36, "Subsection"],
Cell[359291, 14596, 1759, 60, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[361087, 14661, 44, 0, 36, "Subsection"],
Cell[361134, 14663, 2044, 66, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[363215, 14734, 39, 0, 36, "Subsection"],
Cell[363257, 14736, 3197, 121, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[366491, 14862, 39, 0, 36, "Subsection"],
Cell[366533, 14864, 1658, 54, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368228, 14923, 38, 0, 36, "Subsection"],
Cell[368269, 14925, 316, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368622, 14943, 34, 0, 36, "Subsection"],
Cell[368659, 14945, 2916, 118, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371612, 15068, 41, 0, 36, "Subsection"],
Cell[371656, 15070, 277, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371970, 15084, 38, 0, 36, "Subsection"],
Cell[372011, 15086, 790, 31, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[372838, 15122, 34, 0, 36, "Subsection"],
Cell[372875, 15124, 573, 25, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373485, 15154, 40, 0, 36, "Subsection"],
Cell[373528, 15156, 3804, 148, 142, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377369, 15309, 34, 0, 36, "Subsection"],
Cell[377406, 15311, 867, 33, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[378310, 15349, 37, 0, 36, "Subsection"],
Cell[378350, 15351, 721, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[379108, 15390, 38, 0, 36, "Subsection"],
Cell[379149, 15392, 794, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[379980, 15425, 33, 0, 36, "Subsection"],
Cell[380016, 15427, 1697, 67, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381750, 15499, 33, 0, 36, "Subsection"],
Cell[381786, 15501, 287, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[382110, 15518, 44, 0, 36, "Subsection"],
Cell[382157, 15520, 1201, 41, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[383395, 15566, 35, 0, 36, "Subsection"],
Cell[383433, 15568, 814, 35, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[384284, 15608, 43, 0, 36, "Subsection"],
Cell[384330, 15610, 301, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[384668, 15625, 38, 0, 36, "Subsection"],
Cell[384709, 15627, 303, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[385049, 15641, 32, 0, 36, "Subsection"],
Cell[385084, 15643, 286, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[385407, 15659, 38, 0, 36, "Subsection"],
Cell[385448, 15661, 3360, 145, 137, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388845, 15811, 38, 0, 36, "Subsection"],
Cell[388886, 15813, 1122, 37, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[390045, 15855, 33, 0, 36, "Subsection"],
Cell[390081, 15857, 6989, 271, 373, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[397107, 16133, 45, 0, 36, "Subsection"],
Cell[397155, 16135, 688, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[397880, 16168, 41, 0, 36, "Subsection"],
Cell[397924, 16170, 902, 30, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[398863, 16205, 44, 0, 36, "Subsection"],
Cell[398910, 16207, 534, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[399481, 16234, 30, 0, 36, "Subsection"],
Cell[399514, 16236, 4315, 164, 192, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403866, 16405, 36, 0, 36, "Subsection"],
Cell[403905, 16407, 4369, 165, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408311, 16577, 42, 0, 36, "Subsection"],
Cell[408356, 16579, 502, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408895, 16600, 37, 0, 36, "Subsection"],
Cell[408935, 16602, 364, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[409336, 16621, 39, 0, 36, "Subsection"],
Cell[409378, 16623, 2130, 76, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[411545, 16704, 32, 0, 36, "Subsection"],
Cell[411580, 16706, 991, 44, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[412608, 16755, 36, 0, 36, "Subsection"],
Cell[412647, 16757, 2469, 93, 188, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[415153, 16855, 38, 0, 36, "Subsection"],
Cell[415194, 16857, 589, 25, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[415820, 16887, 40, 0, 36, "Subsection"],
Cell[415863, 16889, 1108, 45, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[417008, 16939, 37, 0, 36, "Subsection"],
Cell[417048, 16941, 499, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[417584, 16964, 31, 0, 36, "Subsection"],
Cell[417618, 16966, 2817, 105, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[420472, 17076, 39, 0, 36, "Subsection"],
Cell[420514, 17078, 348, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[420899, 17100, 32, 0, 36, "Subsection"],
Cell[420934, 17102, 1893, 84, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422864, 17191, 31, 0, 36, "Subsection"],
Cell[422898, 17193, 3495, 128, 174, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[426430, 17326, 38, 0, 36, "Subsection"],
Cell[426471, 17328, 2565, 85, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[429073, 17418, 30, 0, 36, "Subsection"],
Cell[429106, 17420, 264, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[429407, 17434, 35, 0, 36, "Subsection"],
Cell[429445, 17436, 1132, 47, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[430614, 17488, 31, 0, 36, "Subsection"],
Cell[430648, 17490, 847, 35, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[431532, 17530, 35, 0, 36, "Subsection"],
Cell[431570, 17532, 156, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[431763, 17542, 40, 0, 36, "Subsection"],
Cell[431806, 17544, 1607, 55, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433450, 17604, 36, 0, 36, "Subsection"],
Cell[433489, 17606, 283, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433809, 17623, 38, 0, 36, "Subsection"],
Cell[433850, 17625, 376, 14, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[434263, 17644, 34, 0, 36, "Subsection"],
Cell[434300, 17646, 299, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[434636, 17660, 29, 0, 36, "Subsection"],
Cell[434668, 17662, 222, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[434927, 17677, 34, 0, 36, "Subsection"],
Cell[434964, 17679, 639, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[435640, 17711, 34, 0, 36, "Subsection"],
Cell[435677, 17713, 581, 25, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[436295, 17743, 42, 0, 36, "Subsection"],
Cell[436340, 17745, 1968, 90, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[438345, 17840, 31, 0, 36, "Subsection"],
Cell[438379, 17842, 2713, 112, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[441129, 17959, 45, 0, 36, "Subsection"],
Cell[441177, 17961, 1987, 90, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443201, 18056, 28, 0, 36, "Subsection"],
Cell[443232, 18058, 320, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443589, 18077, 41, 0, 36, "Subsection"],
Cell[443633, 18079, 794, 29, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444464, 18113, 45, 0, 36, "Subsection"],
Cell[444512, 18115, 294, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444843, 18130, 37, 0, 36, "Subsection"],
Cell[444883, 18132, 1330, 43, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[446250, 18180, 29, 0, 36, "Subsection"],
Cell[446282, 18182, 446, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[446765, 18200, 34, 0, 36, "Subsection"],
Cell[446802, 18202, 801, 26, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[447640, 18233, 35, 0, 36, "Subsection"],
Cell[447678, 18235, 3707, 133, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[451422, 18373, 34, 0, 36, "Subsection"],
Cell[451459, 18375, 377, 12, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[451873, 18392, 48, 0, 36, "Subsection"],
Cell[451924, 18394, 834, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452795, 18430, 57, 0, 36, "Subsection"],
Cell[452855, 18432, 1355, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454247, 18486, 48, 0, 36, "Subsection"],
Cell[454298, 18488, 1638, 50, 114, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455973, 18543, 30, 0, 36, "Subsection"],
Cell[456006, 18545, 3011, 124, 160, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459054, 18674, 27, 0, 36, "Subsection"],
Cell[459084, 18676, 2740, 108, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461861, 18789, 36, 0, 36, "Subsection"],
Cell[461900, 18791, 645, 28, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[462582, 18824, 27, 0, 36, "Subsection"],
Cell[462612, 18826, 154, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[462803, 18838, 33, 0, 36, "Subsection"],
Cell[462839, 18840, 3720, 151, 220, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466596, 18996, 33, 0, 36, "Subsection"],
Cell[466632, 18998, 226, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466895, 19011, 39, 0, 36, "Subsection"],
Cell[466937, 19013, 185, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[467159, 19024, 26, 0, 36, "Subsection"],
Cell[467188, 19026, 300, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[467525, 19043, 32, 0, 36, "Subsection"],
Cell[467560, 19045, 840, 29, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468437, 19079, 31, 0, 36, "Subsection"],
Cell[468471, 19081, 272, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468780, 19095, 42, 0, 36, "Subsection"],
Cell[468825, 19097, 1262, 51, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470124, 19153, 33, 0, 36, "Subsection"],
Cell[470160, 19155, 3527, 149, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473724, 19309, 32, 0, 36, "Subsection"],
Cell[473759, 19311, 323, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474119, 19329, 38, 0, 36, "Subsection"],
Cell[474160, 19331, 1380, 51, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475577, 19387, 31, 0, 36, "Subsection"],
Cell[475611, 19389, 2152, 88, 120, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[477800, 19482, 35, 0, 36, "Subsection"],
Cell[477838, 19484, 3214, 133, 274, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[481089, 19622, 38, 0, 36, "Subsection"],
Cell[481130, 19624, 1994, 74, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[483161, 19703, 35, 0, 36, "Subsection"],
Cell[483199, 19705, 4114, 151, 327, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487350, 19861, 59, 0, 36, "Subsection"],
Cell[487412, 19863, 752, 23, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[488201, 19891, 34, 0, 36, "Subsection"],
Cell[488238, 19893, 1856, 73, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490131, 19971, 33, 0, 36, "Subsection"],
Cell[490167, 19973, 565, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490769, 19998, 31, 0, 36, "Subsection"],
Cell[490803, 20000, 1288, 51, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492128, 20056, 35, 0, 36, "Subsection"],
Cell[492166, 20058, 706, 29, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492909, 20092, 29, 0, 36, "Subsection"],
Cell[492941, 20094, 508, 21, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493486, 20120, 33, 0, 36, "Subsection"],
Cell[493522, 20122, 399, 16, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493958, 20143, 36, 0, 36, "Subsection"],
Cell[493997, 20145, 377, 15, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494411, 20165, 32, 0, 36, "Subsection"],
Cell[494446, 20167, 339, 15, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494822, 20187, 35, 0, 36, "Subsection"],
Cell[494860, 20189, 314, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495211, 20205, 33, 0, 36, "Subsection"],
Cell[495247, 20207, 312, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495596, 20223, 31, 0, 36, "Subsection"],
Cell[495630, 20225, 961, 34, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[496628, 20264, 31, 0, 36, "Subsection"],
Cell[496662, 20266, 464, 22, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497163, 20293, 35, 0, 36, "Subsection"],
Cell[497201, 20295, 1994, 75, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499232, 20375, 38, 0, 36, "Subsection"],
Cell[499273, 20377, 377, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499687, 20396, 37, 0, 36, "Subsection"],
Cell[499727, 20398, 1563, 51, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501327, 20454, 37, 0, 36, "Subsection"],
Cell[501367, 20456, 212, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501616, 20467, 29, 0, 36, "Subsection"],
Cell[501648, 20469, 1875, 71, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[503560, 20545, 40, 0, 36, "Subsection"],
Cell[503603, 20547, 902, 38, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[504542, 20590, 39, 0, 36, "Subsection"],
Cell[504584, 20592, 359, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[504980, 20611, 34, 0, 36, "Subsection"],
Cell[505017, 20613, 3776, 146, 182, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508830, 20764, 37, 0, 36, "Subsection"],
Cell[508870, 20766, 670, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509577, 20799, 27, 0, 36, "Subsection"],
Cell[509607, 20801, 157, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509801, 20813, 38, 0, 36, "Subsection"],
Cell[509842, 20815, 445, 17, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[510324, 20837, 34, 0, 36, "Subsection"],
Cell[510361, 20839, 1245, 48, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511643, 20892, 31, 0, 36, "Subsection"],
Cell[511677, 20894, 790, 36, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[512504, 20935, 28, 0, 36, "Subsection"],
Cell[512535, 20937, 701, 33, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[513273, 20975, 35, 0, 36, "Subsection"],
Cell[513311, 20977, 681, 23, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[514029, 21005, 36, 0, 36, "Subsection"],
Cell[514068, 21007, 1732, 74, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[515837, 21086, 32, 0, 36, "Subsection"],
Cell[515872, 21088, 2341, 83, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[518250, 21176, 39, 0, 36, "Subsection"],
Cell[518292, 21178, 2222, 75, 114, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520551, 21258, 33, 0, 36, "Subsection"],
Cell[520587, 21260, 315, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520939, 21274, 34, 0, 36, "Subsection"],
Cell[520976, 21276, 8195, 307, 437, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[529208, 21588, 37, 0, 36, "Subsection"],
Cell[529248, 21590, 503, 19, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[529788, 21614, 38, 0, 36, "Subsection"],
Cell[529829, 21616, 1034, 43, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[530900, 21664, 30, 0, 36, "Subsection"],
Cell[530933, 21666, 157, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[531127, 21678, 37, 0, 36, "Subsection"],
Cell[531167, 21680, 3217, 137, 114, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[534421, 21822, 38, 0, 36, "Subsection"],
Cell[534462, 21824, 2768, 109, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[537267, 21938, 44, 0, 36, "Subsection"],
Cell[537314, 21940, 636, 21, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[537987, 21966, 37, 0, 36, "Subsection"],
Cell[538027, 21968, 1066, 45, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[539130, 22018, 39, 0, 36, "Subsection"],
Cell[539172, 22020, 5857, 229, 194, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[545066, 22254, 37, 0, 36, "Subsection"],
Cell[545106, 22256, 1388, 52, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[546531, 22313, 30, 0, 36, "Subsection"],
Cell[546564, 22315, 9542, 363, 334, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[556143, 22683, 31, 0, 36, "Subsection"],
Cell[556177, 22685, 453, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[556667, 22703, 38, 0, 36, "Subsection"],
Cell[556708, 22705, 887, 30, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[557632, 22740, 37, 0, 36, "Subsection"],
Cell[557672, 22742, 473, 14, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[558182, 22761, 35, 0, 36, "Subsection"],
Cell[558220, 22763, 1913, 87, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[560170, 22855, 29, 0, 36, "Subsection"],
Cell[560202, 22857, 8075, 318, 368, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[568314, 23180, 37, 0, 36, "Subsection"],
Cell[568354, 23182, 406, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[568797, 23205, 38, 0, 36, "Subsection"],
Cell[568838, 23207, 649, 28, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569524, 23240, 35, 0, 36, "Subsection"],
Cell[569562, 23242, 656, 26, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[570255, 23273, 35, 0, 36, "Subsection"],
Cell[570293, 23275, 5764, 224, 226, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[576094, 23504, 39, 0, 36, "Subsection"],
Cell[576136, 23506, 2207, 85, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[578380, 23596, 43, 0, 36, "Subsection"],
Cell[578426, 23598, 537, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[579000, 23623, 37, 0, 36, "Subsection"],
Cell[579040, 23625, 989, 41, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580066, 23671, 36, 0, 36, "Subsection"],
Cell[580105, 23673, 204, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580346, 23687, 38, 0, 36, "Subsection"],
Cell[580387, 23689, 873, 33, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[581297, 23727, 32, 0, 36, "Subsection"],
Cell[581332, 23729, 5412, 226, 280, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[586781, 23960, 30, 0, 36, "Subsection"],
Cell[586814, 23962, 899, 35, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[587750, 24002, 33, 0, 36, "Subsection"],
Cell[587786, 24004, 4844, 194, 330, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[592667, 24203, 30, 0, 36, "Subsection"],
Cell[592700, 24205, 183, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[592920, 24216, 30, 0, 36, "Subsection"],
Cell[592953, 24218, 1765, 70, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[594755, 24293, 27, 0, 36, "Subsection"],
Cell[594785, 24295, 1394, 60, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596216, 24360, 38, 0, 36, "Subsection"],
Cell[596257, 24362, 145, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596439, 24372, 33, 0, 36, "Subsection"],
Cell[596475, 24374, 873, 37, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[597385, 24416, 40, 0, 36, "Subsection"],
Cell[597428, 24418, 276, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[597741, 24433, 34, 0, 36, "Subsection"],
Cell[597778, 24435, 1551, 57, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[599366, 24497, 41, 0, 36, "Subsection"],
Cell[599410, 24499, 1937, 67, 141, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[601384, 24571, 34, 0, 36, "Subsection"],
Cell[601421, 24573, 711, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[602169, 24608, 45, 0, 36, "Subsection"],
Cell[602217, 24610, 971, 42, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[603225, 24657, 38, 0, 36, "Subsection"],
Cell[603266, 24659, 708, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604011, 24694, 35, 0, 36, "Subsection"],
Cell[604049, 24696, 492, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604578, 24724, 50, 0, 36, "Subsection"],
Cell[604631, 24726, 1083, 44, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[605751, 24775, 54, 0, 36, "Subsection"],
Cell[605808, 24777, 756, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[606601, 24812, 40, 0, 36, "Subsection"],
Cell[606644, 24814, 898, 35, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607579, 24854, 45, 0, 36, "Subsection"],
Cell[607627, 24856, 1872, 74, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[609536, 24935, 38, 0, 46, "Subsection"],
Cell[609577, 24937, 731, 30, 83, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610345, 24972, 41, 0, 46, "Subsection"],
Cell[610389, 24974, 410, 16, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610836, 24995, 41, 0, 46, "Subsection"],
Cell[610880, 24997, 982, 42, 101, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611899, 25044, 34, 0, 46, "Subsection"],
Cell[611936, 25046, 719, 30, 83, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[612692, 25081, 40, 0, 46, "Subsection"],
Cell[612735, 25083, 1737, 79, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[614509, 25167, 49, 0, 46, "Subsection"],
Cell[614561, 25169, 1023, 45, 101, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[615621, 25219, 42, 0, 46, "Subsection"],
Cell[615666, 25221, 764, 32, 83, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[616467, 25258, 39, 0, 46, "Subsection"],
Cell[616509, 25260, 946, 38, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[617492, 25303, 49, 0, 46, "Subsection"],
Cell[617544, 25305, 1244, 53, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[618825, 25363, 42, 0, 36, "Subsection"],
Cell[618870, 25365, 727, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[619634, 25400, 43, 0, 36, "Subsection"],
Cell[619680, 25402, 977, 42, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[620694, 25449, 36, 0, 36, "Subsection"],
Cell[620733, 25451, 704, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[621474, 25486, 43, 0, 36, "Subsection"],
Cell[621520, 25488, 1125, 49, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622682, 25542, 47, 0, 36, "Subsection"],
Cell[622732, 25544, 772, 32, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[623541, 25581, 47, 0, 36, "Subsection"],
Cell[623591, 25583, 1181, 49, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[624809, 25637, 51, 0, 36, "Subsection"],
Cell[624863, 25639, 717, 29, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[625617, 25673, 37, 0, 36, "Subsection"],
Cell[625657, 25675, 1690, 72, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[627384, 25752, 37, 0, 36, "Subsection"],
Cell[627424, 25754, 4041, 156, 217, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631502, 25915, 57, 0, 36, "Subsection"],
Cell[631562, 25917, 1710, 70, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[633309, 25992, 50, 0, 36, "Subsection"],
Cell[633362, 25994, 740, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[634139, 26029, 41, 0, 36, "Subsection"],
Cell[634183, 26031, 1376, 59, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[635596, 26095, 34, 0, 36, "Subsection"],
Cell[635633, 26097, 708, 30, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[636378, 26132, 40, 0, 36, "Subsection"],
Cell[636421, 26134, 2600, 116, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[639058, 26255, 26, 0, 36, "Subsection"],
Cell[639087, 26257, 1394, 53, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[640518, 26315, 34, 0, 36, "Subsection"],
Cell[640555, 26317, 730, 26, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[641322, 26348, 39, 0, 36, "Subsection"],
Cell[641364, 26350, 317, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[641718, 26369, 32, 0, 36, "Subsection"],
Cell[641753, 26371, 875, 29, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[642665, 26405, 38, 0, 36, "Subsection"],
Cell[642706, 26407, 2795, 110, 152, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[645538, 26522, 30, 0, 36, "Subsection"],
Cell[645571, 26524, 277, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[645885, 26536, 40, 0, 36, "Subsection"],
Cell[645928, 26538, 386, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[646351, 26556, 37, 0, 36, "Subsection"],
Cell[646391, 26558, 862, 26, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[647290, 26589, 30, 0, 36, "Subsection"],
Cell[647323, 26591, 3281, 142, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[650641, 26738, 37, 0, 36, "Subsection"],
Cell[650681, 26740, 183, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[650901, 26752, 46, 0, 36, "Subsection"],
Cell[650950, 26754, 974, 35, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[651961, 26794, 43, 0, 36, "Subsection"],
Cell[652007, 26796, 2034, 71, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[654078, 26872, 40, 0, 36, "Subsection"],
Cell[654121, 26874, 524, 17, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[654682, 26896, 41, 0, 36, "Subsection"],
Cell[654726, 26898, 1471, 55, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[656234, 26958, 43, 0, 36, "Subsection"],
Cell[656280, 26960, 538, 17, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[656855, 26982, 39, 0, 36, "Subsection"],
Cell[656897, 26984, 597, 24, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[657531, 27013, 35, 0, 36, "Subsection"],
Cell[657569, 27015, 2626, 111, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[660232, 27131, 48, 0, 36, "Subsection"],
Cell[660283, 27133, 1631, 66, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[661951, 27204, 40, 0, 36, "Subsection"],
Cell[661994, 27206, 583, 19, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[662614, 27230, 38, 0, 36, "Subsection"],
Cell[662655, 27232, 1501, 60, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[664193, 27297, 40, 0, 46, "Subsection"],
Cell[664236, 27299, 1229, 46, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[665502, 27350, 38, 0, 46, "Subsection"],
Cell[665543, 27352, 1262, 54, 119, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[666842, 27411, 41, 0, 36, "Subsection"],
Cell[666886, 27413, 932, 37, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[667855, 27455, 34, 0, 36, "Subsection"],
Cell[667892, 27457, 422, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668351, 27481, 44, 0, 36, "Subsection"],
Cell[668398, 27483, 1350, 52, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[669785, 27540, 31, 0, 36, "Subsection"],
Cell[669819, 27542, 624, 30, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[670480, 27577, 39, 0, 36, "Subsection"],
Cell[670522, 27579, 1729, 70, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[672288, 27654, 36, 0, 36, "Subsection"],
Cell[672327, 27656, 1944, 74, 149, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[674308, 27735, 38, 0, 36, "Subsection"],
Cell[674349, 27737, 1251, 54, 103, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[675637, 27796, 35, 0, 36, "Subsection"],
Cell[675675, 27798, 304, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[676016, 27815, 45, 0, 36, "Subsection"],
Cell[676064, 27817, 517, 17, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[676618, 27839, 43, 0, 36, "Subsection"],
Cell[676664, 27841, 656, 30, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[677357, 27876, 40, 0, 36, "Subsection"],
Cell[677400, 27878, 867, 35, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[678304, 27918, 49, 0, 36, "Subsection"],
Cell[678356, 27920, 3797, 124, 220, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[682190, 28049, 36, 0, 36, "Subsection"],
Cell[682229, 28051, 587, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[682853, 28078, 37, 0, 36, "Subsection"],
Cell[682893, 28080, 1666, 56, 120, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[684596, 28141, 47, 0, 36, "Subsection"],
Cell[684646, 28143, 3931, 132, 228, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[688614, 28280, 38, 0, 36, "Subsection"],
Cell[688655, 28282, 3721, 127, 214, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[692413, 28414, 31, 0, 36, "Subsection"],
Cell[692447, 28416, 191, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[692675, 28429, 36, 0, 36, "Subsection"],
Cell[692714, 28431, 657, 22, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[693408, 28458, 33, 0, 36, "Subsection"],
Cell[693444, 28460, 2708, 104, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[696189, 28569, 38, 0, 36, "Subsection"],
Cell[696230, 28571, 3736, 140, 154, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[700003, 28716, 44, 0, 36, "Subsection"],
Cell[700050, 28718, 925, 38, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[701012, 28761, 31, 0, 36, "Subsection"],
Cell[701046, 28763, 2505, 90, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[703588, 28858, 129, 6, 36, "Subsection"],
Cell[703720, 28866, 2772, 102, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[706529, 28973, 33, 0, 36, "Subsection"],
Cell[706565, 28975, 1385, 57, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[707987, 29037, 35, 0, 36, "Subsection"],
Cell[708025, 29039, 164, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[708226, 29049, 33, 0, 36, "Subsection"],
Cell[708262, 29051, 553, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[708852, 29078, 36, 0, 36, "Subsection"],
Cell[708891, 29080, 1097, 50, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[710025, 29135, 28, 0, 36, "Subsection"],
Cell[710056, 29137, 1134, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[711227, 29191, 35, 0, 36, "Subsection"],
Cell[711265, 29193, 2170, 91, 114, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[713472, 29289, 32, 0, 36, "Subsection"],
Cell[713507, 29291, 851, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[714395, 29327, 27, 0, 36, "Subsection"],
Cell[714425, 29329, 346, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[714808, 29345, 33, 0, 36, "Subsection"],
Cell[714844, 29347, 415, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[715296, 29366, 30, 0, 36, "Subsection"],
Cell[715329, 29368, 1285, 50, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[716651, 29423, 33, 0, 36, "Subsection"],
Cell[716687, 29425, 2683, 98, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[719407, 29528, 33, 0, 36, "Subsection"],
Cell[719443, 29530, 1877, 62, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[721357, 29597, 33, 0, 36, "Subsection"],
Cell[721393, 29599, 3041, 116, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[724471, 29720, 39, 0, 36, "Subsection"],
Cell[724513, 29722, 1754, 70, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[726304, 29797, 34, 0, 36, "Subsection"],
Cell[726341, 29799, 905, 34, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[727283, 29838, 40, 0, 36, "Subsection"],
Cell[727326, 29840, 5163, 202, 186, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[732526, 30047, 37, 0, 36, "Subsection"],
Cell[732566, 30049, 5606, 219, 200, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[738209, 30273, 32, 0, 36, "Subsection"],
Cell[738244, 30275, 3003, 128, 160, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[741284, 30408, 31, 0, 36, "Subsection"],
Cell[741318, 30410, 333, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[741688, 30427, 40, 0, 36, "Subsection"],
Cell[741731, 30429, 436, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[742204, 30453, 37, 0, 36, "Subsection"],
Cell[742244, 30455, 680, 25, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[742961, 30485, 30, 0, 36, "Subsection"],
Cell[742994, 30487, 297, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[743328, 30503, 33, 0, 36, "Subsection"],
Cell[743364, 30505, 217, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[743618, 30519, 39, 0, 36, "Subsection"],
Cell[743660, 30521, 265, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[743962, 30535, 35, 0, 36, "Subsection"],
Cell[744000, 30537, 286, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[744323, 30551, 44, 0, 36, "Subsection"],
Cell[744370, 30553, 1266, 44, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[745673, 30602, 36, 0, 36, "Subsection"],
Cell[745712, 30604, 1042, 39, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[746791, 30648, 33, 0, 36, "Subsection"],
Cell[746827, 30650, 878, 40, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[747742, 30695, 34, 0, 36, "Subsection"],
Cell[747779, 30697, 197, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748013, 30709, 31, 0, 36, "Subsection"],
Cell[748047, 30711, 3684, 139, 170, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[751768, 30855, 30, 0, 36, "Subsection"],
Cell[751801, 30857, 294, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[752132, 30873, 30, 0, 36, "Subsection"],
Cell[752165, 30875, 334, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[752536, 30889, 38, 0, 36, "Subsection"],
Cell[752577, 30891, 590, 24, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[753204, 30920, 40, 0, 36, "Subsection"],
Cell[753247, 30922, 827, 35, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[754111, 30962, 38, 0, 36, "Subsection"],
Cell[754152, 30964, 832, 32, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[755021, 31001, 28, 0, 36, "Subsection"],
Cell[755052, 31003, 1918, 66, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[757007, 31074, 30, 0, 36, "Subsection"],
Cell[757040, 31076, 1678, 69, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[758755, 31150, 32, 0, 36, "Subsection"],
Cell[758790, 31152, 3042, 124, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[761869, 31281, 36, 0, 36, "Subsection"],
Cell[761908, 31283, 1346, 50, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[763291, 31338, 34, 0, 36, "Subsection"],
Cell[763328, 31340, 5124, 188, 220, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[768489, 31533, 36, 0, 36, "Subsection"],
Cell[768528, 31535, 2551, 89, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[771116, 31629, 41, 0, 36, "Subsection"],
Cell[771160, 31631, 1152, 42, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[772349, 31678, 39, 0, 36, "Subsection"],
Cell[772391, 31680, 2624, 94, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[775052, 31779, 35, 0, 36, "Subsection"],
Cell[775090, 31781, 4482, 172, 142, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[779609, 31958, 43, 0, 36, "Subsection"],
Cell[779655, 31960, 1092, 39, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780784, 32004, 42, 0, 36, "Subsection"],
Cell[780829, 32006, 5712, 220, 293, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[786578, 32231, 40, 0, 36, "Subsection"],
Cell[786621, 32233, 1425, 50, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[788083, 32288, 50, 0, 36, "Subsection"],
Cell[788136, 32290, 2973, 100, 160, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[791146, 32395, 39, 0, 36, "Subsection"],
Cell[791188, 32397, 3632, 142, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[794857, 32544, 43, 0, 36, "Subsection"],
Cell[794903, 32546, 1339, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[796279, 32600, 35, 0, 36, "Subsection"],
Cell[796317, 32602, 906, 34, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[797260, 32641, 48, 0, 36, "Subsection"],
Cell[797311, 32643, 2717, 92, 152, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[800065, 32740, 26, 0, 36, "Subsection"],
Cell[800094, 32742, 8145, 346, 270, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[808276, 33093, 28, 0, 36, "Subsection"],
Cell[808307, 33095, 3068, 127, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[811412, 33227, 33, 0, 36, "Subsection"],
Cell[811448, 33229, 1762, 64, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[813247, 33298, 34, 0, 36, "Subsection"],
Cell[813284, 33300, 2960, 124, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[816281, 33429, 36, 0, 36, "Subsection"],
Cell[816320, 33431, 2583, 102, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[818940, 33538, 35, 0, 36, "Subsection"],
Cell[818978, 33540, 223, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[819238, 33553, 41, 0, 36, "Subsection"],
Cell[819282, 33555, 1153, 40, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[820472, 33600, 32, 0, 36, "Subsection"],
Cell[820507, 33602, 1321, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[821865, 33662, 32, 0, 36, "Subsection"],
Cell[821900, 33664, 2947, 120, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[824884, 33789, 34, 0, 36, "Subsection"],
Cell[824921, 33791, 2380, 93, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[827338, 33889, 35, 0, 36, "Subsection"],
Cell[827376, 33891, 1328, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[828741, 33951, 35, 0, 36, "Subsection"],
Cell[828779, 33953, 5908, 237, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[834724, 34195, 37, 0, 36, "Subsection"],
Cell[834764, 34197, 2526, 101, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[837327, 34303, 34, 0, 36, "Subsection"],
Cell[837364, 34305, 1353, 49, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[838754, 34359, 33, 0, 36, "Subsection"],
Cell[838790, 34361, 2716, 101, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[841543, 34467, 25, 0, 36, "Subsection"],
Cell[841571, 34469, 522, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[842130, 34497, 41, 0, 36, "Subsection"],
Cell[842174, 34499, 1134, 38, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[843345, 34542, 24, 0, 36, "Subsection"],
Cell[843372, 34544, 598, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[844007, 34569, 42, 0, 36, "Subsection"],
Cell[844052, 34571, 1134, 36, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[845223, 34612, 28, 0, 36, "Subsection"],
Cell[845254, 34614, 1233, 54, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[846524, 34673, 28, 0, 36, "Subsection"],
Cell[846555, 34675, 160, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[846752, 34686, 28, 0, 36, "Subsection"],
Cell[846783, 34688, 163, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[846983, 34699, 32, 0, 36, "Subsection"],
Cell[847018, 34701, 639, 24, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[847694, 34730, 31, 0, 36, "Subsection"],
Cell[847728, 34732, 316, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[848081, 34751, 31, 0, 36, "Subsection"],
Cell[848115, 34753, 126, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[848278, 34763, 35, 0, 46, "Subsection"],
Cell[848316, 34765, 762, 26, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[849115, 34796, 43, 0, 46, "Subsection"],
Cell[849161, 34798, 375, 14, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[849573, 34817, 34, 0, 46, "Subsection"],
Cell[849610, 34819, 1297, 51, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[850944, 34875, 33, 0, 46, "Subsection"],
Cell[850980, 34877, 1292, 51, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[852309, 34933, 36, 0, 46, "Subsection"],
Cell[852348, 34935, 198, 6, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[852583, 34946, 34, 0, 46, "Subsection"],
Cell[852620, 34948, 378, 16, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[853035, 34969, 36, 0, 46, "Subsection"],
Cell[853074, 34971, 388, 15, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[853499, 34991, 43, 0, 46, "Subsection"],
Cell[853545, 34993, 211, 6, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[853793, 35004, 36, 0, 46, "Subsection"],
Cell[853832, 35006, 169, 6, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[854038, 35017, 34, 0, 46, "Subsection"],
Cell[854075, 35019, 279, 10, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[854391, 35034, 38, 0, 46, "Subsection"],
Cell[854432, 35036, 190, 6, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[854659, 35047, 29, 0, 46, "Subsection"],
Cell[854691, 35049, 494, 18, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[855222, 35072, 45, 0, 46, "Subsection"],
Cell[855270, 35074, 1021, 37, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[856328, 35116, 50, 0, 46, "Subsection"],
Cell[856381, 35118, 1199, 38, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[857617, 35161, 29, 0, 46, "Subsection"],
Cell[857649, 35163, 446, 20, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[858132, 35188, 26, 0, 46, "Subsection"],
Cell[858161, 35190, 185, 8, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[858383, 35203, 26, 0, 46, "Subsection"],
Cell[858412, 35205, 185, 8, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[858634, 35218, 26, 0, 46, "Subsection"],
Cell[858663, 35220, 185, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[858885, 35233, 30, 0, 46, "Subsection"],
Cell[858918, 35235, 870, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[859825, 35278, 35, 0, 36, "Subsection"],
Cell[859863, 35280, 271, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[860171, 35294, 35, 0, 36, "Subsection"],
Cell[860209, 35296, 659, 25, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[860905, 35326, 35, 0, 36, "Subsection"],
Cell[860943, 35328, 938, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[861918, 35371, 36, 0, 36, "Subsection"],
Cell[861957, 35373, 428, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[862422, 35398, 36, 0, 36, "Subsection"],
Cell[862461, 35400, 2350, 87, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[864848, 35492, 33, 0, 36, "Subsection"],
Cell[864884, 35494, 1288, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[866209, 35554, 51, 0, 36, "Subsection"],
Cell[866263, 35556, 703, 23, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[867003, 35584, 49, 0, 36, "Subsection"],
Cell[867055, 35586, 735, 26, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[867827, 35617, 38, 0, 36, "Subsection"],
Cell[867868, 35619, 466, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[868371, 35644, 32, 0, 36, "Subsection"],
Cell[868406, 35646, 381, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[868824, 35665, 35, 0, 36, "Subsection"],
Cell[868862, 35667, 392, 14, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[869291, 35686, 28, 0, 36, "Subsection"],
Cell[869322, 35688, 300, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[869659, 35706, 36, 0, 36, "Subsection"],
Cell[869698, 35708, 398, 14, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[870133, 35727, 32, 0, 36, "Subsection"],
Cell[870168, 35729, 4203, 167, 186, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[874408, 35901, 35, 0, 36, "Subsection"],
Cell[874446, 35903, 410, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[874893, 35927, 35, 0, 36, "Subsection"],
Cell[874931, 35929, 423, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[875391, 35947, 25, 0, 36, "Subsection"],
Cell[875419, 35949, 317, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[875773, 35964, 39, 0, 36, "Subsection"],
Cell[875815, 35966, 4551, 173, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[880403, 36144, 45, 0, 36, "Subsection"],
Cell[880451, 36146, 4608, 173, 214, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[885096, 36324, 42, 0, 36, "Subsection"],
Cell[885141, 36326, 2152, 70, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[887330, 36401, 37, 0, 36, "Subsection"],
Cell[887370, 36403, 5886, 227, 218, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[893293, 36635, 45, 0, 36, "Subsection"],
Cell[893341, 36637, 365, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[893743, 36659, 36, 0, 36, "Subsection"],
Cell[893782, 36661, 314, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[894133, 36679, 44, 0, 36, "Subsection"],
Cell[894180, 36681, 1103, 44, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[895320, 36730, 35, 0, 36, "Subsection"],
Cell[895358, 36732, 1301, 53, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[896696, 36790, 35, 0, 36, "Subsection"],
Cell[896734, 36792, 1389, 56, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[898160, 36853, 33, 0, 36, "Subsection"],
Cell[898196, 36855, 2623, 94, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[900856, 36954, 38, 0, 36, "Subsection"],
Cell[900897, 36956, 3502, 121, 168, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[904436, 37082, 32, 0, 36, "Subsection"],
Cell[904471, 37084, 2786, 110, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[907294, 37199, 32, 0, 36, "Subsection"],
Cell[907329, 37201, 294, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[907660, 37218, 35, 0, 36, "Subsection"],
Cell[907698, 37220, 359, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[908094, 37238, 38, 0, 36, "Subsection"],
Cell[908135, 37240, 1440, 50, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[909612, 37295, 32, 0, 36, "Subsection"],
Cell[909647, 37297, 919, 33, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[910603, 37335, 31, 0, 36, "Subsection"],
Cell[910637, 37337, 520, 18, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[911194, 37360, 43, 0, 36, "Subsection"],
Cell[911240, 37362, 397, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[911674, 37380, 41, 0, 36, "Subsection"],
Cell[911718, 37382, 178, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[911933, 37393, 29, 0, 36, "Subsection"],
Cell[911965, 37395, 1876, 68, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[913878, 37468, 26, 0, 36, "Subsection"],
Cell[913907, 37470, 1896, 64, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[915840, 37539, 33, 0, 36, "Subsection"],
Cell[915876, 37541, 307, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[916220, 37559, 49, 0, 36, "Subsection"],
Cell[916272, 37561, 2247, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[918556, 37637, 38, 0, 36, "Subsection"],
Cell[918597, 37639, 2220, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[920854, 37715, 48, 0, 36, "Subsection"],
Cell[920905, 37717, 2241, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[923183, 37793, 37, 0, 36, "Subsection"],
Cell[923223, 37795, 2218, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[925478, 37871, 28, 0, 36, "Subsection"],
Cell[925509, 37873, 1751, 66, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927297, 37944, 32, 0, 36, "Subsection"],
Cell[927332, 37946, 1273, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[928642, 38002, 32, 0, 36, "Subsection"],
Cell[928677, 38004, 651, 26, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[929365, 38035, 30, 0, 36, "Subsection"],
Cell[929398, 38037, 1798, 81, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[931233, 38123, 26, 0, 36, "Subsection"],
Cell[931262, 38125, 332, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[931631, 38140, 33, 0, 36, "Subsection"],
Cell[931667, 38142, 5987, 245, 296, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[937691, 38392, 34, 0, 36, "Subsection"],
Cell[937728, 38394, 234, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[937999, 38407, 38, 0, 36, "Subsection"],
Cell[938040, 38409, 735, 31, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[938812, 38445, 34, 0, 36, "Subsection"],
Cell[938849, 38447, 1660, 63, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[940546, 38515, 42, 0, 36, "Subsection"],
Cell[940591, 38517, 2246, 109, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[942874, 38631, 48, 0, 36, "Subsection"],
Cell[942925, 38633, 1802, 63, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[944764, 38701, 37, 0, 36, "Subsection"],
Cell[944804, 38703, 7337, 258, 320, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[952178, 38966, 37, 0, 36, "Subsection"],
Cell[952218, 38968, 1444, 49, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[953699, 39022, 36, 0, 36, "Subsection"],
Cell[953738, 39024, 1460, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[955235, 39078, 32, 0, 36, "Subsection"],
Cell[955270, 39080, 2099, 80, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[957406, 39165, 26, 0, 36, "Subsection"],
Cell[957435, 39167, 684, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[958156, 39199, 35, 0, 36, "Subsection"],
Cell[958194, 39201, 1810, 77, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[960041, 39283, 38, 0, 36, "Subsection"],
Cell[960082, 39285, 1338, 57, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[961457, 39347, 26, 0, 36, "Subsection"],
Cell[961486, 39349, 691, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[962214, 39381, 33, 0, 36, "Subsection"],
Cell[962250, 39383, 1774, 63, 165, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964061, 39451, 37, 0, 36, "Subsection"],
Cell[964101, 39453, 474, 21, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964612, 39479, 46, 0, 36, "Subsection"],
Cell[964661, 39481, 207, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964905, 39492, 27, 0, 36, "Subsection"],
Cell[964935, 39494, 4132, 171, 154, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[969104, 39670, 36, 0, 36, "Subsection"],
Cell[969143, 39672, 477, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[969657, 39696, 37, 0, 36, "Subsection"],
Cell[969697, 39698, 1414, 59, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[971148, 39762, 47, 0, 36, "Subsection"],
Cell[971198, 39764, 1881, 71, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[973116, 39840, 24, 0, 36, "Subsection"],
Cell[973143, 39842, 309, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[973489, 39857, 34, 0, 36, "Subsection"],
Cell[973526, 39859, 259, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[973822, 39873, 25, 0, 36, "Subsection"],
Cell[973850, 39875, 321, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[974208, 39890, 25, 0, 36, "Subsection"],
Cell[974236, 39892, 324, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[974597, 39907, 25, 0, 36, "Subsection"],
Cell[974625, 39909, 321, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[974983, 39924, 25, 0, 36, "Subsection"],
Cell[975011, 39926, 327, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[975375, 39941, 27, 0, 36, "Subsection"],
Cell[975405, 39943, 365, 12, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[975807, 39960, 28, 0, 36, "Subsection"],
Cell[975838, 39962, 302, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[976177, 39977, 38, 0, 36, "Subsection"],
Cell[976218, 39979, 2201, 84, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[978456, 40068, 32, 0, 36, "Subsection"],
Cell[978491, 40070, 166, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[978694, 40082, 36, 0, 36, "Subsection"],
Cell[978733, 40084, 394, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[979164, 40102, 39, 0, 36, "Subsection"],
Cell[979206, 40104, 388, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[979631, 40123, 35, 0, 36, "Subsection"],
Cell[979669, 40125, 2985, 122, 174, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[982691, 40252, 25, 0, 36, "Subsection"],
Cell[982719, 40254, 3299, 124, 176, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[986055, 40383, 34, 0, 36, "Subsection"],
Cell[986092, 40385, 1910, 75, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[988039, 40465, 33, 0, 36, "Subsection"],
Cell[988075, 40467, 1106, 48, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[989218, 40520, 31, 0, 36, "Subsection"],
Cell[989252, 40522, 943, 41, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[990232, 40568, 30, 0, 36, "Subsection"],
Cell[990265, 40570, 294, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[990596, 40586, 28, 0, 36, "Subsection"],
Cell[990627, 40588, 362, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[991026, 40606, 32, 0, 36, "Subsection"],
Cell[991061, 40608, 3476, 144, 225, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[994574, 40757, 28, 0, 36, "Subsection"],
Cell[994605, 40759, 2784, 124, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[997426, 40888, 37, 0, 36, "Subsection"],
Cell[997466, 40890, 647, 30, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[998150, 40925, 36, 0, 36, "Subsection"],
Cell[998189, 40927, 424, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[998650, 40949, 37, 0, 36, "Subsection"],
Cell[998690, 40951, 274, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[999001, 40967, 35, 0, 36, "Subsection"],
Cell[999039, 40969, 642, 30, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[999718, 41004, 35, 0, 36, "Subsection"],
Cell[999756, 41006, 495, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000288, 41029, 35, 0, 36, "Subsection"],
Cell[1000326, 41031, 429, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000792, 41053, 26, 0, 36, "Subsection"],
Cell[1000821, 41055, 179, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1001037, 41066, 30, 0, 36, "Subsection"],
Cell[1001070, 41068, 156, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1001263, 41080, 39, 0, 36, "Subsection"],
Cell[1001305, 41082, 2121, 92, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1003463, 41179, 31, 0, 36, "Subsection"],
Cell[1003497, 41181, 850, 36, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1004384, 41222, 31, 0, 36, "Subsection"],
Cell[1004418, 41224, 241, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1004696, 41238, 30, 0, 36, "Subsection"],
Cell[1004729, 41240, 619, 21, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1005385, 41266, 32, 0, 36, "Subsection"],
Cell[1005420, 41268, 1375, 61, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1006832, 41334, 34, 0, 36, "Subsection"],
Cell[1006869, 41336, 414, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1007320, 41359, 38, 0, 36, "Subsection"],
Cell[1007361, 41361, 498, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1007896, 41389, 31, 0, 36, "Subsection"],
Cell[1007930, 41391, 1399, 58, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009366, 41454, 35, 0, 36, "Subsection"],
Cell[1009404, 41456, 1188, 55, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1010629, 41516, 33, 0, 36, "Subsection"],
Cell[1010665, 41518, 587, 26, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1011289, 41549, 34, 0, 36, "Subsection"],
Cell[1011326, 41551, 467, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1011830, 41576, 35, 0, 36, "Subsection"],
Cell[1011868, 41578, 483, 21, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1012388, 41604, 26, 0, 36, "Subsection"],
Cell[1012417, 41606, 407, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1012861, 41631, 40, 0, 36, "Subsection"],
Cell[1012904, 41633, 2720, 118, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1015661, 41756, 31, 0, 36, "Subsection"],
Cell[1015695, 41758, 2524, 96, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1018256, 41859, 45, 0, 36, "Subsection"],
Cell[1018304, 41861, 503, 19, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1018844, 41885, 35, 0, 36, "Subsection"],
Cell[1018882, 41887, 1029, 45, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1019948, 41937, 29, 0, 36, "Subsection"],
Cell[1019980, 41939, 342, 12, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1020359, 41956, 37, 0, 36, "Subsection"],
Cell[1020399, 41958, 3058, 142, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1023494, 42105, 30, 0, 36, "Subsection"],
Cell[1023527, 42107, 360, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1023924, 42125, 29, 0, 36, "Subsection"],
Cell[1023956, 42127, 483, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1024476, 42149, 38, 0, 36, "Subsection"],
Cell[1024517, 42151, 2115, 87, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1026669, 42243, 35, 0, 36, "Subsection"],
Cell[1026707, 42245, 1682, 65, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1028426, 42315, 36, 0, 36, "Subsection"],
Cell[1028465, 42317, 1439, 55, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1029941, 42377, 30, 0, 36, "Subsection"],
Cell[1029974, 42379, 2466, 94, 186, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1032477, 42478, 34, 0, 36, "Subsection"],
Cell[1032514, 42480, 1777, 71, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1034328, 42556, 35, 0, 36, "Subsection"],
Cell[1034366, 42558, 2931, 117, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1037334, 42680, 32, 0, 36, "Subsection"],
Cell[1037369, 42682, 591, 23, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1037997, 42710, 34, 0, 36, "Subsection"],
Cell[1038034, 42712, 890, 36, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1038961, 42753, 34, 0, 36, "Subsection"],
Cell[1038998, 42755, 1394, 50, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1040429, 42810, 38, 0, 36, "Subsection"],
Cell[1040470, 42812, 1859, 72, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1042366, 42889, 36, 0, 36, "Subsection"],
Cell[1042405, 42891, 617, 20, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1043059, 42916, 37, 0, 36, "Subsection"],
Cell[1043099, 42918, 1670, 68, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1044806, 42991, 47, 0, 36, "Subsection"],
Cell[1044856, 42993, 476, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1045369, 43016, 33, 0, 36, "Subsection"],
Cell[1045405, 43018, 4008, 151, 148, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1049450, 43174, 32, 0, 36, "Subsection"],
Cell[1049485, 43176, 352, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1049874, 43195, 32, 0, 36, "Subsection"],
Cell[1049909, 43197, 867, 38, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1050813, 43240, 37, 0, 36, "Subsection"],
Cell[1050853, 43242, 1104, 43, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1051994, 43290, 42, 0, 36, "Subsection"],
Cell[1052039, 43292, 245, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1052321, 43305, 43, 0, 36, "Subsection"],
Cell[1052367, 43307, 243, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1052647, 43320, 45, 0, 36, "Subsection"],
Cell[1052695, 43322, 370, 15, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1053102, 43342, 29, 0, 36, "Subsection"],
Cell[1053134, 43344, 325, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1053496, 43361, 42, 0, 36, "Subsection"],
Cell[1053541, 43363, 548, 15, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1054126, 43383, 42, 0, 36, "Subsection"],
Cell[1054171, 43385, 1229, 49, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1055437, 43439, 38, 0, 36, "Subsection"],
Cell[1055478, 43441, 1251, 53, 133, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1056766, 43499, 40, 0, 36, "Subsection"],
Cell[1056809, 43501, 1039, 39, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1057885, 43545, 35, 0, 36, "Subsection"],
Cell[1057923, 43547, 1494, 66, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1059454, 43618, 41, 0, 36, "Subsection"],
Cell[1059498, 43620, 2087, 79, 114, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1061622, 43704, 34, 0, 36, "Subsection"],
Cell[1061659, 43706, 1187, 51, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1062883, 43762, 40, 0, 36, "Subsection"],
Cell[1062926, 43764, 640, 22, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1063603, 43791, 38, 0, 36, "Subsection"],
Cell[1063644, 43793, 841, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1064522, 43829, 38, 0, 36, "Subsection"],
Cell[1064563, 43831, 554, 21, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1065154, 43857, 34, 0, 36, "Subsection"],
Cell[1065191, 43859, 566, 26, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1065794, 43890, 32, 0, 36, "Subsection"],
Cell[1065829, 43892, 705, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1066571, 43928, 32, 0, 36, "Subsection"],
Cell[1066606, 43930, 2006, 81, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1068649, 44016, 37, 0, 36, "Subsection"],
Cell[1068689, 44018, 611, 23, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1069337, 44046, 38, 0, 36, "Subsection"],
Cell[1069378, 44048, 3638, 163, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1073053, 44216, 40, 0, 36, "Subsection"],
Cell[1073096, 44218, 1720, 73, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1074853, 44296, 34, 0, 36, "Subsection"],
Cell[1074890, 44298, 250, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1075177, 44311, 38, 0, 36, "Subsection"],
Cell[1075218, 44313, 2325, 90, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1077580, 44408, 35, 0, 36, "Subsection"],
Cell[1077618, 44410, 881, 31, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1078536, 44446, 30, 0, 36, "Subsection"],
Cell[1078569, 44448, 2041, 76, 163, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1080647, 44529, 40, 0, 36, "Subsection"],
Cell[1080690, 44531, 598, 23, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1081325, 44559, 38, 0, 36, "Subsection"],
Cell[1081366, 44561, 3842, 143, 170, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1085245, 44709, 38, 0, 36, "Subsection"],
Cell[1085286, 44711, 829, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1086152, 44747, 36, 0, 36, "Subsection"],
Cell[1086191, 44749, 2291, 80, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1088519, 44834, 35, 0, 36, "Subsection"],
Cell[1088557, 44836, 3213, 133, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1091807, 44974, 30, 0, 36, "Subsection"],
Cell[1091840, 44976, 219, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1092096, 44989, 31, 0, 36, "Subsection"],
Cell[1092130, 44991, 1115, 38, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1093282, 45034, 29, 0, 36, "Subsection"],
Cell[1093314, 45036, 1627, 60, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1094978, 45101, 31, 0, 36, "Subsection"],
Cell[1095012, 45103, 1618, 60, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1096667, 45168, 31, 0, 36, "Subsection"],
Cell[1096701, 45170, 3242, 136, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1099980, 45311, 28, 0, 36, "Subsection"],
Cell[1100011, 45313, 7570, 296, 320, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1107618, 45614, 36, 0, 36, "Subsection"],
Cell[1107657, 45616, 551, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1108245, 45643, 25, 0, 36, "Subsection"],
Cell[1108273, 45645, 189, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1108499, 45656, 25, 0, 36, "Subsection"],
Cell[1108527, 45658, 189, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1108753, 45669, 25, 0, 36, "Subsection"],
Cell[1108781, 45671, 187, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1109005, 45682, 25, 0, 36, "Subsection"],
Cell[1109033, 45684, 180, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1109250, 45695, 25, 0, 36, "Subsection"],
Cell[1109278, 45697, 179, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1109494, 45708, 25, 0, 36, "Subsection"],
Cell[1109522, 45710, 179, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1109738, 45721, 39, 0, 36, "Subsection"],
Cell[1109780, 45723, 1118, 47, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1110935, 45775, 28, 0, 36, "Subsection"],
Cell[1110966, 45777, 771, 27, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1111774, 45809, 34, 0, 36, "Subsection"],
Cell[1111811, 45811, 384, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1112232, 45833, 30, 0, 36, "Subsection"],
Cell[1112265, 45835, 313, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1112615, 45849, 27, 0, 36, "Subsection"],
Cell[1112645, 45851, 161, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1112843, 45863, 39, 0, 36, "Subsection"],
Cell[1112885, 45865, 893, 30, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1113815, 45900, 33, 0, 36, "Subsection"],
Cell[1113851, 45902, 1819, 68, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1115707, 45975, 33, 0, 36, "Subsection"],
Cell[1115743, 45977, 1745, 58, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1117525, 46040, 40, 0, 36, "Subsection"],
Cell[1117568, 46042, 1797, 56, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1119402, 46103, 31, 0, 36, "Subsection"],
Cell[1119436, 46105, 913, 36, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1120386, 46146, 32, 0, 36, "Subsection"],
Cell[1120421, 46148, 3202, 145, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1123660, 46298, 32, 0, 36, "Subsection"],
Cell[1123695, 46300, 207, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1123939, 46313, 28, 0, 36, "Subsection"],
Cell[1123970, 46315, 1531, 50, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1125538, 46370, 36, 0, 36, "Subsection"],
Cell[1125577, 46372, 334, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1125948, 46390, 38, 0, 36, "Subsection"],
Cell[1125989, 46392, 598, 23, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1126624, 46420, 25, 0, 36, "Subsection"],
Cell[1126652, 46422, 183, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1126872, 46433, 25, 0, 36, "Subsection"],
Cell[1126900, 46435, 187, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127124, 46446, 25, 0, 36, "Subsection"],
Cell[1127152, 46448, 165, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1127354, 46459, 39, 0, 36, "Subsection"],
Cell[1127396, 46461, 3908, 179, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1131341, 46645, 36, 0, 36, "Subsection"],
Cell[1131380, 46647, 2022, 91, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1133439, 46743, 37, 0, 36, "Subsection"],
Cell[1133479, 46745, 3813, 151, 176, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1137329, 46901, 40, 0, 36, "Subsection"],
Cell[1137372, 46903, 480, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1137889, 46926, 26, 0, 36, "Subsection"],
Cell[1137918, 46928, 346, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1138301, 46944, 25, 0, 36, "Subsection"],
Cell[1138329, 46946, 343, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1138709, 46962, 35, 0, 36, "Subsection"],
Cell[1138747, 46964, 914, 40, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1139698, 47009, 32, 0, 36, "Subsection"],
Cell[1139733, 47011, 741, 33, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1140511, 47049, 32, 0, 36, "Subsection"],
Cell[1140546, 47051, 427, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1141010, 47075, 46, 0, 36, "Subsection"],
Cell[1141059, 47077, 886, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1141982, 47116, 36, 0, 36, "Subsection"],
Cell[1142021, 47118, 519, 25, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1142577, 47148, 33, 0, 36, "Subsection"],
Cell[1142613, 47150, 4967, 177, 272, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1147617, 47332, 42, 0, 36, "Subsection"],
Cell[1147662, 47334, 2921, 115, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1150620, 47454, 32, 0, 36, "Subsection"],
Cell[1150655, 47456, 1813, 69, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1152505, 47530, 32, 0, 36, "Subsection"],
Cell[1152540, 47532, 1083, 48, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1153660, 47585, 31, 0, 36, "Subsection"],
Cell[1153694, 47587, 1054, 48, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1154785, 47640, 40, 0, 36, "Subsection"],
Cell[1154828, 47642, 978, 38, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1155843, 47685, 30, 0, 36, "Subsection"],
Cell[1155876, 47687, 504, 24, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1156417, 47716, 40, 0, 36, "Subsection"],
Cell[1156460, 47718, 1576, 48, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1158073, 47771, 34, 0, 36, "Subsection"],
Cell[1158110, 47773, 1236, 41, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1159383, 47819, 39, 0, 36, "Subsection"],
Cell[1159425, 47821, 791, 31, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1160253, 47857, 41, 0, 36, "Subsection"],
Cell[1160297, 47859, 753, 27, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1161087, 47891, 39, 0, 36, "Subsection"],
Cell[1161129, 47893, 1281, 49, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1162447, 47947, 40, 0, 36, "Subsection"],
Cell[1162490, 47949, 5025, 175, 266, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1167552, 48129, 49, 0, 46, "Subsection"],
Cell[1167604, 48131, 2935, 115, 194, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170576, 48251, 44, 0, 46, "Subsection"],
Cell[1170623, 48253, 916, 37, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1171576, 48295, 37, 0, 46, "Subsection"],
Cell[1171616, 48297, 4572, 167, 302, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1176225, 48469, 46, 0, 46, "Subsection"],
Cell[1176274, 48471, 2929, 115, 176, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1179240, 48591, 44, 0, 46, "Subsection"],
Cell[1179287, 48593, 636, 27, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1179960, 48625, 32, 0, 46, "Subsection"],
Cell[1179995, 48627, 2393, 100, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1182425, 48732, 30, 0, 46, "Subsection"],
Cell[1182458, 48734, 4515, 164, 234, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1187010, 48903, 39, 0, 46, "Subsection"],
Cell[1187052, 48905, 2915, 115, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1190004, 49025, 31, 0, 36, "Subsection"],
Cell[1190038, 49027, 4534, 167, 250, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1194609, 49199, 40, 0, 36, "Subsection"],
Cell[1194652, 49201, 2917, 115, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1197606, 49321, 38, 0, 36, "Subsection"],
Cell[1197647, 49323, 606, 27, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1198290, 49355, 34, 0, 36, "Subsection"],
Cell[1198327, 49357, 556, 17, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1198920, 49379, 30, 0, 36, "Subsection"],
Cell[1198953, 49381, 790, 36, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1199780, 49422, 29, 0, 36, "Subsection"],
Cell[1199812, 49424, 314, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1200163, 49439, 35, 0, 36, "Subsection"],
Cell[1200201, 49441, 1223, 47, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1201461, 49493, 31, 0, 36, "Subsection"],
Cell[1201495, 49495, 2437, 95, 165, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1203969, 49595, 46, 0, 36, "Subsection"],
Cell[1204018, 49597, 583, 22, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1204638, 49624, 40, 0, 36, "Subsection"],
Cell[1204681, 49626, 539, 21, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1205257, 49652, 44, 0, 36, "Subsection"],
Cell[1205304, 49654, 572, 22, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1205913, 49681, 26, 0, 36, "Subsection"],
Cell[1205942, 49683, 345, 11, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1206324, 49699, 28, 0, 36, "Subsection"],
Cell[1206355, 49701, 384, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1206776, 49724, 31, 0, 36, "Subsection"],
Cell[1206810, 49726, 3710, 157, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1210557, 49888, 28, 0, 36, "Subsection"],
Cell[1210588, 49890, 707, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1211332, 49923, 28, 0, 36, "Subsection"],
Cell[1211363, 49925, 708, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1212108, 49958, 35, 0, 36, "Subsection"],
Cell[1212146, 49960, 947, 36, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1213130, 50001, 39, 0, 36, "Subsection"],
Cell[1213172, 50003, 991, 36, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1214200, 50044, 38, 0, 36, "Subsection"],
Cell[1214241, 50046, 2532, 102, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1216810, 50153, 26, 0, 36, "Subsection"],
Cell[1216839, 50155, 2647, 107, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1219523, 50267, 30, 0, 36, "Subsection"],
Cell[1219556, 50269, 2448, 108, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1222041, 50382, 36, 0, 36, "Subsection"],
Cell[1222080, 50384, 1953, 85, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1224070, 50474, 27, 0, 36, "Subsection"],
Cell[1224100, 50476, 215, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1224352, 50489, 37, 0, 36, "Subsection"],
Cell[1224392, 50491, 384, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1224813, 50510, 34, 0, 36, "Subsection"],
Cell[1224850, 50512, 2327, 82, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1227214, 50599, 25, 0, 36, "Subsection"],
Cell[1227242, 50601, 220, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1227499, 50614, 25, 0, 36, "Subsection"],
Cell[1227527, 50616, 221, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1227785, 50629, 25, 0, 36, "Subsection"],
Cell[1227813, 50631, 220, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1228070, 50644, 27, 0, 36, "Subsection"],
Cell[1228100, 50646, 383, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1228520, 50669, 32, 0, 36, "Subsection"],
Cell[1228555, 50671, 623, 17, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1229215, 50693, 37, 0, 36, "Subsection"],
Cell[1229255, 50695, 3772, 142, 186, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1233064, 50842, 31, 0, 36, "Subsection"],
Cell[1233098, 50844, 2250, 90, 165, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1235385, 50939, 32, 0, 36, "Subsection"],
Cell[1235420, 50941, 358, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1235815, 50959, 34, 0, 36, "Subsection"],
Cell[1235852, 50961, 768, 31, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1236657, 50997, 28, 0, 36, "Subsection"],
Cell[1236688, 50999, 2255, 92, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1238980, 51096, 39, 0, 36, "Subsection"],
Cell[1239022, 51098, 323, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1239382, 51117, 37, 0, 36, "Subsection"],
Cell[1239422, 51119, 259, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1239718, 51133, 33, 0, 36, "Subsection"],
Cell[1239754, 51135, 280, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1240071, 51149, 36, 0, 36, "Subsection"],
Cell[1240110, 51151, 785, 31, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1240932, 51187, 37, 0, 36, "Subsection"],
Cell[1240972, 51189, 223, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1241232, 51202, 30, 0, 36, "Subsection"],
Cell[1241265, 51204, 853, 34, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1242155, 51243, 33, 0, 36, "Subsection"],
Cell[1242191, 51245, 631, 24, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1242859, 51274, 34, 0, 36, "Subsection"],
Cell[1242896, 51276, 943, 36, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1243876, 51317, 29, 0, 36, "Subsection"],
Cell[1243908, 51319, 466, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1244411, 51347, 42, 0, 36, "Subsection"],
Cell[1244456, 51349, 541, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1245034, 51377, 34, 0, 36, "Subsection"],
Cell[1245071, 51379, 449, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1245557, 51397, 34, 0, 36, "Subsection"],
Cell[1245594, 51399, 401, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1246032, 51423, 35, 0, 36, "Subsection"],
Cell[1246070, 51425, 750, 35, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1246857, 51465, 36, 0, 36, "Subsection"],
Cell[1246896, 51467, 1648, 53, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1248581, 51525, 35, 0, 36, "Subsection"],
Cell[1248619, 51527, 1278, 42, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1249934, 51574, 37, 0, 36, "Subsection"],
Cell[1249974, 51576, 1919, 69, 119, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1251930, 51650, 43, 0, 36, "Subsection"],
Cell[1251976, 51652, 2397, 85, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1254410, 51742, 39, 0, 36, "Subsection"],
Cell[1254452, 51744, 4552, 173, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1259041, 51922, 45, 0, 36, "Subsection"],
Cell[1259089, 51924, 4610, 173, 214, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1263736, 52102, 44, 0, 36, "Subsection"],
Cell[1263783, 52104, 5959, 232, 226, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1269779, 52341, 35, 0, 36, "Subsection"],
Cell[1269817, 52343, 1752, 60, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1271606, 52408, 42, 0, 36, "Subsection"],
Cell[1271651, 52410, 2084, 69, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1273772, 52484, 37, 0, 36, "Subsection"],
Cell[1273812, 52486, 3602, 138, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1277451, 52629, 37, 0, 36, "Subsection"],
Cell[1277491, 52631, 1650, 54, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1279178, 52690, 36, 0, 36, "Subsection"],
Cell[1279217, 52692, 314, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1279568, 52710, 31, 0, 36, "Subsection"],
Cell[1279602, 52712, 909, 33, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1280548, 52750, 34, 0, 36, "Subsection"],
Cell[1280585, 52752, 383, 15, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1281005, 52772, 30, 0, 36, "Subsection"],
Cell[1281038, 52774, 1149, 39, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1282224, 52818, 36, 0, 36, "Subsection"],
Cell[1282263, 52820, 983, 33, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1283283, 52858, 25, 0, 36, "Subsection"],
Cell[1283311, 52860, 223, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1283571, 52873, 25, 0, 36, "Subsection"],
Cell[1283599, 52875, 224, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1283860, 52888, 25, 0, 36, "Subsection"],
Cell[1283888, 52890, 224, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1284149, 52903, 38, 0, 36, "Subsection"],
Cell[1284190, 52905, 1876, 68, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1286103, 52978, 37, 0, 36, "Subsection"],
Cell[1286143, 52980, 170, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1286350, 52991, 38, 0, 36, "Subsection"],
Cell[1286391, 52993, 630, 25, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1287058, 53023, 34, 0, 36, "Subsection"],
Cell[1287095, 53025, 1130, 48, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1288262, 53078, 39, 0, 36, "Subsection"],
Cell[1288304, 53080, 1259, 48, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1289600, 53133, 32, 0, 36, "Subsection"],
Cell[1289635, 53135, 565, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1290237, 53160, 32, 0, 36, "Subsection"],
Cell[1290272, 53162, 270, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1290579, 53178, 34, 0, 36, "Subsection"],
Cell[1290616, 53180, 472, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1291125, 53204, 30, 0, 36, "Subsection"],
Cell[1291158, 53206, 688, 27, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1291883, 53238, 34, 0, 36, "Subsection"],
Cell[1291920, 53240, 201, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1292158, 53251, 32, 0, 36, "Subsection"],
Cell[1292193, 53253, 1443, 49, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1293673, 53307, 41, 0, 36, "Subsection"],
Cell[1293717, 53309, 1279, 47, 98, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1295033, 53361, 30, 0, 36, "Subsection"],
Cell[1295066, 53363, 178, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1295281, 53376, 29, 0, 36, "Subsection"],
Cell[1295313, 53378, 859, 37, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1296209, 53420, 37, 0, 36, "Subsection"],
Cell[1296249, 53422, 738, 25, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1297024, 53452, 42, 0, 36, "Subsection"],
Cell[1297069, 53454, 7653, 312, 362, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1304759, 53771, 37, 0, 36, "Subsection"],
Cell[1304799, 53773, 1251, 39, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1306087, 53817, 43, 0, 36, "Subsection"],
Cell[1306133, 53819, 860, 32, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1307030, 53856, 34, 0, 36, "Subsection"],
Cell[1307067, 53858, 648, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1307752, 53885, 35, 0, 36, "Subsection"],
Cell[1307790, 53887, 513, 21, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1308340, 53913, 36, 0, 36, "Subsection"],
Cell[1308379, 53915, 1225, 36, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1309641, 53956, 41, 0, 36, "Subsection"],
Cell[1309685, 53958, 792, 31, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1310514, 53994, 40, 0, 36, "Subsection"],
Cell[1310557, 53996, 254, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1310848, 54010, 38, 0, 36, "Subsection"],
Cell[1310889, 54012, 1321, 52, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1312247, 54069, 34, 0, 36, "Subsection"],
Cell[1312284, 54071, 2070, 71, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1314391, 54147, 37, 0, 36, "Subsection"],
Cell[1314431, 54149, 710, 29, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1315178, 54183, 38, 0, 36, "Subsection"],
Cell[1315219, 54185, 651, 28, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1315907, 54218, 36, 0, 36, "Subsection"],
Cell[1315946, 54220, 1140, 46, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1317123, 54271, 31, 0, 36, "Subsection"],
Cell[1317157, 54273, 1029, 41, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1318223, 54319, 38, 0, 36, "Subsection"],
Cell[1318264, 54321, 2256, 100, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1320557, 54426, 49, 0, 36, "Subsection"],
Cell[1320609, 54428, 1601, 59, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1322247, 54492, 42, 0, 36, "Subsection"],
Cell[1322292, 54494, 467, 17, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1322796, 54516, 34, 0, 36, "Subsection"],
Cell[1322833, 54518, 1526, 59, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324396, 54582, 40, 0, 36, "Subsection"],
Cell[1324439, 54584, 331, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324807, 54603, 47, 0, 36, "Subsection"],
Cell[1324857, 54605, 1035, 37, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1325929, 54647, 43, 0, 36, "Subsection"],
Cell[1325975, 54649, 931, 34, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1326943, 54688, 41, 0, 36, "Subsection"],
Cell[1326987, 54690, 449, 16, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1327473, 54711, 35, 0, 36, "Subsection"],
Cell[1327511, 54713, 927, 40, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1328475, 54758, 33, 0, 36, "Subsection"],
Cell[1328511, 54760, 160, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1328708, 54772, 35, 0, 36, "Subsection"],
Cell[1328746, 54774, 1799, 67, 127, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1330582, 54846, 45, 0, 36, "Subsection"],
Cell[1330630, 54848, 5110, 202, 202, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1335777, 55055, 38, 0, 36, "Subsection"],
Cell[1335818, 55057, 962, 42, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1336817, 55104, 43, 0, 36, "Subsection"],
Cell[1336863, 55106, 283, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337183, 55121, 30, 0, 36, "Subsection"],
Cell[1337216, 55123, 365, 17, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337618, 55145, 35, 0, 36, "Subsection"],
Cell[1337656, 55147, 2516, 100, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1340209, 55252, 53, 0, 36, "Subsection"],
Cell[1340265, 55254, 593, 18, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1340895, 55277, 39, 0, 36, "Subsection"],
Cell[1340937, 55279, 205, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1341179, 55290, 34, 0, 36, "Subsection"],
Cell[1341216, 55292, 858, 34, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1342111, 55331, 46, 0, 36, "Subsection"],
Cell[1342160, 55333, 357, 13, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1342554, 55351, 33, 0, 36, "Subsection"],
Cell[1342590, 55353, 1812, 87, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1344439, 55445, 34, 0, 36, "Subsection"],
Cell[1344476, 55447, 703, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1345216, 55480, 26, 0, 36, "Subsection"],
Cell[1345245, 55482, 2388, 105, 98, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1347670, 55592, 49, 0, 36, "Subsection"],
Cell[1347722, 55594, 298, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1348057, 55608, 43, 0, 36, "Subsection"],
Cell[1348103, 55610, 2513, 97, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1350653, 55712, 43, 0, 36, "Subsection"],
Cell[1350699, 55714, 1120, 46, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1351856, 55765, 44, 0, 36, "Subsection"],
Cell[1351903, 55767, 1212, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1353152, 55823, 45, 0, 36, "Subsection"],
Cell[1353200, 55825, 1086, 44, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1354323, 55874, 42, 0, 36, "Subsection"],
Cell[1354368, 55876, 1318, 57, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1355723, 55938, 39, 0, 36, "Subsection"],
Cell[1355765, 55940, 1190, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1356992, 55994, 40, 0, 36, "Subsection"],
Cell[1357035, 55996, 1604, 67, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1358676, 56068, 50, 0, 36, "Subsection"],
Cell[1358729, 56070, 1178, 49, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1359944, 56124, 53, 0, 36, "Subsection"],
Cell[1360000, 56126, 1001, 39, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1361038, 56170, 48, 0, 46, "Subsection"],
Cell[1361089, 56172, 397, 18, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1361523, 56195, 42, 0, 46, "Subsection"],
Cell[1361568, 56197, 562, 22, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1362167, 56224, 40, 0, 46, "Subsection"],
Cell[1362210, 56226, 570, 22, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1362817, 56253, 49, 0, 46, "Subsection"],
Cell[1362869, 56255, 1043, 40, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1363949, 56300, 39, 0, 46, "Subsection"],
Cell[1363991, 56302, 148, 5, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1364176, 56312, 44, 0, 46, "Subsection"],
Cell[1364223, 56314, 486, 16, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1364746, 56335, 37, 0, 46, "Subsection"],
Cell[1364786, 56337, 647, 27, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1365470, 56369, 43, 0, 36, "Subsection"],
Cell[1365516, 56371, 206, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1365759, 56382, 42, 0, 36, "Subsection"],
Cell[1365804, 56384, 157, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1365998, 56394, 36, 0, 36, "Subsection"],
Cell[1366037, 56396, 335, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1366409, 56411, 39, 0, 36, "Subsection"],
Cell[1366451, 56413, 212, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1366700, 56424, 38, 0, 36, "Subsection"],
Cell[1366741, 56426, 176, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1366954, 56437, 37, 0, 36, "Subsection"],
Cell[1366994, 56439, 321, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1367352, 56453, 46, 0, 36, "Subsection"],
Cell[1367401, 56455, 1158, 44, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1368596, 56504, 44, 0, 36, "Subsection"],
Cell[1368643, 56506, 370, 11, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1369050, 56522, 50, 0, 36, "Subsection"],
Cell[1369103, 56524, 562, 23, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1369702, 56552, 45, 0, 36, "Subsection"],
Cell[1369750, 56554, 1183, 37, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1370970, 56596, 48, 0, 36, "Subsection"],
Cell[1371021, 56598, 209, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1371267, 56609, 45, 0, 36, "Subsection"],
Cell[1371315, 56611, 880, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1372232, 56650, 57, 0, 36, "Subsection"],
Cell[1372292, 56652, 589, 20, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1372918, 56677, 51, 0, 36, "Subsection"],
Cell[1372972, 56679, 468, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1373477, 56700, 42, 0, 36, "Subsection"],
Cell[1373522, 56702, 727, 28, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1374286, 56735, 47, 0, 36, "Subsection"],
Cell[1374336, 56737, 441, 14, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1374814, 56756, 36, 0, 36, "Subsection"],
Cell[1374853, 56758, 1367, 53, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1376257, 56816, 43, 0, 36, "Subsection"],
Cell[1376303, 56818, 1076, 44, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1377416, 56867, 40, 0, 36, "Subsection"],
Cell[1377459, 56869, 185, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1377681, 56881, 35, 0, 36, "Subsection"],
Cell[1377719, 56883, 1052, 46, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1378808, 56934, 30, 0, 36, "Subsection"],
Cell[1378841, 56936, 1835, 81, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1380713, 57022, 33, 0, 36, "Subsection"],
Cell[1380749, 57024, 790, 23, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1381576, 57052, 49, 0, 36, "Subsection"],
Cell[1381628, 57054, 952, 42, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1382617, 57101, 29, 0, 36, "Subsection"],
Cell[1382649, 57103, 245, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1382931, 57118, 30, 0, 36, "Subsection"],
Cell[1382964, 57120, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1383247, 57135, 31, 0, 36, "Subsection"],
Cell[1383281, 57137, 247, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1383565, 57152, 30, 0, 36, "Subsection"],
Cell[1383598, 57154, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1383881, 57169, 30, 0, 36, "Subsection"],
Cell[1383914, 57171, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1384197, 57186, 30, 0, 36, "Subsection"],
Cell[1384230, 57188, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1384513, 57203, 30, 0, 36, "Subsection"],
Cell[1384546, 57205, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1384829, 57220, 30, 0, 36, "Subsection"],
Cell[1384862, 57222, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1385145, 57237, 30, 0, 36, "Subsection"],
Cell[1385178, 57239, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1385461, 57254, 30, 0, 36, "Subsection"],
Cell[1385494, 57256, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1385777, 57271, 30, 0, 36, "Subsection"],
Cell[1385810, 57273, 246, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1386093, 57288, 29, 0, 36, "Subsection"],
Cell[1386125, 57290, 771, 23, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1386933, 57318, 41, 0, 36, "Subsection"],
Cell[1386977, 57320, 878, 26, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1387892, 57351, 28, 0, 36, "Subsection"],
Cell[1387923, 57353, 1782, 51, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1389742, 57409, 41, 0, 36, "Subsection"],
Cell[1389786, 57411, 420, 20, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1390243, 57436, 38, 0, 36, "Subsection"],
Cell[1390284, 57438, 668, 27, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1390989, 57470, 31, 0, 36, "Subsection"],
Cell[1391023, 57472, 1532, 57, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1392592, 57534, 40, 0, 36, "Subsection"],
Cell[1392635, 57536, 506, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1393178, 57557, 32, 0, 36, "Subsection"],
Cell[1393213, 57559, 185, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1393435, 57572, 38, 0, 36, "Subsection"],
Cell[1393476, 57574, 197, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1393710, 57587, 30, 0, 36, "Subsection"],
Cell[1393743, 57589, 1425, 53, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1395205, 57647, 32, 0, 36, "Subsection"],
Cell[1395240, 57649, 185, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1395462, 57662, 41, 0, 36, "Subsection"],
Cell[1395506, 57664, 203, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1395746, 57677, 41, 0, 36, "Subsection"],
Cell[1395790, 57679, 203, 8, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1396030, 57692, 40, 0, 36, "Subsection"],
Cell[1396073, 57694, 971, 32, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1397081, 57731, 31, 0, 36, "Subsection"],
Cell[1397115, 57733, 1618, 68, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1398770, 57806, 34, 0, 36, "Subsection"],
Cell[1398807, 57808, 1200, 50, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1400044, 57863, 32, 0, 36, "Subsection"],
Cell[1400079, 57865, 266, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1400382, 57880, 42, 0, 36, "Subsection"],
Cell[1400427, 57882, 1903, 82, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1402367, 57969, 40, 0, 36, "Subsection"],
Cell[1402410, 57971, 1705, 75, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404152, 58051, 29, 0, 36, "Subsection"],
Cell[1404184, 58053, 442, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404663, 58071, 29, 0, 36, "Subsection"],
Cell[1404695, 58073, 790, 36, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1405522, 58114, 34, 0, 36, "Subsection"],
Cell[1405559, 58116, 3334, 113, 148, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1408930, 58234, 41, 0, 36, "Subsection"],
Cell[1408974, 58236, 3098, 104, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1412109, 58345, 36, 0, 36, "Subsection"],
Cell[1412148, 58347, 5252, 195, 200, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1417437, 58547, 35, 0, 36, "Subsection"],
Cell[1417475, 58549, 320, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1417832, 58568, 48, 0, 36, "Subsection"],
Cell[1417883, 58570, 814, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1418734, 58609, 39, 0, 36, "Subsection"],
Cell[1418776, 58611, 767, 31, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1419580, 58647, 45, 0, 36, "Subsection"],
Cell[1419628, 58649, 768, 30, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1420433, 58684, 45, 0, 36, "Subsection"],
Cell[1420481, 58686, 811, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1421329, 58725, 36, 0, 36, "Subsection"],
Cell[1421368, 58727, 2086, 87, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1423491, 58819, 31, 0, 36, "Subsection"],
Cell[1423525, 58821, 2891, 131, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1426453, 58957, 47, 0, 36, "Subsection"],
Cell[1426503, 58959, 550, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1427090, 58986, 31, 0, 36, "Subsection"],
Cell[1427124, 58988, 3179, 136, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1430340, 59129, 33, 0, 36, "Subsection"],
Cell[1430376, 59131, 167, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1430580, 59143, 39, 0, 36, "Subsection"],
Cell[1430622, 59145, 600, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1431259, 59172, 34, 0, 36, "Subsection"],
Cell[1431296, 59174, 839, 34, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1432172, 59213, 39, 0, 46, "Subsection"],
Cell[1432214, 59215, 990, 43, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1433241, 59263, 35, 0, 46, "Subsection"],
Cell[1433279, 59265, 4071, 155, 248, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1437387, 59425, 33, 0, 46, "Subsection"],
Cell[1437423, 59427, 2263, 91, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1439723, 59523, 39, 0, 46, "Subsection"],
Cell[1439765, 59525, 618, 22, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1440420, 59552, 43, 0, 46, "Subsection"],
Cell[1440466, 59554, 773, 28, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1441276, 59587, 43, 0, 46, "Subsection"],
Cell[1441322, 59589, 681, 24, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1442040, 59618, 46, 0, 46, "Subsection"],
Cell[1442089, 59620, 690, 24, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1442816, 59649, 31, 0, 46, "Subsection"],
Cell[1442850, 59651, 2332, 95, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1445219, 59751, 31, 0, 46, "Subsection"],
Cell[1445253, 59753, 1079, 36, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1446369, 59794, 36, 0, 46, "Subsection"],
Cell[1446408, 59796, 1706, 72, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1448151, 59873, 54, 0, 46, "Subsection"],
Cell[1448208, 59875, 549, 22, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1448794, 59902, 43, 0, 36, "Subsection"],
Cell[1448840, 59904, 545, 22, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1449422, 59931, 39, 0, 36, "Subsection"],
Cell[1449464, 59933, 551, 22, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1450052, 59960, 37, 0, 36, "Subsection"],
Cell[1450092, 59962, 409, 15, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1450538, 59982, 36, 0, 36, "Subsection"],
Cell[1450577, 59984, 610, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1451224, 60011, 35, 0, 36, "Subsection"],
Cell[1451262, 60013, 1014, 44, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1452313, 60062, 33, 0, 36, "Subsection"],
Cell[1452349, 60064, 1588, 65, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1453974, 60134, 32, 0, 36, "Subsection"],
Cell[1454009, 60136, 10945, 428, 396, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1464991, 60569, 32, 0, 36, "Subsection"],
Cell[1465026, 60571, 456, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1465519, 60589, 25, 0, 36, "Subsection"],
Cell[1465547, 60591, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1465825, 60606, 26, 0, 36, "Subsection"],
Cell[1465854, 60608, 242, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1466133, 60623, 25, 0, 36, "Subsection"],
Cell[1466161, 60625, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1466439, 60640, 25, 0, 36, "Subsection"],
Cell[1466467, 60642, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1466745, 60657, 25, 0, 36, "Subsection"],
Cell[1466773, 60659, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1467051, 60674, 25, 0, 36, "Subsection"],
Cell[1467079, 60676, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1467357, 60691, 25, 0, 36, "Subsection"],
Cell[1467385, 60693, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1467663, 60708, 25, 0, 36, "Subsection"],
Cell[1467691, 60710, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1467969, 60725, 25, 0, 36, "Subsection"],
Cell[1467997, 60727, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1468275, 60742, 25, 0, 36, "Subsection"],
Cell[1468303, 60744, 241, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1468581, 60759, 32, 0, 36, "Subsection"],
Cell[1468616, 60761, 544, 23, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1469197, 60789, 32, 0, 36, "Subsection"],
Cell[1469232, 60791, 1677, 71, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1470946, 60867, 35, 0, 36, "Subsection"],
Cell[1470984, 60869, 1178, 50, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1472199, 60924, 30, 0, 36, "Subsection"],
Cell[1472232, 60926, 345, 14, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1472614, 60945, 53, 0, 36, "Subsection"],
Cell[1472670, 60947, 515, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1473222, 60971, 31, 0, 36, "Subsection"],
Cell[1473256, 60973, 869, 36, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1474162, 61014, 41, 0, 36, "Subsection"],
Cell[1474206, 61016, 1425, 66, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1475668, 61087, 36, 0, 36, "Subsection"],
Cell[1475707, 61089, 605, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1476349, 61116, 40, 0, 36, "Subsection"],
Cell[1476392, 61118, 897, 37, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1477326, 61160, 47, 0, 36, "Subsection"],
Cell[1477376, 61162, 836, 33, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1478249, 61200, 26, 0, 36, "Subsection"],
Cell[1478278, 61202, 217, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1478532, 61213, 26, 0, 36, "Subsection"],
Cell[1478561, 61215, 215, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1478813, 61226, 28, 0, 36, "Subsection"],
Cell[1478844, 61228, 205, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1479086, 61242, 37, 0, 36, "Subsection"],
Cell[1479126, 61244, 851, 38, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1480014, 61287, 28, 0, 36, "Subsection"],
Cell[1480045, 61289, 162, 7, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1480244, 61301, 38, 0, 36, "Subsection"],
Cell[1480285, 61303, 386, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1480708, 61321, 41, 0, 36, "Subsection"],
Cell[1480752, 61323, 647, 25, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1481436, 61353, 41, 0, 36, "Subsection"],
Cell[1481480, 61355, 597, 25, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1482114, 61385, 35, 0, 36, "Subsection"],
Cell[1482152, 61387, 1130, 46, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1483319, 61438, 27, 0, 36, "Subsection"],
Cell[1483349, 61440, 315, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1483701, 61454, 39, 0, 36, "Subsection"],
Cell[1483743, 61456, 800, 28, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1484580, 61489, 33, 0, 36, "Subsection"],
Cell[1484616, 61491, 1150, 42, 76, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1485803, 61538, 32, 0, 36, "Subsection"],
Cell[1485838, 61540, 261, 12, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1486136, 61557, 37, 0, 36, "Subsection"],
Cell[1486176, 61559, 1169, 47, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1487382, 61611, 30, 0, 36, "Subsection"],
Cell[1487415, 61613, 522, 18, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1487974, 61636, 36, 0, 36, "Subsection"],
Cell[1488013, 61638, 767, 34, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1488817, 61677, 39, 0, 36, "Subsection"],
Cell[1488859, 61679, 2869, 106, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1491765, 61790, 33, 0, 36, "Subsection"],
Cell[1491801, 61792, 3644, 151, 236, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1495482, 61948, 32, 0, 36, "Subsection"],
Cell[1495517, 61950, 2738, 104, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1498292, 62059, 38, 0, 36, "Subsection"],
Cell[1498333, 62061, 1269, 43, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1499639, 62109, 39, 0, 36, "Subsection"],
Cell[1499681, 62111, 759, 29, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1500477, 62145, 28, 0, 36, "Subsection"],
Cell[1500508, 62147, 1402, 45, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1501947, 62197, 38, 0, 36, "Subsection"],
Cell[1501988, 62199, 1246, 47, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1503271, 62251, 39, 0, 36, "Subsection"],
Cell[1503313, 62253, 1790, 67, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1505140, 62325, 26, 0, 36, "Subsection"],
Cell[1505169, 62327, 382, 18, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1505588, 62350, 37, 0, 36, "Subsection"],
Cell[1505628, 62352, 1299, 51, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1506964, 62408, 33, 0, 36, "Subsection"],
Cell[1507000, 62410, 2810, 100, 126, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1509847, 62515, 35, 0, 36, "Subsection"],
Cell[1509885, 62517, 2626, 94, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1512548, 62616, 34, 0, 36, "Subsection"],
Cell[1512585, 62618, 316, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1512938, 62632, 46, 0, 36, "Subsection"],
Cell[1512987, 62634, 580, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1513604, 62655, 41, 0, 36, "Subsection"],
Cell[1513648, 62657, 574, 16, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1514259, 62678, 38, 0, 36, "Subsection"],
Cell[1514300, 62680, 474, 21, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1514811, 62706, 43, 0, 36, "Subsection"],
Cell[1514857, 62708, 198, 6, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1515092, 62719, 32, 0, 36, "Subsection"],
Cell[1515127, 62721, 415, 18, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1515579, 62744, 35, 0, 36, "Subsection"],
Cell[1515617, 62746, 299, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1515953, 62762, 37, 0, 36, "Subsection"],
Cell[1515993, 62764, 345, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1516375, 62780, 37, 0, 36, "Subsection"],
Cell[1516415, 62782, 225, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1516677, 62797, 36, 0, 36, "Subsection"],
Cell[1516716, 62799, 212, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1516965, 62814, 33, 0, 36, "Subsection"],
Cell[1517001, 62816, 260, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1517298, 62831, 46, 0, 36, "Subsection"],
Cell[1517347, 62833, 407, 15, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1517791, 62853, 37, 0, 36, "Subsection"],
Cell[1517831, 62855, 219, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1518087, 62869, 33, 0, 36, "Subsection"],
Cell[1518123, 62871, 203, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1518363, 62885, 37, 0, 36, "Subsection"],
Cell[1518403, 62887, 221, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1518661, 62901, 38, 0, 36, "Subsection"],
Cell[1518702, 62903, 221, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1518960, 62917, 40, 0, 36, "Subsection"],
Cell[1519003, 62919, 247, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1519287, 62934, 36, 0, 36, "Subsection"],
Cell[1519326, 62936, 223, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1519586, 62950, 40, 0, 36, "Subsection"],
Cell[1519629, 62952, 237, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1519903, 62966, 37, 0, 36, "Subsection"],
Cell[1519943, 62968, 211, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1520191, 62982, 43, 0, 36, "Subsection"],
Cell[1520237, 62984, 214, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1520488, 62998, 36, 0, 36, "Subsection"],
Cell[1520527, 63000, 217, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1520781, 63014, 38, 0, 36, "Subsection"],
Cell[1520822, 63016, 212, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1521071, 63030, 40, 0, 36, "Subsection"],
Cell[1521114, 63032, 239, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1521390, 63046, 47, 0, 36, "Subsection"],
Cell[1521440, 63048, 247, 9, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1521724, 63062, 40, 0, 36, "Subsection"],
Cell[1521767, 63064, 429, 19, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1522233, 63088, 44, 0, 36, "Subsection"],
Cell[1522280, 63090, 265, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1522582, 63105, 29, 0, 36, "Subsection"],
Cell[1522614, 63107, 365, 10, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1523016, 63122, 41, 0, 36, "Subsection"],
Cell[1523060, 63124, 480, 21, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1523577, 63150, 41, 0, 36, "Subsection"],
Cell[1523621, 63152, 577, 23, 68, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

